/*
MySQL Data Transfer
Source Host: 192.168.5.222
Source Database: CMSF_TEST
Target Host: 192.168.5.222
Target Database: CMSF_TEST
Date: 2009/07/14 9:41:12
*/

SET FOREIGN_KEY_CHECKS=0;
-- ----------------------------
-- Table structure for ms_addresses
-- ----------------------------
DROP TABLE IF EXISTS `ms_addresses`;
CREATE TABLE `ms_addresses` (
  `id` int(11) unsigned NOT NULL auto_increment,
  `created_by` varchar(20) default NULL,
  `created_at` timestamp NULL default NULL,
  `updated_by` varchar(20) default NULL,
  `updated_at` timestamp NULL default NULL on update CURRENT_TIMESTAMP,
  `name` varchar(255) default NULL,
  `pred_cd` char(2) default NULL,
  `city_cd` char(5) default NULL,
  `zip` char(8) default NULL,
  `pref_name` varchar(20) default NULL,
  `pref_kana` varchar(20) default NULL,
  `city_name` varchar(50) default NULL,
  `city_kana` varchar(50) default NULL,
  `area_name` varchar(50) default NULL,
  `area_kana` varchar(50) default NULL,
  `area_memo` varchar(100) default NULL,
  `street_name` varchar(255) default NULL,
  `aza_name` varchar(50) default NULL,
  `aza_kana` varchar(50) default NULL,
  PRIMARY KEY  (`id`),
  KEY `idx_zip` (`zip`),
  KEY `idx_address1` (`pref_name`,`city_name`,`area_name`,`street_name`,`aza_name`),
  KEY `idx_address2` (`city_name`,`area_name`,`street_name`,`aza_kana`),
  KEY `idx_address3` (`city_name`,`area_kana`,`street_name`,`aza_name`),
  KEY `idx_prefcd_companyflg` (`pred_cd`)
) DEFAULT CHARSET=utf8;

-- ----------------------------
-- Table structure for ms_addresses_pref
-- ----------------------------
DROP TABLE IF EXISTS `ms_addresses_pref`;
CREATE TABLE `ms_addresses_pref` (
  `id` int(11) unsigned NOT NULL auto_increment,
  `created_by` varchar(255) default NULL,
  `created_at` timestamp NULL default NULL,
  `updated_by` varchar(255) default NULL,
  `updated_at` timestamp NULL default NULL on update CURRENT_TIMESTAMP,
  `name` varchar(50) default NULL,
  `pred_cd` char(2) default NULL,
  PRIMARY KEY  (`id`),
  KEY `idx_prefcd` (`pred_cd`)
) DEFAULT CHARSET=utf8;

-- ----------------------------
-- Function structure for CMSF_FUNC_ADDRESS2POSTALCODE
-- ----------------------------
DROP FUNCTION IF EXISTS `CMSF_FUNC_ADDRESS2POSTALCODE`;
DELIMITER ;;
CREATE FUNCTION `CMSF_FUNC_ADDRESS2POSTALCODE`(p_address_full text, p_strict_flg varchar(10)) RETURNS text CHARSET utf8
BEGIN
/**
 * 住所から7桁郵便番号に変換する関数
 *
 * @package     CMSF
 * @category    CMSF_FUNC_ADDRESS2POSTALCODE
 * @param       text              p_address_full   住所
 * @param       varchar(10)       p_strict_flg     正確フラグ
 * @return      text                               name
 * @example
 * @license     LGPL version 3 - http://www.gnu.org/licenses/lgpl.html
 * @copyright   2009 Yuusuke takagi <nya.takasan@gmail.com>
 * @link        http://sourceforge.jp/projects/cmsf/
 * @author      Yuusuke takagi <nya.takasan@gmail.com>
 * @version     $Revision: 0.0.1 2009/07/13 初期リリース Yuusuke takagi <nya.takasan@gmail.com>$
 * @since
 * @see         CMSF_FUNC_GET_MASTER
 * @require     MYSQL 5.0.0 or higther
 */
 /*------------------------------------------------------
    変数定義
 -------------------------------------------------------*/
 declare w_result                       text            default '';             /*  変換文字列 */

 /* ログ関連 */
 declare w_log_result                   varchar(255)    default '';             /* Log 結果 */
 declare w_log_query                    varchar(2000)   default '';             /*  Query Log */

 /* ユーザー定義変数 */
 declare w_zip                          varchar(10)      default '';           /*  文字列 */
 declare w_address_full                 text             default '';           /*  文字列 */
 declare w_pref_name                    varchar(50)      default '';           /*  文字列 */
 declare w_city_name                    varchar(50)      default '';           /*  文字列 */
 declare w_address_name                 varchar(50)      default '';           /*  文字列 */
 declare w_building_name                varchar(50)      default '';           /*  文字列 */

 declare w_maxnum                       int(18)          default 0;            /*  文字列 */

 declare w_strict_flg                   varchar(10)      default 0;            /*  文字列 */

 /*------------------------------------------------------
    ユーザ例外定義
  -------------------------------------------------------*/

 /*------------------------------------------------------
    定数定義
 -------------------------------------------------------*/
 declare s_empty_string                 varchar(255)    default '';             /*  空文字 */
 declare s_true                         varchar(255)    default 1;              /*  TRUE  FLG*/
 declare s_false                        varchar(255)    default 0;              /*  FALSE FLG */

 /* ログ関連 */
 declare s_log_flg                      int(1)          default 0;              /*  エラー処理フラグ ON:1 OFF:0 */

/*
 ログ出力サンプル SQLログ

 SET w_log_query = CONCAT(
 "    SQL"
 );

 SET w_log_result = CMSF_FUNC_PUT_LOG( s_log_created_by , s_log_prj_name , s_log_apps_name , s_log_mod_name , s_log_prg_var , s_log_type_text
                                     , '処理名称' , w_log_query , 'ログ1' , 'ログ2' , 'ログ3' , 'ログ4' , 'ログ5' );

 ログ出力サンプル テキストログ

 SET w_log_result = CMSF_FUNC_PUT_LOG( s_log_created_by , s_log_prj_name , s_log_apps_name , s_log_mod_name , s_log_prg_var , s_log_type_text
                                     , '処理名称' , ''  , 'ログ1' , 'ログ2' , 'ログ3' , 'ログ4' , 'ログ5' );
*/
 declare s_log_prj_name                 varchar(255)    default 'CMSF';                                 /*  プロジェクト名 */
 declare s_log_apps_name                varchar(255)    default 'CMSF_FUNC_ADDRESS_IDENTIFICATION';     /*  アプリケーション名 */
 declare s_log_mod_name                 varchar(255)    default 'CMSF_FUNC_ADDRESS2POSTALCODE';         /*  モジュール名 */
 declare s_log_prg_var                  varchar(255)    default '0.0.1';                                /*  モジュールバージョン */

 declare s_log_created_by               varchar(255)    default 'SYSTEM';               /*  ログ作成者 */

 declare s_log_type_insert              varchar(255)    default 'INSERT';               /*  ログタイプ:INSERT  */
 declare s_log_type_select              varchar(255)    default 'SELECT';               /*  ログタイプ:SELECT  */
 declare s_log_type_update              varchar(255)    default 'UPDATE';               /*  ログタイプ:UPDATE */
 declare s_log_type_delete              varchar(255)    default 'DELETE';               /*  ログタイプ:DELETE */

 declare s_log_type_text                varchar(255)    default 'TEXT';                 /*  ログタイプ:TEXT */

 declare s_log_type_error               varchar(255)    default 'ERROR';                /*  ログタイプ:ERROR */

 declare s_log_type_tmp                 varchar(255)    default 'TEMPORARY';            /*  ログタイプ:TEMPORARY */

 /* ユーザー定義定数 */


 /*------------------------------------------------------
    カーソル定義
 -------------------------------------------------------*/
  /*--------------------------------------------
   カーソル説明
  ---------------------------------------------*/

 /*----------------------------------------------------------
   処理定義
 -----------------------------------------------------------*/
 /* 1.0 初期処理*/
 SET w_address_full     = REPLACE(REPLACE(p_address_full,'　',''),' ','');
 SET w_strict_flg       = p_strict_flg;

 /*  ログ出力*/
 IF( s_log_flg = 1 ) THEN
        SET w_log_result =  CMSF_FUNC_PUT_LOG( s_log_created_by , s_log_prj_name , s_log_apps_name , s_log_mod_name , s_log_prg_var , s_log_type_text
                                             , CONCAT( '1.0 初期処理 パラメータ:' , p_address  ) , '' , '' , '' , '' , '' , '' );
 END IF;

 /* 2.1.1 住所から最もマッチする住所の文字数を取得*/
SELECT
 STRAIGHT_JOIN
 MAX( CHAR_LENGTH( CONCAT( COALESCE( ms_addresses.pref_name , '')
		, COALESCE( ms_addresses.city_name , '')
		, COALESCE( ms_addresses.area_name , '')
		, COALESCE( ms_addresses.aza_name , '')
		, COALESCE( ms_addresses.street_name , '') ) ) )
INTO w_maxnum
FROM ms_addresses_pref
INNER JOIN ms_addresses
ON ms_addresses.pred_cd = ms_addresses_pref.pred_cd
AND (( w_address_full like CONCAT( COALESCE( ms_addresses.pref_name , '')
			, COALESCE( ms_addresses.city_name , '')
			, COALESCE( ms_addresses.area_name , '')
			, REPLACE(COALESCE( ms_addresses.aza_name , ''),'丁目','')
			, COALESCE( ms_addresses.street_name , '')
			, '%' ) )
	OR ( w_address_full like CONCAT( COALESCE( ms_addresses.city_name , '')
			, COALESCE( ms_addresses.area_name , '')
			, REPLACE(COALESCE( ms_addresses.aza_name , ''),'丁目','')
			, COALESCE( ms_addresses.street_name , '')
			, '%' ) )
	OR ( w_address_full like CONCAT( COALESCE( ms_addresses.pref_name , '')
			, COALESCE( ms_addresses.city_name , '')
			, COALESCE( ms_addresses.area_name , '')
			, REPLACE(COALESCE( ms_addresses.aza_name , ''),'丁目','')
			, '%' ) )
	OR ( w_address_full like CONCAT( COALESCE( ms_addresses.city_name , '')
			, COALESCE( ms_addresses.area_name , '')
			, REPLACE(COALESCE( ms_addresses.aza_name , ''),'丁目','')
			, '%' ) ) )
WHERE w_address_full like CONCAT( ms_addresses_pref.name , '%');

 /*  ログ出力*/
 IF( s_log_flg = 1 ) THEN

 SET w_log_query = CONCAT(
 "SELECT"
," STRAIGHT_JOIN"
," MAX( CHAR_LENGTH( CONCAT( COALESCE( ms_addresses.pref_name , '')"
,"		, COALESCE( ms_addresses.city_name , '')"
,"		, COALESCE( ms_addresses.area_name , '')"
,"		, COALESCE( ms_addresses.aza_name , '')"
,"		, COALESCE( ms_addresses.street_name , '') ) ) )"
,"INTO w_maxnum"
,"FROM ms_addresses_pref"
,"INNER JOIN ms_addresses"
,"ON ms_addresses.pred_cd = ms_addresses_pref.pred_cd"
,"AND ms_addresses.company_flg = 0"
,"AND (( '", w_address_full ,"' like CONCAT( COALESCE( ms_addresses.pref_name , '')"
,"			, COALESCE( ms_addresses.city_name , '')"
,"			, COALESCE( ms_addresses.area_name , '')"
,"			, REPLACE(COALESCE( ms_addresses.aza_name , ''),'丁目','')"
,"			, COALESCE( ms_addresses.street_name , '')"
,"			, '%' ) )"
,"	OR ( '", w_address_full ,"' like CONCAT( COALESCE( ms_addresses.city_name , '')"
,"			, COALESCE( ms_addresses.area_name , '')"
,"			, REPLACE(COALESCE( ms_addresses.aza_name , ''),'丁目','')"
,"			, COALESCE( ms_addresses.street_name , '')"
,"			, '%' ) )"
,"	OR ( '", w_address_full ,"' like CONCAT( COALESCE( ms_addresses.pref_name , '')"
,"			, COALESCE( ms_addresses.city_name , '')"
,"			, COALESCE( ms_addresses.area_name , '')"
,"			, REPLACE(COALESCE( ms_addresses.aza_name , ''),'丁目','')"
,"			, '%' ) )"
,"	OR ( '", w_address_full ,"' like CONCAT( COALESCE( ms_addresses.city_name , '')"
,"			, COALESCE( ms_addresses.area_name , '')"
,"			, REPLACE(COALESCE( ms_addresses.aza_name , ''),'丁目','')"
,"			, '%' ) ) )"
,"WHERE '", w_address_full ,"' like CONCAT( ms_addresses_pref.name , '%');"
 );

   SET w_log_result = CMSF_FUNC_PUT_LOG( s_log_created_by , s_log_prj_name , s_log_apps_name , s_log_mod_name , s_log_prg_var , s_log_type_select
                                       , '2.1.1 住所から最もマッチする住所の文字数を取得 ' , w_log_query  , s_empty_string , s_empty_string , s_empty_string , s_empty_string , s_empty_string );
 END IF;

/* 2.1.2 住所から最もマッチする住所の郵便番号を取得*/
SELECT
 STRAIGHT_JOIN
  CONCAT( SUBSTRING(ms_addresses.zip , 1 , 3 ) , '-' , SUBSTRING(ms_addresses.zip , 4 , 4 ) )
 INTO w_result
FROM ms_addresses_pref
INNER JOIN ms_addresses
ON ms_addresses.pred_cd = ms_addresses_pref.pred_cd
AND (( w_address_full like CONCAT( COALESCE( ms_addresses.pref_name , '')
			, COALESCE( ms_addresses.city_name , '')
			, COALESCE( ms_addresses.area_name , '')
			, REPLACE(COALESCE( ms_addresses.aza_name , ''),'丁目','')
			, COALESCE( ms_addresses.street_name , '')
			, '%' ) )
	OR ( w_address_full like CONCAT( COALESCE( ms_addresses.city_name , '')
			, COALESCE( ms_addresses.area_name , '')
			, REPLACE(COALESCE( ms_addresses.aza_name , ''),'丁目','')
			, COALESCE( ms_addresses.street_name , '')
			, '%' ) )
	OR ( w_address_full like CONCAT( COALESCE( ms_addresses.pref_name , '')
			, COALESCE( ms_addresses.city_name , '')
			, COALESCE( ms_addresses.area_name , '')
			, REPLACE(COALESCE( ms_addresses.aza_name , ''),'丁目','')
			, '%' ) )
	OR ( w_address_full like CONCAT( COALESCE( ms_addresses.city_name , '')
			, COALESCE( ms_addresses.area_name , '')
			, REPLACE(COALESCE( ms_addresses.aza_name , ''),'丁目','')
			, '%' ) ) )
WHERE w_address_full like CONCAT( ms_addresses_pref.name , '%')
  AND CHAR_LENGTH( CONCAT( COALESCE( ms_addresses.pref_name , '')
		, COALESCE( ms_addresses.city_name , '')
		, COALESCE( ms_addresses.area_name , '')
		, COALESCE( ms_addresses.aza_name , '')
		, COALESCE( ms_addresses.street_name , '') ) ) = w_maxnum
ORDER BY ms_addresses.zip
limit 1;

 /*  ログ出力*/
 IF( s_log_flg = 1 ) THEN

 SET w_log_query = CONCAT(
 "SELECT"
," STRAIGHT_JOIN"
,"  CONCAT( SUBSTRING(ms_addresses.zip , 1 , 3 ) , '-' , SUBSTRING(ms_addresses.zip , 4 , 4 ) )"
," INTO w_result"
,"FROM ms_addresses_pref"
,"INNER JOIN ms_addresses"
,"ON ms_addresses.pred_cd = ms_addresses_pref.pred_cd"
,"AND (( '", w_address_full ,"' like CONCAT( COALESCE( ms_addresses.pref_name , '')"
,"			, COALESCE( ms_addresses.city_name , '')"
,"			, COALESCE( ms_addresses.area_name , '')"
,"			, REPLACE(COALESCE( ms_addresses.aza_name , ''),'丁目','')"
,"			, COALESCE( ms_addresses.street_name , '')"
,"			, '%' ) )"
,"	OR ( '", w_address_full ,"' like CONCAT( COALESCE( ms_addresses.city_name , '')"
,"			, COALESCE( ms_addresses.area_name , '')"
,"			, REPLACE(COALESCE( ms_addresses.aza_name , ''),'丁目','')"
,"			, COALESCE( ms_addresses.street_name , '')"
,"			, '%' ) )"
,"	OR ( '", w_address_full ,"' like CONCAT( COALESCE( ms_addresses.pref_name , '')"
,"			, COALESCE( ms_addresses.city_name , '')"
,"			, COALESCE( ms_addresses.area_name , '')"
,"			, REPLACE(COALESCE( ms_addresses.aza_name , ''),'丁目','')"
,"			, '%' ) )"
,"	OR ( '", w_address_full ,"' like CONCAT( COALESCE( ms_addresses.city_name , '')"
,"			, COALESCE( ms_addresses.area_name , '')"
,"			, REPLACE(COALESCE( ms_addresses.aza_name , ''),'丁目','')"
,"			, '%' ) ) )"
,"WHERE '", w_address_full ,"' like CONCAT( ms_addresses_pref.name , '%')"
,"  AND CHAR_LENGTH( CONCAT( COALESCE( ms_addresses.pref_name , '')"
,"		, COALESCE( ms_addresses.city_name , '')"
,"		, COALESCE( ms_addresses.area_name , '')"
,"		, COALESCE( ms_addresses.aza_name , '')"
,"		, COALESCE( ms_addresses.street_name , '') ) ) = w_maxnum"
,"ORDER BY ms_addresses.zip"
,"limit 1;"
 );

   SET w_log_result = CMSF_FUNC_PUT_LOG( s_log_created_by , s_log_prj_name , s_log_apps_name , s_log_mod_name , s_log_prg_var , s_log_type_select
                                       , '2.1.1 住所から最もマッチする住所の郵便番号を取得 ' , w_log_query  , s_empty_string , s_empty_string , s_empty_string , s_empty_string , s_empty_string );
 END IF;

/* 2.1.3 STRICTフラグが有効の場合、郵便番号の下4けたが 0000 の場合 null を返す */
IF( w_strict_flg = TRUE AND SUBSTRING( w_result , 5 , 4 ) = '0000' )THEN

  SET w_result = NULL;

  /*  ログ出力*/
  IF( s_log_flg = 1 ) THEN
    SET w_log_result = CMSF_FUNC_PUT_LOG( s_log_created_by , s_log_prj_name , s_log_apps_name , s_log_mod_name , s_log_prg_var , s_log_type_text
                                       , '2.1.1 STRICTフラグが有効の場合、郵便番号の下4けたが 0000 の場合 null を返す ' , s_empty_string  , s_empty_string , s_empty_string , s_empty_string , s_empty_string , s_empty_string );
  END IF;

END IF;

 /*  ログ出力処理  */
 IF( s_log_flg = 1 ) THEN
        SET w_log_result =  CMSF_FUNC_PUT_LOG( s_log_created_by , s_log_prj_name , s_log_apps_name , s_log_mod_name , s_log_prg_var , s_log_type_text
                                             , CONCAT( '9.9.9 処理完了 :' , w_result  ) , '' , '' , '' , '' , '' , '' );
 END IF;

 return w_result;

END;;
DELIMITER ;

-- ----------------------------
-- Records 
-- ----------------------------
INSERT INTO `ms_addresses` VALUES ('1', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区', '01', '01102', '0010000', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('2', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市', '05', '05201', '0100000', '秋田県', 'アキタケン', '秋田市', 'アキタシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('3', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区', '13', '13101', '1000000', '東京都', 'トウキョウト', '千代田区', 'チヨダク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('4', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区千代田', '13', '13101', '1000001', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '千代田', 'チヨダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区皇居外苑', '13', '13101', '1000002', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '皇居外苑', 'コウキョガイエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区一ツ橋1丁目', '13', '13101', '1000003', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '一ツ橋', 'ヒトツバシ', null, null, '1丁目', '01チョウメ');
INSERT INTO `ms_addresses` VALUES ('7', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区大手町', '13', '13101', '1000004', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '大手町', 'オオテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内', '13', '13101', '1000005', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区有楽町', '13', '13101', '1000006', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '有楽町', 'ユウラクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市中通', '05', '05201', '0100001', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '中通', 'ナカドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区内幸町', '13', '13101', '1000011', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '内幸町', 'ウチサイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区日比谷公園', '13', '13101', '1000012', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '日比谷公園', 'ヒビヤコウエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区霞が関', '13', '13101', '1000013', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '霞が関', 'カスミガセキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区永田町', '13', '13101', '1000014', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '永田町', 'ナガタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市東通仲町', '05', '05201', '0100002', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '東通仲町', 'ヒガシドオリナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市東通', '05', '05201', '0100003', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '東通', 'ヒガシドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市東通観音前', '05', '05201', '0100004', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '東通観音前', 'ヒガシドオリカンノンマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市東通明田', '05', '05201', '0100005', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '東通明田', 'ヒガシドオリミョウデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市東通館ノ越', '05', '05201', '0100006', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '東通館ノ越', 'ヒガシドオリタテノコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都大島町', '13', '13361', '1000100', '東京都', 'トウキョウト', '大島町', 'オオシママチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('21', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都大島町元町', '13', '13361', '1000101', '東京都', 'トウキョウト', '大島町', 'オオシママチ', '元町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都大島町岡田', '13', '13361', '1000102', '東京都', 'トウキョウト', '大島町', 'オオシママチ', '岡田', 'オカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都大島町泉津', '13', '13361', '1000103', '東京都', 'トウキョウト', '大島町', 'オオシママチ', '泉津', 'センヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都大島町野増', '13', '13361', '1000104', '東京都', 'トウキョウト', '大島町', 'オオシママチ', '野増', 'ノマシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市南通亀の町', '05', '05201', '0100011', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '南通亀の町', 'ミナミドオリカメノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市南通みその町', '05', '05201', '0100012', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '南通みその町', 'ミナミドオリミソノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市南通築地', '05', '05201', '0100013', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '南通築地', 'ミナミドオリツキジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市南通宮田', '05', '05201', '0100014', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '南通宮田', 'ミナミドオリミヤタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市楢山登町', '05', '05201', '0100021', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '楢山登町', 'ナラヤマノボリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都大島町差木地', '13', '13361', '1000211', '東京都', 'トウキョウト', '大島町', 'オオシママチ', '差木地', 'サシキジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都大島町波浮港', '13', '13361', '1000212', '東京都', 'トウキョウト', '大島町', 'オオシママチ', '波浮港', 'ハブミナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市楢山南中町', '05', '05201', '0100022', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '楢山南中町', 'ナラヤマミナミナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市楢山本町', '05', '05201', '0100023', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '楢山本町', 'ナラヤマホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市楢山南新町上丁', '05', '05201', '0100024', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '楢山南新町上丁', 'ナラヤマミナミシンマチカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市楢山佐竹町', '05', '05201', '0100025', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '楢山佐竹町', 'ナラヤマサタケマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市楢山古川新町', '05', '05201', '0100026', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '楢山古川新町', 'ナラヤマフルカワシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市楢山南新町下丁', '05', '05201', '0100027', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '楢山南新町下丁', 'ナラヤマミナミシンマチシモチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市楢山共和町', '05', '05201', '0100028', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '楢山共和町', 'ナラヤマキョウワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市楢山川口境', '05', '05201', '0100029', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '楢山川口境', 'ナラヤマカワグチサカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都利島村', '13', '13362', '1000301', '東京都', 'トウキョウト', '利島村', 'トシマムラ', null, '　', '（全域）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('41', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市楢山大元町', '05', '05201', '0100031', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '楢山大元町', 'ナラヤマオオモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市楢山太田町', '05', '05201', '0100032', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '楢山太田町', 'ナラヤマオオタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市楢山石塚町', '05', '05201', '0100033', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '楢山石塚町', 'ナラヤマイシヅカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市楢山', '05', '05201', '0100034', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '楢山', 'ナラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市楢山城南町', '05', '05201', '0100035', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '楢山城南町', 'ナラヤマジョウナンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市楢山金照町', '05', '05201', '0100036', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '楢山金照町', 'ナラヤマキンショウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市楢山愛宕下', '05', '05201', '0100037', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '楢山愛宕下', 'ナラヤマアタゴシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市楢山城南新町', '05', '05201', '0100038', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '楢山城南新町', 'ナラヤマジョウナンシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新島村', '13', '13363', '1000400', '東京都', 'トウキョウト', '新島村', 'ニイジマムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('50', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新島村若郷', '13', '13363', '1000401', '東京都', 'トウキョウト', '新島村', 'ニイジマムラ', '若郷', 'ワカゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新島村本村', '13', '13363', '1000402', '東京都', 'トウキョウト', '新島村', 'ニイジマムラ', '本村', 'ホンソン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市広面', '05', '05201', '0100041', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '広面', 'ヒロオモテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市桜', '05', '05201', '0100042', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '桜', 'サクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市桜ガ丘', '05', '05201', '0100043', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '桜ガ丘', 'サクラガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市横森', '05', '05201', '0100044', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '横森', 'ヨコモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市下北手松崎', '05', '05201', '0100051', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '下北手松崎', 'シモキタテマツサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新島村式根島', '13', '13363', '1000511', '東京都', 'トウキョウト', '新島村', 'ニイジマムラ', '式根島', 'シキネジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市下北手柳舘', '05', '05201', '0100052', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '下北手柳舘', 'シモキタテヤナギタテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市下北手寒川', '05', '05201', '0100053', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '下北手寒川', 'シモキタテサムカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市下北手宝川', '05', '05201', '0100054', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '下北手宝川', 'シモキタテタカラカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市下北手通沢', '05', '05201', '0100055', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '下北手通沢', 'シモキタテトオリサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市下北手黒川', '05', '05201', '0100056', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '下北手黒川', 'シモキタテクロカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市下北手梨平', '05', '05201', '0100057', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '下北手梨平', 'シモキタテナシヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市下北手桜', '05', '05201', '0100058', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '下北手桜', 'シモキタテサクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市桜台', '05', '05201', '0100059', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '桜台', 'サクラダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都神津島村', '13', '13364', '1000601', '東京都', 'トウキョウト', '神津島村', 'コウヅシマムラ', null, '　', '（全域）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('67', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市卸町', '05', '05201', '0100061', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '卸町', 'オロシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市牛島東', '05', '05201', '0100062', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '牛島東', 'ウシジマヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市牛島西', '05', '05201', '0100063', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '牛島西', 'ウシジマニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市牛島', '05', '05201', '0100064', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '牛島', 'ウシジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市茨島', '05', '05201', '0100065', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '茨島', 'バラジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市牛島南', '05', '05201', '0100066', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '牛島南', 'ウシジマミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北10条西1丁目', '01', '01102', '0010010', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北10条西', 'キタ10ジョウニシ', null, null, '1丁目', '01チョウメ');
INSERT INTO `ms_addresses` VALUES ('74', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北10条西2丁目', '01', '01102', '0010010', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北10条西', 'キタ10ジョウニシ', null, null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('75', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北10条西3丁目', '01', '01102', '0010010', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北10条西', 'キタ10ジョウニシ', null, null, '3丁目', '03チョウメ');
INSERT INTO `ms_addresses` VALUES ('76', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北10条西4丁目', '01', '01102', '0010010', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北10条西', 'キタ10ジョウニシ', null, null, '4丁目', '04チョウメ');
INSERT INTO `ms_addresses` VALUES ('77', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県潟上市天王追分', '05', '05211', '0100101', '秋田県', 'アキタケン', '潟上市', 'カタガミシ', '天王', 'テンノウ', null, null, '追分', 'オイワケ');
INSERT INTO `ms_addresses` VALUES ('78', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県潟上市天王追分西', '05', '05211', '0100101', '秋田県', 'アキタケン', '潟上市', 'カタガミシ', '天王', 'テンノウ', null, null, '追分西', 'オイワケニシ');
INSERT INTO `ms_addresses` VALUES ('79', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県潟上市天王上北野', '05', '05211', '0100101', '秋田県', 'アキタケン', '潟上市', 'カタガミシ', '天王', 'テンノウ', null, null, '上北野', 'カミキタノ');
INSERT INTO `ms_addresses` VALUES ('80', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県潟上市天王長沼', '05', '05211', '0100101', '秋田県', 'アキタケン', '潟上市', 'カタガミシ', '天王', 'テンノウ', null, null, '長沼', 'ナガヌマ');
INSERT INTO `ms_addresses` VALUES ('81', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北11条西1丁目', '01', '01102', '0010011', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北11条西', 'キタ11ジョウニシ', null, null, '1丁目', '01チョウメ');
INSERT INTO `ms_addresses` VALUES ('82', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都三宅島三宅村', '13', '13381', '1001100', '東京都', 'トウキョウト', '三宅島三宅村', 'ミヤケジマミヤケムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('83', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北11条西2丁目', '01', '01102', '0010011', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北11条西', 'キタ11ジョウニシ', null, null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('84', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都三宅島三宅村神着', '13', '13381', '1001101', '東京都', 'トウキョウト', '三宅島三宅村', 'ミヤケジマミヤケムラ', '神着', 'カミツキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北11条西3丁目', '01', '01102', '0010011', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北11条西', 'キタ11ジョウニシ', null, null, '3丁目', '03チョウメ');
INSERT INTO `ms_addresses` VALUES ('86', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都三宅島三宅村伊豆', '13', '13381', '1001102', '東京都', 'トウキョウト', '三宅島三宅村', 'ミヤケジマミヤケムラ', '伊豆', 'イズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北11条西4丁目', '01', '01102', '0010011', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北11条西', 'キタ11ジョウニシ', null, null, '4丁目', '04チョウメ');
INSERT INTO `ms_addresses` VALUES ('88', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都三宅島三宅村伊ケ谷', '13', '13381', '1001103', '東京都', 'トウキョウト', '三宅島三宅村', 'ミヤケジマミヤケムラ', '伊ケ谷', 'イガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市金足岩瀬', '05', '05201', '0100111', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '金足岩瀬', 'カナアシイワセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市金足堀内', '05', '05201', '0100112', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '金足堀内', 'カナアシホリウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市金足浦山', '05', '05201', '0100113', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '金足浦山', 'カナアシウラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市金足下刈', '05', '05201', '0100114', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '金足下刈', 'カナアシシタカリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市金足大清水', '05', '05201', '0100115', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '金足大清水', 'カナアシオオシミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市金足小泉', '05', '05201', '0100116', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '金足小泉', 'カナアシコイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北12条西1丁目', '01', '01102', '0010012', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北12条西', 'キタ12ジョウニシ', null, null, '1丁目', '01チョウメ');
INSERT INTO `ms_addresses` VALUES ('96', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北12条西2丁目', '01', '01102', '0010012', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北12条西', 'キタ12ジョウニシ', null, null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('97', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北12条西3丁目', '01', '01102', '0010012', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北12条西', 'キタ12ジョウニシ', null, null, '3丁目', '03チョウメ');
INSERT INTO `ms_addresses` VALUES ('98', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北12条西4丁目', '01', '01102', '0010012', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北12条西', 'キタ12ジョウニシ', null, null, '4丁目', '04チョウメ');
INSERT INTO `ms_addresses` VALUES ('99', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市金足黒川', '05', '05201', '0100121', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '金足黒川', 'カナアシクロカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都三宅島三宅村坪田', '13', '13381', '1001211', '東京都', 'トウキョウト', '三宅島三宅村', 'ミヤケジマミヤケムラ', '坪田', 'ツボタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都三宅島三宅村阿古', '13', '13381', '1001212', '東京都', 'トウキョウト', '三宅島三宅村', 'ミヤケジマミヤケムラ', '阿古', 'アコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都三宅島三宅村雄山', '13', '13381', '1001213', '東京都', 'トウキョウト', '三宅島三宅村', 'ミヤケジマミヤケムラ', '雄山', 'オヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市金足吉田', '05', '05201', '0100122', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '金足吉田', 'カナアシヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市金足片田', '05', '05201', '0100123', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '金足片田', 'カナアシカタダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市金足鳰崎', '05', '05201', '0100124', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '金足鳰崎', 'カナアシニオザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市金足高岡', '05', '05201', '0100125', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '金足高岡', 'カナアシタカオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市金足追分', '05', '05201', '0100126', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '金足追分', 'カナアシオイワケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北13条西1丁目', '01', '01102', '0010013', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北13条西', 'キタ13ジョウニシ', null, null, '1丁目', '01チョウメ');
INSERT INTO `ms_addresses` VALUES ('109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北13条西2丁目', '01', '01102', '0010013', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北13条西', 'キタ13ジョウニシ', null, null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都御蔵島村', '13', '13382', '1001301', '東京都', 'トウキョウト', '御蔵島村', 'ミクラジマムラ', null, '　', '（全域）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北13条西3丁目', '01', '01102', '0010013', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北13条西', 'キタ13ジョウニシ', null, null, '3丁目', '03チョウメ');
INSERT INTO `ms_addresses` VALUES ('112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北13条西4丁目', '01', '01102', '0010013', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北13条西', 'キタ13ジョウニシ', null, null, '4丁目', '04チョウメ');
INSERT INTO `ms_addresses` VALUES ('113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市上新城白山', '05', '05201', '0100131', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '上新城白山', 'カミシンジョウシラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市上新城小又', '05', '05201', '0100132', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '上新城小又', 'カミシンジョウオマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市上新城湯ノ里', '05', '05201', '0100133', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '上新城湯ノ里', 'カミシンジョウユノサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市上新城道川', '05', '05201', '0100134', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '上新城道川', 'カミシンジョウミチカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市上新城五十丁', '05', '05201', '0100135', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '上新城五十丁', 'カミシンジョウゴジッチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市上新城中', '05', '05201', '0100136', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '上新城中', 'カミシンジョウナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市上新城石名坂', '05', '05201', '0100137', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '上新城石名坂', 'カミシンジョウイシナザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市上新城保多野', '05', '05201', '0100138', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '上新城保多野', 'カミシンジョウホタノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北14条西1丁目', '01', '01102', '0010014', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北14条西', 'キタ14ジョウニシ', null, null, '1丁目', '01チョウメ');
INSERT INTO `ms_addresses` VALUES ('122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八丈島八丈町', '13', '13401', '1001400', '東京都', 'トウキョウト', '八丈島八丈町', 'ハチジョウジマハチジョウマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北14条西2丁目', '01', '01102', '0010014', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北14条西', 'キタ14ジョウニシ', null, null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八丈島八丈町大賀郷', '13', '13401', '1001401', '東京都', 'トウキョウト', '八丈島八丈町', 'ハチジョウジマハチジョウマチ', '大賀郷', 'オオカゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北14条西3丁目', '01', '01102', '0010014', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北14条西', 'キタ14ジョウニシ', null, null, '3丁目', '03チョウメ');
INSERT INTO `ms_addresses` VALUES ('126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北14条西4丁目', '01', '01102', '0010014', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北14条西', 'キタ14ジョウニシ', null, null, '4丁目', '04チョウメ');
INSERT INTO `ms_addresses` VALUES ('127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市下新城長岡', '05', '05201', '0100141', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '下新城長岡', 'シモシンジョウナガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市下新城青崎', '05', '05201', '0100142', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '下新城青崎', 'シモシンジョウアオザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市下新城小友', '05', '05201', '0100143', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '下新城小友', 'シモシンジョウオトモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市下新城岩城', '05', '05201', '0100144', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '下新城岩城', 'シモシンジョウイワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市下新城笠岡', '05', '05201', '0100145', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '下新城笠岡', 'シモシンジョウカサオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市下新城中野', '05', '05201', '0100146', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '下新城中野', 'シモシンジョウナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北15条西1丁目', '01', '01102', '0010015', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北15条西', 'キタ15ジョウニシ', null, null, '1丁目', '01チョウメ');
INSERT INTO `ms_addresses` VALUES ('136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北15条西2丁目', '01', '01102', '0010015', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北15条西', 'キタ15ジョウニシ', null, null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北15条西3丁目', '01', '01102', '0010015', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北15条西', 'キタ15ジョウニシ', null, null, '3丁目', '03チョウメ');
INSERT INTO `ms_addresses` VALUES ('138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北15条西4丁目', '01', '01102', '0010015', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北15条西', 'キタ15ジョウニシ', null, null, '4丁目', '04チョウメ');
INSERT INTO `ms_addresses` VALUES ('139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北15条西5丁目', '01', '01102', '0010015', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北15条西', 'キタ15ジョウニシ', null, null, '5丁目', '05チョウメ');
INSERT INTO `ms_addresses` VALUES ('140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八丈島八丈町三根', '13', '13401', '1001511', '東京都', 'トウキョウト', '八丈島八丈町', 'ハチジョウジマハチジョウマチ', '三根', 'ミツネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北16条西1丁目', '01', '01102', '0010016', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北16条西', 'キタ16ジョウニシ', null, null, '1丁目', '01チョウメ');
INSERT INTO `ms_addresses` VALUES ('142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北16条西2丁目', '01', '01102', '0010016', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北16条西', 'キタ16ジョウニシ', null, null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北16条西3丁目', '01', '01102', '0010016', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北16条西', 'キタ16ジョウニシ', null, null, '3丁目', '03チョウメ');
INSERT INTO `ms_addresses` VALUES ('144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北16条西4丁目', '01', '01102', '0010016', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北16条西', 'キタ16ジョウニシ', null, null, '4丁目', '04チョウメ'), ('145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北16条西5丁目', '01', '01102', '0010016', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北16条西', 'キタ16ジョウニシ', null, null, '5丁目', '05チョウメ'), ('146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北16条西6丁目', '01', '01102', '0010016', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北16条西', 'キタ16ジョウニシ', null, null, '6丁目', '06チョウメ');
INSERT INTO `ms_addresses` VALUES ('147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八丈島八丈町樫立', '13', '13401', '1001621', '東京都', 'トウキョウト', '八丈島八丈町', 'ハチジョウジマハチジョウマチ', '樫立', 'カシタテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八丈島八丈町末吉', '13', '13401', '1001622', '東京都', 'トウキョウト', '八丈島八丈町', 'ハチジョウジマハチジョウマチ', '末吉', 'スエヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八丈島八丈町中之郷', '13', '13401', '1001623', '東京都', 'トウキョウト', '八丈島八丈町', 'ハチジョウジマハチジョウマチ', '中之郷', 'ナカノゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北17条西1丁目', '01', '01102', '0010017', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北17条西', 'キタ17ジョウニシ', null, null, '1丁目', '01チョウメ');
INSERT INTO `ms_addresses` VALUES ('151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北17条西2丁目', '01', '01102', '0010017', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北17条西', 'キタ17ジョウニシ', null, null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都青ヶ島村', '13', '13402', '1001701', '東京都', 'トウキョウト', '青ヶ島村', 'アオガシマムラ', null, '　', '（全域）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北17条西3丁目', '01', '01102', '0010017', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北17条西', 'キタ17ジョウニシ', null, null, '3丁目', '03チョウメ');
INSERT INTO `ms_addresses` VALUES ('154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北17条西4丁目', '01', '01102', '0010017', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北17条西', 'キタ17ジョウニシ', null, null, '4丁目', '04チョウメ');
INSERT INTO `ms_addresses` VALUES ('155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北17条西5丁目', '01', '01102', '0010017', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北17条西', 'キタ17ジョウニシ', null, null, '5丁目', '05チョウメ');
INSERT INTO `ms_addresses` VALUES ('156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北17条西6丁目', '01', '01102', '0010017', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北17条西', 'キタ17ジョウニシ', null, null, '6丁目', '06チョウメ');
INSERT INTO `ms_addresses` VALUES ('157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北18条西1丁目', '01', '01102', '0010018', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北18条西', 'キタ18ジョウニシ', null, null, '1丁目', '01チョウメ');
INSERT INTO `ms_addresses` VALUES ('158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北18条西2丁目', '01', '01102', '0010018', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北18条西', 'キタ18ジョウニシ', null, null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北18条西3丁目', '01', '01102', '0010018', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北18条西', 'キタ18ジョウニシ', null, null, '3丁目', '03チョウメ');
INSERT INTO `ms_addresses` VALUES ('160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北18条西4丁目', '01', '01102', '0010018', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北18条西', 'キタ18ジョウニシ', null, null, '4丁目', '04チョウメ');
INSERT INTO `ms_addresses` VALUES ('161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北18条西5丁目', '01', '01102', '0010018', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北18条西', 'キタ18ジョウニシ', null, null, '5丁目', '05チョウメ');
INSERT INTO `ms_addresses` VALUES ('162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北18条西6丁目', '01', '01102', '0010018', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北18条西', 'キタ18ジョウニシ', null, null, '6丁目', '06チョウメ');
INSERT INTO `ms_addresses` VALUES ('163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北18条西7丁目', '01', '01102', '0010018', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北18条西', 'キタ18ジョウニシ', null, null, '7丁目', '07チョウメ');
INSERT INTO `ms_addresses` VALUES ('164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北19条西2丁目', '01', '01102', '0010019', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北19条西', 'キタ19ジョウニシ', null, null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北19条西3丁目', '01', '01102', '0010019', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北19条西', 'キタ19ジョウニシ', null, null, '3丁目', '03チョウメ');
INSERT INTO `ms_addresses` VALUES ('166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北19条西4丁目', '01', '01102', '0010019', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北19条西', 'キタ19ジョウニシ', null, null, '4丁目', '04チョウメ');
INSERT INTO `ms_addresses` VALUES ('167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北19条西5丁目', '01', '01102', '0010019', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北19条西', 'キタ19ジョウニシ', null, null, '5丁目', '05チョウメ');
INSERT INTO `ms_addresses` VALUES ('168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北19条西6丁目', '01', '01102', '0010019', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北19条西', 'キタ19ジョウニシ', null, null, '6丁目', '06チョウメ');
INSERT INTO `ms_addresses` VALUES ('169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北19条西7丁目', '01', '01102', '0010019', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北19条西', 'キタ19ジョウニシ', null, null, '7丁目', '07チョウメ');
INSERT INTO `ms_addresses` VALUES ('171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北20条西2丁目', '01', '01102', '0010020', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北20条西', 'キタ20ジョウニシ', null, null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北20条西3丁目', '01', '01102', '0010020', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北20条西', 'キタ20ジョウニシ', null, null, '3丁目', '03チョウメ');
INSERT INTO `ms_addresses` VALUES ('173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北20条西4丁目', '01', '01102', '0010020', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北20条西', 'キタ20ジョウニシ', null, null, '4丁目', '04チョウメ');
INSERT INTO `ms_addresses` VALUES ('174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北20条西5丁目', '01', '01102', '0010020', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北20条西', 'キタ20ジョウニシ', null, null, '5丁目', '05チョウメ');
INSERT INTO `ms_addresses` VALUES ('175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北20条西6丁目', '01', '01102', '0010020', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北20条西', 'キタ20ジョウニシ', null, null, '6丁目', '06チョウメ');
INSERT INTO `ms_addresses` VALUES ('176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北20条西7丁目', '01', '01102', '0010020', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北20条西', 'キタ20ジョウニシ', null, null, '7丁目', '07チョウメ');
INSERT INTO `ms_addresses` VALUES ('177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北20条西8丁目', '01', '01102', '0010020', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北20条西', 'キタ20ジョウニシ', null, null, '8丁目', '08チョウメ');
INSERT INTO `ms_addresses` VALUES ('178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北20条西9丁目', '01', '01102', '0010020', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北20条西', 'キタ20ジョウニシ', null, null, '9丁目', '09チョウメ');
INSERT INTO `ms_addresses` VALUES ('179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北20条西10丁目', '01', '01102', '0010020', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北20条西', 'キタ20ジョウニシ', null, null, '10丁目', '10チョウメ');
INSERT INTO `ms_addresses` VALUES ('180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県潟上市天王', '05', '05211', '0100201', '秋田県', 'アキタケン', '潟上市', 'カタガミシ', '天王', 'テンノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県潟上市天王大崎', '05', '05211', '0100202', '秋田県', 'アキタケン', '潟上市', 'カタガミシ', '天王大崎', 'テンノウオオサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北21条西', '01', '01102', '0010021', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北21条西', 'キタ21ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都小笠原村', '13', '13421', '1002100', '東京都', 'トウキョウト', '小笠原村', 'オガサワラムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都小笠原村父島', '13', '13421', '1002101', '東京都', 'トウキョウト', '小笠原村', 'オガサワラムラ', '父島', 'チチジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北22条西', '01', '01102', '0010022', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北22条西', 'キタ22ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都小笠原村母島', '13', '13421', '1002211', '東京都', 'トウキョウト', '小笠原村', 'オガサワラムラ', '母島', 'ハハジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北23条西', '01', '01102', '0010023', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北23条西', 'キタ23ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北24条西', '01', '01102', '0010024', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北24条西', 'キタ24ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北25条西', '01', '01102', '0010025', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北25条西', 'キタ25ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北26条西', '01', '01102', '0010026', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北26条西', 'キタ26ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北27条西', '01', '01102', '0010027', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北27条西', 'キタ27ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北28条西', '01', '01102', '0010028', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北28条西', 'キタ28ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北29条西', '01', '01102', '0010029', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北29条西', 'キタ29ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北30条西', '01', '01102', '0010030', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北30条西', 'キタ30ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北31条西', '01', '01102', '0010031', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北31条西', 'キタ31ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北32条西', '01', '01102', '0010032', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北32条西', 'キタ32ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北33条西', '01', '01102', '0010033', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北33条西', 'キタ33ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北34条西', '01', '01102', '0010034', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北34条西', 'キタ34ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県男鹿市船越', '05', '05206', '0100341', '秋田県', 'アキタケン', '男鹿市', 'オガシ', '船越', 'フナコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県男鹿市脇本脇本', '05', '05206', '0100342', '秋田県', 'アキタケン', '男鹿市', 'オガシ', '脇本脇本', 'ワキモトワキモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県男鹿市脇本田谷沢', '05', '05206', '0100343', '秋田県', 'アキタケン', '男鹿市', 'オガシ', '脇本田谷沢', 'ワキモトタヤザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県男鹿市脇本富永', '05', '05206', '0100344', '秋田県', 'アキタケン', '男鹿市', 'オガシ', '脇本富永', 'ワキモトトミナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県男鹿市脇本浦田', '05', '05206', '0100345', '秋田県', 'アキタケン', '男鹿市', 'オガシ', '脇本浦田', 'ワキモトウラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県男鹿市脇本樽沢', '05', '05206', '0100346', '秋田県', 'アキタケン', '男鹿市', 'オガシ', '脇本樽沢', 'ワキモトタルザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県男鹿市脇本百川', '05', '05206', '0100347', '秋田県', 'アキタケン', '男鹿市', 'オガシ', '脇本百川', 'ワキモトモモカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北35条西', '01', '01102', '0010035', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北35条西', 'キタ35ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県男鹿市五里合箱井', '05', '05206', '0100351', '秋田県', 'アキタケン', '男鹿市', 'オガシ', '五里合箱井', 'イリアイハコイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県男鹿市五里合琴川', '05', '05206', '0100352', '秋田県', 'アキタケン', '男鹿市', 'オガシ', '五里合琴川', 'イリアイコトガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県男鹿市五里合神谷', '05', '05206', '0100353', '秋田県', 'アキタケン', '男鹿市', 'オガシ', '五里合神谷', 'イリアイカミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県男鹿市五里合中石', '05', '05206', '0100354', '秋田県', 'アキタケン', '男鹿市', 'オガシ', '五里合中石', 'イリアイチュウイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県男鹿市五里合鮪川', '05', '05206', '0100355', '秋田県', 'アキタケン', '男鹿市', 'オガシ', '五里合鮪川', 'イリアイシビカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北36条西', '01', '01102', '0010036', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北36条西', 'キタ36ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北37条西', '01', '01102', '0010037', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北37条西', 'キタ37ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北38条西', '01', '01102', '0010038', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北38条西', 'キタ38ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北39条西', '01', '01102', '0010039', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北39条西', 'キタ39ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北40条西', '01', '01102', '0010040', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北40条西', 'キタ40ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県南秋田郡大潟村', '05', '05368', '0100400', '秋田県', 'アキタケン', '南秋田郡大潟村', 'ミナミアキタグンオオガタムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県男鹿市野石', '05', '05206', '0100401', '秋田県', 'アキタケン', '男鹿市', 'オガシ', '野石', 'ノイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県男鹿市福米沢', '05', '05206', '0100411', '秋田県', 'アキタケン', '男鹿市', 'オガシ', '福米沢', 'フクメザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県男鹿市本内', '05', '05206', '0100412', '秋田県', 'アキタケン', '男鹿市', 'オガシ', '本内', 'ホンナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県男鹿市松木沢', '05', '05206', '0100413', '秋田県', 'アキタケン', '男鹿市', 'オガシ', '松木沢', 'マツキサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県男鹿市鵜木', '05', '05206', '0100421', '秋田県', 'アキタケン', '男鹿市', 'オガシ', '鵜木', 'ウノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県男鹿市角間崎', '05', '05206', '0100422', '秋田県', 'アキタケン', '男鹿市', 'オガシ', '角間崎', 'カクマザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県男鹿市福川', '05', '05206', '0100423', '秋田県', 'アキタケン', '男鹿市', 'オガシ', '福川', 'フクガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県男鹿市払戸', '05', '05206', '0100431', '秋田県', 'アキタケン', '男鹿市', 'オガシ', '払戸', 'フット', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県南秋田郡大潟村北', '05', '05368', '0100441', '秋田県', 'アキタケン', '南秋田郡大潟村', 'ミナミアキタグンオオガタムラ', '北', 'キタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県南秋田郡大潟村東', '05', '05368', '0100442', '秋田県', 'アキタケン', '南秋田郡大潟村', 'ミナミアキタグンオオガタムラ', '東', 'ヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県南秋田郡大潟村中央', '05', '05368', '0100443', '秋田県', 'アキタケン', '南秋田郡大潟村', 'ミナミアキタグンオオガタムラ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県南秋田郡大潟村南', '05', '05368', '0100444', '秋田県', 'アキタケン', '南秋田郡大潟村', 'ミナミアキタグンオオガタムラ', '南', 'ミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県南秋田郡大潟村西', '05', '05368', '0100445', '秋田県', 'アキタケン', '南秋田郡大潟村', 'ミナミアキタグンオオガタムラ', '西', 'ニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区麻生町', '01', '01102', '0010045', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '麻生町', 'アサブチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県南秋田郡大潟村大潟', '05', '05368', '0100451', '秋田県', 'アキタケン', '南秋田郡大潟村', 'ミナミアキタグンオオガタムラ', '大潟', 'オオガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県南秋田郡大潟村方上', '05', '05368', '0100452', '秋田県', 'アキタケン', '南秋田郡大潟村', 'ミナミアキタグンオオガタムラ', '方上', 'カタガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県南秋田郡大潟村方口', '05', '05368', '0100453', '秋田県', 'アキタケン', '南秋田郡大潟村', 'ミナミアキタグンオオガタムラ', '方口', 'カタグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県南秋田郡大潟村中野', '05', '05368', '0100454', '秋田県', 'アキタケン', '南秋田郡大潟村', 'ミナミアキタグンオオガタムラ', '中野', 'ナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県南秋田郡大潟村西野', '05', '05368', '0100455', '秋田県', 'アキタケン', '南秋田郡大潟村', 'ミナミアキタグンオオガタムラ', '西野', 'ニシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県南秋田郡大潟村東野', '05', '05368', '0100456', '秋田県', 'アキタケン', '南秋田郡大潟村', 'ミナミアキタグンオオガタムラ', '東野', 'ヒガシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県男鹿市', '05', '05206', '0100500', '秋田県', 'アキタケン', '男鹿市', 'オガシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県男鹿市船川港仁井山', '05', '05206', '0100501', '秋田県', 'アキタケン', '男鹿市', 'オガシ', '船川港仁井山', 'フナガワミナトニイヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県男鹿市船川港比詰', '05', '05206', '0100502', '秋田県', 'アキタケン', '男鹿市', 'オガシ', '船川港比詰', 'フナガワミナトヒヅメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県男鹿市船川港金川', '05', '05206', '0100503', '秋田県', 'アキタケン', '男鹿市', 'オガシ', '船川港金川', 'フナガワミナトカネガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県男鹿市船川港船川', '05', '05206', '0100511', '秋田県', 'アキタケン', '男鹿市', 'オガシ', '船川港船川', 'フナガワミナトフナガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県男鹿市船川港南平沢', '05', '05206', '0100521', '秋田県', 'アキタケン', '男鹿市', 'オガシ', '船川港南平沢', 'フナガワミナトミナミヒラサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県男鹿市船川港増川', '05', '05206', '0100522', '秋田県', 'アキタケン', '男鹿市', 'オガシ', '船川港増川', 'フナガワミナトマスガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県男鹿市船川港女川', '05', '05206', '0100523', '秋田県', 'アキタケン', '男鹿市', 'オガシ', '船川港女川', 'フナガワミナトオンナガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県男鹿市船川港台島', '05', '05206', '0100531', '秋田県', 'アキタケン', '男鹿市', 'オガシ', '船川港台島', 'フナガワミナトダイシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県男鹿市船川港椿', '05', '05206', '0100532', '秋田県', 'アキタケン', '男鹿市', 'オガシ', '船川港椿', 'フナガワミナトツバキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県男鹿市船川港双六', '05', '05206', '0100533', '秋田県', 'アキタケン', '男鹿市', 'オガシ', '船川港双六', 'フナガワミナトスゴロク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県男鹿市船川港小浜', '05', '05206', '0100534', '秋田県', 'アキタケン', '男鹿市', 'オガシ', '船川港小浜', 'フナガワミナトコハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県男鹿市船川港本山門前', '05', '05206', '0100535', '秋田県', 'アキタケン', '男鹿市', 'オガシ', '船川港本山門前', 'フナガワミナトホンザンモンゼン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区霞が関霞が関ビル　1階', '13', '13101', '1006001', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '霞が関', 'カスミガセキ', null, null, '霞が関ビル　1階', 'カスミガセキビル　01カイ');
INSERT INTO `ms_addresses` VALUES ('257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区霞が関霞が関ビル　2階', '13', '13101', '1006002', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '霞が関', 'カスミガセキ', null, null, '霞が関ビル　2階', 'カスミガセキビル　02カイ');
INSERT INTO `ms_addresses` VALUES ('258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区霞が関霞が関ビル　3階', '13', '13101', '1006003', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '霞が関', 'カスミガセキ', null, null, '霞が関ビル　3階', 'カスミガセキビル　03カイ');
INSERT INTO `ms_addresses` VALUES ('259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区霞が関霞が関ビル　4階', '13', '13101', '1006004', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '霞が関', 'カスミガセキ', null, null, '霞が関ビル　4階', 'カスミガセキビル　04カイ');
INSERT INTO `ms_addresses` VALUES ('260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区霞が関霞が関ビル　5階', '13', '13101', '1006005', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '霞が関', 'カスミガセキ', null, null, '霞が関ビル　5階', 'カスミガセキビル　05カイ');
INSERT INTO `ms_addresses` VALUES ('261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区霞が関霞が関ビル　6階', '13', '13101', '1006006', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '霞が関', 'カスミガセキ', null, null, '霞が関ビル　6階', 'カスミガセキビル　06カイ');
INSERT INTO `ms_addresses` VALUES ('262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区霞が関霞が関ビル　7階', '13', '13101', '1006007', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '霞が関', 'カスミガセキ', null, null, '霞が関ビル　7階', 'カスミガセキビル　07カイ');
INSERT INTO `ms_addresses` VALUES ('263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区霞が関霞が関ビル　8階', '13', '13101', '1006008', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '霞が関', 'カスミガセキ', null, null, '霞が関ビル　8階', 'カスミガセキビル　08カイ');
INSERT INTO `ms_addresses` VALUES ('264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区霞が関霞が関ビル　9階', '13', '13101', '1006009', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '霞が関', 'カスミガセキ', null, null, '霞が関ビル　9階', 'カスミガセキビル　09カイ');
INSERT INTO `ms_addresses` VALUES ('265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区霞が関霞が関ビル　10階', '13', '13101', '1006010', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '霞が関', 'カスミガセキ', null, null, '霞が関ビル　10階', 'カスミガセキビル　10カイ');
INSERT INTO `ms_addresses` VALUES ('266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区霞が関霞が関ビル　11階', '13', '13101', '1006011', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '霞が関', 'カスミガセキ', null, null, '霞が関ビル　11階', 'カスミガセキビル　11カイ');
INSERT INTO `ms_addresses` VALUES ('267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区霞が関霞が関ビル　12階', '13', '13101', '1006012', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '霞が関', 'カスミガセキ', null, null, '霞が関ビル　12階', 'カスミガセキビル　12カイ');
INSERT INTO `ms_addresses` VALUES ('268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区霞が関霞が関ビル　13階', '13', '13101', '1006013', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '霞が関', 'カスミガセキ', null, null, '霞が関ビル　13階', 'カスミガセキビル　13カイ');
INSERT INTO `ms_addresses` VALUES ('269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区霞が関霞が関ビル　14階', '13', '13101', '1006014', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '霞が関', 'カスミガセキ', null, null, '霞が関ビル　14階', 'カスミガセキビル　14カイ');
INSERT INTO `ms_addresses` VALUES ('270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区霞が関霞が関ビル　15階', '13', '13101', '1006015', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '霞が関', 'カスミガセキ', null, null, '霞が関ビル　15階', 'カスミガセキビル　15カイ');
INSERT INTO `ms_addresses` VALUES ('271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区霞が関霞が関ビル　16階', '13', '13101', '1006016', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '霞が関', 'カスミガセキ', null, null, '霞が関ビル　16階', 'カスミガセキビル　16カイ');
INSERT INTO `ms_addresses` VALUES ('272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区霞が関霞が関ビル　17階', '13', '13101', '1006017', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '霞が関', 'カスミガセキ', null, null, '霞が関ビル　17階', 'カスミガセキビル　17カイ');
INSERT INTO `ms_addresses` VALUES ('273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区霞が関霞が関ビル　18階', '13', '13101', '1006018', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '霞が関', 'カスミガセキ', null, null, '霞が関ビル　18階', 'カスミガセキビル　18カイ');
INSERT INTO `ms_addresses` VALUES ('274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区霞が関霞が関ビル　19階', '13', '13101', '1006019', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '霞が関', 'カスミガセキ', null, null, '霞が関ビル　19階', 'カスミガセキビル　19カイ');
INSERT INTO `ms_addresses` VALUES ('275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区霞が関霞が関ビル　20階', '13', '13101', '1006020', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '霞が関', 'カスミガセキ', null, null, '霞が関ビル　20階', 'カスミガセキビル　20カイ');
INSERT INTO `ms_addresses` VALUES ('276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区霞が関霞が関ビル　21階', '13', '13101', '1006021', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '霞が関', 'カスミガセキ', null, null, '霞が関ビル　21階', 'カスミガセキビル　21カイ');
INSERT INTO `ms_addresses` VALUES ('277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区霞が関霞が関ビル　22階', '13', '13101', '1006022', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '霞が関', 'カスミガセキ', null, null, '霞が関ビル　22階', 'カスミガセキビル　22カイ');
INSERT INTO `ms_addresses` VALUES ('278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区霞が関霞が関ビル　23階', '13', '13101', '1006023', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '霞が関', 'カスミガセキ', null, null, '霞が関ビル　23階', 'カスミガセキビル　23カイ');
INSERT INTO `ms_addresses` VALUES ('279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区霞が関霞が関ビル　24階', '13', '13101', '1006024', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '霞が関', 'カスミガセキ', null, null, '霞が関ビル　24階', 'カスミガセキビル　24カイ');
INSERT INTO `ms_addresses` VALUES ('280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区霞が関霞が関ビル　25階', '13', '13101', '1006025', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '霞が関', 'カスミガセキ', null, null, '霞が関ビル　25階', 'カスミガセキビル　25カイ');
INSERT INTO `ms_addresses` VALUES ('281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区霞が関霞が関ビル　26階', '13', '13101', '1006026', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '霞が関', 'カスミガセキ', null, null, '霞が関ビル　26階', 'カスミガセキビル　26カイ');
INSERT INTO `ms_addresses` VALUES ('282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区霞が関霞が関ビル　27階', '13', '13101', '1006027', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '霞が関', 'カスミガセキ', null, null, '霞が関ビル　27階', 'カスミガセキビル　27カイ');
INSERT INTO `ms_addresses` VALUES ('283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区霞が関霞が関ビル　28階', '13', '13101', '1006028', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '霞が関', 'カスミガセキ', null, null, '霞が関ビル　28階', 'カスミガセキビル　28カイ');
INSERT INTO `ms_addresses` VALUES ('284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区霞が関霞が関ビル　29階', '13', '13101', '1006029', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '霞が関', 'カスミガセキ', null, null, '霞が関ビル　29階', 'カスミガセキビル　29カイ');
INSERT INTO `ms_addresses` VALUES ('285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区霞が関霞が関ビル　30階', '13', '13101', '1006030', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '霞が関', 'カスミガセキ', null, null, '霞が関ビル　30階', 'カスミガセキビル　30カイ');
INSERT INTO `ms_addresses` VALUES ('286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区霞が関霞が関ビル　31階', '13', '13101', '1006031', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '霞が関', 'カスミガセキ', null, null, '霞が関ビル　31階', 'カスミガセキビル　31カイ');
INSERT INTO `ms_addresses` VALUES ('287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区霞が関霞が関ビル　32階', '13', '13101', '1006032', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '霞が関', 'カスミガセキ', null, null, '霞が関ビル　32階', 'カスミガセキビル　32カイ');
INSERT INTO `ms_addresses` VALUES ('288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区霞が関霞が関ビル　33階', '13', '13101', '1006033', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '霞が関', 'カスミガセキ', null, null, '霞が関ビル　33階', 'カスミガセキビル　33カイ');
INSERT INTO `ms_addresses` VALUES ('289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区霞が関霞が関ビル　34階', '13', '13101', '1006034', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '霞が関', 'カスミガセキ', null, null, '霞が関ビル　34階', 'カスミガセキビル　34カイ');
INSERT INTO `ms_addresses` VALUES ('290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区霞が関霞が関ビル　35階', '13', '13101', '1006035', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '霞が関', 'カスミガセキ', null, null, '霞が関ビル　35階', 'カスミガセキビル　35カイ');
INSERT INTO `ms_addresses` VALUES ('291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区霞が関霞が関ビル　36階', '13', '13101', '1006036', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '霞が関', 'カスミガセキ', null, null, '霞が関ビル　36階', 'カスミガセキビル　36カイ');
INSERT INTO `ms_addresses` VALUES ('294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区霞が関霞が関ビル　', '13', '13101', '1006090', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '霞が関', 'カスミガセキ', null, null, '霞が関ビル　', 'カスミガセキビル　');
INSERT INTO `ms_addresses` VALUES ('295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区永田町山王パークタワー　1階', '13', '13101', '1006101', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '永田町', 'ナガタチョウ', null, null, '山王パークタワー　1階', 'サンノウパークタワー　01カイ');
INSERT INTO `ms_addresses` VALUES ('296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区永田町山王パークタワー　2階', '13', '13101', '1006102', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '永田町', 'ナガタチョウ', null, null, '山王パークタワー　2階', 'サンノウパークタワー　02カイ');
INSERT INTO `ms_addresses` VALUES ('297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区永田町山王パークタワー　3階', '13', '13101', '1006103', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '永田町', 'ナガタチョウ', null, null, '山王パークタワー　3階', 'サンノウパークタワー　03カイ');
INSERT INTO `ms_addresses` VALUES ('298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区永田町山王パークタワー　4階', '13', '13101', '1006104', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '永田町', 'ナガタチョウ', null, null, '山王パークタワー　4階', 'サンノウパークタワー　04カイ');
INSERT INTO `ms_addresses` VALUES ('299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区永田町山王パークタワー　5階', '13', '13101', '1006105', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '永田町', 'ナガタチョウ', null, null, '山王パークタワー　5階', 'サンノウパークタワー　05カイ');
INSERT INTO `ms_addresses` VALUES ('300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区永田町山王パークタワー　6階', '13', '13101', '1006106', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '永田町', 'ナガタチョウ', null, null, '山王パークタワー　6階', 'サンノウパークタワー　06カイ');
INSERT INTO `ms_addresses` VALUES ('301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区永田町山王パークタワー　7階', '13', '13101', '1006107', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '永田町', 'ナガタチョウ', null, null, '山王パークタワー　7階', 'サンノウパークタワー　07カイ');
INSERT INTO `ms_addresses` VALUES ('302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区永田町山王パークタワー　8階', '13', '13101', '1006108', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '永田町', 'ナガタチョウ', null, null, '山王パークタワー　8階', 'サンノウパークタワー　08カイ');
INSERT INTO `ms_addresses` VALUES ('303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区永田町山王パークタワー　9階', '13', '13101', '1006109', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '永田町', 'ナガタチョウ', null, null, '山王パークタワー　9階', 'サンノウパークタワー　09カイ');
INSERT INTO `ms_addresses` VALUES ('304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区永田町山王パークタワー　10階', '13', '13101', '1006110', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '永田町', 'ナガタチョウ', null, null, '山王パークタワー　10階', 'サンノウパークタワー　10カイ');
INSERT INTO `ms_addresses` VALUES ('305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区永田町山王パークタワー　11階', '13', '13101', '1006111', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '永田町', 'ナガタチョウ', null, null, '山王パークタワー　11階', 'サンノウパークタワー　11カイ');
INSERT INTO `ms_addresses` VALUES ('306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区永田町山王パークタワー　12階', '13', '13101', '1006112', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '永田町', 'ナガタチョウ', null, null, '山王パークタワー　12階', 'サンノウパークタワー　12カイ');
INSERT INTO `ms_addresses` VALUES ('307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区永田町山王パークタワー　13階', '13', '13101', '1006113', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '永田町', 'ナガタチョウ', null, null, '山王パークタワー　13階', 'サンノウパークタワー　13カイ');
INSERT INTO `ms_addresses` VALUES ('308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区永田町山王パークタワー　14階', '13', '13101', '1006114', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '永田町', 'ナガタチョウ', null, null, '山王パークタワー　14階', 'サンノウパークタワー　14カイ');
INSERT INTO `ms_addresses` VALUES ('309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区永田町山王パークタワー　15階', '13', '13101', '1006115', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '永田町', 'ナガタチョウ', null, null, '山王パークタワー　15階', 'サンノウパークタワー　15カイ');
INSERT INTO `ms_addresses` VALUES ('310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区永田町山王パークタワー　16階', '13', '13101', '1006116', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '永田町', 'ナガタチョウ', null, null, '山王パークタワー　16階', 'サンノウパークタワー　16カイ');
INSERT INTO `ms_addresses` VALUES ('311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区永田町山王パークタワー　17階', '13', '13101', '1006117', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '永田町', 'ナガタチョウ', null, null, '山王パークタワー　17階', 'サンノウパークタワー　17カイ');
INSERT INTO `ms_addresses` VALUES ('312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区永田町山王パークタワー　18階', '13', '13101', '1006118', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '永田町', 'ナガタチョウ', null, null, '山王パークタワー　18階', 'サンノウパークタワー　18カイ');
INSERT INTO `ms_addresses` VALUES ('313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区永田町山王パークタワー　19階', '13', '13101', '1006119', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '永田町', 'ナガタチョウ', null, null, '山王パークタワー　19階', 'サンノウパークタワー　19カイ');
INSERT INTO `ms_addresses` VALUES ('314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区永田町山王パークタワー　20階', '13', '13101', '1006120', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '永田町', 'ナガタチョウ', null, null, '山王パークタワー　20階', 'サンノウパークタワー　20カイ');
INSERT INTO `ms_addresses` VALUES ('315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区永田町山王パークタワー　21階', '13', '13101', '1006121', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '永田町', 'ナガタチョウ', null, null, '山王パークタワー　21階', 'サンノウパークタワー　21カイ');
INSERT INTO `ms_addresses` VALUES ('316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区永田町山王パークタワー　22階', '13', '13101', '1006122', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '永田町', 'ナガタチョウ', null, null, '山王パークタワー　22階', 'サンノウパークタワー　22カイ');
INSERT INTO `ms_addresses` VALUES ('317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区永田町山王パークタワー　23階', '13', '13101', '1006123', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '永田町', 'ナガタチョウ', null, null, '山王パークタワー　23階', 'サンノウパークタワー　23カイ');
INSERT INTO `ms_addresses` VALUES ('318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区永田町山王パークタワー　24階', '13', '13101', '1006124', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '永田町', 'ナガタチョウ', null, null, '山王パークタワー　24階', 'サンノウパークタワー　24カイ');
INSERT INTO `ms_addresses` VALUES ('319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区永田町山王パークタワー　25階', '13', '13101', '1006125', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '永田町', 'ナガタチョウ', null, null, '山王パークタワー　25階', 'サンノウパークタワー　25カイ');
INSERT INTO `ms_addresses` VALUES ('320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区永田町山王パークタワー　26階', '13', '13101', '1006126', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '永田町', 'ナガタチョウ', null, null, '山王パークタワー　26階', 'サンノウパークタワー　26カイ');
INSERT INTO `ms_addresses` VALUES ('321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区永田町山王パークタワー　27階', '13', '13101', '1006127', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '永田町', 'ナガタチョウ', null, null, '山王パークタワー　27階', 'サンノウパークタワー　27カイ');
INSERT INTO `ms_addresses` VALUES ('322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区永田町山王パークタワー　28階', '13', '13101', '1006128', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '永田町', 'ナガタチョウ', null, null, '山王パークタワー　28階', 'サンノウパークタワー　28カイ');
INSERT INTO `ms_addresses` VALUES ('323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区永田町山王パークタワー　29階', '13', '13101', '1006129', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '永田町', 'ナガタチョウ', null, null, '山王パークタワー　29階', 'サンノウパークタワー　29カイ');
INSERT INTO `ms_addresses` VALUES ('324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区永田町山王パークタワー　30階', '13', '13101', '1006130', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '永田町', 'ナガタチョウ', null, null, '山王パークタワー　30階', 'サンノウパークタワー　30カイ');
INSERT INTO `ms_addresses` VALUES ('325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区永田町山王パークタワー　31階', '13', '13101', '1006131', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '永田町', 'ナガタチョウ', null, null, '山王パークタワー　31階', 'サンノウパークタワー　31カイ');
INSERT INTO `ms_addresses` VALUES ('326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区永田町山王パークタワー　32階', '13', '13101', '1006132', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '永田町', 'ナガタチョウ', null, null, '山王パークタワー　32階', 'サンノウパークタワー　32カイ');
INSERT INTO `ms_addresses` VALUES ('327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区永田町山王パークタワー　33階', '13', '13101', '1006133', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '永田町', 'ナガタチョウ', null, null, '山王パークタワー　33階', 'サンノウパークタワー　33カイ');
INSERT INTO `ms_addresses` VALUES ('328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区永田町山王パークタワー　34階', '13', '13101', '1006134', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '永田町', 'ナガタチョウ', null, null, '山王パークタワー　34階', 'サンノウパークタワー　34カイ');
INSERT INTO `ms_addresses` VALUES ('329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区永田町山王パークタワー　35階', '13', '13101', '1006135', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '永田町', 'ナガタチョウ', null, null, '山王パークタワー　35階', 'サンノウパークタワー　35カイ');
INSERT INTO `ms_addresses` VALUES ('330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区永田町山王パークタワー　36階', '13', '13101', '1006136', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '永田町', 'ナガタチョウ', null, null, '山王パークタワー　36階', 'サンノウパークタワー　36カイ');
INSERT INTO `ms_addresses` VALUES ('331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区永田町山王パークタワー　37階', '13', '13101', '1006137', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '永田町', 'ナガタチョウ', null, null, '山王パークタワー　37階', 'サンノウパークタワー　37カイ');
INSERT INTO `ms_addresses` VALUES ('332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区永田町山王パークタワー　38階', '13', '13101', '1006138', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '永田町', 'ナガタチョウ', null, null, '山王パークタワー　38階', 'サンノウパークタワー　38カイ');
INSERT INTO `ms_addresses` VALUES ('333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区永田町山王パークタワー　39階', '13', '13101', '1006139', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '永田町', 'ナガタチョウ', null, null, '山王パークタワー　39階', 'サンノウパークタワー　39カイ');
INSERT INTO `ms_addresses` VALUES ('334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区永田町山王パークタワー　40階', '13', '13101', '1006140', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '永田町', 'ナガタチョウ', null, null, '山王パークタワー　40階', 'サンノウパークタワー　40カイ');
INSERT INTO `ms_addresses` VALUES ('335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区永田町山王パークタワー　41階', '13', '13101', '1006141', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '永田町', 'ナガタチョウ', null, null, '山王パークタワー　41階', 'サンノウパークタワー　41カイ');
INSERT INTO `ms_addresses` VALUES ('336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区永田町山王パークタワー　42階', '13', '13101', '1006142', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '永田町', 'ナガタチョウ', null, null, '山王パークタワー　42階', 'サンノウパークタワー　42カイ');
INSERT INTO `ms_addresses` VALUES ('337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区永田町山王パークタワー　43階', '13', '13101', '1006143', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '永田町', 'ナガタチョウ', null, null, '山王パークタワー　43階', 'サンノウパークタワー　43カイ');
INSERT INTO `ms_addresses` VALUES ('338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区永田町山王パークタワー　44階', '13', '13101', '1006144', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '永田町', 'ナガタチョウ', null, null, '山王パークタワー　44階', 'サンノウパークタワー　44カイ');
INSERT INTO `ms_addresses` VALUES ('348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区永田町山王パークタワー　', '13', '13101', '1006190', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '永田町', 'ナガタチョウ', null, null, '山王パークタワー　', 'サンノウパークタワー　');
INSERT INTO `ms_addresses` VALUES ('349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内パシフィックセンチュリープレイス丸の内　1階', '13', '13101', '1006201', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'パシフィックセンチュリープレイス丸の内　1階', 'パシフィックセンチュリープレイスマルノウチ　01カイ');
INSERT INTO `ms_addresses` VALUES ('350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内パシフィックセンチュリープレイス丸の内　2階', '13', '13101', '1006202', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'パシフィックセンチュリープレイス丸の内　2階', 'パシフィックセンチュリープレイスマルノウチ　02カイ');
INSERT INTO `ms_addresses` VALUES ('351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内パシフィックセンチュリープレイス丸の内　3階', '13', '13101', '1006203', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'パシフィックセンチュリープレイス丸の内　3階', 'パシフィックセンチュリープレイスマルノウチ　03カイ');
INSERT INTO `ms_addresses` VALUES ('352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内パシフィックセンチュリープレイス丸の内　4階', '13', '13101', '1006204', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'パシフィックセンチュリープレイス丸の内　4階', 'パシフィックセンチュリープレイスマルノウチ　04カイ');
INSERT INTO `ms_addresses` VALUES ('353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内パシフィックセンチュリープレイス丸の内　5階', '13', '13101', '1006205', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'パシフィックセンチュリープレイス丸の内　5階', 'パシフィックセンチュリープレイスマルノウチ　05カイ');
INSERT INTO `ms_addresses` VALUES ('354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内パシフィックセンチュリープレイス丸の内　6階', '13', '13101', '1006206', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'パシフィックセンチュリープレイス丸の内　6階', 'パシフィックセンチュリープレイスマルノウチ　06カイ');
INSERT INTO `ms_addresses` VALUES ('355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内パシフィックセンチュリープレイス丸の内　7階', '13', '13101', '1006207', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'パシフィックセンチュリープレイス丸の内　7階', 'パシフィックセンチュリープレイスマルノウチ　07カイ');
INSERT INTO `ms_addresses` VALUES ('356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内パシフィックセンチュリープレイス丸の内　8階', '13', '13101', '1006208', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'パシフィックセンチュリープレイス丸の内　8階', 'パシフィックセンチュリープレイスマルノウチ　08カイ');
INSERT INTO `ms_addresses` VALUES ('357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内パシフィックセンチュリープレイス丸の内　9階', '13', '13101', '1006209', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'パシフィックセンチュリープレイス丸の内　9階', 'パシフィックセンチュリープレイスマルノウチ　09カイ');
INSERT INTO `ms_addresses` VALUES ('358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内パシフィックセンチュリープレイス丸の内　10階', '13', '13101', '1006210', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'パシフィックセンチュリープレイス丸の内　10階', 'パシフィックセンチュリープレイスマルノウチ　10カイ');
INSERT INTO `ms_addresses` VALUES ('359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内パシフィックセンチュリープレイス丸の内　11階', '13', '13101', '1006211', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'パシフィックセンチュリープレイス丸の内　11階', 'パシフィックセンチュリープレイスマルノウチ　11カイ');
INSERT INTO `ms_addresses` VALUES ('360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内パシフィックセンチュリープレイス丸の内　12階', '13', '13101', '1006212', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'パシフィックセンチュリープレイス丸の内　12階', 'パシフィックセンチュリープレイスマルノウチ　12カイ');
INSERT INTO `ms_addresses` VALUES ('361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内パシフィックセンチュリープレイス丸の内　13階', '13', '13101', '1006213', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'パシフィックセンチュリープレイス丸の内　13階', 'パシフィックセンチュリープレイスマルノウチ　13カイ');
INSERT INTO `ms_addresses` VALUES ('362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内パシフィックセンチュリープレイス丸の内　14階', '13', '13101', '1006214', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'パシフィックセンチュリープレイス丸の内　14階', 'パシフィックセンチュリープレイスマルノウチ　14カイ');
INSERT INTO `ms_addresses` VALUES ('363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内パシフィックセンチュリープレイス丸の内　15階', '13', '13101', '1006215', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'パシフィックセンチュリープレイス丸の内　15階', 'パシフィックセンチュリープレイスマルノウチ　15カイ');
INSERT INTO `ms_addresses` VALUES ('364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内パシフィックセンチュリープレイス丸の内　16階', '13', '13101', '1006216', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'パシフィックセンチュリープレイス丸の内　16階', 'パシフィックセンチュリープレイスマルノウチ　16カイ');
INSERT INTO `ms_addresses` VALUES ('365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内パシフィックセンチュリープレイス丸の内　17階', '13', '13101', '1006217', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'パシフィックセンチュリープレイス丸の内　17階', 'パシフィックセンチュリープレイスマルノウチ　17カイ');
INSERT INTO `ms_addresses` VALUES ('366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内パシフィックセンチュリープレイス丸の内　18階', '13', '13101', '1006218', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'パシフィックセンチュリープレイス丸の内　18階', 'パシフィックセンチュリープレイスマルノウチ　18カイ');
INSERT INTO `ms_addresses` VALUES ('367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内パシフィックセンチュリープレイス丸の内　19階', '13', '13101', '1006219', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'パシフィックセンチュリープレイス丸の内　19階', 'パシフィックセンチュリープレイスマルノウチ　19カイ');
INSERT INTO `ms_addresses` VALUES ('368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内パシフィックセンチュリープレイス丸の内　20階', '13', '13101', '1006220', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'パシフィックセンチュリープレイス丸の内　20階', 'パシフィックセンチュリープレイスマルノウチ　20カイ');
INSERT INTO `ms_addresses` VALUES ('369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内パシフィックセンチュリープレイス丸の内　21階', '13', '13101', '1006221', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'パシフィックセンチュリープレイス丸の内　21階', 'パシフィックセンチュリープレイスマルノウチ　21カイ');
INSERT INTO `ms_addresses` VALUES ('370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内パシフィックセンチュリープレイス丸の内　22階', '13', '13101', '1006222', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'パシフィックセンチュリープレイス丸の内　22階', 'パシフィックセンチュリープレイスマルノウチ　22カイ');
INSERT INTO `ms_addresses` VALUES ('371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内パシフィックセンチュリープレイス丸の内　23階', '13', '13101', '1006223', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'パシフィックセンチュリープレイス丸の内　23階', 'パシフィックセンチュリープレイスマルノウチ　23カイ');
INSERT INTO `ms_addresses` VALUES ('372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内パシフィックセンチュリープレイス丸の内　24階', '13', '13101', '1006224', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'パシフィックセンチュリープレイス丸の内　24階', 'パシフィックセンチュリープレイスマルノウチ　24カイ');
INSERT INTO `ms_addresses` VALUES ('373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内パシフィックセンチュリープレイス丸の内　25階', '13', '13101', '1006225', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'パシフィックセンチュリープレイス丸の内　25階', 'パシフィックセンチュリープレイスマルノウチ　25カイ');
INSERT INTO `ms_addresses` VALUES ('374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内パシフィックセンチュリープレイス丸の内　26階', '13', '13101', '1006226', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'パシフィックセンチュリープレイス丸の内　26階', 'パシフィックセンチュリープレイスマルノウチ　26カイ');
INSERT INTO `ms_addresses` VALUES ('375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内パシフィックセンチュリープレイス丸の内　27階', '13', '13101', '1006227', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'パシフィックセンチュリープレイス丸の内　27階', 'パシフィックセンチュリープレイスマルノウチ　27カイ');
INSERT INTO `ms_addresses` VALUES ('376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内パシフィックセンチュリープレイス丸の内　28階', '13', '13101', '1006228', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'パシフィックセンチュリープレイス丸の内　28階', 'パシフィックセンチュリープレイスマルノウチ　28カイ');
INSERT INTO `ms_addresses` VALUES ('377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内パシフィックセンチュリープレイス丸の内　29階', '13', '13101', '1006229', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'パシフィックセンチュリープレイス丸の内　29階', 'パシフィックセンチュリープレイスマルノウチ　29カイ');
INSERT INTO `ms_addresses` VALUES ('378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内パシフィックセンチュリープレイス丸の内　30階', '13', '13101', '1006230', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'パシフィックセンチュリープレイス丸の内　30階', 'パシフィックセンチュリープレイスマルノウチ　30カイ');
INSERT INTO `ms_addresses` VALUES ('379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内パシフィックセンチュリープレイス丸の内　31階', '13', '13101', '1006231', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'パシフィックセンチュリープレイス丸の内　31階', 'パシフィックセンチュリープレイスマルノウチ　31カイ');
INSERT INTO `ms_addresses` VALUES ('384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内パシフィックセンチュリープレイス丸の内　', '13', '13101', '1006290', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'パシフィックセンチュリープレイス丸の内　', 'パシフィックセンチュリープレイスマルノウチ　');
INSERT INTO `ms_addresses` VALUES ('385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内丸の内ビルディング　1階', '13', '13101', '1006301', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '丸の内ビルディング　1階', 'マルノウチビルディング　01カイ');
INSERT INTO `ms_addresses` VALUES ('386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内丸の内ビルディング　2階', '13', '13101', '1006302', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '丸の内ビルディング　2階', 'マルノウチビルディング　02カイ');
INSERT INTO `ms_addresses` VALUES ('387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内丸の内ビルディング　3階', '13', '13101', '1006303', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '丸の内ビルディング　3階', 'マルノウチビルディング　03カイ');
INSERT INTO `ms_addresses` VALUES ('388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内丸の内ビルディング　4階', '13', '13101', '1006304', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '丸の内ビルディング　4階', 'マルノウチビルディング　04カイ');
INSERT INTO `ms_addresses` VALUES ('389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内丸の内ビルディング　5階', '13', '13101', '1006305', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '丸の内ビルディング　5階', 'マルノウチビルディング　05カイ');
INSERT INTO `ms_addresses` VALUES ('390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内丸の内ビルディング　6階', '13', '13101', '1006306', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '丸の内ビルディング　6階', 'マルノウチビルディング　06カイ');
INSERT INTO `ms_addresses` VALUES ('391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内丸の内ビルディング　7階', '13', '13101', '1006307', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '丸の内ビルディング　7階', 'マルノウチビルディング　07カイ');
INSERT INTO `ms_addresses` VALUES ('392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内丸の内ビルディング　8階', '13', '13101', '1006308', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '丸の内ビルディング　8階', 'マルノウチビルディング　08カイ');
INSERT INTO `ms_addresses` VALUES ('393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内丸の内ビルディング　9階', '13', '13101', '1006309', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '丸の内ビルディング　9階', 'マルノウチビルディング　09カイ');
INSERT INTO `ms_addresses` VALUES ('394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内丸の内ビルディング　10階', '13', '13101', '1006310', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '丸の内ビルディング　10階', 'マルノウチビルディング　10カイ');
INSERT INTO `ms_addresses` VALUES ('395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内丸の内ビルディング　11階', '13', '13101', '1006311', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '丸の内ビルディング　11階', 'マルノウチビルディング　11カイ');
INSERT INTO `ms_addresses` VALUES ('396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内丸の内ビルディング　12階', '13', '13101', '1006312', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '丸の内ビルディング　12階', 'マルノウチビルディング　12カイ');
INSERT INTO `ms_addresses` VALUES ('397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内丸の内ビルディング　13階', '13', '13101', '1006313', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '丸の内ビルディング　13階', 'マルノウチビルディング　13カイ');
INSERT INTO `ms_addresses` VALUES ('398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内丸の内ビルディング　14階', '13', '13101', '1006314', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '丸の内ビルディング　14階', 'マルノウチビルディング　14カイ');
INSERT INTO `ms_addresses` VALUES ('399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内丸の内ビルディング　15階', '13', '13101', '1006315', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '丸の内ビルディング　15階', 'マルノウチビルディング　15カイ');
INSERT INTO `ms_addresses` VALUES ('400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内丸の内ビルディング　16階', '13', '13101', '1006316', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '丸の内ビルディング　16階', 'マルノウチビルディング　16カイ');
INSERT INTO `ms_addresses` VALUES ('401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内丸の内ビルディング　17階', '13', '13101', '1006317', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '丸の内ビルディング　17階', 'マルノウチビルディング　17カイ');
INSERT INTO `ms_addresses` VALUES ('402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内丸の内ビルディング　18階', '13', '13101', '1006318', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '丸の内ビルディング　18階', 'マルノウチビルディング　18カイ');
INSERT INTO `ms_addresses` VALUES ('403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内丸の内ビルディング　19階', '13', '13101', '1006319', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '丸の内ビルディング　19階', 'マルノウチビルディング　19カイ');
INSERT INTO `ms_addresses` VALUES ('404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内丸の内ビルディング　20階', '13', '13101', '1006320', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '丸の内ビルディング　20階', 'マルノウチビルディング　20カイ');
INSERT INTO `ms_addresses` VALUES ('405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内丸の内ビルディング　21階', '13', '13101', '1006321', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '丸の内ビルディング　21階', 'マルノウチビルディング　21カイ');
INSERT INTO `ms_addresses` VALUES ('406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内丸の内ビルディング　22階', '13', '13101', '1006322', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '丸の内ビルディング　22階', 'マルノウチビルディング　22カイ');
INSERT INTO `ms_addresses` VALUES ('407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内丸の内ビルディング　23階', '13', '13101', '1006323', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '丸の内ビルディング　23階', 'マルノウチビルディング　23カイ');
INSERT INTO `ms_addresses` VALUES ('408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内丸の内ビルディング　24階', '13', '13101', '1006324', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '丸の内ビルディング　24階', 'マルノウチビルディング　24カイ');
INSERT INTO `ms_addresses` VALUES ('409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内丸の内ビルディング　25階', '13', '13101', '1006325', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '丸の内ビルディング　25階', 'マルノウチビルディング　25カイ');
INSERT INTO `ms_addresses` VALUES ('410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内丸の内ビルディング　26階', '13', '13101', '1006326', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '丸の内ビルディング　26階', 'マルノウチビルディング　26カイ');
INSERT INTO `ms_addresses` VALUES ('411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内丸の内ビルディング　27階', '13', '13101', '1006327', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '丸の内ビルディング　27階', 'マルノウチビルディング　27カイ');
INSERT INTO `ms_addresses` VALUES ('412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内丸の内ビルディング　28階', '13', '13101', '1006328', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '丸の内ビルディング　28階', 'マルノウチビルディング　28カイ');
INSERT INTO `ms_addresses` VALUES ('413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内丸の内ビルディング　29階', '13', '13101', '1006329', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '丸の内ビルディング　29階', 'マルノウチビルディング　29カイ');
INSERT INTO `ms_addresses` VALUES ('414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内丸の内ビルディング　30階', '13', '13101', '1006330', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '丸の内ビルディング　30階', 'マルノウチビルディング　30カイ');
INSERT INTO `ms_addresses` VALUES ('415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内丸の内ビルディング　31階', '13', '13101', '1006331', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '丸の内ビルディング　31階', 'マルノウチビルディング　31カイ');
INSERT INTO `ms_addresses` VALUES ('416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内丸の内ビルディング　32階', '13', '13101', '1006332', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '丸の内ビルディング　32階', 'マルノウチビルディング　32カイ');
INSERT INTO `ms_addresses` VALUES ('417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内丸の内ビルディング　33階', '13', '13101', '1006333', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '丸の内ビルディング　33階', 'マルノウチビルディング　33カイ');
INSERT INTO `ms_addresses` VALUES ('418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内丸の内ビルディング　34階', '13', '13101', '1006334', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '丸の内ビルディング　34階', 'マルノウチビルディング　34カイ');
INSERT INTO `ms_addresses` VALUES ('419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内丸の内ビルディング　35階', '13', '13101', '1006335', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '丸の内ビルディング　35階', 'マルノウチビルディング　35カイ');
INSERT INTO `ms_addresses` VALUES ('420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内丸の内ビルディング　36階', '13', '13101', '1006336', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '丸の内ビルディング　36階', 'マルノウチビルディング　36カイ');
INSERT INTO `ms_addresses` VALUES ('421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内丸の内ビルディング　37階', '13', '13101', '1006337', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '丸の内ビルディング　37階', 'マルノウチビルディング　37カイ');
INSERT INTO `ms_addresses` VALUES ('422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内丸の内ビルディング　', '13', '13101', '1006390', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '丸の内ビルディング　', 'マルノウチビルディング　');
INSERT INTO `ms_addresses` VALUES ('423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内東京ビルディング　1階', '13', '13101', '1006401', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '東京ビルディング　1階', 'トウキョウビルディング　01カイ');
INSERT INTO `ms_addresses` VALUES ('424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内東京ビルディング　2階', '13', '13101', '1006402', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '東京ビルディング　2階', 'トウキョウビルディング　02カイ');
INSERT INTO `ms_addresses` VALUES ('425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内東京ビルディング　3階', '13', '13101', '1006403', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '東京ビルディング　3階', 'トウキョウビルディング　03カイ');
INSERT INTO `ms_addresses` VALUES ('426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内東京ビルディング　4階', '13', '13101', '1006404', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '東京ビルディング　4階', 'トウキョウビルディング　04カイ');
INSERT INTO `ms_addresses` VALUES ('427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内東京ビルディング　5階', '13', '13101', '1006405', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '東京ビルディング　5階', 'トウキョウビルディング　05カイ');
INSERT INTO `ms_addresses` VALUES ('428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内東京ビルディング　6階', '13', '13101', '1006406', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '東京ビルディング　6階', 'トウキョウビルディング　06カイ');
INSERT INTO `ms_addresses` VALUES ('429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内東京ビルディング　7階', '13', '13101', '1006407', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '東京ビルディング　7階', 'トウキョウビルディング　07カイ');
INSERT INTO `ms_addresses` VALUES ('430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内東京ビルディング　8階', '13', '13101', '1006408', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '東京ビルディング　8階', 'トウキョウビルディング　08カイ');
INSERT INTO `ms_addresses` VALUES ('431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内東京ビルディング　9階', '13', '13101', '1006409', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '東京ビルディング　9階', 'トウキョウビルディング　09カイ');
INSERT INTO `ms_addresses` VALUES ('432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内東京ビルディング　10階', '13', '13101', '1006410', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '東京ビルディング　10階', 'トウキョウビルディング　10カイ');
INSERT INTO `ms_addresses` VALUES ('433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内東京ビルディング　11階', '13', '13101', '1006411', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '東京ビルディング　11階', 'トウキョウビルディング　11カイ');
INSERT INTO `ms_addresses` VALUES ('434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内東京ビルディング　12階', '13', '13101', '1006412', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '東京ビルディング　12階', 'トウキョウビルディング　12カイ');
INSERT INTO `ms_addresses` VALUES ('435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内東京ビルディング　13階', '13', '13101', '1006413', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '東京ビルディング　13階', 'トウキョウビルディング　13カイ');
INSERT INTO `ms_addresses` VALUES ('436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内東京ビルディング　14階', '13', '13101', '1006414', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '東京ビルディング　14階', 'トウキョウビルディング　14カイ');
INSERT INTO `ms_addresses` VALUES ('437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内東京ビルディング　15階', '13', '13101', '1006415', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '東京ビルディング　15階', 'トウキョウビルディング　15カイ');
INSERT INTO `ms_addresses` VALUES ('438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内東京ビルディング　16階', '13', '13101', '1006416', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '東京ビルディング　16階', 'トウキョウビルディング　16カイ');
INSERT INTO `ms_addresses` VALUES ('439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内東京ビルディング　17階', '13', '13101', '1006417', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '東京ビルディング　17階', 'トウキョウビルディング　17カイ');
INSERT INTO `ms_addresses` VALUES ('440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内東京ビルディング　18階', '13', '13101', '1006418', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '東京ビルディング　18階', 'トウキョウビルディング　18カイ');
INSERT INTO `ms_addresses` VALUES ('441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内東京ビルディング　19階', '13', '13101', '1006419', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '東京ビルディング　19階', 'トウキョウビルディング　19カイ');
INSERT INTO `ms_addresses` VALUES ('442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内東京ビルディング　20階', '13', '13101', '1006420', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '東京ビルディング　20階', 'トウキョウビルディング　20カイ');
INSERT INTO `ms_addresses` VALUES ('443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内東京ビルディング　21階', '13', '13101', '1006421', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '東京ビルディング　21階', 'トウキョウビルディング　21カイ');
INSERT INTO `ms_addresses` VALUES ('444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内東京ビルディング　22階', '13', '13101', '1006422', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '東京ビルディング　22階', 'トウキョウビルディング　22カイ');
INSERT INTO `ms_addresses` VALUES ('445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内東京ビルディング　23階', '13', '13101', '1006423', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '東京ビルディング　23階', 'トウキョウビルディング　23カイ');
INSERT INTO `ms_addresses` VALUES ('446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内東京ビルディング　24階', '13', '13101', '1006424', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '東京ビルディング　24階', 'トウキョウビルディング　24カイ');
INSERT INTO `ms_addresses` VALUES ('447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内東京ビルディング　25階', '13', '13101', '1006425', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '東京ビルディング　25階', 'トウキョウビルディング　25カイ');
INSERT INTO `ms_addresses` VALUES ('448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内東京ビルディング　26階', '13', '13101', '1006426', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '東京ビルディング　26階', 'トウキョウビルディング　26カイ');
INSERT INTO `ms_addresses` VALUES ('449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内東京ビルディング　27階', '13', '13101', '1006427', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '東京ビルディング　27階', 'トウキョウビルディング　27カイ');
INSERT INTO `ms_addresses` VALUES ('450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内東京ビルディング　28階', '13', '13101', '1006428', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '東京ビルディング　28階', 'トウキョウビルディング　28カイ');
INSERT INTO `ms_addresses` VALUES ('451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内東京ビルディング　29階', '13', '13101', '1006429', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '東京ビルディング　29階', 'トウキョウビルディング　29カイ');
INSERT INTO `ms_addresses` VALUES ('452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内東京ビルディング　30階', '13', '13101', '1006430', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '東京ビルディング　30階', 'トウキョウビルディング　30カイ');
INSERT INTO `ms_addresses` VALUES ('453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内東京ビルディング　31階', '13', '13101', '1006431', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '東京ビルディング　31階', 'トウキョウビルディング　31カイ');
INSERT INTO `ms_addresses` VALUES ('454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内東京ビルディング　32階', '13', '13101', '1006432', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '東京ビルディング　32階', 'トウキョウビルディング　32カイ');
INSERT INTO `ms_addresses` VALUES ('455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内東京ビルディング　33階', '13', '13101', '1006433', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '東京ビルディング　33階', 'トウキョウビルディング　33カイ');
INSERT INTO `ms_addresses` VALUES ('456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内東京ビルディング　', '13', '13101', '1006490', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '東京ビルディング　', 'トウキョウビルディング　');
INSERT INTO `ms_addresses` VALUES ('457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内新丸の内ビルディング　1階', '13', '13101', '1006501', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '新丸の内ビルディング　1階', 'シンマルノウチビルディング　01カイ');
INSERT INTO `ms_addresses` VALUES ('458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内新丸の内ビルディング　2階', '13', '13101', '1006502', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '新丸の内ビルディング　2階', 'シンマルノウチビルディング　02カイ');
INSERT INTO `ms_addresses` VALUES ('459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内新丸の内ビルディング　3階', '13', '13101', '1006503', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '新丸の内ビルディング　3階', 'シンマルノウチビルディング　03カイ');
INSERT INTO `ms_addresses` VALUES ('460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内新丸の内ビルディング　4階', '13', '13101', '1006504', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '新丸の内ビルディング　4階', 'シンマルノウチビルディング　04カイ');
INSERT INTO `ms_addresses` VALUES ('461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内新丸の内ビルディング　5階', '13', '13101', '1006505', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '新丸の内ビルディング　5階', 'シンマルノウチビルディング　05カイ');
INSERT INTO `ms_addresses` VALUES ('462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内新丸の内ビルディング　6階', '13', '13101', '1006506', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '新丸の内ビルディング　6階', 'シンマルノウチビルディング　06カイ');
INSERT INTO `ms_addresses` VALUES ('463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内新丸の内ビルディング　7階', '13', '13101', '1006507', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '新丸の内ビルディング　7階', 'シンマルノウチビルディング　07カイ');
INSERT INTO `ms_addresses` VALUES ('464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内新丸の内ビルディング　8階', '13', '13101', '1006508', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '新丸の内ビルディング　8階', 'シンマルノウチビルディング　08カイ');
INSERT INTO `ms_addresses` VALUES ('465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内新丸の内ビルディング　9階', '13', '13101', '1006509', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '新丸の内ビルディング　9階', 'シンマルノウチビルディング　09カイ');
INSERT INTO `ms_addresses` VALUES ('466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内新丸の内ビルディング　10階', '13', '13101', '1006510', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '新丸の内ビルディング　10階', 'シンマルノウチビルディング　10カイ');
INSERT INTO `ms_addresses` VALUES ('467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内新丸の内ビルディング　11階', '13', '13101', '1006511', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '新丸の内ビルディング　11階', 'シンマルノウチビルディング　11カイ');
INSERT INTO `ms_addresses` VALUES ('468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内新丸の内ビルディング　12階', '13', '13101', '1006512', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '新丸の内ビルディング　12階', 'シンマルノウチビルディング　12カイ');
INSERT INTO `ms_addresses` VALUES ('469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内新丸の内ビルディング　13階', '13', '13101', '1006513', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '新丸の内ビルディング　13階', 'シンマルノウチビルディング　13カイ');
INSERT INTO `ms_addresses` VALUES ('470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内新丸の内ビルディング　14階', '13', '13101', '1006514', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '新丸の内ビルディング　14階', 'シンマルノウチビルディング　14カイ');
INSERT INTO `ms_addresses` VALUES ('471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内新丸の内ビルディング　15階', '13', '13101', '1006515', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '新丸の内ビルディング　15階', 'シンマルノウチビルディング　15カイ');
INSERT INTO `ms_addresses` VALUES ('472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内新丸の内ビルディング　16階', '13', '13101', '1006516', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '新丸の内ビルディング　16階', 'シンマルノウチビルディング　16カイ');
INSERT INTO `ms_addresses` VALUES ('473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内新丸の内ビルディング　17階', '13', '13101', '1006517', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '新丸の内ビルディング　17階', 'シンマルノウチビルディング　17カイ');
INSERT INTO `ms_addresses` VALUES ('474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内新丸の内ビルディング　18階', '13', '13101', '1006518', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '新丸の内ビルディング　18階', 'シンマルノウチビルディング　18カイ');
INSERT INTO `ms_addresses` VALUES ('475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内新丸の内ビルディング　19階', '13', '13101', '1006519', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '新丸の内ビルディング　19階', 'シンマルノウチビルディング　19カイ');
INSERT INTO `ms_addresses` VALUES ('476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内新丸の内ビルディング　20階', '13', '13101', '1006520', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '新丸の内ビルディング　20階', 'シンマルノウチビルディング　20カイ');
INSERT INTO `ms_addresses` VALUES ('477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内新丸の内ビルディング　21階', '13', '13101', '1006521', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '新丸の内ビルディング　21階', 'シンマルノウチビルディング　21カイ');
INSERT INTO `ms_addresses` VALUES ('478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内新丸の内ビルディング　22階', '13', '13101', '1006522', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '新丸の内ビルディング　22階', 'シンマルノウチビルディング　22カイ');
INSERT INTO `ms_addresses` VALUES ('479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内新丸の内ビルディング　23階', '13', '13101', '1006523', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '新丸の内ビルディング　23階', 'シンマルノウチビルディング　23カイ');
INSERT INTO `ms_addresses` VALUES ('480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内新丸の内ビルディング　24階', '13', '13101', '1006524', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '新丸の内ビルディング　24階', 'シンマルノウチビルディング　24カイ');
INSERT INTO `ms_addresses` VALUES ('481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内新丸の内ビルディング　25階', '13', '13101', '1006525', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '新丸の内ビルディング　25階', 'シンマルノウチビルディング　25カイ');
INSERT INTO `ms_addresses` VALUES ('482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内新丸の内ビルディング　26階', '13', '13101', '1006526', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '新丸の内ビルディング　26階', 'シンマルノウチビルディング　26カイ');
INSERT INTO `ms_addresses` VALUES ('483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内新丸の内ビルディング　27階', '13', '13101', '1006527', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '新丸の内ビルディング　27階', 'シンマルノウチビルディング　27カイ');
INSERT INTO `ms_addresses` VALUES ('484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内新丸の内ビルディング　28階', '13', '13101', '1006528', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '新丸の内ビルディング　28階', 'シンマルノウチビルディング　28カイ');
INSERT INTO `ms_addresses` VALUES ('485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内新丸の内ビルディング　29階', '13', '13101', '1006529', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '新丸の内ビルディング　29階', 'シンマルノウチビルディング　29カイ');
INSERT INTO `ms_addresses` VALUES ('486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内新丸の内ビルディング　30階', '13', '13101', '1006530', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '新丸の内ビルディング　30階', 'シンマルノウチビルディング　30カイ');
INSERT INTO `ms_addresses` VALUES ('487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内新丸の内ビルディング　31階', '13', '13101', '1006531', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '新丸の内ビルディング　31階', 'シンマルノウチビルディング　31カイ');
INSERT INTO `ms_addresses` VALUES ('488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内新丸の内ビルディング　32階', '13', '13101', '1006532', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '新丸の内ビルディング　32階', 'シンマルノウチビルディング　32カイ');
INSERT INTO `ms_addresses` VALUES ('489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内新丸の内ビルディング　33階', '13', '13101', '1006533', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '新丸の内ビルディング　33階', 'シンマルノウチビルディング　33カイ');
INSERT INTO `ms_addresses` VALUES ('490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内新丸の内ビルディング　34階', '13', '13101', '1006534', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '新丸の内ビルディング　34階', 'シンマルノウチビルディング　34カイ');
INSERT INTO `ms_addresses` VALUES ('491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内新丸の内ビルディング　35階', '13', '13101', '1006535', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '新丸の内ビルディング　35階', 'シンマルノウチビルディング　35カイ');
INSERT INTO `ms_addresses` VALUES ('492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内新丸の内ビルディング　36階', '13', '13101', '1006536', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '新丸の内ビルディング　36階', 'シンマルノウチビルディング　36カイ');
INSERT INTO `ms_addresses` VALUES ('493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内新丸の内ビルディング　37階', '13', '13101', '1006537', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '新丸の内ビルディング　37階', 'シンマルノウチビルディング　37カイ');
INSERT INTO `ms_addresses` VALUES ('494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内新丸の内ビルディング　38階', '13', '13101', '1006538', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '新丸の内ビルディング　38階', 'シンマルノウチビルディング　38カイ');
INSERT INTO `ms_addresses` VALUES ('495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内新丸の内ビルディング　', '13', '13101', '1006590', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, '新丸の内ビルディング　', 'シンマルノウチビルディング　');
INSERT INTO `ms_addresses` VALUES ('496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内グラントウキョウサウスタワー　1階', '13', '13101', '1006601', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'グラントウキョウサウスタワー　1階', 'グラントウキョウサウスタワー　01カイ');
INSERT INTO `ms_addresses` VALUES ('497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内グラントウキョウサウスタワー　2階', '13', '13101', '1006602', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'グラントウキョウサウスタワー　2階', 'グラントウキョウサウスタワー　02カイ');
INSERT INTO `ms_addresses` VALUES ('498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内グラントウキョウサウスタワー　3階', '13', '13101', '1006603', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'グラントウキョウサウスタワー　3階', 'グラントウキョウサウスタワー　03カイ');
INSERT INTO `ms_addresses` VALUES ('499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内グラントウキョウサウスタワー　4階', '13', '13101', '1006604', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'グラントウキョウサウスタワー　4階', 'グラントウキョウサウスタワー　04カイ');
INSERT INTO `ms_addresses` VALUES ('500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内グラントウキョウサウスタワー　5階', '13', '13101', '1006605', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'グラントウキョウサウスタワー　5階', 'グラントウキョウサウスタワー　05カイ');
INSERT INTO `ms_addresses` VALUES ('501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内グラントウキョウサウスタワー　6階', '13', '13101', '1006606', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'グラントウキョウサウスタワー　6階', 'グラントウキョウサウスタワー　06カイ');
INSERT INTO `ms_addresses` VALUES ('502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内グラントウキョウサウスタワー　7階', '13', '13101', '1006607', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'グラントウキョウサウスタワー　7階', 'グラントウキョウサウスタワー　07カイ');
INSERT INTO `ms_addresses` VALUES ('503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内グラントウキョウサウスタワー　8階', '13', '13101', '1006608', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'グラントウキョウサウスタワー　8階', 'グラントウキョウサウスタワー　08カイ');
INSERT INTO `ms_addresses` VALUES ('504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内グラントウキョウサウスタワー　9階', '13', '13101', '1006609', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'グラントウキョウサウスタワー　9階', 'グラントウキョウサウスタワー　09カイ');
INSERT INTO `ms_addresses` VALUES ('505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県男鹿市男鹿中浜間口', '05', '05206', '0100661', '秋田県', 'アキタケン', '男鹿市', 'オガシ', '男鹿中浜間口', 'オガナカハママグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内グラントウキョウサウスタワー　10階', '13', '13101', '1006610', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'グラントウキョウサウスタワー　10階', 'グラントウキョウサウスタワー　10カイ');
INSERT INTO `ms_addresses` VALUES ('507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内グラントウキョウサウスタワー　11階', '13', '13101', '1006611', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'グラントウキョウサウスタワー　11階', 'グラントウキョウサウスタワー　11カイ');
INSERT INTO `ms_addresses` VALUES ('508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内グラントウキョウサウスタワー　12階', '13', '13101', '1006612', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'グラントウキョウサウスタワー　12階', 'グラントウキョウサウスタワー　12カイ');
INSERT INTO `ms_addresses` VALUES ('509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内グラントウキョウサウスタワー　13階', '13', '13101', '1006613', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'グラントウキョウサウスタワー　13階', 'グラントウキョウサウスタワー　13カイ');
INSERT INTO `ms_addresses` VALUES ('510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内グラントウキョウサウスタワー　14階', '13', '13101', '1006614', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'グラントウキョウサウスタワー　14階', 'グラントウキョウサウスタワー　14カイ');
INSERT INTO `ms_addresses` VALUES ('511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内グラントウキョウサウスタワー　15階', '13', '13101', '1006615', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'グラントウキョウサウスタワー　15階', 'グラントウキョウサウスタワー　15カイ');
INSERT INTO `ms_addresses` VALUES ('512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内グラントウキョウサウスタワー　16階', '13', '13101', '1006616', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'グラントウキョウサウスタワー　16階', 'グラントウキョウサウスタワー　16カイ');
INSERT INTO `ms_addresses` VALUES ('513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内グラントウキョウサウスタワー　17階', '13', '13101', '1006617', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'グラントウキョウサウスタワー　17階', 'グラントウキョウサウスタワー　17カイ');
INSERT INTO `ms_addresses` VALUES ('514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内グラントウキョウサウスタワー　18階', '13', '13101', '1006618', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'グラントウキョウサウスタワー　18階', 'グラントウキョウサウスタワー　18カイ');
INSERT INTO `ms_addresses` VALUES ('515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内グラントウキョウサウスタワー　19階', '13', '13101', '1006619', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'グラントウキョウサウスタワー　19階', 'グラントウキョウサウスタワー　19カイ');
INSERT INTO `ms_addresses` VALUES ('516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県男鹿市男鹿中中間口', '05', '05206', '0100662', '秋田県', 'アキタケン', '男鹿市', 'オガシ', '男鹿中中間口', 'オガナカナカマグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内グラントウキョウサウスタワー　20階', '13', '13101', '1006620', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'グラントウキョウサウスタワー　20階', 'グラントウキョウサウスタワー　20カイ');
INSERT INTO `ms_addresses` VALUES ('518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内グラントウキョウサウスタワー　21階', '13', '13101', '1006621', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'グラントウキョウサウスタワー　21階', 'グラントウキョウサウスタワー　21カイ');
INSERT INTO `ms_addresses` VALUES ('519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内グラントウキョウサウスタワー　22階', '13', '13101', '1006622', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'グラントウキョウサウスタワー　22階', 'グラントウキョウサウスタワー　22カイ');
INSERT INTO `ms_addresses` VALUES ('520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内グラントウキョウサウスタワー　23階', '13', '13101', '1006623', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'グラントウキョウサウスタワー　23階', 'グラントウキョウサウスタワー　23カイ');
INSERT INTO `ms_addresses` VALUES ('521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内グラントウキョウサウスタワー　24階', '13', '13101', '1006624', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'グラントウキョウサウスタワー　24階', 'グラントウキョウサウスタワー　24カイ');
INSERT INTO `ms_addresses` VALUES ('522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内グラントウキョウサウスタワー　25階', '13', '13101', '1006625', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'グラントウキョウサウスタワー　25階', 'グラントウキョウサウスタワー　25カイ');
INSERT INTO `ms_addresses` VALUES ('523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内グラントウキョウサウスタワー　26階', '13', '13101', '1006626', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'グラントウキョウサウスタワー　26階', 'グラントウキョウサウスタワー　26カイ');
INSERT INTO `ms_addresses` VALUES ('524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内グラントウキョウサウスタワー　27階', '13', '13101', '1006627', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'グラントウキョウサウスタワー　27階', 'グラントウキョウサウスタワー　27カイ');
INSERT INTO `ms_addresses` VALUES ('525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内グラントウキョウサウスタワー　28階', '13', '13101', '1006628', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'グラントウキョウサウスタワー　28階', 'グラントウキョウサウスタワー　28カイ');
INSERT INTO `ms_addresses` VALUES ('526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内グラントウキョウサウスタワー　29階', '13', '13101', '1006629', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'グラントウキョウサウスタワー　29階', 'グラントウキョウサウスタワー　29カイ');
INSERT INTO `ms_addresses` VALUES ('527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県男鹿市男鹿中滝川', '05', '05206', '0100663', '秋田県', 'アキタケン', '男鹿市', 'オガシ', '男鹿中滝川', 'オガナカタキガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内グラントウキョウサウスタワー　30階', '13', '13101', '1006630', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'グラントウキョウサウスタワー　30階', 'グラントウキョウサウスタワー　30カイ');
INSERT INTO `ms_addresses` VALUES ('529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内グラントウキョウサウスタワー　31階', '13', '13101', '1006631', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'グラントウキョウサウスタワー　31階', 'グラントウキョウサウスタワー　31カイ');
INSERT INTO `ms_addresses` VALUES ('530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内グラントウキョウサウスタワー　32階', '13', '13101', '1006632', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'グラントウキョウサウスタワー　32階', 'グラントウキョウサウスタワー　32カイ');
INSERT INTO `ms_addresses` VALUES ('531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内グラントウキョウサウスタワー　33階', '13', '13101', '1006633', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'グラントウキョウサウスタワー　33階', 'グラントウキョウサウスタワー　33カイ');
INSERT INTO `ms_addresses` VALUES ('532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内グラントウキョウサウスタワー　34階', '13', '13101', '1006634', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'グラントウキョウサウスタワー　34階', 'グラントウキョウサウスタワー　34カイ');
INSERT INTO `ms_addresses` VALUES ('533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内グラントウキョウサウスタワー　35階', '13', '13101', '1006635', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'グラントウキョウサウスタワー　35階', 'グラントウキョウサウスタワー　35カイ');
INSERT INTO `ms_addresses` VALUES ('534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内グラントウキョウサウスタワー　36階', '13', '13101', '1006636', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'グラントウキョウサウスタワー　36階', 'グラントウキョウサウスタワー　36カイ');
INSERT INTO `ms_addresses` VALUES ('535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内グラントウキョウサウスタワー　37階', '13', '13101', '1006637', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'グラントウキョウサウスタワー　37階', 'グラントウキョウサウスタワー　37カイ');
INSERT INTO `ms_addresses` VALUES ('536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内グラントウキョウサウスタワー　38階', '13', '13101', '1006638', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'グラントウキョウサウスタワー　38階', 'グラントウキョウサウスタワー　38カイ');
INSERT INTO `ms_addresses` VALUES ('537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内グラントウキョウサウスタワー　39階', '13', '13101', '1006639', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'グラントウキョウサウスタワー　39階', 'グラントウキョウサウスタワー　39カイ');
INSERT INTO `ms_addresses` VALUES ('538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県男鹿市男鹿中国有地内', '05', '05206', '0100664', '秋田県', 'アキタケン', '男鹿市', 'オガシ', '男鹿中国有地内', 'オガナカコクユウチナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内グラントウキョウサウスタワー　40階', '13', '13101', '1006640', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'グラントウキョウサウスタワー　40階', 'グラントウキョウサウスタワー　40カイ');
INSERT INTO `ms_addresses` VALUES ('540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内グラントウキョウサウスタワー　41階', '13', '13101', '1006641', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'グラントウキョウサウスタワー　41階', 'グラントウキョウサウスタワー　41カイ');
INSERT INTO `ms_addresses` VALUES ('541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内グラントウキョウサウスタワー　42階', '13', '13101', '1006642', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'グラントウキョウサウスタワー　42階', 'グラントウキョウサウスタワー　42カイ');
INSERT INTO `ms_addresses` VALUES ('542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県男鹿市男鹿中山町', '05', '05206', '0100665', '秋田県', 'アキタケン', '男鹿市', 'オガシ', '男鹿中山町', 'オガナカヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内グラントウキョウサウスタワー　', '13', '13101', '1006690', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'グラントウキョウサウスタワー　', 'グラントウキョウサウスタワー　');
INSERT INTO `ms_addresses` VALUES ('544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内グラントウキョウノースタワー　1階', '13', '13101', '1006701', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'グラントウキョウノースタワー　1階', 'グラントウキョウノースタワー　01カイ');
INSERT INTO `ms_addresses` VALUES ('545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内グラントウキョウノースタワー　2階', '13', '13101', '1006702', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'グラントウキョウノースタワー　2階', 'グラントウキョウノースタワー　02カイ');
INSERT INTO `ms_addresses` VALUES ('546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内グラントウキョウノースタワー　3階', '13', '13101', '1006703', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'グラントウキョウノースタワー　3階', 'グラントウキョウノースタワー　03カイ');
INSERT INTO `ms_addresses` VALUES ('547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内グラントウキョウノースタワー　4階', '13', '13101', '1006704', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'グラントウキョウノースタワー　4階', 'グラントウキョウノースタワー　04カイ');
INSERT INTO `ms_addresses` VALUES ('548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内グラントウキョウノースタワー　5階', '13', '13101', '1006705', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'グラントウキョウノースタワー　5階', 'グラントウキョウノースタワー　05カイ');
INSERT INTO `ms_addresses` VALUES ('549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内グラントウキョウノースタワー　6階', '13', '13101', '1006706', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'グラントウキョウノースタワー　6階', 'グラントウキョウノースタワー　06カイ');
INSERT INTO `ms_addresses` VALUES ('550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内グラントウキョウノースタワー　7階', '13', '13101', '1006707', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'グラントウキョウノースタワー　7階', 'グラントウキョウノースタワー　07カイ');
INSERT INTO `ms_addresses` VALUES ('551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内グラントウキョウノースタワー　8階', '13', '13101', '1006708', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'グラントウキョウノースタワー　8階', 'グラントウキョウノースタワー　08カイ');
INSERT INTO `ms_addresses` VALUES ('552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内グラントウキョウノースタワー　9階', '13', '13101', '1006709', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'グラントウキョウノースタワー　9階', 'グラントウキョウノースタワー　09カイ');
INSERT INTO `ms_addresses` VALUES ('553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県男鹿市戸賀加茂青砂', '05', '05206', '0100671', '秋田県', 'アキタケン', '男鹿市', 'オガシ', '戸賀加茂青砂', 'トガカモアオサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内グラントウキョウノースタワー　10階', '13', '13101', '1006710', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'グラントウキョウノースタワー　10階', 'グラントウキョウノースタワー　10カイ');
INSERT INTO `ms_addresses` VALUES ('555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内グラントウキョウノースタワー　11階', '13', '13101', '1006711', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'グラントウキョウノースタワー　11階', 'グラントウキョウノースタワー　11カイ');
INSERT INTO `ms_addresses` VALUES ('556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内グラントウキョウノースタワー　12階', '13', '13101', '1006712', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'グラントウキョウノースタワー　12階', 'グラントウキョウノースタワー　12カイ');
INSERT INTO `ms_addresses` VALUES ('557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内グラントウキョウノースタワー　13階', '13', '13101', '1006713', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'グラントウキョウノースタワー　13階', 'グラントウキョウノースタワー　13カイ');
INSERT INTO `ms_addresses` VALUES ('558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内グラントウキョウノースタワー　14階', '13', '13101', '1006714', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'グラントウキョウノースタワー　14階', 'グラントウキョウノースタワー　14カイ');
INSERT INTO `ms_addresses` VALUES ('559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内グラントウキョウノースタワー　15階', '13', '13101', '1006715', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'グラントウキョウノースタワー　15階', 'グラントウキョウノースタワー　15カイ');
INSERT INTO `ms_addresses` VALUES ('560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内グラントウキョウノースタワー　16階', '13', '13101', '1006716', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'グラントウキョウノースタワー　16階', 'グラントウキョウノースタワー　16カイ');
INSERT INTO `ms_addresses` VALUES ('561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内グラントウキョウノースタワー　17階', '13', '13101', '1006717', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'グラントウキョウノースタワー　17階', 'グラントウキョウノースタワー　17カイ');
INSERT INTO `ms_addresses` VALUES ('562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内グラントウキョウノースタワー　18階', '13', '13101', '1006718', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'グラントウキョウノースタワー　18階', 'グラントウキョウノースタワー　18カイ');
INSERT INTO `ms_addresses` VALUES ('563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内グラントウキョウノースタワー　19階', '13', '13101', '1006719', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'グラントウキョウノースタワー　19階', 'グラントウキョウノースタワー　19カイ');
INSERT INTO `ms_addresses` VALUES ('564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県男鹿市戸賀浜塩谷', '05', '05206', '0100672', '秋田県', 'アキタケン', '男鹿市', 'オガシ', '戸賀浜塩谷', 'トガハマシオヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内グラントウキョウノースタワー　20階', '13', '13101', '1006720', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'グラントウキョウノースタワー　20階', 'グラントウキョウノースタワー　20カイ');
INSERT INTO `ms_addresses` VALUES ('566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内グラントウキョウノースタワー　21階', '13', '13101', '1006721', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'グラントウキョウノースタワー　21階', 'グラントウキョウノースタワー　21カイ');
INSERT INTO `ms_addresses` VALUES ('567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内グラントウキョウノースタワー　22階', '13', '13101', '1006722', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'グラントウキョウノースタワー　22階', 'グラントウキョウノースタワー　22カイ');
INSERT INTO `ms_addresses` VALUES ('568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内グラントウキョウノースタワー　23階', '13', '13101', '1006723', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'グラントウキョウノースタワー　23階', 'グラントウキョウノースタワー　23カイ');
INSERT INTO `ms_addresses` VALUES ('569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内グラントウキョウノースタワー　24階', '13', '13101', '1006724', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'グラントウキョウノースタワー　24階', 'グラントウキョウノースタワー　24カイ');
INSERT INTO `ms_addresses` VALUES ('570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内グラントウキョウノースタワー　25階', '13', '13101', '1006725', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'グラントウキョウノースタワー　25階', 'グラントウキョウノースタワー　25カイ');
INSERT INTO `ms_addresses` VALUES ('571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内グラントウキョウノースタワー　26階', '13', '13101', '1006726', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'グラントウキョウノースタワー　26階', 'グラントウキョウノースタワー　26カイ');
INSERT INTO `ms_addresses` VALUES ('572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内グラントウキョウノースタワー　27階', '13', '13101', '1006727', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'グラントウキョウノースタワー　27階', 'グラントウキョウノースタワー　27カイ');
INSERT INTO `ms_addresses` VALUES ('573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内グラントウキョウノースタワー　28階', '13', '13101', '1006728', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'グラントウキョウノースタワー　28階', 'グラントウキョウノースタワー　28カイ');
INSERT INTO `ms_addresses` VALUES ('574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内グラントウキョウノースタワー　29階', '13', '13101', '1006729', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'グラントウキョウノースタワー　29階', 'グラントウキョウノースタワー　29カイ');
INSERT INTO `ms_addresses` VALUES ('575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県男鹿市戸賀塩浜', '05', '05206', '0100673', '秋田県', 'アキタケン', '男鹿市', 'オガシ', '戸賀塩浜', 'トガシオハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内グラントウキョウノースタワー　30階', '13', '13101', '1006730', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'グラントウキョウノースタワー　30階', 'グラントウキョウノースタワー　30カイ');
INSERT INTO `ms_addresses` VALUES ('577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内グラントウキョウノースタワー　31階', '13', '13101', '1006731', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'グラントウキョウノースタワー　31階', 'グラントウキョウノースタワー　31カイ');
INSERT INTO `ms_addresses` VALUES ('578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内グラントウキョウノースタワー　32階', '13', '13101', '1006732', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'グラントウキョウノースタワー　32階', 'グラントウキョウノースタワー　32カイ');
INSERT INTO `ms_addresses` VALUES ('579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内グラントウキョウノースタワー　33階', '13', '13101', '1006733', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'グラントウキョウノースタワー　33階', 'グラントウキョウノースタワー　33カイ');
INSERT INTO `ms_addresses` VALUES ('580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内グラントウキョウノースタワー　34階', '13', '13101', '1006734', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'グラントウキョウノースタワー　34階', 'グラントウキョウノースタワー　34カイ');
INSERT INTO `ms_addresses` VALUES ('581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内グラントウキョウノースタワー　35階', '13', '13101', '1006735', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'グラントウキョウノースタワー　35階', 'グラントウキョウノースタワー　35カイ');
INSERT INTO `ms_addresses` VALUES ('582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内グラントウキョウノースタワー　36階', '13', '13101', '1006736', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'グラントウキョウノースタワー　36階', 'グラントウキョウノースタワー　36カイ');
INSERT INTO `ms_addresses` VALUES ('583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内グラントウキョウノースタワー　37階', '13', '13101', '1006737', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'グラントウキョウノースタワー　37階', 'グラントウキョウノースタワー　37カイ');
INSERT INTO `ms_addresses` VALUES ('584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内グラントウキョウノースタワー　38階', '13', '13101', '1006738', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'グラントウキョウノースタワー　38階', 'グラントウキョウノースタワー　38カイ');
INSERT INTO `ms_addresses` VALUES ('585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内グラントウキョウノースタワー　39階', '13', '13101', '1006739', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'グラントウキョウノースタワー　39階', 'グラントウキョウノースタワー　39カイ');
INSERT INTO `ms_addresses` VALUES ('586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県男鹿市戸賀戸賀', '05', '05206', '0100674', '秋田県', 'アキタケン', '男鹿市', 'オガシ', '戸賀戸賀', 'トガトガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内グラントウキョウノースタワー　40階', '13', '13101', '1006740', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'グラントウキョウノースタワー　40階', 'グラントウキョウノースタワー　40カイ');
INSERT INTO `ms_addresses` VALUES ('588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内グラントウキョウノースタワー　41階', '13', '13101', '1006741', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'グラントウキョウノースタワー　41階', 'グラントウキョウノースタワー　41カイ');
INSERT INTO `ms_addresses` VALUES ('589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内グラントウキョウノースタワー　42階', '13', '13101', '1006742', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'グラントウキョウノースタワー　42階', 'グラントウキョウノースタワー　42カイ');
INSERT INTO `ms_addresses` VALUES ('590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内グラントウキョウノースタワー　43階', '13', '13101', '1006743', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'グラントウキョウノースタワー　43階', 'グラントウキョウノースタワー　43カイ');
INSERT INTO `ms_addresses` VALUES ('591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県男鹿市北浦入道崎', '05', '05206', '0100675', '秋田県', 'アキタケン', '男鹿市', 'オガシ', '北浦入道崎', 'キタウラニュウドウザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県男鹿市北浦西黒沢', '05', '05206', '0100676', '秋田県', 'アキタケン', '男鹿市', 'オガシ', '北浦西黒沢', 'キタウラニシクロサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区丸の内グラントウキョウノースタワー　', '13', '13101', '1006790', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '丸の内', 'マルノウチ', null, null, 'グラントウキョウノースタワー　', 'グラントウキョウノースタワー　');
INSERT INTO `ms_addresses` VALUES ('599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県男鹿市北浦相川', '05', '05206', '0100681', '秋田県', 'アキタケン', '男鹿市', 'オガシ', '北浦相川', 'キタウラアイカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県男鹿市北浦表町', '05', '05206', '0100682', '秋田県', 'アキタケン', '男鹿市', 'オガシ', '北浦表町', 'キタウラオモテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県男鹿市北浦北浦', '05', '05206', '0100683', '秋田県', 'アキタケン', '男鹿市', 'オガシ', '北浦北浦', 'キタウラキタウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県男鹿市北浦安全寺', '05', '05206', '0100684', '秋田県', 'アキタケン', '男鹿市', 'オガシ', '北浦安全寺', 'キタウラアンゼンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県男鹿市北浦真山', '05', '05206', '0100685', '秋田県', 'アキタケン', '男鹿市', 'オガシ', '北浦真山', 'キタウラシンザン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県男鹿市北浦西水口', '05', '05206', '0100686', '秋田県', 'アキタケン', '男鹿市', 'オガシ', '北浦西水口', 'キタウラニシミズグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県男鹿市北浦湯本', '05', '05206', '0100687', '秋田県', 'アキタケン', '男鹿市', 'オガシ', '北浦湯本', 'キタウラユモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県男鹿市北浦野村', '05', '05206', '0100688', '秋田県', 'アキタケン', '男鹿市', 'オガシ', '北浦野村', 'キタウラノムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市外旭川', '05', '05201', '0100802', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '外旭川', 'ソトアサヒカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市外旭川八柳', '05', '05201', '0100803', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '外旭川八柳', 'ソトアサヒカワヤツヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市外旭川八幡田', '05', '05201', '0100804', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '外旭川八幡田', 'ソトアサヒカワハチマンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市泉釜ノ町', '05', '05201', '0100811', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '泉釜ノ町', 'イズミカマノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市泉三嶽根', '05', '05201', '0100812', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '泉三嶽根', 'イズミミタケネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市泉一ノ坪', '05', '05201', '0100813', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '泉一ノ坪', 'イズミイチノツボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市泉東町', '05', '05201', '0100814', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '泉東町', 'イズミヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市泉馬場', '05', '05201', '0100815', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '泉馬場', 'イズミババ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市泉', '05', '05201', '0100816', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '泉', 'イズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市泉菅野', '05', '05201', '0100817', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '泉菅野', 'イズミスガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市濁川', '05', '05201', '0100821', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '濁川', 'ニゴリカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市添川', '05', '05201', '0100822', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '添川', 'ソエガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市山内', '05', '05201', '0100823', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '山内', 'サンナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市仁別', '05', '05201', '0100824', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '仁別', 'ニベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市柳田', '05', '05201', '0100825', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '柳田', 'ヤナギダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市新藤田', '05', '05201', '0100826', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '新藤田', 'シントウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市旭川清澄町', '05', '05201', '0100831', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '旭川清澄町', 'アサヒカワキヨスミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市旭川新藤田西町', '05', '05201', '0100832', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '旭川新藤田西町', 'アサヒカワシントウダニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市旭川新藤田東町', '05', '05201', '0100833', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '旭川新藤田東町', 'アサヒカワシントウダヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市旭川南町', '05', '05201', '0100834', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '旭川南町', 'アサヒカワミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市手形山西町', '05', '05201', '0100841', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '手形山西町', 'テガタヤマニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市手形山北町', '05', '05201', '0100842', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '手形山北町', 'テガタヤマキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市手形山東町', '05', '05201', '0100843', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '手形山東町', 'テガタヤマヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市手形山中町', '05', '05201', '0100844', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '手形山中町', 'テガタヤマナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市手形山南町', '05', '05201', '0100845', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '手形山南町', 'テガタヤマミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市手形', '05', '05201', '0100851', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '手形', 'テガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市手形学園町', '05', '05201', '0100852', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '手形学園町', 'テガタガクエンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市蛇野', '05', '05201', '0100853', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '蛇野', 'ヘビノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市手形山崎町', '05', '05201', '0100854', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '手形山崎町', 'テガタヤマザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市手形からみでん', '05', '05201', '0100861', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '手形からみでん', 'テガタカラミデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市手形田中', '05', '05201', '0100862', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '手形田中', 'テガタタナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市手形休下町', '05', '05201', '0100863', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '手形休下町', 'テガタキュウカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市手形住吉町', '05', '05201', '0100864', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '手形住吉町', 'テガタスミヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市手形新栄町', '05', '05201', '0100865', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '手形新栄町', 'テガタシンサカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市千秋中島町', '05', '05201', '0100871', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '千秋中島町', 'センシュウナカジママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市千秋北の丸', '05', '05201', '0100872', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '千秋北の丸', 'センシュウキタノマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市千秋城下町', '05', '05201', '0100873', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '千秋城下町', 'センシュウジョウカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市千秋久保田町', '05', '05201', '0100874', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '千秋久保田町', 'センシュウクボタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市千秋明徳町', '05', '05201', '0100875', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '千秋明徳町', 'センシュウメイトクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市千秋公園', '05', '05201', '0100876', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '千秋公園', 'センシュウコウエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市千秋矢留町', '05', '05201', '0100877', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '千秋矢留町', 'センシュウヤドメマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市保戸野桜町', '05', '05201', '0100901', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '保戸野桜町', 'ホドノサクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市保戸野金砂町', '05', '05201', '0100902', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '保戸野金砂町', 'ホドノカナサマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市保戸野八丁', '05', '05201', '0100903', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '保戸野八丁', 'ホドノハッチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市保戸野原の町', '05', '05201', '0100904', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '保戸野原の町', 'ホドノハラノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市保戸野中町', '05', '05201', '0100905', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '保戸野中町', 'ホドノナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市保戸野すわ町', '05', '05201', '0100911', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '保戸野すわ町', 'ホドノスワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市保戸野通町', '05', '05201', '0100912', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '保戸野通町', 'ホドノトオリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市保戸野鉄砲町', '05', '05201', '0100913', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '保戸野鉄砲町', 'ホドノテッポウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市保戸野千代田町', '05', '05201', '0100914', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '保戸野千代田町', 'ホドノチヨダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市保戸野', '05', '05201', '0100915', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '保戸野', 'ホドノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市泉北', '05', '05201', '0100916', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '泉北', 'イズミキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市泉中央', '05', '05201', '0100917', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '泉中央', 'イズミチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市泉南', '05', '05201', '0100918', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '泉南', 'イズミミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市大町', '05', '05201', '0100921', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '大町', 'オオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市旭北栄町', '05', '05201', '0100922', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '旭北栄町', 'キョクホクサカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市旭北錦町', '05', '05201', '0100923', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '旭北錦町', 'キョクホクニシキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市旭北寺町', '05', '05201', '0100924', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '旭北寺町', 'キョクホクテラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市旭南', '05', '05201', '0100925', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '旭南', 'キョクナン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市川元山下町', '05', '05201', '0100931', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '川元山下町', 'カワモトヤマシタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市川元開和町', '05', '05201', '0100932', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '川元開和町', 'カワモトカイワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市川元松丘町', '05', '05201', '0100933', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '川元松丘町', 'カワモトマツオカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市川元むつみ町', '05', '05201', '0100934', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '川元むつみ町', 'カワモトムツミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市川元小川町', '05', '05201', '0100935', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '川元小川町', 'カワモトオガワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市川尻町', '05', '05201', '0100941', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '川尻町', 'カワシリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市川尻大川町', '05', '05201', '0100942', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '川尻大川町', 'カワシリオオカワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市川尻御休町', '05', '05201', '0100943', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '川尻御休町', 'カワシリオヤスミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市川尻若葉町', '05', '05201', '0100944', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '川尻若葉町', 'カワシリワカバマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市川尻みよし町', '05', '05201', '0100945', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '川尻みよし町', 'カワシリミヨシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市川尻総社町', '05', '05201', '0100946', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '川尻総社町', 'カワシリソウシャマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市川尻上野町', '05', '05201', '0100947', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '川尻上野町', 'カワシリウエノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市川尻新川町', '05', '05201', '0100948', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '川尻新川町', 'カワシリシンカワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市山王', '05', '05201', '0100951', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '山王', 'サンノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市山王新町', '05', '05201', '0100952', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '山王新町', 'サンノウシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市山王中園町', '05', '05201', '0100953', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '山王中園町', 'サンノウナカゾノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市山王沼田町', '05', '05201', '0100954', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '山王沼田町', 'サンノウヌマタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市山王中島町', '05', '05201', '0100955', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '山王中島町', 'サンノウナカジママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市山王臨海町', '05', '05201', '0100956', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '山王臨海町', 'サンノウリンカイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市八橋イサノ', '05', '05201', '0100961', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '八橋イサノ', 'ヤバセイサノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市八橋大畑', '05', '05201', '0100962', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '八橋大畑', 'ヤバセオオハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市八橋大沼町', '05', '05201', '0100963', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '八橋大沼町', 'ヤバセオオヌマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市八橋鯲沼町', '05', '05201', '0100964', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '八橋鯲沼町', 'ヤバセドジョウヌママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市八橋新川向', '05', '05201', '0100965', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '八橋新川向', 'ヤバセシンカワムカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市高陽青柳町', '05', '05201', '0100966', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '高陽青柳町', 'コウヨウアオヤギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市高陽幸町', '05', '05201', '0100967', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '高陽幸町', 'コウヨウサイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市八橋三和町', '05', '05201', '0100971', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '八橋三和町', 'ヤバセミワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市八橋田五郎', '05', '05201', '0100972', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '八橋田五郎', 'ヤバセタゴロウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市八橋本町', '05', '05201', '0100973', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '八橋本町', 'ヤバセホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市八橋運動公園', '05', '05201', '0100974', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '八橋運動公園', 'ヤバセウンドウコウエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市八橋', '05', '05201', '0100975', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '八橋', 'ヤバセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市八橋南', '05', '05201', '0100976', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '八橋南', 'ヤバセミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市八橋大道東', '05', '05201', '0100977', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '八橋大道東', 'ヤバセダイドウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区一ツ橋2丁目', '13', '13101', '1010003', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '一ツ橋', 'ヒトツバシ', null, null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区外神田', '13', '13101', '1010021', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '外神田', 'ソトカンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区神田練塀町', '13', '13101', '1010022', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '神田練塀町', 'カンダネリベイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区神田松永町', '13', '13101', '1010023', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '神田松永町', 'カンダマツナガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区神田和泉町', '13', '13101', '1010024', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '神田和泉町', 'カンダイズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区神田佐久間町', '13', '13101', '1010025', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '神田佐久間町', 'カンダサクマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区神田佐久間河岸', '13', '13101', '1010026', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '神田佐久間河岸', 'カンダサクマガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区神田平河町', '13', '13101', '1010027', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '神田平河町', 'カンダヒラカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区神田花岡町', '13', '13101', '1010028', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '神田花岡町', 'カンダハナオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区神田相生町', '13', '13101', '1010029', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '神田相生町', 'カンダアイオイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区東神田', '13', '13101', '1010031', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '東神田', 'ヒガシカンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区岩本町', '13', '13101', '1010032', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '岩本町', 'イワモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区神田岩本町', '13', '13101', '1010033', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '神田岩本町', 'カンダイワモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区神田東紺屋町', '13', '13101', '1010034', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '神田東紺屋町', 'カンダヒガシコンヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区神田紺屋町', '13', '13101', '1010035', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '神田紺屋町', 'カンダコンヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区神田北乗物町', '13', '13101', '1010036', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '神田北乗物町', 'カンダキタノリモノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区神田西福田町', '13', '13101', '1010037', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '神田西福田町', 'カンダニシフクダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区神田美倉町', '13', '13101', '1010038', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '神田美倉町', 'カンダミクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区神田須田町', '13', '13101', '1010041', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '神田須田町', 'カンダスダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区神田東松下町', '13', '13101', '1010042', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '神田東松下町', 'カンダヒガシマツシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区神田富山町', '13', '13101', '1010043', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '神田富山町', 'カンダトミヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区鍛冶町', '13', '13101', '1010044', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '鍛冶町', 'カジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区神田鍛冶町', '13', '13101', '1010045', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '神田鍛冶町', 'カンダカジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区神田多町', '13', '13101', '1010046', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '神田多町', 'カンダタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区内神田', '13', '13101', '1010047', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '内神田', 'ウチカンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区神田司町', '13', '13101', '1010048', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '神田司町', 'カンダツカサマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区神田神保町', '13', '13101', '1010051', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '神田神保町', 'カンダジンボウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区神田小川町', '13', '13101', '1010052', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '神田小川町', 'カンダオガワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区神田美土代町', '13', '13101', '1010053', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '神田美土代町', 'カンダミトシロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区神田錦町', '13', '13101', '1010054', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '神田錦町', 'カンダニシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区三崎町', '13', '13101', '1010061', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '三崎町', 'ミサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区神田駿河台', '13', '13101', '1010062', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '神田駿河台', 'カンダスルガダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区神田淡路町', '13', '13101', '1010063', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '神田淡路町', 'カンダアワジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区猿楽町', '13', '13101', '1010064', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '猿楽町', 'サルガクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区西神田', '13', '13101', '1010065', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '西神田', 'ニシカンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市太平八田', '05', '05201', '0101101', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '太平八田', 'タイヘイハッタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市太平目長崎', '05', '05201', '0101102', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '太平目長崎', 'タイヘイメナガサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市太平中関', '05', '05201', '0101103', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '太平中関', 'タイヘイナカゼキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市太平寺庭', '05', '05201', '0101104', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '太平寺庭', 'タイヘイテラニワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市太平黒沢', '05', '05201', '0101105', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '太平黒沢', 'タイヘイクロサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市太平山谷', '05', '05201', '0101106', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '太平山谷', 'タイヘイヤマヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市雄和田草川', '05', '05201', '0101201', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '雄和田草川', 'ユウワタクサガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市雄和芝野新田', '05', '05201', '0101202', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '雄和芝野新田', 'ユウワシバノシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市雄和下黒瀬', '05', '05201', '0101203', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '雄和下黒瀬', 'ユウワシモクロセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市雄和椿川', '05', '05201', '0101211', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '雄和椿川', 'ユウワツバキカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市雄和平尾鳥', '05', '05201', '0101212', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '雄和平尾鳥', 'ユウワヒラオトリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市雄和平沢', '05', '05201', '0101221', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '雄和平沢', 'ユウワヒラサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市雄和石田', '05', '05201', '0101222', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '雄和石田', 'ユウワイシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市雄和妙法', '05', '05201', '0101223', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '雄和妙法', 'ユウワミョウホウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市雄和種沢', '05', '05201', '0101224', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '雄和種沢', 'ユウワタネザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市雄和左手子', '05', '05201', '0101225', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '雄和左手子', 'ユウワサデコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市雄和相川', '05', '05201', '0101231', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '雄和相川', 'ユウワアイカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市雄和戸賀沢', '05', '05201', '0101232', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '雄和戸賀沢', 'ユウワトガザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市雄和女米木', '05', '05201', '0101233', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '雄和女米木', 'ユウワメメキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市雄和新波', '05', '05201', '0101341', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '雄和新波', 'ユウワアラワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市雄和神ケ村', '05', '05201', '0101342', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '雄和神ケ村', 'ユウワジンガムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市雄和繋', '05', '05201', '0101343', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '雄和繋', 'ユウワツナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市雄和向野', '05', '05201', '0101344', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '雄和向野', 'ユウワムカイノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市雄和碇田', '05', '05201', '0101351', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '雄和碇田', 'ユウワイカリダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市雄和萱ケ沢', '05', '05201', '0101352', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '雄和萱ケ沢', 'ユウワカヤガサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市上北手大杉沢', '05', '05201', '0101401', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '上北手大杉沢', 'カミキタテオオスギサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市上北手小山田', '05', '05201', '0101402', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '上北手小山田', 'カミキタテオヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市上北手荒巻', '05', '05201', '0101403', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '上北手荒巻', 'カミキタテアラマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市上北手古野', '05', '05201', '0101404', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '上北手古野', 'カミキタテコノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市上北手大山田', '05', '05201', '0101405', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '上北手大山田', 'カミキタテオオヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市上北手猿田', '05', '05201', '0101406', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '上北手猿田', 'カミキタテサルタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市上北手百崎', '05', '05201', '0101407', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '上北手百崎', 'カミキタテモモザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市上北手大戸', '05', '05201', '0101408', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '上北手大戸', 'カミキタテオオド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市上北手御所野', '05', '05201', '0101411', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '上北手御所野', 'カミキタテゴショノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市御所野下堤', '05', '05201', '0101412', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '御所野下堤', 'ゴショノシモツツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市御所野地蔵田', '05', '05201', '0101413', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '御所野地蔵田', 'ゴショノジゾウデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市御所野元町', '05', '05201', '0101414', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '御所野元町', 'ゴショノモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市御所野湯本', '05', '05201', '0101415', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '御所野湯本', 'ゴショノユモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市四ツ小屋末戸松本', '05', '05201', '0101416', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '四ツ小屋末戸松本', 'ヨツゴヤスエドマツモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市四ツ小屋', '05', '05201', '0101417', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '四ツ小屋', 'ヨツゴヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市四ツ小屋小阿地', '05', '05201', '0101418', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '四ツ小屋小阿地', 'ヨツゴヤコアジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市御所野堤台', '05', '05201', '0101419', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '御所野堤台', 'ゴショノツツミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市仁井田本町', '05', '05201', '0101421', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '仁井田本町', 'ニイダホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市仁井田目長田', '05', '05201', '0101422', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '仁井田目長田', 'ニイダメナガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市仁井田', '05', '05201', '0101423', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '仁井田', 'ニイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市御野場', '05', '05201', '0101424', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '御野場', 'オノバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市御野場新町', '05', '05201', '0101425', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '御野場新町', 'オノバシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市仁井田小中島', '05', '05201', '0101426', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '仁井田小中島', 'ニイダコナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市仁井田新田', '05', '05201', '0101427', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '仁井田新田', 'ニイダシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市大平台', '05', '05201', '0101428', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '大平台', 'オオヒラダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市山手台', '05', '05201', '0101429', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '山手台', 'ヤマテダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市仁井田二ツ屋', '05', '05201', '0101431', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '仁井田二ツ屋', 'ニイダフタツヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市仁井田福島', '05', '05201', '0101432', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '仁井田福島', 'ニイダフクシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市仁井田栄町', '05', '05201', '0101433', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '仁井田栄町', 'ニイダサカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市仁井田蕗見町', '05', '05201', '0101434', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '仁井田蕗見町', 'ニイダフキミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市仁井田潟中町', '05', '05201', '0101435', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '仁井田潟中町', 'ニイダカタナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市大住', '05', '05201', '0101436', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '大住', 'オオスミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市仁井田緑町', '05', '05201', '0101437', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '仁井田緑町', 'ニイダミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市下浜桂根', '05', '05201', '0101501', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '下浜桂根', 'シモハマカツラネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市下浜長浜', '05', '05201', '0101502', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '下浜長浜', 'シモハマナガハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市下浜羽川', '05', '05201', '0101503', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '下浜羽川', 'シモハマハネカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市下浜名ケ沢', '05', '05201', '0101504', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '下浜名ケ沢', 'シモハマミョウガサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市下浜八田', '05', '05201', '0101505', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '下浜八田', 'シモハマハッタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市下浜楢田', '05', '05201', '0101506', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '下浜楢田', 'シモハマナラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市向浜', '05', '05201', '0101601', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '向浜', 'ムカイハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市新屋下川原町', '05', '05201', '0101602', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '新屋下川原町', 'アラヤシタカワラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市新屋勝平台', '05', '05201', '0101603', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '新屋勝平台', 'アラヤカツヒラダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市新屋松美町', '05', '05201', '0101604', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '新屋松美町', 'アラヤマツミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市新屋勝平町', '05', '05201', '0101605', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '新屋勝平町', 'アラヤカツヒラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市新屋寿町', '05', '05201', '0101606', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '新屋寿町', 'アラヤコトブキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市新屋南浜町', '05', '05201', '0101607', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '新屋南浜町', 'アラヤミナミハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市新屋北浜町', '05', '05201', '0101608', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '新屋北浜町', 'アラヤキタハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市新屋天秤野', '05', '05201', '0101611', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '新屋天秤野', 'アラヤテンビンノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市新屋豊町', '05', '05201', '0101612', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '新屋豊町', 'アラヤユタカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市新屋朝日町', '05', '05201', '0101613', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '新屋朝日町', 'アラヤアサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市新屋割山町', '05', '05201', '0101614', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '新屋割山町', 'アラヤワリヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市新屋船場町', '05', '05201', '0101615', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '新屋船場町', 'アラヤフナバマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市新屋松美ガ丘南町', '05', '05201', '0101616', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '新屋松美ガ丘南町', 'アラヤマツミガオカミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市新屋松美ガ丘東町', '05', '05201', '0101617', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '新屋松美ガ丘東町', 'アラヤマツミガオカヒガシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市新屋松美ガ丘北町', '05', '05201', '0101618', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '新屋松美ガ丘北町', 'アラヤマツミガオカキタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市新屋栗田町', '05', '05201', '0101621', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '新屋栗田町', 'アラヤクリタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市新屋日吉町', '05', '05201', '0101622', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '新屋日吉町', 'アラヤヒヨシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市新屋町', '05', '05201', '0101623', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '新屋町', 'アラヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市新屋元町', '05', '05201', '0101631', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '新屋元町', 'アラヤモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市新屋大川町', '05', '05201', '0101632', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '新屋大川町', 'アラヤオオカワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市新屋鳥木町', '05', '05201', '0101633', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '新屋鳥木町', 'アラヤトリキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市新屋沖田町', '05', '05201', '0101634', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '新屋沖田町', 'アラヤオキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市新屋前野町', '05', '05201', '0101635', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '新屋前野町', 'アラヤマエノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市新屋比内町', '05', '05201', '0101636', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '新屋比内町', 'アラヤヒナイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市新屋扇町', '05', '05201', '0101637', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '新屋扇町', 'アラヤオオギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市新屋表町', '05', '05201', '0101638', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '新屋表町', 'アラヤオモテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市新屋高美町', '05', '05201', '0101641', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '新屋高美町', 'アラヤタカミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市新屋渋谷町', '05', '05201', '0101642', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '新屋渋谷町', 'アラヤシブヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市新屋田尻沢東町', '05', '05201', '0101643', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '新屋田尻沢東町', 'アラヤタジリザワヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市新屋田尻沢中町', '05', '05201', '0101644', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '新屋田尻沢中町', 'アラヤタジリザワナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市新屋田尻沢西町', '05', '05201', '0101645', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '新屋田尻沢西町', 'アラヤタジリザワニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市豊岩石田坂', '05', '05201', '0101651', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '豊岩石田坂', 'トヨイワイシダザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市豊岩豊巻', '05', '05201', '0101652', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '豊岩豊巻', 'トヨイワトヨマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市豊岩小山', '05', '05201', '0101653', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '豊岩小山', 'トヨイワオヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市浜田', '05', '05201', '0101654', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '浜田', 'ハマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区富士見', '13', '13101', '1020071', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '富士見', 'フジミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区飯田橋', '13', '13101', '1020072', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '飯田橋', 'イイダバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区九段北', '13', '13101', '1020073', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '九段北', 'クダンキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区九段南', '13', '13101', '1020074', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '九段南', 'クダンミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区三番町', '13', '13101', '1020075', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '三番町', 'サンバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区五番町', '13', '13101', '1020076', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '五番町', 'ゴバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区四番町', '13', '13101', '1020081', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '四番町', 'ヨンバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区一番町', '13', '13101', '1020082', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '一番町', 'イチバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区麹町', '13', '13101', '1020083', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '麹町', 'コウジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区二番町', '13', '13101', '1020084', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '二番町', 'ニバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区六番町', '13', '13101', '1020085', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '六番町', 'ロクバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区北の丸公園', '13', '13101', '1020091', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '北の丸公園', 'キタノマルコウエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区隼町', '13', '13101', '1020092', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '隼町', 'ハヤブサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区平河町', '13', '13101', '1020093', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '平河町', 'ヒラカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都千代田区紀尾井町', '13', '13101', '1020094', '東京都', 'トウキョウト', '千代田区', 'チヨダク', '紀尾井町', 'キオイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区', '13', '13102', '1030000', '東京都', 'トウキョウト', '中央区', 'チュウオウク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('1573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区日本橋小伝馬町', '13', '13102', '1030001', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '日本橋小伝馬町', 'ニホンバシコデンマチョウ', null, null, null, null), ('1574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区日本橋馬喰町', '13', '13102', '1030002', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '日本橋馬喰町', 'ニホンバシバクロチョウ', null, null, null, null), ('1575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区日本橋横山町', '13', '13102', '1030003', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '日本橋横山町', 'ニホンバシヨコヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区東日本橋', '13', '13102', '1030004', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '東日本橋', 'ヒガシニホンバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区日本橋久松町', '13', '13102', '1030005', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '日本橋久松町', 'ニホンバシヒサマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区日本橋富沢町', '13', '13102', '1030006', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '日本橋富沢町', 'ニホンバシトミザワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区日本橋浜町', '13', '13102', '1030007', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '日本橋浜町', 'ニホンバシハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区日本橋中洲', '13', '13102', '1030008', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '日本橋中洲', 'ニホンバシナカス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区日本橋大伝馬町', '13', '13102', '1030011', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '日本橋大伝馬町', 'ニホンバシオオデンマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区日本橋堀留町', '13', '13102', '1030012', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '日本橋堀留町', 'ニホンバシホリドメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区日本橋人形町', '13', '13102', '1030013', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '日本橋人形町', 'ニホンバシニンギョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区日本橋蛎殻町', '13', '13102', '1030014', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '日本橋蛎殻町', 'ニホンバシカキガラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区日本橋箱崎町', '13', '13102', '1030015', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '日本橋箱崎町', 'ニホンバシハコザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区日本橋小網町', '13', '13102', '1030016', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '日本橋小網町', 'ニホンバシコアミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区日本橋本石町', '13', '13102', '1030021', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '日本橋本石町', 'ニホンバシホンゴクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区日本橋室町', '13', '13102', '1030022', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '日本橋室町', 'ニホンバシムロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区日本橋本町', '13', '13102', '1030023', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '日本橋本町', 'ニホンバシホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区日本橋小舟町', '13', '13102', '1030024', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '日本橋小舟町', 'ニホンバシコブナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区日本橋茅場町', '13', '13102', '1030025', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '日本橋茅場町', 'ニホンバシカヤバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区日本橋兜町', '13', '13102', '1030026', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '日本橋兜町', 'ニホンバシカブトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区日本橋', '13', '13102', '1030027', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '日本橋', 'ニホンバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区八重洲1丁目', '13', '13102', '1030028', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '八重洲', 'ヤエス', null, null, '1丁目', '01チョウメ');
INSERT INTO `ms_addresses` VALUES ('1810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区八重洲2丁目', '13', '13102', '1040028', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '八重洲', 'ヤエス', null, null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('1811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区京橋', '13', '13102', '1040031', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '京橋', 'キョウバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区八丁堀', '13', '13102', '1040032', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '八丁堀', 'ハッチョウボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区新川', '13', '13102', '1040033', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '新川', 'シンカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区新富', '13', '13102', '1040041', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '新富', 'シントミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区入船', '13', '13102', '1040042', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '入船', 'イリフネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区湊', '13', '13102', '1040043', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '湊', 'ミナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区明石町', '13', '13102', '1040044', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '明石町', 'アカシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区築地', '13', '13102', '1040045', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '築地', 'ツキジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区浜離宮庭園', '13', '13102', '1040046', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '浜離宮庭園', 'ハマリキュウテイエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区佃', '13', '13102', '1040051', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '佃', 'ツクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区月島', '13', '13102', '1040052', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '月島', 'ツキシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海', '13', '13102', '1040053', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区勝どき', '13', '13102', '1040054', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '勝どき', 'カチドキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区豊海町', '13', '13102', '1040055', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '豊海町', 'トヨミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区銀座', '13', '13102', '1040061', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '銀座', 'ギンザ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('1826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーX　1階', '13', '13102', '1046001', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーX　1階', 'オフィスタワーX　01カイ');
INSERT INTO `ms_addresses` VALUES ('1827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーX　2階', '13', '13102', '1046002', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーX　2階', 'オフィスタワーX　02カイ');
INSERT INTO `ms_addresses` VALUES ('1828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーX　3階', '13', '13102', '1046003', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーX　3階', 'オフィスタワーX　03カイ');
INSERT INTO `ms_addresses` VALUES ('1829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーX　4階', '13', '13102', '1046004', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーX　4階', 'オフィスタワーX　04カイ');
INSERT INTO `ms_addresses` VALUES ('1830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーX　5階', '13', '13102', '1046005', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーX　5階', 'オフィスタワーX　05カイ');
INSERT INTO `ms_addresses` VALUES ('1831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーX　6階', '13', '13102', '1046006', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーX　6階', 'オフィスタワーX　06カイ');
INSERT INTO `ms_addresses` VALUES ('1832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーX　7階', '13', '13102', '1046007', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーX　7階', 'オフィスタワーX　07カイ');
INSERT INTO `ms_addresses` VALUES ('1833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーX　8階', '13', '13102', '1046008', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーX　8階', 'オフィスタワーX　08カイ');
INSERT INTO `ms_addresses` VALUES ('1834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーX　9階', '13', '13102', '1046009', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーX　9階', 'オフィスタワーX　09カイ');
INSERT INTO `ms_addresses` VALUES ('1835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーX　10階', '13', '13102', '1046010', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーX　10階', 'オフィスタワーX　10カイ');
INSERT INTO `ms_addresses` VALUES ('1836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーX　11階', '13', '13102', '1046011', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーX　11階', 'オフィスタワーX　11カイ');
INSERT INTO `ms_addresses` VALUES ('1837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーX　12階', '13', '13102', '1046012', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーX　12階', 'オフィスタワーX　12カイ');
INSERT INTO `ms_addresses` VALUES ('1838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーX　13階', '13', '13102', '1046013', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーX　13階', 'オフィスタワーX　13カイ');
INSERT INTO `ms_addresses` VALUES ('1839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーX　14階', '13', '13102', '1046014', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーX　14階', 'オフィスタワーX　14カイ');
INSERT INTO `ms_addresses` VALUES ('1840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーX　15階', '13', '13102', '1046015', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーX　15階', 'オフィスタワーX　15カイ');
INSERT INTO `ms_addresses` VALUES ('1841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーX　16階', '13', '13102', '1046016', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーX　16階', 'オフィスタワーX　16カイ');
INSERT INTO `ms_addresses` VALUES ('1842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーX　17階', '13', '13102', '1046017', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーX　17階', 'オフィスタワーX　17カイ');
INSERT INTO `ms_addresses` VALUES ('1843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーX　18階', '13', '13102', '1046018', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーX　18階', 'オフィスタワーX　18カイ');
INSERT INTO `ms_addresses` VALUES ('1844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーX　19階', '13', '13102', '1046019', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーX　19階', 'オフィスタワーX　19カイ');
INSERT INTO `ms_addresses` VALUES ('1845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーX　20階', '13', '13102', '1046020', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーX　20階', 'オフィスタワーX　20カイ');
INSERT INTO `ms_addresses` VALUES ('1846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーX　21階', '13', '13102', '1046021', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーX　21階', 'オフィスタワーX　21カイ');
INSERT INTO `ms_addresses` VALUES ('1847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーX　22階', '13', '13102', '1046022', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーX　22階', 'オフィスタワーX　22カイ');
INSERT INTO `ms_addresses` VALUES ('1848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーX　23階', '13', '13102', '1046023', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーX　23階', 'オフィスタワーX　23カイ');
INSERT INTO `ms_addresses` VALUES ('1849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーX　24階', '13', '13102', '1046024', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーX　24階', 'オフィスタワーX　24カイ');
INSERT INTO `ms_addresses` VALUES ('1850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーX　25階', '13', '13102', '1046025', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーX　25階', 'オフィスタワーX　25カイ');
INSERT INTO `ms_addresses` VALUES ('1851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーX　26階', '13', '13102', '1046026', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーX　26階', 'オフィスタワーX　26カイ');
INSERT INTO `ms_addresses` VALUES ('1852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーX　27階', '13', '13102', '1046027', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーX　27階', 'オフィスタワーX　27カイ');
INSERT INTO `ms_addresses` VALUES ('1853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーX　28階', '13', '13102', '1046028', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーX　28階', 'オフィスタワーX　28カイ');
INSERT INTO `ms_addresses` VALUES ('1854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーX　29階', '13', '13102', '1046029', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーX　29階', 'オフィスタワーX　29カイ');
INSERT INTO `ms_addresses` VALUES ('1855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーX　30階', '13', '13102', '1046030', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーX　30階', 'オフィスタワーX　30カイ');
INSERT INTO `ms_addresses` VALUES ('1856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーX　31階', '13', '13102', '1046031', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーX　31階', 'オフィスタワーX　31カイ');
INSERT INTO `ms_addresses` VALUES ('1857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーX　32階', '13', '13102', '1046032', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーX　32階', 'オフィスタワーX　32カイ');
INSERT INTO `ms_addresses` VALUES ('1858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーX　33階', '13', '13102', '1046033', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーX　33階', 'オフィスタワーX　33カイ');
INSERT INTO `ms_addresses` VALUES ('1859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーX　34階', '13', '13102', '1046034', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーX　34階', 'オフィスタワーX　34カイ');
INSERT INTO `ms_addresses` VALUES ('1860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーX　35階', '13', '13102', '1046035', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーX　35階', 'オフィスタワーX　35カイ');
INSERT INTO `ms_addresses` VALUES ('1861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーX　36階', '13', '13102', '1046036', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーX　36階', 'オフィスタワーX　36カイ');
INSERT INTO `ms_addresses` VALUES ('1862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーX　37階', '13', '13102', '1046037', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーX　37階', 'オフィスタワーX　37カイ');
INSERT INTO `ms_addresses` VALUES ('1863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーX　38階', '13', '13102', '1046038', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーX　38階', 'オフィスタワーX　38カイ');
INSERT INTO `ms_addresses` VALUES ('1864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーX　39階', '13', '13102', '1046039', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーX　39階', 'オフィスタワーX　39カイ');
INSERT INTO `ms_addresses` VALUES ('1865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーX　40階', '13', '13102', '1046040', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーX　40階', 'オフィスタワーX　40カイ');
INSERT INTO `ms_addresses` VALUES ('1866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーX　41階', '13', '13102', '1046041', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーX　41階', 'オフィスタワーX　41カイ');
INSERT INTO `ms_addresses` VALUES ('1867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーX　42階', '13', '13102', '1046042', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーX　42階', 'オフィスタワーX　42カイ');
INSERT INTO `ms_addresses` VALUES ('1868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーX　43階', '13', '13102', '1046043', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーX　43階', 'オフィスタワーX　43カイ');
INSERT INTO `ms_addresses` VALUES ('1869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーX　44階', '13', '13102', '1046044', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーX　44階', 'オフィスタワーX　44カイ');
INSERT INTO `ms_addresses` VALUES ('1870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーX　', '13', '13102', '1046090', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーX　', 'オフィスタワーX　');
INSERT INTO `ms_addresses` VALUES ('1871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーY　1階', '13', '13102', '1046101', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーY　1階', 'オフィスタワーY　01カイ');
INSERT INTO `ms_addresses` VALUES ('1872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーY　2階', '13', '13102', '1046102', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーY　2階', 'オフィスタワーY　02カイ');
INSERT INTO `ms_addresses` VALUES ('1873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーY　3階', '13', '13102', '1046103', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーY　3階', 'オフィスタワーY　03カイ');
INSERT INTO `ms_addresses` VALUES ('1874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーY　4階', '13', '13102', '1046104', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーY　4階', 'オフィスタワーY　04カイ');
INSERT INTO `ms_addresses` VALUES ('1875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーY　5階', '13', '13102', '1046105', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーY　5階', 'オフィスタワーY　05カイ');
INSERT INTO `ms_addresses` VALUES ('1876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーY　6階', '13', '13102', '1046106', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーY　6階', 'オフィスタワーY　06カイ');
INSERT INTO `ms_addresses` VALUES ('1877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーY　7階', '13', '13102', '1046107', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーY　7階', 'オフィスタワーY　07カイ');
INSERT INTO `ms_addresses` VALUES ('1878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーY　8階', '13', '13102', '1046108', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーY　8階', 'オフィスタワーY　08カイ');
INSERT INTO `ms_addresses` VALUES ('1879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーY　9階', '13', '13102', '1046109', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーY　9階', 'オフィスタワーY　09カイ');
INSERT INTO `ms_addresses` VALUES ('1880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーY　10階', '13', '13102', '1046110', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーY　10階', 'オフィスタワーY　10カイ');
INSERT INTO `ms_addresses` VALUES ('1881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーY　11階', '13', '13102', '1046111', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーY　11階', 'オフィスタワーY　11カイ');
INSERT INTO `ms_addresses` VALUES ('1882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーY　12階', '13', '13102', '1046112', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーY　12階', 'オフィスタワーY　12カイ');
INSERT INTO `ms_addresses` VALUES ('1883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーY　13階', '13', '13102', '1046113', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーY　13階', 'オフィスタワーY　13カイ');
INSERT INTO `ms_addresses` VALUES ('1884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーY　14階', '13', '13102', '1046114', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーY　14階', 'オフィスタワーY　14カイ');
INSERT INTO `ms_addresses` VALUES ('1885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーY　15階', '13', '13102', '1046115', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーY　15階', 'オフィスタワーY　15カイ');
INSERT INTO `ms_addresses` VALUES ('1886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーY　16階', '13', '13102', '1046116', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーY　16階', 'オフィスタワーY　16カイ');
INSERT INTO `ms_addresses` VALUES ('1887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーY　17階', '13', '13102', '1046117', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーY　17階', 'オフィスタワーY　17カイ');
INSERT INTO `ms_addresses` VALUES ('1888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーY　18階', '13', '13102', '1046118', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーY　18階', 'オフィスタワーY　18カイ');
INSERT INTO `ms_addresses` VALUES ('1889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーY　19階', '13', '13102', '1046119', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーY　19階', 'オフィスタワーY　19カイ');
INSERT INTO `ms_addresses` VALUES ('1890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーY　20階', '13', '13102', '1046120', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーY　20階', 'オフィスタワーY　20カイ');
INSERT INTO `ms_addresses` VALUES ('1891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーY　21階', '13', '13102', '1046121', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーY　21階', 'オフィスタワーY　21カイ');
INSERT INTO `ms_addresses` VALUES ('1892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーY　22階', '13', '13102', '1046122', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーY　22階', 'オフィスタワーY　22カイ');
INSERT INTO `ms_addresses` VALUES ('1893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーY　23階', '13', '13102', '1046123', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーY　23階', 'オフィスタワーY　23カイ');
INSERT INTO `ms_addresses` VALUES ('1894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーY　24階', '13', '13102', '1046124', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーY　24階', 'オフィスタワーY　24カイ');
INSERT INTO `ms_addresses` VALUES ('1895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーY　25階', '13', '13102', '1046125', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーY　25階', 'オフィスタワーY　25カイ');
INSERT INTO `ms_addresses` VALUES ('1896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーY　26階', '13', '13102', '1046126', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーY　26階', 'オフィスタワーY　26カイ');
INSERT INTO `ms_addresses` VALUES ('1897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーY　27階', '13', '13102', '1046127', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーY　27階', 'オフィスタワーY　27カイ');
INSERT INTO `ms_addresses` VALUES ('1898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーY　28階', '13', '13102', '1046128', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーY　28階', 'オフィスタワーY　28カイ');
INSERT INTO `ms_addresses` VALUES ('1899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーY　29階', '13', '13102', '1046129', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーY　29階', 'オフィスタワーY　29カイ');
INSERT INTO `ms_addresses` VALUES ('1900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーY　30階', '13', '13102', '1046130', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーY　30階', 'オフィスタワーY　30カイ');
INSERT INTO `ms_addresses` VALUES ('1901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーY　31階', '13', '13102', '1046131', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーY　31階', 'オフィスタワーY　31カイ');
INSERT INTO `ms_addresses` VALUES ('1902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーY　32階', '13', '13102', '1046132', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーY　32階', 'オフィスタワーY　32カイ');
INSERT INTO `ms_addresses` VALUES ('1903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーY　33階', '13', '13102', '1046133', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーY　33階', 'オフィスタワーY　33カイ');
INSERT INTO `ms_addresses` VALUES ('1904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーY　34階', '13', '13102', '1046134', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーY　34階', 'オフィスタワーY　34カイ');
INSERT INTO `ms_addresses` VALUES ('1905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーY　35階', '13', '13102', '1046135', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーY　35階', 'オフィスタワーY　35カイ');
INSERT INTO `ms_addresses` VALUES ('1906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーY　36階', '13', '13102', '1046136', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーY　36階', 'オフィスタワーY　36カイ');
INSERT INTO `ms_addresses` VALUES ('1907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーY　37階', '13', '13102', '1046137', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーY　37階', 'オフィスタワーY　37カイ');
INSERT INTO `ms_addresses` VALUES ('1908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーY　38階', '13', '13102', '1046138', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーY　38階', 'オフィスタワーY　38カイ');
INSERT INTO `ms_addresses` VALUES ('1909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーY　39階', '13', '13102', '1046139', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーY　39階', 'オフィスタワーY　39カイ');
INSERT INTO `ms_addresses` VALUES ('1910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーY　', '13', '13102', '1046190', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーY　', 'オフィスタワーY　');
INSERT INTO `ms_addresses` VALUES ('1911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーZ　1階', '13', '13102', '1046201', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーZ　1階', 'オフィスタワーZ　01カイ');
INSERT INTO `ms_addresses` VALUES ('1912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーZ　2階', '13', '13102', '1046202', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーZ　2階', 'オフィスタワーZ　02カイ');
INSERT INTO `ms_addresses` VALUES ('1913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーZ　3階', '13', '13102', '1046203', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーZ　3階', 'オフィスタワーZ　03カイ');
INSERT INTO `ms_addresses` VALUES ('1914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーZ　4階', '13', '13102', '1046204', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーZ　4階', 'オフィスタワーZ　04カイ');
INSERT INTO `ms_addresses` VALUES ('1915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーZ　5階', '13', '13102', '1046205', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーZ　5階', 'オフィスタワーZ　05カイ');
INSERT INTO `ms_addresses` VALUES ('1916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーZ　6階', '13', '13102', '1046206', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーZ　6階', 'オフィスタワーZ　06カイ');
INSERT INTO `ms_addresses` VALUES ('1917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーZ　7階', '13', '13102', '1046207', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーZ　7階', 'オフィスタワーZ　07カイ');
INSERT INTO `ms_addresses` VALUES ('1918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーZ　8階', '13', '13102', '1046208', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーZ　8階', 'オフィスタワーZ　08カイ');
INSERT INTO `ms_addresses` VALUES ('1919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーZ　9階', '13', '13102', '1046209', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーZ　9階', 'オフィスタワーZ　09カイ');
INSERT INTO `ms_addresses` VALUES ('1920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーZ　10階', '13', '13102', '1046210', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーZ　10階', 'オフィスタワーZ　10カイ');
INSERT INTO `ms_addresses` VALUES ('1921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーZ　11階', '13', '13102', '1046211', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーZ　11階', 'オフィスタワーZ　11カイ');
INSERT INTO `ms_addresses` VALUES ('1922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーZ　12階', '13', '13102', '1046212', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーZ　12階', 'オフィスタワーZ　12カイ');
INSERT INTO `ms_addresses` VALUES ('1923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーZ　13階', '13', '13102', '1046213', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーZ　13階', 'オフィスタワーZ　13カイ');
INSERT INTO `ms_addresses` VALUES ('1924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーZ　14階', '13', '13102', '1046214', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーZ　14階', 'オフィスタワーZ　14カイ');
INSERT INTO `ms_addresses` VALUES ('1925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーZ　15階', '13', '13102', '1046215', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーZ　15階', 'オフィスタワーZ　15カイ');
INSERT INTO `ms_addresses` VALUES ('1926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーZ　16階', '13', '13102', '1046216', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーZ　16階', 'オフィスタワーZ　16カイ');
INSERT INTO `ms_addresses` VALUES ('1927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーZ　17階', '13', '13102', '1046217', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーZ　17階', 'オフィスタワーZ　17カイ');
INSERT INTO `ms_addresses` VALUES ('1928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーZ　18階', '13', '13102', '1046218', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーZ　18階', 'オフィスタワーZ　18カイ');
INSERT INTO `ms_addresses` VALUES ('1929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーZ　19階', '13', '13102', '1046219', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーZ　19階', 'オフィスタワーZ　19カイ');
INSERT INTO `ms_addresses` VALUES ('1930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーZ　20階', '13', '13102', '1046220', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーZ　20階', 'オフィスタワーZ　20カイ');
INSERT INTO `ms_addresses` VALUES ('1931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーZ　21階', '13', '13102', '1046221', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーZ　21階', 'オフィスタワーZ　21カイ');
INSERT INTO `ms_addresses` VALUES ('1932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーZ　22階', '13', '13102', '1046222', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーZ　22階', 'オフィスタワーZ　22カイ');
INSERT INTO `ms_addresses` VALUES ('1933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーZ　23階', '13', '13102', '1046223', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーZ　23階', 'オフィスタワーZ　23カイ');
INSERT INTO `ms_addresses` VALUES ('1934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーZ　24階', '13', '13102', '1046224', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーZ　24階', 'オフィスタワーZ　24カイ');
INSERT INTO `ms_addresses` VALUES ('1935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーZ　25階', '13', '13102', '1046225', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーZ　25階', 'オフィスタワーZ　25カイ');
INSERT INTO `ms_addresses` VALUES ('1936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーZ　26階', '13', '13102', '1046226', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーZ　26階', 'オフィスタワーZ　26カイ');
INSERT INTO `ms_addresses` VALUES ('1937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーZ　27階', '13', '13102', '1046227', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーZ　27階', 'オフィスタワーZ　27カイ');
INSERT INTO `ms_addresses` VALUES ('1938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーZ　28階', '13', '13102', '1046228', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーZ　28階', 'オフィスタワーZ　28カイ');
INSERT INTO `ms_addresses` VALUES ('1939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーZ　29階', '13', '13102', '1046229', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーZ　29階', 'オフィスタワーZ　29カイ');
INSERT INTO `ms_addresses` VALUES ('1940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーZ　30階', '13', '13102', '1046230', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーZ　30階', 'オフィスタワーZ　30カイ');
INSERT INTO `ms_addresses` VALUES ('1941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーZ　31階', '13', '13102', '1046231', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーZ　31階', 'オフィスタワーZ　31カイ');
INSERT INTO `ms_addresses` VALUES ('1942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーZ　32階', '13', '13102', '1046232', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーZ　32階', 'オフィスタワーZ　32カイ');
INSERT INTO `ms_addresses` VALUES ('1943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーZ　33階', '13', '13102', '1046233', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーZ　33階', 'オフィスタワーZ　33カイ');
INSERT INTO `ms_addresses` VALUES ('1945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中央区晴海オフィスタワーZ　', '13', '13102', '1046290', '東京都', 'トウキョウト', '中央区', 'チュウオウク', '晴海', 'ハルミ', null, null, 'オフィスタワーZ　', 'オフィスタワーZ　');
INSERT INTO `ms_addresses` VALUES ('2171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区', '13', '13103', '1050000', '東京都', 'トウキョウト', '港区', 'ミナトク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('2172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区虎ノ門', '13', '13103', '1050001', '東京都', 'トウキョウト', '港区', 'ミナトク', '虎ノ門', 'トラノモン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('2173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区愛宕', '13', '13103', '1050002', '東京都', 'トウキョウト', '港区', 'ミナトク', '愛宕', 'アタゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('2174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区西新橋', '13', '13103', '1050003', '東京都', 'トウキョウト', '港区', 'ミナトク', '西新橋', 'ニシシンバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('2175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区新橋', '13', '13103', '1050004', '東京都', 'トウキョウト', '港区', 'ミナトク', '新橋', 'シンバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('2176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区芝公園', '13', '13103', '1050011', '東京都', 'トウキョウト', '港区', 'ミナトク', '芝公園', 'シバコウエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('2177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区芝大門', '13', '13103', '1050012', '東京都', 'トウキョウト', '港区', 'ミナトク', '芝大門', 'シバダイモン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('2178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区浜松町', '13', '13103', '1050013', '東京都', 'トウキョウト', '港区', 'ミナトク', '浜松町', 'ハママツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('2179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区芝1丁目', '13', '13103', '1050014', '東京都', 'トウキョウト', '港区', 'ミナトク', '芝', 'シバ', null, null, '1丁目', '01チョウメ');
INSERT INTO `ms_addresses` VALUES ('2180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区芝2丁目', '13', '13103', '1050014', '東京都', 'トウキョウト', '港区', 'ミナトク', '芝', 'シバ', null, null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('2181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区芝3丁目', '13', '13103', '1050014', '東京都', 'トウキョウト', '港区', 'ミナトク', '芝', 'シバ', null, null, '3丁目', '03チョウメ');
INSERT INTO `ms_addresses` VALUES ('2182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋', '13', '13103', '1050021', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('2183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区海岸1丁目', '13', '13103', '1050022', '東京都', 'トウキョウト', '港区', 'ミナトク', '海岸', 'カイガン', null, null, '1丁目', '01チョウメ');
INSERT INTO `ms_addresses` VALUES ('2184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区海岸2丁目', '13', '13103', '1050022', '東京都', 'トウキョウト', '港区', 'ミナトク', '海岸', 'カイガン', null, null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('2185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区芝浦1丁目', '13', '13103', '1050023', '東京都', 'トウキョウト', '港区', 'ミナトク', '芝浦', 'シバウラ', null, null, '1丁目', '01チョウメ');
INSERT INTO `ms_addresses` VALUES ('2186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区虎ノ門城山トラストタワー　1階', '13', '13103', '1056001', '東京都', 'トウキョウト', '港区', 'ミナトク', '虎ノ門', 'トラノモン', null, null, '城山トラストタワー　1階', 'シロヤマトラストタワー　01カイ');
INSERT INTO `ms_addresses` VALUES ('2187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区虎ノ門城山トラストタワー　2階', '13', '13103', '1056002', '東京都', 'トウキョウト', '港区', 'ミナトク', '虎ノ門', 'トラノモン', null, null, '城山トラストタワー　2階', 'シロヤマトラストタワー　02カイ');
INSERT INTO `ms_addresses` VALUES ('2188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区虎ノ門城山トラストタワー　3階', '13', '13103', '1056003', '東京都', 'トウキョウト', '港区', 'ミナトク', '虎ノ門', 'トラノモン', null, null, '城山トラストタワー　3階', 'シロヤマトラストタワー　03カイ');
INSERT INTO `ms_addresses` VALUES ('2189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区虎ノ門城山トラストタワー　4階', '13', '13103', '1056004', '東京都', 'トウキョウト', '港区', 'ミナトク', '虎ノ門', 'トラノモン', null, null, '城山トラストタワー　4階', 'シロヤマトラストタワー　04カイ');
INSERT INTO `ms_addresses` VALUES ('2190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区虎ノ門城山トラストタワー　5階', '13', '13103', '1056005', '東京都', 'トウキョウト', '港区', 'ミナトク', '虎ノ門', 'トラノモン', null, null, '城山トラストタワー　5階', 'シロヤマトラストタワー　05カイ');
INSERT INTO `ms_addresses` VALUES ('2191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区虎ノ門城山トラストタワー　6階', '13', '13103', '1056006', '東京都', 'トウキョウト', '港区', 'ミナトク', '虎ノ門', 'トラノモン', null, null, '城山トラストタワー　6階', 'シロヤマトラストタワー　06カイ');
INSERT INTO `ms_addresses` VALUES ('2192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区虎ノ門城山トラストタワー　7階', '13', '13103', '1056007', '東京都', 'トウキョウト', '港区', 'ミナトク', '虎ノ門', 'トラノモン', null, null, '城山トラストタワー　7階', 'シロヤマトラストタワー　07カイ');
INSERT INTO `ms_addresses` VALUES ('2193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区虎ノ門城山トラストタワー　8階', '13', '13103', '1056008', '東京都', 'トウキョウト', '港区', 'ミナトク', '虎ノ門', 'トラノモン', null, null, '城山トラストタワー　8階', 'シロヤマトラストタワー　08カイ');
INSERT INTO `ms_addresses` VALUES ('2194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区虎ノ門城山トラストタワー　9階', '13', '13103', '1056009', '東京都', 'トウキョウト', '港区', 'ミナトク', '虎ノ門', 'トラノモン', null, null, '城山トラストタワー　9階', 'シロヤマトラストタワー　09カイ');
INSERT INTO `ms_addresses` VALUES ('2195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区虎ノ門城山トラストタワー　10階', '13', '13103', '1056010', '東京都', 'トウキョウト', '港区', 'ミナトク', '虎ノ門', 'トラノモン', null, null, '城山トラストタワー　10階', 'シロヤマトラストタワー　10カイ');
INSERT INTO `ms_addresses` VALUES ('2196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区虎ノ門城山トラストタワー　11階', '13', '13103', '1056011', '東京都', 'トウキョウト', '港区', 'ミナトク', '虎ノ門', 'トラノモン', null, null, '城山トラストタワー　11階', 'シロヤマトラストタワー　11カイ');
INSERT INTO `ms_addresses` VALUES ('2197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区虎ノ門城山トラストタワー　12階', '13', '13103', '1056012', '東京都', 'トウキョウト', '港区', 'ミナトク', '虎ノ門', 'トラノモン', null, null, '城山トラストタワー　12階', 'シロヤマトラストタワー　12カイ');
INSERT INTO `ms_addresses` VALUES ('2198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区虎ノ門城山トラストタワー　13階', '13', '13103', '1056013', '東京都', 'トウキョウト', '港区', 'ミナトク', '虎ノ門', 'トラノモン', null, null, '城山トラストタワー　13階', 'シロヤマトラストタワー　13カイ');
INSERT INTO `ms_addresses` VALUES ('2199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区虎ノ門城山トラストタワー　14階', '13', '13103', '1056014', '東京都', 'トウキョウト', '港区', 'ミナトク', '虎ノ門', 'トラノモン', null, null, '城山トラストタワー　14階', 'シロヤマトラストタワー　14カイ');
INSERT INTO `ms_addresses` VALUES ('2200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区虎ノ門城山トラストタワー　15階', '13', '13103', '1056015', '東京都', 'トウキョウト', '港区', 'ミナトク', '虎ノ門', 'トラノモン', null, null, '城山トラストタワー　15階', 'シロヤマトラストタワー　15カイ');
INSERT INTO `ms_addresses` VALUES ('2201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区虎ノ門城山トラストタワー　16階', '13', '13103', '1056016', '東京都', 'トウキョウト', '港区', 'ミナトク', '虎ノ門', 'トラノモン', null, null, '城山トラストタワー　16階', 'シロヤマトラストタワー　16カイ');
INSERT INTO `ms_addresses` VALUES ('2202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区虎ノ門城山トラストタワー　17階', '13', '13103', '1056017', '東京都', 'トウキョウト', '港区', 'ミナトク', '虎ノ門', 'トラノモン', null, null, '城山トラストタワー　17階', 'シロヤマトラストタワー　17カイ');
INSERT INTO `ms_addresses` VALUES ('2203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区虎ノ門城山トラストタワー　18階', '13', '13103', '1056018', '東京都', 'トウキョウト', '港区', 'ミナトク', '虎ノ門', 'トラノモン', null, null, '城山トラストタワー　18階', 'シロヤマトラストタワー　18カイ');
INSERT INTO `ms_addresses` VALUES ('2204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区虎ノ門城山トラストタワー　19階', '13', '13103', '1056019', '東京都', 'トウキョウト', '港区', 'ミナトク', '虎ノ門', 'トラノモン', null, null, '城山トラストタワー　19階', 'シロヤマトラストタワー　19カイ');
INSERT INTO `ms_addresses` VALUES ('2205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区虎ノ門城山トラストタワー　20階', '13', '13103', '1056020', '東京都', 'トウキョウト', '港区', 'ミナトク', '虎ノ門', 'トラノモン', null, null, '城山トラストタワー　20階', 'シロヤマトラストタワー　20カイ');
INSERT INTO `ms_addresses` VALUES ('2206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区虎ノ門城山トラストタワー　21階', '13', '13103', '1056021', '東京都', 'トウキョウト', '港区', 'ミナトク', '虎ノ門', 'トラノモン', null, null, '城山トラストタワー　21階', 'シロヤマトラストタワー　21カイ');
INSERT INTO `ms_addresses` VALUES ('2207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区虎ノ門城山トラストタワー　22階', '13', '13103', '1056022', '東京都', 'トウキョウト', '港区', 'ミナトク', '虎ノ門', 'トラノモン', null, null, '城山トラストタワー　22階', 'シロヤマトラストタワー　22カイ');
INSERT INTO `ms_addresses` VALUES ('2208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区虎ノ門城山トラストタワー　23階', '13', '13103', '1056023', '東京都', 'トウキョウト', '港区', 'ミナトク', '虎ノ門', 'トラノモン', null, null, '城山トラストタワー　23階', 'シロヤマトラストタワー　23カイ');
INSERT INTO `ms_addresses` VALUES ('2209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区虎ノ門城山トラストタワー　24階', '13', '13103', '1056024', '東京都', 'トウキョウト', '港区', 'ミナトク', '虎ノ門', 'トラノモン', null, null, '城山トラストタワー　24階', 'シロヤマトラストタワー　24カイ');
INSERT INTO `ms_addresses` VALUES ('2210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区虎ノ門城山トラストタワー　25階', '13', '13103', '1056025', '東京都', 'トウキョウト', '港区', 'ミナトク', '虎ノ門', 'トラノモン', null, null, '城山トラストタワー　25階', 'シロヤマトラストタワー　25カイ');
INSERT INTO `ms_addresses` VALUES ('2211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区虎ノ門城山トラストタワー　26階', '13', '13103', '1056026', '東京都', 'トウキョウト', '港区', 'ミナトク', '虎ノ門', 'トラノモン', null, null, '城山トラストタワー　26階', 'シロヤマトラストタワー　26カイ');
INSERT INTO `ms_addresses` VALUES ('2212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区虎ノ門城山トラストタワー　27階', '13', '13103', '1056027', '東京都', 'トウキョウト', '港区', 'ミナトク', '虎ノ門', 'トラノモン', null, null, '城山トラストタワー　27階', 'シロヤマトラストタワー　27カイ');
INSERT INTO `ms_addresses` VALUES ('2213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区虎ノ門城山トラストタワー　28階', '13', '13103', '1056028', '東京都', 'トウキョウト', '港区', 'ミナトク', '虎ノ門', 'トラノモン', null, null, '城山トラストタワー　28階', 'シロヤマトラストタワー　28カイ');
INSERT INTO `ms_addresses` VALUES ('2214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区虎ノ門城山トラストタワー　29階', '13', '13103', '1056029', '東京都', 'トウキョウト', '港区', 'ミナトク', '虎ノ門', 'トラノモン', null, null, '城山トラストタワー　29階', 'シロヤマトラストタワー　29カイ');
INSERT INTO `ms_addresses` VALUES ('2215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区虎ノ門城山トラストタワー　30階', '13', '13103', '1056030', '東京都', 'トウキョウト', '港区', 'ミナトク', '虎ノ門', 'トラノモン', null, null, '城山トラストタワー　30階', 'シロヤマトラストタワー　30カイ');
INSERT INTO `ms_addresses` VALUES ('2216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区虎ノ門城山トラストタワー　31階', '13', '13103', '1056031', '東京都', 'トウキョウト', '港区', 'ミナトク', '虎ノ門', 'トラノモン', null, null, '城山トラストタワー　31階', 'シロヤマトラストタワー　31カイ');
INSERT INTO `ms_addresses` VALUES ('2217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区虎ノ門城山トラストタワー　32階', '13', '13103', '1056032', '東京都', 'トウキョウト', '港区', 'ミナトク', '虎ノ門', 'トラノモン', null, null, '城山トラストタワー　32階', 'シロヤマトラストタワー　32カイ');
INSERT INTO `ms_addresses` VALUES ('2218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区虎ノ門城山トラストタワー　33階', '13', '13103', '1056033', '東京都', 'トウキョウト', '港区', 'ミナトク', '虎ノ門', 'トラノモン', null, null, '城山トラストタワー　33階', 'シロヤマトラストタワー　33カイ');
INSERT INTO `ms_addresses` VALUES ('2219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区虎ノ門城山トラストタワー　34階', '13', '13103', '1056034', '東京都', 'トウキョウト', '港区', 'ミナトク', '虎ノ門', 'トラノモン', null, null, '城山トラストタワー　34階', 'シロヤマトラストタワー　34カイ');
INSERT INTO `ms_addresses` VALUES ('2220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区虎ノ門城山トラストタワー　35階', '13', '13103', '1056035', '東京都', 'トウキョウト', '港区', 'ミナトク', '虎ノ門', 'トラノモン', null, null, '城山トラストタワー　35階', 'シロヤマトラストタワー　35カイ');
INSERT INTO `ms_addresses` VALUES ('2221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区虎ノ門城山トラストタワー　36階', '13', '13103', '1056036', '東京都', 'トウキョウト', '港区', 'ミナトク', '虎ノ門', 'トラノモン', null, null, '城山トラストタワー　36階', 'シロヤマトラストタワー　36カイ');
INSERT INTO `ms_addresses` VALUES ('2222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区虎ノ門城山トラストタワー　37階', '13', '13103', '1056037', '東京都', 'トウキョウト', '港区', 'ミナトク', '虎ノ門', 'トラノモン', null, null, '城山トラストタワー　37階', 'シロヤマトラストタワー　37カイ');
INSERT INTO `ms_addresses` VALUES ('2223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区虎ノ門城山トラストタワー　', '13', '13103', '1056090', '東京都', 'トウキョウト', '港区', 'ミナトク', '虎ノ門', 'トラノモン', null, null, '城山トラストタワー　', 'シロヤマトラストタワー　');
INSERT INTO `ms_addresses` VALUES ('2224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区浜松町世界貿易センタービル　1階', '13', '13103', '1056101', '東京都', 'トウキョウト', '港区', 'ミナトク', '浜松町', 'ハママツチョウ', null, null, '世界貿易センタービル　1階', 'セカイボウエキセンタービル　01カイ');
INSERT INTO `ms_addresses` VALUES ('2225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区浜松町世界貿易センタービル　2階', '13', '13103', '1056102', '東京都', 'トウキョウト', '港区', 'ミナトク', '浜松町', 'ハママツチョウ', null, null, '世界貿易センタービル　2階', 'セカイボウエキセンタービル　02カイ');
INSERT INTO `ms_addresses` VALUES ('2226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区浜松町世界貿易センタービル　3階', '13', '13103', '1056103', '東京都', 'トウキョウト', '港区', 'ミナトク', '浜松町', 'ハママツチョウ', null, null, '世界貿易センタービル　3階', 'セカイボウエキセンタービル　03カイ');
INSERT INTO `ms_addresses` VALUES ('2227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区浜松町世界貿易センタービル　4階', '13', '13103', '1056104', '東京都', 'トウキョウト', '港区', 'ミナトク', '浜松町', 'ハママツチョウ', null, null, '世界貿易センタービル　4階', 'セカイボウエキセンタービル　04カイ');
INSERT INTO `ms_addresses` VALUES ('2228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区浜松町世界貿易センタービル　5階', '13', '13103', '1056105', '東京都', 'トウキョウト', '港区', 'ミナトク', '浜松町', 'ハママツチョウ', null, null, '世界貿易センタービル　5階', 'セカイボウエキセンタービル　05カイ');
INSERT INTO `ms_addresses` VALUES ('2229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区浜松町世界貿易センタービル　6階', '13', '13103', '1056106', '東京都', 'トウキョウト', '港区', 'ミナトク', '浜松町', 'ハママツチョウ', null, null, '世界貿易センタービル　6階', 'セカイボウエキセンタービル　06カイ');
INSERT INTO `ms_addresses` VALUES ('2230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区浜松町世界貿易センタービル　7階', '13', '13103', '1056107', '東京都', 'トウキョウト', '港区', 'ミナトク', '浜松町', 'ハママツチョウ', null, null, '世界貿易センタービル　7階', 'セカイボウエキセンタービル　07カイ');
INSERT INTO `ms_addresses` VALUES ('2231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区浜松町世界貿易センタービル　8階', '13', '13103', '1056108', '東京都', 'トウキョウト', '港区', 'ミナトク', '浜松町', 'ハママツチョウ', null, null, '世界貿易センタービル　8階', 'セカイボウエキセンタービル　08カイ');
INSERT INTO `ms_addresses` VALUES ('2232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区浜松町世界貿易センタービル　9階', '13', '13103', '1056109', '東京都', 'トウキョウト', '港区', 'ミナトク', '浜松町', 'ハママツチョウ', null, null, '世界貿易センタービル　9階', 'セカイボウエキセンタービル　09カイ');
INSERT INTO `ms_addresses` VALUES ('2233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区浜松町世界貿易センタービル　10階', '13', '13103', '1056110', '東京都', 'トウキョウト', '港区', 'ミナトク', '浜松町', 'ハママツチョウ', null, null, '世界貿易センタービル　10階', 'セカイボウエキセンタービル　10カイ');
INSERT INTO `ms_addresses` VALUES ('2234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区浜松町世界貿易センタービル　11階', '13', '13103', '1056111', '東京都', 'トウキョウト', '港区', 'ミナトク', '浜松町', 'ハママツチョウ', null, null, '世界貿易センタービル　11階', 'セカイボウエキセンタービル　11カイ');
INSERT INTO `ms_addresses` VALUES ('2235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区浜松町世界貿易センタービル　12階', '13', '13103', '1056112', '東京都', 'トウキョウト', '港区', 'ミナトク', '浜松町', 'ハママツチョウ', null, null, '世界貿易センタービル　12階', 'セカイボウエキセンタービル　12カイ');
INSERT INTO `ms_addresses` VALUES ('2236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区浜松町世界貿易センタービル　13階', '13', '13103', '1056113', '東京都', 'トウキョウト', '港区', 'ミナトク', '浜松町', 'ハママツチョウ', null, null, '世界貿易センタービル　13階', 'セカイボウエキセンタービル　13カイ');
INSERT INTO `ms_addresses` VALUES ('2237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区浜松町世界貿易センタービル　14階', '13', '13103', '1056114', '東京都', 'トウキョウト', '港区', 'ミナトク', '浜松町', 'ハママツチョウ', null, null, '世界貿易センタービル　14階', 'セカイボウエキセンタービル　14カイ');
INSERT INTO `ms_addresses` VALUES ('2238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区浜松町世界貿易センタービル　15階', '13', '13103', '1056115', '東京都', 'トウキョウト', '港区', 'ミナトク', '浜松町', 'ハママツチョウ', null, null, '世界貿易センタービル　15階', 'セカイボウエキセンタービル　15カイ');
INSERT INTO `ms_addresses` VALUES ('2239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区浜松町世界貿易センタービル　16階', '13', '13103', '1056116', '東京都', 'トウキョウト', '港区', 'ミナトク', '浜松町', 'ハママツチョウ', null, null, '世界貿易センタービル　16階', 'セカイボウエキセンタービル　16カイ');
INSERT INTO `ms_addresses` VALUES ('2240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区浜松町世界貿易センタービル　17階', '13', '13103', '1056117', '東京都', 'トウキョウト', '港区', 'ミナトク', '浜松町', 'ハママツチョウ', null, null, '世界貿易センタービル　17階', 'セカイボウエキセンタービル　17カイ');
INSERT INTO `ms_addresses` VALUES ('2241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区浜松町世界貿易センタービル　18階', '13', '13103', '1056118', '東京都', 'トウキョウト', '港区', 'ミナトク', '浜松町', 'ハママツチョウ', null, null, '世界貿易センタービル　18階', 'セカイボウエキセンタービル　18カイ');
INSERT INTO `ms_addresses` VALUES ('2242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区浜松町世界貿易センタービル　19階', '13', '13103', '1056119', '東京都', 'トウキョウト', '港区', 'ミナトク', '浜松町', 'ハママツチョウ', null, null, '世界貿易センタービル　19階', 'セカイボウエキセンタービル　19カイ');
INSERT INTO `ms_addresses` VALUES ('2243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区浜松町世界貿易センタービル　20階', '13', '13103', '1056120', '東京都', 'トウキョウト', '港区', 'ミナトク', '浜松町', 'ハママツチョウ', null, null, '世界貿易センタービル　20階', 'セカイボウエキセンタービル　20カイ');
INSERT INTO `ms_addresses` VALUES ('2244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区浜松町世界貿易センタービル　21階', '13', '13103', '1056121', '東京都', 'トウキョウト', '港区', 'ミナトク', '浜松町', 'ハママツチョウ', null, null, '世界貿易センタービル　21階', 'セカイボウエキセンタービル　21カイ');
INSERT INTO `ms_addresses` VALUES ('2245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区浜松町世界貿易センタービル　22階', '13', '13103', '1056122', '東京都', 'トウキョウト', '港区', 'ミナトク', '浜松町', 'ハママツチョウ', null, null, '世界貿易センタービル　22階', 'セカイボウエキセンタービル　22カイ');
INSERT INTO `ms_addresses` VALUES ('2246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区浜松町世界貿易センタービル　23階', '13', '13103', '1056123', '東京都', 'トウキョウト', '港区', 'ミナトク', '浜松町', 'ハママツチョウ', null, null, '世界貿易センタービル　23階', 'セカイボウエキセンタービル　23カイ');
INSERT INTO `ms_addresses` VALUES ('2247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区浜松町世界貿易センタービル　24階', '13', '13103', '1056124', '東京都', 'トウキョウト', '港区', 'ミナトク', '浜松町', 'ハママツチョウ', null, null, '世界貿易センタービル　24階', 'セカイボウエキセンタービル　24カイ');
INSERT INTO `ms_addresses` VALUES ('2248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区浜松町世界貿易センタービル　25階', '13', '13103', '1056125', '東京都', 'トウキョウト', '港区', 'ミナトク', '浜松町', 'ハママツチョウ', null, null, '世界貿易センタービル　25階', 'セカイボウエキセンタービル　25カイ');
INSERT INTO `ms_addresses` VALUES ('2249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区浜松町世界貿易センタービル　26階', '13', '13103', '1056126', '東京都', 'トウキョウト', '港区', 'ミナトク', '浜松町', 'ハママツチョウ', null, null, '世界貿易センタービル　26階', 'セカイボウエキセンタービル　26カイ');
INSERT INTO `ms_addresses` VALUES ('2250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区浜松町世界貿易センタービル　27階', '13', '13103', '1056127', '東京都', 'トウキョウト', '港区', 'ミナトク', '浜松町', 'ハママツチョウ', null, null, '世界貿易センタービル　27階', 'セカイボウエキセンタービル　27カイ');
INSERT INTO `ms_addresses` VALUES ('2251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区浜松町世界貿易センタービル　28階', '13', '13103', '1056128', '東京都', 'トウキョウト', '港区', 'ミナトク', '浜松町', 'ハママツチョウ', null, null, '世界貿易センタービル　28階', 'セカイボウエキセンタービル　28カイ');
INSERT INTO `ms_addresses` VALUES ('2252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区浜松町世界貿易センタービル　29階', '13', '13103', '1056129', '東京都', 'トウキョウト', '港区', 'ミナトク', '浜松町', 'ハママツチョウ', null, null, '世界貿易センタービル　29階', 'セカイボウエキセンタービル　29カイ');
INSERT INTO `ms_addresses` VALUES ('2253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区浜松町世界貿易センタービル　30階', '13', '13103', '1056130', '東京都', 'トウキョウト', '港区', 'ミナトク', '浜松町', 'ハママツチョウ', null, null, '世界貿易センタービル　30階', 'セカイボウエキセンタービル　30カイ');
INSERT INTO `ms_addresses` VALUES ('2254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区浜松町世界貿易センタービル　31階', '13', '13103', '1056131', '東京都', 'トウキョウト', '港区', 'ミナトク', '浜松町', 'ハママツチョウ', null, null, '世界貿易センタービル　31階', 'セカイボウエキセンタービル　31カイ');
INSERT INTO `ms_addresses` VALUES ('2255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区浜松町世界貿易センタービル　32階', '13', '13103', '1056132', '東京都', 'トウキョウト', '港区', 'ミナトク', '浜松町', 'ハママツチョウ', null, null, '世界貿易センタービル　32階', 'セカイボウエキセンタービル　32カイ');
INSERT INTO `ms_addresses` VALUES ('2256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区浜松町世界貿易センタービル　33階', '13', '13103', '1056133', '東京都', 'トウキョウト', '港区', 'ミナトク', '浜松町', 'ハママツチョウ', null, null, '世界貿易センタービル　33階', 'セカイボウエキセンタービル　33カイ');
INSERT INTO `ms_addresses` VALUES ('2257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区浜松町世界貿易センタービル　34階', '13', '13103', '1056134', '東京都', 'トウキョウト', '港区', 'ミナトク', '浜松町', 'ハママツチョウ', null, null, '世界貿易センタービル　34階', 'セカイボウエキセンタービル　34カイ');
INSERT INTO `ms_addresses` VALUES ('2258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区浜松町世界貿易センタービル　35階', '13', '13103', '1056135', '東京都', 'トウキョウト', '港区', 'ミナトク', '浜松町', 'ハママツチョウ', null, null, '世界貿易センタービル　35階', 'セカイボウエキセンタービル　35カイ');
INSERT INTO `ms_addresses` VALUES ('2259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区浜松町世界貿易センタービル　36階', '13', '13103', '1056136', '東京都', 'トウキョウト', '港区', 'ミナトク', '浜松町', 'ハママツチョウ', null, null, '世界貿易センタービル　36階', 'セカイボウエキセンタービル　36カイ');
INSERT INTO `ms_addresses` VALUES ('2260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区浜松町世界貿易センタービル　37階', '13', '13103', '1056137', '東京都', 'トウキョウト', '港区', 'ミナトク', '浜松町', 'ハママツチョウ', null, null, '世界貿易センタービル　37階', 'セカイボウエキセンタービル　37カイ');
INSERT INTO `ms_addresses` VALUES ('2261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区浜松町世界貿易センタービル　38階', '13', '13103', '1056138', '東京都', 'トウキョウト', '港区', 'ミナトク', '浜松町', 'ハママツチョウ', null, null, '世界貿易センタービル　38階', 'セカイボウエキセンタービル　38カイ');
INSERT INTO `ms_addresses` VALUES ('2262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区浜松町世界貿易センタービル　39階', '13', '13103', '1056139', '東京都', 'トウキョウト', '港区', 'ミナトク', '浜松町', 'ハママツチョウ', null, null, '世界貿易センタービル　39階', 'セカイボウエキセンタービル　39カイ');
INSERT INTO `ms_addresses` VALUES ('2263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区浜松町世界貿易センタービル　40階', '13', '13103', '1056140', '東京都', 'トウキョウト', '港区', 'ミナトク', '浜松町', 'ハママツチョウ', null, null, '世界貿易センタービル　40階', 'セカイボウエキセンタービル　40カイ');
INSERT INTO `ms_addresses` VALUES ('2264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区浜松町世界貿易センタービル　', '13', '13103', '1056190', '東京都', 'トウキョウト', '港区', 'ミナトク', '浜松町', 'ハママツチョウ', null, null, '世界貿易センタービル　', 'セカイボウエキセンタービル　');
INSERT INTO `ms_addresses` VALUES ('2265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区愛宕愛宕グリーンヒルズMORIタワー　1階', '13', '13103', '1056201', '東京都', 'トウキョウト', '港区', 'ミナトク', '愛宕', 'アタゴ', null, null, '愛宕グリーンヒルズMORIタワー　1階', 'アタゴグリーンヒルズモリタワー　01カイ');
INSERT INTO `ms_addresses` VALUES ('2266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区愛宕愛宕グリーンヒルズMORIタワー　2階', '13', '13103', '1056202', '東京都', 'トウキョウト', '港区', 'ミナトク', '愛宕', 'アタゴ', null, null, '愛宕グリーンヒルズMORIタワー　2階', 'アタゴグリーンヒルズモリタワー　02カイ');
INSERT INTO `ms_addresses` VALUES ('2267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区愛宕愛宕グリーンヒルズMORIタワー　3階', '13', '13103', '1056203', '東京都', 'トウキョウト', '港区', 'ミナトク', '愛宕', 'アタゴ', null, null, '愛宕グリーンヒルズMORIタワー　3階', 'アタゴグリーンヒルズモリタワー　03カイ');
INSERT INTO `ms_addresses` VALUES ('2268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区愛宕愛宕グリーンヒルズMORIタワー　4階', '13', '13103', '1056204', '東京都', 'トウキョウト', '港区', 'ミナトク', '愛宕', 'アタゴ', null, null, '愛宕グリーンヒルズMORIタワー　4階', 'アタゴグリーンヒルズモリタワー　04カイ');
INSERT INTO `ms_addresses` VALUES ('2269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区愛宕愛宕グリーンヒルズMORIタワー　5階', '13', '13103', '1056205', '東京都', 'トウキョウト', '港区', 'ミナトク', '愛宕', 'アタゴ', null, null, '愛宕グリーンヒルズMORIタワー　5階', 'アタゴグリーンヒルズモリタワー　05カイ');
INSERT INTO `ms_addresses` VALUES ('2270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区愛宕愛宕グリーンヒルズMORIタワー　6階', '13', '13103', '1056206', '東京都', 'トウキョウト', '港区', 'ミナトク', '愛宕', 'アタゴ', null, null, '愛宕グリーンヒルズMORIタワー　6階', 'アタゴグリーンヒルズモリタワー　06カイ');
INSERT INTO `ms_addresses` VALUES ('2271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区愛宕愛宕グリーンヒルズMORIタワー　7階', '13', '13103', '1056207', '東京都', 'トウキョウト', '港区', 'ミナトク', '愛宕', 'アタゴ', null, null, '愛宕グリーンヒルズMORIタワー　7階', 'アタゴグリーンヒルズモリタワー　07カイ');
INSERT INTO `ms_addresses` VALUES ('2272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区愛宕愛宕グリーンヒルズMORIタワー　8階', '13', '13103', '1056208', '東京都', 'トウキョウト', '港区', 'ミナトク', '愛宕', 'アタゴ', null, null, '愛宕グリーンヒルズMORIタワー　8階', 'アタゴグリーンヒルズモリタワー　08カイ');
INSERT INTO `ms_addresses` VALUES ('2273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区愛宕愛宕グリーンヒルズMORIタワー　9階', '13', '13103', '1056209', '東京都', 'トウキョウト', '港区', 'ミナトク', '愛宕', 'アタゴ', null, null, '愛宕グリーンヒルズMORIタワー　9階', 'アタゴグリーンヒルズモリタワー　09カイ');
INSERT INTO `ms_addresses` VALUES ('2274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区愛宕愛宕グリーンヒルズMORIタワー　10階', '13', '13103', '1056210', '東京都', 'トウキョウト', '港区', 'ミナトク', '愛宕', 'アタゴ', null, null, '愛宕グリーンヒルズMORIタワー　10階', 'アタゴグリーンヒルズモリタワー　10カイ');
INSERT INTO `ms_addresses` VALUES ('2275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区愛宕愛宕グリーンヒルズMORIタワー　11階', '13', '13103', '1056211', '東京都', 'トウキョウト', '港区', 'ミナトク', '愛宕', 'アタゴ', null, null, '愛宕グリーンヒルズMORIタワー　11階', 'アタゴグリーンヒルズモリタワー　11カイ');
INSERT INTO `ms_addresses` VALUES ('2276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区愛宕愛宕グリーンヒルズMORIタワー　12階', '13', '13103', '1056212', '東京都', 'トウキョウト', '港区', 'ミナトク', '愛宕', 'アタゴ', null, null, '愛宕グリーンヒルズMORIタワー　12階', 'アタゴグリーンヒルズモリタワー　12カイ');
INSERT INTO `ms_addresses` VALUES ('2277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区愛宕愛宕グリーンヒルズMORIタワー　13階', '13', '13103', '1056213', '東京都', 'トウキョウト', '港区', 'ミナトク', '愛宕', 'アタゴ', null, null, '愛宕グリーンヒルズMORIタワー　13階', 'アタゴグリーンヒルズモリタワー　13カイ');
INSERT INTO `ms_addresses` VALUES ('2278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区愛宕愛宕グリーンヒルズMORIタワー　14階', '13', '13103', '1056214', '東京都', 'トウキョウト', '港区', 'ミナトク', '愛宕', 'アタゴ', null, null, '愛宕グリーンヒルズMORIタワー　14階', 'アタゴグリーンヒルズモリタワー　14カイ');
INSERT INTO `ms_addresses` VALUES ('2279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区愛宕愛宕グリーンヒルズMORIタワー　15階', '13', '13103', '1056215', '東京都', 'トウキョウト', '港区', 'ミナトク', '愛宕', 'アタゴ', null, null, '愛宕グリーンヒルズMORIタワー　15階', 'アタゴグリーンヒルズモリタワー　15カイ');
INSERT INTO `ms_addresses` VALUES ('2280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区愛宕愛宕グリーンヒルズMORIタワー　16階', '13', '13103', '1056216', '東京都', 'トウキョウト', '港区', 'ミナトク', '愛宕', 'アタゴ', null, null, '愛宕グリーンヒルズMORIタワー　16階', 'アタゴグリーンヒルズモリタワー　16カイ');
INSERT INTO `ms_addresses` VALUES ('2281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区愛宕愛宕グリーンヒルズMORIタワー　17階', '13', '13103', '1056217', '東京都', 'トウキョウト', '港区', 'ミナトク', '愛宕', 'アタゴ', null, null, '愛宕グリーンヒルズMORIタワー　17階', 'アタゴグリーンヒルズモリタワー　17カイ');
INSERT INTO `ms_addresses` VALUES ('2282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区愛宕愛宕グリーンヒルズMORIタワー　18階', '13', '13103', '1056218', '東京都', 'トウキョウト', '港区', 'ミナトク', '愛宕', 'アタゴ', null, null, '愛宕グリーンヒルズMORIタワー　18階', 'アタゴグリーンヒルズモリタワー　18カイ');
INSERT INTO `ms_addresses` VALUES ('2283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区愛宕愛宕グリーンヒルズMORIタワー　19階', '13', '13103', '1056219', '東京都', 'トウキョウト', '港区', 'ミナトク', '愛宕', 'アタゴ', null, null, '愛宕グリーンヒルズMORIタワー　19階', 'アタゴグリーンヒルズモリタワー　19カイ');
INSERT INTO `ms_addresses` VALUES ('2284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区愛宕愛宕グリーンヒルズMORIタワー　20階', '13', '13103', '1056220', '東京都', 'トウキョウト', '港区', 'ミナトク', '愛宕', 'アタゴ', null, null, '愛宕グリーンヒルズMORIタワー　20階', 'アタゴグリーンヒルズモリタワー　20カイ');
INSERT INTO `ms_addresses` VALUES ('2285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区愛宕愛宕グリーンヒルズMORIタワー　21階', '13', '13103', '1056221', '東京都', 'トウキョウト', '港区', 'ミナトク', '愛宕', 'アタゴ', null, null, '愛宕グリーンヒルズMORIタワー　21階', 'アタゴグリーンヒルズモリタワー　21カイ');
INSERT INTO `ms_addresses` VALUES ('2286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区愛宕愛宕グリーンヒルズMORIタワー　22階', '13', '13103', '1056222', '東京都', 'トウキョウト', '港区', 'ミナトク', '愛宕', 'アタゴ', null, null, '愛宕グリーンヒルズMORIタワー　22階', 'アタゴグリーンヒルズモリタワー　22カイ');
INSERT INTO `ms_addresses` VALUES ('2287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区愛宕愛宕グリーンヒルズMORIタワー　23階', '13', '13103', '1056223', '東京都', 'トウキョウト', '港区', 'ミナトク', '愛宕', 'アタゴ', null, null, '愛宕グリーンヒルズMORIタワー　23階', 'アタゴグリーンヒルズモリタワー　23カイ');
INSERT INTO `ms_addresses` VALUES ('2288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区愛宕愛宕グリーンヒルズMORIタワー　24階', '13', '13103', '1056224', '東京都', 'トウキョウト', '港区', 'ミナトク', '愛宕', 'アタゴ', null, null, '愛宕グリーンヒルズMORIタワー　24階', 'アタゴグリーンヒルズモリタワー　24カイ');
INSERT INTO `ms_addresses` VALUES ('2289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区愛宕愛宕グリーンヒルズMORIタワー　25階', '13', '13103', '1056225', '東京都', 'トウキョウト', '港区', 'ミナトク', '愛宕', 'アタゴ', null, null, '愛宕グリーンヒルズMORIタワー　25階', 'アタゴグリーンヒルズモリタワー　25カイ');
INSERT INTO `ms_addresses` VALUES ('2290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区愛宕愛宕グリーンヒルズMORIタワー　26階', '13', '13103', '1056226', '東京都', 'トウキョウト', '港区', 'ミナトク', '愛宕', 'アタゴ', null, null, '愛宕グリーンヒルズMORIタワー　26階', 'アタゴグリーンヒルズモリタワー　26カイ');
INSERT INTO `ms_addresses` VALUES ('2291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区愛宕愛宕グリーンヒルズMORIタワー　27階', '13', '13103', '1056227', '東京都', 'トウキョウト', '港区', 'ミナトク', '愛宕', 'アタゴ', null, null, '愛宕グリーンヒルズMORIタワー　27階', 'アタゴグリーンヒルズモリタワー　27カイ');
INSERT INTO `ms_addresses` VALUES ('2292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区愛宕愛宕グリーンヒルズMORIタワー　28階', '13', '13103', '1056228', '東京都', 'トウキョウト', '港区', 'ミナトク', '愛宕', 'アタゴ', null, null, '愛宕グリーンヒルズMORIタワー　28階', 'アタゴグリーンヒルズモリタワー　28カイ');
INSERT INTO `ms_addresses` VALUES ('2293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区愛宕愛宕グリーンヒルズMORIタワー　29階', '13', '13103', '1056229', '東京都', 'トウキョウト', '港区', 'ミナトク', '愛宕', 'アタゴ', null, null, '愛宕グリーンヒルズMORIタワー　29階', 'アタゴグリーンヒルズモリタワー　29カイ');
INSERT INTO `ms_addresses` VALUES ('2294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区愛宕愛宕グリーンヒルズMORIタワー　30階', '13', '13103', '1056230', '東京都', 'トウキョウト', '港区', 'ミナトク', '愛宕', 'アタゴ', null, null, '愛宕グリーンヒルズMORIタワー　30階', 'アタゴグリーンヒルズモリタワー　30カイ');
INSERT INTO `ms_addresses` VALUES ('2295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区愛宕愛宕グリーンヒルズMORIタワー　31階', '13', '13103', '1056231', '東京都', 'トウキョウト', '港区', 'ミナトク', '愛宕', 'アタゴ', null, null, '愛宕グリーンヒルズMORIタワー　31階', 'アタゴグリーンヒルズモリタワー　31カイ');
INSERT INTO `ms_addresses` VALUES ('2296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区愛宕愛宕グリーンヒルズMORIタワー　32階', '13', '13103', '1056232', '東京都', 'トウキョウト', '港区', 'ミナトク', '愛宕', 'アタゴ', null, null, '愛宕グリーンヒルズMORIタワー　32階', 'アタゴグリーンヒルズモリタワー　32カイ');
INSERT INTO `ms_addresses` VALUES ('2297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区愛宕愛宕グリーンヒルズMORIタワー　33階', '13', '13103', '1056233', '東京都', 'トウキョウト', '港区', 'ミナトク', '愛宕', 'アタゴ', null, null, '愛宕グリーンヒルズMORIタワー　33階', 'アタゴグリーンヒルズモリタワー　33カイ');
INSERT INTO `ms_addresses` VALUES ('2298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区愛宕愛宕グリーンヒルズMORIタワー　34階', '13', '13103', '1056234', '東京都', 'トウキョウト', '港区', 'ミナトク', '愛宕', 'アタゴ', null, null, '愛宕グリーンヒルズMORIタワー　34階', 'アタゴグリーンヒルズモリタワー　34カイ');
INSERT INTO `ms_addresses` VALUES ('2299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区愛宕愛宕グリーンヒルズMORIタワー　35階', '13', '13103', '1056235', '東京都', 'トウキョウト', '港区', 'ミナトク', '愛宕', 'アタゴ', null, null, '愛宕グリーンヒルズMORIタワー　35階', 'アタゴグリーンヒルズモリタワー　35カイ');
INSERT INTO `ms_addresses` VALUES ('2300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区愛宕愛宕グリーンヒルズMORIタワー　36階', '13', '13103', '1056236', '東京都', 'トウキョウト', '港区', 'ミナトク', '愛宕', 'アタゴ', null, null, '愛宕グリーンヒルズMORIタワー　36階', 'アタゴグリーンヒルズモリタワー　36カイ');
INSERT INTO `ms_addresses` VALUES ('2301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区愛宕愛宕グリーンヒルズMORIタワー　37階', '13', '13103', '1056237', '東京都', 'トウキョウト', '港区', 'ミナトク', '愛宕', 'アタゴ', null, null, '愛宕グリーンヒルズMORIタワー　37階', 'アタゴグリーンヒルズモリタワー　37カイ');
INSERT INTO `ms_addresses` VALUES ('2302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区愛宕愛宕グリーンヒルズMORIタワー　38階', '13', '13103', '1056238', '東京都', 'トウキョウト', '港区', 'ミナトク', '愛宕', 'アタゴ', null, null, '愛宕グリーンヒルズMORIタワー　38階', 'アタゴグリーンヒルズモリタワー　38カイ');
INSERT INTO `ms_addresses` VALUES ('2303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区愛宕愛宕グリーンヒルズMORIタワー　39階', '13', '13103', '1056239', '東京都', 'トウキョウト', '港区', 'ミナトク', '愛宕', 'アタゴ', null, null, '愛宕グリーンヒルズMORIタワー　39階', 'アタゴグリーンヒルズモリタワー　39カイ');
INSERT INTO `ms_addresses` VALUES ('2304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区愛宕愛宕グリーンヒルズMORIタワー　40階', '13', '13103', '1056240', '東京都', 'トウキョウト', '港区', 'ミナトク', '愛宕', 'アタゴ', null, null, '愛宕グリーンヒルズMORIタワー　40階', 'アタゴグリーンヒルズモリタワー　40カイ');
INSERT INTO `ms_addresses` VALUES ('2305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区愛宕愛宕グリーンヒルズMORIタワー　41階', '13', '13103', '1056241', '東京都', 'トウキョウト', '港区', 'ミナトク', '愛宕', 'アタゴ', null, null, '愛宕グリーンヒルズMORIタワー　41階', 'アタゴグリーンヒルズモリタワー　41カイ');
INSERT INTO `ms_addresses` VALUES ('2306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区愛宕愛宕グリーンヒルズMORIタワー　42階', '13', '13103', '1056242', '東京都', 'トウキョウト', '港区', 'ミナトク', '愛宕', 'アタゴ', null, null, '愛宕グリーンヒルズMORIタワー　42階', 'アタゴグリーンヒルズモリタワー　42カイ');
INSERT INTO `ms_addresses` VALUES ('2307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区愛宕愛宕グリーンヒルズMORIタワー　', '13', '13103', '1056290', '東京都', 'トウキョウト', '港区', 'ミナトク', '愛宕', 'アタゴ', null, null, '愛宕グリーンヒルズMORIタワー　', 'アタゴグリーンヒルズモリタワー　');
INSERT INTO `ms_addresses` VALUES ('2308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋電通本社ビル　1階', '13', '13103', '1057001', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '電通本社ビル　1階', 'デンツウホンシャビル　01カイ');
INSERT INTO `ms_addresses` VALUES ('2309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋電通本社ビル　2階', '13', '13103', '1057002', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '電通本社ビル　2階', 'デンツウホンシャビル　02カイ');
INSERT INTO `ms_addresses` VALUES ('2310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋電通本社ビル　3階', '13', '13103', '1057003', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '電通本社ビル　3階', 'デンツウホンシャビル　03カイ');
INSERT INTO `ms_addresses` VALUES ('2311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋電通本社ビル　4階', '13', '13103', '1057004', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '電通本社ビル　4階', 'デンツウホンシャビル　04カイ');
INSERT INTO `ms_addresses` VALUES ('2312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋電通本社ビル　5階', '13', '13103', '1057005', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '電通本社ビル　5階', 'デンツウホンシャビル　05カイ');
INSERT INTO `ms_addresses` VALUES ('2313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋電通本社ビル　6階', '13', '13103', '1057006', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '電通本社ビル　6階', 'デンツウホンシャビル　06カイ');
INSERT INTO `ms_addresses` VALUES ('2314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋電通本社ビル　7階', '13', '13103', '1057007', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '電通本社ビル　7階', 'デンツウホンシャビル　07カイ');
INSERT INTO `ms_addresses` VALUES ('2315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋電通本社ビル　8階', '13', '13103', '1057008', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '電通本社ビル　8階', 'デンツウホンシャビル　08カイ');
INSERT INTO `ms_addresses` VALUES ('2316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋電通本社ビル　9階', '13', '13103', '1057009', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '電通本社ビル　9階', 'デンツウホンシャビル　09カイ');
INSERT INTO `ms_addresses` VALUES ('2317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋電通本社ビル　10階', '13', '13103', '1057010', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '電通本社ビル　10階', 'デンツウホンシャビル　10カイ');
INSERT INTO `ms_addresses` VALUES ('2318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋電通本社ビル　11階', '13', '13103', '1057011', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '電通本社ビル　11階', 'デンツウホンシャビル　11カイ');
INSERT INTO `ms_addresses` VALUES ('2319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋電通本社ビル　12階', '13', '13103', '1057012', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '電通本社ビル　12階', 'デンツウホンシャビル　12カイ');
INSERT INTO `ms_addresses` VALUES ('2320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋電通本社ビル　13階', '13', '13103', '1057013', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '電通本社ビル　13階', 'デンツウホンシャビル　13カイ');
INSERT INTO `ms_addresses` VALUES ('2321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋電通本社ビル　14階', '13', '13103', '1057014', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '電通本社ビル　14階', 'デンツウホンシャビル　14カイ');
INSERT INTO `ms_addresses` VALUES ('2322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋電通本社ビル　15階', '13', '13103', '1057015', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '電通本社ビル　15階', 'デンツウホンシャビル　15カイ');
INSERT INTO `ms_addresses` VALUES ('2323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋電通本社ビル　16階', '13', '13103', '1057016', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '電通本社ビル　16階', 'デンツウホンシャビル　16カイ');
INSERT INTO `ms_addresses` VALUES ('2324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋電通本社ビル　17階', '13', '13103', '1057017', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '電通本社ビル　17階', 'デンツウホンシャビル　17カイ');
INSERT INTO `ms_addresses` VALUES ('2325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋電通本社ビル　18階', '13', '13103', '1057018', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '電通本社ビル　18階', 'デンツウホンシャビル　18カイ');
INSERT INTO `ms_addresses` VALUES ('2326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋電通本社ビル　19階', '13', '13103', '1057019', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '電通本社ビル　19階', 'デンツウホンシャビル　19カイ');
INSERT INTO `ms_addresses` VALUES ('2327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋電通本社ビル　20階', '13', '13103', '1057020', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '電通本社ビル　20階', 'デンツウホンシャビル　20カイ');
INSERT INTO `ms_addresses` VALUES ('2328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋電通本社ビル　21階', '13', '13103', '1057021', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '電通本社ビル　21階', 'デンツウホンシャビル　21カイ');
INSERT INTO `ms_addresses` VALUES ('2329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋電通本社ビル　22階', '13', '13103', '1057022', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '電通本社ビル　22階', 'デンツウホンシャビル　22カイ');
INSERT INTO `ms_addresses` VALUES ('2330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋電通本社ビル　23階', '13', '13103', '1057023', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '電通本社ビル　23階', 'デンツウホンシャビル　23カイ');
INSERT INTO `ms_addresses` VALUES ('2331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋電通本社ビル　24階', '13', '13103', '1057024', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '電通本社ビル　24階', 'デンツウホンシャビル　24カイ');
INSERT INTO `ms_addresses` VALUES ('2332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋電通本社ビル　25階', '13', '13103', '1057025', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '電通本社ビル　25階', 'デンツウホンシャビル　25カイ');
INSERT INTO `ms_addresses` VALUES ('2333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋電通本社ビル　26階', '13', '13103', '1057026', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '電通本社ビル　26階', 'デンツウホンシャビル　26カイ');
INSERT INTO `ms_addresses` VALUES ('2334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋電通本社ビル　27階', '13', '13103', '1057027', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '電通本社ビル　27階', 'デンツウホンシャビル　27カイ');
INSERT INTO `ms_addresses` VALUES ('2335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋電通本社ビル　28階', '13', '13103', '1057028', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '電通本社ビル　28階', 'デンツウホンシャビル　28カイ');
INSERT INTO `ms_addresses` VALUES ('2336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋電通本社ビル　29階', '13', '13103', '1057029', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '電通本社ビル　29階', 'デンツウホンシャビル　29カイ');
INSERT INTO `ms_addresses` VALUES ('2337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋電通本社ビル　30階', '13', '13103', '1057030', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '電通本社ビル　30階', 'デンツウホンシャビル　30カイ');
INSERT INTO `ms_addresses` VALUES ('2338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋電通本社ビル　31階', '13', '13103', '1057031', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '電通本社ビル　31階', 'デンツウホンシャビル　31カイ');
INSERT INTO `ms_addresses` VALUES ('2339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋電通本社ビル　32階', '13', '13103', '1057032', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '電通本社ビル　32階', 'デンツウホンシャビル　32カイ');
INSERT INTO `ms_addresses` VALUES ('2340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋電通本社ビル　33階', '13', '13103', '1057033', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '電通本社ビル　33階', 'デンツウホンシャビル　33カイ');
INSERT INTO `ms_addresses` VALUES ('2341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋電通本社ビル　34階', '13', '13103', '1057034', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '電通本社ビル　34階', 'デンツウホンシャビル　34カイ');
INSERT INTO `ms_addresses` VALUES ('2342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋電通本社ビル　35階', '13', '13103', '1057035', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '電通本社ビル　35階', 'デンツウホンシャビル　35カイ');
INSERT INTO `ms_addresses` VALUES ('2343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋電通本社ビル　36階', '13', '13103', '1057036', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '電通本社ビル　36階', 'デンツウホンシャビル　36カイ');
INSERT INTO `ms_addresses` VALUES ('2344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋電通本社ビル　37階', '13', '13103', '1057037', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '電通本社ビル　37階', 'デンツウホンシャビル　37カイ');
INSERT INTO `ms_addresses` VALUES ('2345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋電通本社ビル　38階', '13', '13103', '1057038', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '電通本社ビル　38階', 'デンツウホンシャビル　38カイ');
INSERT INTO `ms_addresses` VALUES ('2346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋電通本社ビル　39階', '13', '13103', '1057039', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '電通本社ビル　39階', 'デンツウホンシャビル　39カイ');
INSERT INTO `ms_addresses` VALUES ('2347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋電通本社ビル　40階', '13', '13103', '1057040', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '電通本社ビル　40階', 'デンツウホンシャビル　40カイ');
INSERT INTO `ms_addresses` VALUES ('2348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋電通本社ビル　41階', '13', '13103', '1057041', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '電通本社ビル　41階', 'デンツウホンシャビル　41カイ');
INSERT INTO `ms_addresses` VALUES ('2349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋電通本社ビル　42階', '13', '13103', '1057042', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '電通本社ビル　42階', 'デンツウホンシャビル　42カイ');
INSERT INTO `ms_addresses` VALUES ('2350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋電通本社ビル　43階', '13', '13103', '1057043', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '電通本社ビル　43階', 'デンツウホンシャビル　43カイ');
INSERT INTO `ms_addresses` VALUES ('2351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋電通本社ビル　44階', '13', '13103', '1057044', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '電通本社ビル　44階', 'デンツウホンシャビル　44カイ');
INSERT INTO `ms_addresses` VALUES ('2352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋電通本社ビル　45階', '13', '13103', '1057045', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '電通本社ビル　45階', 'デンツウホンシャビル　45カイ');
INSERT INTO `ms_addresses` VALUES ('2353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋電通本社ビル　46階', '13', '13103', '1057046', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '電通本社ビル　46階', 'デンツウホンシャビル　46カイ');
INSERT INTO `ms_addresses` VALUES ('2354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋電通本社ビル　47階', '13', '13103', '1057047', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '電通本社ビル　47階', 'デンツウホンシャビル　47カイ');
INSERT INTO `ms_addresses` VALUES ('2355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋電通本社ビル　', '13', '13103', '1057090', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '電通本社ビル　', 'デンツウホンシャビル　');
INSERT INTO `ms_addresses` VALUES ('2356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋汐留シティセンター　1階', '13', '13103', '1057101', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '汐留シティセンター　1階', 'シオドメシティセンター　01カイ');
INSERT INTO `ms_addresses` VALUES ('2357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋汐留シティセンター　2階', '13', '13103', '1057102', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '汐留シティセンター　2階', 'シオドメシティセンター　02カイ');
INSERT INTO `ms_addresses` VALUES ('2358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋汐留シティセンター　3階', '13', '13103', '1057103', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '汐留シティセンター　3階', 'シオドメシティセンター　03カイ');
INSERT INTO `ms_addresses` VALUES ('2359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋汐留シティセンター　4階', '13', '13103', '1057104', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '汐留シティセンター　4階', 'シオドメシティセンター　04カイ');
INSERT INTO `ms_addresses` VALUES ('2360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋汐留シティセンター　5階', '13', '13103', '1057105', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '汐留シティセンター　5階', 'シオドメシティセンター　05カイ');
INSERT INTO `ms_addresses` VALUES ('2361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋汐留シティセンター　6階', '13', '13103', '1057106', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '汐留シティセンター　6階', 'シオドメシティセンター　06カイ');
INSERT INTO `ms_addresses` VALUES ('2362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋汐留シティセンター　7階', '13', '13103', '1057107', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '汐留シティセンター　7階', 'シオドメシティセンター　07カイ');
INSERT INTO `ms_addresses` VALUES ('2363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋汐留シティセンター　8階', '13', '13103', '1057108', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '汐留シティセンター　8階', 'シオドメシティセンター　08カイ');
INSERT INTO `ms_addresses` VALUES ('2364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋汐留シティセンター　9階', '13', '13103', '1057109', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '汐留シティセンター　9階', 'シオドメシティセンター　09カイ');
INSERT INTO `ms_addresses` VALUES ('2365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋汐留シティセンター　10階', '13', '13103', '1057110', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '汐留シティセンター　10階', 'シオドメシティセンター　10カイ');
INSERT INTO `ms_addresses` VALUES ('2366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋汐留シティセンター　11階', '13', '13103', '1057111', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '汐留シティセンター　11階', 'シオドメシティセンター　11カイ');
INSERT INTO `ms_addresses` VALUES ('2367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋汐留シティセンター　12階', '13', '13103', '1057112', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '汐留シティセンター　12階', 'シオドメシティセンター　12カイ');
INSERT INTO `ms_addresses` VALUES ('2368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋汐留シティセンター　13階', '13', '13103', '1057113', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '汐留シティセンター　13階', 'シオドメシティセンター　13カイ');
INSERT INTO `ms_addresses` VALUES ('2369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋汐留シティセンター　14階', '13', '13103', '1057114', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '汐留シティセンター　14階', 'シオドメシティセンター　14カイ');
INSERT INTO `ms_addresses` VALUES ('2370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋汐留シティセンター　15階', '13', '13103', '1057115', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '汐留シティセンター　15階', 'シオドメシティセンター　15カイ');
INSERT INTO `ms_addresses` VALUES ('2371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋汐留シティセンター　16階', '13', '13103', '1057116', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '汐留シティセンター　16階', 'シオドメシティセンター　16カイ');
INSERT INTO `ms_addresses` VALUES ('2372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋汐留シティセンター　17階', '13', '13103', '1057117', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '汐留シティセンター　17階', 'シオドメシティセンター　17カイ');
INSERT INTO `ms_addresses` VALUES ('2373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋汐留シティセンター　18階', '13', '13103', '1057118', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '汐留シティセンター　18階', 'シオドメシティセンター　18カイ');
INSERT INTO `ms_addresses` VALUES ('2374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋汐留シティセンター　19階', '13', '13103', '1057119', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '汐留シティセンター　19階', 'シオドメシティセンター　19カイ');
INSERT INTO `ms_addresses` VALUES ('2375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋汐留シティセンター　20階', '13', '13103', '1057120', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '汐留シティセンター　20階', 'シオドメシティセンター　20カイ');
INSERT INTO `ms_addresses` VALUES ('2376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋汐留シティセンター　21階', '13', '13103', '1057121', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '汐留シティセンター　21階', 'シオドメシティセンター　21カイ');
INSERT INTO `ms_addresses` VALUES ('2377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋汐留シティセンター　22階', '13', '13103', '1057122', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '汐留シティセンター　22階', 'シオドメシティセンター　22カイ');
INSERT INTO `ms_addresses` VALUES ('2378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋汐留シティセンター　23階', '13', '13103', '1057123', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '汐留シティセンター　23階', 'シオドメシティセンター　23カイ');
INSERT INTO `ms_addresses` VALUES ('2379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋汐留シティセンター　24階', '13', '13103', '1057124', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '汐留シティセンター　24階', 'シオドメシティセンター　24カイ');
INSERT INTO `ms_addresses` VALUES ('2380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋汐留シティセンター　25階', '13', '13103', '1057125', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '汐留シティセンター　25階', 'シオドメシティセンター　25カイ');
INSERT INTO `ms_addresses` VALUES ('2381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋汐留シティセンター　26階', '13', '13103', '1057126', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '汐留シティセンター　26階', 'シオドメシティセンター　26カイ');
INSERT INTO `ms_addresses` VALUES ('2382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋汐留シティセンター　27階', '13', '13103', '1057127', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '汐留シティセンター　27階', 'シオドメシティセンター　27カイ');
INSERT INTO `ms_addresses` VALUES ('2383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋汐留シティセンター　28階', '13', '13103', '1057128', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '汐留シティセンター　28階', 'シオドメシティセンター　28カイ');
INSERT INTO `ms_addresses` VALUES ('2384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋汐留シティセンター　29階', '13', '13103', '1057129', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '汐留シティセンター　29階', 'シオドメシティセンター　29カイ');
INSERT INTO `ms_addresses` VALUES ('2385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋汐留シティセンター　30階', '13', '13103', '1057130', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '汐留シティセンター　30階', 'シオドメシティセンター　30カイ');
INSERT INTO `ms_addresses` VALUES ('2386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋汐留シティセンター　31階', '13', '13103', '1057131', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '汐留シティセンター　31階', 'シオドメシティセンター　31カイ');
INSERT INTO `ms_addresses` VALUES ('2387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋汐留シティセンター　32階', '13', '13103', '1057132', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '汐留シティセンター　32階', 'シオドメシティセンター　32カイ');
INSERT INTO `ms_addresses` VALUES ('2388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋汐留シティセンター　33階', '13', '13103', '1057133', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '汐留シティセンター　33階', 'シオドメシティセンター　33カイ');
INSERT INTO `ms_addresses` VALUES ('2389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋汐留シティセンター　34階', '13', '13103', '1057134', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '汐留シティセンター　34階', 'シオドメシティセンター　34カイ');
INSERT INTO `ms_addresses` VALUES ('2390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋汐留シティセンター　35階', '13', '13103', '1057135', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '汐留シティセンター　35階', 'シオドメシティセンター　35カイ');
INSERT INTO `ms_addresses` VALUES ('2391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋汐留シティセンター　36階', '13', '13103', '1057136', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '汐留シティセンター　36階', 'シオドメシティセンター　36カイ');
INSERT INTO `ms_addresses` VALUES ('2392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋汐留シティセンター　37階', '13', '13103', '1057137', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '汐留シティセンター　37階', 'シオドメシティセンター　37カイ');
INSERT INTO `ms_addresses` VALUES ('2393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋汐留シティセンター　38階', '13', '13103', '1057138', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '汐留シティセンター　38階', 'シオドメシティセンター　38カイ');
INSERT INTO `ms_addresses` VALUES ('2394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋汐留シティセンター　39階', '13', '13103', '1057139', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '汐留シティセンター　39階', 'シオドメシティセンター　39カイ');
INSERT INTO `ms_addresses` VALUES ('2395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋汐留シティセンター　40階', '13', '13103', '1057140', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '汐留シティセンター　40階', 'シオドメシティセンター　40カイ');
INSERT INTO `ms_addresses` VALUES ('2396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋汐留シティセンター　41階', '13', '13103', '1057141', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '汐留シティセンター　41階', 'シオドメシティセンター　41カイ');
INSERT INTO `ms_addresses` VALUES ('2397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋汐留シティセンター　42階', '13', '13103', '1057142', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '汐留シティセンター　42階', 'シオドメシティセンター　42カイ');
INSERT INTO `ms_addresses` VALUES ('2398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋汐留シティセンター　43階', '13', '13103', '1057143', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '汐留シティセンター　43階', 'シオドメシティセンター　43カイ');
INSERT INTO `ms_addresses` VALUES ('2399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋汐留シティセンター　', '13', '13103', '1057190', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '汐留シティセンター　', 'シオドメシティセンター　');
INSERT INTO `ms_addresses` VALUES ('2400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋汐留メディアタワー　1階', '13', '13103', '1057201', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '汐留メディアタワー　1階', 'シオドメメディアタワー　01カイ');
INSERT INTO `ms_addresses` VALUES ('2401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋汐留メディアタワー　2階', '13', '13103', '1057202', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '汐留メディアタワー　2階', 'シオドメメディアタワー　02カイ');
INSERT INTO `ms_addresses` VALUES ('2402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋汐留メディアタワー　3階', '13', '13103', '1057203', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '汐留メディアタワー　3階', 'シオドメメディアタワー　03カイ');
INSERT INTO `ms_addresses` VALUES ('2403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋汐留メディアタワー　4階', '13', '13103', '1057204', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '汐留メディアタワー　4階', 'シオドメメディアタワー　04カイ');
INSERT INTO `ms_addresses` VALUES ('2404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋汐留メディアタワー　5階', '13', '13103', '1057205', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '汐留メディアタワー　5階', 'シオドメメディアタワー　05カイ');
INSERT INTO `ms_addresses` VALUES ('2405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋汐留メディアタワー　6階', '13', '13103', '1057206', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '汐留メディアタワー　6階', 'シオドメメディアタワー　06カイ');
INSERT INTO `ms_addresses` VALUES ('2406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋汐留メディアタワー　7階', '13', '13103', '1057207', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '汐留メディアタワー　7階', 'シオドメメディアタワー　07カイ');
INSERT INTO `ms_addresses` VALUES ('2407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋汐留メディアタワー　8階', '13', '13103', '1057208', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '汐留メディアタワー　8階', 'シオドメメディアタワー　08カイ');
INSERT INTO `ms_addresses` VALUES ('2408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋汐留メディアタワー　9階', '13', '13103', '1057209', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '汐留メディアタワー　9階', 'シオドメメディアタワー　09カイ');
INSERT INTO `ms_addresses` VALUES ('2409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋汐留メディアタワー　10階', '13', '13103', '1057210', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '汐留メディアタワー　10階', 'シオドメメディアタワー　10カイ');
INSERT INTO `ms_addresses` VALUES ('2410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋汐留メディアタワー　11階', '13', '13103', '1057211', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '汐留メディアタワー　11階', 'シオドメメディアタワー　11カイ');
INSERT INTO `ms_addresses` VALUES ('2411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋汐留メディアタワー　12階', '13', '13103', '1057212', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '汐留メディアタワー　12階', 'シオドメメディアタワー　12カイ');
INSERT INTO `ms_addresses` VALUES ('2412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋汐留メディアタワー　13階', '13', '13103', '1057213', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '汐留メディアタワー　13階', 'シオドメメディアタワー　13カイ');
INSERT INTO `ms_addresses` VALUES ('2413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋汐留メディアタワー　14階', '13', '13103', '1057214', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '汐留メディアタワー　14階', 'シオドメメディアタワー　14カイ');
INSERT INTO `ms_addresses` VALUES ('2414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋汐留メディアタワー　15階', '13', '13103', '1057215', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '汐留メディアタワー　15階', 'シオドメメディアタワー　15カイ');
INSERT INTO `ms_addresses` VALUES ('2415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋汐留メディアタワー　16階', '13', '13103', '1057216', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '汐留メディアタワー　16階', 'シオドメメディアタワー　16カイ');
INSERT INTO `ms_addresses` VALUES ('2416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋汐留メディアタワー　17階', '13', '13103', '1057217', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '汐留メディアタワー　17階', 'シオドメメディアタワー　17カイ');
INSERT INTO `ms_addresses` VALUES ('2417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋汐留メディアタワー　18階', '13', '13103', '1057218', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '汐留メディアタワー　18階', 'シオドメメディアタワー　18カイ');
INSERT INTO `ms_addresses` VALUES ('2418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋汐留メディアタワー　19階', '13', '13103', '1057219', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '汐留メディアタワー　19階', 'シオドメメディアタワー　19カイ');
INSERT INTO `ms_addresses` VALUES ('2419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋汐留メディアタワー　20階', '13', '13103', '1057220', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '汐留メディアタワー　20階', 'シオドメメディアタワー　20カイ');
INSERT INTO `ms_addresses` VALUES ('2420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋汐留メディアタワー　21階', '13', '13103', '1057221', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '汐留メディアタワー　21階', 'シオドメメディアタワー　21カイ');
INSERT INTO `ms_addresses` VALUES ('2421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋汐留メディアタワー　22階', '13', '13103', '1057222', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '汐留メディアタワー　22階', 'シオドメメディアタワー　22カイ');
INSERT INTO `ms_addresses` VALUES ('2422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋汐留メディアタワー　23階', '13', '13103', '1057223', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '汐留メディアタワー　23階', 'シオドメメディアタワー　23カイ');
INSERT INTO `ms_addresses` VALUES ('2423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋汐留メディアタワー　24階', '13', '13103', '1057224', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '汐留メディアタワー　24階', 'シオドメメディアタワー　24カイ');
INSERT INTO `ms_addresses` VALUES ('2424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋汐留メディアタワー　25階', '13', '13103', '1057225', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '汐留メディアタワー　25階', 'シオドメメディアタワー　25カイ');
INSERT INTO `ms_addresses` VALUES ('2425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋汐留メディアタワー　26階', '13', '13103', '1057226', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '汐留メディアタワー　26階', 'シオドメメディアタワー　26カイ');
INSERT INTO `ms_addresses` VALUES ('2426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋汐留メディアタワー　27階', '13', '13103', '1057227', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '汐留メディアタワー　27階', 'シオドメメディアタワー　27カイ');
INSERT INTO `ms_addresses` VALUES ('2427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋汐留メディアタワー　28階', '13', '13103', '1057228', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '汐留メディアタワー　28階', 'シオドメメディアタワー　28カイ');
INSERT INTO `ms_addresses` VALUES ('2428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋汐留メディアタワー　29階', '13', '13103', '1057229', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '汐留メディアタワー　29階', 'シオドメメディアタワー　29カイ');
INSERT INTO `ms_addresses` VALUES ('2429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋汐留メディアタワー　30階', '13', '13103', '1057230', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '汐留メディアタワー　30階', 'シオドメメディアタワー　30カイ');
INSERT INTO `ms_addresses` VALUES ('2430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋汐留メディアタワー　31階', '13', '13103', '1057231', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '汐留メディアタワー　31階', 'シオドメメディアタワー　31カイ');
INSERT INTO `ms_addresses` VALUES ('2431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋汐留メディアタワー　32階', '13', '13103', '1057232', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '汐留メディアタワー　32階', 'シオドメメディアタワー　32カイ');
INSERT INTO `ms_addresses` VALUES ('2432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋汐留メディアタワー　33階', '13', '13103', '1057233', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '汐留メディアタワー　33階', 'シオドメメディアタワー　33カイ');
INSERT INTO `ms_addresses` VALUES ('2433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋汐留メディアタワー　34階', '13', '13103', '1057234', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '汐留メディアタワー　34階', 'シオドメメディアタワー　34カイ');
INSERT INTO `ms_addresses` VALUES ('2434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋汐留メディアタワー　', '13', '13103', '1057290', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '汐留メディアタワー　', 'シオドメメディアタワー　');
INSERT INTO `ms_addresses` VALUES ('2435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋東京汐留ビルディング　1階', '13', '13103', '1057301', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '東京汐留ビルディング　1階', 'トウキョウシオドメビルディング　01カイ');
INSERT INTO `ms_addresses` VALUES ('2436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋東京汐留ビルディング　2階', '13', '13103', '1057302', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '東京汐留ビルディング　2階', 'トウキョウシオドメビルディング　02カイ');
INSERT INTO `ms_addresses` VALUES ('2437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋東京汐留ビルディング　3階', '13', '13103', '1057303', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '東京汐留ビルディング　3階', 'トウキョウシオドメビルディング　03カイ');
INSERT INTO `ms_addresses` VALUES ('2438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋東京汐留ビルディング　4階', '13', '13103', '1057304', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '東京汐留ビルディング　4階', 'トウキョウシオドメビルディング　04カイ');
INSERT INTO `ms_addresses` VALUES ('2439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋東京汐留ビルディング　5階', '13', '13103', '1057305', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '東京汐留ビルディング　5階', 'トウキョウシオドメビルディング　05カイ');
INSERT INTO `ms_addresses` VALUES ('2440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋東京汐留ビルディング　6階', '13', '13103', '1057306', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '東京汐留ビルディング　6階', 'トウキョウシオドメビルディング　06カイ');
INSERT INTO `ms_addresses` VALUES ('2441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋東京汐留ビルディング　7階', '13', '13103', '1057307', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '東京汐留ビルディング　7階', 'トウキョウシオドメビルディング　07カイ');
INSERT INTO `ms_addresses` VALUES ('2442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋東京汐留ビルディング　8階', '13', '13103', '1057308', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '東京汐留ビルディング　8階', 'トウキョウシオドメビルディング　08カイ');
INSERT INTO `ms_addresses` VALUES ('2443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋東京汐留ビルディング　9階', '13', '13103', '1057309', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '東京汐留ビルディング　9階', 'トウキョウシオドメビルディング　09カイ');
INSERT INTO `ms_addresses` VALUES ('2444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋東京汐留ビルディング　10階', '13', '13103', '1057310', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '東京汐留ビルディング　10階', 'トウキョウシオドメビルディング　10カイ');
INSERT INTO `ms_addresses` VALUES ('2445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋東京汐留ビルディング　11階', '13', '13103', '1057311', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '東京汐留ビルディング　11階', 'トウキョウシオドメビルディング　11カイ');
INSERT INTO `ms_addresses` VALUES ('2446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋東京汐留ビルディング　12階', '13', '13103', '1057312', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '東京汐留ビルディング　12階', 'トウキョウシオドメビルディング　12カイ');
INSERT INTO `ms_addresses` VALUES ('2447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋東京汐留ビルディング　13階', '13', '13103', '1057313', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '東京汐留ビルディング　13階', 'トウキョウシオドメビルディング　13カイ');
INSERT INTO `ms_addresses` VALUES ('2448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋東京汐留ビルディング　14階', '13', '13103', '1057314', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '東京汐留ビルディング　14階', 'トウキョウシオドメビルディング　14カイ');
INSERT INTO `ms_addresses` VALUES ('2449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋東京汐留ビルディング　15階', '13', '13103', '1057315', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '東京汐留ビルディング　15階', 'トウキョウシオドメビルディング　15カイ');
INSERT INTO `ms_addresses` VALUES ('2450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋東京汐留ビルディング　16階', '13', '13103', '1057316', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '東京汐留ビルディング　16階', 'トウキョウシオドメビルディング　16カイ');
INSERT INTO `ms_addresses` VALUES ('2451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋東京汐留ビルディング　17階', '13', '13103', '1057317', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '東京汐留ビルディング　17階', 'トウキョウシオドメビルディング　17カイ');
INSERT INTO `ms_addresses` VALUES ('2452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋東京汐留ビルディング　18階', '13', '13103', '1057318', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '東京汐留ビルディング　18階', 'トウキョウシオドメビルディング　18カイ');
INSERT INTO `ms_addresses` VALUES ('2453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋東京汐留ビルディング　19階', '13', '13103', '1057319', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '東京汐留ビルディング　19階', 'トウキョウシオドメビルディング　19カイ');
INSERT INTO `ms_addresses` VALUES ('2454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋東京汐留ビルディング　20階', '13', '13103', '1057320', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '東京汐留ビルディング　20階', 'トウキョウシオドメビルディング　20カイ');
INSERT INTO `ms_addresses` VALUES ('2455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋東京汐留ビルディング　21階', '13', '13103', '1057321', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '東京汐留ビルディング　21階', 'トウキョウシオドメビルディング　21カイ');
INSERT INTO `ms_addresses` VALUES ('2456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋東京汐留ビルディング　22階', '13', '13103', '1057322', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '東京汐留ビルディング　22階', 'トウキョウシオドメビルディング　22カイ');
INSERT INTO `ms_addresses` VALUES ('2457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋東京汐留ビルディング　23階', '13', '13103', '1057323', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '東京汐留ビルディング　23階', 'トウキョウシオドメビルディング　23カイ');
INSERT INTO `ms_addresses` VALUES ('2458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋東京汐留ビルディング　24階', '13', '13103', '1057324', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '東京汐留ビルディング　24階', 'トウキョウシオドメビルディング　24カイ');
INSERT INTO `ms_addresses` VALUES ('2459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋東京汐留ビルディング　25階', '13', '13103', '1057325', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '東京汐留ビルディング　25階', 'トウキョウシオドメビルディング　25カイ');
INSERT INTO `ms_addresses` VALUES ('2460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋東京汐留ビルディング　26階', '13', '13103', '1057326', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '東京汐留ビルディング　26階', 'トウキョウシオドメビルディング　26カイ');
INSERT INTO `ms_addresses` VALUES ('2461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋東京汐留ビルディング　27階', '13', '13103', '1057327', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '東京汐留ビルディング　27階', 'トウキョウシオドメビルディング　27カイ');
INSERT INTO `ms_addresses` VALUES ('2462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋東京汐留ビルディング　28階', '13', '13103', '1057328', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '東京汐留ビルディング　28階', 'トウキョウシオドメビルディング　28カイ');
INSERT INTO `ms_addresses` VALUES ('2463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋東京汐留ビルディング　29階', '13', '13103', '1057329', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '東京汐留ビルディング　29階', 'トウキョウシオドメビルディング　29カイ');
INSERT INTO `ms_addresses` VALUES ('2464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋東京汐留ビルディング　30階', '13', '13103', '1057330', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '東京汐留ビルディング　30階', 'トウキョウシオドメビルディング　30カイ');
INSERT INTO `ms_addresses` VALUES ('2465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋東京汐留ビルディング　31階', '13', '13103', '1057331', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '東京汐留ビルディング　31階', 'トウキョウシオドメビルディング　31カイ');
INSERT INTO `ms_addresses` VALUES ('2466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋東京汐留ビルディング　32階', '13', '13103', '1057332', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '東京汐留ビルディング　32階', 'トウキョウシオドメビルディング　32カイ');
INSERT INTO `ms_addresses` VALUES ('2467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋東京汐留ビルディング　33階', '13', '13103', '1057333', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '東京汐留ビルディング　33階', 'トウキョウシオドメビルディング　33カイ');
INSERT INTO `ms_addresses` VALUES ('2468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋東京汐留ビルディング　34階', '13', '13103', '1057334', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '東京汐留ビルディング　34階', 'トウキョウシオドメビルディング　34カイ');
INSERT INTO `ms_addresses` VALUES ('2469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋東京汐留ビルディング　35階', '13', '13103', '1057335', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '東京汐留ビルディング　35階', 'トウキョウシオドメビルディング　35カイ');
INSERT INTO `ms_addresses` VALUES ('2470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋東京汐留ビルディング　36階', '13', '13103', '1057336', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '東京汐留ビルディング　36階', 'トウキョウシオドメビルディング　36カイ');
INSERT INTO `ms_addresses` VALUES ('2471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋東京汐留ビルディング　37階', '13', '13103', '1057337', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '東京汐留ビルディング　37階', 'トウキョウシオドメビルディング　37カイ');
INSERT INTO `ms_addresses` VALUES ('2472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋東京汐留ビルディング　', '13', '13103', '1057390', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '東京汐留ビルディング　', 'トウキョウシオドメビルディング　');
INSERT INTO `ms_addresses` VALUES ('2473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋日本テレビタワー　1階', '13', '13103', '1057401', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '日本テレビタワー　1階', 'ニホンテレビタワー　01カイ');
INSERT INTO `ms_addresses` VALUES ('2474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋日本テレビタワー　2階', '13', '13103', '1057402', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '日本テレビタワー　2階', 'ニホンテレビタワー　02カイ');
INSERT INTO `ms_addresses` VALUES ('2475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋日本テレビタワー　3階', '13', '13103', '1057403', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '日本テレビタワー　3階', 'ニホンテレビタワー　03カイ');
INSERT INTO `ms_addresses` VALUES ('2476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋日本テレビタワー　4階', '13', '13103', '1057404', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '日本テレビタワー　4階', 'ニホンテレビタワー　04カイ');
INSERT INTO `ms_addresses` VALUES ('2477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋日本テレビタワー　5階', '13', '13103', '1057405', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '日本テレビタワー　5階', 'ニホンテレビタワー　05カイ');
INSERT INTO `ms_addresses` VALUES ('2478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋日本テレビタワー　6階', '13', '13103', '1057406', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '日本テレビタワー　6階', 'ニホンテレビタワー　06カイ');
INSERT INTO `ms_addresses` VALUES ('2479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋日本テレビタワー　7階', '13', '13103', '1057407', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '日本テレビタワー　7階', 'ニホンテレビタワー　07カイ');
INSERT INTO `ms_addresses` VALUES ('2480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋日本テレビタワー　8階', '13', '13103', '1057408', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '日本テレビタワー　8階', 'ニホンテレビタワー　08カイ');
INSERT INTO `ms_addresses` VALUES ('2481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋日本テレビタワー　9階', '13', '13103', '1057409', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '日本テレビタワー　9階', 'ニホンテレビタワー　09カイ');
INSERT INTO `ms_addresses` VALUES ('2482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋日本テレビタワー　10階', '13', '13103', '1057410', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '日本テレビタワー　10階', 'ニホンテレビタワー　10カイ');
INSERT INTO `ms_addresses` VALUES ('2483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋日本テレビタワー　11階', '13', '13103', '1057411', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '日本テレビタワー　11階', 'ニホンテレビタワー　11カイ');
INSERT INTO `ms_addresses` VALUES ('2484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋日本テレビタワー　12階', '13', '13103', '1057412', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '日本テレビタワー　12階', 'ニホンテレビタワー　12カイ');
INSERT INTO `ms_addresses` VALUES ('2485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋日本テレビタワー　13階', '13', '13103', '1057413', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '日本テレビタワー　13階', 'ニホンテレビタワー　13カイ');
INSERT INTO `ms_addresses` VALUES ('2486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋日本テレビタワー　14階', '13', '13103', '1057414', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '日本テレビタワー　14階', 'ニホンテレビタワー　14カイ');
INSERT INTO `ms_addresses` VALUES ('2487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋日本テレビタワー　15階', '13', '13103', '1057415', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '日本テレビタワー　15階', 'ニホンテレビタワー　15カイ');
INSERT INTO `ms_addresses` VALUES ('2488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋日本テレビタワー　16階', '13', '13103', '1057416', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '日本テレビタワー　16階', 'ニホンテレビタワー　16カイ');
INSERT INTO `ms_addresses` VALUES ('2489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋日本テレビタワー　17階', '13', '13103', '1057417', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '日本テレビタワー　17階', 'ニホンテレビタワー　17カイ');
INSERT INTO `ms_addresses` VALUES ('2490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋日本テレビタワー　18階', '13', '13103', '1057418', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '日本テレビタワー　18階', 'ニホンテレビタワー　18カイ');
INSERT INTO `ms_addresses` VALUES ('2491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋日本テレビタワー　19階', '13', '13103', '1057419', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '日本テレビタワー　19階', 'ニホンテレビタワー　19カイ');
INSERT INTO `ms_addresses` VALUES ('2492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋日本テレビタワー　20階', '13', '13103', '1057420', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '日本テレビタワー　20階', 'ニホンテレビタワー　20カイ');
INSERT INTO `ms_addresses` VALUES ('2493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋日本テレビタワー　21階', '13', '13103', '1057421', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '日本テレビタワー　21階', 'ニホンテレビタワー　21カイ');
INSERT INTO `ms_addresses` VALUES ('2494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋日本テレビタワー　22階', '13', '13103', '1057422', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '日本テレビタワー　22階', 'ニホンテレビタワー　22カイ');
INSERT INTO `ms_addresses` VALUES ('2495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋日本テレビタワー　23階', '13', '13103', '1057423', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '日本テレビタワー　23階', 'ニホンテレビタワー　23カイ');
INSERT INTO `ms_addresses` VALUES ('2496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋日本テレビタワー　24階', '13', '13103', '1057424', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '日本テレビタワー　24階', 'ニホンテレビタワー　24カイ');
INSERT INTO `ms_addresses` VALUES ('2497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋日本テレビタワー　25階', '13', '13103', '1057425', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '日本テレビタワー　25階', 'ニホンテレビタワー　25カイ');
INSERT INTO `ms_addresses` VALUES ('2498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋日本テレビタワー　26階', '13', '13103', '1057426', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '日本テレビタワー　26階', 'ニホンテレビタワー　26カイ');
INSERT INTO `ms_addresses` VALUES ('2499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋日本テレビタワー　27階', '13', '13103', '1057427', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '日本テレビタワー　27階', 'ニホンテレビタワー　27カイ');
INSERT INTO `ms_addresses` VALUES ('2500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋日本テレビタワー　28階', '13', '13103', '1057428', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '日本テレビタワー　28階', 'ニホンテレビタワー　28カイ');
INSERT INTO `ms_addresses` VALUES ('2501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋日本テレビタワー　29階', '13', '13103', '1057429', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '日本テレビタワー　29階', 'ニホンテレビタワー　29カイ');
INSERT INTO `ms_addresses` VALUES ('2502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋日本テレビタワー　30階', '13', '13103', '1057430', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '日本テレビタワー　30階', 'ニホンテレビタワー　30カイ');
INSERT INTO `ms_addresses` VALUES ('2503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋日本テレビタワー　31階', '13', '13103', '1057431', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '日本テレビタワー　31階', 'ニホンテレビタワー　31カイ');
INSERT INTO `ms_addresses` VALUES ('2504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋日本テレビタワー　32階', '13', '13103', '1057432', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '日本テレビタワー　32階', 'ニホンテレビタワー　32カイ');
INSERT INTO `ms_addresses` VALUES ('2506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東新橋日本テレビタワー　', '13', '13103', '1057490', '東京都', 'トウキョウト', '港区', 'ミナトク', '東新橋', 'ヒガシシンバシ', null, null, '日本テレビタワー　', 'ニホンテレビタワー　');
INSERT INTO `ms_addresses` VALUES ('2676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区西麻布', '13', '13103', '1060031', '東京都', 'トウキョウト', '港区', 'ミナトク', '西麻布', 'ニシアザブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('2677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区六本木', '13', '13103', '1060032', '東京都', 'トウキョウト', '港区', 'ミナトク', '六本木', 'ロッポンギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('2678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区麻布台', '13', '13103', '1060041', '東京都', 'トウキョウト', '港区', 'ミナトク', '麻布台', 'アザブダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('2679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区麻布狸穴町', '13', '13103', '1060042', '東京都', 'トウキョウト', '港区', 'ミナトク', '麻布狸穴町', 'アザブマミアナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('2680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区麻布永坂町', '13', '13103', '1060043', '東京都', 'トウキョウト', '港区', 'ミナトク', '麻布永坂町', 'アザブナガサカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('2681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区東麻布', '13', '13103', '1060044', '東京都', 'トウキョウト', '港区', 'ミナトク', '東麻布', 'ヒガシアザブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('2682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区麻布十番', '13', '13103', '1060045', '東京都', 'トウキョウト', '港区', 'ミナトク', '麻布十番', 'アザブジュウバン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('2683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区元麻布', '13', '13103', '1060046', '東京都', 'トウキョウト', '港区', 'ミナトク', '元麻布', 'モトアザブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('2684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区南麻布', '13', '13103', '1060047', '東京都', 'トウキョウト', '港区', 'ミナトク', '南麻布', 'ミナミアザブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('2685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区六本木泉ガーデンタワー　1階', '13', '13103', '1066001', '東京都', 'トウキョウト', '港区', 'ミナトク', '六本木', 'ロッポンギ', null, null, '泉ガーデンタワー　1階', 'イズミガーデンタワー　01カイ');
INSERT INTO `ms_addresses` VALUES ('2686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区六本木泉ガーデンタワー　2階', '13', '13103', '1066002', '東京都', 'トウキョウト', '港区', 'ミナトク', '六本木', 'ロッポンギ', null, null, '泉ガーデンタワー　2階', 'イズミガーデンタワー　02カイ');
INSERT INTO `ms_addresses` VALUES ('2687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区六本木泉ガーデンタワー　3階', '13', '13103', '1066003', '東京都', 'トウキョウト', '港区', 'ミナトク', '六本木', 'ロッポンギ', null, null, '泉ガーデンタワー　3階', 'イズミガーデンタワー　03カイ');
INSERT INTO `ms_addresses` VALUES ('2688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区六本木泉ガーデンタワー　4階', '13', '13103', '1066004', '東京都', 'トウキョウト', '港区', 'ミナトク', '六本木', 'ロッポンギ', null, null, '泉ガーデンタワー　4階', 'イズミガーデンタワー　04カイ');
INSERT INTO `ms_addresses` VALUES ('2689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区六本木泉ガーデンタワー　5階', '13', '13103', '1066005', '東京都', 'トウキョウト', '港区', 'ミナトク', '六本木', 'ロッポンギ', null, null, '泉ガーデンタワー　5階', 'イズミガーデンタワー　05カイ');
INSERT INTO `ms_addresses` VALUES ('2690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区六本木泉ガーデンタワー　6階', '13', '13103', '1066006', '東京都', 'トウキョウト', '港区', 'ミナトク', '六本木', 'ロッポンギ', null, null, '泉ガーデンタワー　6階', 'イズミガーデンタワー　06カイ');
INSERT INTO `ms_addresses` VALUES ('2691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区六本木泉ガーデンタワー　7階', '13', '13103', '1066007', '東京都', 'トウキョウト', '港区', 'ミナトク', '六本木', 'ロッポンギ', null, null, '泉ガーデンタワー　7階', 'イズミガーデンタワー　07カイ');
INSERT INTO `ms_addresses` VALUES ('2692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区六本木泉ガーデンタワー　8階', '13', '13103', '1066008', '東京都', 'トウキョウト', '港区', 'ミナトク', '六本木', 'ロッポンギ', null, null, '泉ガーデンタワー　8階', 'イズミガーデンタワー　08カイ');
INSERT INTO `ms_addresses` VALUES ('2693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区六本木泉ガーデンタワー　9階', '13', '13103', '1066009', '東京都', 'トウキョウト', '港区', 'ミナトク', '六本木', 'ロッポンギ', null, null, '泉ガーデンタワー　9階', 'イズミガーデンタワー　09カイ');
INSERT INTO `ms_addresses` VALUES ('2694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区六本木泉ガーデンタワー　10階', '13', '13103', '1066010', '東京都', 'トウキョウト', '港区', 'ミナトク', '六本木', 'ロッポンギ', null, null, '泉ガーデンタワー　10階', 'イズミガーデンタワー　10カイ');
INSERT INTO `ms_addresses` VALUES ('2695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区六本木泉ガーデンタワー　11階', '13', '13103', '1066011', '東京都', 'トウキョウト', '港区', 'ミナトク', '六本木', 'ロッポンギ', null, null, '泉ガーデンタワー　11階', 'イズミガーデンタワー　11カイ');
INSERT INTO `ms_addresses` VALUES ('2696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区六本木泉ガーデンタワー　12階', '13', '13103', '1066012', '東京都', 'トウキョウト', '港区', 'ミナトク', '六本木', 'ロッポンギ', null, null, '泉ガーデンタワー　12階', 'イズミガーデンタワー　12カイ');
INSERT INTO `ms_addresses` VALUES ('2697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区六本木泉ガーデンタワー　13階', '13', '13103', '1066013', '東京都', 'トウキョウト', '港区', 'ミナトク', '六本木', 'ロッポンギ', null, null, '泉ガーデンタワー　13階', 'イズミガーデンタワー　13カイ');
INSERT INTO `ms_addresses` VALUES ('2698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区六本木泉ガーデンタワー　14階', '13', '13103', '1066014', '東京都', 'トウキョウト', '港区', 'ミナトク', '六本木', 'ロッポンギ', null, null, '泉ガーデンタワー　14階', 'イズミガーデンタワー　14カイ');
INSERT INTO `ms_addresses` VALUES ('2699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区六本木泉ガーデンタワー　15階', '13', '13103', '1066015', '東京都', 'トウキョウト', '港区', 'ミナトク', '六本木', 'ロッポンギ', null, null, '泉ガーデンタワー　15階', 'イズミガーデンタワー　15カイ');
INSERT INTO `ms_addresses` VALUES ('2700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区六本木泉ガーデンタワー　16階', '13', '13103', '1066016', '東京都', 'トウキョウト', '港区', 'ミナトク', '六本木', 'ロッポンギ', null, null, '泉ガーデンタワー　16階', 'イズミガーデンタワー　16カイ');
INSERT INTO `ms_addresses` VALUES ('2701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区六本木泉ガーデンタワー　17階', '13', '13103', '1066017', '東京都', 'トウキョウト', '港区', 'ミナトク', '六本木', 'ロッポンギ', null, null, '泉ガーデンタワー　17階', 'イズミガーデンタワー　17カイ');
INSERT INTO `ms_addresses` VALUES ('2702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区六本木泉ガーデンタワー　18階', '13', '13103', '1066018', '東京都', 'トウキョウト', '港区', 'ミナトク', '六本木', 'ロッポンギ', null, null, '泉ガーデンタワー　18階', 'イズミガーデンタワー　18カイ');
INSERT INTO `ms_addresses` VALUES ('2703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区六本木泉ガーデンタワー　19階', '13', '13103', '1066019', '東京都', 'トウキョウト', '港区', 'ミナトク', '六本木', 'ロッポンギ', null, null, '泉ガーデンタワー　19階', 'イズミガーデンタワー　19カイ');
INSERT INTO `ms_addresses` VALUES ('2704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区六本木泉ガーデンタワー　20階', '13', '13103', '1066020', '東京都', 'トウキョウト', '港区', 'ミナトク', '六本木', 'ロッポンギ', null, null, '泉ガーデンタワー　20階', 'イズミガーデンタワー　20カイ');
INSERT INTO `ms_addresses` VALUES ('2705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区六本木泉ガーデンタワー　21階', '13', '13103', '1066021', '東京都', 'トウキョウト', '港区', 'ミナトク', '六本木', 'ロッポンギ', null, null, '泉ガーデンタワー　21階', 'イズミガーデンタワー　21カイ');
INSERT INTO `ms_addresses` VALUES ('2706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区六本木泉ガーデンタワー　22階', '13', '13103', '1066022', '東京都', 'トウキョウト', '港区', 'ミナトク', '六本木', 'ロッポンギ', null, null, '泉ガーデンタワー　22階', 'イズミガーデンタワー　22カイ');
INSERT INTO `ms_addresses` VALUES ('2707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区六本木泉ガーデンタワー　23階', '13', '13103', '1066023', '東京都', 'トウキョウト', '港区', 'ミナトク', '六本木', 'ロッポンギ', null, null, '泉ガーデンタワー　23階', 'イズミガーデンタワー　23カイ');
INSERT INTO `ms_addresses` VALUES ('2708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区六本木泉ガーデンタワー　24階', '13', '13103', '1066024', '東京都', 'トウキョウト', '港区', 'ミナトク', '六本木', 'ロッポンギ', null, null, '泉ガーデンタワー　24階', 'イズミガーデンタワー　24カイ');
INSERT INTO `ms_addresses` VALUES ('2709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区六本木泉ガーデンタワー　25階', '13', '13103', '1066025', '東京都', 'トウキョウト', '港区', 'ミナトク', '六本木', 'ロッポンギ', null, null, '泉ガーデンタワー　25階', 'イズミガーデンタワー　25カイ');
INSERT INTO `ms_addresses` VALUES ('2710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区六本木泉ガーデンタワー　26階', '13', '13103', '1066026', '東京都', 'トウキョウト', '港区', 'ミナトク', '六本木', 'ロッポンギ', null, null, '泉ガーデンタワー　26階', 'イズミガーデンタワー　26カイ');
INSERT INTO `ms_addresses` VALUES ('2711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区六本木泉ガーデンタワー　27階', '13', '13103', '1066027', '東京都', 'トウキョウト', '港区', 'ミナトク', '六本木', 'ロッポンギ', null, null, '泉ガーデンタワー　27階', 'イズミガーデンタワー　27カイ');
INSERT INTO `ms_addresses` VALUES ('2712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区六本木泉ガーデンタワー　28階', '13', '13103', '1066028', '東京都', 'トウキョウト', '港区', 'ミナトク', '六本木', 'ロッポンギ', null, null, '泉ガーデンタワー　28階', 'イズミガーデンタワー　28カイ');
INSERT INTO `ms_addresses` VALUES ('2713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区六本木泉ガーデンタワー　29階', '13', '13103', '1066029', '東京都', 'トウキョウト', '港区', 'ミナトク', '六本木', 'ロッポンギ', null, null, '泉ガーデンタワー　29階', 'イズミガーデンタワー　29カイ');
INSERT INTO `ms_addresses` VALUES ('2714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区六本木泉ガーデンタワー　30階', '13', '13103', '1066030', '東京都', 'トウキョウト', '港区', 'ミナトク', '六本木', 'ロッポンギ', null, null, '泉ガーデンタワー　30階', 'イズミガーデンタワー　30カイ');
INSERT INTO `ms_addresses` VALUES ('2715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区六本木泉ガーデンタワー　31階', '13', '13103', '1066031', '東京都', 'トウキョウト', '港区', 'ミナトク', '六本木', 'ロッポンギ', null, null, '泉ガーデンタワー　31階', 'イズミガーデンタワー　31カイ');
INSERT INTO `ms_addresses` VALUES ('2716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区六本木泉ガーデンタワー　32階', '13', '13103', '1066032', '東京都', 'トウキョウト', '港区', 'ミナトク', '六本木', 'ロッポンギ', null, null, '泉ガーデンタワー　32階', 'イズミガーデンタワー　32カイ');
INSERT INTO `ms_addresses` VALUES ('2717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区六本木泉ガーデンタワー　33階', '13', '13103', '1066033', '東京都', 'トウキョウト', '港区', 'ミナトク', '六本木', 'ロッポンギ', null, null, '泉ガーデンタワー　33階', 'イズミガーデンタワー　33カイ');
INSERT INTO `ms_addresses` VALUES ('2718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区六本木泉ガーデンタワー　34階', '13', '13103', '1066034', '東京都', 'トウキョウト', '港区', 'ミナトク', '六本木', 'ロッポンギ', null, null, '泉ガーデンタワー　34階', 'イズミガーデンタワー　34カイ');
INSERT INTO `ms_addresses` VALUES ('2719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区六本木泉ガーデンタワー　35階', '13', '13103', '1066035', '東京都', 'トウキョウト', '港区', 'ミナトク', '六本木', 'ロッポンギ', null, null, '泉ガーデンタワー　35階', 'イズミガーデンタワー　35カイ');
INSERT INTO `ms_addresses` VALUES ('2720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区六本木泉ガーデンタワー　36階', '13', '13103', '1066036', '東京都', 'トウキョウト', '港区', 'ミナトク', '六本木', 'ロッポンギ', null, null, '泉ガーデンタワー　36階', 'イズミガーデンタワー　36カイ');
INSERT INTO `ms_addresses` VALUES ('2721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区六本木泉ガーデンタワー　37階', '13', '13103', '1066037', '東京都', 'トウキョウト', '港区', 'ミナトク', '六本木', 'ロッポンギ', null, null, '泉ガーデンタワー　37階', 'イズミガーデンタワー　37カイ');
INSERT INTO `ms_addresses` VALUES ('2722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区六本木泉ガーデンタワー　38階', '13', '13103', '1066038', '東京都', 'トウキョウト', '港区', 'ミナトク', '六本木', 'ロッポンギ', null, null, '泉ガーデンタワー　38階', 'イズミガーデンタワー　38カイ');
INSERT INTO `ms_addresses` VALUES ('2723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区六本木泉ガーデンタワー　39階', '13', '13103', '1066039', '東京都', 'トウキョウト', '港区', 'ミナトク', '六本木', 'ロッポンギ', null, null, '泉ガーデンタワー　39階', 'イズミガーデンタワー　39カイ');
INSERT INTO `ms_addresses` VALUES ('2724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区六本木泉ガーデンタワー　40階', '13', '13103', '1066040', '東京都', 'トウキョウト', '港区', 'ミナトク', '六本木', 'ロッポンギ', null, null, '泉ガーデンタワー　40階', 'イズミガーデンタワー　40カイ');
INSERT INTO `ms_addresses` VALUES ('2725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区六本木泉ガーデンタワー　41階', '13', '13103', '1066041', '東京都', 'トウキョウト', '港区', 'ミナトク', '六本木', 'ロッポンギ', null, null, '泉ガーデンタワー　41階', 'イズミガーデンタワー　41カイ');
INSERT INTO `ms_addresses` VALUES ('2726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区六本木泉ガーデンタワー　42階', '13', '13103', '1066042', '東京都', 'トウキョウト', '港区', 'ミナトク', '六本木', 'ロッポンギ', null, null, '泉ガーデンタワー　42階', 'イズミガーデンタワー　42カイ');
INSERT INTO `ms_addresses` VALUES ('2727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区六本木泉ガーデンタワー　43階', '13', '13103', '1066043', '東京都', 'トウキョウト', '港区', 'ミナトク', '六本木', 'ロッポンギ', null, null, '泉ガーデンタワー　43階', 'イズミガーデンタワー　43カイ');
INSERT INTO `ms_addresses` VALUES ('2728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区六本木泉ガーデンタワー　44階', '13', '13103', '1066044', '東京都', 'トウキョウト', '港区', 'ミナトク', '六本木', 'ロッポンギ', null, null, '泉ガーデンタワー　44階', 'イズミガーデンタワー　44カイ');
INSERT INTO `ms_addresses` VALUES ('2729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区六本木泉ガーデンタワー　45階', '13', '13103', '1066045', '東京都', 'トウキョウト', '港区', 'ミナトク', '六本木', 'ロッポンギ', null, null, '泉ガーデンタワー　45階', 'イズミガーデンタワー　45カイ');
INSERT INTO `ms_addresses` VALUES ('2732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区六本木泉ガーデンタワー　', '13', '13103', '1066090', '東京都', 'トウキョウト', '港区', 'ミナトク', '六本木', 'ロッポンギ', null, null, '泉ガーデンタワー　', 'イズミガーデンタワー　');
INSERT INTO `ms_addresses` VALUES ('2733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区六本木六本木ヒルズ森タワー　1階', '13', '13103', '1066101', '東京都', 'トウキョウト', '港区', 'ミナトク', '六本木', 'ロッポンギ', null, null, '六本木ヒルズ森タワー　1階', 'ロッポンギヒルズモリタワー　01カイ');
INSERT INTO `ms_addresses` VALUES ('2734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区六本木六本木ヒルズ森タワー　2階', '13', '13103', '1066102', '東京都', 'トウキョウト', '港区', 'ミナトク', '六本木', 'ロッポンギ', null, null, '六本木ヒルズ森タワー　2階', 'ロッポンギヒルズモリタワー　02カイ');
INSERT INTO `ms_addresses` VALUES ('2735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区六本木六本木ヒルズ森タワー　3階', '13', '13103', '1066103', '東京都', 'トウキョウト', '港区', 'ミナトク', '六本木', 'ロッポンギ', null, null, '六本木ヒルズ森タワー　3階', 'ロッポンギヒルズモリタワー　03カイ');
INSERT INTO `ms_addresses` VALUES ('2736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区六本木六本木ヒルズ森タワー　4階', '13', '13103', '1066104', '東京都', 'トウキョウト', '港区', 'ミナトク', '六本木', 'ロッポンギ', null, null, '六本木ヒルズ森タワー　4階', 'ロッポンギヒルズモリタワー　04カイ');
INSERT INTO `ms_addresses` VALUES ('2737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区六本木六本木ヒルズ森タワー　5階', '13', '13103', '1066105', '東京都', 'トウキョウト', '港区', 'ミナトク', '六本木', 'ロッポンギ', null, null, '六本木ヒルズ森タワー　5階', 'ロッポンギヒルズモリタワー　05カイ');
INSERT INTO `ms_addresses` VALUES ('2738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区六本木六本木ヒルズ森タワー　6階', '13', '13103', '1066106', '東京都', 'トウキョウト', '港区', 'ミナトク', '六本木', 'ロッポンギ', null, null, '六本木ヒルズ森タワー　6階', 'ロッポンギヒルズモリタワー　06カイ');
INSERT INTO `ms_addresses` VALUES ('2739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区六本木六本木ヒルズ森タワー　7階', '13', '13103', '1066107', '東京都', 'トウキョウト', '港区', 'ミナトク', '六本木', 'ロッポンギ', null, null, '六本木ヒルズ森タワー　7階', 'ロッポンギヒルズモリタワー　07カイ');
INSERT INTO `ms_addresses` VALUES ('2740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区六本木六本木ヒルズ森タワー　8階', '13', '13103', '1066108', '東京都', 'トウキョウト', '港区', 'ミナトク', '六本木', 'ロッポンギ', null, null, '六本木ヒルズ森タワー　8階', 'ロッポンギヒルズモリタワー　08カイ');
INSERT INTO `ms_addresses` VALUES ('2741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区六本木六本木ヒルズ森タワー　9階', '13', '13103', '1066109', '東京都', 'トウキョウト', '港区', 'ミナトク', '六本木', 'ロッポンギ', null, null, '六本木ヒルズ森タワー　9階', 'ロッポンギヒルズモリタワー　09カイ');
INSERT INTO `ms_addresses` VALUES ('2742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区六本木六本木ヒルズ森タワー　10階', '13', '13103', '1066110', '東京都', 'トウキョウト', '港区', 'ミナトク', '六本木', 'ロッポンギ', null, null, '六本木ヒルズ森タワー　10階', 'ロッポンギヒルズモリタワー　10カイ');
INSERT INTO `ms_addresses` VALUES ('2743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区六本木六本木ヒルズ森タワー　11階', '13', '13103', '1066111', '東京都', 'トウキョウト', '港区', 'ミナトク', '六本木', 'ロッポンギ', null, null, '六本木ヒルズ森タワー　11階', 'ロッポンギヒルズモリタワー　11カイ');
INSERT INTO `ms_addresses` VALUES ('2744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区六本木六本木ヒルズ森タワー　12階', '13', '13103', '1066112', '東京都', 'トウキョウト', '港区', 'ミナトク', '六本木', 'ロッポンギ', null, null, '六本木ヒルズ森タワー　12階', 'ロッポンギヒルズモリタワー　12カイ');
INSERT INTO `ms_addresses` VALUES ('2745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区六本木六本木ヒルズ森タワー　13階', '13', '13103', '1066113', '東京都', 'トウキョウト', '港区', 'ミナトク', '六本木', 'ロッポンギ', null, null, '六本木ヒルズ森タワー　13階', 'ロッポンギヒルズモリタワー　13カイ');
INSERT INTO `ms_addresses` VALUES ('2746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区六本木六本木ヒルズ森タワー　14階', '13', '13103', '1066114', '東京都', 'トウキョウト', '港区', 'ミナトク', '六本木', 'ロッポンギ', null, null, '六本木ヒルズ森タワー　14階', 'ロッポンギヒルズモリタワー　14カイ');
INSERT INTO `ms_addresses` VALUES ('2747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区六本木六本木ヒルズ森タワー　15階', '13', '13103', '1066115', '東京都', 'トウキョウト', '港区', 'ミナトク', '六本木', 'ロッポンギ', null, null, '六本木ヒルズ森タワー　15階', 'ロッポンギヒルズモリタワー　15カイ');
INSERT INTO `ms_addresses` VALUES ('2748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区六本木六本木ヒルズ森タワー　16階', '13', '13103', '1066116', '東京都', 'トウキョウト', '港区', 'ミナトク', '六本木', 'ロッポンギ', null, null, '六本木ヒルズ森タワー　16階', 'ロッポンギヒルズモリタワー　16カイ');
INSERT INTO `ms_addresses` VALUES ('2749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区六本木六本木ヒルズ森タワー　17階', '13', '13103', '1066117', '東京都', 'トウキョウト', '港区', 'ミナトク', '六本木', 'ロッポンギ', null, null, '六本木ヒルズ森タワー　17階', 'ロッポンギヒルズモリタワー　17カイ');
INSERT INTO `ms_addresses` VALUES ('2750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区六本木六本木ヒルズ森タワー　18階', '13', '13103', '1066118', '東京都', 'トウキョウト', '港区', 'ミナトク', '六本木', 'ロッポンギ', null, null, '六本木ヒルズ森タワー　18階', 'ロッポンギヒルズモリタワー　18カイ');
INSERT INTO `ms_addresses` VALUES ('2751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区六本木六本木ヒルズ森タワー　19階', '13', '13103', '1066119', '東京都', 'トウキョウト', '港区', 'ミナトク', '六本木', 'ロッポンギ', null, null, '六本木ヒルズ森タワー　19階', 'ロッポンギヒルズモリタワー　19カイ');
INSERT INTO `ms_addresses` VALUES ('2752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区六本木六本木ヒルズ森タワー　20階', '13', '13103', '1066120', '東京都', 'トウキョウト', '港区', 'ミナトク', '六本木', 'ロッポンギ', null, null, '六本木ヒルズ森タワー　20階', 'ロッポンギヒルズモリタワー　20カイ');
INSERT INTO `ms_addresses` VALUES ('2753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区六本木六本木ヒルズ森タワー　21階', '13', '13103', '1066121', '東京都', 'トウキョウト', '港区', 'ミナトク', '六本木', 'ロッポンギ', null, null, '六本木ヒルズ森タワー　21階', 'ロッポンギヒルズモリタワー　21カイ');
INSERT INTO `ms_addresses` VALUES ('2754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区六本木六本木ヒルズ森タワー　22階', '13', '13103', '1066122', '東京都', 'トウキョウト', '港区', 'ミナトク', '六本木', 'ロッポンギ', null, null, '六本木ヒルズ森タワー　22階', 'ロッポンギヒルズモリタワー　22カイ');
INSERT INTO `ms_addresses` VALUES ('2755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区六本木六本木ヒルズ森タワー　23階', '13', '13103', '1066123', '東京都', 'トウキョウト', '港区', 'ミナトク', '六本木', 'ロッポンギ', null, null, '六本木ヒルズ森タワー　23階', 'ロッポンギヒルズモリタワー　23カイ');
INSERT INTO `ms_addresses` VALUES ('2756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区六本木六本木ヒルズ森タワー　24階', '13', '13103', '1066124', '東京都', 'トウキョウト', '港区', 'ミナトク', '六本木', 'ロッポンギ', null, null, '六本木ヒルズ森タワー　24階', 'ロッポンギヒルズモリタワー　24カイ');
INSERT INTO `ms_addresses` VALUES ('2757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区六本木六本木ヒルズ森タワー　25階', '13', '13103', '1066125', '東京都', 'トウキョウト', '港区', 'ミナトク', '六本木', 'ロッポンギ', null, null, '六本木ヒルズ森タワー　25階', 'ロッポンギヒルズモリタワー　25カイ');
INSERT INTO `ms_addresses` VALUES ('2758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区六本木六本木ヒルズ森タワー　26階', '13', '13103', '1066126', '東京都', 'トウキョウト', '港区', 'ミナトク', '六本木', 'ロッポンギ', null, null, '六本木ヒルズ森タワー　26階', 'ロッポンギヒルズモリタワー　26カイ');
INSERT INTO `ms_addresses` VALUES ('2759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区六本木六本木ヒルズ森タワー　27階', '13', '13103', '1066127', '東京都', 'トウキョウト', '港区', 'ミナトク', '六本木', 'ロッポンギ', null, null, '六本木ヒルズ森タワー　27階', 'ロッポンギヒルズモリタワー　27カイ');
INSERT INTO `ms_addresses` VALUES ('2760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区六本木六本木ヒルズ森タワー　28階', '13', '13103', '1066128', '東京都', 'トウキョウト', '港区', 'ミナトク', '六本木', 'ロッポンギ', null, null, '六本木ヒルズ森タワー　28階', 'ロッポンギヒルズモリタワー　28カイ');
INSERT INTO `ms_addresses` VALUES ('2761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区六本木六本木ヒルズ森タワー　29階', '13', '13103', '1066129', '東京都', 'トウキョウト', '港区', 'ミナトク', '六本木', 'ロッポンギ', null, null, '六本木ヒルズ森タワー　29階', 'ロッポンギヒルズモリタワー　29カイ');
INSERT INTO `ms_addresses` VALUES ('2762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区六本木六本木ヒルズ森タワー　30階', '13', '13103', '1066130', '東京都', 'トウキョウト', '港区', 'ミナトク', '六本木', 'ロッポンギ', null, null, '六本木ヒルズ森タワー　30階', 'ロッポンギヒルズモリタワー　30カイ');
INSERT INTO `ms_addresses` VALUES ('2763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区六本木六本木ヒルズ森タワー　31階', '13', '13103', '1066131', '東京都', 'トウキョウト', '港区', 'ミナトク', '六本木', 'ロッポンギ', null, null, '六本木ヒルズ森タワー　31階', 'ロッポンギヒルズモリタワー　31カイ');
INSERT INTO `ms_addresses` VALUES ('2764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区六本木六本木ヒルズ森タワー　32階', '13', '13103', '1066132', '東京都', 'トウキョウト', '港区', 'ミナトク', '六本木', 'ロッポンギ', null, null, '六本木ヒルズ森タワー　32階', 'ロッポンギヒルズモリタワー　32カイ');
INSERT INTO `ms_addresses` VALUES ('2765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区六本木六本木ヒルズ森タワー　33階', '13', '13103', '1066133', '東京都', 'トウキョウト', '港区', 'ミナトク', '六本木', 'ロッポンギ', null, null, '六本木ヒルズ森タワー　33階', 'ロッポンギヒルズモリタワー　33カイ');
INSERT INTO `ms_addresses` VALUES ('2766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区六本木六本木ヒルズ森タワー　34階', '13', '13103', '1066134', '東京都', 'トウキョウト', '港区', 'ミナトク', '六本木', 'ロッポンギ', null, null, '六本木ヒルズ森タワー　34階', 'ロッポンギヒルズモリタワー　34カイ');
INSERT INTO `ms_addresses` VALUES ('2767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区六本木六本木ヒルズ森タワー　35階', '13', '13103', '1066135', '東京都', 'トウキョウト', '港区', 'ミナトク', '六本木', 'ロッポンギ', null, null, '六本木ヒルズ森タワー　35階', 'ロッポンギヒルズモリタワー　35カイ');
INSERT INTO `ms_addresses` VALUES ('2768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区六本木六本木ヒルズ森タワー　36階', '13', '13103', '1066136', '東京都', 'トウキョウト', '港区', 'ミナトク', '六本木', 'ロッポンギ', null, null, '六本木ヒルズ森タワー　36階', 'ロッポンギヒルズモリタワー　36カイ');
INSERT INTO `ms_addresses` VALUES ('2769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区六本木六本木ヒルズ森タワー　37階', '13', '13103', '1066137', '東京都', 'トウキョウト', '港区', 'ミナトク', '六本木', 'ロッポンギ', null, null, '六本木ヒルズ森タワー　37階', 'ロッポンギヒルズモリタワー　37カイ');
INSERT INTO `ms_addresses` VALUES ('2770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区六本木六本木ヒルズ森タワー　38階', '13', '13103', '1066138', '東京都', 'トウキョウト', '港区', 'ミナトク', '六本木', 'ロッポンギ', null, null, '六本木ヒルズ森タワー　38階', 'ロッポンギヒルズモリタワー　38カイ');
INSERT INTO `ms_addresses` VALUES ('2771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区六本木六本木ヒルズ森タワー　39階', '13', '13103', '1066139', '東京都', 'トウキョウト', '港区', 'ミナトク', '六本木', 'ロッポンギ', null, null, '六本木ヒルズ森タワー　39階', 'ロッポンギヒルズモリタワー　39カイ');
INSERT INTO `ms_addresses` VALUES ('2772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区六本木六本木ヒルズ森タワー　40階', '13', '13103', '1066140', '東京都', 'トウキョウト', '港区', 'ミナトク', '六本木', 'ロッポンギ', null, null, '六本木ヒルズ森タワー　40階', 'ロッポンギヒルズモリタワー　40カイ');
INSERT INTO `ms_addresses` VALUES ('2773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区六本木六本木ヒルズ森タワー　41階', '13', '13103', '1066141', '東京都', 'トウキョウト', '港区', 'ミナトク', '六本木', 'ロッポンギ', null, null, '六本木ヒルズ森タワー　41階', 'ロッポンギヒルズモリタワー　41カイ');
INSERT INTO `ms_addresses` VALUES ('2774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区六本木六本木ヒルズ森タワー　42階', '13', '13103', '1066142', '東京都', 'トウキョウト', '港区', 'ミナトク', '六本木', 'ロッポンギ', null, null, '六本木ヒルズ森タワー　42階', 'ロッポンギヒルズモリタワー　42カイ');
INSERT INTO `ms_addresses` VALUES ('2775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区六本木六本木ヒルズ森タワー　43階', '13', '13103', '1066143', '東京都', 'トウキョウト', '港区', 'ミナトク', '六本木', 'ロッポンギ', null, null, '六本木ヒルズ森タワー　43階', 'ロッポンギヒルズモリタワー　43カイ');
INSERT INTO `ms_addresses` VALUES ('2776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区六本木六本木ヒルズ森タワー　44階', '13', '13103', '1066144', '東京都', 'トウキョウト', '港区', 'ミナトク', '六本木', 'ロッポンギ', null, null, '六本木ヒルズ森タワー　44階', 'ロッポンギヒルズモリタワー　44カイ');
INSERT INTO `ms_addresses` VALUES ('2777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区六本木六本木ヒルズ森タワー　45階', '13', '13103', '1066145', '東京都', 'トウキョウト', '港区', 'ミナトク', '六本木', 'ロッポンギ', null, null, '六本木ヒルズ森タワー　45階', 'ロッポンギヒルズモリタワー　45カイ');
INSERT INTO `ms_addresses` VALUES ('2778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区六本木六本木ヒルズ森タワー　46階', '13', '13103', '1066146', '東京都', 'トウキョウト', '港区', 'ミナトク', '六本木', 'ロッポンギ', null, null, '六本木ヒルズ森タワー　46階', 'ロッポンギヒルズモリタワー　46カイ');
INSERT INTO `ms_addresses` VALUES ('2779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区六本木六本木ヒルズ森タワー　47階', '13', '13103', '1066147', '東京都', 'トウキョウト', '港区', 'ミナトク', '六本木', 'ロッポンギ', null, null, '六本木ヒルズ森タワー　47階', 'ロッポンギヒルズモリタワー　47カイ'), ('2780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区六本木六本木ヒルズ森タワー　48階', '13', '13103', '1066148', '東京都', 'トウキョウト', '港区', 'ミナトク', '六本木', 'ロッポンギ', null, null, '六本木ヒルズ森タワー　48階', 'ロッポンギヒルズモリタワー　48カイ'), ('2781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区六本木六本木ヒルズ森タワー　49階', '13', '13103', '1066149', '東京都', 'トウキョウト', '港区', 'ミナトク', '六本木', 'ロッポンギ', null, null, '六本木ヒルズ森タワー　49階', 'ロッポンギヒルズモリタワー　49カイ');
INSERT INTO `ms_addresses` VALUES ('2782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区六本木六本木ヒルズ森タワー　50階', '13', '13103', '1066150', '東京都', 'トウキョウト', '港区', 'ミナトク', '六本木', 'ロッポンギ', null, null, '六本木ヒルズ森タワー　50階', 'ロッポンギヒルズモリタワー　50カイ');
INSERT INTO `ms_addresses` VALUES ('2783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区六本木六本木ヒルズ森タワー　51階', '13', '13103', '1066151', '東京都', 'トウキョウト', '港区', 'ミナトク', '六本木', 'ロッポンギ', null, null, '六本木ヒルズ森タワー　51階', 'ロッポンギヒルズモリタワー　51カイ');
INSERT INTO `ms_addresses` VALUES ('2784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区六本木六本木ヒルズ森タワー　52階', '13', '13103', '1066152', '東京都', 'トウキョウト', '港区', 'ミナトク', '六本木', 'ロッポンギ', null, null, '六本木ヒルズ森タワー　52階', 'ロッポンギヒルズモリタワー　52カイ');
INSERT INTO `ms_addresses` VALUES ('2785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区六本木六本木ヒルズ森タワー　53階', '13', '13103', '1066153', '東京都', 'トウキョウト', '港区', 'ミナトク', '六本木', 'ロッポンギ', null, null, '六本木ヒルズ森タワー　53階', 'ロッポンギヒルズモリタワー　53カイ');
INSERT INTO `ms_addresses` VALUES ('2786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区六本木六本木ヒルズ森タワー　54階', '13', '13103', '1066154', '東京都', 'トウキョウト', '港区', 'ミナトク', '六本木', 'ロッポンギ', null, null, '六本木ヒルズ森タワー　54階', 'ロッポンギヒルズモリタワー　54カイ');
INSERT INTO `ms_addresses` VALUES ('2789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区六本木六本木ヒルズ森タワー　', '13', '13103', '1066190', '東京都', 'トウキョウト', '港区', 'ミナトク', '六本木', 'ロッポンギ', null, null, '六本木ヒルズ森タワー　', 'ロッポンギヒルズモリタワー　');
INSERT INTO `ms_addresses` VALUES ('2863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区元赤坂', '13', '13103', '1070051', '東京都', 'トウキョウト', '港区', 'ミナトク', '元赤坂', 'モトアカサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('2864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂', '13', '13103', '1070052', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('2865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区北青山', '13', '13103', '1070061', '東京都', 'トウキョウト', '港区', 'ミナトク', '北青山', 'キタアオヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('2866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区南青山', '13', '13103', '1070062', '東京都', 'トウキョウト', '港区', 'ミナトク', '南青山', 'ミナミアオヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('2867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂アークヒルズ・アーク森ビル　1階', '13', '13103', '1076001', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂アークヒルズ・アーク森ビル　1階', 'アカサカアークヒルズ・アークモリビル　01カイ');
INSERT INTO `ms_addresses` VALUES ('2868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂アークヒルズ・アーク森ビル　2階', '13', '13103', '1076002', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂アークヒルズ・アーク森ビル　2階', 'アカサカアークヒルズ・アークモリビル　02カイ');
INSERT INTO `ms_addresses` VALUES ('2869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂アークヒルズ・アーク森ビル　3階', '13', '13103', '1076003', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂アークヒルズ・アーク森ビル　3階', 'アカサカアークヒルズ・アークモリビル　03カイ');
INSERT INTO `ms_addresses` VALUES ('2870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂アークヒルズ・アーク森ビル　4階', '13', '13103', '1076004', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂アークヒルズ・アーク森ビル　4階', 'アカサカアークヒルズ・アークモリビル　04カイ');
INSERT INTO `ms_addresses` VALUES ('2871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂アークヒルズ・アーク森ビル　5階', '13', '13103', '1076005', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂アークヒルズ・アーク森ビル　5階', 'アカサカアークヒルズ・アークモリビル　05カイ');
INSERT INTO `ms_addresses` VALUES ('2872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂アークヒルズ・アーク森ビル　6階', '13', '13103', '1076006', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂アークヒルズ・アーク森ビル　6階', 'アカサカアークヒルズ・アークモリビル　06カイ');
INSERT INTO `ms_addresses` VALUES ('2873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂アークヒルズ・アーク森ビル　7階', '13', '13103', '1076007', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂アークヒルズ・アーク森ビル　7階', 'アカサカアークヒルズ・アークモリビル　07カイ');
INSERT INTO `ms_addresses` VALUES ('2874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂アークヒルズ・アーク森ビル　8階', '13', '13103', '1076008', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂アークヒルズ・アーク森ビル　8階', 'アカサカアークヒルズ・アークモリビル　08カイ');
INSERT INTO `ms_addresses` VALUES ('2875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂アークヒルズ・アーク森ビル　9階', '13', '13103', '1076009', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂アークヒルズ・アーク森ビル　9階', 'アカサカアークヒルズ・アークモリビル　09カイ');
INSERT INTO `ms_addresses` VALUES ('2876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂アークヒルズ・アーク森ビル　10階', '13', '13103', '1076010', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂アークヒルズ・アーク森ビル　10階', 'アカサカアークヒルズ・アークモリビル　10カイ');
INSERT INTO `ms_addresses` VALUES ('2877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂アークヒルズ・アーク森ビル　11階', '13', '13103', '1076011', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂アークヒルズ・アーク森ビル　11階', 'アカサカアークヒルズ・アークモリビル　11カイ');
INSERT INTO `ms_addresses` VALUES ('2878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂アークヒルズ・アーク森ビル　12階', '13', '13103', '1076012', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂アークヒルズ・アーク森ビル　12階', 'アカサカアークヒルズ・アークモリビル　12カイ');
INSERT INTO `ms_addresses` VALUES ('2879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂アークヒルズ・アーク森ビル　13階', '13', '13103', '1076013', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂アークヒルズ・アーク森ビル　13階', 'アカサカアークヒルズ・アークモリビル　13カイ');
INSERT INTO `ms_addresses` VALUES ('2880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂アークヒルズ・アーク森ビル　14階', '13', '13103', '1076014', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂アークヒルズ・アーク森ビル　14階', 'アカサカアークヒルズ・アークモリビル　14カイ');
INSERT INTO `ms_addresses` VALUES ('2881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂アークヒルズ・アーク森ビル　15階', '13', '13103', '1076015', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂アークヒルズ・アーク森ビル　15階', 'アカサカアークヒルズ・アークモリビル　15カイ');
INSERT INTO `ms_addresses` VALUES ('2882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂アークヒルズ・アーク森ビル　16階', '13', '13103', '1076016', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂アークヒルズ・アーク森ビル　16階', 'アカサカアークヒルズ・アークモリビル　16カイ');
INSERT INTO `ms_addresses` VALUES ('2883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂アークヒルズ・アーク森ビル　17階', '13', '13103', '1076017', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂アークヒルズ・アーク森ビル　17階', 'アカサカアークヒルズ・アークモリビル　17カイ');
INSERT INTO `ms_addresses` VALUES ('2884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂アークヒルズ・アーク森ビル　18階', '13', '13103', '1076018', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂アークヒルズ・アーク森ビル　18階', 'アカサカアークヒルズ・アークモリビル　18カイ');
INSERT INTO `ms_addresses` VALUES ('2885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂アークヒルズ・アーク森ビル　19階', '13', '13103', '1076019', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂アークヒルズ・アーク森ビル　19階', 'アカサカアークヒルズ・アークモリビル　19カイ');
INSERT INTO `ms_addresses` VALUES ('2886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂アークヒルズ・アーク森ビル　20階', '13', '13103', '1076020', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂アークヒルズ・アーク森ビル　20階', 'アカサカアークヒルズ・アークモリビル　20カイ');
INSERT INTO `ms_addresses` VALUES ('2887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂アークヒルズ・アーク森ビル　21階', '13', '13103', '1076021', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂アークヒルズ・アーク森ビル　21階', 'アカサカアークヒルズ・アークモリビル　21カイ');
INSERT INTO `ms_addresses` VALUES ('2888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂アークヒルズ・アーク森ビル　22階', '13', '13103', '1076022', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂アークヒルズ・アーク森ビル　22階', 'アカサカアークヒルズ・アークモリビル　22カイ');
INSERT INTO `ms_addresses` VALUES ('2889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂アークヒルズ・アーク森ビル　23階', '13', '13103', '1076023', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂アークヒルズ・アーク森ビル　23階', 'アカサカアークヒルズ・アークモリビル　23カイ');
INSERT INTO `ms_addresses` VALUES ('2890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂アークヒルズ・アーク森ビル　24階', '13', '13103', '1076024', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂アークヒルズ・アーク森ビル　24階', 'アカサカアークヒルズ・アークモリビル　24カイ');
INSERT INTO `ms_addresses` VALUES ('2891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂アークヒルズ・アーク森ビル　25階', '13', '13103', '1076025', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂アークヒルズ・アーク森ビル　25階', 'アカサカアークヒルズ・アークモリビル　25カイ');
INSERT INTO `ms_addresses` VALUES ('2892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂アークヒルズ・アーク森ビル　26階', '13', '13103', '1076026', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂アークヒルズ・アーク森ビル　26階', 'アカサカアークヒルズ・アークモリビル　26カイ');
INSERT INTO `ms_addresses` VALUES ('2893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂アークヒルズ・アーク森ビル　27階', '13', '13103', '1076027', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂アークヒルズ・アーク森ビル　27階', 'アカサカアークヒルズ・アークモリビル　27カイ');
INSERT INTO `ms_addresses` VALUES ('2894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂アークヒルズ・アーク森ビル　28階', '13', '13103', '1076028', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂アークヒルズ・アーク森ビル　28階', 'アカサカアークヒルズ・アークモリビル　28カイ');
INSERT INTO `ms_addresses` VALUES ('2895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂アークヒルズ・アーク森ビル　29階', '13', '13103', '1076029', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂アークヒルズ・アーク森ビル　29階', 'アカサカアークヒルズ・アークモリビル　29カイ');
INSERT INTO `ms_addresses` VALUES ('2896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂アークヒルズ・アーク森ビル　30階', '13', '13103', '1076030', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂アークヒルズ・アーク森ビル　30階', 'アカサカアークヒルズ・アークモリビル　30カイ');
INSERT INTO `ms_addresses` VALUES ('2897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂アークヒルズ・アーク森ビル　31階', '13', '13103', '1076031', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂アークヒルズ・アーク森ビル　31階', 'アカサカアークヒルズ・アークモリビル　31カイ');
INSERT INTO `ms_addresses` VALUES ('2898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂アークヒルズ・アーク森ビル　32階', '13', '13103', '1076032', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂アークヒルズ・アーク森ビル　32階', 'アカサカアークヒルズ・アークモリビル　32カイ');
INSERT INTO `ms_addresses` VALUES ('2899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂アークヒルズ・アーク森ビル　33階', '13', '13103', '1076033', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂アークヒルズ・アーク森ビル　33階', 'アカサカアークヒルズ・アークモリビル　33カイ');
INSERT INTO `ms_addresses` VALUES ('2900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂アークヒルズ・アーク森ビル　34階', '13', '13103', '1076034', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂アークヒルズ・アーク森ビル　34階', 'アカサカアークヒルズ・アークモリビル　34カイ');
INSERT INTO `ms_addresses` VALUES ('2901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂アークヒルズ・アーク森ビル　35階', '13', '13103', '1076035', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂アークヒルズ・アーク森ビル　35階', 'アカサカアークヒルズ・アークモリビル　35カイ');
INSERT INTO `ms_addresses` VALUES ('2902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂アークヒルズ・アーク森ビル　36階', '13', '13103', '1076036', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂アークヒルズ・アーク森ビル　36階', 'アカサカアークヒルズ・アークモリビル　36カイ');
INSERT INTO `ms_addresses` VALUES ('2903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂アークヒルズ・アーク森ビル　37階', '13', '13103', '1076037', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂アークヒルズ・アーク森ビル　37階', 'アカサカアークヒルズ・アークモリビル　37カイ');
INSERT INTO `ms_addresses` VALUES ('2904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂アークヒルズ・アーク森ビル　', '13', '13103', '1076090', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂アークヒルズ・アーク森ビル　', 'アカサカアークヒルズ・アークモリビル　');
INSERT INTO `ms_addresses` VALUES ('2905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂パークビル　1階', '13', '13103', '1076101', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂パークビル　1階', 'アカサカパークビル　01カイ');
INSERT INTO `ms_addresses` VALUES ('2906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂パークビル　2階', '13', '13103', '1076102', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂パークビル　2階', 'アカサカパークビル　02カイ');
INSERT INTO `ms_addresses` VALUES ('2907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂パークビル　3階', '13', '13103', '1076103', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂パークビル　3階', 'アカサカパークビル　03カイ');
INSERT INTO `ms_addresses` VALUES ('2908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂パークビル　4階', '13', '13103', '1076104', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂パークビル　4階', 'アカサカパークビル　04カイ');
INSERT INTO `ms_addresses` VALUES ('2909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂パークビル　5階', '13', '13103', '1076105', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂パークビル　5階', 'アカサカパークビル　05カイ');
INSERT INTO `ms_addresses` VALUES ('2910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂パークビル　6階', '13', '13103', '1076106', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂パークビル　6階', 'アカサカパークビル　06カイ');
INSERT INTO `ms_addresses` VALUES ('2911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂パークビル　7階', '13', '13103', '1076107', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂パークビル　7階', 'アカサカパークビル　07カイ');
INSERT INTO `ms_addresses` VALUES ('2912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂パークビル　8階', '13', '13103', '1076108', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂パークビル　8階', 'アカサカパークビル　08カイ');
INSERT INTO `ms_addresses` VALUES ('2913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂パークビル　9階', '13', '13103', '1076109', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂パークビル　9階', 'アカサカパークビル　09カイ');
INSERT INTO `ms_addresses` VALUES ('2914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂パークビル　10階', '13', '13103', '1076110', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂パークビル　10階', 'アカサカパークビル　10カイ');
INSERT INTO `ms_addresses` VALUES ('2915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂パークビル　11階', '13', '13103', '1076111', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂パークビル　11階', 'アカサカパークビル　11カイ');
INSERT INTO `ms_addresses` VALUES ('2916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂パークビル　12階', '13', '13103', '1076112', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂パークビル　12階', 'アカサカパークビル　12カイ');
INSERT INTO `ms_addresses` VALUES ('2917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂パークビル　13階', '13', '13103', '1076113', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂パークビル　13階', 'アカサカパークビル　13カイ');
INSERT INTO `ms_addresses` VALUES ('2918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂パークビル　14階', '13', '13103', '1076114', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂パークビル　14階', 'アカサカパークビル　14カイ');
INSERT INTO `ms_addresses` VALUES ('2919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂パークビル　15階', '13', '13103', '1076115', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂パークビル　15階', 'アカサカパークビル　15カイ');
INSERT INTO `ms_addresses` VALUES ('2920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂パークビル　16階', '13', '13103', '1076116', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂パークビル　16階', 'アカサカパークビル　16カイ');
INSERT INTO `ms_addresses` VALUES ('2921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂パークビル　17階', '13', '13103', '1076117', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂パークビル　17階', 'アカサカパークビル　17カイ');
INSERT INTO `ms_addresses` VALUES ('2922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂パークビル　18階', '13', '13103', '1076118', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂パークビル　18階', 'アカサカパークビル　18カイ');
INSERT INTO `ms_addresses` VALUES ('2923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂パークビル　19階', '13', '13103', '1076119', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂パークビル　19階', 'アカサカパークビル　19カイ');
INSERT INTO `ms_addresses` VALUES ('2924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂パークビル　20階', '13', '13103', '1076120', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂パークビル　20階', 'アカサカパークビル　20カイ');
INSERT INTO `ms_addresses` VALUES ('2925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂パークビル　21階', '13', '13103', '1076121', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂パークビル　21階', 'アカサカパークビル　21カイ');
INSERT INTO `ms_addresses` VALUES ('2926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂パークビル　22階', '13', '13103', '1076122', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂パークビル　22階', 'アカサカパークビル　22カイ');
INSERT INTO `ms_addresses` VALUES ('2927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂パークビル　23階', '13', '13103', '1076123', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂パークビル　23階', 'アカサカパークビル　23カイ');
INSERT INTO `ms_addresses` VALUES ('2928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂パークビル　24階', '13', '13103', '1076124', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂パークビル　24階', 'アカサカパークビル　24カイ');
INSERT INTO `ms_addresses` VALUES ('2929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂パークビル　25階', '13', '13103', '1076125', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂パークビル　25階', 'アカサカパークビル　25カイ');
INSERT INTO `ms_addresses` VALUES ('2930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂パークビル　26階', '13', '13103', '1076126', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂パークビル　26階', 'アカサカパークビル　26カイ');
INSERT INTO `ms_addresses` VALUES ('2931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂パークビル　27階', '13', '13103', '1076127', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂パークビル　27階', 'アカサカパークビル　27カイ');
INSERT INTO `ms_addresses` VALUES ('2932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂パークビル　28階', '13', '13103', '1076128', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂パークビル　28階', 'アカサカパークビル　28カイ');
INSERT INTO `ms_addresses` VALUES ('2933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂パークビル　29階', '13', '13103', '1076129', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂パークビル　29階', 'アカサカパークビル　29カイ');
INSERT INTO `ms_addresses` VALUES ('2934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂パークビル　30階', '13', '13103', '1076130', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂パークビル　30階', 'アカサカパークビル　30カイ');
INSERT INTO `ms_addresses` VALUES ('2935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂パークビル　', '13', '13103', '1076190', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂パークビル　', 'アカサカパークビル　');
INSERT INTO `ms_addresses` VALUES ('2936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂ミッドタウン・タワー　1階', '13', '13103', '1076201', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, 'ミッドタウン・タワー　1階', 'ミッドタウン・タワー　01カイ');
INSERT INTO `ms_addresses` VALUES ('2937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂ミッドタウン・タワー　2階', '13', '13103', '1076202', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, 'ミッドタウン・タワー　2階', 'ミッドタウン・タワー　02カイ');
INSERT INTO `ms_addresses` VALUES ('2938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂ミッドタウン・タワー　3階', '13', '13103', '1076203', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, 'ミッドタウン・タワー　3階', 'ミッドタウン・タワー　03カイ');
INSERT INTO `ms_addresses` VALUES ('2939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂ミッドタウン・タワー　4階', '13', '13103', '1076204', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, 'ミッドタウン・タワー　4階', 'ミッドタウン・タワー　04カイ');
INSERT INTO `ms_addresses` VALUES ('2940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂ミッドタウン・タワー　5階', '13', '13103', '1076205', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, 'ミッドタウン・タワー　5階', 'ミッドタウン・タワー　05カイ');
INSERT INTO `ms_addresses` VALUES ('2941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂ミッドタウン・タワー　6階', '13', '13103', '1076206', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, 'ミッドタウン・タワー　6階', 'ミッドタウン・タワー　06カイ');
INSERT INTO `ms_addresses` VALUES ('2942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂ミッドタウン・タワー　7階', '13', '13103', '1076207', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, 'ミッドタウン・タワー　7階', 'ミッドタウン・タワー　07カイ');
INSERT INTO `ms_addresses` VALUES ('2943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂ミッドタウン・タワー　8階', '13', '13103', '1076208', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, 'ミッドタウン・タワー　8階', 'ミッドタウン・タワー　08カイ');
INSERT INTO `ms_addresses` VALUES ('2944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂ミッドタウン・タワー　9階', '13', '13103', '1076209', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, 'ミッドタウン・タワー　9階', 'ミッドタウン・タワー　09カイ');
INSERT INTO `ms_addresses` VALUES ('2945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂ミッドタウン・タワー　10階', '13', '13103', '1076210', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, 'ミッドタウン・タワー　10階', 'ミッドタウン・タワー　10カイ');
INSERT INTO `ms_addresses` VALUES ('2946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂ミッドタウン・タワー　11階', '13', '13103', '1076211', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, 'ミッドタウン・タワー　11階', 'ミッドタウン・タワー　11カイ');
INSERT INTO `ms_addresses` VALUES ('2947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂ミッドタウン・タワー　12階', '13', '13103', '1076212', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, 'ミッドタウン・タワー　12階', 'ミッドタウン・タワー　12カイ');
INSERT INTO `ms_addresses` VALUES ('2948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂ミッドタウン・タワー　13階', '13', '13103', '1076213', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, 'ミッドタウン・タワー　13階', 'ミッドタウン・タワー　13カイ');
INSERT INTO `ms_addresses` VALUES ('2949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂ミッドタウン・タワー　14階', '13', '13103', '1076214', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, 'ミッドタウン・タワー　14階', 'ミッドタウン・タワー　14カイ');
INSERT INTO `ms_addresses` VALUES ('2950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂ミッドタウン・タワー　15階', '13', '13103', '1076215', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, 'ミッドタウン・タワー　15階', 'ミッドタウン・タワー　15カイ');
INSERT INTO `ms_addresses` VALUES ('2951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂ミッドタウン・タワー　16階', '13', '13103', '1076216', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, 'ミッドタウン・タワー　16階', 'ミッドタウン・タワー　16カイ');
INSERT INTO `ms_addresses` VALUES ('2952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂ミッドタウン・タワー　17階', '13', '13103', '1076217', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, 'ミッドタウン・タワー　17階', 'ミッドタウン・タワー　17カイ');
INSERT INTO `ms_addresses` VALUES ('2953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂ミッドタウン・タワー　18階', '13', '13103', '1076218', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, 'ミッドタウン・タワー　18階', 'ミッドタウン・タワー　18カイ');
INSERT INTO `ms_addresses` VALUES ('2954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂ミッドタウン・タワー　19階', '13', '13103', '1076219', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, 'ミッドタウン・タワー　19階', 'ミッドタウン・タワー　19カイ');
INSERT INTO `ms_addresses` VALUES ('2955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂ミッドタウン・タワー　20階', '13', '13103', '1076220', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, 'ミッドタウン・タワー　20階', 'ミッドタウン・タワー　20カイ');
INSERT INTO `ms_addresses` VALUES ('2956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂ミッドタウン・タワー　21階', '13', '13103', '1076221', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, 'ミッドタウン・タワー　21階', 'ミッドタウン・タワー　21カイ');
INSERT INTO `ms_addresses` VALUES ('2957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂ミッドタウン・タワー　22階', '13', '13103', '1076222', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, 'ミッドタウン・タワー　22階', 'ミッドタウン・タワー　22カイ');
INSERT INTO `ms_addresses` VALUES ('2958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂ミッドタウン・タワー　23階', '13', '13103', '1076223', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, 'ミッドタウン・タワー　23階', 'ミッドタウン・タワー　23カイ');
INSERT INTO `ms_addresses` VALUES ('2959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂ミッドタウン・タワー　24階', '13', '13103', '1076224', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, 'ミッドタウン・タワー　24階', 'ミッドタウン・タワー　24カイ');
INSERT INTO `ms_addresses` VALUES ('2960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂ミッドタウン・タワー　25階', '13', '13103', '1076225', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, 'ミッドタウン・タワー　25階', 'ミッドタウン・タワー　25カイ');
INSERT INTO `ms_addresses` VALUES ('2961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂ミッドタウン・タワー　26階', '13', '13103', '1076226', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, 'ミッドタウン・タワー　26階', 'ミッドタウン・タワー　26カイ');
INSERT INTO `ms_addresses` VALUES ('2962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂ミッドタウン・タワー　27階', '13', '13103', '1076227', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, 'ミッドタウン・タワー　27階', 'ミッドタウン・タワー　27カイ');
INSERT INTO `ms_addresses` VALUES ('2963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂ミッドタウン・タワー　28階', '13', '13103', '1076228', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, 'ミッドタウン・タワー　28階', 'ミッドタウン・タワー　28カイ');
INSERT INTO `ms_addresses` VALUES ('2964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂ミッドタウン・タワー　29階', '13', '13103', '1076229', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, 'ミッドタウン・タワー　29階', 'ミッドタウン・タワー　29カイ');
INSERT INTO `ms_addresses` VALUES ('2965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂ミッドタウン・タワー　30階', '13', '13103', '1076230', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, 'ミッドタウン・タワー　30階', 'ミッドタウン・タワー　30カイ');
INSERT INTO `ms_addresses` VALUES ('2966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂ミッドタウン・タワー　31階', '13', '13103', '1076231', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, 'ミッドタウン・タワー　31階', 'ミッドタウン・タワー　31カイ');
INSERT INTO `ms_addresses` VALUES ('2967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂ミッドタウン・タワー　32階', '13', '13103', '1076232', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, 'ミッドタウン・タワー　32階', 'ミッドタウン・タワー　32カイ');
INSERT INTO `ms_addresses` VALUES ('2968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂ミッドタウン・タワー　33階', '13', '13103', '1076233', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, 'ミッドタウン・タワー　33階', 'ミッドタウン・タワー　33カイ');
INSERT INTO `ms_addresses` VALUES ('2969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂ミッドタウン・タワー　34階', '13', '13103', '1076234', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, 'ミッドタウン・タワー　34階', 'ミッドタウン・タワー　34カイ');
INSERT INTO `ms_addresses` VALUES ('2970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂ミッドタウン・タワー　35階', '13', '13103', '1076235', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, 'ミッドタウン・タワー　35階', 'ミッドタウン・タワー　35カイ');
INSERT INTO `ms_addresses` VALUES ('2971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂ミッドタウン・タワー　36階', '13', '13103', '1076236', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, 'ミッドタウン・タワー　36階', 'ミッドタウン・タワー　36カイ');
INSERT INTO `ms_addresses` VALUES ('2972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂ミッドタウン・タワー　37階', '13', '13103', '1076237', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, 'ミッドタウン・タワー　37階', 'ミッドタウン・タワー　37カイ');
INSERT INTO `ms_addresses` VALUES ('2973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂ミッドタウン・タワー　38階', '13', '13103', '1076238', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, 'ミッドタウン・タワー　38階', 'ミッドタウン・タワー　38カイ');
INSERT INTO `ms_addresses` VALUES ('2974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂ミッドタウン・タワー　39階', '13', '13103', '1076239', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, 'ミッドタウン・タワー　39階', 'ミッドタウン・タワー　39カイ');
INSERT INTO `ms_addresses` VALUES ('2975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂ミッドタウン・タワー　40階', '13', '13103', '1076240', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, 'ミッドタウン・タワー　40階', 'ミッドタウン・タワー　40カイ');
INSERT INTO `ms_addresses` VALUES ('2976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂ミッドタウン・タワー　41階', '13', '13103', '1076241', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, 'ミッドタウン・タワー　41階', 'ミッドタウン・タワー　41カイ');
INSERT INTO `ms_addresses` VALUES ('2977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂ミッドタウン・タワー　42階', '13', '13103', '1076242', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, 'ミッドタウン・タワー　42階', 'ミッドタウン・タワー　42カイ');
INSERT INTO `ms_addresses` VALUES ('2978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂ミッドタウン・タワー　43階', '13', '13103', '1076243', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, 'ミッドタウン・タワー　43階', 'ミッドタウン・タワー　43カイ');
INSERT INTO `ms_addresses` VALUES ('2979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂ミッドタウン・タワー　44階', '13', '13103', '1076244', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, 'ミッドタウン・タワー　44階', 'ミッドタウン・タワー　44カイ');
INSERT INTO `ms_addresses` VALUES ('2980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂ミッドタウン・タワー　45階', '13', '13103', '1076245', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, 'ミッドタウン・タワー　45階', 'ミッドタウン・タワー　45カイ');
INSERT INTO `ms_addresses` VALUES ('2981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂ミッドタウン・タワー　', '13', '13103', '1076290', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, 'ミッドタウン・タワー　', 'ミッドタウン・タワー　');
INSERT INTO `ms_addresses` VALUES ('2982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂Bizタワー　1階', '13', '13103', '1076301', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂Bizタワー　1階', 'アカサカビズタワー　01カイ');
INSERT INTO `ms_addresses` VALUES ('2983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂Bizタワー　2階', '13', '13103', '1076302', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂Bizタワー　2階', 'アカサカビズタワー　02カイ');
INSERT INTO `ms_addresses` VALUES ('2984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂Bizタワー　3階', '13', '13103', '1076303', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂Bizタワー　3階', 'アカサカビズタワー　03カイ');
INSERT INTO `ms_addresses` VALUES ('2985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂Bizタワー　4階', '13', '13103', '1076304', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂Bizタワー　4階', 'アカサカビズタワー　04カイ');
INSERT INTO `ms_addresses` VALUES ('2986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂Bizタワー　5階', '13', '13103', '1076305', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂Bizタワー　5階', 'アカサカビズタワー　05カイ');
INSERT INTO `ms_addresses` VALUES ('2987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂Bizタワー　6階', '13', '13103', '1076306', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂Bizタワー　6階', 'アカサカビズタワー　06カイ');
INSERT INTO `ms_addresses` VALUES ('2988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂Bizタワー　7階', '13', '13103', '1076307', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂Bizタワー　7階', 'アカサカビズタワー　07カイ');
INSERT INTO `ms_addresses` VALUES ('2989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂Bizタワー　8階', '13', '13103', '1076308', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂Bizタワー　8階', 'アカサカビズタワー　08カイ');
INSERT INTO `ms_addresses` VALUES ('2990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂Bizタワー　9階', '13', '13103', '1076309', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂Bizタワー　9階', 'アカサカビズタワー　09カイ');
INSERT INTO `ms_addresses` VALUES ('2991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂Bizタワー　10階', '13', '13103', '1076310', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂Bizタワー　10階', 'アカサカビズタワー　10カイ');
INSERT INTO `ms_addresses` VALUES ('2992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂Bizタワー　11階', '13', '13103', '1076311', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂Bizタワー　11階', 'アカサカビズタワー　11カイ');
INSERT INTO `ms_addresses` VALUES ('2993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂Bizタワー　12階', '13', '13103', '1076312', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂Bizタワー　12階', 'アカサカビズタワー　12カイ');
INSERT INTO `ms_addresses` VALUES ('2994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂Bizタワー　13階', '13', '13103', '1076313', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂Bizタワー　13階', 'アカサカビズタワー　13カイ');
INSERT INTO `ms_addresses` VALUES ('2995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂Bizタワー　14階', '13', '13103', '1076314', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂Bizタワー　14階', 'アカサカビズタワー　14カイ');
INSERT INTO `ms_addresses` VALUES ('2996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂Bizタワー　15階', '13', '13103', '1076315', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂Bizタワー　15階', 'アカサカビズタワー　15カイ');
INSERT INTO `ms_addresses` VALUES ('2997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂Bizタワー　16階', '13', '13103', '1076316', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂Bizタワー　16階', 'アカサカビズタワー　16カイ');
INSERT INTO `ms_addresses` VALUES ('2998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂Bizタワー　17階', '13', '13103', '1076317', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂Bizタワー　17階', 'アカサカビズタワー　17カイ');
INSERT INTO `ms_addresses` VALUES ('2999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂Bizタワー　18階', '13', '13103', '1076318', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂Bizタワー　18階', 'アカサカビズタワー　18カイ');
INSERT INTO `ms_addresses` VALUES ('3000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂Bizタワー　19階', '13', '13103', '1076319', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂Bizタワー　19階', 'アカサカビズタワー　19カイ');
INSERT INTO `ms_addresses` VALUES ('3001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂Bizタワー　20階', '13', '13103', '1076320', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂Bizタワー　20階', 'アカサカビズタワー　20カイ');
INSERT INTO `ms_addresses` VALUES ('3002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂Bizタワー　21階', '13', '13103', '1076321', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂Bizタワー　21階', 'アカサカビズタワー　21カイ');
INSERT INTO `ms_addresses` VALUES ('3003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂Bizタワー　22階', '13', '13103', '1076322', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂Bizタワー　22階', 'アカサカビズタワー　22カイ');
INSERT INTO `ms_addresses` VALUES ('3004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂Bizタワー　23階', '13', '13103', '1076323', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂Bizタワー　23階', 'アカサカビズタワー　23カイ');
INSERT INTO `ms_addresses` VALUES ('3005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂Bizタワー　24階', '13', '13103', '1076324', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂Bizタワー　24階', 'アカサカビズタワー　24カイ');
INSERT INTO `ms_addresses` VALUES ('3006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂Bizタワー　25階', '13', '13103', '1076325', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂Bizタワー　25階', 'アカサカビズタワー　25カイ');
INSERT INTO `ms_addresses` VALUES ('3007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂Bizタワー　26階', '13', '13103', '1076326', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂Bizタワー　26階', 'アカサカビズタワー　26カイ');
INSERT INTO `ms_addresses` VALUES ('3008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂Bizタワー　27階', '13', '13103', '1076327', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂Bizタワー　27階', 'アカサカビズタワー　27カイ');
INSERT INTO `ms_addresses` VALUES ('3009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂Bizタワー　28階', '13', '13103', '1076328', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂Bizタワー　28階', 'アカサカビズタワー　28カイ');
INSERT INTO `ms_addresses` VALUES ('3010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂Bizタワー　29階', '13', '13103', '1076329', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂Bizタワー　29階', 'アカサカビズタワー　29カイ');
INSERT INTO `ms_addresses` VALUES ('3011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂Bizタワー　30階', '13', '13103', '1076330', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂Bizタワー　30階', 'アカサカビズタワー　30カイ');
INSERT INTO `ms_addresses` VALUES ('3012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂Bizタワー　31階', '13', '13103', '1076331', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂Bizタワー　31階', 'アカサカビズタワー　31カイ');
INSERT INTO `ms_addresses` VALUES ('3013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂Bizタワー　32階', '13', '13103', '1076332', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂Bizタワー　32階', 'アカサカビズタワー　32カイ');
INSERT INTO `ms_addresses` VALUES ('3014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂Bizタワー　33階', '13', '13103', '1076333', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂Bizタワー　33階', 'アカサカビズタワー　33カイ');
INSERT INTO `ms_addresses` VALUES ('3015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂Bizタワー　34階', '13', '13103', '1076334', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂Bizタワー　34階', 'アカサカビズタワー　34カイ');
INSERT INTO `ms_addresses` VALUES ('3016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂Bizタワー　35階', '13', '13103', '1076335', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂Bizタワー　35階', 'アカサカビズタワー　35カイ');
INSERT INTO `ms_addresses` VALUES ('3017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂Bizタワー　36階', '13', '13103', '1076336', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂Bizタワー　36階', 'アカサカビズタワー　36カイ');
INSERT INTO `ms_addresses` VALUES ('3018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂Bizタワー　37階', '13', '13103', '1076337', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂Bizタワー　37階', 'アカサカビズタワー　37カイ');
INSERT INTO `ms_addresses` VALUES ('3019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂Bizタワー　38階', '13', '13103', '1076338', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂Bizタワー　38階', 'アカサカビズタワー　38カイ');
INSERT INTO `ms_addresses` VALUES ('3020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂Bizタワー　39階', '13', '13103', '1076339', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂Bizタワー　39階', 'アカサカビズタワー　39カイ');
INSERT INTO `ms_addresses` VALUES ('3021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区赤坂赤坂Bizタワー　', '13', '13103', '1076390', '東京都', 'トウキョウト', '港区', 'ミナトク', '赤坂', 'アカサカ', null, null, '赤坂Bizタワー　', 'アカサカビズタワー　');
INSERT INTO `ms_addresses` VALUES ('3127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区芝4丁目', '13', '13103', '1080014', '東京都', 'トウキョウト', '港区', 'ミナトク', '芝', 'シバ', null, null, '4丁目', '04チョウメ');
INSERT INTO `ms_addresses` VALUES ('3128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区芝5丁目', '13', '13103', '1080014', '東京都', 'トウキョウト', '港区', 'ミナトク', '芝', 'シバ', null, null, '5丁目', '05チョウメ');
INSERT INTO `ms_addresses` VALUES ('3129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区海岸3丁目', '13', '13103', '1080022', '東京都', 'トウキョウト', '港区', 'ミナトク', '海岸', 'カイガン', null, null, '3丁目', '03チョウメ');
INSERT INTO `ms_addresses` VALUES ('3130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区芝浦2丁目', '13', '13103', '1080023', '東京都', 'トウキョウト', '港区', 'ミナトク', '芝浦', 'シバウラ', null, null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('3131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区芝浦3丁目', '13', '13103', '1080023', '東京都', 'トウキョウト', '港区', 'ミナトク', '芝浦', 'シバウラ', null, null, '3丁目', '03チョウメ');
INSERT INTO `ms_addresses` VALUES ('3132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区芝浦4丁目', '13', '13103', '1080023', '東京都', 'トウキョウト', '港区', 'ミナトク', '芝浦', 'シバウラ', null, null, '4丁目', '04チョウメ');
INSERT INTO `ms_addresses` VALUES ('3133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区白金台', '13', '13103', '1080071', '東京都', 'トウキョウト', '港区', 'ミナトク', '白金台', 'シロカネダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区白金', '13', '13103', '1080072', '東京都', 'トウキョウト', '港区', 'ミナトク', '白金', 'シロカネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区三田', '13', '13103', '1080073', '東京都', 'トウキョウト', '港区', 'ミナトク', '三田', 'ミタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区高輪', '13', '13103', '1080074', '東京都', 'トウキョウト', '港区', 'ミナトク', '高輪', 'タカナワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区港南', '13', '13103', '1080075', '東京都', 'トウキョウト', '港区', 'ミナトク', '港南', 'コウナン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区港南品川インターシティA棟　1階', '13', '13103', '1086001', '東京都', 'トウキョウト', '港区', 'ミナトク', '港南', 'コウナン', null, null, '品川インターシティA棟　1階', 'シナガワインターシティAトウ　01カイ');
INSERT INTO `ms_addresses` VALUES ('3164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区港南品川インターシティA棟　2階', '13', '13103', '1086002', '東京都', 'トウキョウト', '港区', 'ミナトク', '港南', 'コウナン', null, null, '品川インターシティA棟　2階', 'シナガワインターシティAトウ　02カイ');
INSERT INTO `ms_addresses` VALUES ('3165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区港南品川インターシティA棟　3階', '13', '13103', '1086003', '東京都', 'トウキョウト', '港区', 'ミナトク', '港南', 'コウナン', null, null, '品川インターシティA棟　3階', 'シナガワインターシティAトウ　03カイ');
INSERT INTO `ms_addresses` VALUES ('3166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区港南品川インターシティA棟　4階', '13', '13103', '1086004', '東京都', 'トウキョウト', '港区', 'ミナトク', '港南', 'コウナン', null, null, '品川インターシティA棟　4階', 'シナガワインターシティAトウ　04カイ');
INSERT INTO `ms_addresses` VALUES ('3167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区港南品川インターシティA棟　5階', '13', '13103', '1086005', '東京都', 'トウキョウト', '港区', 'ミナトク', '港南', 'コウナン', null, null, '品川インターシティA棟　5階', 'シナガワインターシティAトウ　05カイ');
INSERT INTO `ms_addresses` VALUES ('3168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区港南品川インターシティA棟　6階', '13', '13103', '1086006', '東京都', 'トウキョウト', '港区', 'ミナトク', '港南', 'コウナン', null, null, '品川インターシティA棟　6階', 'シナガワインターシティAトウ　06カイ');
INSERT INTO `ms_addresses` VALUES ('3169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区港南品川インターシティA棟　7階', '13', '13103', '1086007', '東京都', 'トウキョウト', '港区', 'ミナトク', '港南', 'コウナン', null, null, '品川インターシティA棟　7階', 'シナガワインターシティAトウ　07カイ');
INSERT INTO `ms_addresses` VALUES ('3170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区港南品川インターシティA棟　8階', '13', '13103', '1086008', '東京都', 'トウキョウト', '港区', 'ミナトク', '港南', 'コウナン', null, null, '品川インターシティA棟　8階', 'シナガワインターシティAトウ　08カイ');
INSERT INTO `ms_addresses` VALUES ('3171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区港南品川インターシティA棟　9階', '13', '13103', '1086009', '東京都', 'トウキョウト', '港区', 'ミナトク', '港南', 'コウナン', null, null, '品川インターシティA棟　9階', 'シナガワインターシティAトウ　09カイ');
INSERT INTO `ms_addresses` VALUES ('3173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区港南品川インターシティA棟　10階', '13', '13103', '1086010', '東京都', 'トウキョウト', '港区', 'ミナトク', '港南', 'コウナン', null, null, '品川インターシティA棟　10階', 'シナガワインターシティAトウ　10カイ');
INSERT INTO `ms_addresses` VALUES ('3174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区港南品川インターシティA棟　11階', '13', '13103', '1086011', '東京都', 'トウキョウト', '港区', 'ミナトク', '港南', 'コウナン', null, null, '品川インターシティA棟　11階', 'シナガワインターシティAトウ　11カイ');
INSERT INTO `ms_addresses` VALUES ('3175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区港南品川インターシティA棟　12階', '13', '13103', '1086012', '東京都', 'トウキョウト', '港区', 'ミナトク', '港南', 'コウナン', null, null, '品川インターシティA棟　12階', 'シナガワインターシティAトウ　12カイ');
INSERT INTO `ms_addresses` VALUES ('3176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区港南品川インターシティA棟　13階', '13', '13103', '1086013', '東京都', 'トウキョウト', '港区', 'ミナトク', '港南', 'コウナン', null, null, '品川インターシティA棟　13階', 'シナガワインターシティAトウ　13カイ');
INSERT INTO `ms_addresses` VALUES ('3177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区港南品川インターシティA棟　14階', '13', '13103', '1086014', '東京都', 'トウキョウト', '港区', 'ミナトク', '港南', 'コウナン', null, null, '品川インターシティA棟　14階', 'シナガワインターシティAトウ　14カイ');
INSERT INTO `ms_addresses` VALUES ('3178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区港南品川インターシティA棟　15階', '13', '13103', '1086015', '東京都', 'トウキョウト', '港区', 'ミナトク', '港南', 'コウナン', null, null, '品川インターシティA棟　15階', 'シナガワインターシティAトウ　15カイ');
INSERT INTO `ms_addresses` VALUES ('3179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区港南品川インターシティA棟　16階', '13', '13103', '1086016', '東京都', 'トウキョウト', '港区', 'ミナトク', '港南', 'コウナン', null, null, '品川インターシティA棟　16階', 'シナガワインターシティAトウ　16カイ');
INSERT INTO `ms_addresses` VALUES ('3180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区港南品川インターシティA棟　17階', '13', '13103', '1086017', '東京都', 'トウキョウト', '港区', 'ミナトク', '港南', 'コウナン', null, null, '品川インターシティA棟　17階', 'シナガワインターシティAトウ　17カイ');
INSERT INTO `ms_addresses` VALUES ('3181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区港南品川インターシティA棟　18階', '13', '13103', '1086018', '東京都', 'トウキョウト', '港区', 'ミナトク', '港南', 'コウナン', null, null, '品川インターシティA棟　18階', 'シナガワインターシティAトウ　18カイ');
INSERT INTO `ms_addresses` VALUES ('3182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区港南品川インターシティA棟　19階', '13', '13103', '1086019', '東京都', 'トウキョウト', '港区', 'ミナトク', '港南', 'コウナン', null, null, '品川インターシティA棟　19階', 'シナガワインターシティAトウ　19カイ');
INSERT INTO `ms_addresses` VALUES ('3183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区港南品川インターシティA棟　20階', '13', '13103', '1086020', '東京都', 'トウキョウト', '港区', 'ミナトク', '港南', 'コウナン', null, null, '品川インターシティA棟　20階', 'シナガワインターシティAトウ　20カイ');
INSERT INTO `ms_addresses` VALUES ('3184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区港南品川インターシティA棟　21階', '13', '13103', '1086021', '東京都', 'トウキョウト', '港区', 'ミナトク', '港南', 'コウナン', null, null, '品川インターシティA棟　21階', 'シナガワインターシティAトウ　21カイ');
INSERT INTO `ms_addresses` VALUES ('3185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区港南品川インターシティA棟　22階', '13', '13103', '1086022', '東京都', 'トウキョウト', '港区', 'ミナトク', '港南', 'コウナン', null, null, '品川インターシティA棟　22階', 'シナガワインターシティAトウ　22カイ');
INSERT INTO `ms_addresses` VALUES ('3186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区港南品川インターシティA棟　23階', '13', '13103', '1086023', '東京都', 'トウキョウト', '港区', 'ミナトク', '港南', 'コウナン', null, null, '品川インターシティA棟　23階', 'シナガワインターシティAトウ　23カイ');
INSERT INTO `ms_addresses` VALUES ('3187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区港南品川インターシティA棟　24階', '13', '13103', '1086024', '東京都', 'トウキョウト', '港区', 'ミナトク', '港南', 'コウナン', null, null, '品川インターシティA棟　24階', 'シナガワインターシティAトウ　24カイ');
INSERT INTO `ms_addresses` VALUES ('3188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区港南品川インターシティA棟　25階', '13', '13103', '1086025', '東京都', 'トウキョウト', '港区', 'ミナトク', '港南', 'コウナン', null, null, '品川インターシティA棟　25階', 'シナガワインターシティAトウ　25カイ');
INSERT INTO `ms_addresses` VALUES ('3189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区港南品川インターシティA棟　26階', '13', '13103', '1086026', '東京都', 'トウキョウト', '港区', 'ミナトク', '港南', 'コウナン', null, null, '品川インターシティA棟　26階', 'シナガワインターシティAトウ　26カイ');
INSERT INTO `ms_addresses` VALUES ('3190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区港南品川インターシティA棟　27階', '13', '13103', '1086027', '東京都', 'トウキョウト', '港区', 'ミナトク', '港南', 'コウナン', null, null, '品川インターシティA棟　27階', 'シナガワインターシティAトウ　27カイ');
INSERT INTO `ms_addresses` VALUES ('3191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区港南品川インターシティA棟　28階', '13', '13103', '1086028', '東京都', 'トウキョウト', '港区', 'ミナトク', '港南', 'コウナン', null, null, '品川インターシティA棟　28階', 'シナガワインターシティAトウ　28カイ');
INSERT INTO `ms_addresses` VALUES ('3192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区港南品川インターシティA棟　29階', '13', '13103', '1086029', '東京都', 'トウキョウト', '港区', 'ミナトク', '港南', 'コウナン', null, null, '品川インターシティA棟　29階', 'シナガワインターシティAトウ　29カイ');
INSERT INTO `ms_addresses` VALUES ('3193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区港南品川インターシティA棟　30階', '13', '13103', '1086030', '東京都', 'トウキョウト', '港区', 'ミナトク', '港南', 'コウナン', null, null, '品川インターシティA棟　30階', 'シナガワインターシティAトウ　30カイ');
INSERT INTO `ms_addresses` VALUES ('3194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区港南品川インターシティA棟　31階', '13', '13103', '1086031', '東京都', 'トウキョウト', '港区', 'ミナトク', '港南', 'コウナン', null, null, '品川インターシティA棟　31階', 'シナガワインターシティAトウ　31カイ');
INSERT INTO `ms_addresses` VALUES ('3195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区港南品川インターシティA棟　32階', '13', '13103', '1086032', '東京都', 'トウキョウト', '港区', 'ミナトク', '港南', 'コウナン', null, null, '品川インターシティA棟　32階', 'シナガワインターシティAトウ　32カイ');
INSERT INTO `ms_addresses` VALUES ('3196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区港南品川インターシティA棟　', '13', '13103', '1086090', '東京都', 'トウキョウト', '港区', 'ミナトク', '港南', 'コウナン', null, null, '品川インターシティA棟　', 'シナガワインターシティAトウ　');
INSERT INTO `ms_addresses` VALUES ('3197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区港南品川インターシティB棟　1階', '13', '13103', '1086101', '東京都', 'トウキョウト', '港区', 'ミナトク', '港南', 'コウナン', null, null, '品川インターシティB棟　1階', 'シナガワインターシティBトウ　01カイ');
INSERT INTO `ms_addresses` VALUES ('3198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区港南品川インターシティB棟　2階', '13', '13103', '1086102', '東京都', 'トウキョウト', '港区', 'ミナトク', '港南', 'コウナン', null, null, '品川インターシティB棟　2階', 'シナガワインターシティBトウ　02カイ');
INSERT INTO `ms_addresses` VALUES ('3199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区港南品川インターシティB棟　3階', '13', '13103', '1086103', '東京都', 'トウキョウト', '港区', 'ミナトク', '港南', 'コウナン', null, null, '品川インターシティB棟　3階', 'シナガワインターシティBトウ　03カイ');
INSERT INTO `ms_addresses` VALUES ('3200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区港南品川インターシティB棟　4階', '13', '13103', '1086104', '東京都', 'トウキョウト', '港区', 'ミナトク', '港南', 'コウナン', null, null, '品川インターシティB棟　4階', 'シナガワインターシティBトウ　04カイ');
INSERT INTO `ms_addresses` VALUES ('3201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区港南品川インターシティB棟　5階', '13', '13103', '1086105', '東京都', 'トウキョウト', '港区', 'ミナトク', '港南', 'コウナン', null, null, '品川インターシティB棟　5階', 'シナガワインターシティBトウ　05カイ');
INSERT INTO `ms_addresses` VALUES ('3202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区港南品川インターシティB棟　6階', '13', '13103', '1086106', '東京都', 'トウキョウト', '港区', 'ミナトク', '港南', 'コウナン', null, null, '品川インターシティB棟　6階', 'シナガワインターシティBトウ　06カイ');
INSERT INTO `ms_addresses` VALUES ('3203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区港南品川インターシティB棟　7階', '13', '13103', '1086107', '東京都', 'トウキョウト', '港区', 'ミナトク', '港南', 'コウナン', null, null, '品川インターシティB棟　7階', 'シナガワインターシティBトウ　07カイ');
INSERT INTO `ms_addresses` VALUES ('3204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区港南品川インターシティB棟　8階', '13', '13103', '1086108', '東京都', 'トウキョウト', '港区', 'ミナトク', '港南', 'コウナン', null, null, '品川インターシティB棟　8階', 'シナガワインターシティBトウ　08カイ');
INSERT INTO `ms_addresses` VALUES ('3205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区港南品川インターシティB棟　9階', '13', '13103', '1086109', '東京都', 'トウキョウト', '港区', 'ミナトク', '港南', 'コウナン', null, null, '品川インターシティB棟　9階', 'シナガワインターシティBトウ　09カイ');
INSERT INTO `ms_addresses` VALUES ('3207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区港南品川インターシティB棟　10階', '13', '13103', '1086110', '東京都', 'トウキョウト', '港区', 'ミナトク', '港南', 'コウナン', null, null, '品川インターシティB棟　10階', 'シナガワインターシティBトウ　10カイ');
INSERT INTO `ms_addresses` VALUES ('3208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区港南品川インターシティB棟　11階', '13', '13103', '1086111', '東京都', 'トウキョウト', '港区', 'ミナトク', '港南', 'コウナン', null, null, '品川インターシティB棟　11階', 'シナガワインターシティBトウ　11カイ');
INSERT INTO `ms_addresses` VALUES ('3209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区港南品川インターシティB棟　12階', '13', '13103', '1086112', '東京都', 'トウキョウト', '港区', 'ミナトク', '港南', 'コウナン', null, null, '品川インターシティB棟　12階', 'シナガワインターシティBトウ　12カイ');
INSERT INTO `ms_addresses` VALUES ('3210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区港南品川インターシティB棟　13階', '13', '13103', '1086113', '東京都', 'トウキョウト', '港区', 'ミナトク', '港南', 'コウナン', null, null, '品川インターシティB棟　13階', 'シナガワインターシティBトウ　13カイ');
INSERT INTO `ms_addresses` VALUES ('3211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区港南品川インターシティB棟　14階', '13', '13103', '1086114', '東京都', 'トウキョウト', '港区', 'ミナトク', '港南', 'コウナン', null, null, '品川インターシティB棟　14階', 'シナガワインターシティBトウ　14カイ');
INSERT INTO `ms_addresses` VALUES ('3212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区港南品川インターシティB棟　15階', '13', '13103', '1086115', '東京都', 'トウキョウト', '港区', 'ミナトク', '港南', 'コウナン', null, null, '品川インターシティB棟　15階', 'シナガワインターシティBトウ　15カイ');
INSERT INTO `ms_addresses` VALUES ('3213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区港南品川インターシティB棟　16階', '13', '13103', '1086116', '東京都', 'トウキョウト', '港区', 'ミナトク', '港南', 'コウナン', null, null, '品川インターシティB棟　16階', 'シナガワインターシティBトウ　16カイ');
INSERT INTO `ms_addresses` VALUES ('3214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区港南品川インターシティB棟　17階', '13', '13103', '1086117', '東京都', 'トウキョウト', '港区', 'ミナトク', '港南', 'コウナン', null, null, '品川インターシティB棟　17階', 'シナガワインターシティBトウ　17カイ');
INSERT INTO `ms_addresses` VALUES ('3215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区港南品川インターシティB棟　18階', '13', '13103', '1086118', '東京都', 'トウキョウト', '港区', 'ミナトク', '港南', 'コウナン', null, null, '品川インターシティB棟　18階', 'シナガワインターシティBトウ　18カイ');
INSERT INTO `ms_addresses` VALUES ('3216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区港南品川インターシティB棟　19階', '13', '13103', '1086119', '東京都', 'トウキョウト', '港区', 'ミナトク', '港南', 'コウナン', null, null, '品川インターシティB棟　19階', 'シナガワインターシティBトウ　19カイ');
INSERT INTO `ms_addresses` VALUES ('3217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区港南品川インターシティB棟　20階', '13', '13103', '1086120', '東京都', 'トウキョウト', '港区', 'ミナトク', '港南', 'コウナン', null, null, '品川インターシティB棟　20階', 'シナガワインターシティBトウ　20カイ');
INSERT INTO `ms_addresses` VALUES ('3218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区港南品川インターシティB棟　21階', '13', '13103', '1086121', '東京都', 'トウキョウト', '港区', 'ミナトク', '港南', 'コウナン', null, null, '品川インターシティB棟　21階', 'シナガワインターシティBトウ　21カイ');
INSERT INTO `ms_addresses` VALUES ('3219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区港南品川インターシティB棟　22階', '13', '13103', '1086122', '東京都', 'トウキョウト', '港区', 'ミナトク', '港南', 'コウナン', null, null, '品川インターシティB棟　22階', 'シナガワインターシティBトウ　22カイ');
INSERT INTO `ms_addresses` VALUES ('3220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区港南品川インターシティB棟　23階', '13', '13103', '1086123', '東京都', 'トウキョウト', '港区', 'ミナトク', '港南', 'コウナン', null, null, '品川インターシティB棟　23階', 'シナガワインターシティBトウ　23カイ');
INSERT INTO `ms_addresses` VALUES ('3221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区港南品川インターシティB棟　24階', '13', '13103', '1086124', '東京都', 'トウキョウト', '港区', 'ミナトク', '港南', 'コウナン', null, null, '品川インターシティB棟　24階', 'シナガワインターシティBトウ　24カイ');
INSERT INTO `ms_addresses` VALUES ('3222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区港南品川インターシティB棟　25階', '13', '13103', '1086125', '東京都', 'トウキョウト', '港区', 'ミナトク', '港南', 'コウナン', null, null, '品川インターシティB棟　25階', 'シナガワインターシティBトウ　25カイ');
INSERT INTO `ms_addresses` VALUES ('3223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区港南品川インターシティB棟　26階', '13', '13103', '1086126', '東京都', 'トウキョウト', '港区', 'ミナトク', '港南', 'コウナン', null, null, '品川インターシティB棟　26階', 'シナガワインターシティBトウ　26カイ');
INSERT INTO `ms_addresses` VALUES ('3224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区港南品川インターシティB棟　27階', '13', '13103', '1086127', '東京都', 'トウキョウト', '港区', 'ミナトク', '港南', 'コウナン', null, null, '品川インターシティB棟　27階', 'シナガワインターシティBトウ　27カイ');
INSERT INTO `ms_addresses` VALUES ('3225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区港南品川インターシティB棟　28階', '13', '13103', '1086128', '東京都', 'トウキョウト', '港区', 'ミナトク', '港南', 'コウナン', null, null, '品川インターシティB棟　28階', 'シナガワインターシティBトウ　28カイ');
INSERT INTO `ms_addresses` VALUES ('3226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区港南品川インターシティB棟　29階', '13', '13103', '1086129', '東京都', 'トウキョウト', '港区', 'ミナトク', '港南', 'コウナン', null, null, '品川インターシティB棟　29階', 'シナガワインターシティBトウ　29カイ');
INSERT INTO `ms_addresses` VALUES ('3227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区港南品川インターシティB棟　30階', '13', '13103', '1086130', '東京都', 'トウキョウト', '港区', 'ミナトク', '港南', 'コウナン', null, null, '品川インターシティB棟　30階', 'シナガワインターシティBトウ　30カイ');
INSERT INTO `ms_addresses` VALUES ('3228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区港南品川インターシティB棟　31階', '13', '13103', '1086131', '東京都', 'トウキョウト', '港区', 'ミナトク', '港南', 'コウナン', null, null, '品川インターシティB棟　31階', 'シナガワインターシティBトウ　31カイ');
INSERT INTO `ms_addresses` VALUES ('3229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区港南品川インターシティB棟　', '13', '13103', '1086190', '東京都', 'トウキョウト', '港区', 'ミナトク', '港南', 'コウナン', null, null, '品川インターシティB棟　', 'シナガワインターシティBトウ　');
INSERT INTO `ms_addresses` VALUES ('3230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区港南品川インターシティC棟　1階', '13', '13103', '1086201', '東京都', 'トウキョウト', '港区', 'ミナトク', '港南', 'コウナン', null, null, '品川インターシティC棟　1階', 'シナガワインターシティCトウ　01カイ');
INSERT INTO `ms_addresses` VALUES ('3231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区港南品川インターシティC棟　2階', '13', '13103', '1086202', '東京都', 'トウキョウト', '港区', 'ミナトク', '港南', 'コウナン', null, null, '品川インターシティC棟　2階', 'シナガワインターシティCトウ　02カイ');
INSERT INTO `ms_addresses` VALUES ('3232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区港南品川インターシティC棟　3階', '13', '13103', '1086203', '東京都', 'トウキョウト', '港区', 'ミナトク', '港南', 'コウナン', null, null, '品川インターシティC棟　3階', 'シナガワインターシティCトウ　03カイ');
INSERT INTO `ms_addresses` VALUES ('3233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区港南品川インターシティC棟　4階', '13', '13103', '1086204', '東京都', 'トウキョウト', '港区', 'ミナトク', '港南', 'コウナン', null, null, '品川インターシティC棟　4階', 'シナガワインターシティCトウ　04カイ');
INSERT INTO `ms_addresses` VALUES ('3234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区港南品川インターシティC棟　5階', '13', '13103', '1086205', '東京都', 'トウキョウト', '港区', 'ミナトク', '港南', 'コウナン', null, null, '品川インターシティC棟　5階', 'シナガワインターシティCトウ　05カイ');
INSERT INTO `ms_addresses` VALUES ('3235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区港南品川インターシティC棟　6階', '13', '13103', '1086206', '東京都', 'トウキョウト', '港区', 'ミナトク', '港南', 'コウナン', null, null, '品川インターシティC棟　6階', 'シナガワインターシティCトウ　06カイ');
INSERT INTO `ms_addresses` VALUES ('3236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区港南品川インターシティC棟　7階', '13', '13103', '1086207', '東京都', 'トウキョウト', '港区', 'ミナトク', '港南', 'コウナン', null, null, '品川インターシティC棟　7階', 'シナガワインターシティCトウ　07カイ');
INSERT INTO `ms_addresses` VALUES ('3237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区港南品川インターシティC棟　8階', '13', '13103', '1086208', '東京都', 'トウキョウト', '港区', 'ミナトク', '港南', 'コウナン', null, null, '品川インターシティC棟　8階', 'シナガワインターシティCトウ　08カイ');
INSERT INTO `ms_addresses` VALUES ('3238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区港南品川インターシティC棟　9階', '13', '13103', '1086209', '東京都', 'トウキョウト', '港区', 'ミナトク', '港南', 'コウナン', null, null, '品川インターシティC棟　9階', 'シナガワインターシティCトウ　09カイ');
INSERT INTO `ms_addresses` VALUES ('3239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区港南品川インターシティC棟　10階', '13', '13103', '1086210', '東京都', 'トウキョウト', '港区', 'ミナトク', '港南', 'コウナン', null, null, '品川インターシティC棟　10階', 'シナガワインターシティCトウ　10カイ');
INSERT INTO `ms_addresses` VALUES ('3240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区港南品川インターシティC棟　11階', '13', '13103', '1086211', '東京都', 'トウキョウト', '港区', 'ミナトク', '港南', 'コウナン', null, null, '品川インターシティC棟　11階', 'シナガワインターシティCトウ　11カイ');
INSERT INTO `ms_addresses` VALUES ('3241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区港南品川インターシティC棟　12階', '13', '13103', '1086212', '東京都', 'トウキョウト', '港区', 'ミナトク', '港南', 'コウナン', null, null, '品川インターシティC棟　12階', 'シナガワインターシティCトウ　12カイ');
INSERT INTO `ms_addresses` VALUES ('3242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区港南品川インターシティC棟　13階', '13', '13103', '1086213', '東京都', 'トウキョウト', '港区', 'ミナトク', '港南', 'コウナン', null, null, '品川インターシティC棟　13階', 'シナガワインターシティCトウ　13カイ');
INSERT INTO `ms_addresses` VALUES ('3243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区港南品川インターシティC棟　14階', '13', '13103', '1086214', '東京都', 'トウキョウト', '港区', 'ミナトク', '港南', 'コウナン', null, null, '品川インターシティC棟　14階', 'シナガワインターシティCトウ　14カイ');
INSERT INTO `ms_addresses` VALUES ('3244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区港南品川インターシティC棟　15階', '13', '13103', '1086215', '東京都', 'トウキョウト', '港区', 'ミナトク', '港南', 'コウナン', null, null, '品川インターシティC棟　15階', 'シナガワインターシティCトウ　15カイ');
INSERT INTO `ms_addresses` VALUES ('3245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区港南品川インターシティC棟　16階', '13', '13103', '1086216', '東京都', 'トウキョウト', '港区', 'ミナトク', '港南', 'コウナン', null, null, '品川インターシティC棟　16階', 'シナガワインターシティCトウ　16カイ');
INSERT INTO `ms_addresses` VALUES ('3246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区港南品川インターシティC棟　17階', '13', '13103', '1086217', '東京都', 'トウキョウト', '港区', 'ミナトク', '港南', 'コウナン', null, null, '品川インターシティC棟　17階', 'シナガワインターシティCトウ　17カイ');
INSERT INTO `ms_addresses` VALUES ('3247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区港南品川インターシティC棟　18階', '13', '13103', '1086218', '東京都', 'トウキョウト', '港区', 'ミナトク', '港南', 'コウナン', null, null, '品川インターシティC棟　18階', 'シナガワインターシティCトウ　18カイ');
INSERT INTO `ms_addresses` VALUES ('3248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区港南品川インターシティC棟　19階', '13', '13103', '1086219', '東京都', 'トウキョウト', '港区', 'ミナトク', '港南', 'コウナン', null, null, '品川インターシティC棟　19階', 'シナガワインターシティCトウ　19カイ');
INSERT INTO `ms_addresses` VALUES ('3250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区港南品川インターシティC棟　20階', '13', '13103', '1086220', '東京都', 'トウキョウト', '港区', 'ミナトク', '港南', 'コウナン', null, null, '品川インターシティC棟　20階', 'シナガワインターシティCトウ　20カイ');
INSERT INTO `ms_addresses` VALUES ('3251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区港南品川インターシティC棟　21階', '13', '13103', '1086221', '東京都', 'トウキョウト', '港区', 'ミナトク', '港南', 'コウナン', null, null, '品川インターシティC棟　21階', 'シナガワインターシティCトウ　21カイ');
INSERT INTO `ms_addresses` VALUES ('3252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区港南品川インターシティC棟　22階', '13', '13103', '1086222', '東京都', 'トウキョウト', '港区', 'ミナトク', '港南', 'コウナン', null, null, '品川インターシティC棟　22階', 'シナガワインターシティCトウ　22カイ');
INSERT INTO `ms_addresses` VALUES ('3253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区港南品川インターシティC棟　23階', '13', '13103', '1086223', '東京都', 'トウキョウト', '港区', 'ミナトク', '港南', 'コウナン', null, null, '品川インターシティC棟　23階', 'シナガワインターシティCトウ　23カイ');
INSERT INTO `ms_addresses` VALUES ('3254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区港南品川インターシティC棟　24階', '13', '13103', '1086224', '東京都', 'トウキョウト', '港区', 'ミナトク', '港南', 'コウナン', null, null, '品川インターシティC棟　24階', 'シナガワインターシティCトウ　24カイ');
INSERT INTO `ms_addresses` VALUES ('3255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区港南品川インターシティC棟　25階', '13', '13103', '1086225', '東京都', 'トウキョウト', '港区', 'ミナトク', '港南', 'コウナン', null, null, '品川インターシティC棟　25階', 'シナガワインターシティCトウ　25カイ');
INSERT INTO `ms_addresses` VALUES ('3256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区港南品川インターシティC棟　26階', '13', '13103', '1086226', '東京都', 'トウキョウト', '港区', 'ミナトク', '港南', 'コウナン', null, null, '品川インターシティC棟　26階', 'シナガワインターシティCトウ　26カイ');
INSERT INTO `ms_addresses` VALUES ('3257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区港南品川インターシティC棟　27階', '13', '13103', '1086227', '東京都', 'トウキョウト', '港区', 'ミナトク', '港南', 'コウナン', null, null, '品川インターシティC棟　27階', 'シナガワインターシティCトウ　27カイ');
INSERT INTO `ms_addresses` VALUES ('3258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区港南品川インターシティC棟　28階', '13', '13103', '1086228', '東京都', 'トウキョウト', '港区', 'ミナトク', '港南', 'コウナン', null, null, '品川インターシティC棟　28階', 'シナガワインターシティCトウ　28カイ');
INSERT INTO `ms_addresses` VALUES ('3259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区港南品川インターシティC棟　29階', '13', '13103', '1086229', '東京都', 'トウキョウト', '港区', 'ミナトク', '港南', 'コウナン', null, null, '品川インターシティC棟　29階', 'シナガワインターシティCトウ　29カイ');
INSERT INTO `ms_addresses` VALUES ('3260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区港南品川インターシティC棟　30階', '13', '13103', '1086230', '東京都', 'トウキョウト', '港区', 'ミナトク', '港南', 'コウナン', null, null, '品川インターシティC棟　30階', 'シナガワインターシティCトウ　30カイ');
INSERT INTO `ms_addresses` VALUES ('3261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区港南品川インターシティC棟　31階', '13', '13103', '1086231', '東京都', 'トウキョウト', '港区', 'ミナトク', '港南', 'コウナン', null, null, '品川インターシティC棟　31階', 'シナガワインターシティCトウ　31カイ');
INSERT INTO `ms_addresses` VALUES ('3262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区港南品川インターシティC棟　', '13', '13103', '1086290', '東京都', 'トウキョウト', '港区', 'ミナトク', '港南', 'コウナン', null, null, '品川インターシティC棟　', 'シナガワインターシティCトウ　');
INSERT INTO `ms_addresses` VALUES ('3263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区三田住友不動産三田ツインビル西館　1階', '13', '13103', '1086301', '東京都', 'トウキョウト', '港区', 'ミナトク', '三田', 'ミタ', null, null, '住友不動産三田ツインビル西館　1階', 'スミトモフドウサンミタツインビルニシカン　01カイ');
INSERT INTO `ms_addresses` VALUES ('3264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区三田住友不動産三田ツインビル西館　2階', '13', '13103', '1086302', '東京都', 'トウキョウト', '港区', 'ミナトク', '三田', 'ミタ', null, null, '住友不動産三田ツインビル西館　2階', 'スミトモフドウサンミタツインビルニシカン　02カイ');
INSERT INTO `ms_addresses` VALUES ('3265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区三田住友不動産三田ツインビル西館　3階', '13', '13103', '1086303', '東京都', 'トウキョウト', '港区', 'ミナトク', '三田', 'ミタ', null, null, '住友不動産三田ツインビル西館　3階', 'スミトモフドウサンミタツインビルニシカン　03カイ');
INSERT INTO `ms_addresses` VALUES ('3266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区三田住友不動産三田ツインビル西館　4階', '13', '13103', '1086304', '東京都', 'トウキョウト', '港区', 'ミナトク', '三田', 'ミタ', null, null, '住友不動産三田ツインビル西館　4階', 'スミトモフドウサンミタツインビルニシカン　04カイ');
INSERT INTO `ms_addresses` VALUES ('3267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区三田住友不動産三田ツインビル西館　5階', '13', '13103', '1086305', '東京都', 'トウキョウト', '港区', 'ミナトク', '三田', 'ミタ', null, null, '住友不動産三田ツインビル西館　5階', 'スミトモフドウサンミタツインビルニシカン　05カイ');
INSERT INTO `ms_addresses` VALUES ('3268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区三田住友不動産三田ツインビル西館　6階', '13', '13103', '1086306', '東京都', 'トウキョウト', '港区', 'ミナトク', '三田', 'ミタ', null, null, '住友不動産三田ツインビル西館　6階', 'スミトモフドウサンミタツインビルニシカン　06カイ');
INSERT INTO `ms_addresses` VALUES ('3269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区三田住友不動産三田ツインビル西館　7階', '13', '13103', '1086307', '東京都', 'トウキョウト', '港区', 'ミナトク', '三田', 'ミタ', null, null, '住友不動産三田ツインビル西館　7階', 'スミトモフドウサンミタツインビルニシカン　07カイ');
INSERT INTO `ms_addresses` VALUES ('3270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区三田住友不動産三田ツインビル西館　8階', '13', '13103', '1086308', '東京都', 'トウキョウト', '港区', 'ミナトク', '三田', 'ミタ', null, null, '住友不動産三田ツインビル西館　8階', 'スミトモフドウサンミタツインビルニシカン　08カイ');
INSERT INTO `ms_addresses` VALUES ('3271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区三田住友不動産三田ツインビル西館　9階', '13', '13103', '1086309', '東京都', 'トウキョウト', '港区', 'ミナトク', '三田', 'ミタ', null, null, '住友不動産三田ツインビル西館　9階', 'スミトモフドウサンミタツインビルニシカン　09カイ');
INSERT INTO `ms_addresses` VALUES ('3272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区三田住友不動産三田ツインビル西館　10階', '13', '13103', '1086310', '東京都', 'トウキョウト', '港区', 'ミナトク', '三田', 'ミタ', null, null, '住友不動産三田ツインビル西館　10階', 'スミトモフドウサンミタツインビルニシカン　10カイ');
INSERT INTO `ms_addresses` VALUES ('3273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区三田住友不動産三田ツインビル西館　11階', '13', '13103', '1086311', '東京都', 'トウキョウト', '港区', 'ミナトク', '三田', 'ミタ', null, null, '住友不動産三田ツインビル西館　11階', 'スミトモフドウサンミタツインビルニシカン　11カイ');
INSERT INTO `ms_addresses` VALUES ('3274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区三田住友不動産三田ツインビル西館　12階', '13', '13103', '1086312', '東京都', 'トウキョウト', '港区', 'ミナトク', '三田', 'ミタ', null, null, '住友不動産三田ツインビル西館　12階', 'スミトモフドウサンミタツインビルニシカン　12カイ');
INSERT INTO `ms_addresses` VALUES ('3275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区三田住友不動産三田ツインビル西館　13階', '13', '13103', '1086313', '東京都', 'トウキョウト', '港区', 'ミナトク', '三田', 'ミタ', null, null, '住友不動産三田ツインビル西館　13階', 'スミトモフドウサンミタツインビルニシカン　13カイ');
INSERT INTO `ms_addresses` VALUES ('3276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区三田住友不動産三田ツインビル西館　14階', '13', '13103', '1086314', '東京都', 'トウキョウト', '港区', 'ミナトク', '三田', 'ミタ', null, null, '住友不動産三田ツインビル西館　14階', 'スミトモフドウサンミタツインビルニシカン　14カイ');
INSERT INTO `ms_addresses` VALUES ('3277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区三田住友不動産三田ツインビル西館　15階', '13', '13103', '1086315', '東京都', 'トウキョウト', '港区', 'ミナトク', '三田', 'ミタ', null, null, '住友不動産三田ツインビル西館　15階', 'スミトモフドウサンミタツインビルニシカン　15カイ');
INSERT INTO `ms_addresses` VALUES ('3278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区三田住友不動産三田ツインビル西館　16階', '13', '13103', '1086316', '東京都', 'トウキョウト', '港区', 'ミナトク', '三田', 'ミタ', null, null, '住友不動産三田ツインビル西館　16階', 'スミトモフドウサンミタツインビルニシカン　16カイ');
INSERT INTO `ms_addresses` VALUES ('3279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区三田住友不動産三田ツインビル西館　17階', '13', '13103', '1086317', '東京都', 'トウキョウト', '港区', 'ミナトク', '三田', 'ミタ', null, null, '住友不動産三田ツインビル西館　17階', 'スミトモフドウサンミタツインビルニシカン　17カイ');
INSERT INTO `ms_addresses` VALUES ('3280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区三田住友不動産三田ツインビル西館　18階', '13', '13103', '1086318', '東京都', 'トウキョウト', '港区', 'ミナトク', '三田', 'ミタ', null, null, '住友不動産三田ツインビル西館　18階', 'スミトモフドウサンミタツインビルニシカン　18カイ');
INSERT INTO `ms_addresses` VALUES ('3281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区三田住友不動産三田ツインビル西館　19階', '13', '13103', '1086319', '東京都', 'トウキョウト', '港区', 'ミナトク', '三田', 'ミタ', null, null, '住友不動産三田ツインビル西館　19階', 'スミトモフドウサンミタツインビルニシカン　19カイ');
INSERT INTO `ms_addresses` VALUES ('3282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区三田住友不動産三田ツインビル西館　20階', '13', '13103', '1086320', '東京都', 'トウキョウト', '港区', 'ミナトク', '三田', 'ミタ', null, null, '住友不動産三田ツインビル西館　20階', 'スミトモフドウサンミタツインビルニシカン　20カイ');
INSERT INTO `ms_addresses` VALUES ('3283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区三田住友不動産三田ツインビル西館　21階', '13', '13103', '1086321', '東京都', 'トウキョウト', '港区', 'ミナトク', '三田', 'ミタ', null, null, '住友不動産三田ツインビル西館　21階', 'スミトモフドウサンミタツインビルニシカン　21カイ');
INSERT INTO `ms_addresses` VALUES ('3284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区三田住友不動産三田ツインビル西館　22階', '13', '13103', '1086322', '東京都', 'トウキョウト', '港区', 'ミナトク', '三田', 'ミタ', null, null, '住友不動産三田ツインビル西館　22階', 'スミトモフドウサンミタツインビルニシカン　22カイ');
INSERT INTO `ms_addresses` VALUES ('3285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区三田住友不動産三田ツインビル西館　23階', '13', '13103', '1086323', '東京都', 'トウキョウト', '港区', 'ミナトク', '三田', 'ミタ', null, null, '住友不動産三田ツインビル西館　23階', 'スミトモフドウサンミタツインビルニシカン　23カイ');
INSERT INTO `ms_addresses` VALUES ('3286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区三田住友不動産三田ツインビル西館　24階', '13', '13103', '1086324', '東京都', 'トウキョウト', '港区', 'ミナトク', '三田', 'ミタ', null, null, '住友不動産三田ツインビル西館　24階', 'スミトモフドウサンミタツインビルニシカン　24カイ');
INSERT INTO `ms_addresses` VALUES ('3287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区三田住友不動産三田ツインビル西館　25階', '13', '13103', '1086325', '東京都', 'トウキョウト', '港区', 'ミナトク', '三田', 'ミタ', null, null, '住友不動産三田ツインビル西館　25階', 'スミトモフドウサンミタツインビルニシカン　25カイ');
INSERT INTO `ms_addresses` VALUES ('3288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区三田住友不動産三田ツインビル西館　26階', '13', '13103', '1086326', '東京都', 'トウキョウト', '港区', 'ミナトク', '三田', 'ミタ', null, null, '住友不動産三田ツインビル西館　26階', 'スミトモフドウサンミタツインビルニシカン　26カイ');
INSERT INTO `ms_addresses` VALUES ('3289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区三田住友不動産三田ツインビル西館　27階', '13', '13103', '1086327', '東京都', 'トウキョウト', '港区', 'ミナトク', '三田', 'ミタ', null, null, '住友不動産三田ツインビル西館　27階', 'スミトモフドウサンミタツインビルニシカン　27カイ');
INSERT INTO `ms_addresses` VALUES ('3290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区三田住友不動産三田ツインビル西館　28階', '13', '13103', '1086328', '東京都', 'トウキョウト', '港区', 'ミナトク', '三田', 'ミタ', null, null, '住友不動産三田ツインビル西館　28階', 'スミトモフドウサンミタツインビルニシカン　28カイ');
INSERT INTO `ms_addresses` VALUES ('3291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区三田住友不動産三田ツインビル西館　29階', '13', '13103', '1086329', '東京都', 'トウキョウト', '港区', 'ミナトク', '三田', 'ミタ', null, null, '住友不動産三田ツインビル西館　29階', 'スミトモフドウサンミタツインビルニシカン　29カイ');
INSERT INTO `ms_addresses` VALUES ('3293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区三田住友不動産三田ツインビル西館　30階', '13', '13103', '1086330', '東京都', 'トウキョウト', '港区', 'ミナトク', '三田', 'ミタ', null, null, '住友不動産三田ツインビル西館　30階', 'スミトモフドウサンミタツインビルニシカン　30カイ');
INSERT INTO `ms_addresses` VALUES ('3295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区三田住友不動産三田ツインビル西館　', '13', '13103', '1086390', '東京都', 'トウキョウト', '港区', 'ミナトク', '三田', 'ミタ', null, null, '住友不動産三田ツインビル西館　', 'スミトモフドウサンミタツインビルニシカン　');
INSERT INTO `ms_addresses` VALUES ('3486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区新琴似1条', '01', '01102', '0010901', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '新琴似1条', 'シンコトニ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区新琴似2条', '01', '01102', '0010902', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '新琴似2条', 'シンコトニ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区新琴似3条', '01', '01102', '0010903', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '新琴似3条', 'シンコトニ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区新琴似4条', '01', '01102', '0010904', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '新琴似4条', 'シンコトニ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区新琴似5条', '01', '01102', '0010905', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '新琴似5条', 'シンコトニ05ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区新琴似6条', '01', '01102', '0010906', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '新琴似6条', 'シンコトニ06ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区新琴似7条', '01', '01102', '0010907', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '新琴似7条', 'シンコトニ07ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区新琴似8条', '01', '01102', '0010908', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '新琴似8条', 'シンコトニ08ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区新琴似9条', '01', '01102', '0010909', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '新琴似9条', 'シンコトニ09ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区新琴似10条', '01', '01102', '0010910', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '新琴似10条', 'シンコトニ10ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区新琴似11条', '01', '01102', '0010911', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '新琴似11条', 'シンコトニ11ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区新琴似12条', '01', '01102', '0010912', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '新琴似12条', 'シンコトニ12ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区新琴似町', '01', '01102', '0010915', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '新琴似町', 'シンコトニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区新川1条', '01', '01102', '0010921', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '新川1条', 'シンカワ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区新川2条', '01', '01102', '0010922', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '新川2条', 'シンカワ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区新川3条', '01', '01102', '0010923', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '新川3条', 'シンカワ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区新川4条', '01', '01102', '0010924', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '新川4条', 'シンカワ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区新川5条', '01', '01102', '0010925', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '新川5条', 'シンカワ05ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区新川6条', '01', '01102', '0010926', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '新川6条', 'シンカワ06ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区新川7条', '01', '01102', '0010927', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '新川7条', 'シンカワ07ジョウ', null, null, null, null), ('3506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区新川', '01', '01102', '0010930', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '新川', 'シンカワ', null, null, null, null), ('3507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区新川西1条', '01', '01102', '0010931', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '新川西1条', 'シンカワニシ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区新川西2条', '01', '01102', '0010932', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '新川西2条', 'シンカワニシ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区新川西3条', '01', '01102', '0010933', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '新川西3条', 'シンカワニシ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区新川西4条', '01', '01102', '0010934', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '新川西4条', 'シンカワニシ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区新川西5条', '01', '01102', '0010935', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '新川西5条', 'シンカワニシ05ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都台東区', '13', '13106', '1100000', '東京都', 'トウキョウト', '台東区', 'タイトウク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('3514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都台東区谷中', '13', '13106', '1100001', '東京都', 'トウキョウト', '台東区', 'タイトウク', '谷中', 'ヤナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都台東区上野桜木', '13', '13106', '1100002', '東京都', 'トウキョウト', '台東区', 'タイトウク', '上野桜木', 'ウエノサクラギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都台東区根岸', '13', '13106', '1100003', '東京都', 'トウキョウト', '台東区', 'タイトウク', '根岸', 'ネギシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都台東区下谷', '13', '13106', '1100004', '東京都', 'トウキョウト', '台東区', 'タイトウク', '下谷', 'シタヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都台東区上野', '13', '13106', '1100005', '東京都', 'トウキョウト', '台東区', 'タイトウク', '上野', 'ウエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都台東区秋葉原', '13', '13106', '1100006', '東京都', 'トウキョウト', '台東区', 'タイトウク', '秋葉原', 'アキハバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都台東区上野公園', '13', '13106', '1100007', '東京都', 'トウキョウト', '台東区', 'タイトウク', '上野公園', 'ウエノコウエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都台東区池之端', '13', '13106', '1100008', '東京都', 'トウキョウト', '台東区', 'タイトウク', '池之端', 'イケノハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都台東区三ノ輪', '13', '13106', '1100011', '東京都', 'トウキョウト', '台東区', 'タイトウク', '三ノ輪', 'ミノワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都台東区竜泉', '13', '13106', '1100012', '東京都', 'トウキョウト', '台東区', 'タイトウク', '竜泉', 'リュウセン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都台東区入谷', '13', '13106', '1100013', '東京都', 'トウキョウト', '台東区', 'タイトウク', '入谷', 'イリヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都台東区北上野', '13', '13106', '1100014', '東京都', 'トウキョウト', '台東区', 'タイトウク', '北上野', 'キタウエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都台東区東上野', '13', '13106', '1100015', '東京都', 'トウキョウト', '台東区', 'タイトウク', '東上野', 'ヒガシウエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都台東区台東', '13', '13106', '1100016', '東京都', 'トウキョウト', '台東区', 'タイトウク', '台東', 'タイトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市寺内', '05', '05201', '0110901', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '寺内', 'テラウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市寺内堂ノ沢', '05', '05201', '0110902', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '寺内堂ノ沢', 'テラウチドウノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市寺内油田', '05', '05201', '0110903', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '寺内油田', 'テラウチアブラデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市寺内蛭根', '05', '05201', '0110904', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '寺内蛭根', 'テラウチヒルネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市寺内神屋敷', '05', '05201', '0110905', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '寺内神屋敷', 'テラウチカミヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市寺内後城', '05', '05201', '0110906', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '寺内後城', 'テラウチウシロジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市寺内焼山', '05', '05201', '0110907', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '寺内焼山', 'テラウチヤケヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市寺内大小路', '05', '05201', '0110908', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '寺内大小路', 'テラウチオオコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市寺内児桜', '05', '05201', '0110909', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '寺内児桜', 'テラウチコザクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市飯島', '05', '05201', '0110911', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '飯島', 'イイジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市飯島川端', '05', '05201', '0110912', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '飯島川端', 'イイジマカワバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市飯島鼠田', '05', '05201', '0110913', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '飯島鼠田', 'イイジマネズミタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市飯島美砂町', '05', '05201', '0110914', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '飯島美砂町', 'イイジマミサゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市飯島緑丘町', '05', '05201', '0110915', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '飯島緑丘町', 'イイジマミドリガオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市飯島穀丁', '05', '05201', '0110916', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '飯島穀丁', 'イイジマコクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市飯島道東', '05', '05201', '0110917', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '飯島道東', 'イイジマミチヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市飯島松根西町', '05', '05201', '0110921', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '飯島松根西町', 'イイジママツネニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市飯島松根東町', '05', '05201', '0110922', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '飯島松根東町', 'イイジママツネヒガシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市飯島文京町', '05', '05201', '0110923', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '飯島文京町', 'イイジマブンキョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市飯島長野本町', '05', '05201', '0110924', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '飯島長野本町', 'イイジマナガノホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市飯島長野中町', '05', '05201', '0110925', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '飯島長野中町', 'イイジマナガノナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市港北松野町', '05', '05201', '0110926', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '港北松野町', 'コウホクマツノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市港北新町', '05', '05201', '0110927', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '港北新町', 'コウホクシンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市飯島長野上町', '05', '05201', '0110928', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '飯島長野上町', 'イイジマナガノカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市将軍野東', '05', '05201', '0110931', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '将軍野東', 'ショウグンノヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市将軍野青山町', '05', '05201', '0110932', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '将軍野青山町', 'ショウグンノアオヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市将軍野堰越', '05', '05201', '0110933', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '将軍野堰越', 'ショウグンノセキコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市将軍野桂町', '05', '05201', '0110934', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '将軍野桂町', 'ショウグンノカツラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市将軍野向山', '05', '05201', '0110935', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '将軍野向山', 'ショウグンノムカイヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市将軍野南', '05', '05201', '0110936', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '将軍野南', 'ショウグンノミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市寺内高野', '05', '05201', '0110937', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '寺内高野', 'テラウチコウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市寺内鵜ノ木', '05', '05201', '0110938', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '寺内鵜ノ木', 'テラウチウノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市寺内大畑', '05', '05201', '0110939', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '寺内大畑', 'テラウチオオハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市土崎港北', '05', '05201', '0110941', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '土崎港北', 'ツチザキミナトキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市土崎港東', '05', '05201', '0110942', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '土崎港東', 'ツチザキミナトヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市土崎港南', '05', '05201', '0110943', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '土崎港南', 'ツチザキミナトミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市土崎港穀保町', '05', '05201', '0110944', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '土崎港穀保町', 'ツチザキミナトコクボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市土崎港西', '05', '05201', '0110945', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '土崎港西', 'ツチザキミナトニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市土崎港中央', '05', '05201', '0110946', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '土崎港中央', 'ツチザキミナトチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市飯島新町', '05', '05201', '0110947', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '飯島新町', 'イイジマシンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市飯島西袋', '05', '05201', '0110948', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '飯島西袋', 'イイジマニシブクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市飯島飯田', '05', '05201', '0110949', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '飯島飯田', 'イイジマイイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市土崎港相染町', '05', '05201', '0110951', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '土崎港相染町', 'ツチザキミナトソウゼンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市土崎港古川町', '05', '05201', '0110951', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '土崎港古川町', 'ツチザキミナトフルカワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都台東区日本堤', '13', '13106', '1110021', '東京都', 'トウキョウト', '台東区', 'タイトウク', '日本堤', 'ニホンヅツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都台東区清川', '13', '13106', '1110022', '東京都', 'トウキョウト', '台東区', 'タイトウク', '清川', 'キヨカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都台東区橋場', '13', '13106', '1110023', '東京都', 'トウキョウト', '台東区', 'タイトウク', '橋場', 'ハシバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都台東区今戸', '13', '13106', '1110024', '東京都', 'トウキョウト', '台東区', 'タイトウク', '今戸', 'イマド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都台東区東浅草', '13', '13106', '1110025', '東京都', 'トウキョウト', '台東区', 'タイトウク', '東浅草', 'ヒガシアサクサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都台東区千束', '13', '13106', '1110031', '東京都', 'トウキョウト', '台東区', 'タイトウク', '千束', 'センゾク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都台東区浅草', '13', '13106', '1110032', '東京都', 'トウキョウト', '台東区', 'タイトウク', '浅草', 'アサクサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都台東区花川戸', '13', '13106', '1110033', '東京都', 'トウキョウト', '台東区', 'タイトウク', '花川戸', 'ハナカワド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都台東区雷門', '13', '13106', '1110034', '東京都', 'トウキョウト', '台東区', 'タイトウク', '雷門', 'カミナリモン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都台東区西浅草', '13', '13106', '1110035', '東京都', 'トウキョウト', '台東区', 'タイトウク', '西浅草', 'ニシアサクサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都台東区松が谷', '13', '13106', '1110036', '東京都', 'トウキョウト', '台東区', 'タイトウク', '松が谷', 'マツガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都台東区元浅草', '13', '13106', '1110041', '東京都', 'トウキョウト', '台東区', 'タイトウク', '元浅草', 'モトアサクサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都台東区寿', '13', '13106', '1110042', '東京都', 'トウキョウト', '台東区', 'タイトウク', '寿', 'コトブキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都台東区駒形', '13', '13106', '1110043', '東京都', 'トウキョウト', '台東区', 'タイトウク', '駒形', 'コマガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都台東区蔵前', '13', '13106', '1110051', '東京都', 'トウキョウト', '台東区', 'タイトウク', '蔵前', 'クラマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都台東区柳橋', '13', '13106', '1110052', '東京都', 'トウキョウト', '台東区', 'タイトウク', '柳橋', 'ヤナギバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都台東区浅草橋', '13', '13106', '1110053', '東京都', 'トウキョウト', '台東区', 'タイトウク', '浅草橋', 'アサクサバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都台東区鳥越', '13', '13106', '1110054', '東京都', 'トウキョウト', '台東区', 'タイトウク', '鳥越', 'トリゴエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都台東区三筋', '13', '13106', '1110055', '東京都', 'トウキョウト', '台東区', 'タイトウク', '三筋', 'ミスジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都台東区小島', '13', '13106', '1110056', '東京都', 'トウキョウト', '台東区', 'タイトウク', '小島', 'コジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都文京区', '13', '13105', '1120000', '東京都', 'トウキョウト', '文京区', 'ブンキョウク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('3800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都文京区白山2丁目', '13', '13105', '1120001', '東京都', 'トウキョウト', '文京区', 'ブンキョウク', '白山', 'ハクサン', null, null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('3801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都文京区白山3丁目', '13', '13105', '1120001', '東京都', 'トウキョウト', '文京区', 'ブンキョウク', '白山', 'ハクサン', null, null, '3丁目', '03チョウメ');
INSERT INTO `ms_addresses` VALUES ('3802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都文京区白山4丁目', '13', '13105', '1120001', '東京都', 'トウキョウト', '文京区', 'ブンキョウク', '白山', 'ハクサン', null, null, '4丁目', '04チョウメ');
INSERT INTO `ms_addresses` VALUES ('3803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都文京区白山5丁目', '13', '13105', '1120001', '東京都', 'トウキョウト', '文京区', 'ブンキョウク', '白山', 'ハクサン', null, null, '5丁目', '05チョウメ');
INSERT INTO `ms_addresses` VALUES ('3804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都文京区小石川', '13', '13105', '1120002', '東京都', 'トウキョウト', '文京区', 'ブンキョウク', '小石川', 'コイシカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都文京区春日', '13', '13105', '1120003', '東京都', 'トウキョウト', '文京区', 'ブンキョウク', '春日', 'カスガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都文京区後楽', '13', '13105', '1120004', '東京都', 'トウキョウト', '文京区', 'ブンキョウク', '後楽', 'コウラク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都文京区水道', '13', '13105', '1120005', '東京都', 'トウキョウト', '文京区', 'ブンキョウク', '水道', 'スイドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都文京区小日向', '13', '13105', '1120006', '東京都', 'トウキョウト', '文京区', 'ブンキョウク', '小日向', 'コヒナタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都文京区千石', '13', '13105', '1120011', '東京都', 'トウキョウト', '文京区', 'ブンキョウク', '千石', 'センゴク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都文京区大塚', '13', '13105', '1120012', '東京都', 'トウキョウト', '文京区', 'ブンキョウク', '大塚', 'オオツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都文京区音羽', '13', '13105', '1120013', '東京都', 'トウキョウト', '文京区', 'ブンキョウク', '音羽', 'オトワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都文京区関口', '13', '13105', '1120014', '東京都', 'トウキョウト', '文京区', 'ブンキョウク', '関口', 'セキグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都文京区目白台', '13', '13105', '1120015', '東京都', 'トウキョウト', '文京区', 'ブンキョウク', '目白台', 'メジロダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都文京区白山1丁目', '13', '13105', '1130001', '東京都', 'トウキョウト', '文京区', 'ブンキョウク', '白山', 'ハクサン', null, null, '1丁目', '01チョウメ');
INSERT INTO `ms_addresses` VALUES ('3907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都文京区本駒込', '13', '13105', '1130021', '東京都', 'トウキョウト', '文京区', 'ブンキョウク', '本駒込', 'ホンコマゴメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都文京区千駄木', '13', '13105', '1130022', '東京都', 'トウキョウト', '文京区', 'ブンキョウク', '千駄木', 'センダギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都文京区向丘', '13', '13105', '1130023', '東京都', 'トウキョウト', '文京区', 'ブンキョウク', '向丘', 'ムコウガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都文京区西片', '13', '13105', '1130024', '東京都', 'トウキョウト', '文京区', 'ブンキョウク', '西片', 'ニシカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都文京区根津', '13', '13105', '1130031', '東京都', 'トウキョウト', '文京区', 'ブンキョウク', '根津', 'ネヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都文京区弥生', '13', '13105', '1130032', '東京都', 'トウキョウト', '文京区', 'ブンキョウク', '弥生', 'ヤヨイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都文京区本郷', '13', '13105', '1130033', '東京都', 'トウキョウト', '文京区', 'ブンキョウク', '本郷', 'ホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('3914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都文京区湯島', '13', '13105', '1130034', '東京都', 'トウキョウト', '文京区', 'ブンキョウク', '湯島', 'ユシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都北区', '13', '13117', '1140000', '東京都', 'トウキョウト', '北区', 'キタク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('4013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都北区東十条', '13', '13117', '1140001', '東京都', 'トウキョウト', '北区', 'キタク', '東十条', 'ヒガシジュウジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都北区王子', '13', '13117', '1140002', '東京都', 'トウキョウト', '北区', 'キタク', '王子', 'オウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都北区豊島', '13', '13117', '1140003', '東京都', 'トウキョウト', '北区', 'キタク', '豊島', 'トシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都北区堀船', '13', '13117', '1140004', '東京都', 'トウキョウト', '北区', 'キタク', '堀船', 'ホリフネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都北区栄町', '13', '13117', '1140005', '東京都', 'トウキョウト', '北区', 'キタク', '栄町', 'サカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都北区昭和町', '13', '13117', '1140011', '東京都', 'トウキョウト', '北区', 'キタク', '昭和町', 'ショウワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都北区田端新町', '13', '13117', '1140012', '東京都', 'トウキョウト', '北区', 'キタク', '田端新町', 'タバタシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都北区東田端', '13', '13117', '1140013', '東京都', 'トウキョウト', '北区', 'キタク', '東田端', 'ヒガシタバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都北区田端', '13', '13117', '1140014', '東京都', 'トウキョウト', '北区', 'キタク', '田端', 'タバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都北区中里', '13', '13117', '1140015', '東京都', 'トウキョウト', '北区', 'キタク', '中里', 'ナカザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都北区上中里', '13', '13117', '1140016', '東京都', 'トウキョウト', '北区', 'キタク', '上中里', 'カミナカザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都北区岸町', '13', '13117', '1140021', '東京都', 'トウキョウト', '北区', 'キタク', '岸町', 'キシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都北区王子本町', '13', '13117', '1140022', '東京都', 'トウキョウト', '北区', 'キタク', '王子本町', 'オウジホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都北区滝野川', '13', '13117', '1140023', '東京都', 'トウキョウト', '北区', 'キタク', '滝野川', 'タキノガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都北区西ケ原', '13', '13117', '1140024', '東京都', 'トウキョウト', '北区', 'キタク', '西ケ原', 'ニシガハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都北区十条仲原', '13', '13117', '1140031', '東京都', 'トウキョウト', '北区', 'キタク', '十条仲原', 'ジュウジョウナカハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都北区中十条', '13', '13117', '1140032', '東京都', 'トウキョウト', '北区', 'キタク', '中十条', 'ナカジュウジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都北区十条台', '13', '13117', '1140033', '東京都', 'トウキョウト', '北区', 'キタク', '十条台', 'ジュウジョウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都北区上十条', '13', '13117', '1140034', '東京都', 'トウキョウト', '北区', 'キタク', '上十条', 'カミジュウジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都北区岩淵町', '13', '13117', '1150041', '東京都', 'トウキョウト', '北区', 'キタク', '岩淵町', 'イワブチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都北区志茂', '13', '13117', '1150042', '東京都', 'トウキョウト', '北区', 'キタク', '志茂', 'シモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都北区神谷', '13', '13117', '1150043', '東京都', 'トウキョウト', '北区', 'キタク', '神谷', 'カミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都北区赤羽南', '13', '13117', '1150044', '東京都', 'トウキョウト', '北区', 'キタク', '赤羽南', 'アカバネミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都北区赤羽', '13', '13117', '1150045', '東京都', 'トウキョウト', '北区', 'キタク', '赤羽', 'アカバネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都北区浮間', '13', '13117', '1150051', '東京都', 'トウキョウト', '北区', 'キタク', '浮間', 'ウキマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都北区赤羽北', '13', '13117', '1150052', '東京都', 'トウキョウト', '北区', 'キタク', '赤羽北', 'アカバネキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都北区赤羽台', '13', '13117', '1150053', '東京都', 'トウキョウト', '北区', 'キタク', '赤羽台', 'アカバネダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都北区桐ケ丘', '13', '13117', '1150054', '東京都', 'トウキョウト', '北区', 'キタク', '桐ケ丘', 'キリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都北区赤羽西', '13', '13117', '1150055', '東京都', 'トウキョウト', '北区', 'キタク', '赤羽西', 'アカバネニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都北区西が丘', '13', '13117', '1150056', '東京都', 'トウキョウト', '北区', 'キタク', '西が丘', 'ニシガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都荒川区', '13', '13118', '1160000', '東京都', 'トウキョウト', '荒川区', 'アラカワク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('4115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都荒川区町屋', '13', '13118', '1160001', '東京都', 'トウキョウト', '荒川区', 'アラカワク', '町屋', 'マチヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都荒川区荒川', '13', '13118', '1160002', '東京都', 'トウキョウト', '荒川区', 'アラカワク', '荒川', 'アラカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都荒川区南千住', '13', '13118', '1160003', '東京都', 'トウキョウト', '荒川区', 'アラカワク', '南千住', 'ミナミセンジュ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都荒川区西尾久', '13', '13118', '1160011', '東京都', 'トウキョウト', '荒川区', 'アラカワク', '西尾久', 'ニシオグ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都荒川区東尾久', '13', '13118', '1160012', '東京都', 'トウキョウト', '荒川区', 'アラカワク', '東尾久', 'ヒガシオグ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都荒川区西日暮里', '13', '13118', '1160013', '東京都', 'トウキョウト', '荒川区', 'アラカワク', '西日暮里', 'ニシニッポリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都荒川区東日暮里', '13', '13118', '1160014', '東京都', 'トウキョウト', '荒川区', 'アラカワク', '東日暮里', 'ヒガシニッポリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市', '05', '05207', '0120000', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('4169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都足立区', '13', '13121', '1200000', '東京都', 'トウキョウト', '足立区', 'アダチク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('4170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都足立区大谷田', '13', '13121', '1200001', '東京都', 'トウキョウト', '足立区', 'アダチク', '大谷田', 'オオヤタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都足立区中川', '13', '13121', '1200002', '東京都', 'トウキョウト', '足立区', 'アダチク', '中川', 'ナカガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都足立区東和', '13', '13121', '1200003', '東京都', 'トウキョウト', '足立区', 'アダチク', '東和', 'トウワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都足立区東綾瀬', '13', '13121', '1200004', '東京都', 'トウキョウト', '足立区', 'アダチク', '東綾瀬', 'ヒガシアヤセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都足立区綾瀬', '13', '13121', '1200005', '東京都', 'トウキョウト', '足立区', 'アダチク', '綾瀬', 'アヤセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都足立区谷中', '13', '13121', '1200006', '東京都', 'トウキョウト', '足立区', 'アダチク', '谷中', 'ヤナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市角間', '05', '05207', '0120001', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '角間', 'カクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都足立区中央本町1丁目', '13', '13121', '1200011', '東京都', 'トウキョウト', '足立区', 'アダチク', '中央本町', 'チュウオウホンチョウ', null, null, '1丁目', '01チョウメ');
INSERT INTO `ms_addresses` VALUES ('4178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都足立区中央本町2丁目', '13', '13121', '1200011', '東京都', 'トウキョウト', '足立区', 'アダチク', '中央本町', 'チュウオウホンチョウ', null, null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('4179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都足立区青井1丁目', '13', '13121', '1200012', '東京都', 'トウキョウト', '足立区', 'アダチク', '青井', 'アオイ', null, null, '1丁目', '01チョウメ');
INSERT INTO `ms_addresses` VALUES ('4180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都足立区青井2丁目', '13', '13121', '1200012', '東京都', 'トウキョウト', '足立区', 'アダチク', '青井', 'アオイ', null, null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('4181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都足立区青井3丁目', '13', '13121', '1200012', '東京都', 'トウキョウト', '足立区', 'アダチク', '青井', 'アオイ', null, null, '3丁目', '03チョウメ');
INSERT INTO `ms_addresses` VALUES ('4182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都足立区弘道', '13', '13121', '1200013', '東京都', 'トウキョウト', '足立区', 'アダチク', '弘道', 'コウドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都足立区西綾瀬', '13', '13121', '1200014', '東京都', 'トウキョウト', '足立区', 'アダチク', '西綾瀬', 'ニシアヤセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都足立区足立', '13', '13121', '1200015', '東京都', 'トウキョウト', '足立区', 'アダチク', '足立', 'アダチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市下二井田', '05', '05207', '0120002', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '下二井田', 'シモニイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都足立区日ノ出町', '13', '13121', '1200021', '東京都', 'トウキョウト', '足立区', 'アダチク', '日ノ出町', 'ヒノデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都足立区柳原', '13', '13121', '1200022', '東京都', 'トウキョウト', '足立区', 'アダチク', '柳原', 'ヤナギハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都足立区千住曙町', '13', '13121', '1200023', '東京都', 'トウキョウト', '足立区', 'アダチク', '千住曙町', 'センジュアケボノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都足立区千住関屋町', '13', '13121', '1200024', '東京都', 'トウキョウト', '足立区', 'アダチク', '千住関屋町', 'センジュセキヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都足立区千住東', '13', '13121', '1200025', '東京都', 'トウキョウト', '足立区', 'アダチク', '千住東', 'センジュアズマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都足立区千住旭町', '13', '13121', '1200026', '東京都', 'トウキョウト', '足立区', 'アダチク', '千住旭町', 'センジュアサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市上二井田', '05', '05207', '0120003', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '上二井田', 'カミニイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都足立区千住大川町', '13', '13121', '1200031', '東京都', 'トウキョウト', '足立区', 'アダチク', '千住大川町', 'センジュオオカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都足立区千住柳町', '13', '13121', '1200032', '東京都', 'トウキョウト', '足立区', 'アダチク', '千住柳町', 'センジュヤナギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都足立区千住寿町', '13', '13121', '1200033', '東京都', 'トウキョウト', '足立区', 'アダチク', '千住寿町', 'センジュコトブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都足立区千住', '13', '13121', '1200034', '東京都', 'トウキョウト', '足立区', 'アダチク', '千住', 'センジュ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都足立区千住中居町', '13', '13121', '1200035', '東京都', 'トウキョウト', '足立区', 'アダチク', '千住中居町', 'センジュナカイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都足立区千住仲町', '13', '13121', '1200036', '東京都', 'トウキョウト', '足立区', 'アダチク', '千住仲町', 'センジュナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都足立区千住河原町', '13', '13121', '1200037', '東京都', 'トウキョウト', '足立区', 'アダチク', '千住河原町', 'センジュカワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都足立区千住橋戸町', '13', '13121', '1200038', '東京都', 'トウキョウト', '足立区', 'アダチク', '千住橋戸町', 'センジュハシドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市二井田', '05', '05207', '0120004', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '二井田', 'ニイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都足立区千住元町', '13', '13121', '1200041', '東京都', 'トウキョウト', '足立区', 'アダチク', '千住元町', 'センジュモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都足立区千住龍田町', '13', '13121', '1200042', '東京都', 'トウキョウト', '足立区', 'アダチク', '千住龍田町', 'センジュタツタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都足立区千住宮元町', '13', '13121', '1200043', '東京都', 'トウキョウト', '足立区', 'アダチク', '千住宮元町', 'センジュミヤモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都足立区千住緑町', '13', '13121', '1200044', '東京都', 'トウキョウト', '足立区', 'アダチク', '千住緑町', 'センジュミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都足立区千住桜木', '13', '13121', '1200045', '東京都', 'トウキョウト', '足立区', 'アダチク', '千住桜木', 'センジュサクラギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都足立区小台', '13', '13121', '1200046', '東京都', 'トウキョウト', '足立区', 'アダチク', '小台', 'オダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都足立区宮城', '13', '13121', '1200047', '東京都', 'トウキョウト', '足立区', 'アダチク', '宮城', 'ミヤギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市金谷', '05', '05207', '0120005', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '金谷', 'カナヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市柳田', '05', '05207', '0120006', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '柳田', 'ヤナギダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市八幡', '05', '05207', '0120007', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '八幡', 'ヤワタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市高前', '05', '05207', '0120008', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '高前', 'タカマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市森', '05', '05207', '0120011', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '森', 'モリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市大森', '05', '05207', '0120012', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '大森', 'オオモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市栄田', '05', '05207', '0120013', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '栄田', 'サカエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市大倉谷地', '05', '05207', '0120014', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '大倉谷地', 'オオクラヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市倉内', '05', '05207', '0120015', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '倉内', 'クラウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市千刈', '05', '05207', '0120016', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '千刈', 'センガリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市富士見', '05', '05207', '0120017', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '富士見', 'フジミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市黄金原', '05', '05207', '0120021', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '黄金原', 'コガネハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市祝田', '05', '05207', '0120022', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '祝田', 'イワイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市沖田', '05', '05207', '0120023', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '沖田', 'オキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市赤土', '05', '05207', '0120024', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '赤土', 'アカツチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市前島', '05', '05207', '0120025', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '前島', 'マエジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市大島', '05', '05207', '0120026', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '大島', 'オオシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市鶴館', '05', '05207', '0120031', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '鶴館', 'ツルダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市元清水', '05', '05207', '0120032', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '元清水', 'モトシミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市清水町', '05', '05207', '0120033', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '清水町', 'シミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市西新町', '05', '05207', '0120034', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '西新町', 'ニシシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市幸町', '05', '05207', '0120035', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市両神', '05', '05207', '0120036', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '両神', 'リョウジン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市沖鶴', '05', '05207', '0120037', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '沖鶴', 'オキツル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市中野', '05', '05207', '0120041', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '中野', 'ナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市小豆田', '05', '05207', '0120042', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '小豆田', 'アヅキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市万石', '05', '05207', '0120043', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '万石', 'マンゴク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市中野々目', '05', '05207', '0120044', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '中野々目', 'ナカノノメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市岡田', '05', '05207', '0120045', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '岡田', 'オカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市深堀', '05', '05207', '0120051', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '深堀', 'フカボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市下中川原', '05', '05207', '0120052', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '下中川原', 'シモナカガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市中川原', '05', '05207', '0120053', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '中川原', 'ナカガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市西中川原', '05', '05207', '0120054', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '西中川原', 'ニシナカガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市山田', '05', '05207', '0120055', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '山田', 'ヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市藤花', '05', '05207', '0120056', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '藤花', 'フジハナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市雄勝田', '05', '05207', '0120057', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '雄勝田', 'オガチタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市松岡', '05', '05207', '0120061', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '松岡', 'マツオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市石塚', '05', '05207', '0120062', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '石塚', 'イシヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市駒形町', '05', '05207', '0120104', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '駒形町', 'コマガタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市川連町', '05', '05207', '0120105', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '川連町', 'カワツラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市三梨町', '05', '05207', '0120106', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '三梨町', 'ミツナシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市稲庭町', '05', '05207', '0120107', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '稲庭町', 'イナニワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市皆瀬', '05', '05207', '0120183', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '皆瀬', 'ミナセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市岩崎', '05', '05207', '0120801', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '岩崎', 'イワサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市成沢', '05', '05207', '0120802', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '成沢', 'ナリサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市杉沢新所', '05', '05207', '0120803', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '杉沢新所', 'スギサワアラトコロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市杉沢', '05', '05207', '0120804', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '杉沢', 'スギサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市桜通り', '05', '05207', '0120811', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '桜通り', 'サクラドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市東赤土山', '05', '05207', '0120812', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '東赤土山', 'ヒガシアカツチヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市前森', '05', '05207', '0120813', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '前森', 'マエモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市大工町', '05', '05207', '0120814', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '大工町', 'ダイクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市古館', '05', '05207', '0120815', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '古館', 'フルダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市山谷', '05', '05207', '0120821', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '山谷', 'ヤマヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市下山谷', '05', '05207', '0120822', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '下山谷', 'シモヤマヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市湯ノ上山', '05', '05207', '0120823', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '湯ノ上山', 'ユノカミヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市湯ノ原', '05', '05207', '0120823', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '湯ノ原', 'ユノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市裏門', '05', '05207', '0120824', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '裏門', 'ウラモン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市佐竹町', '05', '05207', '0120824', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '佐竹町', 'サタケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市北荒町', '05', '05207', '0120825', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '北荒町', 'キタアラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市柳町', '05', '05207', '0120826', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '柳町', 'ヤナギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市表町', '05', '05207', '0120827', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '表町', 'オモテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市角間沢', '05', '05207', '0120831', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '角間沢', 'カクマザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市広沢山', '05', '05207', '0120832', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '広沢山', 'ヒロサワヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市カツクイ沢山', '05', '05207', '0120833', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', 'カツクイ沢山', 'カックイサワヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市岩ノ沢山', '05', '05207', '0120834', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '岩ノ沢山', 'イワノサワヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市鉦打沢', '05', '05207', '0120835', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '鉦打沢', 'カネウチザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市金堀沢山', '05', '05207', '0120836', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '金堀沢山', 'カネホリザワヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市西金堀沢山', '05', '05207', '0120837', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '西金堀沢山', 'ニシカネホリザワヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市蛇野', '05', '05207', '0120838', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '蛇野', 'ヘビノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市大町', '05', '05207', '0120841', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '大町', 'オオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市内舘町', '05', '05207', '0120842', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '内舘町', 'ウチダテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市内町', '05', '05207', '0120843', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '内町', 'ウチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市田町', '05', '05207', '0120844', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '田町', 'タマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市材木町', '05', '05207', '0120845', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '材木町', 'ザイモクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市吹張', '05', '05207', '0120851', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '吹張', 'フッパリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市荒町', '05', '05207', '0120852', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '荒町', 'アラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市新町', '05', '05207', '0120853', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '新町', 'シンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市鳶ケ沢山', '05', '05207', '0120854', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '鳶ケ沢山', 'トビガサワヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市愛宕町', '05', '05207', '0120855', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '愛宕町', 'アタゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市御囲地町', '05', '05207', '0120856', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '御囲地町', 'オカチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市千石町', '05', '05207', '0120857', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '千石町', 'センゴクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市東松沢', '05', '05207', '0120861', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '東松沢', 'ヒガシマツザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市関口', '05', '05207', '0120862', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '関口', 'セキグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市下関', '05', '05207', '0120863', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '下関', 'シモセキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市上関', '05', '05207', '0120864', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '上関', 'カミセキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市沼樋', '05', '05207', '0120865', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '沼樋', 'ヌマドイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市西松沢', '05', '05207', '0120866', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '西松沢', 'ニシマツザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市南台', '05', '05207', '0120867', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '南台', 'ミナミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市西愛宕町', '05', '05207', '0120868', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '西愛宕町', 'ニシアタゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市若葉町', '05', '05207', '0120869', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '若葉町', 'ワカバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都足立区中央本町3丁目', '13', '13121', '1210011', '東京都', 'トウキョウト', '足立区', 'アダチク', '中央本町', 'チュウオウホンチョウ', null, null, '3丁目', '03チョウメ');
INSERT INTO `ms_addresses` VALUES ('4324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都足立区中央本町4丁目', '13', '13121', '1210011', '東京都', 'トウキョウト', '足立区', 'アダチク', '中央本町', 'チュウオウホンチョウ', null, null, '4丁目', '04チョウメ');
INSERT INTO `ms_addresses` VALUES ('4325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都足立区中央本町5丁目', '13', '13121', '1210011', '東京都', 'トウキョウト', '足立区', 'アダチク', '中央本町', 'チュウオウホンチョウ', null, null, '5丁目', '05チョウメ');
INSERT INTO `ms_addresses` VALUES ('4326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都足立区青井4丁目', '13', '13121', '1210012', '東京都', 'トウキョウト', '足立区', 'アダチク', '青井', 'アオイ', null, null, '4丁目', '04チョウメ');
INSERT INTO `ms_addresses` VALUES ('4327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都足立区青井5丁目', '13', '13121', '1210012', '東京都', 'トウキョウト', '足立区', 'アダチク', '青井', 'アオイ', null, null, '5丁目', '05チョウメ');
INSERT INTO `ms_addresses` VALUES ('4328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都足立区青井6丁目', '13', '13121', '1210012', '東京都', 'トウキョウト', '足立区', 'アダチク', '青井', 'アオイ', null, null, '6丁目', '06チョウメ');
INSERT INTO `ms_addresses` VALUES ('4329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都足立区神明', '13', '13121', '1210051', '東京都', 'トウキョウト', '足立区', 'アダチク', '神明', 'シンメイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都足立区六木', '13', '13121', '1210052', '東京都', 'トウキョウト', '足立区', 'アダチク', '六木', 'ムツキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都足立区佐野', '13', '13121', '1210053', '東京都', 'トウキョウト', '足立区', 'アダチク', '佐野', 'サノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都足立区辰沼', '13', '13121', '1210054', '東京都', 'トウキョウト', '足立区', 'アダチク', '辰沼', 'タツヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都足立区加平', '13', '13121', '1210055', '東京都', 'トウキョウト', '足立区', 'アダチク', '加平', 'カヘイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都足立区北加平町', '13', '13121', '1210056', '東京都', 'トウキョウト', '足立区', 'アダチク', '北加平町', 'キタカヘイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都足立区神明南', '13', '13121', '1210057', '東京都', 'トウキョウト', '足立区', 'アダチク', '神明南', 'シンメイミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都足立区花畑', '13', '13121', '1210061', '東京都', 'トウキョウト', '足立区', 'アダチク', '花畑', 'ハナハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都足立区南花畑', '13', '13121', '1210062', '東京都', 'トウキョウト', '足立区', 'アダチク', '南花畑', 'ミナミハナハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都足立区東保木間', '13', '13121', '1210063', '東京都', 'トウキョウト', '足立区', 'アダチク', '東保木間', 'ヒガシホキマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都足立区保木間', '13', '13121', '1210064', '東京都', 'トウキョウト', '足立区', 'アダチク', '保木間', 'ホキマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都足立区東六月町', '13', '13121', '1210071', '東京都', 'トウキョウト', '足立区', 'アダチク', '東六月町', 'ヒガシロクガツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都足立区保塚町', '13', '13121', '1210072', '東京都', 'トウキョウト', '足立区', 'アダチク', '保塚町', 'ホヅカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都足立区六町', '13', '13121', '1210073', '東京都', 'トウキョウト', '足立区', 'アダチク', '六町', 'ロクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都足立区西加平', '13', '13121', '1210074', '東京都', 'トウキョウト', '足立区', 'アダチク', '西加平', 'ニシカヘイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都足立区一ツ家', '13', '13121', '1210075', '東京都', 'トウキョウト', '足立区', 'アダチク', '一ツ家', 'ヒトツヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都足立区平野', '13', '13121', '1210076', '東京都', 'トウキョウト', '足立区', 'アダチク', '平野', 'ヒラノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都足立区東伊興', '13', '13121', '1210801', '東京都', 'トウキョウト', '足立区', 'アダチク', '東伊興', 'ヒガシイコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都足立区伊興本町', '13', '13121', '1210807', '東京都', 'トウキョウト', '足立区', 'アダチク', '伊興本町', 'イコウホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都足立区西保木間', '13', '13121', '1210812', '東京都', 'トウキョウト', '足立区', 'アダチク', '西保木間', 'ニシホキマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都足立区竹の塚', '13', '13121', '1210813', '東京都', 'トウキョウト', '足立区', 'アダチク', '竹の塚', 'タケノツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都足立区六月', '13', '13121', '1210814', '東京都', 'トウキョウト', '足立区', 'アダチク', '六月', 'ロクガツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都足立区島根', '13', '13121', '1210815', '東京都', 'トウキョウト', '足立区', 'アダチク', '島根', 'シマネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都足立区梅島', '13', '13121', '1210816', '東京都', 'トウキョウト', '足立区', 'アダチク', '梅島', 'ウメジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都足立区西竹の塚', '13', '13121', '1210822', '東京都', 'トウキョウト', '足立区', 'アダチク', '西竹の塚', 'ニシタケノツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都足立区伊興', '13', '13121', '1210823', '東京都', 'トウキョウト', '足立区', 'アダチク', '伊興', 'イコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都足立区西伊興', '13', '13121', '1210824', '東京都', 'トウキョウト', '足立区', 'アダチク', '西伊興', 'ニシイコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都足立区西伊興町', '13', '13121', '1210825', '東京都', 'トウキョウト', '足立区', 'アダチク', '西伊興町', 'ニシイコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都足立区舎人', '13', '13121', '1210831', '東京都', 'トウキョウト', '足立区', 'アダチク', '舎人', 'トネリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都足立区古千谷本町', '13', '13121', '1210832', '東京都', 'トウキョウト', '足立区', 'アダチク', '古千谷本町', 'コヂヤホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都足立区古千谷', '13', '13121', '1210833', '東京都', 'トウキョウト', '足立区', 'アダチク', '古千谷', 'コヂヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都足立区入谷町', '13', '13121', '1210834', '東京都', 'トウキョウト', '足立区', 'アダチク', '入谷町', 'イリヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都足立区舎人町', '13', '13121', '1210835', '東京都', 'トウキョウト', '足立区', 'アダチク', '舎人町', 'トネリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都足立区入谷', '13', '13121', '1210836', '東京都', 'トウキョウト', '足立区', 'アダチク', '入谷', 'イリヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都足立区舎人公園', '13', '13121', '1210837', '東京都', 'トウキョウト', '足立区', 'アダチク', '舎人公園', 'トネリコウエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県雄勝郡羽後町', '05', '05463', '0121100', '秋田県', 'アキタケン', '雄勝郡羽後町', 'オガチグンウゴマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('4365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県雄勝郡羽後町大沢', '05', '05463', '0121101', '秋田県', 'アキタケン', '雄勝郡羽後町', 'オガチグンウゴマチ', '大沢', 'オオサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県雄勝郡羽後町新町', '05', '05463', '0121102', '秋田県', 'アキタケン', '雄勝郡羽後町', 'オガチグンウゴマチ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県雄勝郡羽後町林崎', '05', '05463', '0121103', '秋田県', 'アキタケン', '雄勝郡羽後町', 'オガチグンウゴマチ', '林崎', 'ハヤシザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県雄勝郡羽後町堀内', '05', '05463', '0121104', '秋田県', 'アキタケン', '雄勝郡羽後町', 'オガチグンウゴマチ', '堀内', 'ホリウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県雄勝郡羽後町水沢', '05', '05463', '0121105', '秋田県', 'アキタケン', '雄勝郡羽後町', 'オガチグンウゴマチ', '水沢', 'ミズサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県雄勝郡羽後町払体', '05', '05463', '0121106', '秋田県', 'アキタケン', '雄勝郡羽後町', 'オガチグンウゴマチ', '払体', 'ホッタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県雄勝郡羽後町嶋田新田', '05', '05463', '0121111', '秋田県', 'アキタケン', '雄勝郡羽後町', 'オガチグンウゴマチ', '嶋田新田', 'シマダシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県雄勝郡羽後町睦合', '05', '05463', '0121112', '秋田県', 'アキタケン', '雄勝郡羽後町', 'オガチグンウゴマチ', '睦合', 'ムツアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県雄勝郡羽後町郡山', '05', '05463', '0121113', '秋田県', 'アキタケン', '雄勝郡羽後町', 'オガチグンウゴマチ', '郡山', 'コオリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県雄勝郡羽後町糠塚', '05', '05463', '0121114', '秋田県', 'アキタケン', '雄勝郡羽後町', 'オガチグンウゴマチ', '糠塚', 'ヌカヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県雄勝郡羽後町足田', '05', '05463', '0121115', '秋田県', 'アキタケン', '雄勝郡羽後町', 'オガチグンウゴマチ', '足田', 'タラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県雄勝郡羽後町高尾田', '05', '05463', '0121116', '秋田県', 'アキタケン', '雄勝郡羽後町', 'オガチグンウゴマチ', '高尾田', 'タコウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県雄勝郡羽後町大久保', '05', '05463', '0121121', '秋田県', 'アキタケン', '雄勝郡羽後町', 'オガチグンウゴマチ', '大久保', 'オオクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県雄勝郡羽後町柏原', '05', '05463', '0121122', '秋田県', 'アキタケン', '雄勝郡羽後町', 'オガチグンウゴマチ', '柏原', 'カシワバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県雄勝郡羽後町貝沢', '05', '05463', '0121123', '秋田県', 'アキタケン', '雄勝郡羽後町', 'オガチグンウゴマチ', '貝沢', 'カイザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県雄勝郡羽後町赤袴', '05', '05463', '0121124', '秋田県', 'アキタケン', '雄勝郡羽後町', 'オガチグンウゴマチ', '赤袴', 'アカバカマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県雄勝郡羽後町野中', '05', '05463', '0121125', '秋田県', 'アキタケン', '雄勝郡羽後町', 'オガチグンウゴマチ', '野中', 'ノナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県雄勝郡羽後町杉宮', '05', '05463', '0121126', '秋田県', 'アキタケン', '雄勝郡羽後町', 'オガチグンウゴマチ', '杉宮', 'スギノミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県雄勝郡羽後町西馬音内', '05', '05463', '0121131', '秋田県', 'アキタケン', '雄勝郡羽後町', 'オガチグンウゴマチ', '西馬音内', 'ニシモナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県雄勝郡羽後町大戸', '05', '05463', '0121132', '秋田県', 'アキタケン', '雄勝郡羽後町', 'オガチグンウゴマチ', '大戸', 'オオド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県雄勝郡羽後町床舞', '05', '05463', '0121133', '秋田県', 'アキタケン', '雄勝郡羽後町', 'オガチグンウゴマチ', '床舞', 'トコマイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県雄勝郡羽後町田沢', '05', '05463', '0121134', '秋田県', 'アキタケン', '雄勝郡羽後町', 'オガチグンウゴマチ', '田沢', 'タザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県雄勝郡羽後町鹿内', '05', '05463', '0121135', '秋田県', 'アキタケン', '雄勝郡羽後町', 'オガチグンウゴマチ', '鹿内', 'シカナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県雄勝郡羽後町飯沢', '05', '05463', '0121136', '秋田県', 'アキタケン', '雄勝郡羽後町', 'オガチグンウゴマチ', '飯沢', 'イイザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県雄勝郡羽後町西馬音内堀回', '05', '05463', '0121137', '秋田県', 'アキタケン', '雄勝郡羽後町', 'オガチグンウゴマチ', '西馬音内堀回', 'ニシモナイホリマワリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県雄勝郡羽後町田代', '05', '05463', '0121241', '秋田県', 'アキタケン', '雄勝郡羽後町', 'オガチグンウゴマチ', '田代', 'タシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県雄勝郡羽後町上到米', '05', '05463', '0121242', '秋田県', 'アキタケン', '雄勝郡羽後町', 'オガチグンウゴマチ', '上到米', 'カミトウマイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県雄勝郡羽後町軽井沢', '05', '05463', '0121243', '秋田県', 'アキタケン', '雄勝郡羽後町', 'オガチグンウゴマチ', '軽井沢', 'カルイザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県雄勝郡羽後町下仙道', '05', '05463', '0121351', '秋田県', 'アキタケン', '雄勝郡羽後町', 'オガチグンウゴマチ', '下仙道', 'シモセンドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県雄勝郡羽後町中仙道', '05', '05463', '0121352', '秋田県', 'アキタケン', '雄勝郡羽後町', 'オガチグンウゴマチ', '中仙道', 'ナカセンドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県雄勝郡羽後町上仙道', '05', '05463', '0121353', '秋田県', 'アキタケン', '雄勝郡羽後町', 'オガチグンウゴマチ', '上仙道', 'カミセンドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都足立区西新井', '13', '13121', '1230841', '東京都', 'トウキョウト', '足立区', 'アダチク', '西新井', 'ニシアライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都足立区栗原', '13', '13121', '1230842', '東京都', 'トウキョウト', '足立区', 'アダチク', '栗原', 'クリハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都足立区西新井栄町', '13', '13121', '1230843', '東京都', 'トウキョウト', '足立区', 'アダチク', '西新井栄町', 'ニシアライサカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都足立区興野', '13', '13121', '1230844', '東京都', 'トウキョウト', '足立区', 'アダチク', '興野', 'オキノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都足立区西新井本町', '13', '13121', '1230845', '東京都', 'トウキョウト', '足立区', 'アダチク', '西新井本町', 'ニシアライホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都足立区梅田', '13', '13121', '1230851', '東京都', 'トウキョウト', '足立区', 'アダチク', '梅田', 'ウメダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都足立区関原', '13', '13121', '1230852', '東京都', 'トウキョウト', '足立区', 'アダチク', '関原', 'セキバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都足立区本木', '13', '13121', '1230853', '東京都', 'トウキョウト', '足立区', 'アダチク', '本木', 'モトキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都足立区本木東町', '13', '13121', '1230854', '東京都', 'トウキョウト', '足立区', 'アダチク', '本木東町', 'モトキヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都足立区本木南町', '13', '13121', '1230855', '東京都', 'トウキョウト', '足立区', 'アダチク', '本木南町', 'モトキミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都足立区本木西町', '13', '13121', '1230856', '東京都', 'トウキョウト', '足立区', 'アダチク', '本木西町', 'モトキニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都足立区本木北町', '13', '13121', '1230857', '東京都', 'トウキョウト', '足立区', 'アダチク', '本木北町', 'モトキキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都足立区加賀', '13', '13121', '1230861', '東京都', 'トウキョウト', '足立区', 'アダチク', '加賀', 'カガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都足立区皿沼', '13', '13121', '1230862', '東京都', 'トウキョウト', '足立区', 'アダチク', '皿沼', 'サラヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都足立区谷在家', '13', '13121', '1230863', '東京都', 'トウキョウト', '足立区', 'アダチク', '谷在家', 'ヤザイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都足立区鹿浜', '13', '13121', '1230864', '東京都', 'トウキョウト', '足立区', 'アダチク', '鹿浜', 'シカハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都足立区新田', '13', '13121', '1230865', '東京都', 'トウキョウト', '足立区', 'アダチク', '新田', 'シンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都足立区椿', '13', '13121', '1230871', '東京都', 'トウキョウト', '足立区', 'アダチク', '椿', 'ツバキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都足立区江北', '13', '13121', '1230872', '東京都', 'トウキョウト', '足立区', 'アダチク', '江北', 'コウホク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都足立区扇', '13', '13121', '1230873', '東京都', 'トウキョウト', '足立区', 'アダチク', '扇', 'オウギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都足立区堀之内', '13', '13121', '1230874', '東京都', 'トウキョウト', '足立区', 'アダチク', '堀之内', 'ホリノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都葛飾区', '13', '13122', '1240000', '東京都', 'トウキョウト', '葛飾区', 'カツシカク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('4460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都葛飾区小菅', '13', '13122', '1240001', '東京都', 'トウキョウト', '葛飾区', 'カツシカク', '小菅', 'コスゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都葛飾区西亀有1丁目', '13', '13122', '1240002', '東京都', 'トウキョウト', '葛飾区', 'カツシカク', '西亀有', 'ニシカメアリ', null, null, '1丁目', '01チョウメ');
INSERT INTO `ms_addresses` VALUES ('4462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都葛飾区西亀有2丁目', '13', '13122', '1240002', '東京都', 'トウキョウト', '葛飾区', 'カツシカク', '西亀有', 'ニシカメアリ', null, null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('4463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都葛飾区お花茶屋', '13', '13122', '1240003', '東京都', 'トウキョウト', '葛飾区', 'カツシカク', 'お花茶屋', 'オハナヂャヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都葛飾区東堀切', '13', '13122', '1240004', '東京都', 'トウキョウト', '葛飾区', 'カツシカク', '東堀切', 'ヒガシホリキリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都葛飾区宝町', '13', '13122', '1240005', '東京都', 'トウキョウト', '葛飾区', 'カツシカク', '宝町', 'タカラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都葛飾区堀切', '13', '13122', '1240006', '東京都', 'トウキョウト', '葛飾区', 'カツシカク', '堀切', 'ホリキリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都葛飾区四つ木', '13', '13122', '1240011', '東京都', 'トウキョウト', '葛飾区', 'カツシカク', '四つ木', 'ヨツギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都葛飾区立石', '13', '13122', '1240012', '東京都', 'トウキョウト', '葛飾区', 'カツシカク', '立石', 'タテイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都葛飾区東立石', '13', '13122', '1240013', '東京都', 'トウキョウト', '葛飾区', 'カツシカク', '東立石', 'ヒガシタテイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都葛飾区東四つ木', '13', '13122', '1240014', '東京都', 'トウキョウト', '葛飾区', 'カツシカク', '東四つ木', 'ヒガシヨツギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都葛飾区細田', '13', '13122', '1240021', '東京都', 'トウキョウト', '葛飾区', 'カツシカク', '細田', 'ホソダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都葛飾区奥戸', '13', '13122', '1240022', '東京都', 'トウキョウト', '葛飾区', 'カツシカク', '奥戸', 'オクド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都葛飾区東新小岩', '13', '13122', '1240023', '東京都', 'トウキョウト', '葛飾区', 'カツシカク', '東新小岩', 'ヒガシシンコイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都葛飾区新小岩', '13', '13122', '1240024', '東京都', 'トウキョウト', '葛飾区', 'カツシカク', '新小岩', 'シンコイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都葛飾区西新小岩', '13', '13122', '1240025', '東京都', 'トウキョウト', '葛飾区', 'カツシカク', '西新小岩', 'ニシシンコイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都葛飾区西亀有3丁目', '13', '13122', '1250002', '東京都', 'トウキョウト', '葛飾区', 'カツシカク', '西亀有', 'ニシカメアリ', null, null, '3丁目', '03チョウメ');
INSERT INTO `ms_addresses` VALUES ('4500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都葛飾区西亀有4丁目', '13', '13122', '1250002', '東京都', 'トウキョウト', '葛飾区', 'カツシカク', '西亀有', 'ニシカメアリ', null, null, '4丁目', '04チョウメ');
INSERT INTO `ms_addresses` VALUES ('4501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都葛飾区西水元', '13', '13122', '1250031', '東京都', 'トウキョウト', '葛飾区', 'カツシカク', '西水元', 'ニシミズモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都葛飾区水元', '13', '13122', '1250032', '東京都', 'トウキョウト', '葛飾区', 'カツシカク', '水元', 'ミズモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都葛飾区東水元', '13', '13122', '1250033', '東京都', 'トウキョウト', '葛飾区', 'カツシカク', '東水元', 'ヒガシミズモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都葛飾区水元公園', '13', '13122', '1250034', '東京都', 'トウキョウト', '葛飾区', 'カツシカク', '水元公園', 'ミズモトコウエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都葛飾区南水元', '13', '13122', '1250035', '東京都', 'トウキョウト', '葛飾区', 'カツシカク', '南水元', 'ミナミミズモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都葛飾区東金町', '13', '13122', '1250041', '東京都', 'トウキョウト', '葛飾区', 'カツシカク', '東金町', 'ヒガシカナマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都葛飾区金町', '13', '13122', '1250042', '東京都', 'トウキョウト', '葛飾区', 'カツシカク', '金町', 'カナマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都葛飾区金町浄水場', '13', '13122', '1250043', '東京都', 'トウキョウト', '葛飾区', 'カツシカク', '金町浄水場', 'カナマチジョウスイジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都葛飾区新宿', '13', '13122', '1250051', '東京都', 'トウキョウト', '葛飾区', 'カツシカク', '新宿', 'ニイジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都葛飾区柴又', '13', '13122', '1250052', '東京都', 'トウキョウト', '葛飾区', 'カツシカク', '柴又', 'シバマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都葛飾区鎌倉', '13', '13122', '1250053', '東京都', 'トウキョウト', '葛飾区', 'カツシカク', '鎌倉', 'カマクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都葛飾区高砂', '13', '13122', '1250054', '東京都', 'トウキョウト', '葛飾区', 'カツシカク', '高砂', 'タカサゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都葛飾区亀有', '13', '13122', '1250061', '東京都', 'トウキョウト', '葛飾区', 'カツシカク', '亀有', 'カメアリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都葛飾区青戸', '13', '13122', '1250062', '東京都', 'トウキョウト', '葛飾区', 'カツシカク', '青戸', 'アオト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都葛飾区白鳥', '13', '13122', '1250063', '東京都', 'トウキョウト', '葛飾区', 'カツシカク', '白鳥', 'シラトリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市', '05', '05203', '0130000', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('4542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都墨田区', '13', '13107', '1300000', '東京都', 'トウキョウト', '墨田区', 'スミダク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('4543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都墨田区吾妻橋', '13', '13107', '1300001', '東京都', 'トウキョウト', '墨田区', 'スミダク', '吾妻橋', 'アヅマバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都墨田区業平', '13', '13107', '1300002', '東京都', 'トウキョウト', '墨田区', 'スミダク', '業平', 'ナリヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都墨田区横川', '13', '13107', '1300003', '東京都', 'トウキョウト', '墨田区', 'スミダク', '横川', 'ヨコカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都墨田区本所', '13', '13107', '1300004', '東京都', 'トウキョウト', '墨田区', 'スミダク', '本所', 'ホンジョ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都墨田区東駒形', '13', '13107', '1300005', '東京都', 'トウキョウト', '墨田区', 'スミダク', '東駒形', 'ヒガシコマガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市杉沢', '05', '05203', '0130001', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '杉沢', 'スギサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都墨田区石原', '13', '13107', '1300011', '東京都', 'トウキョウト', '墨田区', 'スミダク', '石原', 'イシワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都墨田区太平', '13', '13107', '1300012', '東京都', 'トウキョウト', '墨田区', 'スミダク', '太平', 'タイヘイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都墨田区錦糸', '13', '13107', '1300013', '東京都', 'トウキョウト', '墨田区', 'スミダク', '錦糸', 'キンシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都墨田区亀沢', '13', '13107', '1300014', '東京都', 'トウキョウト', '墨田区', 'スミダク', '亀沢', 'カメザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都墨田区横網', '13', '13107', '1300015', '東京都', 'トウキョウト', '墨田区', 'スミダク', '横網', 'ヨコアミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市追廻', '05', '05203', '0130002', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '追廻', 'オイマワシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都墨田区緑', '13', '13107', '1300021', '東京都', 'トウキョウト', '墨田区', 'スミダク', '緑', 'ミドリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都墨田区江東橋', '13', '13107', '1300022', '東京都', 'トウキョウト', '墨田区', 'スミダク', '江東橋', 'コウトウバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都墨田区立川', '13', '13107', '1300023', '東京都', 'トウキョウト', '墨田区', 'スミダク', '立川', 'タテカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都墨田区菊川', '13', '13107', '1300024', '東京都', 'トウキョウト', '墨田区', 'スミダク', '菊川', 'キクカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都墨田区千歳', '13', '13107', '1300025', '東京都', 'トウキョウト', '墨田区', 'スミダク', '千歳', 'チトセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都墨田区両国', '13', '13107', '1300026', '東京都', 'トウキョウト', '墨田区', 'スミダク', '両国', 'リョウゴク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市台所町', '05', '05203', '0130003', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '台所町', 'ダイドコロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市明永町', '05', '05203', '0130004', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '明永町', 'ミョウエイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市幸町', '05', '05203', '0130005', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市新坂町', '05', '05203', '0130006', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '新坂町', 'シンザカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大鳥町', '05', '05203', '0130007', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大鳥町', 'オオトリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市睦成', '05', '05203', '0130008', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '睦成', 'ムツナリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市城西町', '05', '05203', '0130011', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '城西町', 'シロニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市城山町', '05', '05203', '0130012', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '城山町', 'シロヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市城南町', '05', '05203', '0130013', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '城南町', 'シロミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市上内町', '05', '05203', '0130014', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '上内町', 'カミウチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市羽黒町', '05', '05203', '0130015', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '羽黒町', 'ハグロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市根岸町', '05', '05203', '0130016', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '根岸町', 'ネギシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市蛇の崎町', '05', '05203', '0130017', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '蛇の崎町', 'ジャノサキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市本町', '05', '05203', '0130018', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '本町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市二葉町', '05', '05203', '0130019', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '二葉町', 'フタバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大町', '05', '05203', '0130021', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大町', 'オオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市四日町', '05', '05203', '0130022', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '四日町', 'ヨッカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市中央町', '05', '05203', '0130023', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '中央町', 'チュウオウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市田中町', '05', '05203', '0130024', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '田中町', 'タナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市寿町', '05', '05203', '0130025', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '寿町', 'コトブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大水戸町', '05', '05203', '0130026', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大水戸町', 'オオミトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市平城町', '05', '05203', '0130027', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '平城町', 'ヒラジョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市朝倉町', '05', '05203', '0130028', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '朝倉町', 'アサクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市鍛冶町', '05', '05203', '0130031', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '鍛冶町', 'カジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市清川町', '05', '05203', '0130032', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '清川町', 'キヨカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市旭川', '05', '05203', '0130033', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '旭川', 'アサヒカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市本郷町', '05', '05203', '0130034', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '本郷町', 'ホンゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市平和町', '05', '05203', '0130035', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '平和町', 'ヘイワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市駅前町', '05', '05203', '0130036', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '駅前町', 'エキマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市前郷二番町', '05', '05203', '0130037', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '前郷二番町', 'マエゴウニバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市前郷一番町', '05', '05203', '0130038', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '前郷一番町', 'マエゴウイチバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大沢', '05', '05203', '0130041', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大沢', 'オオサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市前郷', '05', '05203', '0130042', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '前郷', 'マエゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市安田', '05', '05203', '0130043', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '安田', 'ヤスダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市横山町', '05', '05203', '0130044', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '横山町', 'ヨコヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市南町', '05', '05203', '0130045', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '南町', 'ミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市神明町', '05', '05203', '0130046', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '神明町', 'シンメイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市松原町', '05', '05203', '0130047', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '松原町', 'マツバラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市安田原町', '05', '05203', '0130048', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '安田原町', 'ヤスダハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大屋新町', '05', '05203', '0130051', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大屋新町', 'オオヤシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大屋寺内', '05', '05203', '0130052', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大屋寺内', 'オオヤテラウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市外目', '05', '05203', '0130053', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '外目', 'ソトノメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市柳田', '05', '05203', '0130054', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '柳田', 'ヤナギダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市朝日が丘', '05', '05203', '0130055', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '朝日が丘', 'アサヒガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市清水町新田', '05', '05203', '0130056', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '清水町新田', 'シミズマチシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市条里', '05', '05203', '0130060', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '条里', 'ジョウリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市横手町', '05', '05203', '0130061', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '横手町', 'ヨコテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市駅南', '05', '05203', '0130062', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '駅南', 'エキミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市婦気大堤', '05', '05203', '0130063', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '婦気大堤', 'フケオオヅツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市赤坂', '05', '05203', '0130064', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '赤坂', 'アカサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市猪岡', '05', '05203', '0130065', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '猪岡', 'イノオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市塚堀', '05', '05203', '0130066', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '塚堀', 'ツカボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市梅の木町', '05', '05203', '0130068', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '梅の木町', 'ウメノキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市三枚橋', '05', '05203', '0130069', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '三枚橋', 'サンマイバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市八幡', '05', '05203', '0130071', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '八幡', 'ヤワタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市卸町', '05', '05203', '0130072', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '卸町', 'オロシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市赤川', '05', '05203', '0130073', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '赤川', 'アカガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市三本柳', '05', '05203', '0130074', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '三本柳', 'サンボンヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市静町', '05', '05203', '0130075', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '静町', 'シズカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市杉目', '05', '05203', '0130076', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '杉目', 'スギメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市平鹿町上吉田', '05', '05203', '0130101', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '平鹿町上吉田', 'ヒラカマチカミヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市平鹿町醍醐', '05', '05203', '0130102', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '平鹿町醍醐', 'ヒラカマチダイゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市平鹿町下鍋倉', '05', '05203', '0130103', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '平鹿町下鍋倉', 'ヒラカマチシモナベクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市平鹿町樽見内', '05', '05203', '0130104', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '平鹿町樽見内', 'ヒラカマチタルミナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市平鹿町浅舞', '05', '05203', '0130105', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '平鹿町浅舞', 'ヒラカマチアサマイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市平鹿町中吉田', '05', '05203', '0130106', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '平鹿町中吉田', 'ヒラカマチナカヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市平鹿町下吉田', '05', '05203', '0130107', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '平鹿町下吉田', 'ヒラカマチシモヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市雄物川町会塚', '05', '05203', '0130201', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '雄物川町会塚', 'オモノガワマチアイヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市雄物川町砂子田', '05', '05203', '0130202', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '雄物川町砂子田', 'オモノガワマチスナゴタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市雄物川町東里', '05', '05203', '0130203', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '雄物川町東里', 'オモノガワマチトウサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市雄物川町谷地新田', '05', '05203', '0130204', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '雄物川町谷地新田', 'オモノガワマチヤチシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市雄物川町今宿', '05', '05203', '0130205', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '雄物川町今宿', 'オモノガワマチイマシュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市雄物川町二井山', '05', '05203', '0130206', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '雄物川町二井山', 'オモノガワマチニイヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市雄物川町矢神', '05', '05203', '0130207', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '雄物川町矢神', 'オモノガワマチヤガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市雄物川町沼館', '05', '05203', '0130208', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '雄物川町沼館', 'オモノガワマチヌマダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市雄物川町深井', '05', '05203', '0130211', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '雄物川町深井', 'オモノガワマチフカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市雄物川町造山', '05', '05203', '0130212', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '雄物川町造山', 'オモノガワマチツクリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市雄物川町南形', '05', '05203', '0130213', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '雄物川町南形', 'オモノガワマチナンカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市雄物川町柏木', '05', '05203', '0130214', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '雄物川町柏木', 'オモノガワマチカシワギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市雄物川町常野', '05', '05203', '0130215', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '雄物川町常野', 'オモノガワマチジョウノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市雄物川町西野', '05', '05203', '0130216', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '雄物川町西野', 'オモノガワマチニシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市雄物川町道地', '05', '05203', '0130217', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '雄物川町道地', 'オモノガワマチドウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市雄物川町大沢', '05', '05203', '0130218', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '雄物川町大沢', 'オモノガワマチオオサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄福島', '05', '05203', '0130301', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄福島', 'タイユウフクジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄新町北', '05', '05203', '0130302', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄新町北', 'タイユウシンマチキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄福島南', '05', '05203', '0130303', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄福島南', 'タイユウフクジマミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄新町南', '05', '05203', '0130304', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄新町南', 'タイユウシンマチミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄柏木南', '05', '05203', '0130305', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄柏木南', 'タイユウカシワギミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄田村', '05', '05203', '0130306', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄田村', 'タイユウタムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄新町東', '05', '05203', '0130307', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄新町東', 'タイユウシンマチヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄佐加里', '05', '05203', '0130308', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄佐加里', 'タイユウサガリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄佐加里南', '05', '05203', '0130309', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄佐加里南', 'タイユウサガリミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄中野東', '05', '05203', '0130311', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄中野東', 'タイユウナカノヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄中野', '05', '05203', '0130312', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄中野', 'タイユウナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄大森道北', '05', '05203', '0130313', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄大森道北', 'タイユウオオモリミチキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄傾城塚', '05', '05203', '0130314', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄傾城塚', 'タイユウケイセイヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄下根田谷地', '05', '05203', '0130315', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄下根田谷地', 'タイユウシタコンダヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄潤井谷地', '05', '05203', '0130316', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄潤井谷地', 'タイユウウルイヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄大戸川端', '05', '05203', '0130317', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄大戸川端', 'タイユウオオドカワバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄根田谷地南', '05', '05203', '0130318', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄根田谷地南', 'タイユウコンダヤチミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄四ツ屋東', '05', '05203', '0130319', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄四ツ屋東', 'タイユウヨツヤヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄根田谷地西', '05', '05203', '0130321', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄根田谷地西', 'タイユウコンダヤチニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄伝蔵村', '05', '05203', '0130322', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄伝蔵村', 'タイユウデンゾウムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄根田谷地東', '05', '05203', '0130323', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄根田谷地東', 'タイユウコンダヤチヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄根田谷地', '05', '05203', '0130324', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄根田谷地', 'タイユウコンダヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄田根森東', '05', '05203', '0130325', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄田根森東', 'タイユウタネモリヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄上田村東', '05', '05203', '0130326', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄上田村東', 'タイユウカミタムラヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄焼野', '05', '05203', '0130327', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄焼野', 'タイユウヤケノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄東高津野', '05', '05203', '0130331', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄東高津野', 'タイユウヒガシタカヅノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄新町西野添', '05', '05203', '0130332', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄新町西野添', 'タイユウシンマチニシノゾイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄新町西', '05', '05203', '0130333', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄新町西', 'タイユウシンマチニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄新町', '05', '05203', '0130334', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄新町', 'タイユウシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄折橋', '05', '05203', '0130335', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄折橋', 'タイユウオリハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄傾城塚南', '05', '05203', '0130336', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄傾城塚南', 'タイユウケイセイヅカミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄折橋南', '05', '05203', '0130337', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄折橋南', 'タイユウオリハシミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄耳取西', '05', '05203', '0130338', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄耳取西', 'タイユウミミドリニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄耳取', '05', '05203', '0130339', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄耳取', 'タイユウミミドリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄四ツ屋', '05', '05203', '0130341', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄四ツ屋', 'タイユウヨツヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄精兵村', '05', '05203', '0130342', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄精兵村', 'タイユウセイベイムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄田根森西', '05', '05203', '0130343', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄田根森西', 'タイユウタネモリニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄精兵西', '05', '05203', '0130344', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄精兵西', 'タイユウセイベイニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄本庄道北堰間', '05', '05203', '0130345', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄本庄道北堰間', 'タイユウホンジョウミチキタセキマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄四ツ屋西', '05', '05203', '0130346', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄四ツ屋西', 'タイユウヨツヤニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄本庄道南', '05', '05203', '0130347', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄本庄道南', 'タイユウホンジョウミチミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄田根森', '05', '05203', '0130348', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄田根森', 'タイユウタネモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄上田村西', '05', '05203', '0130349', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄上田村西', 'タイユウカミタムラニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄上田村', '05', '05203', '0130351', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄上田村', 'タイユウカミタムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄一ノ関東', '05', '05203', '0130352', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄一ノ関東', 'タイユウイチノセキヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄一ノ関', '05', '05203', '0130353', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄一ノ関', 'タイユウイチノセキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄狐塚', '05', '05203', '0130354', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄狐塚', 'タイユウキツネヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄上桜森', '05', '05203', '0130355', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄上桜森', 'タイユウカミサクラモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄一ノ関南', '05', '05203', '0130356', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄一ノ関南', 'タイユウイチノセキミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄向東', '05', '05203', '0130357', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄向東', 'タイユウムカイヒガシ', null, null, null, null), ('4694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄向', '05', '05203', '0130358', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄向', 'タイユウムカイ', null, null, null, null), ('4695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄柏木', '05', '05203', '0130359', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄柏木', 'タイユウカシワギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄柏木西', '05', '05203', '0130361', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄柏木西', 'タイユウカシワギニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄柏木下', '05', '05203', '0130362', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄柏木下', 'タイユウカシワギシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄桜森西', '05', '05203', '0130363', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄桜森西', 'タイユウサクラモリニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄袋谷地', '05', '05203', '0130364', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄袋谷地', 'タイユウフクロヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄鍛治村', '05', '05203', '0130365', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄鍛治村', 'タイユウカジムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄文蔵開', '05', '05203', '0130371', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄文蔵開', 'タイユウブンゾウビラキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄上田村南', '05', '05203', '0130372', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄上田村南', 'タイユウカミタムラミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄八柏谷地', '05', '05203', '0130373', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄八柏谷地', 'タイユウヤガシワヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄八柏中村東', '05', '05203', '0130374', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄八柏中村東', 'タイユウヤガシワナカムラヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄八柏釜蓋', '05', '05203', '0130375', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄八柏釜蓋', 'タイユウヤガシワカマブタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄八柏馬道添', '05', '05203', '0130376', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄八柏馬道添', 'タイユウヤガシワウマミチゾイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄八柏中村', '05', '05203', '0130377', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄八柏中村', 'タイユウヤガシワナカムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄八柏街道添', '05', '05203', '0130378', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄八柏街道添', 'タイユウヤガシワカイドウゾイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄八柏家間', '05', '05203', '0130379', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄八柏家間', 'タイユウヤガシワイエマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄八柏下村', '05', '05203', '0130381', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄八柏下村', 'タイユウヤガシワシモムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄上堰東', '05', '05203', '0130382', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄上堰東', 'タイユウウワセキヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄八柏村西', '05', '05203', '0130383', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄八柏村西', 'タイユウヤガシワムラニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄八柏村表', '05', '05203', '0130384', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄八柏村表', 'タイユウヤガシワムラオモテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄万貝', '05', '05203', '0130385', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄万貝', 'タイユウマンカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄八柏', '05', '05203', '0130402', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄八柏', 'タイユウヤガシワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄上柏木', '05', '05203', '0130404', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄上柏木', 'タイユウカミカシワギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄南四津屋', '05', '05203', '0130405', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄南四津屋', 'タイユウミナミヨツヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄西四津屋', '05', '05203', '0130406', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄西四津屋', 'タイユウニシヨツヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄四津屋下', '05', '05203', '0130407', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄四津屋下', 'タイユウヨツヤシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄北四津屋', '05', '05203', '0130408', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄北四津屋', 'タイユウキタヨツヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄東四津屋', '05', '05203', '0130409', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄東四津屋', 'タイユウヒガシヨツヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄剰水東', '05', '05203', '0130411', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄剰水東', 'タイユウセセナギヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄剰水', '05', '05203', '0130412', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄剰水', 'タイユウセセナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄宮田', '05', '05203', '0130413', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄宮田', 'タイユウミヤタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄藤巻', '05', '05203', '0130414', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄藤巻', 'タイユウフジマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄藤巻西', '05', '05203', '0130415', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄藤巻西', 'タイユウフジマキニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄藤巻中島', '05', '05203', '0130416', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄藤巻中島', 'タイユウフジマキナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄六町下', '05', '05203', '0130417', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄六町下', 'タイユウロクチョウシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄六町東', '05', '05203', '0130418', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄六町東', 'タイユウロクチョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄六町', '05', '05203', '0130419', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄六町', 'タイユウロクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄江原', '05', '05203', '0130421', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄江原', 'タイユウエバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄南阿気', '05', '05203', '0130422', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄南阿気', 'タイユウミナミアゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄土井尻', '05', '05203', '0130423', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄土井尻', 'タイユウドイジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄中館合', '05', '05203', '0130424', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄中館合', 'タイユウナカタテアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄西館合', '05', '05203', '0130425', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄西館合', 'タイユウニシタテアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄木戸口', '05', '05203', '0130426', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄木戸口', 'タイユウキドグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄阿気', '05', '05203', '0130427', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄阿気', 'タイユウアゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄鶴巻田', '05', '05203', '0130428', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄鶴巻田', 'タイユウツルマキダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄宮小路', '05', '05203', '0130429', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄宮小路', 'タイユウミヤコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄牛中島', '05', '05203', '0130431', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄牛中島', 'タイユウウシナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄東中島', '05', '05203', '0130432', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄東中島', 'タイユウヒガシナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄西中島', '05', '05203', '0130433', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄西中島', 'タイユウニシナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄山王', '05', '05203', '0130434', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄山王', 'タイユウサンノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄木戸口西', '05', '05203', '0130435', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄木戸口西', 'タイユウキドグチニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄小林西', '05', '05203', '0130436', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄小林西', 'タイユウコバヤシニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄小林', '05', '05203', '0130437', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄小林', 'タイユウコバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄木戸口下', '05', '05203', '0130438', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄木戸口下', 'タイユウキドグチシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄山王西', '05', '05203', '0130439', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄山王西', 'タイユウサンノウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄野中', '05', '05203', '0130441', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄野中', 'タイユウノナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄高津野下', '05', '05203', '0130442', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄高津野下', 'タイユウタカヅノシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄高津野', '05', '05203', '0130443', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄高津野', 'タイユウタカヅノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄向田東', '05', '05203', '0130444', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄向田東', 'タイユウムカイダヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄向田', '05', '05203', '0130445', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄向田', 'タイユウムカイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄乗阿気', '05', '05203', '0130446', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄乗阿気', 'タイユウノリアゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄阿久戸', '05', '05203', '0130447', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄阿久戸', 'タイユウアクド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄乗阿気下', '05', '05203', '0130448', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄乗阿気下', 'タイユウノリアゲシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄折橋西', '05', '05203', '0130451', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄折橋西', 'タイユウオリハシニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄大関', '05', '05203', '0130452', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄大関', 'タイユウオオゼキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄三村北', '05', '05203', '0130453', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄三村北', 'タイユウミムラキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄大谷地', '05', '05203', '0130454', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄大谷地', 'タイユウオオヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄大谷地西', '05', '05203', '0130455', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄大谷地西', 'タイユウオオヤチニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄大慈寺前', '05', '05203', '0130456', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄大慈寺前', 'タイユウダイジジマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄大慈寺東', '05', '05203', '0130457', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄大慈寺東', 'タイユウダイジジヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄大慈寺谷地', '05', '05203', '0130458', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄大慈寺谷地', 'タイユウダイジジヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄赤沼', '05', '05203', '0130459', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄赤沼', 'タイユウアカヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄三村東', '05', '05203', '0130461', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄三村東', 'タイユウミムラヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄樋脇', '05', '05203', '0130462', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄樋脇', 'タイユウトヨワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄石持前', '05', '05203', '0130463', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄石持前', 'タイユウイシモチマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄石持', '05', '05203', '0130464', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄石持', 'タイユウイシモチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄石持下', '05', '05203', '0130465', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄石持下', 'タイユウイシモチシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄三村', '05', '05203', '0130466', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄三村', 'タイユウミムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄三村西', '05', '05203', '0130467', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄三村西', 'タイユウミムラニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄中谷地', '05', '05203', '0130468', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄中谷地', 'タイユウナカヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄板橋堰添', '05', '05203', '0130471', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄板橋堰添', 'タイユウイタバシセキゾイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄東阿気', '05', '05203', '0130472', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄東阿気', 'タイユウヒガシアゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄東桜森', '05', '05203', '0130473', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄東桜森', 'タイユウヒガシサクラモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄桜森', '05', '05203', '0130474', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄桜森', 'タイユウサクラモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄桜森前', '05', '05203', '0130475', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄桜森前', 'タイユウサクラモリマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄西桜森', '05', '05203', '0130476', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄西桜森', 'タイユウニシサクラモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄桜森東', '05', '05203', '0130477', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄桜森東', 'タイユウサクラモリヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市雄物川町薄井', '05', '05203', '0130481', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '雄物川町薄井', 'オモノガワマチウスイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄平柳', '05', '05203', '0130482', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄平柳', 'タイユウヒラヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄島田', '05', '05203', '0130483', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄島田', 'タイユウシマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄新処', '05', '05203', '0130484', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄新処', 'タイユウアラトコロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄下新処', '05', '05203', '0130485', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄下新処', 'タイユウシモアラトコロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄田町', '05', '05203', '0130486', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄田町', 'タイユウタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄下田町', '05', '05203', '0130487', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄下田町', 'タイユウシモタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大雄東館合', '05', '05203', '0130488', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大雄東館合', 'タイユウヒガシタテアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大森町板井田', '05', '05203', '0130501', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大森町板井田', 'オオモリマチイタイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大森町袴形', '05', '05203', '0130502', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大森町袴形', 'オオモリマチハカマガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大森町十日町', '05', '05203', '0130503', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大森町十日町', 'オオモリマチトオカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大森町牛中島', '05', '05203', '0130511', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大森町牛中島', 'オオモリマチウシナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大森町湯ノ沢', '05', '05203', '0130512', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大森町湯ノ沢', 'オオモリマチユノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大森町湯ノ島', '05', '05203', '0130513', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大森町湯ノ島', 'オオモリマチユノシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大森町大中島', '05', '05203', '0130514', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大森町大中島', 'オオモリマチオオナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大森町西中島', '05', '05203', '0130515', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大森町西中島', 'オオモリマチニシナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大森町東中島', '05', '05203', '0130516', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大森町東中島', 'オオモリマチヒガシナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大森町高口下水戸堤', '05', '05203', '0130517', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大森町高口下水戸堤', 'オオモリマチタカクチシタミトツツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大森町文天鏡田', '05', '05203', '0130518', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大森町文天鏡田', 'オオモリマチモンテンカガミダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大森町持向', '05', '05203', '0130519', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大森町持向', 'オオモリマチモチムカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大森町大森', '05', '05203', '0130521', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大森町大森', 'オオモリマチオオモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大森町町回', '05', '05203', '0130522', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大森町町回', 'オオモリマチマチマワリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大森町堂林', '05', '05203', '0130523', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大森町堂林', 'オオモリマチドウバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大森町清水上', '05', '05203', '0130524', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大森町清水上', 'オオモリマチシミズノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大森町菅生田', '05', '05203', '0130525', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大森町菅生田', 'オオモリマチスゴウタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大森町西野', '05', '05203', '0130526', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大森町西野', 'オオモリマチニシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大森町佐渡', '05', '05203', '0130531', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大森町佐渡', 'オオモリマチサド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大森町久保', '05', '05203', '0130532', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大森町久保', 'オオモリマチクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大森町中田', '05', '05203', '0130533', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大森町中田', 'オオモリマチナカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大森町峠町頭', '05', '05203', '0130534', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大森町峠町頭', 'オオモリマチトウゲマチガシラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大森町町田', '05', '05203', '0130535', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大森町町田', 'オオモリマチマチダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大森町真山', '05', '05203', '0130536', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大森町真山', 'オオモリマチシンザン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大森町中嶋', '05', '05203', '0130541', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大森町中嶋', 'オオモリマチナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大森町高野中島', '05', '05203', '0130542', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大森町高野中島', 'オオモリマチタカノナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大森町本郷', '05', '05203', '0130543', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大森町本郷', 'オオモリマチホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大森町長助巻', '05', '05203', '0130544', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大森町長助巻', 'オオモリマチチョウスケマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大森町鯲沼', '05', '05203', '0130545', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大森町鯲沼', 'オオモリマチドジョウヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大森町牛ケ沢', '05', '05203', '0130546', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大森町牛ケ沢', 'オオモリマチウシガサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大森町猿田', '05', '05203', '0130551', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大森町猿田', 'オオモリマチサルタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大森町上溝', '05', '05203', '0130552', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大森町上溝', 'オオモリマチウワミゾ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大森町八沢木', '05', '05203', '0130561', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大森町八沢木', 'オオモリマチヤサワギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市大森町坂部', '05', '05203', '0130562', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '大森町坂部', 'オオモリマチサカベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市安本', '05', '05203', '0130811', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '安本', 'ヤスモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市金沢本町', '05', '05203', '0130812', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '金沢本町', 'カネザワモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市金沢', '05', '05203', '0130813', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '金沢', 'カネザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市金沢中野', '05', '05203', '0130814', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '金沢中野', 'カネザワナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市上境', '05', '05203', '0130821', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '上境', 'カミザカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市上八丁', '05', '05203', '0130822', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '上八丁', 'カミハッチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市下八丁', '05', '05203', '0130823', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '下八丁', 'シモハッチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市下境', '05', '05203', '0130824', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '下境', 'シモザカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市百万刈', '05', '05203', '0130825', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '百万刈', 'ヒャクマンガリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市黒川', '05', '05203', '0130826', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '黒川', 'クロカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都墨田区墨田', '13', '13107', '1310031', '東京都', 'トウキョウト', '墨田区', 'スミダク', '墨田', 'スミダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都墨田区東向島', '13', '13107', '1310032', '東京都', 'トウキョウト', '墨田区', 'スミダク', '東向島', 'ヒガシムコウジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都墨田区向島', '13', '13107', '1310033', '東京都', 'トウキョウト', '墨田区', 'スミダク', '向島', 'ムコウジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都墨田区堤通', '13', '13107', '1310034', '東京都', 'トウキョウト', '墨田区', 'スミダク', '堤通', 'ツツミドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都墨田区八広', '13', '13107', '1310041', '東京都', 'トウキョウト', '墨田区', 'スミダク', '八広', 'ヤヒロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都墨田区東墨田', '13', '13107', '1310042', '東京都', 'トウキョウト', '墨田区', 'スミダク', '東墨田', 'ヒガシスミダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都墨田区立花', '13', '13107', '1310043', '東京都', 'トウキョウト', '墨田区', 'スミダク', '立花', 'タチバナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都墨田区文花', '13', '13107', '1310044', '東京都', 'トウキョウト', '墨田区', 'スミダク', '文花', 'ブンカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都墨田区押上', '13', '13107', '1310045', '東京都', 'トウキョウト', '墨田区', 'スミダク', '押上', 'オシアゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都墨田区京島', '13', '13107', '1310046', '東京都', 'トウキョウト', '墨田区', 'スミダク', '京島', 'キョウジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江戸川区', '13', '13123', '1320000', '東京都', 'トウキョウト', '江戸川区', 'エドガワク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('4945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江戸川区新堀', '13', '13123', '1320001', '東京都', 'トウキョウト', '江戸川区', 'エドガワク', '新堀', 'ニイホリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江戸川区谷河内1丁目', '13', '13123', '1320002', '東京都', 'トウキョウト', '江戸川区', 'エドガワク', '谷河内', 'ヤゴウチ', null, null, '1丁目', '01チョウメ');
INSERT INTO `ms_addresses` VALUES ('4947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江戸川区春江町1丁目', '13', '13123', '1320003', '東京都', 'トウキョウト', '江戸川区', 'エドガワク', '春江町', 'ハルエチョウ', null, null, '1丁目', '01チョウメ');
INSERT INTO `ms_addresses` VALUES ('4948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江戸川区春江町2丁目', '13', '13123', '1320003', '東京都', 'トウキョウト', '江戸川区', 'エドガワク', '春江町', 'ハルエチョウ', null, null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('4949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江戸川区春江町3丁目', '13', '13123', '1320003', '東京都', 'トウキョウト', '江戸川区', 'エドガワク', '春江町', 'ハルエチョウ', null, null, '3丁目', '03チョウメ');
INSERT INTO `ms_addresses` VALUES ('4950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江戸川区瑞江', '13', '13123', '1320011', '東京都', 'トウキョウト', '江戸川区', 'エドガワク', '瑞江', 'ミズエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江戸川区江戸川1丁目', '13', '13123', '1320013', '東京都', 'トウキョウト', '江戸川区', 'エドガワク', '江戸川', 'エドガワ', null, null, '1丁目', '01チョウメ');
INSERT INTO `ms_addresses` VALUES ('4952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江戸川区江戸川2丁目', '13', '13123', '1320013', '東京都', 'トウキョウト', '江戸川区', 'エドガワク', '江戸川', 'エドガワ', null, null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('4953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江戸川区江戸川3丁目', '13', '13123', '1320013', '東京都', 'トウキョウト', '江戸川区', 'エドガワク', '江戸川', 'エドガワ', null, null, '3丁目', '03チョウメ');
INSERT INTO `ms_addresses` VALUES ('4954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江戸川区江戸川4丁目', '13', '13123', '1320013', '東京都', 'トウキョウト', '江戸川区', 'エドガワク', '江戸川', 'エドガワ', null, null, '4丁目', '04チョウメ');
INSERT INTO `ms_addresses` VALUES ('4955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江戸川区東瑞江', '13', '13123', '1320014', '東京都', 'トウキョウト', '江戸川区', 'エドガワク', '東瑞江', 'ヒガシミズエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江戸川区西瑞江2丁目', '13', '13123', '1320015', '東京都', 'トウキョウト', '江戸川区', 'エドガワク', '西瑞江', 'ニシミズエ', null, null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('4957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江戸川区西瑞江3丁目', '13', '13123', '1320015', '東京都', 'トウキョウト', '江戸川区', 'エドガワク', '西瑞江', 'ニシミズエ', null, null, '3丁目', '03チョウメ');
INSERT INTO `ms_addresses` VALUES ('4958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江戸川区西瑞江4丁目', '13', '13123', '1320015', '東京都', 'トウキョウト', '江戸川区', 'エドガワク', '西瑞江', 'ニシミズエ', null, null, '4丁目', '04チョウメ');
INSERT INTO `ms_addresses` VALUES ('4959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江戸川区中央', '13', '13123', '1320021', '東京都', 'トウキョウト', '江戸川区', 'エドガワク', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江戸川区大杉', '13', '13123', '1320022', '東京都', 'トウキョウト', '江戸川区', 'エドガワク', '大杉', 'オオスギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江戸川区西一之江', '13', '13123', '1320023', '東京都', 'トウキョウト', '江戸川区', 'エドガワク', '西一之江', 'ニシイチノエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江戸川区一之江', '13', '13123', '1320024', '東京都', 'トウキョウト', '江戸川区', 'エドガワク', '一之江', 'イチノエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江戸川区松江', '13', '13123', '1320025', '東京都', 'トウキョウト', '江戸川区', 'エドガワク', '松江', 'マツエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江戸川区松島', '13', '13123', '1320031', '東京都', 'トウキョウト', '江戸川区', 'エドガワク', '松島', 'マツシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江戸川区西小松川町', '13', '13123', '1320032', '東京都', 'トウキョウト', '江戸川区', 'エドガワク', '西小松川町', 'ニシコマツガワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江戸川区東小松川', '13', '13123', '1320033', '東京都', 'トウキョウト', '江戸川区', 'エドガワク', '東小松川', 'ヒガシコマツガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江戸川区小松川', '13', '13123', '1320034', '東京都', 'トウキョウト', '江戸川区', 'エドガワク', '小松川', 'コマツガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江戸川区平井', '13', '13123', '1320035', '東京都', 'トウキョウト', '江戸川区', 'エドガワク', '平井', 'ヒライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江戸川区谷河内2丁目', '13', '13123', '1330002', '東京都', 'トウキョウト', '江戸川区', 'エドガワク', '谷河内', 'ヤゴウチ', null, null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('4992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江戸川区上一色', '13', '13123', '1330041', '東京都', 'トウキョウト', '江戸川区', 'エドガワク', '上一色', 'カミイッシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江戸川区興宮町', '13', '13123', '1330042', '東京都', 'トウキョウト', '江戸川区', 'エドガワク', '興宮町', 'オキノミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江戸川区松本', '13', '13123', '1330043', '東京都', 'トウキョウト', '江戸川区', 'エドガワク', '松本', 'マツモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江戸川区本一色', '13', '13123', '1330044', '東京都', 'トウキョウト', '江戸川区', 'エドガワク', '本一色', 'ホンイッシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江戸川区北小岩', '13', '13123', '1330051', '東京都', 'トウキョウト', '江戸川区', 'エドガワク', '北小岩', 'キタコイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江戸川区東小岩', '13', '13123', '1330052', '東京都', 'トウキョウト', '江戸川区', 'エドガワク', '東小岩', 'ヒガシコイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江戸川区北篠崎', '13', '13123', '1330053', '東京都', 'トウキョウト', '江戸川区', 'エドガワク', '北篠崎', 'キタシノザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('4999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江戸川区上篠崎', '13', '13123', '1330054', '東京都', 'トウキョウト', '江戸川区', 'エドガワク', '上篠崎', 'カミシノザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江戸川区西篠崎', '13', '13123', '1330055', '東京都', 'トウキョウト', '江戸川区', 'エドガワク', '西篠崎', 'ニシシノザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江戸川区南小岩', '13', '13123', '1330056', '東京都', 'トウキョウト', '江戸川区', 'エドガワク', '南小岩', 'ミナミコイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江戸川区西小岩', '13', '13123', '1330057', '東京都', 'トウキョウト', '江戸川区', 'エドガワク', '西小岩', 'ニシコイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江戸川区篠崎町', '13', '13123', '1330061', '東京都', 'トウキョウト', '江戸川区', 'エドガワク', '篠崎町', 'シノザキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江戸川区東篠崎町', '13', '13123', '1330062', '東京都', 'トウキョウト', '江戸川区', 'エドガワク', '東篠崎町', 'ヒガシシノザキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江戸川区東篠崎', '13', '13123', '1330063', '東京都', 'トウキョウト', '江戸川区', 'エドガワク', '東篠崎', 'ヒガシシノザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江戸川区下篠崎町', '13', '13123', '1330064', '東京都', 'トウキョウト', '江戸川区', 'エドガワク', '下篠崎町', 'シモシノザキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江戸川区南篠崎町', '13', '13123', '1330065', '東京都', 'トウキョウト', '江戸川区', 'エドガワク', '南篠崎町', 'ミナミシノザキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江戸川区東松本', '13', '13123', '1330071', '東京都', 'トウキョウト', '江戸川区', 'エドガワク', '東松本', 'ヒガシマツモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江戸川区鹿骨町', '13', '13123', '1330072', '東京都', 'トウキョウト', '江戸川区', 'エドガワク', '鹿骨町', 'シシボネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江戸川区鹿骨', '13', '13123', '1330073', '東京都', 'トウキョウト', '江戸川区', 'エドガワク', '鹿骨', 'シシボネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江戸川区春江町4丁目', '13', '13123', '1340003', '東京都', 'トウキョウト', '江戸川区', 'エドガワク', '春江町', 'ハルエチョウ', null, null, '4丁目', '04チョウメ');
INSERT INTO `ms_addresses` VALUES ('5021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江戸川区春江町5丁目', '13', '13123', '1340003', '東京都', 'トウキョウト', '江戸川区', 'エドガワク', '春江町', 'ハルエチョウ', null, null, '5丁目', '05チョウメ');
INSERT INTO `ms_addresses` VALUES ('5022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江戸川区江戸川', '13', '13123', '1340013', '東京都', 'トウキョウト', '江戸川区', 'エドガワク', '江戸川', 'エドガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江戸川区西瑞江4丁目', '13', '13123', '1340015', '東京都', 'トウキョウト', '江戸川区', 'エドガワク', '西瑞江', 'ニシミズエ', null, null, '4丁目', '04チョウメ');
INSERT INTO `ms_addresses` VALUES ('5024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江戸川区西瑞江5丁目', '13', '13123', '1340015', '東京都', 'トウキョウト', '江戸川区', 'エドガワク', '西瑞江', 'ニシミズエ', null, null, '5丁目', '05チョウメ');
INSERT INTO `ms_addresses` VALUES ('5025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江戸川区北葛西', '13', '13123', '1340081', '東京都', 'トウキョウト', '江戸川区', 'エドガワク', '北葛西', 'キタカサイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江戸川区宇喜田町', '13', '13123', '1340082', '東京都', 'トウキョウト', '江戸川区', 'エドガワク', '宇喜田町', 'ウキタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江戸川区中葛西', '13', '13123', '1340083', '東京都', 'トウキョウト', '江戸川区', 'エドガワク', '中葛西', 'ナカカサイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江戸川区東葛西', '13', '13123', '1340084', '東京都', 'トウキョウト', '江戸川区', 'エドガワク', '東葛西', 'ヒガシカサイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江戸川区南葛西', '13', '13123', '1340085', '東京都', 'トウキョウト', '江戸川区', 'エドガワク', '南葛西', 'ミナミカサイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江戸川区臨海町', '13', '13123', '1340086', '東京都', 'トウキョウト', '江戸川区', 'エドガワク', '臨海町', 'リンカイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江戸川区清新町', '13', '13123', '1340087', '東京都', 'トウキョウト', '江戸川区', 'エドガワク', '清新町', 'セイシンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江戸川区西葛西', '13', '13123', '1340088', '東京都', 'トウキョウト', '江戸川区', 'エドガワク', '西葛西', 'ニシカサイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江戸川区船堀', '13', '13123', '1340091', '東京都', 'トウキョウト', '江戸川区', 'エドガワク', '船堀', 'フナボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江戸川区一之江町', '13', '13123', '1340092', '東京都', 'トウキョウト', '江戸川区', 'エドガワク', '一之江町', 'イチノエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江戸川区二之江町', '13', '13123', '1340093', '東京都', 'トウキョウト', '江戸川区', 'エドガワク', '二之江町', 'ニノエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江東区', '13', '13108', '1350000', '東京都', 'トウキョウト', '江東区', 'コウトウク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('5066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江東区毛利', '13', '13108', '1350001', '東京都', 'トウキョウト', '江東区', 'コウトウク', '毛利', 'モウリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江東区住吉', '13', '13108', '1350002', '東京都', 'トウキョウト', '江東区', 'コウトウク', '住吉', 'スミヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江東区猿江', '13', '13108', '1350003', '東京都', 'トウキョウト', '江東区', 'コウトウク', '猿江', 'サルエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江東区森下', '13', '13108', '1350004', '東京都', 'トウキョウト', '江東区', 'コウトウク', '森下', 'モリシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江東区高橋', '13', '13108', '1350005', '東京都', 'トウキョウト', '江東区', 'コウトウク', '高橋', 'タカバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江東区常盤', '13', '13108', '1350006', '東京都', 'トウキョウト', '江東区', 'コウトウク', '常盤', 'トキワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江東区新大橋', '13', '13108', '1350007', '東京都', 'トウキョウト', '江東区', 'コウトウク', '新大橋', 'シンオオハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江東区扇橋', '13', '13108', '1350011', '東京都', 'トウキョウト', '江東区', 'コウトウク', '扇橋', 'オウギバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江東区海辺', '13', '13108', '1350012', '東京都', 'トウキョウト', '江東区', 'コウトウク', '海辺', 'ウミベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江東区千田', '13', '13108', '1350013', '東京都', 'トウキョウト', '江東区', 'コウトウク', '千田', 'センダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江東区石島', '13', '13108', '1350014', '東京都', 'トウキョウト', '江東区', 'コウトウク', '石島', 'イシジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江東区千石', '13', '13108', '1350015', '東京都', 'トウキョウト', '江東区', 'コウトウク', '千石', 'センゴク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江東区東陽', '13', '13108', '1350016', '東京都', 'トウキョウト', '江東区', 'コウトウク', '東陽', 'トウヨウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江東区白河', '13', '13108', '1350021', '東京都', 'トウキョウト', '江東区', 'コウトウク', '白河', 'シラカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江東区三好', '13', '13108', '1350022', '東京都', 'トウキョウト', '江東区', 'コウトウク', '三好', 'ミヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江東区平野', '13', '13108', '1350023', '東京都', 'トウキョウト', '江東区', 'コウトウク', '平野', 'ヒラノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江東区清澄', '13', '13108', '1350024', '東京都', 'トウキョウト', '江東区', 'コウトウク', '清澄', 'キヨスミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江東区佐賀', '13', '13108', '1350031', '東京都', 'トウキョウト', '江東区', 'コウトウク', '佐賀', 'サガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江東区福住', '13', '13108', '1350032', '東京都', 'トウキョウト', '江東区', 'コウトウク', '福住', 'フクズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江東区深川', '13', '13108', '1350033', '東京都', 'トウキョウト', '江東区', 'コウトウク', '深川', 'フカガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江東区永代', '13', '13108', '1350034', '東京都', 'トウキョウト', '江東区', 'コウトウク', '永代', 'エイタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江東区冬木', '13', '13108', '1350041', '東京都', 'トウキョウト', '江東区', 'コウトウク', '冬木', 'フユキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江東区木場', '13', '13108', '1350042', '東京都', 'トウキョウト', '江東区', 'コウトウク', '木場', 'キバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江東区塩浜', '13', '13108', '1350043', '東京都', 'トウキョウト', '江東区', 'コウトウク', '塩浜', 'シオハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江東区越中島', '13', '13108', '1350044', '東京都', 'トウキョウト', '江東区', 'コウトウク', '越中島', 'エッチュウジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江東区古石場', '13', '13108', '1350045', '東京都', 'トウキョウト', '江東区', 'コウトウク', '古石場', 'フルイシバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江東区牡丹', '13', '13108', '1350046', '東京都', 'トウキョウト', '江東区', 'コウトウク', '牡丹', 'ボタン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江東区富岡', '13', '13108', '1350047', '東京都', 'トウキョウト', '江東区', 'コウトウク', '富岡', 'トミオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江東区門前仲町', '13', '13108', '1350048', '東京都', 'トウキョウト', '江東区', 'コウトウク', '門前仲町', 'モンゼンナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江東区枝川', '13', '13108', '1350051', '東京都', 'トウキョウト', '江東区', 'コウトウク', '枝川', 'エダガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江東区潮見', '13', '13108', '1350052', '東京都', 'トウキョウト', '江東区', 'コウトウク', '潮見', 'シオミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江東区辰巳', '13', '13108', '1350053', '東京都', 'トウキョウト', '江東区', 'コウトウク', '辰巳', 'タツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江東区豊洲', '13', '13108', '1350061', '東京都', 'トウキョウト', '江東区', 'コウトウク', '豊洲', 'トヨス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江東区東雲', '13', '13108', '1350062', '東京都', 'トウキョウト', '江東区', 'コウトウク', '東雲', 'シノノメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江東区有明', '13', '13108', '1350063', '東京都', 'トウキョウト', '江東区', 'コウトウク', '有明', 'アリアケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江東区青海', '13', '13108', '1350064', '東京都', 'トウキョウト', '江東区', 'コウトウク', '青海', 'アオミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江東区中央防波堤', '13', '13108', '1350065', '東京都', 'トウキョウト', '江東区', 'コウトウク', '中央防波堤', 'チュウオウボウハテイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都港区台場', '13', '13103', '1350091', '東京都', 'トウキョウト', '港区', 'ミナトク', '台場', 'ダイバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都品川区東八潮', '13', '13109', '1350092', '東京都', 'トウキョウト', '品川区', 'シナガワク', '東八潮', 'ヒガシヤシオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江東区豊洲豊洲センタービル　1階', '13', '13108', '1356001', '東京都', 'トウキョウト', '江東区', 'コウトウク', '豊洲', 'トヨス', null, null, '豊洲センタービル　1階', 'トヨスセンタービル　01カイ');
INSERT INTO `ms_addresses` VALUES ('5106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江東区豊洲豊洲センタービル　2階', '13', '13108', '1356002', '東京都', 'トウキョウト', '江東区', 'コウトウク', '豊洲', 'トヨス', null, null, '豊洲センタービル　2階', 'トヨスセンタービル　02カイ');
INSERT INTO `ms_addresses` VALUES ('5107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江東区豊洲豊洲センタービル　3階', '13', '13108', '1356003', '東京都', 'トウキョウト', '江東区', 'コウトウク', '豊洲', 'トヨス', null, null, '豊洲センタービル　3階', 'トヨスセンタービル　03カイ');
INSERT INTO `ms_addresses` VALUES ('5108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江東区豊洲豊洲センタービル　4階', '13', '13108', '1356004', '東京都', 'トウキョウト', '江東区', 'コウトウク', '豊洲', 'トヨス', null, null, '豊洲センタービル　4階', 'トヨスセンタービル　04カイ');
INSERT INTO `ms_addresses` VALUES ('5109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江東区豊洲豊洲センタービル　5階', '13', '13108', '1356005', '東京都', 'トウキョウト', '江東区', 'コウトウク', '豊洲', 'トヨス', null, null, '豊洲センタービル　5階', 'トヨスセンタービル　05カイ');
INSERT INTO `ms_addresses` VALUES ('5110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江東区豊洲豊洲センタービル　6階', '13', '13108', '1356006', '東京都', 'トウキョウト', '江東区', 'コウトウク', '豊洲', 'トヨス', null, null, '豊洲センタービル　6階', 'トヨスセンタービル　06カイ');
INSERT INTO `ms_addresses` VALUES ('5111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江東区豊洲豊洲センタービル　7階', '13', '13108', '1356007', '東京都', 'トウキョウト', '江東区', 'コウトウク', '豊洲', 'トヨス', null, null, '豊洲センタービル　7階', 'トヨスセンタービル　07カイ');
INSERT INTO `ms_addresses` VALUES ('5112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江東区豊洲豊洲センタービル　8階', '13', '13108', '1356008', '東京都', 'トウキョウト', '江東区', 'コウトウク', '豊洲', 'トヨス', null, null, '豊洲センタービル　8階', 'トヨスセンタービル　08カイ');
INSERT INTO `ms_addresses` VALUES ('5113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江東区豊洲豊洲センタービル　9階', '13', '13108', '1356009', '東京都', 'トウキョウト', '江東区', 'コウトウク', '豊洲', 'トヨス', null, null, '豊洲センタービル　9階', 'トヨスセンタービル　09カイ');
INSERT INTO `ms_addresses` VALUES ('5114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江東区豊洲豊洲センタービル　10階', '13', '13108', '1356010', '東京都', 'トウキョウト', '江東区', 'コウトウク', '豊洲', 'トヨス', null, null, '豊洲センタービル　10階', 'トヨスセンタービル　10カイ');
INSERT INTO `ms_addresses` VALUES ('5115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江東区豊洲豊洲センタービル　11階', '13', '13108', '1356011', '東京都', 'トウキョウト', '江東区', 'コウトウク', '豊洲', 'トヨス', null, null, '豊洲センタービル　11階', 'トヨスセンタービル　11カイ');
INSERT INTO `ms_addresses` VALUES ('5116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江東区豊洲豊洲センタービル　12階', '13', '13108', '1356012', '東京都', 'トウキョウト', '江東区', 'コウトウク', '豊洲', 'トヨス', null, null, '豊洲センタービル　12階', 'トヨスセンタービル　12カイ');
INSERT INTO `ms_addresses` VALUES ('5117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江東区豊洲豊洲センタービル　13階', '13', '13108', '1356013', '東京都', 'トウキョウト', '江東区', 'コウトウク', '豊洲', 'トヨス', null, null, '豊洲センタービル　13階', 'トヨスセンタービル　13カイ');
INSERT INTO `ms_addresses` VALUES ('5118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江東区豊洲豊洲センタービル　14階', '13', '13108', '1356014', '東京都', 'トウキョウト', '江東区', 'コウトウク', '豊洲', 'トヨス', null, null, '豊洲センタービル　14階', 'トヨスセンタービル　14カイ');
INSERT INTO `ms_addresses` VALUES ('5119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江東区豊洲豊洲センタービル　15階', '13', '13108', '1356015', '東京都', 'トウキョウト', '江東区', 'コウトウク', '豊洲', 'トヨス', null, null, '豊洲センタービル　15階', 'トヨスセンタービル　15カイ');
INSERT INTO `ms_addresses` VALUES ('5120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江東区豊洲豊洲センタービル　16階', '13', '13108', '1356016', '東京都', 'トウキョウト', '江東区', 'コウトウク', '豊洲', 'トヨス', null, null, '豊洲センタービル　16階', 'トヨスセンタービル　16カイ');
INSERT INTO `ms_addresses` VALUES ('5121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江東区豊洲豊洲センタービル　17階', '13', '13108', '1356017', '東京都', 'トウキョウト', '江東区', 'コウトウク', '豊洲', 'トヨス', null, null, '豊洲センタービル　17階', 'トヨスセンタービル　17カイ');
INSERT INTO `ms_addresses` VALUES ('5122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江東区豊洲豊洲センタービル　18階', '13', '13108', '1356018', '東京都', 'トウキョウト', '江東区', 'コウトウク', '豊洲', 'トヨス', null, null, '豊洲センタービル　18階', 'トヨスセンタービル　18カイ');
INSERT INTO `ms_addresses` VALUES ('5123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江東区豊洲豊洲センタービル　19階', '13', '13108', '1356019', '東京都', 'トウキョウト', '江東区', 'コウトウク', '豊洲', 'トヨス', null, null, '豊洲センタービル　19階', 'トヨスセンタービル　19カイ');
INSERT INTO `ms_addresses` VALUES ('5124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江東区豊洲豊洲センタービル　20階', '13', '13108', '1356020', '東京都', 'トウキョウト', '江東区', 'コウトウク', '豊洲', 'トヨス', null, null, '豊洲センタービル　20階', 'トヨスセンタービル　20カイ');
INSERT INTO `ms_addresses` VALUES ('5125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江東区豊洲豊洲センタービル　21階', '13', '13108', '1356021', '東京都', 'トウキョウト', '江東区', 'コウトウク', '豊洲', 'トヨス', null, null, '豊洲センタービル　21階', 'トヨスセンタービル　21カイ');
INSERT INTO `ms_addresses` VALUES ('5126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江東区豊洲豊洲センタービル　22階', '13', '13108', '1356022', '東京都', 'トウキョウト', '江東区', 'コウトウク', '豊洲', 'トヨス', null, null, '豊洲センタービル　22階', 'トヨスセンタービル　22カイ');
INSERT INTO `ms_addresses` VALUES ('5127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江東区豊洲豊洲センタービル　23階', '13', '13108', '1356023', '東京都', 'トウキョウト', '江東区', 'コウトウク', '豊洲', 'トヨス', null, null, '豊洲センタービル　23階', 'トヨスセンタービル　23カイ');
INSERT INTO `ms_addresses` VALUES ('5128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江東区豊洲豊洲センタービル　24階', '13', '13108', '1356024', '東京都', 'トウキョウト', '江東区', 'コウトウク', '豊洲', 'トヨス', null, null, '豊洲センタービル　24階', 'トヨスセンタービル　24カイ');
INSERT INTO `ms_addresses` VALUES ('5129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江東区豊洲豊洲センタービル　25階', '13', '13108', '1356025', '東京都', 'トウキョウト', '江東区', 'コウトウク', '豊洲', 'トヨス', null, null, '豊洲センタービル　25階', 'トヨスセンタービル　25カイ');
INSERT INTO `ms_addresses` VALUES ('5130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江東区豊洲豊洲センタービル　26階', '13', '13108', '1356026', '東京都', 'トウキョウト', '江東区', 'コウトウク', '豊洲', 'トヨス', null, null, '豊洲センタービル　26階', 'トヨスセンタービル　26カイ');
INSERT INTO `ms_addresses` VALUES ('5131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江東区豊洲豊洲センタービル　27階', '13', '13108', '1356027', '東京都', 'トウキョウト', '江東区', 'コウトウク', '豊洲', 'トヨス', null, null, '豊洲センタービル　27階', 'トヨスセンタービル　27カイ');
INSERT INTO `ms_addresses` VALUES ('5132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江東区豊洲豊洲センタービル　28階', '13', '13108', '1356028', '東京都', 'トウキョウト', '江東区', 'コウトウク', '豊洲', 'トヨス', null, null, '豊洲センタービル　28階', 'トヨスセンタービル　28カイ');
INSERT INTO `ms_addresses` VALUES ('5133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江東区豊洲豊洲センタービル　29階', '13', '13108', '1356029', '東京都', 'トウキョウト', '江東区', 'コウトウク', '豊洲', 'トヨス', null, null, '豊洲センタービル　29階', 'トヨスセンタービル　29カイ');
INSERT INTO `ms_addresses` VALUES ('5134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江東区豊洲豊洲センタービル　30階', '13', '13108', '1356030', '東京都', 'トウキョウト', '江東区', 'コウトウク', '豊洲', 'トヨス', null, null, '豊洲センタービル　30階', 'トヨスセンタービル　30カイ');
INSERT INTO `ms_addresses` VALUES ('5135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江東区豊洲豊洲センタービル　31階', '13', '13108', '1356031', '東京都', 'トウキョウト', '江東区', 'コウトウク', '豊洲', 'トヨス', null, null, '豊洲センタービル　31階', 'トヨスセンタービル　31カイ');
INSERT INTO `ms_addresses` VALUES ('5136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江東区豊洲豊洲センタービル　32階', '13', '13108', '1356032', '東京都', 'トウキョウト', '江東区', 'コウトウク', '豊洲', 'トヨス', null, null, '豊洲センタービル　32階', 'トヨスセンタービル　32カイ');
INSERT INTO `ms_addresses` VALUES ('5137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江東区豊洲豊洲センタービル　33階', '13', '13108', '1356033', '東京都', 'トウキョウト', '江東区', 'コウトウク', '豊洲', 'トヨス', null, null, '豊洲センタービル　33階', 'トヨスセンタービル　33カイ');
INSERT INTO `ms_addresses` VALUES ('5138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江東区豊洲豊洲センタービル　34階', '13', '13108', '1356034', '東京都', 'トウキョウト', '江東区', 'コウトウク', '豊洲', 'トヨス', null, null, '豊洲センタービル　34階', 'トヨスセンタービル　34カイ');
INSERT INTO `ms_addresses` VALUES ('5139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江東区豊洲豊洲センタービル　35階', '13', '13108', '1356035', '東京都', 'トウキョウト', '江東区', 'コウトウク', '豊洲', 'トヨス', null, null, '豊洲センタービル　35階', 'トヨスセンタービル　35カイ');
INSERT INTO `ms_addresses` VALUES ('5140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江東区豊洲豊洲センタービル　36階', '13', '13108', '1356036', '東京都', 'トウキョウト', '江東区', 'コウトウク', '豊洲', 'トヨス', null, null, '豊洲センタービル　36階', 'トヨスセンタービル　36カイ');
INSERT INTO `ms_addresses` VALUES ('5141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江東区豊洲豊洲センタービル　37階', '13', '13108', '1356037', '東京都', 'トウキョウト', '江東区', 'コウトウク', '豊洲', 'トヨス', null, null, '豊洲センタービル　37階', 'トヨスセンタービル　37カイ');
INSERT INTO `ms_addresses` VALUES ('5142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江東区豊洲豊洲センタービル　', '13', '13108', '1356090', '東京都', 'トウキョウト', '江東区', 'コウトウク', '豊洲', 'トヨス', null, null, '豊洲センタービル　', 'トヨスセンタービル　');
INSERT INTO `ms_addresses` VALUES ('5279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江東区亀戸', '13', '13108', '1360071', '東京都', 'トウキョウト', '江東区', 'コウトウク', '亀戸', 'カメイド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江東区大島', '13', '13108', '1360072', '東京都', 'トウキョウト', '江東区', 'コウトウク', '大島', 'オオジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江東区北砂', '13', '13108', '1360073', '東京都', 'トウキョウト', '江東区', 'コウトウク', '北砂', 'キタスナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江東区東砂', '13', '13108', '1360074', '東京都', 'トウキョウト', '江東区', 'コウトウク', '東砂', 'ヒガシスナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江東区新砂', '13', '13108', '1360075', '東京都', 'トウキョウト', '江東区', 'コウトウク', '新砂', 'シンスナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江東区南砂', '13', '13108', '1360076', '東京都', 'トウキョウト', '江東区', 'コウトウク', '南砂', 'ミナミスナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江東区夢の島', '13', '13108', '1360081', '東京都', 'トウキョウト', '江東区', 'コウトウク', '夢の島', 'ユメノシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江東区新木場', '13', '13108', '1360082', '東京都', 'トウキョウト', '江東区', 'コウトウク', '新木場', 'シンキバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都江東区若洲', '13', '13108', '1360083', '東京都', 'トウキョウト', '江東区', 'コウトウク', '若洲', 'ワカス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市', '05', '05212', '0140000', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('5355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都品川区', '13', '13109', '1400000', '東京都', 'トウキョウト', '品川区', 'シナガワク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('5356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都品川区北品川1丁目', '13', '13109', '1400001', '東京都', 'トウキョウト', '品川区', 'シナガワク', '北品川', 'キタシナガワ', null, null, '1丁目', '01チョウメ');
INSERT INTO `ms_addresses` VALUES ('5357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都品川区北品川2丁目', '13', '13109', '1400001', '東京都', 'トウキョウト', '品川区', 'シナガワク', '北品川', 'キタシナガワ', null, null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('5358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都品川区北品川3丁目', '13', '13109', '1400001', '東京都', 'トウキョウト', '品川区', 'シナガワク', '北品川', 'キタシナガワ', null, null, '3丁目', '03チョウメ');
INSERT INTO `ms_addresses` VALUES ('5359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都品川区北品川4丁目', '13', '13109', '1400001', '東京都', 'トウキョウト', '品川区', 'シナガワク', '北品川', 'キタシナガワ', null, null, '4丁目', '04チョウメ');
INSERT INTO `ms_addresses` VALUES ('5360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都品川区東品川', '13', '13109', '1400002', '東京都', 'トウキョウト', '品川区', 'シナガワク', '東品川', 'ヒガシシナガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都品川区八潮', '13', '13109', '1400003', '東京都', 'トウキョウト', '品川区', 'シナガワク', '八潮', 'ヤシオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都品川区南品川', '13', '13109', '1400004', '東京都', 'トウキョウト', '品川区', 'シナガワク', '南品川', 'ミナミシナガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都品川区広町', '13', '13109', '1400005', '東京都', 'トウキョウト', '品川区', 'シナガワク', '広町', 'ヒロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市花館', '05', '05212', '0140001', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '花館', 'ハナダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都品川区東大井', '13', '13109', '1400011', '東京都', 'トウキョウト', '品川区', 'シナガワク', '東大井', 'ヒガシオオイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都品川区勝島', '13', '13109', '1400012', '東京都', 'トウキョウト', '品川区', 'シナガワク', '勝島', 'カツシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都品川区南大井', '13', '13109', '1400013', '東京都', 'トウキョウト', '品川区', 'シナガワク', '南大井', 'ミナミオオイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都品川区大井', '13', '13109', '1400014', '東京都', 'トウキョウト', '品川区', 'シナガワク', '大井', 'オオイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都品川区西大井', '13', '13109', '1400015', '東京都', 'トウキョウト', '品川区', 'シナガワク', '西大井', 'ニシオオイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市花館上町', '05', '05212', '0140002', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '花館上町', 'ハナダテカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市美原町', '05', '05212', '0140003', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '美原町', 'ミハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市泉町', '05', '05212', '0140004', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '泉町', 'イズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市花館柳町', '05', '05212', '0140005', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '花館柳町', 'ハナダテヤナギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市花館中町', '05', '05212', '0140006', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '花館中町', 'ハナダテナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市富士見町', '05', '05212', '0140011', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '富士見町', 'フジミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市幸町', '05', '05212', '0140012', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市朝日町', '05', '05212', '0140013', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '朝日町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市大曲福住町', '05', '05212', '0140014', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '大曲福住町', 'オオマガリフクズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市大曲白金町', '05', '05212', '0140015', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '大曲白金町', 'オオマガリシロガネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市若竹町', '05', '05212', '0140016', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '若竹町', 'ワカタケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市佐野町', '05', '05212', '0140017', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '佐野町', 'サノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市福田町', '05', '05212', '0140021', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '福田町', 'フクダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市大花町', '05', '05212', '0140022', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '大花町', 'オオハナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市大曲黒瀬町', '05', '05212', '0140023', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '大曲黒瀬町', 'オオマガリクロセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市大曲中通町', '05', '05212', '0140024', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '大曲中通町', 'オオマガリナカドオリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市大曲大町', '05', '05212', '0140025', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '大曲大町', 'オオマガリオオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市大曲丸の内町', '05', '05212', '0140026', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '大曲丸の内町', 'オオマガリマルノウチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市大曲通町', '05', '05212', '0140027', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '大曲通町', 'オオマガリトオリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市大曲', '05', '05212', '0140031', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '大曲', 'オオマガリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市東川', '05', '05212', '0140032', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '東川', 'ヒガシカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市和合', '05', '05212', '0140033', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '和合', 'ワゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市大曲住吉町', '05', '05212', '0140034', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '大曲住吉町', 'オオマガリスミヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市大曲丸子町', '05', '05212', '0140041', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '大曲丸子町', 'オオマガリマルコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市大曲福見町', '05', '05212', '0140042', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '大曲福見町', 'オオマガリフクミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市大曲戸巻町', '05', '05212', '0140043', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '大曲戸巻町', 'オオマガリトマキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市戸蒔', '05', '05212', '0140044', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '戸蒔', 'トマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市大曲若葉町', '05', '05212', '0140045', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '大曲若葉町', 'オオマガリワカバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市大曲田町', '05', '05212', '0140046', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '大曲田町', 'オオマガリタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市大曲須和町', '05', '05212', '0140047', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '大曲須和町', 'オオマガリスワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市大曲上大町', '05', '05212', '0140048', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '大曲上大町', 'オオマガリカミオオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市大曲浜町', '05', '05212', '0140051', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '大曲浜町', 'オオマガリハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市大曲川原町', '05', '05212', '0140052', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '大曲川原町', 'オオマガリカワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市大曲花園町', '05', '05212', '0140053', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '大曲花園町', 'オオマガリハナゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市大曲金谷町', '05', '05212', '0140054', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '大曲金谷町', 'オオマガリカナヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市大曲あけぼの町', '05', '05212', '0140055', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '大曲あけぼの町', 'オオマガリアケボノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市大曲緑町', '05', '05212', '0140056', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '大曲緑町', 'オオマガリミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市大曲船場町', '05', '05212', '0140057', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '大曲船場町', 'オオマガリフナバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市大曲栄町', '05', '05212', '0140061', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '大曲栄町', 'オオマガリサカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市大曲上栄町', '05', '05212', '0140062', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '大曲上栄町', 'オオマガリカミサカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市大曲日の出町', '05', '05212', '0140063', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '大曲日の出町', 'オオマガリヒノデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市小貫高畑', '05', '05212', '0140064', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '小貫高畑', 'オヌキタカバタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市下深井', '05', '05212', '0140065', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '下深井', 'シモフカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市川目', '05', '05212', '0140066', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '川目', 'カワノメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市飯田', '05', '05212', '0140067', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '飯田', 'イイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市大曲飯田町', '05', '05212', '0140068', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '大曲飯田町', 'オオマガリイイダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市蛭川', '05', '05212', '0140071', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '蛭川', 'ヒルガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市大曲西根', '05', '05212', '0140072', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '大曲西根', 'オオマガリニシネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市内小友', '05', '05212', '0140073', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '内小友', 'ウチオトモ', null, null, null, null), ('5419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市松倉', '05', '05212', '0140101', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '松倉', 'マツクラ', null, null, null, null), ('5420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市四ツ屋', '05', '05212', '0140102', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '四ツ屋', 'ヨツヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市高関上郷', '05', '05212', '0140103', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '高関上郷', 'タカゼキカミゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市新谷地', '05', '05212', '0140104', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '新谷地', 'ニイヤジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市横堀', '05', '05212', '0140111', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '横堀', 'ヨコボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市板見内', '05', '05212', '0140112', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '板見内', 'イタミナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市堀見内', '05', '05212', '0140113', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '堀見内', 'ホリミナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市福田', '05', '05212', '0140114', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '福田', 'フクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市下鶯野', '05', '05212', '0140201', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '下鶯野', 'シモウグイスノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市上鶯野', '05', '05212', '0140202', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '上鶯野', 'カミウグイスノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市北長野', '05', '05212', '0140203', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '北長野', 'キタナガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市清水', '05', '05212', '0140204', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '清水', 'シミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市鑓見内', '05', '05212', '0140205', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '鑓見内', 'ヤリミナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市長戸呂', '05', '05212', '0140206', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '長戸呂', 'ナガトロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市長野', '05', '05212', '0140207', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '長野', 'ナガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県仙北市', '05', '05215', '0140300', '秋田県', 'アキタケン', '仙北市', 'センボクシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('5436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県仙北市角館町広久内', '05', '05215', '0140301', '秋田県', 'アキタケン', '仙北市', 'センボクシ', '角館町広久内', 'カクノダテマチヒロクナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県仙北市角館町白岩', '05', '05215', '0140302', '秋田県', 'アキタケン', '仙北市', 'センボクシ', '角館町白岩', 'カクノダテマチシライワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県仙北市角館町薗田', '05', '05215', '0140303', '秋田県', 'アキタケン', '仙北市', 'センボクシ', '角館町薗田', 'カクノダテマチソノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県仙北市角館町田町上丁', '05', '05215', '0140311', '秋田県', 'アキタケン', '仙北市', 'センボクシ', '角館町田町上丁', 'カクノダテマチタマチカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県仙北市角館町田町下丁', '05', '05215', '0140312', '秋田県', 'アキタケン', '仙北市', 'センボクシ', '角館町田町下丁', 'カクノダテマチタマチシモチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県仙北市角館町下岩瀬町', '05', '05215', '0140313', '秋田県', 'アキタケン', '仙北市', 'センボクシ', '角館町下岩瀬町', 'カクノダテマチシモイワセマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県仙北市角館町下新町', '05', '05215', '0140315', '秋田県', 'アキタケン', '仙北市', 'センボクシ', '角館町下新町', 'カクノダテマチシモシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県仙北市角館町岩瀬町', '05', '05215', '0140316', '秋田県', 'アキタケン', '仙北市', 'センボクシ', '角館町岩瀬町', 'カクノダテマチイワセマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県仙北市角館町下中町', '05', '05215', '0140317', '秋田県', 'アキタケン', '仙北市', 'センボクシ', '角館町下中町', 'カクノダテマチシモナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県仙北市角館町中町', '05', '05215', '0140318', '秋田県', 'アキタケン', '仙北市', 'センボクシ', '角館町中町', 'カクノダテマチナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県仙北市角館町西勝楽町', '05', '05215', '0140321', '秋田県', 'アキタケン', '仙北市', 'センボクシ', '角館町西勝楽町', 'カクノダテマチニシカツラクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県仙北市角館町七日町', '05', '05215', '0140322', '秋田県', 'アキタケン', '仙北市', 'センボクシ', '角館町七日町', 'カクノダテマチナノカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県仙北市角館町横町', '05', '05215', '0140323', '秋田県', 'アキタケン', '仙北市', 'センボクシ', '角館町横町', 'カクノダテマチヨコマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県仙北市角館町小人町', '05', '05215', '0140324', '秋田県', 'アキタケン', '仙北市', 'センボクシ', '角館町小人町', 'カクノダテマチコビトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県仙北市角館町東勝楽丁', '05', '05215', '0140325', '秋田県', 'アキタケン', '仙北市', 'センボクシ', '角館町東勝楽丁', 'カクノダテマチヒガシカツラクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県仙北市角館町山根町', '05', '05215', '0140326', '秋田県', 'アキタケン', '仙北市', 'センボクシ', '角館町山根町', 'カクノダテマチヤマネマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県仙北市角館町上新町', '05', '05215', '0140327', '秋田県', 'アキタケン', '仙北市', 'センボクシ', '角館町上新町', 'カクノダテマチカミシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県仙北市角館町竹原町', '05', '05215', '0140328', '秋田県', 'アキタケン', '仙北市', 'センボクシ', '角館町竹原町', 'カクノダテマチタケワラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県仙北市角館町表町下丁', '05', '05215', '0140331', '秋田県', 'アキタケン', '仙北市', 'センボクシ', '角館町表町下丁', 'カクノダテマチオモテマチシモチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県仙北市角館町歩行町', '05', '05215', '0140332', '秋田県', 'アキタケン', '仙北市', 'センボクシ', '角館町歩行町', 'カクノダテマチオカチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県仙北市角館町川原町', '05', '05215', '0140333', '秋田県', 'アキタケン', '仙北市', 'センボクシ', '角館町川原町', 'カクノダテマチカワラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県仙北市角館町表町上丁', '05', '05215', '0140334', '秋田県', 'アキタケン', '仙北市', 'センボクシ', '角館町表町上丁', 'カクノダテマチオモテマチカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県仙北市角館町細越町', '05', '05215', '0140335', '秋田県', 'アキタケン', '仙北市', 'センボクシ', '角館町細越町', 'カクノダテマチホソゴエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県仙北市角館町裏町', '05', '05215', '0140336', '秋田県', 'アキタケン', '仙北市', 'センボクシ', '角館町裏町', 'カクノダテマチウラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県仙北市角館町古城', '05', '05215', '0140337', '秋田県', 'アキタケン', '仙北市', 'センボクシ', '角館町古城', 'カクノダテマチフルシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県仙北市角館町雲然', '05', '05215', '0140341', '秋田県', 'アキタケン', '仙北市', 'センボクシ', '角館町雲然', 'カクノダテマチクモシカリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県仙北市角館町八割', '05', '05215', '0140342', '秋田県', 'アキタケン', '仙北市', 'センボクシ', '角館町八割', 'カクノダテマチハチワリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県仙北市角館町下延', '05', '05215', '0140343', '秋田県', 'アキタケン', '仙北市', 'センボクシ', '角館町下延', 'カクノダテマチシモノブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県仙北市角館町西長野', '05', '05215', '0140344', '秋田県', 'アキタケン', '仙北市', 'センボクシ', '角館町西長野', 'カクノダテマチニシナガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県仙北市角館町山谷川崎', '05', '05215', '0140345', '秋田県', 'アキタケン', '仙北市', 'センボクシ', '角館町山谷川崎', 'カクノダテマチヤマヤカワサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県仙北市角館町川原', '05', '05215', '0140346', '秋田県', 'アキタケン', '仙北市', 'センボクシ', '角館町川原', 'カクノダテマチカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県仙北市角館町小勝田', '05', '05215', '0140347', '秋田県', 'アキタケン', '仙北市', 'センボクシ', '角館町小勝田', 'カクノダテマチオガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県仙北市角館町古城山', '05', '05215', '0140351', '秋田県', 'アキタケン', '仙北市', 'センボクシ', '角館町古城山', 'カクノダテマチフルシロヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県仙北市角館町外ノ山', '05', '05215', '0140352', '秋田県', 'アキタケン', '仙北市', 'センボクシ', '角館町外ノ山', 'カクノダテマチトノヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県仙北市角館町西菅沢', '05', '05215', '0140353', '秋田県', 'アキタケン', '仙北市', 'センボクシ', '角館町西菅沢', 'カクノダテマチニシスガザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県仙北市角館町水ノ目沢', '05', '05215', '0140354', '秋田県', 'アキタケン', '仙北市', 'センボクシ', '角館町水ノ目沢', 'カクノダテマチミズノメサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県仙北市角館町外ノ山官有地', '05', '05215', '0140355', '秋田県', 'アキタケン', '仙北市', 'センボクシ', '角館町外ノ山官有地', 'カクノダテマチトノヤマカンユウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県仙北市角館町花場', '05', '05215', '0140356', '秋田県', 'アキタケン', '仙北市', 'センボクシ', '角館町花場', 'カクノダテマチハナバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県仙北市角館町花場下', '05', '05215', '0140357', '秋田県', 'アキタケン', '仙北市', 'センボクシ', '角館町花場下', 'カクノダテマチハナバシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県仙北市角館町川原町後', '05', '05215', '0140358', '秋田県', 'アキタケン', '仙北市', 'センボクシ', '角館町川原町後', 'カクノダテマチカワラマチウシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県仙北市角館町北野', '05', '05215', '0140359', '秋田県', 'アキタケン', '仙北市', 'センボクシ', '角館町北野', 'カクノダテマチキタノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県仙北市角館町鳥木沢', '05', '05215', '0140361', '秋田県', 'アキタケン', '仙北市', 'センボクシ', '角館町鳥木沢', 'カクノダテマチトリキザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県仙北市角館町金山下', '05', '05215', '0140362', '秋田県', 'アキタケン', '仙北市', 'センボクシ', '角館町金山下', 'カクノダテマチカナヤマシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県仙北市角館町下川原', '05', '05215', '0140363', '秋田県', 'アキタケン', '仙北市', 'センボクシ', '角館町下川原', 'カクノダテマチシタガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県仙北市角館町大中嶋', '05', '05215', '0140364', '秋田県', 'アキタケン', '仙北市', 'センボクシ', '角館町大中嶋', 'カクノダテマチオオナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県仙北市角館町菅沢', '05', '05215', '0140365', '秋田県', 'アキタケン', '仙北市', 'センボクシ', '角館町菅沢', 'カクノダテマチスガザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県仙北市角館町下菅沢', '05', '05215', '0140366', '秋田県', 'アキタケン', '仙北市', 'センボクシ', '角館町下菅沢', 'カクノダテマチシモスガザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県仙北市角館町勝楽', '05', '05215', '0140367', '秋田県', 'アキタケン', '仙北市', 'センボクシ', '角館町勝楽', 'カクノダテマチカツラク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県仙北市角館町中菅沢', '05', '05215', '0140368', '秋田県', 'アキタケン', '仙北市', 'センボクシ', '角館町中菅沢', 'カクノダテマチナカスガザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県仙北市角館町上菅沢', '05', '05215', '0140369', '秋田県', 'アキタケン', '仙北市', 'センボクシ', '角館町上菅沢', 'カクノダテマチカミスガザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県仙北市角館町大風呂', '05', '05215', '0140371', '秋田県', 'アキタケン', '仙北市', 'センボクシ', '角館町大風呂', 'カクノダテマチオオフロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県仙北市角館町小館', '05', '05215', '0140372', '秋田県', 'アキタケン', '仙北市', 'センボクシ', '角館町小館', 'カクノダテマチコダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県仙北市角館町岩瀬', '05', '05215', '0140373', '秋田県', 'アキタケン', '仙北市', 'センボクシ', '角館町岩瀬', 'カクノダテマチイワセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県仙北市角館町上野', '05', '05215', '0140374', '秋田県', 'アキタケン', '仙北市', 'センボクシ', '角館町上野', 'カクノダテマチウワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県仙北市角館町岩瀬下タ野', '05', '05215', '0140375', '秋田県', 'アキタケン', '仙北市', 'センボクシ', '角館町岩瀬下タ野', 'カクノダテマチイワセシタノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県仙北市角館町西下タ野', '05', '05215', '0140376', '秋田県', 'アキタケン', '仙北市', 'センボクシ', '角館町西下タ野', 'カクノダテマチニシシタノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県仙北市角館町西田', '05', '05215', '0140377', '秋田県', 'アキタケン', '仙北市', 'センボクシ', '角館町西田', 'カクノダテマチニシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県仙北市角館町西野川原', '05', '05215', '0140378', '秋田県', 'アキタケン', '仙北市', 'センボクシ', '角館町西野川原', 'カクノダテマチニシノカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県仙北市角館町西北野', '05', '05215', '0140379', '秋田県', 'アキタケン', '仙北市', 'センボクシ', '角館町西北野', 'カクノダテマチニシキタノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県仙北市西木町西明寺', '05', '05215', '0140511', '秋田県', 'アキタケン', '仙北市', 'センボクシ', '西木町西明寺', 'ニシキチョウサイミョウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県仙北市西木町上荒井', '05', '05215', '0140512', '秋田県', 'アキタケン', '仙北市', 'センボクシ', '西木町上荒井', 'ニシキチョウカミアライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県仙北市西木町小渕野', '05', '05215', '0140513', '秋田県', 'アキタケン', '仙北市', 'センボクシ', '西木町小渕野', 'ニシキチョウコブチノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県仙北市西木町西荒井', '05', '05215', '0140514', '秋田県', 'アキタケン', '仙北市', 'センボクシ', '西木町西荒井', 'ニシキチョウニシアライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県仙北市西木町門屋', '05', '05215', '0140515', '秋田県', 'アキタケン', '仙北市', 'センボクシ', '西木町門屋', 'ニシキチョウカドヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県仙北市西木町小山田', '05', '05215', '0140516', '秋田県', 'アキタケン', '仙北市', 'センボクシ', '西木町小山田', 'ニシキチョウコヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県仙北市西木町上桧木内', '05', '05215', '0140601', '秋田県', 'アキタケン', '仙北市', 'センボクシ', '西木町上桧木内', 'ニシキチョウカミヒノキナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県仙北市西木町桧木内', '05', '05215', '0140602', '秋田県', 'アキタケン', '仙北市', 'センボクシ', '西木町桧木内', 'ニシキチョウヒノキナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市豊川', '05', '05212', '0140711', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '豊川', 'トヨカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市豊岡', '05', '05212', '0140712', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '豊岡', 'トヨオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市栗沢', '05', '05212', '0140713', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '栗沢', 'クリサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市大神成', '05', '05212', '0140714', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '大神成', 'オオカンナリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市戸地谷', '05', '05212', '0140801', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '戸地谷', 'トチヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市払田', '05', '05212', '0140802', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '払田', 'ホッタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市上野田', '05', '05212', '0140803', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '上野田', 'コウズケタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市橋本', '05', '05212', '0140804', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '橋本', 'ハシモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市高梨', '05', '05212', '0140805', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '高梨', 'タカナシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都品川区北品川5丁目', '13', '13109', '1410001', '東京都', 'トウキョウト', '品川区', 'シナガワク', '北品川', 'キタシナガワ', null, null, '5丁目', '05チョウメ');
INSERT INTO `ms_addresses` VALUES ('5615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都品川区北品川6丁目', '13', '13109', '1410001', '東京都', 'トウキョウト', '品川区', 'シナガワク', '北品川', 'キタシナガワ', null, null, '6丁目', '06チョウメ');
INSERT INTO `ms_addresses` VALUES ('5616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都品川区上大崎', '13', '13109', '1410021', '東京都', 'トウキョウト', '品川区', 'シナガワク', '上大崎', 'カミオオサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都品川区東五反田', '13', '13109', '1410022', '東京都', 'トウキョウト', '品川区', 'シナガワク', '東五反田', 'ヒガシゴタンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都品川区西五反田', '13', '13109', '1410031', '東京都', 'トウキョウト', '品川区', 'シナガワク', '西五反田', 'ニシゴタンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都品川区大崎', '13', '13109', '1410032', '東京都', 'トウキョウト', '品川区', 'シナガワク', '大崎', 'オオサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都品川区西品川', '13', '13109', '1410033', '東京都', 'トウキョウト', '品川区', 'シナガワク', '西品川', 'ニシシナガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県仙北市田沢湖岡崎', '05', '05215', '0141111', '秋田県', 'アキタケン', '仙北市', 'センボクシ', '田沢湖岡崎', 'タザワコオカザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県仙北市田沢湖梅沢', '05', '05215', '0141112', '秋田県', 'アキタケン', '仙北市', 'センボクシ', '田沢湖梅沢', 'タザワコウメザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県仙北市田沢湖卒田', '05', '05215', '0141113', '秋田県', 'アキタケン', '仙北市', 'センボクシ', '田沢湖卒田', 'タザワコソツダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県仙北市田沢湖神代', '05', '05215', '0141114', '秋田県', 'アキタケン', '仙北市', 'センボクシ', '田沢湖神代', 'タザワコジンダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県仙北市田沢湖小松', '05', '05215', '0141115', '秋田県', 'アキタケン', '仙北市', 'センボクシ', '田沢湖小松', 'タザワココマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県仙北市田沢湖角館東前郷', '05', '05215', '0141116', '秋田県', 'アキタケン', '仙北市', 'センボクシ', '田沢湖角館東前郷', 'タザワコカクノダテヒガシマエゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県仙北市田沢湖生保内', '05', '05215', '0141201', '秋田県', 'アキタケン', '仙北市', 'センボクシ', '田沢湖生保内', 'タザワコオボナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県仙北市田沢湖刺巻', '05', '05215', '0141202', '秋田県', 'アキタケン', '仙北市', 'センボクシ', '田沢湖刺巻', 'タザワコサシマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県仙北市田沢湖潟', '05', '05215', '0141203', '秋田県', 'アキタケン', '仙北市', 'センボクシ', '田沢湖潟', 'タザワコカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県仙北市田沢湖田沢', '05', '05215', '0141204', '秋田県', 'アキタケン', '仙北市', 'センボクシ', '田沢湖田沢', 'タザワコタザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県仙北市田沢湖玉川', '05', '05215', '0141205', '秋田県', 'アキタケン', '仙北市', 'センボクシ', '田沢湖玉川', 'タザワコタマガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市六郷西根', '05', '05212', '0141411', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '六郷西根', 'ロクゴウニシネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市藤木', '05', '05212', '0141412', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '藤木', 'フジキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市角間川町', '05', '05212', '0141413', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '角間川町', 'カクマガワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都品川区大崎ThinkParkTower　1階', '13', '13109', '1416001', '東京都', 'トウキョウト', '品川区', 'シナガワク', '大崎', 'オオサキ', null, null, 'ThinkParkTower　1階', 'シンクパークタワー　01カイ');
INSERT INTO `ms_addresses` VALUES ('5638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都品川区大崎ThinkParkTower　2階', '13', '13109', '1416002', '東京都', 'トウキョウト', '品川区', 'シナガワク', '大崎', 'オオサキ', null, null, 'ThinkParkTower　2階', 'シンクパークタワー　02カイ');
INSERT INTO `ms_addresses` VALUES ('5639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都品川区大崎ThinkParkTower　3階', '13', '13109', '1416003', '東京都', 'トウキョウト', '品川区', 'シナガワク', '大崎', 'オオサキ', null, null, 'ThinkParkTower　3階', 'シンクパークタワー　03カイ');
INSERT INTO `ms_addresses` VALUES ('5640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都品川区大崎ThinkParkTower　4階', '13', '13109', '1416004', '東京都', 'トウキョウト', '品川区', 'シナガワク', '大崎', 'オオサキ', null, null, 'ThinkParkTower　4階', 'シンクパークタワー　04カイ');
INSERT INTO `ms_addresses` VALUES ('5641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都品川区大崎ThinkParkTower　5階', '13', '13109', '1416005', '東京都', 'トウキョウト', '品川区', 'シナガワク', '大崎', 'オオサキ', null, null, 'ThinkParkTower　5階', 'シンクパークタワー　05カイ');
INSERT INTO `ms_addresses` VALUES ('5642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都品川区大崎ThinkParkTower　6階', '13', '13109', '1416006', '東京都', 'トウキョウト', '品川区', 'シナガワク', '大崎', 'オオサキ', null, null, 'ThinkParkTower　6階', 'シンクパークタワー　06カイ');
INSERT INTO `ms_addresses` VALUES ('5643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都品川区大崎ThinkParkTower　7階', '13', '13109', '1416007', '東京都', 'トウキョウト', '品川区', 'シナガワク', '大崎', 'オオサキ', null, null, 'ThinkParkTower　7階', 'シンクパークタワー　07カイ');
INSERT INTO `ms_addresses` VALUES ('5644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都品川区大崎ThinkParkTower　8階', '13', '13109', '1416008', '東京都', 'トウキョウト', '品川区', 'シナガワク', '大崎', 'オオサキ', null, null, 'ThinkParkTower　8階', 'シンクパークタワー　08カイ');
INSERT INTO `ms_addresses` VALUES ('5645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都品川区大崎ThinkParkTower　9階', '13', '13109', '1416009', '東京都', 'トウキョウト', '品川区', 'シナガワク', '大崎', 'オオサキ', null, null, 'ThinkParkTower　9階', 'シンクパークタワー　09カイ');
INSERT INTO `ms_addresses` VALUES ('5646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都品川区大崎ThinkParkTower　10階', '13', '13109', '1416010', '東京都', 'トウキョウト', '品川区', 'シナガワク', '大崎', 'オオサキ', null, null, 'ThinkParkTower　10階', 'シンクパークタワー　10カイ');
INSERT INTO `ms_addresses` VALUES ('5647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都品川区大崎ThinkParkTower　11階', '13', '13109', '1416011', '東京都', 'トウキョウト', '品川区', 'シナガワク', '大崎', 'オオサキ', null, null, 'ThinkParkTower　11階', 'シンクパークタワー　11カイ');
INSERT INTO `ms_addresses` VALUES ('5648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都品川区大崎ThinkParkTower　12階', '13', '13109', '1416012', '東京都', 'トウキョウト', '品川区', 'シナガワク', '大崎', 'オオサキ', null, null, 'ThinkParkTower　12階', 'シンクパークタワー　12カイ');
INSERT INTO `ms_addresses` VALUES ('5649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都品川区大崎ThinkParkTower　13階', '13', '13109', '1416013', '東京都', 'トウキョウト', '品川区', 'シナガワク', '大崎', 'オオサキ', null, null, 'ThinkParkTower　13階', 'シンクパークタワー　13カイ');
INSERT INTO `ms_addresses` VALUES ('5650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都品川区大崎ThinkParkTower　14階', '13', '13109', '1416014', '東京都', 'トウキョウト', '品川区', 'シナガワク', '大崎', 'オオサキ', null, null, 'ThinkParkTower　14階', 'シンクパークタワー　14カイ');
INSERT INTO `ms_addresses` VALUES ('5651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都品川区大崎ThinkParkTower　15階', '13', '13109', '1416015', '東京都', 'トウキョウト', '品川区', 'シナガワク', '大崎', 'オオサキ', null, null, 'ThinkParkTower　15階', 'シンクパークタワー　15カイ');
INSERT INTO `ms_addresses` VALUES ('5652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都品川区大崎ThinkParkTower　16階', '13', '13109', '1416016', '東京都', 'トウキョウト', '品川区', 'シナガワク', '大崎', 'オオサキ', null, null, 'ThinkParkTower　16階', 'シンクパークタワー　16カイ');
INSERT INTO `ms_addresses` VALUES ('5653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都品川区大崎ThinkParkTower　17階', '13', '13109', '1416017', '東京都', 'トウキョウト', '品川区', 'シナガワク', '大崎', 'オオサキ', null, null, 'ThinkParkTower　17階', 'シンクパークタワー　17カイ');
INSERT INTO `ms_addresses` VALUES ('5654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都品川区大崎ThinkParkTower　18階', '13', '13109', '1416018', '東京都', 'トウキョウト', '品川区', 'シナガワク', '大崎', 'オオサキ', null, null, 'ThinkParkTower　18階', 'シンクパークタワー　18カイ');
INSERT INTO `ms_addresses` VALUES ('5655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都品川区大崎ThinkParkTower　19階', '13', '13109', '1416019', '東京都', 'トウキョウト', '品川区', 'シナガワク', '大崎', 'オオサキ', null, null, 'ThinkParkTower　19階', 'シンクパークタワー　19カイ');
INSERT INTO `ms_addresses` VALUES ('5656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都品川区大崎ThinkParkTower　20階', '13', '13109', '1416020', '東京都', 'トウキョウト', '品川区', 'シナガワク', '大崎', 'オオサキ', null, null, 'ThinkParkTower　20階', 'シンクパークタワー　20カイ');
INSERT INTO `ms_addresses` VALUES ('5657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都品川区大崎ThinkParkTower　21階', '13', '13109', '1416021', '東京都', 'トウキョウト', '品川区', 'シナガワク', '大崎', 'オオサキ', null, null, 'ThinkParkTower　21階', 'シンクパークタワー　21カイ');
INSERT INTO `ms_addresses` VALUES ('5658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都品川区大崎ThinkParkTower　22階', '13', '13109', '1416022', '東京都', 'トウキョウト', '品川区', 'シナガワク', '大崎', 'オオサキ', null, null, 'ThinkParkTower　22階', 'シンクパークタワー　22カイ');
INSERT INTO `ms_addresses` VALUES ('5659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都品川区大崎ThinkParkTower　23階', '13', '13109', '1416023', '東京都', 'トウキョウト', '品川区', 'シナガワク', '大崎', 'オオサキ', null, null, 'ThinkParkTower　23階', 'シンクパークタワー　23カイ');
INSERT INTO `ms_addresses` VALUES ('5660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都品川区大崎ThinkParkTower　24階', '13', '13109', '1416024', '東京都', 'トウキョウト', '品川区', 'シナガワク', '大崎', 'オオサキ', null, null, 'ThinkParkTower　24階', 'シンクパークタワー　24カイ');
INSERT INTO `ms_addresses` VALUES ('5661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都品川区大崎ThinkParkTower　25階', '13', '13109', '1416025', '東京都', 'トウキョウト', '品川区', 'シナガワク', '大崎', 'オオサキ', null, null, 'ThinkParkTower　25階', 'シンクパークタワー　25カイ');
INSERT INTO `ms_addresses` VALUES ('5662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都品川区大崎ThinkParkTower　26階', '13', '13109', '1416026', '東京都', 'トウキョウト', '品川区', 'シナガワク', '大崎', 'オオサキ', null, null, 'ThinkParkTower　26階', 'シンクパークタワー　26カイ');
INSERT INTO `ms_addresses` VALUES ('5663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都品川区大崎ThinkParkTower　27階', '13', '13109', '1416027', '東京都', 'トウキョウト', '品川区', 'シナガワク', '大崎', 'オオサキ', null, null, 'ThinkParkTower　27階', 'シンクパークタワー　27カイ');
INSERT INTO `ms_addresses` VALUES ('5664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都品川区大崎ThinkParkTower　28階', '13', '13109', '1416028', '東京都', 'トウキョウト', '品川区', 'シナガワク', '大崎', 'オオサキ', null, null, 'ThinkParkTower　28階', 'シンクパークタワー　28カイ');
INSERT INTO `ms_addresses` VALUES ('5665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都品川区大崎ThinkParkTower　29階', '13', '13109', '1416029', '東京都', 'トウキョウト', '品川区', 'シナガワク', '大崎', 'オオサキ', null, null, 'ThinkParkTower　29階', 'シンクパークタワー　29カイ');
INSERT INTO `ms_addresses` VALUES ('5666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都品川区大崎ThinkParkTower　30階', '13', '13109', '1416030', '東京都', 'トウキョウト', '品川区', 'シナガワク', '大崎', 'オオサキ', null, null, 'ThinkParkTower　30階', 'シンクパークタワー　30カイ');
INSERT INTO `ms_addresses` VALUES ('5667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都品川区大崎ThinkParkTower　', '13', '13109', '1416090', '東京都', 'トウキョウト', '品川区', 'シナガワク', '大崎', 'オオサキ', null, null, 'ThinkParkTower　', 'シンクパークタワー　');
INSERT INTO `ms_addresses` VALUES ('5769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都品川区戸越', '13', '13109', '1420041', '東京都', 'トウキョウト', '品川区', 'シナガワク', '戸越', 'トゴシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都品川区豊町', '13', '13109', '1420042', '東京都', 'トウキョウト', '品川区', 'シナガワク', '豊町', 'ユタカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都品川区二葉', '13', '13109', '1420043', '東京都', 'トウキョウト', '品川区', 'シナガワク', '二葉', 'フタバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都品川区平塚', '13', '13109', '1420051', '東京都', 'トウキョウト', '品川区', 'シナガワク', '平塚', 'ヒラツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都品川区東中延', '13', '13109', '1420052', '東京都', 'トウキョウト', '品川区', 'シナガワク', '東中延', 'ヒガシナカノブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都品川区中延', '13', '13109', '1420053', '東京都', 'トウキョウト', '品川区', 'シナガワク', '中延', 'ナカノブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都品川区西中延', '13', '13109', '1420054', '東京都', 'トウキョウト', '品川区', 'シナガワク', '西中延', 'ニシナカノブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都品川区小山台', '13', '13109', '1420061', '東京都', 'トウキョウト', '品川区', 'シナガワク', '小山台', 'コヤマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都品川区小山', '13', '13109', '1420062', '東京都', 'トウキョウト', '品川区', 'シナガワク', '小山', 'コヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都品川区荏原', '13', '13109', '1420063', '東京都', 'トウキョウト', '品川区', 'シナガワク', '荏原', 'エバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都品川区旗の台', '13', '13109', '1420064', '東京都', 'トウキョウト', '品川区', 'シナガワク', '旗の台', 'ハタノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都大田区東海', '13', '13111', '1430001', '東京都', 'トウキョウト', '大田区', 'オオタク', '東海', 'トウカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都大田区城南島', '13', '13111', '1430002', '東京都', 'トウキョウト', '大田区', 'オオタク', '城南島', 'ジョウナンジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都大田区京浜島', '13', '13111', '1430003', '東京都', 'トウキョウト', '大田区', 'オオタク', '京浜島', 'ケイヒンジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都大田区昭和島', '13', '13111', '1430004', '東京都', 'トウキョウト', '大田区', 'オオタク', '昭和島', 'ショウワジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都大田区平和の森公園', '13', '13111', '1430005', '東京都', 'トウキョウト', '大田区', 'オオタク', '平和の森公園', 'ヘイワノモリコウエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都大田区平和島', '13', '13111', '1430006', '東京都', 'トウキョウト', '大田区', 'オオタク', '平和島', 'ヘイワジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都大田区ふるさとの浜辺公園', '13', '13111', '1430007', '東京都', 'トウキョウト', '大田区', 'オオタク', 'ふるさとの浜辺公園', 'フルサトノハマベコウエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都大田区大森本町', '13', '13111', '1430011', '東京都', 'トウキョウト', '大田区', 'オオタク', '大森本町', 'オオモリホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都大田区大森東', '13', '13111', '1430012', '東京都', 'トウキョウト', '大田区', 'オオタク', '大森東', 'オオモリヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都大田区大森南', '13', '13111', '1430013', '東京都', 'トウキョウト', '大田区', 'オオタク', '大森南', 'オオモリミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都大田区大森中', '13', '13111', '1430014', '東京都', 'トウキョウト', '大田区', 'オオタク', '大森中', 'オオモリナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都大田区大森西', '13', '13111', '1430015', '東京都', 'トウキョウト', '大田区', 'オオタク', '大森西', 'オオモリニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都大田区大森北', '13', '13111', '1430016', '東京都', 'トウキョウト', '大田区', 'オオタク', '大森北', 'オオモリキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都大田区北馬込', '13', '13111', '1430021', '東京都', 'トウキョウト', '大田区', 'オオタク', '北馬込', 'キタマゴメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都大田区東馬込', '13', '13111', '1430022', '東京都', 'トウキョウト', '大田区', 'オオタク', '東馬込', 'ヒガシマゴメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都大田区山王', '13', '13111', '1430023', '東京都', 'トウキョウト', '大田区', 'オオタク', '山王', 'サンノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都大田区中央', '13', '13111', '1430024', '東京都', 'トウキョウト', '大田区', 'オオタク', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都大田区南馬込', '13', '13111', '1430025', '東京都', 'トウキョウト', '大田区', 'オオタク', '南馬込', 'ミナミマゴメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都大田区西馬込', '13', '13111', '1430026', '東京都', 'トウキョウト', '大田区', 'オオタク', '西馬込', 'ニシマゴメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都大田区中馬込', '13', '13111', '1430027', '東京都', 'トウキョウト', '大田区', 'オオタク', '中馬込', 'ナカマゴメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都大田区', '13', '13111', '1440000', '東京都', 'トウキョウト', '大田区', 'オオタク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('5846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都大田区東蒲田', '13', '13111', '1440031', '東京都', 'トウキョウト', '大田区', 'オオタク', '東蒲田', 'ヒガシカマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都大田区北糀谷', '13', '13111', '1440032', '東京都', 'トウキョウト', '大田区', 'オオタク', '北糀谷', 'キタコウジヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都大田区東糀谷', '13', '13111', '1440033', '東京都', 'トウキョウト', '大田区', 'オオタク', '東糀谷', 'ヒガシコウジヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都大田区西糀谷', '13', '13111', '1440034', '東京都', 'トウキョウト', '大田区', 'オオタク', '西糀谷', 'ニシコウジヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都大田区南蒲田', '13', '13111', '1440035', '東京都', 'トウキョウト', '大田区', 'オオタク', '南蒲田', 'ミナミカマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都大田区羽田空港', '13', '13111', '1440041', '東京都', 'トウキョウト', '大田区', 'オオタク', '羽田空港', 'ハネダクウコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都大田区羽田旭町', '13', '13111', '1440042', '東京都', 'トウキョウト', '大田区', 'オオタク', '羽田旭町', 'ハネダアサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都大田区羽田', '13', '13111', '1440043', '東京都', 'トウキョウト', '大田区', 'オオタク', '羽田', 'ハネダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都大田区本羽田', '13', '13111', '1440044', '東京都', 'トウキョウト', '大田区', 'オオタク', '本羽田', 'ホンハネダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都大田区南六郷', '13', '13111', '1440045', '東京都', 'トウキョウト', '大田区', 'オオタク', '南六郷', 'ミナミロクゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都大田区東六郷', '13', '13111', '1440046', '東京都', 'トウキョウト', '大田区', 'オオタク', '東六郷', 'ヒガシロクゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都大田区萩中', '13', '13111', '1440047', '東京都', 'トウキョウト', '大田区', 'オオタク', '萩中', 'ハギナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都大田区西蒲田', '13', '13111', '1440051', '東京都', 'トウキョウト', '大田区', 'オオタク', '西蒲田', 'ニシカマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都大田区蒲田', '13', '13111', '1440052', '東京都', 'トウキョウト', '大田区', 'オオタク', '蒲田', 'カマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都大田区蒲田本町', '13', '13111', '1440053', '東京都', 'トウキョウト', '大田区', 'オオタク', '蒲田本町', 'カマタホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都大田区新蒲田', '13', '13111', '1440054', '東京都', 'トウキョウト', '大田区', 'オオタク', '新蒲田', 'シンカマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都大田区仲六郷', '13', '13111', '1440055', '東京都', 'トウキョウト', '大田区', 'オオタク', '仲六郷', 'ナカロクゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都大田区西六郷', '13', '13111', '1440056', '東京都', 'トウキョウト', '大田区', 'オオタク', '西六郷', 'ニシロクゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都大田区石川町', '13', '13111', '1450061', '東京都', 'トウキョウト', '大田区', 'オオタク', '石川町', 'イシカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都大田区北千束', '13', '13111', '1450062', '東京都', 'トウキョウト', '大田区', 'オオタク', '北千束', 'キタセンゾク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都大田区南千束', '13', '13111', '1450063', '東京都', 'トウキョウト', '大田区', 'オオタク', '南千束', 'ミナミセンゾク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都大田区上池台', '13', '13111', '1450064', '東京都', 'トウキョウト', '大田区', 'オオタク', '上池台', 'カミイケダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都大田区東雪谷', '13', '13111', '1450065', '東京都', 'トウキョウト', '大田区', 'オオタク', '東雪谷', 'ヒガシユキガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都大田区南雪谷', '13', '13111', '1450066', '東京都', 'トウキョウト', '大田区', 'オオタク', '南雪谷', 'ミナミユキガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都大田区雪谷大塚町', '13', '13111', '1450067', '東京都', 'トウキョウト', '大田区', 'オオタク', '雪谷大塚町', 'ユキガヤオオツカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都大田区田園調布', '13', '13111', '1450071', '東京都', 'トウキョウト', '大田区', 'オオタク', '田園調布', 'デンエンチョウフ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都大田区田園調布本町', '13', '13111', '1450072', '東京都', 'トウキョウト', '大田区', 'オオタク', '田園調布本町', 'デンエンチョウフホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都大田区北嶺町', '13', '13111', '1450073', '東京都', 'トウキョウト', '大田区', 'オオタク', '北嶺町', 'キタミネマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都大田区東嶺町', '13', '13111', '1450074', '東京都', 'トウキョウト', '大田区', 'オオタク', '東嶺町', 'ヒガシミネマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都大田区西嶺町', '13', '13111', '1450075', '東京都', 'トウキョウト', '大田区', 'オオタク', '西嶺町', 'ニシミネマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都大田区田園調布南', '13', '13111', '1450076', '東京都', 'トウキョウト', '大田区', 'オオタク', '田園調布南', 'デンエンチョウフミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都大田区仲池上', '13', '13111', '1460081', '東京都', 'トウキョウト', '大田区', 'オオタク', '仲池上', 'ナカイケガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都大田区池上', '13', '13111', '1460082', '東京都', 'トウキョウト', '大田区', 'オオタク', '池上', 'イケガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都大田区千鳥', '13', '13111', '1460083', '東京都', 'トウキョウト', '大田区', 'オオタク', '千鳥', 'チドリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都大田区南久が原', '13', '13111', '1460084', '東京都', 'トウキョウト', '大田区', 'オオタク', '南久が原', 'ミナミクガハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都大田区久が原', '13', '13111', '1460085', '東京都', 'トウキョウト', '大田区', 'オオタク', '久が原', 'クガハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都大田区鵜の木', '13', '13111', '1460091', '東京都', 'トウキョウト', '大田区', 'オオタク', '鵜の木', 'ウノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都大田区下丸子', '13', '13111', '1460092', '東京都', 'トウキョウト', '大田区', 'オオタク', '下丸子', 'シモマルコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都大田区矢口', '13', '13111', '1460093', '東京都', 'トウキョウト', '大田区', 'オオタク', '矢口', 'ヤグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都大田区東矢口', '13', '13111', '1460094', '東京都', 'トウキョウト', '大田区', 'オオタク', '東矢口', 'ヒガシヤグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都大田区多摩川', '13', '13111', '1460095', '東京都', 'トウキョウト', '大田区', 'オオタク', '多摩川', 'タマガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市', '05', '05210', '0150000', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('5963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都渋谷区', '13', '13113', '1500000', '東京都', 'トウキョウト', '渋谷区', 'シブヤク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('5964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都渋谷区神宮前', '13', '13113', '1500001', '東京都', 'トウキョウト', '渋谷区', 'シブヤク', '神宮前', 'ジングウマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都渋谷区渋谷', '13', '13113', '1500002', '東京都', 'トウキョウト', '渋谷区', 'シブヤク', '渋谷', 'シブヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都渋谷区東', '13', '13113', '1500011', '東京都', 'トウキョウト', '渋谷区', 'シブヤク', '東', 'ヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都渋谷区広尾', '13', '13113', '1500012', '東京都', 'トウキョウト', '渋谷区', 'シブヤク', '広尾', 'ヒロオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都渋谷区恵比寿', '13', '13113', '1500013', '東京都', 'トウキョウト', '渋谷区', 'シブヤク', '恵比寿', 'エビス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都渋谷区恵比寿西', '13', '13113', '1500021', '東京都', 'トウキョウト', '渋谷区', 'シブヤク', '恵比寿西', 'エビスニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都渋谷区恵比寿南', '13', '13113', '1500022', '東京都', 'トウキョウト', '渋谷区', 'シブヤク', '恵比寿南', 'エビスミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都渋谷区桜丘町', '13', '13113', '1500031', '東京都', 'トウキョウト', '渋谷区', 'シブヤク', '桜丘町', 'サクラガオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都渋谷区鶯谷町', '13', '13113', '1500032', '東京都', 'トウキョウト', '渋谷区', 'シブヤク', '鶯谷町', 'ウグイスダニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都渋谷区猿楽町', '13', '13113', '1500033', '東京都', 'トウキョウト', '渋谷区', 'シブヤク', '猿楽町', 'サルガクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都渋谷区代官山町', '13', '13113', '1500034', '東京都', 'トウキョウト', '渋谷区', 'シブヤク', '代官山町', 'ダイカンヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都渋谷区鉢山町', '13', '13113', '1500035', '東京都', 'トウキョウト', '渋谷区', 'シブヤク', '鉢山町', 'ハチヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都渋谷区南平台町', '13', '13113', '1500036', '東京都', 'トウキョウト', '渋谷区', 'シブヤク', '南平台町', 'ナンペイダイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都渋谷区神南', '13', '13113', '1500041', '東京都', 'トウキョウト', '渋谷区', 'シブヤク', '神南', 'ジンナン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都渋谷区宇田川町', '13', '13113', '1500042', '東京都', 'トウキョウト', '渋谷区', 'シブヤク', '宇田川町', 'ウダガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都渋谷区道玄坂', '13', '13113', '1500043', '東京都', 'トウキョウト', '渋谷区', 'シブヤク', '道玄坂', 'ドウゲンザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都渋谷区円山町', '13', '13113', '1500044', '東京都', 'トウキョウト', '渋谷区', 'シブヤク', '円山町', 'マルヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都渋谷区神泉町', '13', '13113', '1500045', '東京都', 'トウキョウト', '渋谷区', 'シブヤク', '神泉町', 'シンセンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都渋谷区松濤', '13', '13113', '1500046', '東京都', 'トウキョウト', '渋谷区', 'シブヤク', '松濤', 'ショウトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都渋谷区神山町', '13', '13113', '1500047', '東京都', 'トウキョウト', '渋谷区', 'シブヤク', '神山町', 'カミヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市石脇', '05', '05210', '0150011', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '石脇', 'イシワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市石脇田尻', '05', '05210', '0150012', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '石脇', 'イシワキ', null, null, '田尻', 'タジリ');
INSERT INTO `ms_addresses` VALUES ('5986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市石脇田尻野', '05', '05210', '0150013', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '石脇', 'イシワキ', null, null, '田尻野', 'タジリノ');
INSERT INTO `ms_addresses` VALUES ('5987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市石脇山ノ神', '05', '05210', '0150014', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '石脇', 'イシワキ', null, null, '山ノ神', 'ヤマノカミ');
INSERT INTO `ms_addresses` VALUES ('5988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市大浦', '05', '05210', '0150021', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '大浦', 'オオラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市内黒瀬', '05', '05210', '0150022', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '内黒瀬', 'ウチクロセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市赤田', '05', '05210', '0150023', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '赤田', 'アカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市内越', '05', '05210', '0150024', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '内越', 'ウテツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市山田', '05', '05210', '0150025', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '山田', 'ヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市浜三川', '05', '05210', '0150031', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '浜三川', 'ハマサンカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市松ケ崎', '05', '05210', '0150032', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '松ケ崎', 'マツガサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市神沢', '05', '05210', '0150033', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '神沢', 'シンノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市芦川', '05', '05210', '0150034', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '芦川', 'アシカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市親川', '05', '05210', '0150035', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '親川', 'オヤカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('5998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市薬師堂', '05', '05210', '0150041', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '薬師堂', 'ヤクシドウ', null, null, null, null), ('5999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市埋田', '05', '05210', '0150042', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '埋田', 'ウメダ', null, null, null, null), ('6000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市宮内', '05', '05210', '0150043', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '宮内', 'ミヤウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市玉ノ池', '05', '05210', '0150044', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '玉ノ池', 'タマノイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市葛法', '05', '05210', '0150045', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '葛法', 'クズノリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市船岡', '05', '05210', '0150046', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '船岡', 'フナオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市藤崎', '05', '05210', '0150047', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '藤崎', 'フジサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市川口', '05', '05210', '0150051', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '川口', 'カワグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市畑谷', '05', '05210', '0150052', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '畑谷', 'ハタヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市福山', '05', '05210', '0150053', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '福山', 'フクヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市土谷谷地', '05', '05210', '0150054', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '土谷', 'ツチヤ', null, null, '谷地', 'ヤチ');
INSERT INTO `ms_addresses` VALUES ('6009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市土谷', '05', '05210', '0150055', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '土谷', 'ツチヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市二十六木', '05', '05210', '0150061', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '二十六木', 'トドロキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市大中ノ沢', '05', '05210', '0150062', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '大中ノ沢', 'オオナカノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市舘前', '05', '05210', '0150063', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '舘前', 'タテマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市万願寺', '05', '05210', '0150064', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '万願寺', 'マンガンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市荒町', '05', '05210', '0150065', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '荒町', 'アラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市金山', '05', '05210', '0150066', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '金山', 'カネヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市三条', '05', '05210', '0150067', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '三条', 'サンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市南ノ股', '05', '05210', '0150068', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '南ノ股', 'ミナミノマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市北ノ股', '05', '05210', '0150069', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '北ノ股', 'キタノマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市赤沼町', '05', '05210', '0150071', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '赤沼町', 'アカヌママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市裏尾崎町', '05', '05210', '0150072', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '裏尾崎町', 'ウラオザキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市笹道', '05', '05210', '0150073', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '笹道', 'ササミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市桜小路', '05', '05210', '0150074', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '桜小路', 'サクラコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市花畑町', '05', '05210', '0150075', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '花畑町', 'ハナバタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市東町', '05', '05210', '0150076', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '東町', 'ヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市本田仲町', '05', '05210', '0150077', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '本田仲町', 'ホンタナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市谷地町', '05', '05210', '0150078', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '谷地町', 'ヤチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市赤沼下道', '05', '05210', '0150079', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '赤沼下道', 'アカヌマシタミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市雪車町', '05', '05210', '0150081', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '雪車町', 'ソリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市宮沢', '05', '05210', '0150082', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '宮沢', 'ミヤザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市滝ノ沢', '05', '05210', '0150083', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '滝ノ沢', 'タキノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市鮎瀬', '05', '05210', '0150084', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '鮎瀬', 'アユセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市烏川', '05', '05210', '0150085', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '烏川', 'カラスカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市舘', '05', '05210', '0150086', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '舘', 'タテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市湯沢', '05', '05210', '0150087', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '湯沢', 'ユザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市柳生', '05', '05210', '0150088', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '柳生', 'ヤギュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市鳥田目', '05', '05210', '0150089', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '鳥田目', 'トリタメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市大簗', '05', '05210', '0150091', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '大簗', 'オオヤナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市山内', '05', '05210', '0150092', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '山内', 'ヤマウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市大沢', '05', '05210', '0150093', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '大沢', 'オオサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市上野', '05', '05210', '0150094', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '上野', 'ウワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市東由利法内', '05', '05210', '0150201', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '東由利法内', 'ヒガシユリホウナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市東由利蔵', '05', '05210', '0150202', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '東由利蔵', 'ヒガシユリクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市東由利老方', '05', '05210', '0150211', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '東由利老方', 'ヒガシユリオイカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市東由利舘合', '05', '05210', '0150221', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '東由利舘合', 'ヒガシユリタテアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市東由利黒渕', '05', '05210', '0150231', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '東由利黒渕', 'ヒガシユリクロブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市東由利田代', '05', '05210', '0150232', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '東由利田代', 'ヒガシユリタシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市東由利宿', '05', '05210', '0150241', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '東由利宿', 'ヒガシユリシュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市東由利杉森', '05', '05210', '0150242', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '東由利杉森', 'ヒガシユリスギモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市山内三ツ方森', '05', '05210', '0150243', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '山内', 'ヤマウチ', null, null, '三ツ方森', 'ミツカタモリ');
INSERT INTO `ms_addresses` VALUES ('6051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市飯沢', '05', '05210', '0150301', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '飯沢', 'イイザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市久保田', '05', '05210', '0150302', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '久保田', 'クボタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市陳ケ森', '05', '05210', '0150303', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '陳ケ森', 'ジンガモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市曲沢', '05', '05210', '0150304', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '曲沢', 'マガリサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市五十土', '05', '05210', '0150311', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '五十土', 'イカヅチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市大水口', '05', '05210', '0150312', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '大水口', 'オオミナクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市小菅野', '05', '05210', '0150313', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '小菅野', 'コスガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市東中沢', '05', '05210', '0150314', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '東中沢', 'ヒガシナカザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市蟹沢', '05', '05210', '0150321', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '蟹沢', 'カニザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市新上条', '05', '05210', '0150322', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '新上条', 'シンカミジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市土倉', '05', '05210', '0150323', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '土倉', 'ツチクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市吉沢', '05', '05210', '0150324', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '吉沢', 'ヨシザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市川西', '05', '05210', '0150331', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '川西', 'カワニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市森子', '05', '05210', '0150332', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '森子', 'モリコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市山本', '05', '05210', '0150333', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '山本', 'ヤマモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市前郷', '05', '05210', '0150341', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '前郷', 'マエゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市堰口', '05', '05210', '0150351', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '堰口', 'セキグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市西沢', '05', '05210', '0150352', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '西沢', 'ニシサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市平石', '05', '05210', '0150353', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '平石', 'ヒライシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市黒沢', '05', '05210', '0150361', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '黒沢', 'クロサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市東鮎川', '05', '05210', '0150362', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '東鮎川', 'ヒガシアユカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市町村', '05', '05210', '0150363', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '町村', 'マチムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市南福田', '05', '05210', '0150364', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '南福田', 'ミナミフクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市矢島町田中町', '05', '05210', '0150401', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '矢島町田中町', 'ヤシママチタナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市矢島町矢島町', '05', '05210', '0150402', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '矢島町矢島町', 'ヤシママチヤシママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市矢島町舘町', '05', '05210', '0150403', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '矢島町舘町', 'ヤシママチタテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市矢島町七日町', '05', '05210', '0150404', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '矢島町七日町', 'ヤシママチナノカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市矢島町城内', '05', '05210', '0150411', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '矢島町城内', 'ヤシママチジョウナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市矢島町川辺', '05', '05210', '0150412', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '矢島町川辺', 'ヤシママチカワベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市矢島町木在', '05', '05210', '0150413', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '矢島町木在', 'ヤシママチキサラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市矢島町立石', '05', '05210', '0150414', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '矢島町立石', 'ヤシママチタテイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市矢島町新荘', '05', '05210', '0150415', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '矢島町新荘', 'ヤシママチシンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市矢島町坂之下', '05', '05210', '0150416', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '矢島町坂之下', 'ヤシママチサカノシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市矢島町元町', '05', '05210', '0150417', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '矢島町元町', 'ヤシママチモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市矢島町荒沢', '05', '05210', '0150418', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '矢島町荒沢', 'ヤシママチアラサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市鳥海町伏見', '05', '05210', '0150501', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '鳥海町伏見', 'チョウカイマチフシミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市鳥海町下川内', '05', '05210', '0150502', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '鳥海町下川内', 'チョウカイマチシモカワウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市鳥海町栗沢', '05', '05210', '0150503', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '鳥海町栗沢', 'チョウカイマチクリサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市鳥海町上川内', '05', '05210', '0150504', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '鳥海町上川内', 'チョウカイマチカミカワウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市鳥海町小川', '05', '05210', '0150505', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '鳥海町小川', 'チョウカイマチコガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市鳥海町戈之神', '05', '05210', '0150511', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '鳥海町戈之神', 'チョウカイマチサイノカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市鳥海町猿倉', '05', '05210', '0150512', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '鳥海町猿倉', 'チョウカイマチサルクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市鳥海町下直根', '05', '05210', '0150513', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '鳥海町下直根', 'チョウカイマチシモヒタネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市鳥海町中直根', '05', '05210', '0150514', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '鳥海町中直根', 'チョウカイマチナカヒタネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市鳥海町上直根', '05', '05210', '0150515', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '鳥海町上直根', 'チョウカイマチカミヒタネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市鳥海町百宅', '05', '05210', '0150516', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '鳥海町百宅', 'チョウカイマチモモヤケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都渋谷区恵比寿恵比寿ガーデンプレイス　1階', '13', '13113', '1506001', '東京都', 'トウキョウト', '渋谷区', 'シブヤク', '恵比寿', 'エビス', null, null, '恵比寿ガーデンプレイス　1階', 'エビスガーデンプレイス　01カイ');
INSERT INTO `ms_addresses` VALUES ('6098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都渋谷区恵比寿恵比寿ガーデンプレイス　2階', '13', '13113', '1506002', '東京都', 'トウキョウト', '渋谷区', 'シブヤク', '恵比寿', 'エビス', null, null, '恵比寿ガーデンプレイス　2階', 'エビスガーデンプレイス　02カイ');
INSERT INTO `ms_addresses` VALUES ('6099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都渋谷区恵比寿恵比寿ガーデンプレイス　3階', '13', '13113', '1506003', '東京都', 'トウキョウト', '渋谷区', 'シブヤク', '恵比寿', 'エビス', null, null, '恵比寿ガーデンプレイス　3階', 'エビスガーデンプレイス　03カイ');
INSERT INTO `ms_addresses` VALUES ('6100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都渋谷区恵比寿恵比寿ガーデンプレイス　4階', '13', '13113', '1506004', '東京都', 'トウキョウト', '渋谷区', 'シブヤク', '恵比寿', 'エビス', null, null, '恵比寿ガーデンプレイス　4階', 'エビスガーデンプレイス　04カイ');
INSERT INTO `ms_addresses` VALUES ('6101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都渋谷区恵比寿恵比寿ガーデンプレイス　5階', '13', '13113', '1506005', '東京都', 'トウキョウト', '渋谷区', 'シブヤク', '恵比寿', 'エビス', null, null, '恵比寿ガーデンプレイス　5階', 'エビスガーデンプレイス　05カイ');
INSERT INTO `ms_addresses` VALUES ('6102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都渋谷区恵比寿恵比寿ガーデンプレイス　6階', '13', '13113', '1506006', '東京都', 'トウキョウト', '渋谷区', 'シブヤク', '恵比寿', 'エビス', null, null, '恵比寿ガーデンプレイス　6階', 'エビスガーデンプレイス　06カイ');
INSERT INTO `ms_addresses` VALUES ('6103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都渋谷区恵比寿恵比寿ガーデンプレイス　7階', '13', '13113', '1506007', '東京都', 'トウキョウト', '渋谷区', 'シブヤク', '恵比寿', 'エビス', null, null, '恵比寿ガーデンプレイス　7階', 'エビスガーデンプレイス　07カイ');
INSERT INTO `ms_addresses` VALUES ('6104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都渋谷区恵比寿恵比寿ガーデンプレイス　8階', '13', '13113', '1506008', '東京都', 'トウキョウト', '渋谷区', 'シブヤク', '恵比寿', 'エビス', null, null, '恵比寿ガーデンプレイス　8階', 'エビスガーデンプレイス　08カイ');
INSERT INTO `ms_addresses` VALUES ('6105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都渋谷区恵比寿恵比寿ガーデンプレイス　9階', '13', '13113', '1506009', '東京都', 'トウキョウト', '渋谷区', 'シブヤク', '恵比寿', 'エビス', null, null, '恵比寿ガーデンプレイス　9階', 'エビスガーデンプレイス　09カイ');
INSERT INTO `ms_addresses` VALUES ('6106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都渋谷区恵比寿恵比寿ガーデンプレイス　10階', '13', '13113', '1506010', '東京都', 'トウキョウト', '渋谷区', 'シブヤク', '恵比寿', 'エビス', null, null, '恵比寿ガーデンプレイス　10階', 'エビスガーデンプレイス　10カイ');
INSERT INTO `ms_addresses` VALUES ('6107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都渋谷区恵比寿恵比寿ガーデンプレイス　11階', '13', '13113', '1506011', '東京都', 'トウキョウト', '渋谷区', 'シブヤク', '恵比寿', 'エビス', null, null, '恵比寿ガーデンプレイス　11階', 'エビスガーデンプレイス　11カイ');
INSERT INTO `ms_addresses` VALUES ('6108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都渋谷区恵比寿恵比寿ガーデンプレイス　12階', '13', '13113', '1506012', '東京都', 'トウキョウト', '渋谷区', 'シブヤク', '恵比寿', 'エビス', null, null, '恵比寿ガーデンプレイス　12階', 'エビスガーデンプレイス　12カイ');
INSERT INTO `ms_addresses` VALUES ('6109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都渋谷区恵比寿恵比寿ガーデンプレイス　13階', '13', '13113', '1506013', '東京都', 'トウキョウト', '渋谷区', 'シブヤク', '恵比寿', 'エビス', null, null, '恵比寿ガーデンプレイス　13階', 'エビスガーデンプレイス　13カイ');
INSERT INTO `ms_addresses` VALUES ('6110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都渋谷区恵比寿恵比寿ガーデンプレイス　14階', '13', '13113', '1506014', '東京都', 'トウキョウト', '渋谷区', 'シブヤク', '恵比寿', 'エビス', null, null, '恵比寿ガーデンプレイス　14階', 'エビスガーデンプレイス　14カイ');
INSERT INTO `ms_addresses` VALUES ('6111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都渋谷区恵比寿恵比寿ガーデンプレイス　15階', '13', '13113', '1506015', '東京都', 'トウキョウト', '渋谷区', 'シブヤク', '恵比寿', 'エビス', null, null, '恵比寿ガーデンプレイス　15階', 'エビスガーデンプレイス　15カイ');
INSERT INTO `ms_addresses` VALUES ('6112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都渋谷区恵比寿恵比寿ガーデンプレイス　16階', '13', '13113', '1506016', '東京都', 'トウキョウト', '渋谷区', 'シブヤク', '恵比寿', 'エビス', null, null, '恵比寿ガーデンプレイス　16階', 'エビスガーデンプレイス　16カイ');
INSERT INTO `ms_addresses` VALUES ('6113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都渋谷区恵比寿恵比寿ガーデンプレイス　17階', '13', '13113', '1506017', '東京都', 'トウキョウト', '渋谷区', 'シブヤク', '恵比寿', 'エビス', null, null, '恵比寿ガーデンプレイス　17階', 'エビスガーデンプレイス　17カイ');
INSERT INTO `ms_addresses` VALUES ('6114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都渋谷区恵比寿恵比寿ガーデンプレイス　18階', '13', '13113', '1506018', '東京都', 'トウキョウト', '渋谷区', 'シブヤク', '恵比寿', 'エビス', null, null, '恵比寿ガーデンプレイス　18階', 'エビスガーデンプレイス　18カイ');
INSERT INTO `ms_addresses` VALUES ('6115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都渋谷区恵比寿恵比寿ガーデンプレイス　19階', '13', '13113', '1506019', '東京都', 'トウキョウト', '渋谷区', 'シブヤク', '恵比寿', 'エビス', null, null, '恵比寿ガーデンプレイス　19階', 'エビスガーデンプレイス　19カイ');
INSERT INTO `ms_addresses` VALUES ('6116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都渋谷区恵比寿恵比寿ガーデンプレイス　20階', '13', '13113', '1506020', '東京都', 'トウキョウト', '渋谷区', 'シブヤク', '恵比寿', 'エビス', null, null, '恵比寿ガーデンプレイス　20階', 'エビスガーデンプレイス　20カイ');
INSERT INTO `ms_addresses` VALUES ('6117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都渋谷区恵比寿恵比寿ガーデンプレイス　21階', '13', '13113', '1506021', '東京都', 'トウキョウト', '渋谷区', 'シブヤク', '恵比寿', 'エビス', null, null, '恵比寿ガーデンプレイス　21階', 'エビスガーデンプレイス　21カイ');
INSERT INTO `ms_addresses` VALUES ('6118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都渋谷区恵比寿恵比寿ガーデンプレイス　22階', '13', '13113', '1506022', '東京都', 'トウキョウト', '渋谷区', 'シブヤク', '恵比寿', 'エビス', null, null, '恵比寿ガーデンプレイス　22階', 'エビスガーデンプレイス　22カイ');
INSERT INTO `ms_addresses` VALUES ('6119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都渋谷区恵比寿恵比寿ガーデンプレイス　23階', '13', '13113', '1506023', '東京都', 'トウキョウト', '渋谷区', 'シブヤク', '恵比寿', 'エビス', null, null, '恵比寿ガーデンプレイス　23階', 'エビスガーデンプレイス　23カイ');
INSERT INTO `ms_addresses` VALUES ('6120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都渋谷区恵比寿恵比寿ガーデンプレイス　24階', '13', '13113', '1506024', '東京都', 'トウキョウト', '渋谷区', 'シブヤク', '恵比寿', 'エビス', null, null, '恵比寿ガーデンプレイス　24階', 'エビスガーデンプレイス　24カイ');
INSERT INTO `ms_addresses` VALUES ('6121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都渋谷区恵比寿恵比寿ガーデンプレイス　25階', '13', '13113', '1506025', '東京都', 'トウキョウト', '渋谷区', 'シブヤク', '恵比寿', 'エビス', null, null, '恵比寿ガーデンプレイス　25階', 'エビスガーデンプレイス　25カイ');
INSERT INTO `ms_addresses` VALUES ('6122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都渋谷区恵比寿恵比寿ガーデンプレイス　26階', '13', '13113', '1506026', '東京都', 'トウキョウト', '渋谷区', 'シブヤク', '恵比寿', 'エビス', null, null, '恵比寿ガーデンプレイス　26階', 'エビスガーデンプレイス　26カイ');
INSERT INTO `ms_addresses` VALUES ('6123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都渋谷区恵比寿恵比寿ガーデンプレイス　27階', '13', '13113', '1506027', '東京都', 'トウキョウト', '渋谷区', 'シブヤク', '恵比寿', 'エビス', null, null, '恵比寿ガーデンプレイス　27階', 'エビスガーデンプレイス　27カイ');
INSERT INTO `ms_addresses` VALUES ('6124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都渋谷区恵比寿恵比寿ガーデンプレイス　28階', '13', '13113', '1506028', '東京都', 'トウキョウト', '渋谷区', 'シブヤク', '恵比寿', 'エビス', null, null, '恵比寿ガーデンプレイス　28階', 'エビスガーデンプレイス　28カイ');
INSERT INTO `ms_addresses` VALUES ('6125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都渋谷区恵比寿恵比寿ガーデンプレイス　29階', '13', '13113', '1506029', '東京都', 'トウキョウト', '渋谷区', 'シブヤク', '恵比寿', 'エビス', null, null, '恵比寿ガーデンプレイス　29階', 'エビスガーデンプレイス　29カイ');
INSERT INTO `ms_addresses` VALUES ('6126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都渋谷区恵比寿恵比寿ガーデンプレイス　30階', '13', '13113', '1506030', '東京都', 'トウキョウト', '渋谷区', 'シブヤク', '恵比寿', 'エビス', null, null, '恵比寿ガーデンプレイス　30階', 'エビスガーデンプレイス　30カイ');
INSERT INTO `ms_addresses` VALUES ('6127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都渋谷区恵比寿恵比寿ガーデンプレイス　31階', '13', '13113', '1506031', '東京都', 'トウキョウト', '渋谷区', 'シブヤク', '恵比寿', 'エビス', null, null, '恵比寿ガーデンプレイス　31階', 'エビスガーデンプレイス　31カイ');
INSERT INTO `ms_addresses` VALUES ('6128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都渋谷区恵比寿恵比寿ガーデンプレイス　32階', '13', '13113', '1506032', '東京都', 'トウキョウト', '渋谷区', 'シブヤク', '恵比寿', 'エビス', null, null, '恵比寿ガーデンプレイス　32階', 'エビスガーデンプレイス　32カイ');
INSERT INTO `ms_addresses` VALUES ('6129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都渋谷区恵比寿恵比寿ガーデンプレイス　33階', '13', '13113', '1506033', '東京都', 'トウキョウト', '渋谷区', 'シブヤク', '恵比寿', 'エビス', null, null, '恵比寿ガーデンプレイス　33階', 'エビスガーデンプレイス　33カイ');
INSERT INTO `ms_addresses` VALUES ('6130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都渋谷区恵比寿恵比寿ガーデンプレイス　34階', '13', '13113', '1506034', '東京都', 'トウキョウト', '渋谷区', 'シブヤク', '恵比寿', 'エビス', null, null, '恵比寿ガーデンプレイス　34階', 'エビスガーデンプレイス　34カイ');
INSERT INTO `ms_addresses` VALUES ('6131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都渋谷区恵比寿恵比寿ガーデンプレイス　35階', '13', '13113', '1506035', '東京都', 'トウキョウト', '渋谷区', 'シブヤク', '恵比寿', 'エビス', null, null, '恵比寿ガーデンプレイス　35階', 'エビスガーデンプレイス　35カイ');
INSERT INTO `ms_addresses` VALUES ('6132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都渋谷区恵比寿恵比寿ガーデンプレイス　36階', '13', '13113', '1506036', '東京都', 'トウキョウト', '渋谷区', 'シブヤク', '恵比寿', 'エビス', null, null, '恵比寿ガーデンプレイス　36階', 'エビスガーデンプレイス　36カイ');
INSERT INTO `ms_addresses` VALUES ('6133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都渋谷区恵比寿恵比寿ガーデンプレイス　37階', '13', '13113', '1506037', '東京都', 'トウキョウト', '渋谷区', 'シブヤク', '恵比寿', 'エビス', null, null, '恵比寿ガーデンプレイス　37階', 'エビスガーデンプレイス　37カイ');
INSERT INTO `ms_addresses` VALUES ('6134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都渋谷区恵比寿恵比寿ガーデンプレイス　38階', '13', '13113', '1506038', '東京都', 'トウキョウト', '渋谷区', 'シブヤク', '恵比寿', 'エビス', null, null, '恵比寿ガーデンプレイス　38階', 'エビスガーデンプレイス　38カイ');
INSERT INTO `ms_addresses` VALUES ('6135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都渋谷区恵比寿恵比寿ガーデンプレイス　39階', '13', '13113', '1506039', '東京都', 'トウキョウト', '渋谷区', 'シブヤク', '恵比寿', 'エビス', null, null, '恵比寿ガーデンプレイス　39階', 'エビスガーデンプレイス　39カイ');
INSERT INTO `ms_addresses` VALUES ('6136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都渋谷区恵比寿恵比寿ガーデンプレイス　', '13', '13113', '1506090', '東京都', 'トウキョウト', '渋谷区', 'シブヤク', '恵比寿', 'エビス', null, null, '恵比寿ガーデンプレイス　', 'エビスガーデンプレイス　');
INSERT INTO `ms_addresses` VALUES ('6137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市鳥海町上笹子', '05', '05210', '0150721', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '鳥海町上笹子', 'チョウカイマチカミジネゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市鳥海町下笹子', '05', '05210', '0150722', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '鳥海町下笹子', 'チョウカイマチシモジネゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市美倉町', '05', '05210', '0150801', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '美倉町', 'ミクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市表尾崎町', '05', '05210', '0150802', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '表尾崎町', 'オモテオザキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市中竪町', '05', '05210', '0150803', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '中竪町', 'ナカダテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市谷山小路', '05', '05210', '0150804', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '谷山小路', 'タニヤマコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市油小路', '05', '05210', '0150805', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '油小路', 'アブラコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市上横町', '05', '05210', '0150806', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '上横町', 'カミヨコマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市中横町', '05', '05210', '0150807', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '中横町', 'ナカヨコマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市桶屋町', '05', '05210', '0150811', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '桶屋町', 'オケヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市鍛治町', '05', '05210', '0150812', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '鍛治町', 'カジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市日役町', '05', '05210', '0150813', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '日役町', 'ヒキジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市後町', '05', '05210', '0150814', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '後町', 'ウシロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市猟師町', '05', '05210', '0150815', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '猟師町', 'リョウシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市大町', '05', '05210', '0150816', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '大町', 'オオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市中町', '05', '05210', '0150817', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '中町', 'ナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市肴町', '05', '05210', '0150821', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '肴町', 'サカナマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市田町', '05', '05210', '0150822', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '田町', 'タマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市和泉町', '05', '05210', '0150823', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '和泉町', 'イズミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市古雪町', '05', '05210', '0150824', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '古雪町', 'フルユキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市観音町', '05', '05210', '0150825', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '観音町', 'カンノンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市片町', '05', '05210', '0150826', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '片町', 'カタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市浜ノ町', '05', '05210', '0150827', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '浜ノ町', 'ハマノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市北裏地', '05', '05210', '0150831', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '北裏地', 'キタウラジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市下川原中島', '05', '05210', '0150832', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '下川原中島', 'シモカワハラナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市巣組', '05', '05210', '0150833', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '巣組', 'スグミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市岩渕下', '05', '05210', '0150834', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '岩渕下', 'イワブチシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市八幡下', '05', '05210', '0150835', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '八幡下', 'ハチマンシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市赤沼下', '05', '05210', '0150836', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '赤沼下', 'アカヌマシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市出戸町赤沼下道', '05', '05210', '0150837', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '出戸町', 'デトマチ', null, null, '赤沼下道', 'アカヌマシタミチ');
INSERT INTO `ms_addresses` VALUES ('6198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市梵天谷地', '05', '05210', '0150838', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '梵天谷地', 'ボンテンヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市古川端', '05', '05210', '0150839', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '古川端', 'フルカワバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市瀬越場', '05', '05210', '0150840', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '瀬越場', 'セゴシバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市下大野', '05', '05210', '0150841', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '下大野', 'シモオオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市出戸上野', '05', '05210', '0150842', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '出戸上野', 'デトウエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市東梵天', '05', '05210', '0150843', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '東梵天', 'ヒガシボンテン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市中梵天', '05', '05210', '0150851', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '中梵天', 'ナカボンテン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市一番堰', '05', '05210', '0150852', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '一番堰', 'イチバンゼキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市松街道', '05', '05210', '0150853', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '松街道', 'マツカイドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市上大野', '05', '05210', '0150854', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '上大野', 'カミオオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市二番堰', '05', '05210', '0150855', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '二番堰', 'ニバンゼキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市円正脇', '05', '05210', '0150856', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '円正脇', 'エンショウワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市寺後', '05', '05210', '0150857', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '寺後', 'テラウシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市西梵天', '05', '05210', '0150858', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '西梵天', 'ニシボンテン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市御門', '05', '05210', '0150861', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '御門', 'ゴモン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市小人町', '05', '05210', '0150862', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '小人町', 'コビトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市不戻沢', '05', '05210', '0150863', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '不戻沢', 'フモドリサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市大鍬町', '05', '05210', '0150864', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '大鍬町', 'オオクワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市西大鍬町', '05', '05210', '0150865', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '西大鍬町', 'ニシオオクワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市堤脇', '05', '05210', '0150866', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '堤脇', 'ツツミワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市千刈', '05', '05210', '0150867', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '千刈', 'センガリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市大堤下', '05', '05210', '0150868', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '大堤下', 'オオヅツミシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市陣場岱', '05', '05210', '0150869', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '陣場岱', 'ジンバダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市尾崎', '05', '05210', '0150871', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '尾崎', 'オザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市瓦谷地', '05', '05210', '0150872', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '瓦谷地', 'カワラヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市鶴沼', '05', '05210', '0150873', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '鶴沼', 'ツルヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市給人町', '05', '05210', '0150874', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '給人町', 'キュウジンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市砂子下', '05', '05210', '0150875', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '砂子下', 'スナゴシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市井戸尻', '05', '05210', '0150876', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '井戸尻', 'イドジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市濡浜北', '05', '05210', '0150877', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '濡浜北', 'ヌレハマキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市観音森', '05', '05210', '0150878', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '観音森', 'カンノンモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市切通', '05', '05210', '0150881', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '切通', 'キリドオシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市西小人町', '05', '05210', '0150882', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '西小人町', 'ニシコビトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市下地ケ沢', '05', '05210', '0150883', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '下地ケ沢', 'ゲチガサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市狐森', '05', '05210', '0150884', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '狐森', 'キツネモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市水林', '05', '05210', '0150885', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '水林', 'ミズバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市調練場', '05', '05210', '0150886', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '調練場', 'チョウレンバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市今野谷地', '05', '05210', '0150887', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '今野谷地', 'コンノヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市新組町', '05', '05210', '0150888', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '新組町', 'シンクミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市砂糖畑', '05', '05210', '0150889', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '砂糖畑', 'サトウバタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市船ケ台', '05', '05210', '0150890', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '船ケ台', 'フナガダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市小防ケ沢', '05', '05210', '0150891', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '小防ケ沢', 'コボウガサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市蟻山', '05', '05210', '0150892', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '蟻山', 'アリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都渋谷区千駄ケ谷', '13', '13113', '1510051', '東京都', 'トウキョウト', '渋谷区', 'シブヤク', '千駄ケ谷', 'センダガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都渋谷区代々木神園町', '13', '13113', '1510052', '東京都', 'トウキョウト', '渋谷区', 'シブヤク', '代々木神園町', 'ヨヨギカミゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都渋谷区代々木', '13', '13113', '1510053', '東京都', 'トウキョウト', '渋谷区', 'シブヤク', '代々木', 'ヨヨギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都渋谷区初台', '13', '13113', '1510061', '東京都', 'トウキョウト', '渋谷区', 'シブヤク', '初台', 'ハツダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都渋谷区元代々木町', '13', '13113', '1510062', '東京都', 'トウキョウト', '渋谷区', 'シブヤク', '元代々木町', 'モトヨヨギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都渋谷区富ケ谷', '13', '13113', '1510063', '東京都', 'トウキョウト', '渋谷区', 'シブヤク', '富ケ谷', 'トミガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都渋谷区上原', '13', '13113', '1510064', '東京都', 'トウキョウト', '渋谷区', 'シブヤク', '上原', 'ウエハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都渋谷区大山町', '13', '13113', '1510065', '東京都', 'トウキョウト', '渋谷区', 'シブヤク', '大山町', 'オオヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都渋谷区西原', '13', '13113', '1510066', '東京都', 'トウキョウト', '渋谷区', 'シブヤク', '西原', 'ニシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都渋谷区本町', '13', '13113', '1510071', '東京都', 'トウキョウト', '渋谷区', 'シブヤク', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都渋谷区幡ケ谷', '13', '13113', '1510072', '東京都', 'トウキョウト', '渋谷区', 'シブヤク', '幡ケ谷', 'ハタガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都渋谷区笹塚', '13', '13113', '1510073', '東京都', 'トウキョウト', '渋谷区', 'シブヤク', '笹塚', 'ササヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都目黒区', '13', '13110', '1520000', '東京都', 'トウキョウト', '目黒区', 'メグロク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('6382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都目黒区中央町', '13', '13110', '1520001', '東京都', 'トウキョウト', '目黒区', 'メグロク', '中央町', 'チュウオウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都目黒区目黒本町', '13', '13110', '1520002', '東京都', 'トウキョウト', '目黒区', 'メグロク', '目黒本町', 'メグロホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都目黒区碑文谷', '13', '13110', '1520003', '東京都', 'トウキョウト', '目黒区', 'メグロク', '碑文谷', 'ヒモンヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都目黒区鷹番', '13', '13110', '1520004', '東京都', 'トウキョウト', '目黒区', 'メグロク', '鷹番', 'タカバン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都目黒区原町', '13', '13110', '1520011', '東京都', 'トウキョウト', '目黒区', 'メグロク', '原町', 'ハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都目黒区洗足', '13', '13110', '1520012', '東京都', 'トウキョウト', '目黒区', 'メグロク', '洗足', 'センゾク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都目黒区南', '13', '13110', '1520013', '東京都', 'トウキョウト', '目黒区', 'メグロク', '南', 'ミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都目黒区東が丘', '13', '13110', '1520021', '東京都', 'トウキョウト', '目黒区', 'メグロク', '東が丘', 'ヒガシガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都目黒区柿の木坂', '13', '13110', '1520022', '東京都', 'トウキョウト', '目黒区', 'メグロク', '柿の木坂', 'カキノキザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都目黒区八雲', '13', '13110', '1520023', '東京都', 'トウキョウト', '目黒区', 'メグロク', '八雲', 'ヤクモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都目黒区中根', '13', '13110', '1520031', '東京都', 'トウキョウト', '目黒区', 'メグロク', '中根', 'ナカネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都目黒区平町', '13', '13110', '1520032', '東京都', 'トウキョウト', '目黒区', 'メグロク', '平町', 'タイラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都目黒区大岡山', '13', '13110', '1520033', '東京都', 'トウキョウト', '目黒区', 'メグロク', '大岡山', 'オオオカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都目黒区緑が丘', '13', '13110', '1520034', '東京都', 'トウキョウト', '目黒区', 'メグロク', '緑が丘', 'ミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都目黒区自由が丘', '13', '13110', '1520035', '東京都', 'トウキョウト', '目黒区', 'メグロク', '自由が丘', 'ジユウガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都目黒区駒場', '13', '13110', '1530041', '東京都', 'トウキョウト', '目黒区', 'メグロク', '駒場', 'コマバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都目黒区青葉台', '13', '13110', '1530042', '東京都', 'トウキョウト', '目黒区', 'メグロク', '青葉台', 'アオバダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都目黒区東山', '13', '13110', '1530043', '東京都', 'トウキョウト', '目黒区', 'メグロク', '東山', 'ヒガシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都目黒区大橋', '13', '13110', '1530044', '東京都', 'トウキョウト', '目黒区', 'メグロク', '大橋', 'オオハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都目黒区上目黒', '13', '13110', '1530051', '東京都', 'トウキョウト', '目黒区', 'メグロク', '上目黒', 'カミメグロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都目黒区祐天寺', '13', '13110', '1530052', '東京都', 'トウキョウト', '目黒区', 'メグロク', '祐天寺', 'ユウテンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都目黒区五本木', '13', '13110', '1530053', '東京都', 'トウキョウト', '目黒区', 'メグロク', '五本木', 'ゴホンギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都目黒区中目黒', '13', '13110', '1530061', '東京都', 'トウキョウト', '目黒区', 'メグロク', '中目黒', 'ナカメグロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都目黒区三田', '13', '13110', '1530062', '東京都', 'トウキョウト', '目黒区', 'メグロク', '三田', 'ミタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都目黒区目黒', '13', '13110', '1530063', '東京都', 'トウキョウト', '目黒区', 'メグロク', '目黒', 'メグロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都目黒区下目黒', '13', '13110', '1530064', '東京都', 'トウキョウト', '目黒区', 'メグロク', '下目黒', 'シモメグロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都目黒区中町', '13', '13110', '1530065', '東京都', 'トウキョウト', '目黒区', 'メグロク', '中町', 'ナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都世田谷区', '13', '13112', '1540000', '東京都', 'トウキョウト', '世田谷区', 'セタガヤク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('6536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都世田谷区池尻', '13', '13112', '1540001', '東京都', 'トウキョウト', '世田谷区', 'セタガヤク', '池尻', 'イケジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都世田谷区下馬', '13', '13112', '1540002', '東京都', 'トウキョウト', '世田谷区', 'セタガヤク', '下馬', 'シモウマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都世田谷区野沢', '13', '13112', '1540003', '東京都', 'トウキョウト', '世田谷区', 'セタガヤク', '野沢', 'ノザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都世田谷区太子堂', '13', '13112', '1540004', '東京都', 'トウキョウト', '世田谷区', 'セタガヤク', '太子堂', 'タイシドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都世田谷区三宿', '13', '13112', '1540005', '東京都', 'トウキョウト', '世田谷区', 'セタガヤク', '三宿', 'ミシュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都世田谷区上馬', '13', '13112', '1540011', '東京都', 'トウキョウト', '世田谷区', 'セタガヤク', '上馬', 'カミウマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都世田谷区駒沢', '13', '13112', '1540012', '東京都', 'トウキョウト', '世田谷区', 'セタガヤク', '駒沢', 'コマザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都世田谷区駒沢公園', '13', '13112', '1540013', '東京都', 'トウキョウト', '世田谷区', 'セタガヤク', '駒沢公園', 'コマザワコウエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都世田谷区新町', '13', '13112', '1540014', '東京都', 'トウキョウト', '世田谷区', 'セタガヤク', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都世田谷区桜新町', '13', '13112', '1540015', '東京都', 'トウキョウト', '世田谷区', 'セタガヤク', '桜新町', 'サクラシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都世田谷区弦巻', '13', '13112', '1540016', '東京都', 'トウキョウト', '世田谷区', 'セタガヤク', '弦巻', 'ツルマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都世田谷区世田谷', '13', '13112', '1540017', '東京都', 'トウキョウト', '世田谷区', 'セタガヤク', '世田谷', 'セタガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都世田谷区豪徳寺', '13', '13112', '1540021', '東京都', 'トウキョウト', '世田谷区', 'セタガヤク', '豪徳寺', 'ゴウトクジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都世田谷区梅丘', '13', '13112', '1540022', '東京都', 'トウキョウト', '世田谷区', 'セタガヤク', '梅丘', 'ウメガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都世田谷区若林', '13', '13112', '1540023', '東京都', 'トウキョウト', '世田谷区', 'セタガヤク', '若林', 'ワカバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都世田谷区三軒茶屋', '13', '13112', '1540024', '東京都', 'トウキョウト', '世田谷区', 'セタガヤク', '三軒茶屋', 'サンゲンヂャヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都世田谷区北沢', '13', '13112', '1550031', '東京都', 'トウキョウト', '世田谷区', 'セタガヤク', '北沢', 'キタザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都世田谷区代沢', '13', '13112', '1550032', '東京都', 'トウキョウト', '世田谷区', 'セタガヤク', '代沢', 'ダイザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都世田谷区代田', '13', '13112', '1550033', '東京都', 'トウキョウト', '世田谷区', 'セタガヤク', '代田', 'ダイタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都世田谷区大原', '13', '13112', '1560041', '東京都', 'トウキョウト', '世田谷区', 'セタガヤク', '大原', 'オオハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都世田谷区羽根木', '13', '13112', '1560042', '東京都', 'トウキョウト', '世田谷区', 'セタガヤク', '羽根木', 'ハネギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都世田谷区松原', '13', '13112', '1560043', '東京都', 'トウキョウト', '世田谷区', 'セタガヤク', '松原', 'マツバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都世田谷区赤堤', '13', '13112', '1560044', '東京都', 'トウキョウト', '世田谷区', 'セタガヤク', '赤堤', 'アカツツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都世田谷区桜上水', '13', '13112', '1560045', '東京都', 'トウキョウト', '世田谷区', 'セタガヤク', '桜上水', 'サクラジョウスイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都世田谷区宮坂', '13', '13112', '1560051', '東京都', 'トウキョウト', '世田谷区', 'セタガヤク', '宮坂', 'ミヤサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都世田谷区経堂', '13', '13112', '1560052', '東京都', 'トウキョウト', '世田谷区', 'セタガヤク', '経堂', 'キョウドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都世田谷区桜', '13', '13112', '1560053', '東京都', 'トウキョウト', '世田谷区', 'セタガヤク', '桜', 'サクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都世田谷区桜丘', '13', '13112', '1560054', '東京都', 'トウキョウト', '世田谷区', 'セタガヤク', '桜丘', 'サクラガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都世田谷区船橋', '13', '13112', '1560055', '東京都', 'トウキョウト', '世田谷区', 'セタガヤク', '船橋', 'フナバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都世田谷区八幡山', '13', '13112', '1560056', '東京都', 'トウキョウト', '世田谷区', 'セタガヤク', '八幡山', 'ハチマンヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都世田谷区上北沢', '13', '13112', '1560057', '東京都', 'トウキョウト', '世田谷区', 'セタガヤク', '上北沢', 'カミキタザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都世田谷区北烏山', '13', '13112', '1570061', '東京都', 'トウキョウト', '世田谷区', 'セタガヤク', '北烏山', 'キタカラスヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都世田谷区南烏山', '13', '13112', '1570062', '東京都', 'トウキョウト', '世田谷区', 'セタガヤク', '南烏山', 'ミナミカラスヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都世田谷区粕谷', '13', '13112', '1570063', '東京都', 'トウキョウト', '世田谷区', 'セタガヤク', '粕谷', 'カスヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都世田谷区給田', '13', '13112', '1570064', '東京都', 'トウキョウト', '世田谷区', 'セタガヤク', '給田', 'キュウデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都世田谷区上祖師谷', '13', '13112', '1570065', '東京都', 'トウキョウト', '世田谷区', 'セタガヤク', '上祖師谷', 'カミソシガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都世田谷区成城', '13', '13112', '1570066', '東京都', 'トウキョウト', '世田谷区', 'セタガヤク', '成城', 'セイジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都世田谷区喜多見', '13', '13112', '1570067', '東京都', 'トウキョウト', '世田谷区', 'セタガヤク', '喜多見', 'キタミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都世田谷区宇奈根', '13', '13112', '1570068', '東京都', 'トウキョウト', '世田谷区', 'セタガヤク', '宇奈根', 'ウナネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都世田谷区千歳台', '13', '13112', '1570071', '東京都', 'トウキョウト', '世田谷区', 'セタガヤク', '千歳台', 'チトセダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都世田谷区祖師谷', '13', '13112', '1570072', '東京都', 'トウキョウト', '世田谷区', 'セタガヤク', '祖師谷', 'ソシガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都世田谷区砧', '13', '13112', '1570073', '東京都', 'トウキョウト', '世田谷区', 'セタガヤク', '砧', 'キヌタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都世田谷区大蔵', '13', '13112', '1570074', '東京都', 'トウキョウト', '世田谷区', 'セタガヤク', '大蔵', 'オオクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都世田谷区砧公園', '13', '13112', '1570075', '東京都', 'トウキョウト', '世田谷区', 'セタガヤク', '砧公園', 'キヌタコウエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都世田谷区岡本', '13', '13112', '1570076', '東京都', 'トウキョウト', '世田谷区', 'セタガヤク', '岡本', 'オカモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都世田谷区鎌田', '13', '13112', '1570077', '東京都', 'トウキョウト', '世田谷区', 'セタガヤク', '鎌田', 'カマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都世田谷区深沢', '13', '13112', '1580081', '東京都', 'トウキョウト', '世田谷区', 'セタガヤク', '深沢', 'フカサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都世田谷区等々力', '13', '13112', '1580082', '東京都', 'トウキョウト', '世田谷区', 'セタガヤク', '等々力', 'トドロキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都世田谷区奥沢', '13', '13112', '1580083', '東京都', 'トウキョウト', '世田谷区', 'セタガヤク', '奥沢', 'オクサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都世田谷区東玉川', '13', '13112', '1580084', '東京都', 'トウキョウト', '世田谷区', 'セタガヤク', '東玉川', 'ヒガシタマガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都世田谷区玉川田園調布', '13', '13112', '1580085', '東京都', 'トウキョウト', '世田谷区', 'セタガヤク', '玉川田園調布', 'タマガワデンエンチョウフ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都世田谷区尾山台', '13', '13112', '1580086', '東京都', 'トウキョウト', '世田谷区', 'セタガヤク', '尾山台', 'オヤマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都世田谷区玉堤', '13', '13112', '1580087', '東京都', 'トウキョウト', '世田谷区', 'セタガヤク', '玉堤', 'タマヅツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都世田谷区中町', '13', '13112', '1580091', '東京都', 'トウキョウト', '世田谷区', 'セタガヤク', '中町', 'ナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都世田谷区野毛', '13', '13112', '1580092', '東京都', 'トウキョウト', '世田谷区', 'セタガヤク', '野毛', 'ノゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都世田谷区上野毛', '13', '13112', '1580093', '東京都', 'トウキョウト', '世田谷区', 'セタガヤク', '上野毛', 'カミノゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都世田谷区玉川', '13', '13112', '1580094', '東京都', 'トウキョウト', '世田谷区', 'セタガヤク', '玉川', 'タマガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都世田谷区瀬田', '13', '13112', '1580095', '東京都', 'トウキョウト', '世田谷区', 'セタガヤク', '瀬田', 'セタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都世田谷区玉川台', '13', '13112', '1580096', '東京都', 'トウキョウト', '世田谷区', 'セタガヤク', '玉川台', 'タマガワダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都世田谷区用賀', '13', '13112', '1580097', '東京都', 'トウキョウト', '世田谷区', 'セタガヤク', '用賀', 'ヨウガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都世田谷区上用賀', '13', '13112', '1580098', '東京都', 'トウキョウト', '世田谷区', 'セタガヤク', '上用賀', 'カミヨウガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市', '05', '05202', '0160000', '秋田県', 'アキタケン', '能代市', 'ノシロシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('6748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区', '13', '13104', '1600000', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('6749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区片町', '13', '13104', '1600001', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '片町', 'カタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区坂町', '13', '13104', '1600002', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '坂町', 'サカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区本塩町', '13', '13104', '1600003', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '本塩町', 'ホンシオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区四谷', '13', '13104', '1600004', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '四谷', 'ヨツヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区愛住町', '13', '13104', '1600005', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '愛住町', 'アイズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区舟町', '13', '13104', '1600006', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '舟町', 'フナマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区荒木町', '13', '13104', '1600007', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '荒木町', 'アラキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区三栄町', '13', '13104', '1600008', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '三栄町', 'サンエイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市外荒巻', '05', '05202', '0160001', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '外荒巻', 'ソトアラマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区若葉', '13', '13104', '1600011', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '若葉', 'ワカバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区南元町', '13', '13104', '1600012', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '南元町', 'ミナミモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区霞ケ丘町', '13', '13104', '1600013', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '霞ケ丘町', 'カスミガオカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区内藤町', '13', '13104', '1600014', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '内藤町', 'ナイトウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区大京町', '13', '13104', '1600015', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '大京町', 'ダイキョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区信濃町', '13', '13104', '1600016', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '信濃町', 'シナノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区左門町', '13', '13104', '1600017', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '左門町', 'サモンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区須賀町', '13', '13104', '1600018', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '須賀町', 'スガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市朴瀬', '05', '05202', '0160002', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '朴瀬', 'ホノキセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区歌舞伎町', '13', '13104', '1600021', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '歌舞伎町', 'カブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区新宿', '13', '13104', '1600022', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '新宿', 'シンジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿', '13', '13104', '1600023', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市荷八田', '05', '05202', '0160003', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '荷八田', 'ニハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市吹越', '05', '05202', '0160004', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '吹越', 'フッコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市真壁地', '05', '05202', '0160005', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '真壁地', 'マカベチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市坂形', '05', '05202', '0160011', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '坂形', 'サカガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市比八田', '05', '05202', '0160012', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '比八田', 'ヒハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市向能代', '05', '05202', '0160013', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '向能代', 'ムカイノシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市落合', '05', '05202', '0160014', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '落合', 'オチアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市須田', '05', '05202', '0160015', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '須田', 'スダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市竹生', '05', '05202', '0160016', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '竹生', 'タコウ', null, null, null, null), ('6779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市磐', '05', '05202', '0160017', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '磐', 'イワオ', null, null, null, null), ('6780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市中関', '05', '05202', '0160101', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '中関', 'ナカセキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市一本木', '05', '05202', '0160102', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '一本木', 'イッポンギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市宮ノ前', '05', '05202', '0160103', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '宮ノ前', 'ミヤノマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市下関', '05', '05202', '0160104', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '下関', 'シモセキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市仁井田白山', '05', '05202', '0160111', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '仁井田白山', 'ニイダシロヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市中嶋', '05', '05202', '0160112', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '中嶋', 'ナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市下悪戸', '05', '05202', '0160113', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '下悪戸', 'シモアクド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市中悪戸', '05', '05202', '0160114', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '中悪戸', 'ナカアクド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市悪戸', '05', '05202', '0160115', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '悪戸', 'アクド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市機織轌ノ目', '05', '05202', '0160116', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '機織轌ノ目', 'ハタオリソリノメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市鰄渕', '05', '05202', '0160121', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '鰄渕', 'カイラゲフチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市扇田', '05', '05202', '0160122', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '扇田', 'オウギダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市田床内', '05', '05202', '0160123', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '田床内', 'タドコナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市鶴形', '05', '05202', '0160131', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '鶴形', 'ツルガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市町後', '05', '05202', '0160132', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '町後', 'マチウシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市向田表', '05', '05202', '0160133', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '向田表', 'ムカイタオモテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市戸草沢', '05', '05202', '0160134', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '戸草沢', 'トクサザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市姥懐', '05', '05202', '0160135', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '姥懐', 'ウバフトコロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市鵜鳥', '05', '05202', '0160136', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '鵜鳥', 'ウトリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市鵜鳥悪戸', '05', '05202', '0160137', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '鵜鳥悪戸', 'ウドリアクド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市鵜鳥川原', '05', '05202', '0160138', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '鵜鳥川原', 'ウドリガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市谷地上', '05', '05202', '0160139', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '谷地上', 'ヤチウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市鵜ノ沢', '05', '05202', '0160141', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '鵜ノ沢', 'ウノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市半戸沢', '05', '05202', '0160142', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '半戸沢', 'ハントザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市上ノ山', '05', '05202', '0160143', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '上ノ山', 'ウエノヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市上ノ山台', '05', '05202', '0160144', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '上ノ山台', 'ウエノヤマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市若田', '05', '05202', '0160145', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '若田', 'ワカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市外堤', '05', '05202', '0160146', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '外堤', 'ソトツツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市鳥矢場', '05', '05202', '0160147', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '鳥矢場', 'トヤバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市冷清水', '05', '05202', '0160148', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '冷清水', 'ヒヤシミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市田中谷地', '05', '05202', '0160149', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '田中谷地', 'タナカヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市檜山', '05', '05202', '0160151', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '檜山', 'ヒヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市母体', '05', '05202', '0160152', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '母体', 'モタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市上関', '05', '05202', '0160153', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '上関', 'カミセキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市上谷地', '05', '05202', '0160154', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '上谷地', 'カミヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市大森', '05', '05202', '0160155', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '大森', 'オオモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市中沢', '05', '05202', '0160156', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '中沢', 'ナカザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市腹鞁ノ沢', '05', '05202', '0160157', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '腹鞁ノ沢', 'ハラガイノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市松長布', '05', '05202', '0160161', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '松長布', 'マツナガシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市大内田', '05', '05202', '0160162', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '大内田', 'オオウチダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市袖又', '05', '05202', '0160163', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '袖又', 'ソデマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市大塚', '05', '05202', '0160164', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '大塚', 'オオツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市田屋', '05', '05202', '0160165', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '田屋', 'タヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市柏子所', '05', '05202', '0160166', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '柏子所', 'カシコドコロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市塩干田', '05', '05202', '0160167', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '塩干田', 'シオカラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市塩干田前', '05', '05202', '0160167', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '塩干田前', 'シオカラダマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市十洲崎', '05', '05202', '0160168', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '十洲崎', 'ジッシュウザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市坊ケ崎', '05', '05202', '0160169', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '坊ケ崎', 'ボウガサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市河戸川', '05', '05202', '0160171', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '河戸川', 'カワトガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市上古川布', '05', '05202', '0160172', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '上古川布', 'カミフルカワシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市下古川布', '05', '05202', '0160173', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '下古川布', 'シモフルカワシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市新山前', '05', '05202', '0160174', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '新山前', 'シンザンマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市古屋布', '05', '05202', '0160175', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '古屋布', 'フルヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市戸川向', '05', '05202', '0160176', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '戸川向', 'トガワムカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市権現台', '05', '05202', '0160177', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '権現台', 'ゴンゲンダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市九郎左衛門笹台', '05', '05202', '0160178', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '九郎左衛門笹台', 'クロウザエモンササダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市浅内', '05', '05202', '0160179', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '浅内', 'アサナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市大瀬儘下', '05', '05202', '0160181', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '大瀬儘下', 'オオセママシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市上柳', '05', '05202', '0160182', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '上柳', 'カミヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市中柳', '05', '05202', '0160183', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '中柳', 'ナカヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市高塙', '05', '05202', '0160184', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '高塙', 'タカハナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市下瀬', '05', '05202', '0160185', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '下瀬', 'シモセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市下野', '05', '05202', '0160186', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '下野', 'シモノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市下柳', '05', '05202', '0160187', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '下柳', 'シモヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市寺向', '05', '05202', '0160188', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '寺向', 'テラムカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市浜通町', '05', '05202', '0160801', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '浜通町', 'ハマドオリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市川反町', '05', '05202', '0160802', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '川反町', 'カワバタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市大町', '05', '05202', '0160803', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '大町', 'オオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市万町', '05', '05202', '0160804', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '万町', 'アラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市大手町', '05', '05202', '0160805', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '大手町', 'オオテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市清助町', '05', '05202', '0160806', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '清助町', 'セイスケマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市大森山', '05', '05202', '0160807', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '大森山', 'オオモリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市日和山下', '05', '05202', '0160808', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '日和山下', 'ヒヨリヤマシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市日吉町', '05', '05202', '0160811', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '日吉町', 'ヒヨシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市中嶋', '05', '05202', '0160812', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '中嶋', 'ナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市能代町', '05', '05202', '0160813', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '能代町', 'ノシロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市中川原', '05', '05202', '0160814', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '中川原', 'ナカガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市御指南町', '05', '05202', '0160815', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '御指南町', 'ゴシナンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市富町', '05', '05202', '0160816', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '富町', 'トミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市上町', '05', '05202', '0160817', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '上町', 'カンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市畠町', '05', '05202', '0160821', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '畠町', 'ハタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市東町', '05', '05202', '0160822', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '東町', 'ヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市若松町', '05', '05202', '0160823', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '若松町', 'ワカマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市住吉町', '05', '05202', '0160824', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '住吉町', 'スミヨシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市柳町', '05', '05202', '0160825', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '柳町', 'ヤナギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市元町', '05', '05202', '0160831', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '元町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市南元町', '05', '05202', '0160832', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '南元町', 'ミナミモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市明治町', '05', '05202', '0160833', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '明治町', 'メイジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市下内崎', '05', '05202', '0160834', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '下内崎', 'ゲナイザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市赤沼', '05', '05202', '0160835', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '赤沼', 'アカヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市東赤沼', '05', '05202', '0160836', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '東赤沼', 'ヒガシアカヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市西赤沼', '05', '05202', '0160837', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '西赤沼', 'ニシアカヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市養蚕脇', '05', '05202', '0160838', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '養蚕脇', 'ヨウサンワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市東大瀬', '05', '05202', '0160839', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '東大瀬', 'ヒガシオオセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市養蚕', '05', '05202', '0160841', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '養蚕', 'ヨウサン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市追分町', '05', '05202', '0160842', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '追分町', 'オイワケマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市中和', '05', '05202', '0160843', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '中和', 'チュウワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市花園町', '05', '05202', '0160844', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '花園町', 'ハナゾノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市通町', '05', '05202', '0160845', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '通町', 'トオリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市栄町', '05', '05202', '0160846', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市緑町', '05', '05202', '0160851', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '緑町', 'ミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市出戸本町', '05', '05202', '0160852', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '出戸本町', 'デトホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市出戸後', '05', '05202', '0160853', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '出戸後', 'デトウシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市豊祥岱', '05', '05202', '0160854', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '豊祥岱', 'ホウショウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市西大瀬', '05', '05202', '0160855', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '西大瀬', 'ニシオオセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市藤山', '05', '05202', '0160856', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '藤山', 'フジヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市田子向', '05', '05202', '0160857', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '田子向', 'タコムカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市彩霞長根', '05', '05202', '0160861', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '彩霞長根', 'サイカナガネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市寿域長根', '05', '05202', '0160862', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '寿域長根', 'ジュイキナガネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市後谷地', '05', '05202', '0160863', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '後谷地', 'ウシロヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市鳥小屋', '05', '05202', '0160864', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '鳥小屋', 'トリゴヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市青葉町', '05', '05202', '0160865', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '青葉町', 'アオバマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市昇平岱', '05', '05202', '0160871', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '昇平岱', 'ショウヘイダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市芝童森', '05', '05202', '0160872', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '芝童森', 'シドウモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市長崎', '05', '05202', '0160873', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '長崎', 'ナガサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市沼ノ上', '05', '05202', '0160874', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '沼ノ上', 'ヌマノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市南陽崎', '05', '05202', '0160875', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '南陽崎', 'ナンヨウザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市海詠坂', '05', '05202', '0160876', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '海詠坂', 'カイエイザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市仙遊長根', '05', '05202', '0160877', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '仙遊長根', 'センユウナガネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市臥竜山', '05', '05202', '0160878', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '臥竜山', 'ガリュウザン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市不老岱', '05', '05202', '0160879', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '不老岱', 'フロウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市砂留山', '05', '05202', '0160881', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '砂留山', 'スナドメヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市鳳凰岱', '05', '05202', '0160882', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '鳳凰岱', 'ホウオウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('6999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市五雲岱', '05', '05202', '0160883', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '五雲岱', 'ゴウンダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市卸町', '05', '05202', '0160884', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '卸町', 'オロシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市西通町', '05', '05202', '0160891', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '西通町', 'ニシドオリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市景林町', '05', '05202', '0160892', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '景林町', 'ケイリンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市松美町', '05', '05202', '0160893', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '松美町', 'マツミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市萩の台', '05', '05202', '0160894', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '萩の台', 'ハギノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市末広町', '05', '05202', '0160895', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '末広町', 'スエヒロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市盤若町', '05', '05202', '0160896', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '盤若町', 'ハンニャマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市昭南町', '05', '05202', '0160897', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '昭南町', 'ショウナンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西落合', '13', '13104', '1610031', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西落合', 'ニシオチアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区中落合', '13', '13104', '1610032', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '中落合', 'ナカオチアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区下落合', '13', '13104', '1610033', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '下落合', 'シモオチアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区上落合', '13', '13104', '1610034', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '上落合', 'カミオチアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区中井', '13', '13104', '1610035', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '中井', 'ナカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区早稲田鶴巻町', '13', '13104', '1620041', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '早稲田鶴巻町', 'ワセダツルマキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区早稲田町', '13', '13104', '1620042', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '早稲田町', 'ワセダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区早稲田南町', '13', '13104', '1620043', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '早稲田南町', 'ワセダミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区喜久井町', '13', '13104', '1620044', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '喜久井町', 'キクイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区馬場下町', '13', '13104', '1620045', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '馬場下町', 'ババシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西早稲田2丁目', '13', '13104', '1620051', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西早稲田', 'ニシワセダ', null, null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('7045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区戸山', '13', '13104', '1620052', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '戸山', 'トヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区原町', '13', '13104', '1620053', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '原町', 'ハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区河田町', '13', '13104', '1620054', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '河田町', 'カワダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区余丁町', '13', '13104', '1620055', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '余丁町', 'ヨチョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区若松町', '13', '13104', '1620056', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '若松町', 'ワカマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区市谷柳町', '13', '13104', '1620061', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '市谷柳町', 'イチガヤヤナギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区市谷加賀町', '13', '13104', '1620062', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '市谷加賀町', 'イチガヤカガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区市谷薬王寺町', '13', '13104', '1620063', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '市谷薬王寺町', 'イチガヤヤクオウジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区市谷仲之町', '13', '13104', '1620064', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '市谷仲之町', 'イチガヤナカノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区住吉町', '13', '13104', '1620065', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '住吉町', 'スミヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区市谷台町', '13', '13104', '1620066', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '市谷台町', 'イチガヤダイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区富久町', '13', '13104', '1620067', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '富久町', 'トミヒサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区山吹町', '13', '13104', '1620801', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '山吹町', 'ヤマブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区改代町', '13', '13104', '1620802', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '改代町', 'カイタイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区赤城下町', '13', '13104', '1620803', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '赤城下町', 'アカギシタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区中里町', '13', '13104', '1620804', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '中里町', 'ナカザトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区矢来町', '13', '13104', '1620805', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '矢来町', 'ヤライチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区榎町', '13', '13104', '1620806', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '榎町', 'エノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区東榎町', '13', '13104', '1620807', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '東榎町', 'ヒガシエノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区天神町', '13', '13104', '1620808', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '天神町', 'テンジンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区水道町', '13', '13104', '1620811', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '水道町', 'スイドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西五軒町', '13', '13104', '1620812', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西五軒町', 'ニシゴケンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区東五軒町', '13', '13104', '1620813', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '東五軒町', 'ヒガシゴケンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区新小川町', '13', '13104', '1620814', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '新小川町', 'シンオガワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区筑土八幡町', '13', '13104', '1620815', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '筑土八幡町', 'ツクドハチマンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区白銀町', '13', '13104', '1620816', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '白銀町', 'シロガネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区赤城元町', '13', '13104', '1620817', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '赤城元町', 'アカギモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区築地町', '13', '13104', '1620818', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '築地町', 'ツキジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区津久戸町', '13', '13104', '1620821', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '津久戸町', 'ツクドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区下宮比町', '13', '13104', '1620822', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '下宮比町', 'シモミヤビチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区神楽河岸', '13', '13104', '1620823', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '神楽河岸', 'カグラガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区揚場町', '13', '13104', '1620824', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '揚場町', 'アゲバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区神楽坂', '13', '13104', '1620825', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '神楽坂', 'カグラザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区市谷船河原町', '13', '13104', '1620826', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '市谷船河原町', 'イチガヤフナガワラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区若宮町', '13', '13104', '1620827', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '若宮町', 'ワカミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区袋町', '13', '13104', '1620828', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '袋町', 'フクロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区横寺町', '13', '13104', '1620831', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '横寺町', 'ヨコテラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区岩戸町', '13', '13104', '1620832', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '岩戸町', 'イワトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区箪笥町', '13', '13104', '1620833', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '箪笥町', 'タンスマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区北町', '13', '13104', '1620834', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '北町', 'キタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区中町', '13', '13104', '1620835', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '中町', 'ナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区南町', '13', '13104', '1620836', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '南町', 'ミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区納戸町', '13', '13104', '1620837', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '納戸町', 'ナンドマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区細工町', '13', '13104', '1620838', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '細工町', 'サイクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区払方町', '13', '13104', '1620841', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '払方町', 'ハライカタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区市谷砂土原町', '13', '13104', '1620842', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '市谷砂土原町', 'イチガヤサドハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区市谷田町', '13', '13104', '1620843', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '市谷田町', 'イチガヤタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区市谷八幡町', '13', '13104', '1620844', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '市谷八幡町', 'イチガヤハチマンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区市谷本村町', '13', '13104', '1620845', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '市谷本村町', 'イチガヤホンムラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区市谷左内町', '13', '13104', '1620846', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '市谷左内町', 'イチガヤサナイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区市谷長延寺町', '13', '13104', '1620847', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '市谷長延寺町', 'イチガヤチョウエンジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区市谷鷹匠町', '13', '13104', '1620848', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '市谷鷹匠町', 'イチガヤタカジョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区弁天町', '13', '13104', '1620851', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '弁天町', 'ベンテンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区南榎町', '13', '13104', '1620852', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '南榎町', 'ミナミエノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区北山伏町', '13', '13104', '1620853', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '北山伏町', 'キタヤマブシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区南山伏町', '13', '13104', '1620854', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '南山伏町', 'ミナミヤマブシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区二十騎町', '13', '13104', '1620855', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '二十騎町', 'ニジュツキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区市谷甲良町', '13', '13104', '1620856', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '市谷甲良町', 'イチガヤコウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区市谷山伏町', '13', '13104', '1620857', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '市谷山伏町', 'イチガヤヤマブシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿住友ビル　1階', '13', '13104', '1630201', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿住友ビル　1階', 'シンジュクスミトモビル　01カイ');
INSERT INTO `ms_addresses` VALUES ('7219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿住友ビル　2階', '13', '13104', '1630202', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿住友ビル　2階', 'シンジュクスミトモビル　02カイ');
INSERT INTO `ms_addresses` VALUES ('7220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿住友ビル　3階', '13', '13104', '1630203', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿住友ビル　3階', 'シンジュクスミトモビル　03カイ');
INSERT INTO `ms_addresses` VALUES ('7221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿住友ビル　4階', '13', '13104', '1630204', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿住友ビル　4階', 'シンジュクスミトモビル　04カイ');
INSERT INTO `ms_addresses` VALUES ('7222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿住友ビル　5階', '13', '13104', '1630205', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿住友ビル　5階', 'シンジュクスミトモビル　05カイ');
INSERT INTO `ms_addresses` VALUES ('7223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿住友ビル　6階', '13', '13104', '1630206', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿住友ビル　6階', 'シンジュクスミトモビル　06カイ');
INSERT INTO `ms_addresses` VALUES ('7224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿住友ビル　7階', '13', '13104', '1630207', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿住友ビル　7階', 'シンジュクスミトモビル　07カイ');
INSERT INTO `ms_addresses` VALUES ('7225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿住友ビル　8階', '13', '13104', '1630208', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿住友ビル　8階', 'シンジュクスミトモビル　08カイ');
INSERT INTO `ms_addresses` VALUES ('7226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿住友ビル　9階', '13', '13104', '1630209', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿住友ビル　9階', 'シンジュクスミトモビル　09カイ');
INSERT INTO `ms_addresses` VALUES ('7227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿住友ビル　10階', '13', '13104', '1630210', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿住友ビル　10階', 'シンジュクスミトモビル　10カイ');
INSERT INTO `ms_addresses` VALUES ('7228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿住友ビル　11階', '13', '13104', '1630211', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿住友ビル　11階', 'シンジュクスミトモビル　11カイ');
INSERT INTO `ms_addresses` VALUES ('7229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿住友ビル　12階', '13', '13104', '1630212', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿住友ビル　12階', 'シンジュクスミトモビル　12カイ');
INSERT INTO `ms_addresses` VALUES ('7230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿住友ビル　13階', '13', '13104', '1630213', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿住友ビル　13階', 'シンジュクスミトモビル　13カイ');
INSERT INTO `ms_addresses` VALUES ('7231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿住友ビル　14階', '13', '13104', '1630214', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿住友ビル　14階', 'シンジュクスミトモビル　14カイ');
INSERT INTO `ms_addresses` VALUES ('7232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿住友ビル　15階', '13', '13104', '1630215', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿住友ビル　15階', 'シンジュクスミトモビル　15カイ');
INSERT INTO `ms_addresses` VALUES ('7233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿住友ビル　16階', '13', '13104', '1630216', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿住友ビル　16階', 'シンジュクスミトモビル　16カイ');
INSERT INTO `ms_addresses` VALUES ('7234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿住友ビル　17階', '13', '13104', '1630217', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿住友ビル　17階', 'シンジュクスミトモビル　17カイ');
INSERT INTO `ms_addresses` VALUES ('7235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿住友ビル　18階', '13', '13104', '1630218', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿住友ビル　18階', 'シンジュクスミトモビル　18カイ');
INSERT INTO `ms_addresses` VALUES ('7236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿住友ビル　19階', '13', '13104', '1630219', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿住友ビル　19階', 'シンジュクスミトモビル　19カイ');
INSERT INTO `ms_addresses` VALUES ('7237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿住友ビル　20階', '13', '13104', '1630220', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿住友ビル　20階', 'シンジュクスミトモビル　20カイ');
INSERT INTO `ms_addresses` VALUES ('7238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿住友ビル　21階', '13', '13104', '1630221', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿住友ビル　21階', 'シンジュクスミトモビル　21カイ');
INSERT INTO `ms_addresses` VALUES ('7239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿住友ビル　22階', '13', '13104', '1630222', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿住友ビル　22階', 'シンジュクスミトモビル　22カイ');
INSERT INTO `ms_addresses` VALUES ('7240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿住友ビル　23階', '13', '13104', '1630223', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿住友ビル　23階', 'シンジュクスミトモビル　23カイ');
INSERT INTO `ms_addresses` VALUES ('7241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿住友ビル　24階', '13', '13104', '1630224', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿住友ビル　24階', 'シンジュクスミトモビル　24カイ');
INSERT INTO `ms_addresses` VALUES ('7242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿住友ビル　25階', '13', '13104', '1630225', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿住友ビル　25階', 'シンジュクスミトモビル　25カイ');
INSERT INTO `ms_addresses` VALUES ('7243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿住友ビル　26階', '13', '13104', '1630226', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿住友ビル　26階', 'シンジュクスミトモビル　26カイ');
INSERT INTO `ms_addresses` VALUES ('7244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿住友ビル　27階', '13', '13104', '1630227', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿住友ビル　27階', 'シンジュクスミトモビル　27カイ');
INSERT INTO `ms_addresses` VALUES ('7245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿住友ビル　28階', '13', '13104', '1630228', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿住友ビル　28階', 'シンジュクスミトモビル　28カイ');
INSERT INTO `ms_addresses` VALUES ('7246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿住友ビル　29階', '13', '13104', '1630229', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿住友ビル　29階', 'シンジュクスミトモビル　29カイ');
INSERT INTO `ms_addresses` VALUES ('7247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿住友ビル　30階', '13', '13104', '1630230', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿住友ビル　30階', 'シンジュクスミトモビル　30カイ');
INSERT INTO `ms_addresses` VALUES ('7248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿住友ビル　31階', '13', '13104', '1630231', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿住友ビル　31階', 'シンジュクスミトモビル　31カイ');
INSERT INTO `ms_addresses` VALUES ('7249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿住友ビル　32階', '13', '13104', '1630232', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿住友ビル　32階', 'シンジュクスミトモビル　32カイ');
INSERT INTO `ms_addresses` VALUES ('7250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿住友ビル　33階', '13', '13104', '1630233', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿住友ビル　33階', 'シンジュクスミトモビル　33カイ');
INSERT INTO `ms_addresses` VALUES ('7251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿住友ビル　34階', '13', '13104', '1630234', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿住友ビル　34階', 'シンジュクスミトモビル　34カイ');
INSERT INTO `ms_addresses` VALUES ('7252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿住友ビル　35階', '13', '13104', '1630235', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿住友ビル　35階', 'シンジュクスミトモビル　35カイ');
INSERT INTO `ms_addresses` VALUES ('7253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿住友ビル　36階', '13', '13104', '1630236', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿住友ビル　36階', 'シンジュクスミトモビル　36カイ');
INSERT INTO `ms_addresses` VALUES ('7254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿住友ビル　37階', '13', '13104', '1630237', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿住友ビル　37階', 'シンジュクスミトモビル　37カイ');
INSERT INTO `ms_addresses` VALUES ('7255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿住友ビル　38階', '13', '13104', '1630238', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿住友ビル　38階', 'シンジュクスミトモビル　38カイ');
INSERT INTO `ms_addresses` VALUES ('7256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿住友ビル　39階', '13', '13104', '1630239', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿住友ビル　39階', 'シンジュクスミトモビル　39カイ');
INSERT INTO `ms_addresses` VALUES ('7257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿住友ビル　40階', '13', '13104', '1630240', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿住友ビル　40階', 'シンジュクスミトモビル　40カイ');
INSERT INTO `ms_addresses` VALUES ('7258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿住友ビル　41階', '13', '13104', '1630241', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿住友ビル　41階', 'シンジュクスミトモビル　41カイ');
INSERT INTO `ms_addresses` VALUES ('7259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿住友ビル　42階', '13', '13104', '1630242', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿住友ビル　42階', 'シンジュクスミトモビル　42カイ');
INSERT INTO `ms_addresses` VALUES ('7260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿住友ビル　43階', '13', '13104', '1630243', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿住友ビル　43階', 'シンジュクスミトモビル　43カイ');
INSERT INTO `ms_addresses` VALUES ('7261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿住友ビル　44階', '13', '13104', '1630244', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿住友ビル　44階', 'シンジュクスミトモビル　44カイ');
INSERT INTO `ms_addresses` VALUES ('7262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿住友ビル　45階', '13', '13104', '1630245', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿住友ビル　45階', 'シンジュクスミトモビル　45カイ');
INSERT INTO `ms_addresses` VALUES ('7263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿住友ビル　46階', '13', '13104', '1630246', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿住友ビル　46階', 'シンジュクスミトモビル　46カイ');
INSERT INTO `ms_addresses` VALUES ('7264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿住友ビル　47階', '13', '13104', '1630247', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿住友ビル　47階', 'シンジュクスミトモビル　47カイ');
INSERT INTO `ms_addresses` VALUES ('7265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿住友ビル　48階', '13', '13104', '1630248', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿住友ビル　48階', 'シンジュクスミトモビル　48カイ');
INSERT INTO `ms_addresses` VALUES ('7266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿住友ビル　49階', '13', '13104', '1630249', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿住友ビル　49階', 'シンジュクスミトモビル　49カイ');
INSERT INTO `ms_addresses` VALUES ('7267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿住友ビル　50階', '13', '13104', '1630250', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿住友ビル　50階', 'シンジュクスミトモビル　50カイ');
INSERT INTO `ms_addresses` VALUES ('7268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿住友ビル　51階', '13', '13104', '1630251', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿住友ビル　51階', 'シンジュクスミトモビル　51カイ');
INSERT INTO `ms_addresses` VALUES ('7269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿住友ビル　52階', '13', '13104', '1630252', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿住友ビル　52階', 'シンジュクスミトモビル　52カイ');
INSERT INTO `ms_addresses` VALUES ('7274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿住友ビル　', '13', '13104', '1630290', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿住友ビル　', 'シンジュクスミトモビル　');
INSERT INTO `ms_addresses` VALUES ('7275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿三井ビル　1階', '13', '13104', '1630401', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿三井ビル　1階', 'シンジュクミツイビル　01カイ');
INSERT INTO `ms_addresses` VALUES ('7276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿三井ビル　2階', '13', '13104', '1630402', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿三井ビル　2階', 'シンジュクミツイビル　02カイ');
INSERT INTO `ms_addresses` VALUES ('7277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿三井ビル　3階', '13', '13104', '1630403', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿三井ビル　3階', 'シンジュクミツイビル　03カイ');
INSERT INTO `ms_addresses` VALUES ('7278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿三井ビル　4階', '13', '13104', '1630404', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿三井ビル　4階', 'シンジュクミツイビル　04カイ');
INSERT INTO `ms_addresses` VALUES ('7279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿三井ビル　5階', '13', '13104', '1630405', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿三井ビル　5階', 'シンジュクミツイビル　05カイ');
INSERT INTO `ms_addresses` VALUES ('7280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿三井ビル　6階', '13', '13104', '1630406', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿三井ビル　6階', 'シンジュクミツイビル　06カイ');
INSERT INTO `ms_addresses` VALUES ('7281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿三井ビル　7階', '13', '13104', '1630407', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿三井ビル　7階', 'シンジュクミツイビル　07カイ');
INSERT INTO `ms_addresses` VALUES ('7282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿三井ビル　8階', '13', '13104', '1630408', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿三井ビル　8階', 'シンジュクミツイビル　08カイ');
INSERT INTO `ms_addresses` VALUES ('7283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿三井ビル　9階', '13', '13104', '1630409', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿三井ビル　9階', 'シンジュクミツイビル　09カイ');
INSERT INTO `ms_addresses` VALUES ('7284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿三井ビル　10階', '13', '13104', '1630410', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿三井ビル　10階', 'シンジュクミツイビル　10カイ');
INSERT INTO `ms_addresses` VALUES ('7285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿三井ビル　11階', '13', '13104', '1630411', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿三井ビル　11階', 'シンジュクミツイビル　11カイ');
INSERT INTO `ms_addresses` VALUES ('7286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿三井ビル　12階', '13', '13104', '1630412', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿三井ビル　12階', 'シンジュクミツイビル　12カイ');
INSERT INTO `ms_addresses` VALUES ('7287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿三井ビル　13階', '13', '13104', '1630413', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿三井ビル　13階', 'シンジュクミツイビル　13カイ');
INSERT INTO `ms_addresses` VALUES ('7288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿三井ビル　14階', '13', '13104', '1630414', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿三井ビル　14階', 'シンジュクミツイビル　14カイ');
INSERT INTO `ms_addresses` VALUES ('7289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿三井ビル　15階', '13', '13104', '1630415', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿三井ビル　15階', 'シンジュクミツイビル　15カイ');
INSERT INTO `ms_addresses` VALUES ('7290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿三井ビル　16階', '13', '13104', '1630416', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿三井ビル　16階', 'シンジュクミツイビル　16カイ');
INSERT INTO `ms_addresses` VALUES ('7291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿三井ビル　17階', '13', '13104', '1630417', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿三井ビル　17階', 'シンジュクミツイビル　17カイ');
INSERT INTO `ms_addresses` VALUES ('7292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿三井ビル　18階', '13', '13104', '1630418', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿三井ビル　18階', 'シンジュクミツイビル　18カイ');
INSERT INTO `ms_addresses` VALUES ('7293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿三井ビル　19階', '13', '13104', '1630419', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿三井ビル　19階', 'シンジュクミツイビル　19カイ');
INSERT INTO `ms_addresses` VALUES ('7294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿三井ビル　20階', '13', '13104', '1630420', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿三井ビル　20階', 'シンジュクミツイビル　20カイ');
INSERT INTO `ms_addresses` VALUES ('7295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿三井ビル　21階', '13', '13104', '1630421', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿三井ビル　21階', 'シンジュクミツイビル　21カイ');
INSERT INTO `ms_addresses` VALUES ('7296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿三井ビル　22階', '13', '13104', '1630422', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿三井ビル　22階', 'シンジュクミツイビル　22カイ');
INSERT INTO `ms_addresses` VALUES ('7297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿三井ビル　23階', '13', '13104', '1630423', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿三井ビル　23階', 'シンジュクミツイビル　23カイ');
INSERT INTO `ms_addresses` VALUES ('7298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿三井ビル　24階', '13', '13104', '1630424', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿三井ビル　24階', 'シンジュクミツイビル　24カイ');
INSERT INTO `ms_addresses` VALUES ('7299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿三井ビル　25階', '13', '13104', '1630425', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿三井ビル　25階', 'シンジュクミツイビル　25カイ');
INSERT INTO `ms_addresses` VALUES ('7300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿三井ビル　26階', '13', '13104', '1630426', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿三井ビル　26階', 'シンジュクミツイビル　26カイ');
INSERT INTO `ms_addresses` VALUES ('7301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿三井ビル　27階', '13', '13104', '1630427', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿三井ビル　27階', 'シンジュクミツイビル　27カイ');
INSERT INTO `ms_addresses` VALUES ('7302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿三井ビル　28階', '13', '13104', '1630428', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿三井ビル　28階', 'シンジュクミツイビル　28カイ');
INSERT INTO `ms_addresses` VALUES ('7303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿三井ビル　29階', '13', '13104', '1630429', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿三井ビル　29階', 'シンジュクミツイビル　29カイ');
INSERT INTO `ms_addresses` VALUES ('7304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿三井ビル　30階', '13', '13104', '1630430', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿三井ビル　30階', 'シンジュクミツイビル　30カイ');
INSERT INTO `ms_addresses` VALUES ('7305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿三井ビル　31階', '13', '13104', '1630431', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿三井ビル　31階', 'シンジュクミツイビル　31カイ');
INSERT INTO `ms_addresses` VALUES ('7306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿三井ビル　32階', '13', '13104', '1630432', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿三井ビル　32階', 'シンジュクミツイビル　32カイ');
INSERT INTO `ms_addresses` VALUES ('7307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿三井ビル　33階', '13', '13104', '1630433', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿三井ビル　33階', 'シンジュクミツイビル　33カイ');
INSERT INTO `ms_addresses` VALUES ('7308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿三井ビル　34階', '13', '13104', '1630434', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿三井ビル　34階', 'シンジュクミツイビル　34カイ');
INSERT INTO `ms_addresses` VALUES ('7309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿三井ビル　35階', '13', '13104', '1630435', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿三井ビル　35階', 'シンジュクミツイビル　35カイ');
INSERT INTO `ms_addresses` VALUES ('7310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿三井ビル　36階', '13', '13104', '1630436', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿三井ビル　36階', 'シンジュクミツイビル　36カイ');
INSERT INTO `ms_addresses` VALUES ('7311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿三井ビル　37階', '13', '13104', '1630437', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿三井ビル　37階', 'シンジュクミツイビル　37カイ');
INSERT INTO `ms_addresses` VALUES ('7312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿三井ビル　38階', '13', '13104', '1630438', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿三井ビル　38階', 'シンジュクミツイビル　38カイ');
INSERT INTO `ms_addresses` VALUES ('7313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿三井ビル　39階', '13', '13104', '1630439', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿三井ビル　39階', 'シンジュクミツイビル　39カイ');
INSERT INTO `ms_addresses` VALUES ('7314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿三井ビル　40階', '13', '13104', '1630440', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿三井ビル　40階', 'シンジュクミツイビル　40カイ');
INSERT INTO `ms_addresses` VALUES ('7315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿三井ビル　41階', '13', '13104', '1630441', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿三井ビル　41階', 'シンジュクミツイビル　41カイ');
INSERT INTO `ms_addresses` VALUES ('7316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿三井ビル　42階', '13', '13104', '1630442', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿三井ビル　42階', 'シンジュクミツイビル　42カイ');
INSERT INTO `ms_addresses` VALUES ('7317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿三井ビル　43階', '13', '13104', '1630443', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿三井ビル　43階', 'シンジュクミツイビル　43カイ');
INSERT INTO `ms_addresses` VALUES ('7318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿三井ビル　44階', '13', '13104', '1630444', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿三井ビル　44階', 'シンジュクミツイビル　44カイ');
INSERT INTO `ms_addresses` VALUES ('7319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿三井ビル　45階', '13', '13104', '1630445', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿三井ビル　45階', 'シンジュクミツイビル　45カイ');
INSERT INTO `ms_addresses` VALUES ('7320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿三井ビル　46階', '13', '13104', '1630446', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿三井ビル　46階', 'シンジュクミツイビル　46カイ');
INSERT INTO `ms_addresses` VALUES ('7321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿三井ビル　47階', '13', '13104', '1630447', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿三井ビル　47階', 'シンジュクミツイビル　47カイ');
INSERT INTO `ms_addresses` VALUES ('7322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿三井ビル　48階', '13', '13104', '1630448', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿三井ビル　48階', 'シンジュクミツイビル　48カイ');
INSERT INTO `ms_addresses` VALUES ('7323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿三井ビル　49階', '13', '13104', '1630449', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿三井ビル　49階', 'シンジュクミツイビル　49カイ');
INSERT INTO `ms_addresses` VALUES ('7324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿三井ビル　50階', '13', '13104', '1630450', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿三井ビル　50階', 'シンジュクミツイビル　50カイ');
INSERT INTO `ms_addresses` VALUES ('7325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿三井ビル　51階', '13', '13104', '1630451', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿三井ビル　51階', 'シンジュクミツイビル　51カイ');
INSERT INTO `ms_addresses` VALUES ('7326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿三井ビル　52階', '13', '13104', '1630452', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿三井ビル　52階', 'シンジュクミツイビル　52カイ');
INSERT INTO `ms_addresses` VALUES ('7327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿三井ビル　53階', '13', '13104', '1630453', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿三井ビル　53階', 'シンジュクミツイビル　53カイ');
INSERT INTO `ms_addresses` VALUES ('7328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿三井ビル　54階', '13', '13104', '1630454', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿三井ビル　54階', 'シンジュクミツイビル　54カイ');
INSERT INTO `ms_addresses` VALUES ('7329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿三井ビル　55階', '13', '13104', '1630455', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿三井ビル　55階', 'シンジュクミツイビル　55カイ');
INSERT INTO `ms_addresses` VALUES ('7336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿三井ビル　', '13', '13104', '1630490', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿三井ビル　', 'シンジュクミツイビル　');
INSERT INTO `ms_addresses` VALUES ('7337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿野村ビル　1階', '13', '13104', '1630501', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿野村ビル　1階', 'シンジュクノムラビル　01カイ');
INSERT INTO `ms_addresses` VALUES ('7338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿野村ビル　2階', '13', '13104', '1630502', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿野村ビル　2階', 'シンジュクノムラビル　02カイ');
INSERT INTO `ms_addresses` VALUES ('7339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿野村ビル　3階', '13', '13104', '1630503', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿野村ビル　3階', 'シンジュクノムラビル　03カイ');
INSERT INTO `ms_addresses` VALUES ('7340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿野村ビル　4階', '13', '13104', '1630504', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿野村ビル　4階', 'シンジュクノムラビル　04カイ');
INSERT INTO `ms_addresses` VALUES ('7341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿野村ビル　5階', '13', '13104', '1630505', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿野村ビル　5階', 'シンジュクノムラビル　05カイ');
INSERT INTO `ms_addresses` VALUES ('7342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿野村ビル　6階', '13', '13104', '1630506', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿野村ビル　6階', 'シンジュクノムラビル　06カイ');
INSERT INTO `ms_addresses` VALUES ('7343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿野村ビル　7階', '13', '13104', '1630507', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿野村ビル　7階', 'シンジュクノムラビル　07カイ');
INSERT INTO `ms_addresses` VALUES ('7344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿野村ビル　8階', '13', '13104', '1630508', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿野村ビル　8階', 'シンジュクノムラビル　08カイ');
INSERT INTO `ms_addresses` VALUES ('7345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿野村ビル　9階', '13', '13104', '1630509', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿野村ビル　9階', 'シンジュクノムラビル　09カイ');
INSERT INTO `ms_addresses` VALUES ('7346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿野村ビル　10階', '13', '13104', '1630510', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿野村ビル　10階', 'シンジュクノムラビル　10カイ');
INSERT INTO `ms_addresses` VALUES ('7347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿野村ビル　11階', '13', '13104', '1630511', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿野村ビル　11階', 'シンジュクノムラビル　11カイ');
INSERT INTO `ms_addresses` VALUES ('7348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿野村ビル　12階', '13', '13104', '1630512', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿野村ビル　12階', 'シンジュクノムラビル　12カイ');
INSERT INTO `ms_addresses` VALUES ('7349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿野村ビル　13階', '13', '13104', '1630513', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿野村ビル　13階', 'シンジュクノムラビル　13カイ');
INSERT INTO `ms_addresses` VALUES ('7350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿野村ビル　14階', '13', '13104', '1630514', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿野村ビル　14階', 'シンジュクノムラビル　14カイ'), ('7351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿野村ビル　15階', '13', '13104', '1630515', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿野村ビル　15階', 'シンジュクノムラビル　15カイ'), ('7352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿野村ビル　16階', '13', '13104', '1630516', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿野村ビル　16階', 'シンジュクノムラビル　16カイ');
INSERT INTO `ms_addresses` VALUES ('7353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿野村ビル　17階', '13', '13104', '1630517', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿野村ビル　17階', 'シンジュクノムラビル　17カイ');
INSERT INTO `ms_addresses` VALUES ('7354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿野村ビル　18階', '13', '13104', '1630518', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿野村ビル　18階', 'シンジュクノムラビル　18カイ');
INSERT INTO `ms_addresses` VALUES ('7355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿野村ビル　19階', '13', '13104', '1630519', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿野村ビル　19階', 'シンジュクノムラビル　19カイ');
INSERT INTO `ms_addresses` VALUES ('7356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿野村ビル　20階', '13', '13104', '1630520', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿野村ビル　20階', 'シンジュクノムラビル　20カイ');
INSERT INTO `ms_addresses` VALUES ('7357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿野村ビル　21階', '13', '13104', '1630521', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿野村ビル　21階', 'シンジュクノムラビル　21カイ');
INSERT INTO `ms_addresses` VALUES ('7358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿野村ビル　22階', '13', '13104', '1630522', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿野村ビル　22階', 'シンジュクノムラビル　22カイ');
INSERT INTO `ms_addresses` VALUES ('7359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿野村ビル　23階', '13', '13104', '1630523', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿野村ビル　23階', 'シンジュクノムラビル　23カイ');
INSERT INTO `ms_addresses` VALUES ('7360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿野村ビル　24階', '13', '13104', '1630524', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿野村ビル　24階', 'シンジュクノムラビル　24カイ');
INSERT INTO `ms_addresses` VALUES ('7361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿野村ビル　25階', '13', '13104', '1630525', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿野村ビル　25階', 'シンジュクノムラビル　25カイ');
INSERT INTO `ms_addresses` VALUES ('7362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿野村ビル　26階', '13', '13104', '1630526', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿野村ビル　26階', 'シンジュクノムラビル　26カイ');
INSERT INTO `ms_addresses` VALUES ('7363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿野村ビル　27階', '13', '13104', '1630527', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿野村ビル　27階', 'シンジュクノムラビル　27カイ');
INSERT INTO `ms_addresses` VALUES ('7364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿野村ビル　28階', '13', '13104', '1630528', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿野村ビル　28階', 'シンジュクノムラビル　28カイ');
INSERT INTO `ms_addresses` VALUES ('7365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿野村ビル　29階', '13', '13104', '1630529', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿野村ビル　29階', 'シンジュクノムラビル　29カイ');
INSERT INTO `ms_addresses` VALUES ('7366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿野村ビル　30階', '13', '13104', '1630530', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿野村ビル　30階', 'シンジュクノムラビル　30カイ');
INSERT INTO `ms_addresses` VALUES ('7367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿野村ビル　31階', '13', '13104', '1630531', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿野村ビル　31階', 'シンジュクノムラビル　31カイ');
INSERT INTO `ms_addresses` VALUES ('7368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿野村ビル　32階', '13', '13104', '1630532', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿野村ビル　32階', 'シンジュクノムラビル　32カイ');
INSERT INTO `ms_addresses` VALUES ('7369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿野村ビル　33階', '13', '13104', '1630533', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿野村ビル　33階', 'シンジュクノムラビル　33カイ');
INSERT INTO `ms_addresses` VALUES ('7370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿野村ビル　34階', '13', '13104', '1630534', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿野村ビル　34階', 'シンジュクノムラビル　34カイ');
INSERT INTO `ms_addresses` VALUES ('7371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿野村ビル　35階', '13', '13104', '1630535', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿野村ビル　35階', 'シンジュクノムラビル　35カイ');
INSERT INTO `ms_addresses` VALUES ('7372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿野村ビル　36階', '13', '13104', '1630536', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿野村ビル　36階', 'シンジュクノムラビル　36カイ');
INSERT INTO `ms_addresses` VALUES ('7373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿野村ビル　37階', '13', '13104', '1630537', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿野村ビル　37階', 'シンジュクノムラビル　37カイ');
INSERT INTO `ms_addresses` VALUES ('7374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿野村ビル　38階', '13', '13104', '1630538', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿野村ビル　38階', 'シンジュクノムラビル　38カイ');
INSERT INTO `ms_addresses` VALUES ('7375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿野村ビル　39階', '13', '13104', '1630539', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿野村ビル　39階', 'シンジュクノムラビル　39カイ');
INSERT INTO `ms_addresses` VALUES ('7376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿野村ビル　40階', '13', '13104', '1630540', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿野村ビル　40階', 'シンジュクノムラビル　40カイ');
INSERT INTO `ms_addresses` VALUES ('7377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿野村ビル　41階', '13', '13104', '1630541', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿野村ビル　41階', 'シンジュクノムラビル　41カイ');
INSERT INTO `ms_addresses` VALUES ('7378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿野村ビル　42階', '13', '13104', '1630542', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿野村ビル　42階', 'シンジュクノムラビル　42カイ');
INSERT INTO `ms_addresses` VALUES ('7379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿野村ビル　43階', '13', '13104', '1630543', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿野村ビル　43階', 'シンジュクノムラビル　43カイ');
INSERT INTO `ms_addresses` VALUES ('7380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿野村ビル　44階', '13', '13104', '1630544', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿野村ビル　44階', 'シンジュクノムラビル　44カイ');
INSERT INTO `ms_addresses` VALUES ('7381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿野村ビル　45階', '13', '13104', '1630545', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿野村ビル　45階', 'シンジュクノムラビル　45カイ');
INSERT INTO `ms_addresses` VALUES ('7382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿野村ビル　46階', '13', '13104', '1630546', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿野村ビル　46階', 'シンジュクノムラビル　46カイ');
INSERT INTO `ms_addresses` VALUES ('7383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿野村ビル　47階', '13', '13104', '1630547', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿野村ビル　47階', 'シンジュクノムラビル　47カイ');
INSERT INTO `ms_addresses` VALUES ('7384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿野村ビル　48階', '13', '13104', '1630548', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿野村ビル　48階', 'シンジュクノムラビル　48カイ');
INSERT INTO `ms_addresses` VALUES ('7385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿野村ビル　49階', '13', '13104', '1630549', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿野村ビル　49階', 'シンジュクノムラビル　49カイ');
INSERT INTO `ms_addresses` VALUES ('7386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿野村ビル　50階', '13', '13104', '1630550', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿野村ビル　50階', 'シンジュクノムラビル　50カイ');
INSERT INTO `ms_addresses` VALUES ('7395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿野村ビル　', '13', '13104', '1630590', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿野村ビル　', 'シンジュクノムラビル　');
INSERT INTO `ms_addresses` VALUES ('7396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿センタービル　1階', '13', '13104', '1630601', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿センタービル　1階', 'シンジュクセンタービル　01カイ');
INSERT INTO `ms_addresses` VALUES ('7397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿センタービル　2階', '13', '13104', '1630602', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿センタービル　2階', 'シンジュクセンタービル　02カイ');
INSERT INTO `ms_addresses` VALUES ('7398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿センタービル　3階', '13', '13104', '1630603', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿センタービル　3階', 'シンジュクセンタービル　03カイ');
INSERT INTO `ms_addresses` VALUES ('7399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿センタービル　4階', '13', '13104', '1630604', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿センタービル　4階', 'シンジュクセンタービル　04カイ');
INSERT INTO `ms_addresses` VALUES ('7400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿センタービル　5階', '13', '13104', '1630605', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿センタービル　5階', 'シンジュクセンタービル　05カイ');
INSERT INTO `ms_addresses` VALUES ('7401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿センタービル　6階', '13', '13104', '1630606', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿センタービル　6階', 'シンジュクセンタービル　06カイ');
INSERT INTO `ms_addresses` VALUES ('7402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿センタービル　7階', '13', '13104', '1630607', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿センタービル　7階', 'シンジュクセンタービル　07カイ');
INSERT INTO `ms_addresses` VALUES ('7403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿センタービル　8階', '13', '13104', '1630608', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿センタービル　8階', 'シンジュクセンタービル　08カイ');
INSERT INTO `ms_addresses` VALUES ('7404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿センタービル　9階', '13', '13104', '1630609', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿センタービル　9階', 'シンジュクセンタービル　09カイ');
INSERT INTO `ms_addresses` VALUES ('7405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿センタービル　10階', '13', '13104', '1630610', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿センタービル　10階', 'シンジュクセンタービル　10カイ');
INSERT INTO `ms_addresses` VALUES ('7406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿センタービル　11階', '13', '13104', '1630611', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿センタービル　11階', 'シンジュクセンタービル　11カイ');
INSERT INTO `ms_addresses` VALUES ('7407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿センタービル　12階', '13', '13104', '1630612', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿センタービル　12階', 'シンジュクセンタービル　12カイ');
INSERT INTO `ms_addresses` VALUES ('7408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿センタービル　13階', '13', '13104', '1630613', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿センタービル　13階', 'シンジュクセンタービル　13カイ');
INSERT INTO `ms_addresses` VALUES ('7409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿センタービル　14階', '13', '13104', '1630614', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿センタービル　14階', 'シンジュクセンタービル　14カイ');
INSERT INTO `ms_addresses` VALUES ('7410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿センタービル　15階', '13', '13104', '1630615', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿センタービル　15階', 'シンジュクセンタービル　15カイ');
INSERT INTO `ms_addresses` VALUES ('7411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿センタービル　16階', '13', '13104', '1630616', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿センタービル　16階', 'シンジュクセンタービル　16カイ');
INSERT INTO `ms_addresses` VALUES ('7412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿センタービル　17階', '13', '13104', '1630617', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿センタービル　17階', 'シンジュクセンタービル　17カイ');
INSERT INTO `ms_addresses` VALUES ('7413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿センタービル　18階', '13', '13104', '1630618', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿センタービル　18階', 'シンジュクセンタービル　18カイ');
INSERT INTO `ms_addresses` VALUES ('7414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿センタービル　19階', '13', '13104', '1630619', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿センタービル　19階', 'シンジュクセンタービル　19カイ');
INSERT INTO `ms_addresses` VALUES ('7415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿センタービル　20階', '13', '13104', '1630620', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿センタービル　20階', 'シンジュクセンタービル　20カイ');
INSERT INTO `ms_addresses` VALUES ('7416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿センタービル　21階', '13', '13104', '1630621', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿センタービル　21階', 'シンジュクセンタービル　21カイ');
INSERT INTO `ms_addresses` VALUES ('7417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿センタービル　22階', '13', '13104', '1630622', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿センタービル　22階', 'シンジュクセンタービル　22カイ');
INSERT INTO `ms_addresses` VALUES ('7418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿センタービル　23階', '13', '13104', '1630623', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿センタービル　23階', 'シンジュクセンタービル　23カイ');
INSERT INTO `ms_addresses` VALUES ('7419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿センタービル　24階', '13', '13104', '1630624', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿センタービル　24階', 'シンジュクセンタービル　24カイ');
INSERT INTO `ms_addresses` VALUES ('7420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿センタービル　25階', '13', '13104', '1630625', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿センタービル　25階', 'シンジュクセンタービル　25カイ');
INSERT INTO `ms_addresses` VALUES ('7421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿センタービル　26階', '13', '13104', '1630626', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿センタービル　26階', 'シンジュクセンタービル　26カイ');
INSERT INTO `ms_addresses` VALUES ('7422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿センタービル　27階', '13', '13104', '1630627', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿センタービル　27階', 'シンジュクセンタービル　27カイ');
INSERT INTO `ms_addresses` VALUES ('7423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿センタービル　28階', '13', '13104', '1630628', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿センタービル　28階', 'シンジュクセンタービル　28カイ');
INSERT INTO `ms_addresses` VALUES ('7424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿センタービル　29階', '13', '13104', '1630629', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿センタービル　29階', 'シンジュクセンタービル　29カイ');
INSERT INTO `ms_addresses` VALUES ('7425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿センタービル　30階', '13', '13104', '1630630', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿センタービル　30階', 'シンジュクセンタービル　30カイ');
INSERT INTO `ms_addresses` VALUES ('7426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿センタービル　31階', '13', '13104', '1630631', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿センタービル　31階', 'シンジュクセンタービル　31カイ');
INSERT INTO `ms_addresses` VALUES ('7427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿センタービル　32階', '13', '13104', '1630632', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿センタービル　32階', 'シンジュクセンタービル　32カイ');
INSERT INTO `ms_addresses` VALUES ('7428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿センタービル　33階', '13', '13104', '1630633', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿センタービル　33階', 'シンジュクセンタービル　33カイ');
INSERT INTO `ms_addresses` VALUES ('7429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿センタービル　34階', '13', '13104', '1630634', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿センタービル　34階', 'シンジュクセンタービル　34カイ');
INSERT INTO `ms_addresses` VALUES ('7430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿センタービル　35階', '13', '13104', '1630635', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿センタービル　35階', 'シンジュクセンタービル　35カイ');
INSERT INTO `ms_addresses` VALUES ('7431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿センタービル　36階', '13', '13104', '1630636', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿センタービル　36階', 'シンジュクセンタービル　36カイ');
INSERT INTO `ms_addresses` VALUES ('7432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿センタービル　37階', '13', '13104', '1630637', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿センタービル　37階', 'シンジュクセンタービル　37カイ');
INSERT INTO `ms_addresses` VALUES ('7433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿センタービル　38階', '13', '13104', '1630638', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿センタービル　38階', 'シンジュクセンタービル　38カイ');
INSERT INTO `ms_addresses` VALUES ('7434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿センタービル　39階', '13', '13104', '1630639', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿センタービル　39階', 'シンジュクセンタービル　39カイ');
INSERT INTO `ms_addresses` VALUES ('7435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿センタービル　40階', '13', '13104', '1630640', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿センタービル　40階', 'シンジュクセンタービル　40カイ');
INSERT INTO `ms_addresses` VALUES ('7436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿センタービル　41階', '13', '13104', '1630641', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿センタービル　41階', 'シンジュクセンタービル　41カイ');
INSERT INTO `ms_addresses` VALUES ('7437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿センタービル　42階', '13', '13104', '1630642', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿センタービル　42階', 'シンジュクセンタービル　42カイ');
INSERT INTO `ms_addresses` VALUES ('7438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿センタービル　43階', '13', '13104', '1630643', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿センタービル　43階', 'シンジュクセンタービル　43カイ');
INSERT INTO `ms_addresses` VALUES ('7439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿センタービル　44階', '13', '13104', '1630644', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿センタービル　44階', 'シンジュクセンタービル　44カイ');
INSERT INTO `ms_addresses` VALUES ('7440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿センタービル　45階', '13', '13104', '1630645', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿センタービル　45階', 'シンジュクセンタービル　45カイ');
INSERT INTO `ms_addresses` VALUES ('7441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿センタービル　46階', '13', '13104', '1630646', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿センタービル　46階', 'シンジュクセンタービル　46カイ');
INSERT INTO `ms_addresses` VALUES ('7442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿センタービル　47階', '13', '13104', '1630647', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿センタービル　47階', 'シンジュクセンタービル　47カイ');
INSERT INTO `ms_addresses` VALUES ('7443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿センタービル　48階', '13', '13104', '1630648', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿センタービル　48階', 'シンジュクセンタービル　48カイ');
INSERT INTO `ms_addresses` VALUES ('7444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿センタービル　49階', '13', '13104', '1630649', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿センタービル　49階', 'シンジュクセンタービル　49カイ');
INSERT INTO `ms_addresses` VALUES ('7445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿センタービル　50階', '13', '13104', '1630650', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿センタービル　50階', 'シンジュクセンタービル　50カイ');
INSERT INTO `ms_addresses` VALUES ('7446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿センタービル　51階', '13', '13104', '1630651', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿センタービル　51階', 'シンジュクセンタービル　51カイ');
INSERT INTO `ms_addresses` VALUES ('7447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿センタービル　52階', '13', '13104', '1630652', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿センタービル　52階', 'シンジュクセンタービル　52カイ');
INSERT INTO `ms_addresses` VALUES ('7448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿センタービル　53階', '13', '13104', '1630653', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿センタービル　53階', 'シンジュクセンタービル　53カイ');
INSERT INTO `ms_addresses` VALUES ('7449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿センタービル　54階', '13', '13104', '1630654', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿センタービル　54階', 'シンジュクセンタービル　54カイ');
INSERT INTO `ms_addresses` VALUES ('7461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿センタービル　', '13', '13104', '1630690', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿センタービル　', 'シンジュクセンタービル　');
INSERT INTO `ms_addresses` VALUES ('7462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿第一生命ビル　1階', '13', '13104', '1630701', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿第一生命ビル　1階', 'シンジュクダイイチセイメイビル　01カイ');
INSERT INTO `ms_addresses` VALUES ('7463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿第一生命ビル　2階', '13', '13104', '1630702', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿第一生命ビル　2階', 'シンジュクダイイチセイメイビル　02カイ');
INSERT INTO `ms_addresses` VALUES ('7464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿第一生命ビル　3階', '13', '13104', '1630703', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿第一生命ビル　3階', 'シンジュクダイイチセイメイビル　03カイ');
INSERT INTO `ms_addresses` VALUES ('7465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿第一生命ビル　4階', '13', '13104', '1630704', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿第一生命ビル　4階', 'シンジュクダイイチセイメイビル　04カイ');
INSERT INTO `ms_addresses` VALUES ('7466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿第一生命ビル　5階', '13', '13104', '1630705', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿第一生命ビル　5階', 'シンジュクダイイチセイメイビル　05カイ');
INSERT INTO `ms_addresses` VALUES ('7467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿第一生命ビル　6階', '13', '13104', '1630706', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿第一生命ビル　6階', 'シンジュクダイイチセイメイビル　06カイ');
INSERT INTO `ms_addresses` VALUES ('7468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿第一生命ビル　7階', '13', '13104', '1630707', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿第一生命ビル　7階', 'シンジュクダイイチセイメイビル　07カイ');
INSERT INTO `ms_addresses` VALUES ('7469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿第一生命ビル　8階', '13', '13104', '1630708', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿第一生命ビル　8階', 'シンジュクダイイチセイメイビル　08カイ');
INSERT INTO `ms_addresses` VALUES ('7470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿第一生命ビル　9階', '13', '13104', '1630709', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿第一生命ビル　9階', 'シンジュクダイイチセイメイビル　09カイ');
INSERT INTO `ms_addresses` VALUES ('7471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿第一生命ビル　10階', '13', '13104', '1630710', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿第一生命ビル　10階', 'シンジュクダイイチセイメイビル　10カイ');
INSERT INTO `ms_addresses` VALUES ('7472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿第一生命ビル　11階', '13', '13104', '1630711', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿第一生命ビル　11階', 'シンジュクダイイチセイメイビル　11カイ');
INSERT INTO `ms_addresses` VALUES ('7473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿第一生命ビル　12階', '13', '13104', '1630712', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿第一生命ビル　12階', 'シンジュクダイイチセイメイビル　12カイ');
INSERT INTO `ms_addresses` VALUES ('7474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿第一生命ビル　13階', '13', '13104', '1630713', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿第一生命ビル　13階', 'シンジュクダイイチセイメイビル　13カイ');
INSERT INTO `ms_addresses` VALUES ('7475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿第一生命ビル　14階', '13', '13104', '1630714', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿第一生命ビル　14階', 'シンジュクダイイチセイメイビル　14カイ');
INSERT INTO `ms_addresses` VALUES ('7476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿第一生命ビル　15階', '13', '13104', '1630715', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿第一生命ビル　15階', 'シンジュクダイイチセイメイビル　15カイ');
INSERT INTO `ms_addresses` VALUES ('7477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿第一生命ビル　16階', '13', '13104', '1630716', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿第一生命ビル　16階', 'シンジュクダイイチセイメイビル　16カイ');
INSERT INTO `ms_addresses` VALUES ('7478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿第一生命ビル　17階', '13', '13104', '1630717', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿第一生命ビル　17階', 'シンジュクダイイチセイメイビル　17カイ');
INSERT INTO `ms_addresses` VALUES ('7479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿第一生命ビル　18階', '13', '13104', '1630718', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿第一生命ビル　18階', 'シンジュクダイイチセイメイビル　18カイ');
INSERT INTO `ms_addresses` VALUES ('7480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿第一生命ビル　19階', '13', '13104', '1630719', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿第一生命ビル　19階', 'シンジュクダイイチセイメイビル　19カイ');
INSERT INTO `ms_addresses` VALUES ('7481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿第一生命ビル　20階', '13', '13104', '1630720', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿第一生命ビル　20階', 'シンジュクダイイチセイメイビル　20カイ');
INSERT INTO `ms_addresses` VALUES ('7482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿第一生命ビル　21階', '13', '13104', '1630721', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿第一生命ビル　21階', 'シンジュクダイイチセイメイビル　21カイ');
INSERT INTO `ms_addresses` VALUES ('7483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿第一生命ビル　22階', '13', '13104', '1630722', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿第一生命ビル　22階', 'シンジュクダイイチセイメイビル　22カイ');
INSERT INTO `ms_addresses` VALUES ('7484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿第一生命ビル　23階', '13', '13104', '1630723', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿第一生命ビル　23階', 'シンジュクダイイチセイメイビル　23カイ');
INSERT INTO `ms_addresses` VALUES ('7485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿第一生命ビル　24階', '13', '13104', '1630724', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿第一生命ビル　24階', 'シンジュクダイイチセイメイビル　24カイ');
INSERT INTO `ms_addresses` VALUES ('7486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿第一生命ビル　25階', '13', '13104', '1630725', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿第一生命ビル　25階', 'シンジュクダイイチセイメイビル　25カイ');
INSERT INTO `ms_addresses` VALUES ('7487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿第一生命ビル　26階', '13', '13104', '1630726', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿第一生命ビル　26階', 'シンジュクダイイチセイメイビル　26カイ');
INSERT INTO `ms_addresses` VALUES ('7495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿第一生命ビル　', '13', '13104', '1630790', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿第一生命ビル　', 'シンジュクダイイチセイメイビル　');
INSERT INTO `ms_addresses` VALUES ('7496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿NSビル　1階', '13', '13104', '1630801', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿NSビル　1階', 'シンジュクエヌエスビル　01カイ');
INSERT INTO `ms_addresses` VALUES ('7497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿NSビル　2階', '13', '13104', '1630802', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿NSビル　2階', 'シンジュクエヌエスビル　02カイ');
INSERT INTO `ms_addresses` VALUES ('7498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿NSビル　3階', '13', '13104', '1630803', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿NSビル　3階', 'シンジュクエヌエスビル　03カイ');
INSERT INTO `ms_addresses` VALUES ('7499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿NSビル　4階', '13', '13104', '1630804', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿NSビル　4階', 'シンジュクエヌエスビル　04カイ');
INSERT INTO `ms_addresses` VALUES ('7500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿NSビル　5階', '13', '13104', '1630805', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿NSビル　5階', 'シンジュクエヌエスビル　05カイ');
INSERT INTO `ms_addresses` VALUES ('7501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿NSビル　6階', '13', '13104', '1630806', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿NSビル　6階', 'シンジュクエヌエスビル　06カイ');
INSERT INTO `ms_addresses` VALUES ('7502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿NSビル　7階', '13', '13104', '1630807', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿NSビル　7階', 'シンジュクエヌエスビル　07カイ');
INSERT INTO `ms_addresses` VALUES ('7503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿NSビル　8階', '13', '13104', '1630808', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿NSビル　8階', 'シンジュクエヌエスビル　08カイ');
INSERT INTO `ms_addresses` VALUES ('7504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿NSビル　9階', '13', '13104', '1630809', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿NSビル　9階', 'シンジュクエヌエスビル　09カイ');
INSERT INTO `ms_addresses` VALUES ('7505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿NSビル　10階', '13', '13104', '1630810', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿NSビル　10階', 'シンジュクエヌエスビル　10カイ');
INSERT INTO `ms_addresses` VALUES ('7506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿NSビル　11階', '13', '13104', '1630811', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿NSビル　11階', 'シンジュクエヌエスビル　11カイ');
INSERT INTO `ms_addresses` VALUES ('7507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿NSビル　12階', '13', '13104', '1630812', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿NSビル　12階', 'シンジュクエヌエスビル　12カイ');
INSERT INTO `ms_addresses` VALUES ('7508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿NSビル　13階', '13', '13104', '1630813', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿NSビル　13階', 'シンジュクエヌエスビル　13カイ');
INSERT INTO `ms_addresses` VALUES ('7509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿NSビル　14階', '13', '13104', '1630814', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿NSビル　14階', 'シンジュクエヌエスビル　14カイ');
INSERT INTO `ms_addresses` VALUES ('7510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿NSビル　15階', '13', '13104', '1630815', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿NSビル　15階', 'シンジュクエヌエスビル　15カイ');
INSERT INTO `ms_addresses` VALUES ('7511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿NSビル　16階', '13', '13104', '1630816', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿NSビル　16階', 'シンジュクエヌエスビル　16カイ');
INSERT INTO `ms_addresses` VALUES ('7512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿NSビル　17階', '13', '13104', '1630817', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿NSビル　17階', 'シンジュクエヌエスビル　17カイ');
INSERT INTO `ms_addresses` VALUES ('7513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿NSビル　18階', '13', '13104', '1630818', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿NSビル　18階', 'シンジュクエヌエスビル　18カイ');
INSERT INTO `ms_addresses` VALUES ('7514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿NSビル　19階', '13', '13104', '1630819', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿NSビル　19階', 'シンジュクエヌエスビル　19カイ');
INSERT INTO `ms_addresses` VALUES ('7515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿NSビル　20階', '13', '13104', '1630820', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿NSビル　20階', 'シンジュクエヌエスビル　20カイ');
INSERT INTO `ms_addresses` VALUES ('7516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿NSビル　21階', '13', '13104', '1630821', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿NSビル　21階', 'シンジュクエヌエスビル　21カイ');
INSERT INTO `ms_addresses` VALUES ('7517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿NSビル　22階', '13', '13104', '1630822', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿NSビル　22階', 'シンジュクエヌエスビル　22カイ');
INSERT INTO `ms_addresses` VALUES ('7518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿NSビル　23階', '13', '13104', '1630823', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿NSビル　23階', 'シンジュクエヌエスビル　23カイ');
INSERT INTO `ms_addresses` VALUES ('7519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿NSビル　24階', '13', '13104', '1630824', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿NSビル　24階', 'シンジュクエヌエスビル　24カイ');
INSERT INTO `ms_addresses` VALUES ('7520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿NSビル　25階', '13', '13104', '1630825', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿NSビル　25階', 'シンジュクエヌエスビル　25カイ');
INSERT INTO `ms_addresses` VALUES ('7521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿NSビル　26階', '13', '13104', '1630826', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿NSビル　26階', 'シンジュクエヌエスビル　26カイ');
INSERT INTO `ms_addresses` VALUES ('7522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿NSビル　27階', '13', '13104', '1630827', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿NSビル　27階', 'シンジュクエヌエスビル　27カイ');
INSERT INTO `ms_addresses` VALUES ('7523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿NSビル　28階', '13', '13104', '1630828', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿NSビル　28階', 'シンジュクエヌエスビル　28カイ');
INSERT INTO `ms_addresses` VALUES ('7524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿NSビル　29階', '13', '13104', '1630829', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿NSビル　29階', 'シンジュクエヌエスビル　29カイ');
INSERT INTO `ms_addresses` VALUES ('7525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿NSビル　30階', '13', '13104', '1630830', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿NSビル　30階', 'シンジュクエヌエスビル　30カイ');
INSERT INTO `ms_addresses` VALUES ('7530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿NSビル　', '13', '13104', '1630890', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿NSビル　', 'シンジュクエヌエスビル　');
INSERT INTO `ms_addresses` VALUES ('7531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿モノリス　1階', '13', '13104', '1630901', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿モノリス　1階', 'シンジュクモノリス　01カイ');
INSERT INTO `ms_addresses` VALUES ('7532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿モノリス　2階', '13', '13104', '1630902', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿モノリス　2階', 'シンジュクモノリス　02カイ');
INSERT INTO `ms_addresses` VALUES ('7533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿モノリス　3階', '13', '13104', '1630903', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿モノリス　3階', 'シンジュクモノリス　03カイ');
INSERT INTO `ms_addresses` VALUES ('7534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿モノリス　4階', '13', '13104', '1630904', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿モノリス　4階', 'シンジュクモノリス　04カイ');
INSERT INTO `ms_addresses` VALUES ('7535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿モノリス　5階', '13', '13104', '1630905', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿モノリス　5階', 'シンジュクモノリス　05カイ');
INSERT INTO `ms_addresses` VALUES ('7536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿モノリス　6階', '13', '13104', '1630906', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿モノリス　6階', 'シンジュクモノリス　06カイ');
INSERT INTO `ms_addresses` VALUES ('7537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿モノリス　7階', '13', '13104', '1630907', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿モノリス　7階', 'シンジュクモノリス　07カイ');
INSERT INTO `ms_addresses` VALUES ('7538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿モノリス　8階', '13', '13104', '1630908', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿モノリス　8階', 'シンジュクモノリス　08カイ');
INSERT INTO `ms_addresses` VALUES ('7539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿モノリス　9階', '13', '13104', '1630909', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿モノリス　9階', 'シンジュクモノリス　09カイ');
INSERT INTO `ms_addresses` VALUES ('7540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿モノリス　10階', '13', '13104', '1630910', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿モノリス　10階', 'シンジュクモノリス　10カイ');
INSERT INTO `ms_addresses` VALUES ('7541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿モノリス　11階', '13', '13104', '1630911', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿モノリス　11階', 'シンジュクモノリス　11カイ');
INSERT INTO `ms_addresses` VALUES ('7542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿モノリス　12階', '13', '13104', '1630912', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿モノリス　12階', 'シンジュクモノリス　12カイ');
INSERT INTO `ms_addresses` VALUES ('7543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿モノリス　13階', '13', '13104', '1630913', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿モノリス　13階', 'シンジュクモノリス　13カイ');
INSERT INTO `ms_addresses` VALUES ('7544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿モノリス　14階', '13', '13104', '1630914', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿モノリス　14階', 'シンジュクモノリス　14カイ');
INSERT INTO `ms_addresses` VALUES ('7545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿モノリス　15階', '13', '13104', '1630915', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿モノリス　15階', 'シンジュクモノリス　15カイ');
INSERT INTO `ms_addresses` VALUES ('7546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿モノリス　16階', '13', '13104', '1630916', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿モノリス　16階', 'シンジュクモノリス　16カイ');
INSERT INTO `ms_addresses` VALUES ('7547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿モノリス　17階', '13', '13104', '1630917', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿モノリス　17階', 'シンジュクモノリス　17カイ');
INSERT INTO `ms_addresses` VALUES ('7548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿モノリス　18階', '13', '13104', '1630918', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿モノリス　18階', 'シンジュクモノリス　18カイ');
INSERT INTO `ms_addresses` VALUES ('7549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿モノリス　19階', '13', '13104', '1630919', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿モノリス　19階', 'シンジュクモノリス　19カイ');
INSERT INTO `ms_addresses` VALUES ('7550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿モノリス　20階', '13', '13104', '1630920', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿モノリス　20階', 'シンジュクモノリス　20カイ');
INSERT INTO `ms_addresses` VALUES ('7551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿モノリス　21階', '13', '13104', '1630921', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿モノリス　21階', 'シンジュクモノリス　21カイ');
INSERT INTO `ms_addresses` VALUES ('7552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿モノリス　22階', '13', '13104', '1630922', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿モノリス　22階', 'シンジュクモノリス　22カイ');
INSERT INTO `ms_addresses` VALUES ('7553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿モノリス　23階', '13', '13104', '1630923', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿モノリス　23階', 'シンジュクモノリス　23カイ');
INSERT INTO `ms_addresses` VALUES ('7554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿モノリス　24階', '13', '13104', '1630924', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿モノリス　24階', 'シンジュクモノリス　24カイ');
INSERT INTO `ms_addresses` VALUES ('7555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿モノリス　25階', '13', '13104', '1630925', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿モノリス　25階', 'シンジュクモノリス　25カイ');
INSERT INTO `ms_addresses` VALUES ('7556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿モノリス　26階', '13', '13104', '1630926', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿モノリス　26階', 'シンジュクモノリス　26カイ');
INSERT INTO `ms_addresses` VALUES ('7557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿モノリス　27階', '13', '13104', '1630927', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿モノリス　27階', 'シンジュクモノリス　27カイ');
INSERT INTO `ms_addresses` VALUES ('7558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿モノリス　28階', '13', '13104', '1630928', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿モノリス　28階', 'シンジュクモノリス　28カイ');
INSERT INTO `ms_addresses` VALUES ('7559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿モノリス　29階', '13', '13104', '1630929', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿モノリス　29階', 'シンジュクモノリス　29カイ');
INSERT INTO `ms_addresses` VALUES ('7560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿モノリス　30階', '13', '13104', '1630930', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿モノリス　30階', 'シンジュクモノリス　30カイ');
INSERT INTO `ms_addresses` VALUES ('7565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿モノリス　', '13', '13104', '1630990', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿モノリス　', 'シンジュクモノリス　');
INSERT INTO `ms_addresses` VALUES ('7566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿パークタワー　1階', '13', '13104', '1631001', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿パークタワー　1階', 'シンジュクパークタワー　01カイ');
INSERT INTO `ms_addresses` VALUES ('7567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿パークタワー　2階', '13', '13104', '1631002', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿パークタワー　2階', 'シンジュクパークタワー　02カイ');
INSERT INTO `ms_addresses` VALUES ('7568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿パークタワー　3階', '13', '13104', '1631003', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿パークタワー　3階', 'シンジュクパークタワー　03カイ');
INSERT INTO `ms_addresses` VALUES ('7569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿パークタワー　4階', '13', '13104', '1631004', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿パークタワー　4階', 'シンジュクパークタワー　04カイ');
INSERT INTO `ms_addresses` VALUES ('7570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿パークタワー　5階', '13', '13104', '1631005', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿パークタワー　5階', 'シンジュクパークタワー　05カイ');
INSERT INTO `ms_addresses` VALUES ('7571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿パークタワー　6階', '13', '13104', '1631006', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿パークタワー　6階', 'シンジュクパークタワー　06カイ');
INSERT INTO `ms_addresses` VALUES ('7572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿パークタワー　7階', '13', '13104', '1631007', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿パークタワー　7階', 'シンジュクパークタワー　07カイ');
INSERT INTO `ms_addresses` VALUES ('7573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿パークタワー　8階', '13', '13104', '1631008', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿パークタワー　8階', 'シンジュクパークタワー　08カイ');
INSERT INTO `ms_addresses` VALUES ('7574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿パークタワー　9階', '13', '13104', '1631009', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿パークタワー　9階', 'シンジュクパークタワー　09カイ');
INSERT INTO `ms_addresses` VALUES ('7575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿パークタワー　10階', '13', '13104', '1631010', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿パークタワー　10階', 'シンジュクパークタワー　10カイ');
INSERT INTO `ms_addresses` VALUES ('7576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿パークタワー　11階', '13', '13104', '1631011', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿パークタワー　11階', 'シンジュクパークタワー　11カイ');
INSERT INTO `ms_addresses` VALUES ('7577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿パークタワー　12階', '13', '13104', '1631012', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿パークタワー　12階', 'シンジュクパークタワー　12カイ');
INSERT INTO `ms_addresses` VALUES ('7578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿パークタワー　13階', '13', '13104', '1631013', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿パークタワー　13階', 'シンジュクパークタワー　13カイ');
INSERT INTO `ms_addresses` VALUES ('7579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿パークタワー　14階', '13', '13104', '1631014', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿パークタワー　14階', 'シンジュクパークタワー　14カイ');
INSERT INTO `ms_addresses` VALUES ('7580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿パークタワー　15階', '13', '13104', '1631015', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿パークタワー　15階', 'シンジュクパークタワー　15カイ');
INSERT INTO `ms_addresses` VALUES ('7581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿パークタワー　16階', '13', '13104', '1631016', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿パークタワー　16階', 'シンジュクパークタワー　16カイ');
INSERT INTO `ms_addresses` VALUES ('7582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿パークタワー　17階', '13', '13104', '1631017', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿パークタワー　17階', 'シンジュクパークタワー　17カイ');
INSERT INTO `ms_addresses` VALUES ('7583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿パークタワー　18階', '13', '13104', '1631018', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿パークタワー　18階', 'シンジュクパークタワー　18カイ');
INSERT INTO `ms_addresses` VALUES ('7584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿パークタワー　19階', '13', '13104', '1631019', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿パークタワー　19階', 'シンジュクパークタワー　19カイ');
INSERT INTO `ms_addresses` VALUES ('7585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿パークタワー　20階', '13', '13104', '1631020', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿パークタワー　20階', 'シンジュクパークタワー　20カイ');
INSERT INTO `ms_addresses` VALUES ('7586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿パークタワー　21階', '13', '13104', '1631021', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿パークタワー　21階', 'シンジュクパークタワー　21カイ');
INSERT INTO `ms_addresses` VALUES ('7587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿パークタワー　22階', '13', '13104', '1631022', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿パークタワー　22階', 'シンジュクパークタワー　22カイ');
INSERT INTO `ms_addresses` VALUES ('7588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿パークタワー　23階', '13', '13104', '1631023', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿パークタワー　23階', 'シンジュクパークタワー　23カイ');
INSERT INTO `ms_addresses` VALUES ('7589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿パークタワー　24階', '13', '13104', '1631024', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿パークタワー　24階', 'シンジュクパークタワー　24カイ');
INSERT INTO `ms_addresses` VALUES ('7590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿パークタワー　25階', '13', '13104', '1631025', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿パークタワー　25階', 'シンジュクパークタワー　25カイ');
INSERT INTO `ms_addresses` VALUES ('7591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿パークタワー　26階', '13', '13104', '1631026', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿パークタワー　26階', 'シンジュクパークタワー　26カイ');
INSERT INTO `ms_addresses` VALUES ('7592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿パークタワー　27階', '13', '13104', '1631027', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿パークタワー　27階', 'シンジュクパークタワー　27カイ');
INSERT INTO `ms_addresses` VALUES ('7593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿パークタワー　28階', '13', '13104', '1631028', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿パークタワー　28階', 'シンジュクパークタワー　28カイ');
INSERT INTO `ms_addresses` VALUES ('7594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿パークタワー　29階', '13', '13104', '1631029', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿パークタワー　29階', 'シンジュクパークタワー　29カイ');
INSERT INTO `ms_addresses` VALUES ('7595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿パークタワー　30階', '13', '13104', '1631030', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿パークタワー　30階', 'シンジュクパークタワー　30カイ');
INSERT INTO `ms_addresses` VALUES ('7596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿パークタワー　31階', '13', '13104', '1631031', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿パークタワー　31階', 'シンジュクパークタワー　31カイ');
INSERT INTO `ms_addresses` VALUES ('7597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿パークタワー　32階', '13', '13104', '1631032', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿パークタワー　32階', 'シンジュクパークタワー　32カイ');
INSERT INTO `ms_addresses` VALUES ('7598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿パークタワー　33階', '13', '13104', '1631033', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿パークタワー　33階', 'シンジュクパークタワー　33カイ');
INSERT INTO `ms_addresses` VALUES ('7599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿パークタワー　34階', '13', '13104', '1631034', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿パークタワー　34階', 'シンジュクパークタワー　34カイ');
INSERT INTO `ms_addresses` VALUES ('7600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿パークタワー　35階', '13', '13104', '1631035', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿パークタワー　35階', 'シンジュクパークタワー　35カイ');
INSERT INTO `ms_addresses` VALUES ('7601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿パークタワー　36階', '13', '13104', '1631036', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿パークタワー　36階', 'シンジュクパークタワー　36カイ');
INSERT INTO `ms_addresses` VALUES ('7602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿パークタワー　37階', '13', '13104', '1631037', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿パークタワー　37階', 'シンジュクパークタワー　37カイ');
INSERT INTO `ms_addresses` VALUES ('7603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿パークタワー　38階', '13', '13104', '1631038', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿パークタワー　38階', 'シンジュクパークタワー　38カイ');
INSERT INTO `ms_addresses` VALUES ('7604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿パークタワー　39階', '13', '13104', '1631039', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿パークタワー　39階', 'シンジュクパークタワー　39カイ');
INSERT INTO `ms_addresses` VALUES ('7605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿パークタワー　40階', '13', '13104', '1631040', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿パークタワー　40階', 'シンジュクパークタワー　40カイ');
INSERT INTO `ms_addresses` VALUES ('7606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿パークタワー　41階', '13', '13104', '1631041', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿パークタワー　41階', 'シンジュクパークタワー　41カイ');
INSERT INTO `ms_addresses` VALUES ('7607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿パークタワー　42階', '13', '13104', '1631042', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿パークタワー　42階', 'シンジュクパークタワー　42カイ');
INSERT INTO `ms_addresses` VALUES ('7608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿パークタワー　43階', '13', '13104', '1631043', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿パークタワー　43階', 'シンジュクパークタワー　43カイ');
INSERT INTO `ms_addresses` VALUES ('7609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿パークタワー　44階', '13', '13104', '1631044', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿パークタワー　44階', 'シンジュクパークタワー　44カイ');
INSERT INTO `ms_addresses` VALUES ('7610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿パークタワー　45階', '13', '13104', '1631045', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿パークタワー　45階', 'シンジュクパークタワー　45カイ');
INSERT INTO `ms_addresses` VALUES ('7611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿パークタワー　46階', '13', '13104', '1631046', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿パークタワー　46階', 'シンジュクパークタワー　46カイ');
INSERT INTO `ms_addresses` VALUES ('7612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿パークタワー　47階', '13', '13104', '1631047', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿パークタワー　47階', 'シンジュクパークタワー　47カイ');
INSERT INTO `ms_addresses` VALUES ('7613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿パークタワー　48階', '13', '13104', '1631048', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿パークタワー　48階', 'シンジュクパークタワー　48カイ');
INSERT INTO `ms_addresses` VALUES ('7614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿パークタワー　49階', '13', '13104', '1631049', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿パークタワー　49階', 'シンジュクパークタワー　49カイ');
INSERT INTO `ms_addresses` VALUES ('7615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿パークタワー　50階', '13', '13104', '1631050', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿パークタワー　50階', 'シンジュクパークタワー　50カイ');
INSERT INTO `ms_addresses` VALUES ('7616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿パークタワー　51階', '13', '13104', '1631051', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿パークタワー　51階', 'シンジュクパークタワー　51カイ');
INSERT INTO `ms_addresses` VALUES ('7617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿パークタワー　52階', '13', '13104', '1631052', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿パークタワー　52階', 'シンジュクパークタワー　52カイ');
INSERT INTO `ms_addresses` VALUES ('7623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿パークタワー　', '13', '13104', '1631090', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿パークタワー　', 'シンジュクパークタワー　');
INSERT INTO `ms_addresses` VALUES ('7624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿スクエアタワー　1階', '13', '13104', '1631101', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿スクエアタワー　1階', 'シンジュクスクエアタワー　01カイ');
INSERT INTO `ms_addresses` VALUES ('7625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿スクエアタワー　2階', '13', '13104', '1631102', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿スクエアタワー　2階', 'シンジュクスクエアタワー　02カイ');
INSERT INTO `ms_addresses` VALUES ('7626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿スクエアタワー　3階', '13', '13104', '1631103', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿スクエアタワー　3階', 'シンジュクスクエアタワー　03カイ');
INSERT INTO `ms_addresses` VALUES ('7627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿スクエアタワー　4階', '13', '13104', '1631104', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿スクエアタワー　4階', 'シンジュクスクエアタワー　04カイ');
INSERT INTO `ms_addresses` VALUES ('7628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿スクエアタワー　5階', '13', '13104', '1631105', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿スクエアタワー　5階', 'シンジュクスクエアタワー　05カイ');
INSERT INTO `ms_addresses` VALUES ('7629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿スクエアタワー　6階', '13', '13104', '1631106', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿スクエアタワー　6階', 'シンジュクスクエアタワー　06カイ');
INSERT INTO `ms_addresses` VALUES ('7630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿スクエアタワー　7階', '13', '13104', '1631107', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿スクエアタワー　7階', 'シンジュクスクエアタワー　07カイ');
INSERT INTO `ms_addresses` VALUES ('7631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿スクエアタワー　8階', '13', '13104', '1631108', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿スクエアタワー　8階', 'シンジュクスクエアタワー　08カイ');
INSERT INTO `ms_addresses` VALUES ('7632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿スクエアタワー　9階', '13', '13104', '1631109', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿スクエアタワー　9階', 'シンジュクスクエアタワー　09カイ');
INSERT INTO `ms_addresses` VALUES ('7633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿スクエアタワー　10階', '13', '13104', '1631110', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿スクエアタワー　10階', 'シンジュクスクエアタワー　10カイ');
INSERT INTO `ms_addresses` VALUES ('7634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿スクエアタワー　11階', '13', '13104', '1631111', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿スクエアタワー　11階', 'シンジュクスクエアタワー　11カイ');
INSERT INTO `ms_addresses` VALUES ('7635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿スクエアタワー　12階', '13', '13104', '1631112', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿スクエアタワー　12階', 'シンジュクスクエアタワー　12カイ');
INSERT INTO `ms_addresses` VALUES ('7636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿スクエアタワー　13階', '13', '13104', '1631113', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿スクエアタワー　13階', 'シンジュクスクエアタワー　13カイ');
INSERT INTO `ms_addresses` VALUES ('7637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿スクエアタワー　14階', '13', '13104', '1631114', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿スクエアタワー　14階', 'シンジュクスクエアタワー　14カイ');
INSERT INTO `ms_addresses` VALUES ('7638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿スクエアタワー　15階', '13', '13104', '1631115', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿スクエアタワー　15階', 'シンジュクスクエアタワー　15カイ');
INSERT INTO `ms_addresses` VALUES ('7639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿スクエアタワー　16階', '13', '13104', '1631116', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿スクエアタワー　16階', 'シンジュクスクエアタワー　16カイ');
INSERT INTO `ms_addresses` VALUES ('7640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿スクエアタワー　17階', '13', '13104', '1631117', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿スクエアタワー　17階', 'シンジュクスクエアタワー　17カイ');
INSERT INTO `ms_addresses` VALUES ('7641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿スクエアタワー　18階', '13', '13104', '1631118', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿スクエアタワー　18階', 'シンジュクスクエアタワー　18カイ');
INSERT INTO `ms_addresses` VALUES ('7642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿スクエアタワー　19階', '13', '13104', '1631119', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿スクエアタワー　19階', 'シンジュクスクエアタワー　19カイ');
INSERT INTO `ms_addresses` VALUES ('7643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿スクエアタワー　20階', '13', '13104', '1631120', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿スクエアタワー　20階', 'シンジュクスクエアタワー　20カイ');
INSERT INTO `ms_addresses` VALUES ('7644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿スクエアタワー　21階', '13', '13104', '1631121', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿スクエアタワー　21階', 'シンジュクスクエアタワー　21カイ');
INSERT INTO `ms_addresses` VALUES ('7645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿スクエアタワー　22階', '13', '13104', '1631122', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿スクエアタワー　22階', 'シンジュクスクエアタワー　22カイ');
INSERT INTO `ms_addresses` VALUES ('7646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿スクエアタワー　23階', '13', '13104', '1631123', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿スクエアタワー　23階', 'シンジュクスクエアタワー　23カイ');
INSERT INTO `ms_addresses` VALUES ('7647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿スクエアタワー　24階', '13', '13104', '1631124', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿スクエアタワー　24階', 'シンジュクスクエアタワー　24カイ');
INSERT INTO `ms_addresses` VALUES ('7648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿スクエアタワー　25階', '13', '13104', '1631125', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿スクエアタワー　25階', 'シンジュクスクエアタワー　25カイ');
INSERT INTO `ms_addresses` VALUES ('7649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿スクエアタワー　26階', '13', '13104', '1631126', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿スクエアタワー　26階', 'シンジュクスクエアタワー　26カイ');
INSERT INTO `ms_addresses` VALUES ('7650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿スクエアタワー　27階', '13', '13104', '1631127', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿スクエアタワー　27階', 'シンジュクスクエアタワー　27カイ');
INSERT INTO `ms_addresses` VALUES ('7651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿スクエアタワー　28階', '13', '13104', '1631128', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿スクエアタワー　28階', 'シンジュクスクエアタワー　28カイ');
INSERT INTO `ms_addresses` VALUES ('7652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿スクエアタワー　29階', '13', '13104', '1631129', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿スクエアタワー　29階', 'シンジュクスクエアタワー　29カイ');
INSERT INTO `ms_addresses` VALUES ('7653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿スクエアタワー　30階', '13', '13104', '1631130', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿スクエアタワー　30階', 'シンジュクスクエアタワー　30カイ');
INSERT INTO `ms_addresses` VALUES ('7654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿スクエアタワー　', '13', '13104', '1631190', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿スクエアタワー　', 'シンジュクスクエアタワー　');
INSERT INTO `ms_addresses` VALUES ('7655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿アイランドタワー　1階', '13', '13104', '1631301', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿アイランドタワー　1階', 'シンジュクアイランドタワー　01カイ');
INSERT INTO `ms_addresses` VALUES ('7656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿アイランドタワー　2階', '13', '13104', '1631302', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿アイランドタワー　2階', 'シンジュクアイランドタワー　02カイ');
INSERT INTO `ms_addresses` VALUES ('7657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿アイランドタワー　3階', '13', '13104', '1631303', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿アイランドタワー　3階', 'シンジュクアイランドタワー　03カイ');
INSERT INTO `ms_addresses` VALUES ('7658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿アイランドタワー　4階', '13', '13104', '1631304', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿アイランドタワー　4階', 'シンジュクアイランドタワー　04カイ');
INSERT INTO `ms_addresses` VALUES ('7659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿アイランドタワー　5階', '13', '13104', '1631305', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿アイランドタワー　5階', 'シンジュクアイランドタワー　05カイ');
INSERT INTO `ms_addresses` VALUES ('7660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿アイランドタワー　6階', '13', '13104', '1631306', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿アイランドタワー　6階', 'シンジュクアイランドタワー　06カイ');
INSERT INTO `ms_addresses` VALUES ('7661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿アイランドタワー　7階', '13', '13104', '1631307', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿アイランドタワー　7階', 'シンジュクアイランドタワー　07カイ');
INSERT INTO `ms_addresses` VALUES ('7662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿アイランドタワー　8階', '13', '13104', '1631308', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿アイランドタワー　8階', 'シンジュクアイランドタワー　08カイ');
INSERT INTO `ms_addresses` VALUES ('7663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿アイランドタワー　9階', '13', '13104', '1631309', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿アイランドタワー　9階', 'シンジュクアイランドタワー　09カイ');
INSERT INTO `ms_addresses` VALUES ('7664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿アイランドタワー　10階', '13', '13104', '1631310', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿アイランドタワー　10階', 'シンジュクアイランドタワー　10カイ');
INSERT INTO `ms_addresses` VALUES ('7665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿アイランドタワー　11階', '13', '13104', '1631311', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿アイランドタワー　11階', 'シンジュクアイランドタワー　11カイ');
INSERT INTO `ms_addresses` VALUES ('7666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿アイランドタワー　12階', '13', '13104', '1631312', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿アイランドタワー　12階', 'シンジュクアイランドタワー　12カイ');
INSERT INTO `ms_addresses` VALUES ('7667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿アイランドタワー　13階', '13', '13104', '1631313', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿アイランドタワー　13階', 'シンジュクアイランドタワー　13カイ');
INSERT INTO `ms_addresses` VALUES ('7668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿アイランドタワー　14階', '13', '13104', '1631314', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿アイランドタワー　14階', 'シンジュクアイランドタワー　14カイ');
INSERT INTO `ms_addresses` VALUES ('7669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿アイランドタワー　15階', '13', '13104', '1631315', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿アイランドタワー　15階', 'シンジュクアイランドタワー　15カイ');
INSERT INTO `ms_addresses` VALUES ('7670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿アイランドタワー　16階', '13', '13104', '1631316', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿アイランドタワー　16階', 'シンジュクアイランドタワー　16カイ');
INSERT INTO `ms_addresses` VALUES ('7671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿アイランドタワー　17階', '13', '13104', '1631317', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿アイランドタワー　17階', 'シンジュクアイランドタワー　17カイ');
INSERT INTO `ms_addresses` VALUES ('7672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿アイランドタワー　18階', '13', '13104', '1631318', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿アイランドタワー　18階', 'シンジュクアイランドタワー　18カイ');
INSERT INTO `ms_addresses` VALUES ('7673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿アイランドタワー　19階', '13', '13104', '1631319', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿アイランドタワー　19階', 'シンジュクアイランドタワー　19カイ');
INSERT INTO `ms_addresses` VALUES ('7674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿アイランドタワー　20階', '13', '13104', '1631320', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿アイランドタワー　20階', 'シンジュクアイランドタワー　20カイ');
INSERT INTO `ms_addresses` VALUES ('7675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿アイランドタワー　21階', '13', '13104', '1631321', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿アイランドタワー　21階', 'シンジュクアイランドタワー　21カイ');
INSERT INTO `ms_addresses` VALUES ('7676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿アイランドタワー　22階', '13', '13104', '1631322', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿アイランドタワー　22階', 'シンジュクアイランドタワー　22カイ');
INSERT INTO `ms_addresses` VALUES ('7677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿アイランドタワー　23階', '13', '13104', '1631323', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿アイランドタワー　23階', 'シンジュクアイランドタワー　23カイ');
INSERT INTO `ms_addresses` VALUES ('7678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿アイランドタワー　24階', '13', '13104', '1631324', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿アイランドタワー　24階', 'シンジュクアイランドタワー　24カイ');
INSERT INTO `ms_addresses` VALUES ('7679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿アイランドタワー　25階', '13', '13104', '1631325', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿アイランドタワー　25階', 'シンジュクアイランドタワー　25カイ');
INSERT INTO `ms_addresses` VALUES ('7680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿アイランドタワー　26階', '13', '13104', '1631326', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿アイランドタワー　26階', 'シンジュクアイランドタワー　26カイ');
INSERT INTO `ms_addresses` VALUES ('7681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿アイランドタワー　27階', '13', '13104', '1631327', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿アイランドタワー　27階', 'シンジュクアイランドタワー　27カイ');
INSERT INTO `ms_addresses` VALUES ('7682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿アイランドタワー　28階', '13', '13104', '1631328', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿アイランドタワー　28階', 'シンジュクアイランドタワー　28カイ');
INSERT INTO `ms_addresses` VALUES ('7683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿アイランドタワー　29階', '13', '13104', '1631329', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿アイランドタワー　29階', 'シンジュクアイランドタワー　29カイ');
INSERT INTO `ms_addresses` VALUES ('7684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿アイランドタワー　30階', '13', '13104', '1631330', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿アイランドタワー　30階', 'シンジュクアイランドタワー　30カイ');
INSERT INTO `ms_addresses` VALUES ('7685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿アイランドタワー　31階', '13', '13104', '1631331', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿アイランドタワー　31階', 'シンジュクアイランドタワー　31カイ');
INSERT INTO `ms_addresses` VALUES ('7686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿アイランドタワー　32階', '13', '13104', '1631332', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿アイランドタワー　32階', 'シンジュクアイランドタワー　32カイ');
INSERT INTO `ms_addresses` VALUES ('7687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿アイランドタワー　33階', '13', '13104', '1631333', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿アイランドタワー　33階', 'シンジュクアイランドタワー　33カイ');
INSERT INTO `ms_addresses` VALUES ('7688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿アイランドタワー　34階', '13', '13104', '1631334', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿アイランドタワー　34階', 'シンジュクアイランドタワー　34カイ');
INSERT INTO `ms_addresses` VALUES ('7689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿アイランドタワー　35階', '13', '13104', '1631335', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿アイランドタワー　35階', 'シンジュクアイランドタワー　35カイ');
INSERT INTO `ms_addresses` VALUES ('7690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿アイランドタワー　36階', '13', '13104', '1631336', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿アイランドタワー　36階', 'シンジュクアイランドタワー　36カイ');
INSERT INTO `ms_addresses` VALUES ('7691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿アイランドタワー　37階', '13', '13104', '1631337', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿アイランドタワー　37階', 'シンジュクアイランドタワー　37カイ');
INSERT INTO `ms_addresses` VALUES ('7692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿アイランドタワー　38階', '13', '13104', '1631338', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿アイランドタワー　38階', 'シンジュクアイランドタワー　38カイ');
INSERT INTO `ms_addresses` VALUES ('7693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿アイランドタワー　39階', '13', '13104', '1631339', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿アイランドタワー　39階', 'シンジュクアイランドタワー　39カイ');
INSERT INTO `ms_addresses` VALUES ('7694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿アイランドタワー　40階', '13', '13104', '1631340', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿アイランドタワー　40階', 'シンジュクアイランドタワー　40カイ');
INSERT INTO `ms_addresses` VALUES ('7695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿アイランドタワー　41階', '13', '13104', '1631341', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿アイランドタワー　41階', 'シンジュクアイランドタワー　41カイ');
INSERT INTO `ms_addresses` VALUES ('7696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿アイランドタワー　42階', '13', '13104', '1631342', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿アイランドタワー　42階', 'シンジュクアイランドタワー　42カイ');
INSERT INTO `ms_addresses` VALUES ('7697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿アイランドタワー　43階', '13', '13104', '1631343', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿アイランドタワー　43階', 'シンジュクアイランドタワー　43カイ');
INSERT INTO `ms_addresses` VALUES ('7698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿アイランドタワー　44階', '13', '13104', '1631344', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿アイランドタワー　44階', 'シンジュクアイランドタワー　44カイ');
INSERT INTO `ms_addresses` VALUES ('7709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿アイランドタワー　', '13', '13104', '1631390', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿アイランドタワー　', 'シンジュクアイランドタワー　');
INSERT INTO `ms_addresses` VALUES ('7710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿東京オペラシティ　1階', '13', '13104', '1631401', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '東京オペラシティ　1階', 'トウキョウオペラシティ　01カイ');
INSERT INTO `ms_addresses` VALUES ('7711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿東京オペラシティ　2階', '13', '13104', '1631402', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '東京オペラシティ　2階', 'トウキョウオペラシティ　02カイ');
INSERT INTO `ms_addresses` VALUES ('7712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿東京オペラシティ　3階', '13', '13104', '1631403', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '東京オペラシティ　3階', 'トウキョウオペラシティ　03カイ');
INSERT INTO `ms_addresses` VALUES ('7713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿東京オペラシティ　4階', '13', '13104', '1631404', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '東京オペラシティ　4階', 'トウキョウオペラシティ　04カイ');
INSERT INTO `ms_addresses` VALUES ('7714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿東京オペラシティ　5階', '13', '13104', '1631405', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '東京オペラシティ　5階', 'トウキョウオペラシティ　05カイ');
INSERT INTO `ms_addresses` VALUES ('7715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿東京オペラシティ　6階', '13', '13104', '1631406', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '東京オペラシティ　6階', 'トウキョウオペラシティ　06カイ');
INSERT INTO `ms_addresses` VALUES ('7716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿東京オペラシティ　7階', '13', '13104', '1631407', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '東京オペラシティ　7階', 'トウキョウオペラシティ　07カイ');
INSERT INTO `ms_addresses` VALUES ('7717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿東京オペラシティ　8階', '13', '13104', '1631408', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '東京オペラシティ　8階', 'トウキョウオペラシティ　08カイ');
INSERT INTO `ms_addresses` VALUES ('7718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿東京オペラシティ　9階', '13', '13104', '1631409', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '東京オペラシティ　9階', 'トウキョウオペラシティ　09カイ');
INSERT INTO `ms_addresses` VALUES ('7719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿東京オペラシティ　10階', '13', '13104', '1631410', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '東京オペラシティ　10階', 'トウキョウオペラシティ　10カイ');
INSERT INTO `ms_addresses` VALUES ('7720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿東京オペラシティ　11階', '13', '13104', '1631411', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '東京オペラシティ　11階', 'トウキョウオペラシティ　11カイ');
INSERT INTO `ms_addresses` VALUES ('7721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿東京オペラシティ　12階', '13', '13104', '1631412', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '東京オペラシティ　12階', 'トウキョウオペラシティ　12カイ');
INSERT INTO `ms_addresses` VALUES ('7722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿東京オペラシティ　13階', '13', '13104', '1631413', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '東京オペラシティ　13階', 'トウキョウオペラシティ　13カイ');
INSERT INTO `ms_addresses` VALUES ('7723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿東京オペラシティ　14階', '13', '13104', '1631414', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '東京オペラシティ　14階', 'トウキョウオペラシティ　14カイ');
INSERT INTO `ms_addresses` VALUES ('7724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿東京オペラシティ　15階', '13', '13104', '1631415', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '東京オペラシティ　15階', 'トウキョウオペラシティ　15カイ');
INSERT INTO `ms_addresses` VALUES ('7725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿東京オペラシティ　16階', '13', '13104', '1631416', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '東京オペラシティ　16階', 'トウキョウオペラシティ　16カイ');
INSERT INTO `ms_addresses` VALUES ('7726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿東京オペラシティ　17階', '13', '13104', '1631417', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '東京オペラシティ　17階', 'トウキョウオペラシティ　17カイ');
INSERT INTO `ms_addresses` VALUES ('7727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿東京オペラシティ　18階', '13', '13104', '1631418', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '東京オペラシティ　18階', 'トウキョウオペラシティ　18カイ');
INSERT INTO `ms_addresses` VALUES ('7728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿東京オペラシティ　19階', '13', '13104', '1631419', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '東京オペラシティ　19階', 'トウキョウオペラシティ　19カイ');
INSERT INTO `ms_addresses` VALUES ('7729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿東京オペラシティ　20階', '13', '13104', '1631420', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '東京オペラシティ　20階', 'トウキョウオペラシティ　20カイ');
INSERT INTO `ms_addresses` VALUES ('7730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿東京オペラシティ　21階', '13', '13104', '1631421', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '東京オペラシティ　21階', 'トウキョウオペラシティ　21カイ');
INSERT INTO `ms_addresses` VALUES ('7731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿東京オペラシティ　22階', '13', '13104', '1631422', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '東京オペラシティ　22階', 'トウキョウオペラシティ　22カイ');
INSERT INTO `ms_addresses` VALUES ('7732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿東京オペラシティ　23階', '13', '13104', '1631423', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '東京オペラシティ　23階', 'トウキョウオペラシティ　23カイ');
INSERT INTO `ms_addresses` VALUES ('7733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿東京オペラシティ　24階', '13', '13104', '1631424', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '東京オペラシティ　24階', 'トウキョウオペラシティ　24カイ');
INSERT INTO `ms_addresses` VALUES ('7734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿東京オペラシティ　25階', '13', '13104', '1631425', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '東京オペラシティ　25階', 'トウキョウオペラシティ　25カイ');
INSERT INTO `ms_addresses` VALUES ('7735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿東京オペラシティ　26階', '13', '13104', '1631426', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '東京オペラシティ　26階', 'トウキョウオペラシティ　26カイ');
INSERT INTO `ms_addresses` VALUES ('7736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿東京オペラシティ　27階', '13', '13104', '1631427', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '東京オペラシティ　27階', 'トウキョウオペラシティ　27カイ');
INSERT INTO `ms_addresses` VALUES ('7737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿東京オペラシティ　28階', '13', '13104', '1631428', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '東京オペラシティ　28階', 'トウキョウオペラシティ　28カイ');
INSERT INTO `ms_addresses` VALUES ('7738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿東京オペラシティ　29階', '13', '13104', '1631429', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '東京オペラシティ　29階', 'トウキョウオペラシティ　29カイ');
INSERT INTO `ms_addresses` VALUES ('7739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿東京オペラシティ　30階', '13', '13104', '1631430', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '東京オペラシティ　30階', 'トウキョウオペラシティ　30カイ');
INSERT INTO `ms_addresses` VALUES ('7740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿東京オペラシティ　31階', '13', '13104', '1631431', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '東京オペラシティ　31階', 'トウキョウオペラシティ　31カイ');
INSERT INTO `ms_addresses` VALUES ('7741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿東京オペラシティ　32階', '13', '13104', '1631432', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '東京オペラシティ　32階', 'トウキョウオペラシティ　32カイ');
INSERT INTO `ms_addresses` VALUES ('7742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿東京オペラシティ　33階', '13', '13104', '1631433', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '東京オペラシティ　33階', 'トウキョウオペラシティ　33カイ');
INSERT INTO `ms_addresses` VALUES ('7743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿東京オペラシティ　34階', '13', '13104', '1631434', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '東京オペラシティ　34階', 'トウキョウオペラシティ　34カイ');
INSERT INTO `ms_addresses` VALUES ('7744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿東京オペラシティ　35階', '13', '13104', '1631435', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '東京オペラシティ　35階', 'トウキョウオペラシティ　35カイ');
INSERT INTO `ms_addresses` VALUES ('7745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿東京オペラシティ　36階', '13', '13104', '1631436', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '東京オペラシティ　36階', 'トウキョウオペラシティ　36カイ');
INSERT INTO `ms_addresses` VALUES ('7746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿東京オペラシティ　37階', '13', '13104', '1631437', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '東京オペラシティ　37階', 'トウキョウオペラシティ　37カイ');
INSERT INTO `ms_addresses` VALUES ('7747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿東京オペラシティ　38階', '13', '13104', '1631438', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '東京オペラシティ　38階', 'トウキョウオペラシティ　38カイ');
INSERT INTO `ms_addresses` VALUES ('7748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿東京オペラシティ　39階', '13', '13104', '1631439', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '東京オペラシティ　39階', 'トウキョウオペラシティ　39カイ');
INSERT INTO `ms_addresses` VALUES ('7749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿東京オペラシティ　40階', '13', '13104', '1631440', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '東京オペラシティ　40階', 'トウキョウオペラシティ　40カイ');
INSERT INTO `ms_addresses` VALUES ('7750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿東京オペラシティ　41階', '13', '13104', '1631441', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '東京オペラシティ　41階', 'トウキョウオペラシティ　41カイ');
INSERT INTO `ms_addresses` VALUES ('7751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿東京オペラシティ　42階', '13', '13104', '1631442', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '東京オペラシティ　42階', 'トウキョウオペラシティ　42カイ');
INSERT INTO `ms_addresses` VALUES ('7752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿東京オペラシティ　43階', '13', '13104', '1631443', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '東京オペラシティ　43階', 'トウキョウオペラシティ　43カイ');
INSERT INTO `ms_addresses` VALUES ('7753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿東京オペラシティ　44階', '13', '13104', '1631444', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '東京オペラシティ　44階', 'トウキョウオペラシティ　44カイ');
INSERT INTO `ms_addresses` VALUES ('7754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿東京オペラシティ　45階', '13', '13104', '1631445', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '東京オペラシティ　45階', 'トウキョウオペラシティ　45カイ');
INSERT INTO `ms_addresses` VALUES ('7755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿東京オペラシティ　46階', '13', '13104', '1631446', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '東京オペラシティ　46階', 'トウキョウオペラシティ　46カイ');
INSERT INTO `ms_addresses` VALUES ('7756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿東京オペラシティ　47階', '13', '13104', '1631447', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '東京オペラシティ　47階', 'トウキョウオペラシティ　47カイ');
INSERT INTO `ms_addresses` VALUES ('7757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿東京オペラシティ　48階', '13', '13104', '1631448', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '東京オペラシティ　48階', 'トウキョウオペラシティ　48カイ');
INSERT INTO `ms_addresses` VALUES ('7758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿東京オペラシティ　49階', '13', '13104', '1631449', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '東京オペラシティ　49階', 'トウキョウオペラシティ　49カイ');
INSERT INTO `ms_addresses` VALUES ('7759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿東京オペラシティ　50階', '13', '13104', '1631450', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '東京オペラシティ　50階', 'トウキョウオペラシティ　50カイ');
INSERT INTO `ms_addresses` VALUES ('7760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿東京オペラシティ　51階', '13', '13104', '1631451', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '東京オペラシティ　51階', 'トウキョウオペラシティ　51カイ');
INSERT INTO `ms_addresses` VALUES ('7761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿東京オペラシティ　52階', '13', '13104', '1631452', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '東京オペラシティ　52階', 'トウキョウオペラシティ　52カイ');
INSERT INTO `ms_addresses` VALUES ('7762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿東京オペラシティ　53階', '13', '13104', '1631453', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '東京オペラシティ　53階', 'トウキョウオペラシティ　53カイ');
INSERT INTO `ms_addresses` VALUES ('7763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿東京オペラシティ　54階', '13', '13104', '1631454', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '東京オペラシティ　54階', 'トウキョウオペラシティ　54カイ');
INSERT INTO `ms_addresses` VALUES ('7770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿東京オペラシティ　', '13', '13104', '1631490', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '東京オペラシティ　', 'トウキョウオペラシティ　');
INSERT INTO `ms_addresses` VALUES ('7771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿エルタワー　1階', '13', '13104', '1631501', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿エルタワー　1階', 'シンジュクエルタワー　01カイ');
INSERT INTO `ms_addresses` VALUES ('7772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿エルタワー　2階', '13', '13104', '1631502', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿エルタワー　2階', 'シンジュクエルタワー　02カイ');
INSERT INTO `ms_addresses` VALUES ('7773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿エルタワー　3階', '13', '13104', '1631503', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿エルタワー　3階', 'シンジュクエルタワー　03カイ');
INSERT INTO `ms_addresses` VALUES ('7774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿エルタワー　4階', '13', '13104', '1631504', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿エルタワー　4階', 'シンジュクエルタワー　04カイ');
INSERT INTO `ms_addresses` VALUES ('7775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿エルタワー　5階', '13', '13104', '1631505', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿エルタワー　5階', 'シンジュクエルタワー　05カイ');
INSERT INTO `ms_addresses` VALUES ('7776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿エルタワー　6階', '13', '13104', '1631506', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿エルタワー　6階', 'シンジュクエルタワー　06カイ');
INSERT INTO `ms_addresses` VALUES ('7777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿エルタワー　7階', '13', '13104', '1631507', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿エルタワー　7階', 'シンジュクエルタワー　07カイ');
INSERT INTO `ms_addresses` VALUES ('7778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿エルタワー　8階', '13', '13104', '1631508', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿エルタワー　8階', 'シンジュクエルタワー　08カイ');
INSERT INTO `ms_addresses` VALUES ('7779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿エルタワー　9階', '13', '13104', '1631509', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿エルタワー　9階', 'シンジュクエルタワー　09カイ');
INSERT INTO `ms_addresses` VALUES ('7780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿エルタワー　10階', '13', '13104', '1631510', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿エルタワー　10階', 'シンジュクエルタワー　10カイ');
INSERT INTO `ms_addresses` VALUES ('7781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿エルタワー　11階', '13', '13104', '1631511', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿エルタワー　11階', 'シンジュクエルタワー　11カイ');
INSERT INTO `ms_addresses` VALUES ('7782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿エルタワー　12階', '13', '13104', '1631512', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿エルタワー　12階', 'シンジュクエルタワー　12カイ');
INSERT INTO `ms_addresses` VALUES ('7783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿エルタワー　13階', '13', '13104', '1631513', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿エルタワー　13階', 'シンジュクエルタワー　13カイ');
INSERT INTO `ms_addresses` VALUES ('7784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿エルタワー　14階', '13', '13104', '1631514', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿エルタワー　14階', 'シンジュクエルタワー　14カイ');
INSERT INTO `ms_addresses` VALUES ('7785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿エルタワー　15階', '13', '13104', '1631515', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿エルタワー　15階', 'シンジュクエルタワー　15カイ');
INSERT INTO `ms_addresses` VALUES ('7786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿エルタワー　16階', '13', '13104', '1631516', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿エルタワー　16階', 'シンジュクエルタワー　16カイ');
INSERT INTO `ms_addresses` VALUES ('7787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿エルタワー　17階', '13', '13104', '1631517', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿エルタワー　17階', 'シンジュクエルタワー　17カイ');
INSERT INTO `ms_addresses` VALUES ('7788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿エルタワー　18階', '13', '13104', '1631518', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿エルタワー　18階', 'シンジュクエルタワー　18カイ');
INSERT INTO `ms_addresses` VALUES ('7789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿エルタワー　19階', '13', '13104', '1631519', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿エルタワー　19階', 'シンジュクエルタワー　19カイ');
INSERT INTO `ms_addresses` VALUES ('7790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿エルタワー　20階', '13', '13104', '1631520', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿エルタワー　20階', 'シンジュクエルタワー　20カイ');
INSERT INTO `ms_addresses` VALUES ('7791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿エルタワー　21階', '13', '13104', '1631521', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿エルタワー　21階', 'シンジュクエルタワー　21カイ');
INSERT INTO `ms_addresses` VALUES ('7792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿エルタワー　22階', '13', '13104', '1631522', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿エルタワー　22階', 'シンジュクエルタワー　22カイ');
INSERT INTO `ms_addresses` VALUES ('7793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿エルタワー　23階', '13', '13104', '1631523', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿エルタワー　23階', 'シンジュクエルタワー　23カイ');
INSERT INTO `ms_addresses` VALUES ('7794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿エルタワー　24階', '13', '13104', '1631524', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿エルタワー　24階', 'シンジュクエルタワー　24カイ');
INSERT INTO `ms_addresses` VALUES ('7795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿エルタワー　25階', '13', '13104', '1631525', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿エルタワー　25階', 'シンジュクエルタワー　25カイ');
INSERT INTO `ms_addresses` VALUES ('7796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿エルタワー　26階', '13', '13104', '1631526', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿エルタワー　26階', 'シンジュクエルタワー　26カイ');
INSERT INTO `ms_addresses` VALUES ('7797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿エルタワー　27階', '13', '13104', '1631527', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿エルタワー　27階', 'シンジュクエルタワー　27カイ');
INSERT INTO `ms_addresses` VALUES ('7798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿エルタワー　28階', '13', '13104', '1631528', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿エルタワー　28階', 'シンジュクエルタワー　28カイ');
INSERT INTO `ms_addresses` VALUES ('7799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿エルタワー　29階', '13', '13104', '1631529', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿エルタワー　29階', 'シンジュクエルタワー　29カイ');
INSERT INTO `ms_addresses` VALUES ('7800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿エルタワー　30階', '13', '13104', '1631530', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿エルタワー　30階', 'シンジュクエルタワー　30カイ');
INSERT INTO `ms_addresses` VALUES ('7801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿エルタワー　31階', '13', '13104', '1631531', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿エルタワー　31階', 'シンジュクエルタワー　31カイ');
INSERT INTO `ms_addresses` VALUES ('7806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿新宿エルタワー　', '13', '13104', '1631590', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '新宿エルタワー　', 'シンジュクエルタワー　');
INSERT INTO `ms_addresses` VALUES ('7807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿住友不動産新宿オークタワー　1階', '13', '13104', '1636001', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '住友不動産新宿オークタワー　1階', 'スミトモフドウサンシンジュクオークタワー　01カイ');
INSERT INTO `ms_addresses` VALUES ('7808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿住友不動産新宿オークタワー　2階', '13', '13104', '1636002', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '住友不動産新宿オークタワー　2階', 'スミトモフドウサンシンジュクオークタワー　02カイ');
INSERT INTO `ms_addresses` VALUES ('7809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿住友不動産新宿オークタワー　3階', '13', '13104', '1636003', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '住友不動産新宿オークタワー　3階', 'スミトモフドウサンシンジュクオークタワー　03カイ');
INSERT INTO `ms_addresses` VALUES ('7810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿住友不動産新宿オークタワー　4階', '13', '13104', '1636004', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '住友不動産新宿オークタワー　4階', 'スミトモフドウサンシンジュクオークタワー　04カイ');
INSERT INTO `ms_addresses` VALUES ('7811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿住友不動産新宿オークタワー　5階', '13', '13104', '1636005', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '住友不動産新宿オークタワー　5階', 'スミトモフドウサンシンジュクオークタワー　05カイ');
INSERT INTO `ms_addresses` VALUES ('7812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿住友不動産新宿オークタワー　6階', '13', '13104', '1636006', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '住友不動産新宿オークタワー　6階', 'スミトモフドウサンシンジュクオークタワー　06カイ');
INSERT INTO `ms_addresses` VALUES ('7813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿住友不動産新宿オークタワー　7階', '13', '13104', '1636007', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '住友不動産新宿オークタワー　7階', 'スミトモフドウサンシンジュクオークタワー　07カイ');
INSERT INTO `ms_addresses` VALUES ('7814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿住友不動産新宿オークタワー　8階', '13', '13104', '1636008', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '住友不動産新宿オークタワー　8階', 'スミトモフドウサンシンジュクオークタワー　08カイ');
INSERT INTO `ms_addresses` VALUES ('7815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿住友不動産新宿オークタワー　9階', '13', '13104', '1636009', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '住友不動産新宿オークタワー　9階', 'スミトモフドウサンシンジュクオークタワー　09カイ');
INSERT INTO `ms_addresses` VALUES ('7816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿住友不動産新宿オークタワー　10階', '13', '13104', '1636010', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '住友不動産新宿オークタワー　10階', 'スミトモフドウサンシンジュクオークタワー　10カイ');
INSERT INTO `ms_addresses` VALUES ('7817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿住友不動産新宿オークタワー　11階', '13', '13104', '1636011', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '住友不動産新宿オークタワー　11階', 'スミトモフドウサンシンジュクオークタワー　11カイ');
INSERT INTO `ms_addresses` VALUES ('7818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿住友不動産新宿オークタワー　12階', '13', '13104', '1636012', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '住友不動産新宿オークタワー　12階', 'スミトモフドウサンシンジュクオークタワー　12カイ');
INSERT INTO `ms_addresses` VALUES ('7819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿住友不動産新宿オークタワー　13階', '13', '13104', '1636013', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '住友不動産新宿オークタワー　13階', 'スミトモフドウサンシンジュクオークタワー　13カイ');
INSERT INTO `ms_addresses` VALUES ('7820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿住友不動産新宿オークタワー　14階', '13', '13104', '1636014', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '住友不動産新宿オークタワー　14階', 'スミトモフドウサンシンジュクオークタワー　14カイ');
INSERT INTO `ms_addresses` VALUES ('7821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿住友不動産新宿オークタワー　15階', '13', '13104', '1636015', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '住友不動産新宿オークタワー　15階', 'スミトモフドウサンシンジュクオークタワー　15カイ');
INSERT INTO `ms_addresses` VALUES ('7822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿住友不動産新宿オークタワー　16階', '13', '13104', '1636016', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '住友不動産新宿オークタワー　16階', 'スミトモフドウサンシンジュクオークタワー　16カイ');
INSERT INTO `ms_addresses` VALUES ('7823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿住友不動産新宿オークタワー　17階', '13', '13104', '1636017', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '住友不動産新宿オークタワー　17階', 'スミトモフドウサンシンジュクオークタワー　17カイ');
INSERT INTO `ms_addresses` VALUES ('7824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿住友不動産新宿オークタワー　18階', '13', '13104', '1636018', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '住友不動産新宿オークタワー　18階', 'スミトモフドウサンシンジュクオークタワー　18カイ');
INSERT INTO `ms_addresses` VALUES ('7825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿住友不動産新宿オークタワー　19階', '13', '13104', '1636019', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '住友不動産新宿オークタワー　19階', 'スミトモフドウサンシンジュクオークタワー　19カイ');
INSERT INTO `ms_addresses` VALUES ('7826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿住友不動産新宿オークタワー　20階', '13', '13104', '1636020', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '住友不動産新宿オークタワー　20階', 'スミトモフドウサンシンジュクオークタワー　20カイ');
INSERT INTO `ms_addresses` VALUES ('7827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿住友不動産新宿オークタワー　21階', '13', '13104', '1636021', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '住友不動産新宿オークタワー　21階', 'スミトモフドウサンシンジュクオークタワー　21カイ');
INSERT INTO `ms_addresses` VALUES ('7828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿住友不動産新宿オークタワー　22階', '13', '13104', '1636022', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '住友不動産新宿オークタワー　22階', 'スミトモフドウサンシンジュクオークタワー　22カイ');
INSERT INTO `ms_addresses` VALUES ('7829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿住友不動産新宿オークタワー　23階', '13', '13104', '1636023', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '住友不動産新宿オークタワー　23階', 'スミトモフドウサンシンジュクオークタワー　23カイ');
INSERT INTO `ms_addresses` VALUES ('7830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿住友不動産新宿オークタワー　24階', '13', '13104', '1636024', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '住友不動産新宿オークタワー　24階', 'スミトモフドウサンシンジュクオークタワー　24カイ');
INSERT INTO `ms_addresses` VALUES ('7831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿住友不動産新宿オークタワー　25階', '13', '13104', '1636025', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '住友不動産新宿オークタワー　25階', 'スミトモフドウサンシンジュクオークタワー　25カイ');
INSERT INTO `ms_addresses` VALUES ('7832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿住友不動産新宿オークタワー　26階', '13', '13104', '1636026', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '住友不動産新宿オークタワー　26階', 'スミトモフドウサンシンジュクオークタワー　26カイ');
INSERT INTO `ms_addresses` VALUES ('7833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿住友不動産新宿オークタワー　27階', '13', '13104', '1636027', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '住友不動産新宿オークタワー　27階', 'スミトモフドウサンシンジュクオークタワー　27カイ');
INSERT INTO `ms_addresses` VALUES ('7834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿住友不動産新宿オークタワー　28階', '13', '13104', '1636028', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '住友不動産新宿オークタワー　28階', 'スミトモフドウサンシンジュクオークタワー　28カイ');
INSERT INTO `ms_addresses` VALUES ('7835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿住友不動産新宿オークタワー　29階', '13', '13104', '1636029', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '住友不動産新宿オークタワー　29階', 'スミトモフドウサンシンジュクオークタワー　29カイ');
INSERT INTO `ms_addresses` VALUES ('7836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿住友不動産新宿オークタワー　30階', '13', '13104', '1636030', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '住友不動産新宿オークタワー　30階', 'スミトモフドウサンシンジュクオークタワー　30カイ');
INSERT INTO `ms_addresses` VALUES ('7837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿住友不動産新宿オークタワー　31階', '13', '13104', '1636031', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '住友不動産新宿オークタワー　31階', 'スミトモフドウサンシンジュクオークタワー　31カイ');
INSERT INTO `ms_addresses` VALUES ('7838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿住友不動産新宿オークタワー　32階', '13', '13104', '1636032', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '住友不動産新宿オークタワー　32階', 'スミトモフドウサンシンジュクオークタワー　32カイ');
INSERT INTO `ms_addresses` VALUES ('7839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿住友不動産新宿オークタワー　33階', '13', '13104', '1636033', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '住友不動産新宿オークタワー　33階', 'スミトモフドウサンシンジュクオークタワー　33カイ');
INSERT INTO `ms_addresses` VALUES ('7840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿住友不動産新宿オークタワー　34階', '13', '13104', '1636034', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '住友不動産新宿オークタワー　34階', 'スミトモフドウサンシンジュクオークタワー　34カイ');
INSERT INTO `ms_addresses` VALUES ('7841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿住友不動産新宿オークタワー　35階', '13', '13104', '1636035', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '住友不動産新宿オークタワー　35階', 'スミトモフドウサンシンジュクオークタワー　35カイ');
INSERT INTO `ms_addresses` VALUES ('7842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿住友不動産新宿オークタワー　36階', '13', '13104', '1636036', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '住友不動産新宿オークタワー　36階', 'スミトモフドウサンシンジュクオークタワー　36カイ');
INSERT INTO `ms_addresses` VALUES ('7843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿住友不動産新宿オークタワー　37階', '13', '13104', '1636037', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '住友不動産新宿オークタワー　37階', 'スミトモフドウサンシンジュクオークタワー　37カイ');
INSERT INTO `ms_addresses` VALUES ('7844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿住友不動産新宿オークタワー　38階', '13', '13104', '1636038', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '住友不動産新宿オークタワー　38階', 'スミトモフドウサンシンジュクオークタワー　38カイ');
INSERT INTO `ms_addresses` VALUES ('7845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西新宿住友不動産新宿オークタワー　', '13', '13104', '1636090', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西新宿', 'ニシシンジュク', null, null, '住友不動産新宿オークタワー　', 'スミトモフドウサンシンジュクオークタワー　');
INSERT INTO `ms_addresses` VALUES ('7868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中野区', '13', '13114', '1640000', '東京都', 'トウキョウト', '中野区', 'ナカノク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('7869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中野区中野', '13', '13114', '1640001', '東京都', 'トウキョウト', '中野区', 'ナカノク', '中野', 'ナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中野区上高田', '13', '13114', '1640002', '東京都', 'トウキョウト', '中野区', 'ナカノク', '上高田', 'カミタカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中野区東中野', '13', '13114', '1640003', '東京都', 'トウキョウト', '中野区', 'ナカノク', '東中野', 'ヒガシナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中野区中央', '13', '13114', '1640011', '東京都', 'トウキョウト', '中野区', 'ナカノク', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中野区本町', '13', '13114', '1640012', '東京都', 'トウキョウト', '中野区', 'ナカノク', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中野区弥生町', '13', '13114', '1640013', '東京都', 'トウキョウト', '中野区', 'ナカノク', '弥生町', 'ヤヨイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中野区南台', '13', '13114', '1640014', '東京都', 'トウキョウト', '中野区', 'ナカノク', '南台', 'ミナミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中野区丸山', '13', '13114', '1650021', '東京都', 'トウキョウト', '中野区', 'ナカノク', '丸山', 'マルヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中野区江古田', '13', '13114', '1650022', '東京都', 'トウキョウト', '中野区', 'ナカノク', '江古田', 'エゴタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中野区江原町', '13', '13114', '1650023', '東京都', 'トウキョウト', '中野区', 'ナカノク', '江原町', 'エハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中野区松が丘', '13', '13114', '1650024', '東京都', 'トウキョウト', '中野区', 'ナカノク', '松が丘', 'マツガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中野区沼袋', '13', '13114', '1650025', '東京都', 'トウキョウト', '中野区', 'ナカノク', '沼袋', 'ヌマブクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中野区新井', '13', '13114', '1650026', '東京都', 'トウキョウト', '中野区', 'ナカノク', '新井', 'アライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中野区野方', '13', '13114', '1650027', '東京都', 'トウキョウト', '中野区', 'ナカノク', '野方', 'ノガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中野区上鷺宮', '13', '13114', '1650031', '東京都', 'トウキョウト', '中野区', 'ナカノク', '上鷺宮', 'カミサギノミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中野区鷺宮', '13', '13114', '1650032', '東京都', 'トウキョウト', '中野区', 'ナカノク', '鷺宮', 'サギノミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中野区若宮', '13', '13114', '1650033', '東京都', 'トウキョウト', '中野区', 'ナカノク', '若宮', 'ワカミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中野区大和町', '13', '13114', '1650034', '東京都', 'トウキョウト', '中野区', 'ナカノク', '大和町', 'ヤマトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都中野区白鷺', '13', '13114', '1650035', '東京都', 'トウキョウト', '中野区', 'ナカノク', '白鷺', 'シラサギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都杉並区', '13', '13115', '1660000', '東京都', 'トウキョウト', '杉並区', 'スギナミク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('7918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都杉並区阿佐谷北', '13', '13115', '1660001', '東京都', 'トウキョウト', '杉並区', 'スギナミク', '阿佐谷北', 'アサガヤキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都杉並区高円寺北', '13', '13115', '1660002', '東京都', 'トウキョウト', '杉並区', 'スギナミク', '高円寺北', 'コウエンジキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都杉並区高円寺南', '13', '13115', '1660003', '東京都', 'トウキョウト', '杉並区', 'スギナミク', '高円寺南', 'コウエンジミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都杉並区阿佐谷南', '13', '13115', '1660004', '東京都', 'トウキョウト', '杉並区', 'スギナミク', '阿佐谷南', 'アサガヤミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都杉並区梅里', '13', '13115', '1660011', '東京都', 'トウキョウト', '杉並区', 'スギナミク', '梅里', 'ウメザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都杉並区和田', '13', '13115', '1660012', '東京都', 'トウキョウト', '杉並区', 'スギナミク', '和田', 'ワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都杉並区堀ノ内', '13', '13115', '1660013', '東京都', 'トウキョウト', '杉並区', 'スギナミク', '堀ノ内', 'ホリノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都杉並区松ノ木', '13', '13115', '1660014', '東京都', 'トウキョウト', '杉並区', 'スギナミク', '松ノ木', 'マツノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都杉並区成田東', '13', '13115', '1660015', '東京都', 'トウキョウト', '杉並区', 'スギナミク', '成田東', 'ナリタヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都杉並区成田西', '13', '13115', '1660016', '東京都', 'トウキョウト', '杉並区', 'スギナミク', '成田西', 'ナリタニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都杉並区井草', '13', '13115', '1670021', '東京都', 'トウキョウト', '杉並区', 'スギナミク', '井草', 'イグサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都杉並区下井草', '13', '13115', '1670022', '東京都', 'トウキョウト', '杉並区', 'スギナミク', '下井草', 'シモイグサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都杉並区上井草', '13', '13115', '1670023', '東京都', 'トウキョウト', '杉並区', 'スギナミク', '上井草', 'カミイグサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都杉並区本天沼', '13', '13115', '1670031', '東京都', 'トウキョウト', '杉並区', 'スギナミク', '本天沼', 'ホンアマヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都杉並区天沼', '13', '13115', '1670032', '東京都', 'トウキョウト', '杉並区', 'スギナミク', '天沼', 'アマヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都杉並区清水', '13', '13115', '1670033', '東京都', 'トウキョウト', '杉並区', 'スギナミク', '清水', 'シミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都杉並区桃井', '13', '13115', '1670034', '東京都', 'トウキョウト', '杉並区', 'スギナミク', '桃井', 'モモイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都杉並区今川', '13', '13115', '1670035', '東京都', 'トウキョウト', '杉並区', 'スギナミク', '今川', 'イマガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都杉並区善福寺', '13', '13115', '1670041', '東京都', 'トウキョウト', '杉並区', 'スギナミク', '善福寺', 'ゼンプクジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都杉並区西荻北', '13', '13115', '1670042', '東京都', 'トウキョウト', '杉並区', 'スギナミク', '西荻北', 'ニシオギキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都杉並区上荻', '13', '13115', '1670043', '東京都', 'トウキョウト', '杉並区', 'スギナミク', '上荻', 'カミオギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都杉並区荻窪', '13', '13115', '1670051', '東京都', 'トウキョウト', '杉並区', 'スギナミク', '荻窪', 'オギクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都杉並区南荻窪', '13', '13115', '1670052', '東京都', 'トウキョウト', '杉並区', 'スギナミク', '南荻窪', 'ミナミオギクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都杉並区西荻南', '13', '13115', '1670053', '東京都', 'トウキョウト', '杉並区', 'スギナミク', '西荻南', 'ニシオギミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都杉並区松庵', '13', '13115', '1670054', '東京都', 'トウキョウト', '杉並区', 'スギナミク', '松庵', 'ショウアン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都杉並区大宮', '13', '13115', '1680061', '東京都', 'トウキョウト', '杉並区', 'スギナミク', '大宮', 'オオミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都杉並区方南', '13', '13115', '1680062', '東京都', 'トウキョウト', '杉並区', 'スギナミク', '方南', 'ホウナン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都杉並区和泉', '13', '13115', '1680063', '東京都', 'トウキョウト', '杉並区', 'スギナミク', '和泉', 'イズミ', null, null, null, null), ('7993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都杉並区永福', '13', '13115', '1680064', '東京都', 'トウキョウト', '杉並区', 'スギナミク', '永福', 'エイフク', null, null, null, null), ('7994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都杉並区浜田山', '13', '13115', '1680065', '東京都', 'トウキョウト', '杉並区', 'スギナミク', '浜田山', 'ハマダヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都杉並区高井戸西', '13', '13115', '1680071', '東京都', 'トウキョウト', '杉並区', 'スギナミク', '高井戸西', 'タカイドニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都杉並区高井戸東', '13', '13115', '1680072', '東京都', 'トウキョウト', '杉並区', 'スギナミク', '高井戸東', 'タカイドヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都杉並区下高井戸', '13', '13115', '1680073', '東京都', 'トウキョウト', '杉並区', 'スギナミク', '下高井戸', 'シモタカイド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都杉並区上高井戸', '13', '13115', '1680074', '東京都', 'トウキョウト', '杉並区', 'スギナミク', '上高井戸', 'カミタカイド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('7999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都杉並区宮前', '13', '13115', '1680081', '東京都', 'トウキョウト', '杉並区', 'スギナミク', '宮前', 'ミヤマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都杉並区久我山', '13', '13115', '1680082', '東京都', 'トウキョウト', '杉並区', 'スギナミク', '久我山', 'クガヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区西早稲田', '13', '13104', '1690051', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '西早稲田', 'ニシワセダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区戸山3丁目', '13', '13104', '1690052', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '戸山', 'トヤマ', null, null, '3丁目', '03チョウメ');
INSERT INTO `ms_addresses` VALUES ('8033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区戸塚町', '13', '13104', '1690071', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '戸塚町', 'トツカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区大久保', '13', '13104', '1690072', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '大久保', 'オオクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区百人町', '13', '13104', '1690073', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '百人町', 'ヒャクニンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区北新宿', '13', '13104', '1690074', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '北新宿', 'キタシンジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都新宿区高田馬場', '13', '13104', '1690075', '東京都', 'トウキョウト', '新宿区', 'シンジュクク', '高田馬場', 'タカダノババ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市', '05', '05204', '0170000', '秋田県', 'アキタケン', '大館市', 'オオダテシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('8107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都豊島区', '13', '13116', '1700000', '東京都', 'トウキョウト', '豊島区', 'トシマク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('8108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都豊島区西巣鴨', '13', '13116', '1700001', '東京都', 'トウキョウト', '豊島区', 'トシマク', '西巣鴨', 'ニシスガモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都豊島区巣鴨', '13', '13116', '1700002', '東京都', 'トウキョウト', '豊島区', 'トシマク', '巣鴨', 'スガモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都豊島区駒込', '13', '13116', '1700003', '東京都', 'トウキョウト', '豊島区', 'トシマク', '駒込', 'コマゴメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都豊島区北大塚', '13', '13116', '1700004', '東京都', 'トウキョウト', '豊島区', 'トシマク', '北大塚', 'キタオオツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都豊島区南大塚', '13', '13116', '1700005', '東京都', 'トウキョウト', '豊島区', 'トシマク', '南大塚', 'ミナミオオツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市長走', '05', '05204', '0170001', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '長走', 'ナガバシリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都豊島区池袋本町', '13', '13116', '1700011', '東京都', 'トウキョウト', '豊島区', 'トシマク', '池袋本町', 'イケブクロホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都豊島区上池袋', '13', '13116', '1700012', '東京都', 'トウキョウト', '豊島区', 'トシマク', '上池袋', 'カミイケブクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都豊島区東池袋', '13', '13116', '1700013', '東京都', 'トウキョウト', '豊島区', 'トシマク', '東池袋', 'ヒガシイケブクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都豊島区池袋1丁目', '13', '13116', '1700014', '東京都', 'トウキョウト', '豊島区', 'トシマク', '池袋', 'イケブクロ', null, null, '1丁目', '01チョウメ');
INSERT INTO `ms_addresses` VALUES ('8118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市白沢', '05', '05204', '0170002', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '白沢', 'シラサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市橋桁', '05', '05204', '0170003', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '橋桁', 'ハシゲタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市粕田', '05', '05204', '0170004', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '粕田', 'カスダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市花岡町', '05', '05204', '0170005', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '花岡町', 'ハナオカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市商人留', '05', '05204', '0170011', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '商人留', 'アキヒトドメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市釈迦内', '05', '05204', '0170012', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '釈迦内', 'シャカナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市小釈迦内道上', '05', '05204', '0170014', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '小釈迦内道上', 'コシャカナイミチウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市小釈迦内道下', '05', '05204', '0170015', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '小釈迦内道下', 'コシャカナイミチシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市雪沢', '05', '05204', '0170021', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '雪沢', 'ユキサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市茂内', '05', '05204', '0170022', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '茂内', 'シゲナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市東', '05', '05204', '0170023', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '東', 'アズマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市大茂内', '05', '05204', '0170024', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '大茂内', 'オオシゲナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市芦田子', '05', '05204', '0170025', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '芦田子', 'アシダコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市二ツ屋境', '05', '05204', '0170026', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '二ツ屋境', 'フタツヤサカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市上代野', '05', '05204', '0170031', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '上代野', 'カミダイノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市新綱', '05', '05204', '0170032', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '新綱', 'ニイヅナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市下綱', '05', '05204', '0170033', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '下綱', 'シモツナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市下代野', '05', '05204', '0170034', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '下代野', 'シモダイノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市代野', '05', '05204', '0170035', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '代野', 'ダイノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市二本杉後', '05', '05204', '0170036', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '二本杉後', 'ニホンスギウシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市清水堰合', '05', '05204', '0170037', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '清水堰合', 'シミズセキアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市大田面', '05', '05204', '0170041', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '大田面', 'オオタオモテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市観音堂', '05', '05204', '0170042', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '観音堂', 'カンノンドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市有浦', '05', '05204', '0170043', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '有浦', 'アリウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市御成町', '05', '05204', '0170044', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '御成町', 'オナリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市中道', '05', '05204', '0170045', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '中道', 'ナカミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市清水', '05', '05204', '0170046', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '清水', 'シミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市松峰', '05', '05204', '0170051', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '松峰', 'マツミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市松木', '05', '05204', '0170052', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '松木', 'マツキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市板子石境', '05', '05204', '0170053', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '板子石境', 'イタコイシザカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市松館', '05', '05204', '0170054', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '松館', 'マツダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市沼館道上', '05', '05204', '0170055', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '沼館道上', 'ヌマタテミチウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市沼館道南', '05', '05204', '0170056', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '沼館道南', 'ヌマタテミチミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市沼館', '05', '05204', '0170057', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '沼館', 'ヌマダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県鹿角郡小坂町', '05', '05303', '0170200', '秋田県', 'アキタケン', '鹿角郡小坂町', 'カヅノグンコサカマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('8153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県鹿角郡小坂町小坂', '05', '05303', '0170201', '秋田県', 'アキタケン', '鹿角郡小坂町', 'カヅノグンコサカマチ', '小坂', 'コサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県鹿角郡小坂町小坂鉱山', '05', '05303', '0170202', '秋田県', 'アキタケン', '鹿角郡小坂町', 'カヅノグンコサカマチ', '小坂鉱山', 'コサカコウザン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県鹿角郡小坂町上向', '05', '05303', '0170203', '秋田県', 'アキタケン', '鹿角郡小坂町', 'カヅノグンコサカマチ', '上向', 'ウワムキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県鹿角郡小坂町荒谷', '05', '05303', '0170204', '秋田県', 'アキタケン', '鹿角郡小坂町', 'カヅノグンコサカマチ', '荒谷', 'アラヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県鹿角郡小坂町大地', '05', '05303', '0170205', '秋田県', 'アキタケン', '鹿角郡小坂町', 'カヅノグンコサカマチ', '大地', 'ダイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都豊島区東池袋サンシャイン60　1階', '13', '13116', '1706001', '東京都', 'トウキョウト', '豊島区', 'トシマク', '東池袋', 'ヒガシイケブクロ', null, null, 'サンシャイン60　1階', 'サンシャイン60　01カイ');
INSERT INTO `ms_addresses` VALUES ('8161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都豊島区東池袋サンシャイン60　2階', '13', '13116', '1706002', '東京都', 'トウキョウト', '豊島区', 'トシマク', '東池袋', 'ヒガシイケブクロ', null, null, 'サンシャイン60　2階', 'サンシャイン60　02カイ');
INSERT INTO `ms_addresses` VALUES ('8162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都豊島区東池袋サンシャイン60　3階', '13', '13116', '1706003', '東京都', 'トウキョウト', '豊島区', 'トシマク', '東池袋', 'ヒガシイケブクロ', null, null, 'サンシャイン60　3階', 'サンシャイン60　03カイ');
INSERT INTO `ms_addresses` VALUES ('8163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都豊島区東池袋サンシャイン60　4階', '13', '13116', '1706004', '東京都', 'トウキョウト', '豊島区', 'トシマク', '東池袋', 'ヒガシイケブクロ', null, null, 'サンシャイン60　4階', 'サンシャイン60　04カイ');
INSERT INTO `ms_addresses` VALUES ('8164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都豊島区東池袋サンシャイン60　5階', '13', '13116', '1706005', '東京都', 'トウキョウト', '豊島区', 'トシマク', '東池袋', 'ヒガシイケブクロ', null, null, 'サンシャイン60　5階', 'サンシャイン60　05カイ');
INSERT INTO `ms_addresses` VALUES ('8165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都豊島区東池袋サンシャイン60　6階', '13', '13116', '1706006', '東京都', 'トウキョウト', '豊島区', 'トシマク', '東池袋', 'ヒガシイケブクロ', null, null, 'サンシャイン60　6階', 'サンシャイン60　06カイ');
INSERT INTO `ms_addresses` VALUES ('8166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都豊島区東池袋サンシャイン60　7階', '13', '13116', '1706007', '東京都', 'トウキョウト', '豊島区', 'トシマク', '東池袋', 'ヒガシイケブクロ', null, null, 'サンシャイン60　7階', 'サンシャイン60　07カイ');
INSERT INTO `ms_addresses` VALUES ('8167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都豊島区東池袋サンシャイン60　8階', '13', '13116', '1706008', '東京都', 'トウキョウト', '豊島区', 'トシマク', '東池袋', 'ヒガシイケブクロ', null, null, 'サンシャイン60　8階', 'サンシャイン60　08カイ');
INSERT INTO `ms_addresses` VALUES ('8168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都豊島区東池袋サンシャイン60　9階', '13', '13116', '1706009', '東京都', 'トウキョウト', '豊島区', 'トシマク', '東池袋', 'ヒガシイケブクロ', null, null, 'サンシャイン60　9階', 'サンシャイン60　09カイ');
INSERT INTO `ms_addresses` VALUES ('8169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都豊島区東池袋サンシャイン60　10階', '13', '13116', '1706010', '東京都', 'トウキョウト', '豊島区', 'トシマク', '東池袋', 'ヒガシイケブクロ', null, null, 'サンシャイン60　10階', 'サンシャイン60　10カイ');
INSERT INTO `ms_addresses` VALUES ('8170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都豊島区東池袋サンシャイン60　11階', '13', '13116', '1706011', '東京都', 'トウキョウト', '豊島区', 'トシマク', '東池袋', 'ヒガシイケブクロ', null, null, 'サンシャイン60　11階', 'サンシャイン60　11カイ');
INSERT INTO `ms_addresses` VALUES ('8171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都豊島区東池袋サンシャイン60　12階', '13', '13116', '1706012', '東京都', 'トウキョウト', '豊島区', 'トシマク', '東池袋', 'ヒガシイケブクロ', null, null, 'サンシャイン60　12階', 'サンシャイン60　12カイ');
INSERT INTO `ms_addresses` VALUES ('8172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都豊島区東池袋サンシャイン60　13階', '13', '13116', '1706013', '東京都', 'トウキョウト', '豊島区', 'トシマク', '東池袋', 'ヒガシイケブクロ', null, null, 'サンシャイン60　13階', 'サンシャイン60　13カイ');
INSERT INTO `ms_addresses` VALUES ('8173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都豊島区東池袋サンシャイン60　14階', '13', '13116', '1706014', '東京都', 'トウキョウト', '豊島区', 'トシマク', '東池袋', 'ヒガシイケブクロ', null, null, 'サンシャイン60　14階', 'サンシャイン60　14カイ');
INSERT INTO `ms_addresses` VALUES ('8174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都豊島区東池袋サンシャイン60　15階', '13', '13116', '1706015', '東京都', 'トウキョウト', '豊島区', 'トシマク', '東池袋', 'ヒガシイケブクロ', null, null, 'サンシャイン60　15階', 'サンシャイン60　15カイ');
INSERT INTO `ms_addresses` VALUES ('8175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都豊島区東池袋サンシャイン60　16階', '13', '13116', '1706016', '東京都', 'トウキョウト', '豊島区', 'トシマク', '東池袋', 'ヒガシイケブクロ', null, null, 'サンシャイン60　16階', 'サンシャイン60　16カイ');
INSERT INTO `ms_addresses` VALUES ('8176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都豊島区東池袋サンシャイン60　17階', '13', '13116', '1706017', '東京都', 'トウキョウト', '豊島区', 'トシマク', '東池袋', 'ヒガシイケブクロ', null, null, 'サンシャイン60　17階', 'サンシャイン60　17カイ');
INSERT INTO `ms_addresses` VALUES ('8177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都豊島区東池袋サンシャイン60　18階', '13', '13116', '1706018', '東京都', 'トウキョウト', '豊島区', 'トシマク', '東池袋', 'ヒガシイケブクロ', null, null, 'サンシャイン60　18階', 'サンシャイン60　18カイ');
INSERT INTO `ms_addresses` VALUES ('8178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都豊島区東池袋サンシャイン60　19階', '13', '13116', '1706019', '東京都', 'トウキョウト', '豊島区', 'トシマク', '東池袋', 'ヒガシイケブクロ', null, null, 'サンシャイン60　19階', 'サンシャイン60　19カイ');
INSERT INTO `ms_addresses` VALUES ('8179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都豊島区東池袋サンシャイン60　20階', '13', '13116', '1706020', '東京都', 'トウキョウト', '豊島区', 'トシマク', '東池袋', 'ヒガシイケブクロ', null, null, 'サンシャイン60　20階', 'サンシャイン60　20カイ');
INSERT INTO `ms_addresses` VALUES ('8180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都豊島区東池袋サンシャイン60　21階', '13', '13116', '1706021', '東京都', 'トウキョウト', '豊島区', 'トシマク', '東池袋', 'ヒガシイケブクロ', null, null, 'サンシャイン60　21階', 'サンシャイン60　21カイ');
INSERT INTO `ms_addresses` VALUES ('8181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都豊島区東池袋サンシャイン60　22階', '13', '13116', '1706022', '東京都', 'トウキョウト', '豊島区', 'トシマク', '東池袋', 'ヒガシイケブクロ', null, null, 'サンシャイン60　22階', 'サンシャイン60　22カイ');
INSERT INTO `ms_addresses` VALUES ('8182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都豊島区東池袋サンシャイン60　23階', '13', '13116', '1706023', '東京都', 'トウキョウト', '豊島区', 'トシマク', '東池袋', 'ヒガシイケブクロ', null, null, 'サンシャイン60　23階', 'サンシャイン60　23カイ');
INSERT INTO `ms_addresses` VALUES ('8183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都豊島区東池袋サンシャイン60　24階', '13', '13116', '1706024', '東京都', 'トウキョウト', '豊島区', 'トシマク', '東池袋', 'ヒガシイケブクロ', null, null, 'サンシャイン60　24階', 'サンシャイン60　24カイ');
INSERT INTO `ms_addresses` VALUES ('8184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都豊島区東池袋サンシャイン60　25階', '13', '13116', '1706025', '東京都', 'トウキョウト', '豊島区', 'トシマク', '東池袋', 'ヒガシイケブクロ', null, null, 'サンシャイン60　25階', 'サンシャイン60　25カイ');
INSERT INTO `ms_addresses` VALUES ('8185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都豊島区東池袋サンシャイン60　26階', '13', '13116', '1706026', '東京都', 'トウキョウト', '豊島区', 'トシマク', '東池袋', 'ヒガシイケブクロ', null, null, 'サンシャイン60　26階', 'サンシャイン60　26カイ');
INSERT INTO `ms_addresses` VALUES ('8186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都豊島区東池袋サンシャイン60　27階', '13', '13116', '1706027', '東京都', 'トウキョウト', '豊島区', 'トシマク', '東池袋', 'ヒガシイケブクロ', null, null, 'サンシャイン60　27階', 'サンシャイン60　27カイ');
INSERT INTO `ms_addresses` VALUES ('8187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都豊島区東池袋サンシャイン60　28階', '13', '13116', '1706028', '東京都', 'トウキョウト', '豊島区', 'トシマク', '東池袋', 'ヒガシイケブクロ', null, null, 'サンシャイン60　28階', 'サンシャイン60　28カイ');
INSERT INTO `ms_addresses` VALUES ('8188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都豊島区東池袋サンシャイン60　29階', '13', '13116', '1706029', '東京都', 'トウキョウト', '豊島区', 'トシマク', '東池袋', 'ヒガシイケブクロ', null, null, 'サンシャイン60　29階', 'サンシャイン60　29カイ');
INSERT INTO `ms_addresses` VALUES ('8189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都豊島区東池袋サンシャイン60　30階', '13', '13116', '1706030', '東京都', 'トウキョウト', '豊島区', 'トシマク', '東池袋', 'ヒガシイケブクロ', null, null, 'サンシャイン60　30階', 'サンシャイン60　30カイ');
INSERT INTO `ms_addresses` VALUES ('8190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都豊島区東池袋サンシャイン60　31階', '13', '13116', '1706031', '東京都', 'トウキョウト', '豊島区', 'トシマク', '東池袋', 'ヒガシイケブクロ', null, null, 'サンシャイン60　31階', 'サンシャイン60　31カイ');
INSERT INTO `ms_addresses` VALUES ('8191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都豊島区東池袋サンシャイン60　32階', '13', '13116', '1706032', '東京都', 'トウキョウト', '豊島区', 'トシマク', '東池袋', 'ヒガシイケブクロ', null, null, 'サンシャイン60　32階', 'サンシャイン60　32カイ');
INSERT INTO `ms_addresses` VALUES ('8192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都豊島区東池袋サンシャイン60　33階', '13', '13116', '1706033', '東京都', 'トウキョウト', '豊島区', 'トシマク', '東池袋', 'ヒガシイケブクロ', null, null, 'サンシャイン60　33階', 'サンシャイン60　33カイ');
INSERT INTO `ms_addresses` VALUES ('8193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都豊島区東池袋サンシャイン60　34階', '13', '13116', '1706034', '東京都', 'トウキョウト', '豊島区', 'トシマク', '東池袋', 'ヒガシイケブクロ', null, null, 'サンシャイン60　34階', 'サンシャイン60　34カイ');
INSERT INTO `ms_addresses` VALUES ('8194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都豊島区東池袋サンシャイン60　35階', '13', '13116', '1706035', '東京都', 'トウキョウト', '豊島区', 'トシマク', '東池袋', 'ヒガシイケブクロ', null, null, 'サンシャイン60　35階', 'サンシャイン60　35カイ');
INSERT INTO `ms_addresses` VALUES ('8195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都豊島区東池袋サンシャイン60　36階', '13', '13116', '1706036', '東京都', 'トウキョウト', '豊島区', 'トシマク', '東池袋', 'ヒガシイケブクロ', null, null, 'サンシャイン60　36階', 'サンシャイン60　36カイ');
INSERT INTO `ms_addresses` VALUES ('8196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都豊島区東池袋サンシャイン60　37階', '13', '13116', '1706037', '東京都', 'トウキョウト', '豊島区', 'トシマク', '東池袋', 'ヒガシイケブクロ', null, null, 'サンシャイン60　37階', 'サンシャイン60　37カイ');
INSERT INTO `ms_addresses` VALUES ('8197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都豊島区東池袋サンシャイン60　38階', '13', '13116', '1706038', '東京都', 'トウキョウト', '豊島区', 'トシマク', '東池袋', 'ヒガシイケブクロ', null, null, 'サンシャイン60　38階', 'サンシャイン60　38カイ');
INSERT INTO `ms_addresses` VALUES ('8198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都豊島区東池袋サンシャイン60　39階', '13', '13116', '1706039', '東京都', 'トウキョウト', '豊島区', 'トシマク', '東池袋', 'ヒガシイケブクロ', null, null, 'サンシャイン60　39階', 'サンシャイン60　39カイ');
INSERT INTO `ms_addresses` VALUES ('8199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都豊島区東池袋サンシャイン60　40階', '13', '13116', '1706040', '東京都', 'トウキョウト', '豊島区', 'トシマク', '東池袋', 'ヒガシイケブクロ', null, null, 'サンシャイン60　40階', 'サンシャイン60　40カイ');
INSERT INTO `ms_addresses` VALUES ('8200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都豊島区東池袋サンシャイン60　41階', '13', '13116', '1706041', '東京都', 'トウキョウト', '豊島区', 'トシマク', '東池袋', 'ヒガシイケブクロ', null, null, 'サンシャイン60　41階', 'サンシャイン60　41カイ');
INSERT INTO `ms_addresses` VALUES ('8201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都豊島区東池袋サンシャイン60　42階', '13', '13116', '1706042', '東京都', 'トウキョウト', '豊島区', 'トシマク', '東池袋', 'ヒガシイケブクロ', null, null, 'サンシャイン60　42階', 'サンシャイン60　42カイ');
INSERT INTO `ms_addresses` VALUES ('8202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都豊島区東池袋サンシャイン60　43階', '13', '13116', '1706043', '東京都', 'トウキョウト', '豊島区', 'トシマク', '東池袋', 'ヒガシイケブクロ', null, null, 'サンシャイン60　43階', 'サンシャイン60　43カイ');
INSERT INTO `ms_addresses` VALUES ('8203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都豊島区東池袋サンシャイン60　44階', '13', '13116', '1706044', '東京都', 'トウキョウト', '豊島区', 'トシマク', '東池袋', 'ヒガシイケブクロ', null, null, 'サンシャイン60　44階', 'サンシャイン60　44カイ');
INSERT INTO `ms_addresses` VALUES ('8204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都豊島区東池袋サンシャイン60　45階', '13', '13116', '1706045', '東京都', 'トウキョウト', '豊島区', 'トシマク', '東池袋', 'ヒガシイケブクロ', null, null, 'サンシャイン60　45階', 'サンシャイン60　45カイ');
INSERT INTO `ms_addresses` VALUES ('8205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都豊島区東池袋サンシャイン60　46階', '13', '13116', '1706046', '東京都', 'トウキョウト', '豊島区', 'トシマク', '東池袋', 'ヒガシイケブクロ', null, null, 'サンシャイン60　46階', 'サンシャイン60　46カイ');
INSERT INTO `ms_addresses` VALUES ('8206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都豊島区東池袋サンシャイン60　47階', '13', '13116', '1706047', '東京都', 'トウキョウト', '豊島区', 'トシマク', '東池袋', 'ヒガシイケブクロ', null, null, 'サンシャイン60　47階', 'サンシャイン60　47カイ');
INSERT INTO `ms_addresses` VALUES ('8207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都豊島区東池袋サンシャイン60　48階', '13', '13116', '1706048', '東京都', 'トウキョウト', '豊島区', 'トシマク', '東池袋', 'ヒガシイケブクロ', null, null, 'サンシャイン60　48階', 'サンシャイン60　48カイ');
INSERT INTO `ms_addresses` VALUES ('8208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都豊島区東池袋サンシャイン60　49階', '13', '13116', '1706049', '東京都', 'トウキョウト', '豊島区', 'トシマク', '東池袋', 'ヒガシイケブクロ', null, null, 'サンシャイン60　49階', 'サンシャイン60　49カイ');
INSERT INTO `ms_addresses` VALUES ('8209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都豊島区東池袋サンシャイン60　50階', '13', '13116', '1706050', '東京都', 'トウキョウト', '豊島区', 'トシマク', '東池袋', 'ヒガシイケブクロ', null, null, 'サンシャイン60　50階', 'サンシャイン60　50カイ');
INSERT INTO `ms_addresses` VALUES ('8210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都豊島区東池袋サンシャイン60　51階', '13', '13116', '1706051', '東京都', 'トウキョウト', '豊島区', 'トシマク', '東池袋', 'ヒガシイケブクロ', null, null, 'サンシャイン60　51階', 'サンシャイン60　51カイ');
INSERT INTO `ms_addresses` VALUES ('8211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都豊島区東池袋サンシャイン60　52階', '13', '13116', '1706052', '東京都', 'トウキョウト', '豊島区', 'トシマク', '東池袋', 'ヒガシイケブクロ', null, null, 'サンシャイン60　52階', 'サンシャイン60　52カイ');
INSERT INTO `ms_addresses` VALUES ('8212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都豊島区東池袋サンシャイン60　53階', '13', '13116', '1706053', '東京都', 'トウキョウト', '豊島区', 'トシマク', '東池袋', 'ヒガシイケブクロ', null, null, 'サンシャイン60　53階', 'サンシャイン60　53カイ');
INSERT INTO `ms_addresses` VALUES ('8213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都豊島区東池袋サンシャイン60　54階', '13', '13116', '1706054', '東京都', 'トウキョウト', '豊島区', 'トシマク', '東池袋', 'ヒガシイケブクロ', null, null, 'サンシャイン60　54階', 'サンシャイン60　54カイ');
INSERT INTO `ms_addresses` VALUES ('8214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都豊島区東池袋サンシャイン60　55階', '13', '13116', '1706055', '東京都', 'トウキョウト', '豊島区', 'トシマク', '東池袋', 'ヒガシイケブクロ', null, null, 'サンシャイン60　55階', 'サンシャイン60　55カイ');
INSERT INTO `ms_addresses` VALUES ('8215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都豊島区東池袋サンシャイン60　56階', '13', '13116', '1706056', '東京都', 'トウキョウト', '豊島区', 'トシマク', '東池袋', 'ヒガシイケブクロ', null, null, 'サンシャイン60　56階', 'サンシャイン60　56カイ');
INSERT INTO `ms_addresses` VALUES ('8216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都豊島区東池袋サンシャイン60　57階', '13', '13116', '1706057', '東京都', 'トウキョウト', '豊島区', 'トシマク', '東池袋', 'ヒガシイケブクロ', null, null, 'サンシャイン60　57階', 'サンシャイン60　57カイ');
INSERT INTO `ms_addresses` VALUES ('8217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都豊島区東池袋サンシャイン60　58階', '13', '13116', '1706058', '東京都', 'トウキョウト', '豊島区', 'トシマク', '東池袋', 'ヒガシイケブクロ', null, null, 'サンシャイン60　58階', 'サンシャイン60　58カイ');
INSERT INTO `ms_addresses` VALUES ('8218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都豊島区東池袋サンシャイン60　59階', '13', '13116', '1706059', '東京都', 'トウキョウト', '豊島区', 'トシマク', '東池袋', 'ヒガシイケブクロ', null, null, 'サンシャイン60　59階', 'サンシャイン60　59カイ');
INSERT INTO `ms_addresses` VALUES ('8219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都豊島区東池袋サンシャイン60　60階', '13', '13116', '1706060', '東京都', 'トウキョウト', '豊島区', 'トシマク', '東池袋', 'ヒガシイケブクロ', null, null, 'サンシャイン60　60階', 'サンシャイン60　60カイ');
INSERT INTO `ms_addresses` VALUES ('8221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都豊島区東池袋サンシャイン60　', '13', '13116', '1706090', '東京都', 'トウキョウト', '豊島区', 'トシマク', '東池袋', 'ヒガシイケブクロ', null, null, 'サンシャイン60　', 'サンシャイン60　');
INSERT INTO `ms_addresses` VALUES ('8222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市一本杉', '05', '05204', '0170801', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '一本杉', 'イッポンスギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市長根山下', '05', '05204', '0170802', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '長根山下', 'ナガネヤマシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市東台', '05', '05204', '0170803', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '東台', 'ヒガシダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市柄沢', '05', '05204', '0170804', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '柄沢', 'カラサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市扇田道下', '05', '05204', '0170805', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '扇田道下', 'オウギダミチシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市相染沢中岱', '05', '05204', '0170806', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '相染沢中岱', 'アイゾメサワナカタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市八幡', '05', '05204', '0170811', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '八幡', 'ハチマン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市金坂', '05', '05204', '0170812', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '金坂', 'カネザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市金坂後', '05', '05204', '0170813', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '金坂後', 'カネザカウシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市赤館町', '05', '05204', '0170814', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '赤館町', 'アカダテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市部垂町', '05', '05204', '0170815', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '部垂町', 'ヘダレマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市赤館', '05', '05204', '0170816', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '赤館', 'アカダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市上町', '05', '05204', '0170817', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '上町', 'ウワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市桜町', '05', '05204', '0170821', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '桜町', 'サクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市桜町南', '05', '05204', '0170822', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '桜町南', 'サクラチョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市八幡沢岱', '05', '05204', '0170823', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '八幡沢岱', 'ハチマンサワタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市七曲岱', '05', '05204', '0170824', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '七曲岱', 'ナナマガリタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市一心院南', '05', '05204', '0170825', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '一心院南', 'イッシンインミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市谷地町後', '05', '05204', '0170826', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '谷地町後', 'ヤチマチウシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市谷地町', '05', '05204', '0170827', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '谷地町', 'ヤチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市向町', '05', '05204', '0170828', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '向町', 'ムカイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市青葉町', '05', '05204', '0170831', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '青葉町', 'アオバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市池内道下', '05', '05204', '0170832', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '池内道下', 'イケナイミチシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市象ケ鼻', '05', '05204', '0170833', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '象ケ鼻', 'ゾウガハナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市池内道上', '05', '05204', '0170834', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '池内道上', 'イケナイミチウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市小館花', '05', '05204', '0170835', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '小館花', 'コタテハナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市池内', '05', '05204', '0170836', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '池内', 'イケナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市餌釣', '05', '05204', '0170837', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '餌釣', 'エツリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市山館', '05', '05204', '0170838', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '山館', 'ヤマダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市中山', '05', '05204', '0170839', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '中山', 'ナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市大町', '05', '05204', '0170841', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '大町', 'オオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市馬喰町', '05', '05204', '0170842', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '馬喰町', 'バクロウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市中町', '05', '05204', '0170843', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '中町', 'ナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市新町', '05', '05204', '0170844', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市泉町', '05', '05204', '0170845', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '泉町', 'イズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市常盤木町', '05', '05204', '0170846', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '常盤木町', 'トキワギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市幸町', '05', '05204', '0170847', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市大披', '05', '05204', '0170851', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '大披', 'オオビラキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市小袴', '05', '05204', '0170852', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '小袴', 'コハカマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市板沢', '05', '05204', '0170853', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '板沢', 'イタザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市赤石', '05', '05204', '0170854', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '赤石', 'アカイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市櫃崎', '05', '05204', '0170855', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '櫃崎', 'ヒツザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市出川', '05', '05204', '0170857', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '出川', 'イデガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市小館町', '05', '05204', '0170861', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '小館町', 'コタテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市根下戸', '05', '05204', '0170862', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '根下戸', 'ネゲト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市根下戸町', '05', '05204', '0170863', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '根下戸町', 'ネゲトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市根下戸新町', '05', '05204', '0170864', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '根下戸新町', 'ネゲトシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市城西町', '05', '05204', '0170865', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '城西町', 'ジョウセイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市北神明町', '05', '05204', '0170866', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '北神明町', 'キタシンメイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市中神明町', '05', '05204', '0170867', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '中神明町', 'ナカシンメイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市南神明町', '05', '05204', '0170868', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '南神明町', 'ミナミシンメイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市片山', '05', '05204', '0170871', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '片山', 'カタヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市片山町', '05', '05204', '0170872', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '片山町', 'カタヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市御坂', '05', '05204', '0170873', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '御坂', 'ミサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市美園町', '05', '05204', '0170874', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '美園町', 'ミソノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市住吉町', '05', '05204', '0170875', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '住吉町', 'スミヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市餅田', '05', '05204', '0170876', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '餅田', 'モチタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市立花', '05', '05204', '0170877', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '立花', 'タテバナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市川口', '05', '05204', '0170878', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '川口', 'カワグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市長木川南', '05', '05204', '0170881', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '長木川南', 'ナガキカワミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市鉄砲場', '05', '05204', '0170882', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '鉄砲場', 'テッポウバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市古川町', '05', '05204', '0170883', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '古川町', 'フルカワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市土飛山下', '05', '05204', '0170884', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '土飛山下', 'ドビヤマシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市豊町', '05', '05204', '0170885', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '豊町', 'ユタカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市館下', '05', '05204', '0170886', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '館下', 'タテシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市水門町', '05', '05204', '0170887', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '水門町', 'スイモンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市水門前', '05', '05204', '0170888', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '水門前', 'スイモンマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市中城', '05', '05204', '0170891', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '中城', 'ナカジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市片町', '05', '05204', '0170892', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '片町', 'カタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市桂城', '05', '05204', '0170893', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '桂城', 'ケイジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市裏町', '05', '05204', '0170894', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '裏町', 'ウラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市長倉', '05', '05204', '0170895', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '長倉', 'ナガクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市大館', '05', '05204', '0170896', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '大館', 'オオダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市三ノ丸', '05', '05204', '0170897', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '三ノ丸', 'サンノマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都豊島区池袋2丁目', '13', '13116', '1710014', '東京都', 'トウキョウト', '豊島区', 'トシマク', '池袋', 'イケブクロ', null, null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('8355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都豊島区池袋3丁目', '13', '13116', '1710014', '東京都', 'トウキョウト', '豊島区', 'トシマク', '池袋', 'イケブクロ', null, null, '3丁目', '03チョウメ');
INSERT INTO `ms_addresses` VALUES ('8356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都豊島区池袋4丁目', '13', '13116', '1710014', '東京都', 'トウキョウト', '豊島区', 'トシマク', '池袋', 'イケブクロ', null, null, '4丁目', '04チョウメ');
INSERT INTO `ms_addresses` VALUES ('8357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都豊島区西池袋', '13', '13116', '1710021', '東京都', 'トウキョウト', '豊島区', 'トシマク', '西池袋', 'ニシイケブクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都豊島区南池袋', '13', '13116', '1710022', '東京都', 'トウキョウト', '豊島区', 'トシマク', '南池袋', 'ミナミイケブクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都豊島区目白', '13', '13116', '1710031', '東京都', 'トウキョウト', '豊島区', 'トシマク', '目白', 'メジロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都豊島区雑司が谷', '13', '13116', '1710032', '東京都', 'トウキョウト', '豊島区', 'トシマク', '雑司が谷', 'ゾウシガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都豊島区高田', '13', '13116', '1710033', '東京都', 'トウキョウト', '豊島区', 'トシマク', '高田', 'タカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都豊島区千川', '13', '13116', '1710041', '東京都', 'トウキョウト', '豊島区', 'トシマク', '千川', 'センカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都豊島区高松', '13', '13116', '1710042', '東京都', 'トウキョウト', '豊島区', 'トシマク', '高松', 'タカマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都豊島区要町', '13', '13116', '1710043', '東京都', 'トウキョウト', '豊島区', 'トシマク', '要町', 'カナメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都豊島区千早', '13', '13116', '1710044', '東京都', 'トウキョウト', '豊島区', 'トシマク', '千早', 'チハヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都豊島区長崎', '13', '13116', '1710051', '東京都', 'トウキョウト', '豊島区', 'トシマク', '長崎', 'ナガサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都豊島区南長崎', '13', '13116', '1710052', '東京都', 'トウキョウト', '豊島区', 'トシマク', '南長崎', 'ミナミナガサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都板橋区本町', '13', '13119', '1730001', '東京都', 'トウキョウト', '板橋区', 'イタバシク', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都板橋区稲荷台', '13', '13119', '1730002', '東京都', 'トウキョウト', '板橋区', 'イタバシク', '稲荷台', 'イナリダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都板橋区加賀', '13', '13119', '1730003', '東京都', 'トウキョウト', '板橋区', 'イタバシク', '加賀', 'カガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都板橋区板橋', '13', '13119', '1730004', '東京都', 'トウキョウト', '板橋区', 'イタバシク', '板橋', 'イタバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都板橋区仲宿', '13', '13119', '1730005', '東京都', 'トウキョウト', '板橋区', 'イタバシク', '仲宿', 'ナカジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都板橋区双葉町', '13', '13119', '1730011', '東京都', 'トウキョウト', '板橋区', 'イタバシク', '双葉町', 'フタバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都板橋区大和町', '13', '13119', '1730012', '東京都', 'トウキョウト', '板橋区', 'イタバシク', '大和町', 'ヤマトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都板橋区氷川町', '13', '13119', '1730013', '東京都', 'トウキョウト', '板橋区', 'イタバシク', '氷川町', 'ヒカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都板橋区大山東町', '13', '13119', '1730014', '東京都', 'トウキョウト', '板橋区', 'イタバシク', '大山東町', 'オオヤマヒガシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都板橋区栄町', '13', '13119', '1730015', '東京都', 'トウキョウト', '板橋区', 'イタバシク', '栄町', 'サカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都板橋区中板橋', '13', '13119', '1730016', '東京都', 'トウキョウト', '板橋区', 'イタバシク', '中板橋', 'ナカイタバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都板橋区弥生町', '13', '13119', '1730021', '東京都', 'トウキョウト', '板橋区', 'イタバシク', '弥生町', 'ヤヨイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都板橋区仲町', '13', '13119', '1730022', '東京都', 'トウキョウト', '板橋区', 'イタバシク', '仲町', 'ナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都板橋区大山町', '13', '13119', '1730023', '東京都', 'トウキョウト', '板橋区', 'イタバシク', '大山町', 'オオヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都板橋区大山金井町', '13', '13119', '1730024', '東京都', 'トウキョウト', '板橋区', 'イタバシク', '大山金井町', 'オオヤマカナイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都板橋区熊野町', '13', '13119', '1730025', '東京都', 'トウキョウト', '板橋区', 'イタバシク', '熊野町', 'クマノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都板橋区中丸町', '13', '13119', '1730026', '東京都', 'トウキョウト', '板橋区', 'イタバシク', '中丸町', 'ナカマルチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都板橋区南町', '13', '13119', '1730027', '東京都', 'トウキョウト', '板橋区', 'イタバシク', '南町', 'ミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都板橋区大谷口北町', '13', '13119', '1730031', '東京都', 'トウキョウト', '板橋区', 'イタバシク', '大谷口北町', 'オオヤグチキタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都板橋区大谷口上町', '13', '13119', '1730032', '東京都', 'トウキョウト', '板橋区', 'イタバシク', '大谷口上町', 'オオヤグチカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都板橋区大山西町', '13', '13119', '1730033', '東京都', 'トウキョウト', '板橋区', 'イタバシク', '大山西町', 'オオヤマニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都板橋区幸町', '13', '13119', '1730034', '東京都', 'トウキョウト', '板橋区', 'イタバシク', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都板橋区大谷口', '13', '13119', '1730035', '東京都', 'トウキョウト', '板橋区', 'イタバシク', '大谷口', 'オオヤグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都板橋区向原', '13', '13119', '1730036', '東京都', 'トウキョウト', '板橋区', 'イタバシク', '向原', 'ムカイハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都板橋区小茂根', '13', '13119', '1730037', '東京都', 'トウキョウト', '板橋区', 'イタバシク', '小茂根', 'コモネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都板橋区', '13', '13119', '1740000', '東京都', 'トウキョウト', '板橋区', 'イタバシク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('8461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都板橋区舟渡', '13', '13119', '1740041', '東京都', 'トウキョウト', '板橋区', 'イタバシク', '舟渡', 'フナド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都板橋区東坂下', '13', '13119', '1740042', '東京都', 'トウキョウト', '板橋区', 'イタバシク', '東坂下', 'ヒガシサカシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都板橋区坂下', '13', '13119', '1740043', '東京都', 'トウキョウト', '板橋区', 'イタバシク', '坂下', 'サカシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都板橋区相生町', '13', '13119', '1740044', '東京都', 'トウキョウト', '板橋区', 'イタバシク', '相生町', 'アイオイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都板橋区西台1丁目', '13', '13119', '1740045', '東京都', 'トウキョウト', '板橋区', 'イタバシク', '西台', 'ニシダイ', null, null, '1丁目', '01チョウメ');
INSERT INTO `ms_addresses` VALUES ('8466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都板橋区蓮根', '13', '13119', '1740046', '東京都', 'トウキョウト', '板橋区', 'イタバシク', '蓮根', 'ハスネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都板橋区小豆沢', '13', '13119', '1740051', '東京都', 'トウキョウト', '板橋区', 'イタバシク', '小豆沢', 'アズサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都板橋区蓮沼町', '13', '13119', '1740052', '東京都', 'トウキョウト', '板橋区', 'イタバシク', '蓮沼町', 'ハスヌマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都板橋区清水町', '13', '13119', '1740053', '東京都', 'トウキョウト', '板橋区', 'イタバシク', '清水町', 'シミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都板橋区宮本町', '13', '13119', '1740054', '東京都', 'トウキョウト', '板橋区', 'イタバシク', '宮本町', 'ミヤモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都板橋区泉町', '13', '13119', '1740055', '東京都', 'トウキョウト', '板橋区', 'イタバシク', '泉町', 'イズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都板橋区志村', '13', '13119', '1740056', '東京都', 'トウキョウト', '板橋区', 'イタバシク', '志村', 'シムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都板橋区大原町', '13', '13119', '1740061', '東京都', 'トウキョウト', '板橋区', 'イタバシク', '大原町', 'オオハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都板橋区富士見町', '13', '13119', '1740062', '東京都', 'トウキョウト', '板橋区', 'イタバシク', '富士見町', 'フジミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都板橋区前野町', '13', '13119', '1740063', '東京都', 'トウキョウト', '板橋区', 'イタバシク', '前野町', 'マエノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都板橋区中台', '13', '13119', '1740064', '東京都', 'トウキョウト', '板橋区', 'イタバシク', '中台', 'ナカダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都板橋区若木', '13', '13119', '1740065', '東京都', 'トウキョウト', '板橋区', 'イタバシク', '若木', 'ワカギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都板橋区常盤台', '13', '13119', '1740071', '東京都', 'トウキョウト', '板橋区', 'イタバシク', '常盤台', 'トキワダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都板橋区南常盤台', '13', '13119', '1740072', '東京都', 'トウキョウト', '板橋区', 'イタバシク', '南常盤台', 'ミナミトキワダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都板橋区東山町', '13', '13119', '1740073', '東京都', 'トウキョウト', '板橋区', 'イタバシク', '東山町', 'ヒガシヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都板橋区東新町', '13', '13119', '1740074', '東京都', 'トウキョウト', '板橋区', 'イタバシク', '東新町', 'トウシンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都板橋区桜川', '13', '13119', '1740075', '東京都', 'トウキョウト', '板橋区', 'イタバシク', '桜川', 'サクラガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都板橋区上板橋', '13', '13119', '1740076', '東京都', 'トウキョウト', '板橋区', 'イタバシク', '上板橋', 'カミイタバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都板橋区西台2丁目', '13', '13119', '1750045', '東京都', 'トウキョウト', '板橋区', 'イタバシク', '西台', 'ニシダイ', null, null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('8515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都板橋区西台3丁目', '13', '13119', '1750045', '東京都', 'トウキョウト', '板橋区', 'イタバシク', '西台', 'ニシダイ', null, null, '3丁目', '03チョウメ');
INSERT INTO `ms_addresses` VALUES ('8516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都板橋区西台4丁目', '13', '13119', '1750045', '東京都', 'トウキョウト', '板橋区', 'イタバシク', '西台', 'ニシダイ', null, null, '4丁目', '04チョウメ');
INSERT INTO `ms_addresses` VALUES ('8517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都板橋区新河岸', '13', '13119', '1750081', '東京都', 'トウキョウト', '板橋区', 'イタバシク', '新河岸', 'シンガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都板橋区高島平', '13', '13119', '1750082', '東京都', 'トウキョウト', '板橋区', 'イタバシク', '高島平', 'タカシマダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都板橋区徳丸', '13', '13119', '1750083', '東京都', 'トウキョウト', '板橋区', 'イタバシク', '徳丸', 'トクマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都板橋区四葉', '13', '13119', '1750084', '東京都', 'トウキョウト', '板橋区', 'イタバシク', '四葉', 'ヨツバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都板橋区大門', '13', '13119', '1750085', '東京都', 'トウキョウト', '板橋区', 'イタバシク', '大門', 'ダイモン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都板橋区三園', '13', '13119', '1750091', '東京都', 'トウキョウト', '板橋区', 'イタバシク', '三園', 'ミソノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都板橋区赤塚', '13', '13119', '1750092', '東京都', 'トウキョウト', '板橋区', 'イタバシク', '赤塚', 'アカツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都板橋区赤塚新町', '13', '13119', '1750093', '東京都', 'トウキョウト', '板橋区', 'イタバシク', '赤塚新町', 'アカツカシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都板橋区成増', '13', '13119', '1750094', '東京都', 'トウキョウト', '板橋区', 'イタバシク', '成増', 'ナリマス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都練馬区', '13', '13120', '1760000', '東京都', 'トウキョウト', '練馬区', 'ネリマク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('8530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都練馬区練馬', '13', '13120', '1760001', '東京都', 'トウキョウト', '練馬区', 'ネリマク', '練馬', 'ネリマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都練馬区桜台', '13', '13120', '1760002', '東京都', 'トウキョウト', '練馬区', 'ネリマク', '桜台', 'サクラダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都練馬区羽沢', '13', '13120', '1760003', '東京都', 'トウキョウト', '練馬区', 'ネリマク', '羽沢', 'ハザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都練馬区小竹町', '13', '13120', '1760004', '東京都', 'トウキョウト', '練馬区', 'ネリマク', '小竹町', 'コタケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都練馬区旭丘', '13', '13120', '1760005', '東京都', 'トウキョウト', '練馬区', 'ネリマク', '旭丘', 'アサヒガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都練馬区栄町', '13', '13120', '1760006', '東京都', 'トウキョウト', '練馬区', 'ネリマク', '栄町', 'サカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都練馬区豊玉上', '13', '13120', '1760011', '東京都', 'トウキョウト', '練馬区', 'ネリマク', '豊玉上', 'トヨタマカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都練馬区豊玉北', '13', '13120', '1760012', '東京都', 'トウキョウト', '練馬区', 'ネリマク', '豊玉北', 'トヨタマキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都練馬区豊玉中', '13', '13120', '1760013', '東京都', 'トウキョウト', '練馬区', 'ネリマク', '豊玉中', 'トヨタマナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都練馬区豊玉南', '13', '13120', '1760014', '東京都', 'トウキョウト', '練馬区', 'ネリマク', '豊玉南', 'トヨタマミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都練馬区貫井', '13', '13120', '1760021', '東京都', 'トウキョウト', '練馬区', 'ネリマク', '貫井', 'ヌクイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都練馬区向山', '13', '13120', '1760022', '東京都', 'トウキョウト', '練馬区', 'ネリマク', '向山', 'コウヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都練馬区中村北', '13', '13120', '1760023', '東京都', 'トウキョウト', '練馬区', 'ネリマク', '中村北', 'ナカムラキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都練馬区中村', '13', '13120', '1760024', '東京都', 'トウキョウト', '練馬区', 'ネリマク', '中村', 'ナカムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都練馬区中村南', '13', '13120', '1760025', '東京都', 'トウキョウト', '練馬区', 'ネリマク', '中村南', 'ナカムラミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都練馬区三原台', '13', '13120', '1770031', '東京都', 'トウキョウト', '練馬区', 'ネリマク', '三原台', 'ミハラダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都練馬区谷原', '13', '13120', '1770032', '東京都', 'トウキョウト', '練馬区', 'ネリマク', '谷原', 'ヤハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都練馬区高野台', '13', '13120', '1770033', '東京都', 'トウキョウト', '練馬区', 'ネリマク', '高野台', 'タカノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都練馬区富士見台', '13', '13120', '1770034', '東京都', 'トウキョウト', '練馬区', 'ネリマク', '富士見台', 'フジミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都練馬区南田中', '13', '13120', '1770035', '東京都', 'トウキョウト', '練馬区', 'ネリマク', '南田中', 'ミナミタナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都練馬区石神井町', '13', '13120', '1770041', '東京都', 'トウキョウト', '練馬区', 'ネリマク', '石神井町', 'シャクジイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都練馬区下石神井', '13', '13120', '1770042', '東京都', 'トウキョウト', '練馬区', 'ネリマク', '下石神井', 'シモシャクジイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都練馬区上石神井南町', '13', '13120', '1770043', '東京都', 'トウキョウト', '練馬区', 'ネリマク', '上石神井南町', 'カミシャクジイミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都練馬区上石神井', '13', '13120', '1770044', '東京都', 'トウキョウト', '練馬区', 'ネリマク', '上石神井', 'カミシャクジイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都練馬区石神井台', '13', '13120', '1770045', '東京都', 'トウキョウト', '練馬区', 'ネリマク', '石神井台', 'シャクジイダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都練馬区関町北', '13', '13120', '1770051', '東京都', 'トウキョウト', '練馬区', 'ネリマク', '関町北', 'セキマチキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都練馬区関町東', '13', '13120', '1770052', '東京都', 'トウキョウト', '練馬区', 'ネリマク', '関町東', 'セキマチヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都練馬区関町南', '13', '13120', '1770053', '東京都', 'トウキョウト', '練馬区', 'ネリマク', '関町南', 'セキマチミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都練馬区立野町', '13', '13120', '1770054', '東京都', 'トウキョウト', '練馬区', 'ネリマク', '立野町', 'タテノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都練馬区大泉学園町', '13', '13120', '1780061', '東京都', 'トウキョウト', '練馬区', 'ネリマク', '大泉学園町', 'オオイズミガクエンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都練馬区大泉町', '13', '13120', '1780062', '東京都', 'トウキョウト', '練馬区', 'ネリマク', '大泉町', 'オオイズミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都練馬区東大泉', '13', '13120', '1780063', '東京都', 'トウキョウト', '練馬区', 'ネリマク', '東大泉', 'ヒガシオオイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都練馬区南大泉', '13', '13120', '1780064', '東京都', 'トウキョウト', '練馬区', 'ネリマク', '南大泉', 'ミナミオオイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都練馬区西大泉', '13', '13120', '1780065', '東京都', 'トウキョウト', '練馬区', 'ネリマク', '西大泉', 'ニシオオイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都練馬区西大泉町', '13', '13120', '1780066', '東京都', 'トウキョウト', '練馬区', 'ネリマク', '西大泉町', 'ニシオオイズミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都練馬区旭町', '13', '13120', '1790071', '東京都', 'トウキョウト', '練馬区', 'ネリマク', '旭町', 'アサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都練馬区光が丘', '13', '13120', '1790072', '東京都', 'トウキョウト', '練馬区', 'ネリマク', '光が丘', 'ヒカリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都練馬区田柄', '13', '13120', '1790073', '東京都', 'トウキョウト', '練馬区', 'ネリマク', '田柄', 'タガラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都練馬区春日町', '13', '13120', '1790074', '東京都', 'トウキョウト', '練馬区', 'ネリマク', '春日町', 'カスガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都練馬区高松', '13', '13120', '1790075', '東京都', 'トウキョウト', '練馬区', 'ネリマク', '高松', 'タカマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都練馬区土支田', '13', '13120', '1790076', '東京都', 'トウキョウト', '練馬区', 'ネリマク', '土支田', 'ドシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都練馬区北町', '13', '13120', '1790081', '東京都', 'トウキョウト', '練馬区', 'ネリマク', '北町', 'キタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都練馬区錦', '13', '13120', '1790082', '東京都', 'トウキョウト', '練馬区', 'ネリマク', '錦', 'ニシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都練馬区平和台', '13', '13120', '1790083', '東京都', 'トウキョウト', '練馬区', 'ネリマク', '平和台', 'ヘイワダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都練馬区氷川台', '13', '13120', '1790084', '東京都', 'トウキョウト', '練馬区', 'ネリマク', '氷川台', 'ヒカワダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都練馬区早宮', '13', '13120', '1790085', '東京都', 'トウキョウト', '練馬区', 'ネリマク', '早宮', 'ハヤミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都武蔵野市', '13', '13203', '1800000', '東京都', 'トウキョウト', '武蔵野市', 'ムサシノシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('8637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都武蔵野市吉祥寺北町', '13', '13203', '1800001', '東京都', 'トウキョウト', '武蔵野市', 'ムサシノシ', '吉祥寺北町', 'キチジョウジキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都武蔵野市吉祥寺東町', '13', '13203', '1800002', '東京都', 'トウキョウト', '武蔵野市', 'ムサシノシ', '吉祥寺東町', 'キチジョウジヒガシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都武蔵野市吉祥寺南町', '13', '13203', '1800003', '東京都', 'トウキョウト', '武蔵野市', 'ムサシノシ', '吉祥寺南町', 'キチジョウジミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都武蔵野市吉祥寺本町', '13', '13203', '1800004', '東京都', 'トウキョウト', '武蔵野市', 'ムサシノシ', '吉祥寺本町', 'キチジョウジホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都武蔵野市御殿山', '13', '13203', '1800005', '東京都', 'トウキョウト', '武蔵野市', 'ムサシノシ', '御殿山', 'ゴテンヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都武蔵野市中町', '13', '13203', '1800006', '東京都', 'トウキョウト', '武蔵野市', 'ムサシノシ', '中町', 'ナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都武蔵野市八幡町', '13', '13203', '1800011', '東京都', 'トウキョウト', '武蔵野市', 'ムサシノシ', '八幡町', 'ヤハタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都武蔵野市緑町', '13', '13203', '1800012', '東京都', 'トウキョウト', '武蔵野市', 'ムサシノシ', '緑町', 'ミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都武蔵野市西久保', '13', '13203', '1800013', '東京都', 'トウキョウト', '武蔵野市', 'ムサシノシ', '西久保', 'ニシクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都武蔵野市関前', '13', '13203', '1800014', '東京都', 'トウキョウト', '武蔵野市', 'ムサシノシ', '関前', 'セキマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都武蔵野市桜堤', '13', '13203', '1800021', '東京都', 'トウキョウト', '武蔵野市', 'ムサシノシ', '桜堤', 'サクラヅツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都武蔵野市境', '13', '13203', '1800022', '東京都', 'トウキョウト', '武蔵野市', 'ムサシノシ', '境', 'サカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都武蔵野市境南町', '13', '13203', '1800023', '東京都', 'トウキョウト', '武蔵野市', 'ムサシノシ', '境南町', 'キョウナンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県にかほ市象潟町浜山', '05', '05214', '0180101', '秋田県', 'アキタケン', 'にかほ市', 'ニカホシ', '象潟町浜山', 'キサカタマチハマヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県にかほ市象潟町木戸口', '05', '05214', '0180102', '秋田県', 'アキタケン', 'にかほ市', 'ニカホシ', '象潟町木戸口', 'キサカタマチキドグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県にかほ市象潟町上狐森', '05', '05214', '0180103', '秋田県', 'アキタケン', 'にかほ市', 'ニカホシ', '象潟町上狐森', 'キサカタマチカミキツネモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県にかほ市象潟町狐森', '05', '05214', '0180104', '秋田県', 'アキタケン', 'にかほ市', 'ニカホシ', '象潟町狐森', 'キサカタマチキツネモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県にかほ市象潟町荒屋妻', '05', '05214', '0180105', '秋田県', 'アキタケン', 'にかほ市', 'ニカホシ', '象潟町荒屋妻', 'キサカタマチアラヤヅマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県にかほ市象潟町5丁目塩越', '05', '05214', '0180106', '秋田県', 'アキタケン', 'にかほ市', 'ニカホシ', '象潟町5丁目塩越', 'キサカタマチ05チョウメシオコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県にかほ市象潟町荒屋下', '05', '05214', '0180107', '秋田県', 'アキタケン', 'にかほ市', 'ニカホシ', '象潟町荒屋下', 'キサカタマチアラヤシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県にかほ市象潟町入湖の澗', '05', '05214', '0180108', '秋田県', 'アキタケン', 'にかほ市', 'ニカホシ', '象潟町入湖の澗', 'キサカタマチイリコノマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県にかほ市象潟町冠石下', '05', '05214', '0180109', '秋田県', 'アキタケン', 'にかほ市', 'ニカホシ', '象潟町冠石下', 'キサカタマチカンムリイシシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県にかほ市象潟町武道島', '05', '05214', '0180111', '秋田県', 'アキタケン', 'にかほ市', 'ニカホシ', '象潟町武道島', 'キサカタマチブドウジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県にかほ市象潟町家の後', '05', '05214', '0180112', '秋田県', 'アキタケン', 'にかほ市', 'ニカホシ', '象潟町家の後', 'キサカタマチイエノウシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県にかほ市象潟町浜の田', '05', '05214', '0180113', '秋田県', 'アキタケン', 'にかほ市', 'ニカホシ', '象潟町浜の田', 'キサカタマチハマノタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県にかほ市象潟町沖の田', '05', '05214', '0180114', '秋田県', 'アキタケン', 'にかほ市', 'ニカホシ', '象潟町沖の田', 'キサカタマチオキノタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県にかほ市象潟町後田', '05', '05214', '0180115', '秋田県', 'アキタケン', 'にかほ市', 'ニカホシ', '象潟町後田', 'キサカタマチウシロダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県にかほ市象潟町4丁目塩越', '05', '05214', '0180116', '秋田県', 'アキタケン', 'にかほ市', 'ニカホシ', '象潟町4丁目塩越', 'キサカタマチ04チョウメシオコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県にかほ市象潟町浜畑', '05', '05214', '0180117', '秋田県', 'アキタケン', 'にかほ市', 'ニカホシ', '象潟町浜畑', 'キサカタマチハマハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県にかほ市象潟町2丁目塩越', '05', '05214', '0180118', '秋田県', 'アキタケン', 'にかほ市', 'ニカホシ', '象潟町2丁目塩越', 'キサカタマチ02チョウメシオコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県にかほ市象潟町3丁目塩越', '05', '05214', '0180119', '秋田県', 'アキタケン', 'にかほ市', 'ニカホシ', '象潟町3丁目塩越', 'キサカタマチ03チョウメシオコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県にかほ市象潟町大塩越', '05', '05214', '0180121', '秋田県', 'アキタケン', 'にかほ市', 'ニカホシ', '象潟町大塩越', 'キサカタマチオオシオコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県にかほ市象潟町象潟島', '05', '05214', '0180122', '秋田県', 'アキタケン', 'にかほ市', 'ニカホシ', '象潟町象潟島', 'キサカタマチキサカタジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県にかほ市象潟町妙見下', '05', '05214', '0180123', '秋田県', 'アキタケン', 'にかほ市', 'ニカホシ', '象潟町妙見下', 'キサカタマチミョウケンシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県にかほ市象潟町入道島', '05', '05214', '0180124', '秋田県', 'アキタケン', 'にかほ市', 'ニカホシ', '象潟町入道島', 'キサカタマチニュウドウジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県にかほ市象潟町二の丸', '05', '05214', '0180125', '秋田県', 'アキタケン', 'にかほ市', 'ニカホシ', '象潟町二の丸', 'キサカタマチニノマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県にかほ市象潟町1丁目塩越', '05', '05214', '0180126', '秋田県', 'アキタケン', 'にかほ市', 'ニカホシ', '象潟町1丁目塩越', 'キサカタマチ01チョウメシオコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県にかほ市象潟町中橋町', '05', '05214', '0180127', '秋田県', 'アキタケン', 'にかほ市', 'ニカホシ', '象潟町中橋町', 'キサカタマチナカバシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県にかほ市象潟町太郎島', '05', '05214', '0180128', '秋田県', 'アキタケン', 'にかほ市', 'ニカホシ', '象潟町太郎島', 'キサカタマチタロウジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県にかほ市象潟町才の神', '05', '05214', '0180129', '秋田県', 'アキタケン', 'にかほ市', 'ニカホシ', '象潟町才の神', 'キサカタマチサイノカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県にかほ市象潟町大谷地', '05', '05214', '0180131', '秋田県', 'アキタケン', 'にかほ市', 'ニカホシ', '象潟町大谷地', 'キサカタマチオオヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県にかほ市象潟町鳥の海', '05', '05214', '0180132', '秋田県', 'アキタケン', 'にかほ市', 'ニカホシ', '象潟町鳥の海', 'キサカタマチトリノウミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県にかほ市象潟町関', '05', '05214', '0180133', '秋田県', 'アキタケン', 'にかほ市', 'ニカホシ', '象潟町関', 'キサカタマチセキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県にかほ市象潟町西中野沢', '05', '05214', '0180134', '秋田県', 'アキタケン', 'にかほ市', 'ニカホシ', '象潟町西中野沢', 'キサカタマチニシナカノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県にかほ市象潟町洗釜', '05', '05214', '0180135', '秋田県', 'アキタケン', 'にかほ市', 'ニカホシ', '象潟町洗釜', 'キサカタマチアライガマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県にかほ市象潟町大砂川', '05', '05214', '0180136', '秋田県', 'アキタケン', 'にかほ市', 'ニカホシ', '象潟町大砂川', 'キサカタマチオオサガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県にかほ市象潟町川袋', '05', '05214', '0180141', '秋田県', 'アキタケン', 'にかほ市', 'ニカホシ', '象潟町川袋', 'キサカタマチカワフクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県にかほ市象潟町大須郷', '05', '05214', '0180142', '秋田県', 'アキタケン', 'にかほ市', 'ニカホシ', '象潟町大須郷', 'キサカタマチオオスゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県にかほ市象潟町小砂川', '05', '05214', '0180143', '秋田県', 'アキタケン', 'にかほ市', 'ニカホシ', '象潟町小砂川', 'キサカタマチコサガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県にかほ市象潟町中谷地', '05', '05214', '0180144', '秋田県', 'アキタケン', 'にかほ市', 'ニカホシ', '象潟町中谷地', 'キサカタマチナカヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県にかほ市象潟町源蔵潟', '05', '05214', '0180145', '秋田県', 'アキタケン', 'にかほ市', 'ニカホシ', '象潟町源蔵潟', 'キサカタマチゲンゾウガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県にかほ市象潟町蒲谷池', '05', '05214', '0180146', '秋田県', 'アキタケン', 'にかほ市', 'ニカホシ', '象潟町蒲谷池', 'キサカタマチカバヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県にかほ市象潟町立石', '05', '05214', '0180147', '秋田県', 'アキタケン', 'にかほ市', 'ニカホシ', '象潟町立石', 'キサカタマチタテイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県にかほ市象潟町下浜山', '05', '05214', '0180148', '秋田県', 'アキタケン', 'にかほ市', 'ニカホシ', '象潟町下浜山', 'キサカタマチシモハマヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県にかほ市象潟町横岡', '05', '05214', '0180151', '秋田県', 'アキタケン', 'にかほ市', 'ニカホシ', '象潟町横岡', 'キサカタマチヨコオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県にかほ市象潟町本郷', '05', '05214', '0180152', '秋田県', 'アキタケン', 'にかほ市', 'ニカホシ', '象潟町本郷', 'キサカタマチホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県にかほ市象潟町小滝', '05', '05214', '0180153', '秋田県', 'アキタケン', 'にかほ市', 'ニカホシ', '象潟町小滝', 'キサカタマチコダキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県にかほ市象潟町二階谷地', '05', '05214', '0180154', '秋田県', 'アキタケン', 'にかほ市', 'ニカホシ', '象潟町二階谷地', 'キサカタマチニカイヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県にかほ市象潟町弁天島', '05', '05214', '0180155', '秋田県', 'アキタケン', 'にかほ市', 'ニカホシ', '象潟町弁天島', 'キサカタマチベンテンジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県にかほ市象潟町大門先', '05', '05214', '0180156', '秋田県', 'アキタケン', 'にかほ市', 'ニカホシ', '象潟町大門先', 'キサカタマチダイモンザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県にかほ市象潟町鷹放', '05', '05214', '0180157', '秋田県', 'アキタケン', 'にかほ市', 'ニカホシ', '象潟町鷹放', 'キサカタマチタカハナシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県にかほ市象潟町琴和喜', '05', '05214', '0180158', '秋田県', 'アキタケン', 'にかほ市', 'ニカホシ', '象潟町琴和喜', 'キサカタマチコトワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県にかほ市象潟町大飯郷', '05', '05214', '0180161', '秋田県', 'アキタケン', 'にかほ市', 'ニカホシ', '象潟町大飯郷', 'キサカタマチダイハンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県にかほ市象潟町大森', '05', '05214', '0180162', '秋田県', 'アキタケン', 'にかほ市', 'ニカホシ', '象潟町大森', 'キサカタマチオオモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県にかほ市象潟町長岡', '05', '05214', '0180163', '秋田県', 'アキタケン', 'にかほ市', 'ニカホシ', '象潟町長岡', 'キサカタマチナガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県にかほ市象潟町丸山', '05', '05214', '0180164', '秋田県', 'アキタケン', 'にかほ市', 'ニカホシ', '象潟町丸山', 'キサカタマチマルヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県にかほ市象潟町狸森', '05', '05214', '0180165', '秋田県', 'アキタケン', 'にかほ市', 'ニカホシ', '象潟町狸森', 'キサカタマチタヌキモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県にかほ市象潟町高田', '05', '05214', '0180166', '秋田県', 'アキタケン', 'にかほ市', 'ニカホシ', '象潟町高田', 'キサカタマチタカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県にかほ市象潟町田の神', '05', '05214', '0180167', '秋田県', 'アキタケン', 'にかほ市', 'ニカホシ', '象潟町田の神', 'キサカタマチタノカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県にかほ市象潟町続島', '05', '05214', '0180171', '秋田県', 'アキタケン', 'にかほ市', 'ニカホシ', '象潟町続島', 'キサカタマチツヅキジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県にかほ市象潟町小才の神', '05', '05214', '0180172', '秋田県', 'アキタケン', 'にかほ市', 'ニカホシ', '象潟町小才の神', 'キサカタマチコサイノカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県にかほ市象潟町四隅池', '05', '05214', '0180173', '秋田県', 'アキタケン', 'にかほ市', 'ニカホシ', '象潟町四隅池', 'キサカタマチヨスミイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県にかほ市象潟町林の下', '05', '05214', '0180174', '秋田県', 'アキタケン', 'にかほ市', 'ニカホシ', '象潟町林の下', 'キサカタマチハヤシノシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県にかほ市象潟町坂の下', '05', '05214', '0180175', '秋田県', 'アキタケン', 'にかほ市', 'ニカホシ', '象潟町坂の下', 'キサカタマチサカノシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県にかほ市象潟町横山', '05', '05214', '0180176', '秋田県', 'アキタケン', 'にかほ市', 'ニカホシ', '象潟町横山', 'キサカタマチヨコヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県にかほ市象潟町白山堂', '05', '05214', '0180181', '秋田県', 'アキタケン', 'にかほ市', 'ニカホシ', '象潟町白山堂', 'キサカタマチシラヤマドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県にかほ市象潟町不動沢', '05', '05214', '0180182', '秋田県', 'アキタケン', 'にかほ市', 'ニカホシ', '象潟町不動沢', 'キサカタマチフドウサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県にかほ市象潟町小坂', '05', '05214', '0180183', '秋田県', 'アキタケン', 'にかほ市', 'ニカホシ', '象潟町小坂', 'キサカタマチコサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県にかほ市象潟町上小坂', '05', '05214', '0180184', '秋田県', 'アキタケン', 'にかほ市', 'ニカホシ', '象潟町上小坂', 'キサカタマチカミコサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県にかほ市象潟町屋敷田', '05', '05214', '0180185', '秋田県', 'アキタケン', 'にかほ市', 'ニカホシ', '象潟町屋敷田', 'キサカタマチヤシキダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県にかほ市象潟町能因島', '05', '05214', '0180186', '秋田県', 'アキタケン', 'にかほ市', 'ニカホシ', '象潟町能因島', 'キサカタマチノウインジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県にかほ市象潟町小烏島', '05', '05214', '0180187', '秋田県', 'アキタケン', 'にかほ市', 'ニカホシ', '象潟町小烏島', 'キサカタマチコガラスジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県にかほ市象潟町烏島', '05', '05214', '0180188', '秋田県', 'アキタケン', 'にかほ市', 'ニカホシ', '象潟町烏島', 'キサカタマチカラスジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県にかほ市飛', '05', '05214', '0180301', '秋田県', 'アキタケン', 'にかほ市', 'ニカホシ', '飛', 'トビ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県にかほ市黒川', '05', '05214', '0180302', '秋田県', 'アキタケン', 'にかほ市', 'ニカホシ', '黒川', 'クロカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県にかほ市金浦', '05', '05214', '0180311', '秋田県', 'アキタケン', 'にかほ市', 'ニカホシ', '金浦', 'コノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県にかほ市前川', '05', '05214', '0180321', '秋田県', 'アキタケン', 'にかほ市', 'ニカホシ', '前川', 'マエカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県にかほ市大竹', '05', '05214', '0180322', '秋田県', 'アキタケン', 'にかほ市', 'ニカホシ', '大竹', 'オオタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県にかほ市', '05', '05214', '0180400', '秋田県', 'アキタケン', 'にかほ市', 'ニカホシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('8728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県にかほ市両前寺', '05', '05214', '0180401', '秋田県', 'アキタケン', 'にかほ市', 'ニカホシ', '両前寺', 'リョウゼンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県にかほ市平沢', '05', '05214', '0180402', '秋田県', 'アキタケン', 'にかほ市', 'ニカホシ', '平沢', 'ヒラサワ', null, null, null, null), ('8730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県にかほ市三森', '05', '05214', '0180403', '秋田県', 'アキタケン', 'にかほ市', 'ニカホシ', '三森', 'ミツモリ', null, null, null, null), ('8731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県にかほ市芹田', '05', '05214', '0180404', '秋田県', 'アキタケン', 'にかほ市', 'ニカホシ', '芹田', 'セリダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県にかほ市院内', '05', '05214', '0180411', '秋田県', 'アキタケン', 'にかほ市', 'ニカホシ', '院内', 'インナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県にかほ市小国', '05', '05214', '0180412', '秋田県', 'アキタケン', 'にかほ市', 'ニカホシ', '小国', 'オグニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県にかほ市馬場', '05', '05214', '0180413', '秋田県', 'アキタケン', 'にかほ市', 'ニカホシ', '馬場', 'ババ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県にかほ市田抓', '05', '05214', '0180414', '秋田県', 'アキタケン', 'にかほ市', 'ニカホシ', '田抓', 'タヅカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県にかほ市釜ケ台', '05', '05214', '0180421', '秋田県', 'アキタケン', 'にかほ市', 'ニカホシ', '釜ケ台', 'カマガタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県にかほ市冬師', '05', '05214', '0180422', '秋田県', 'アキタケン', 'にかほ市', 'ニカホシ', '冬師', 'トウシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県にかほ市伊勢居地', '05', '05214', '0180431', '秋田県', 'アキタケン', 'にかほ市', 'ニカホシ', '伊勢居地', 'イセイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県にかほ市水沢', '05', '05214', '0180432', '秋田県', 'アキタケン', 'にかほ市', 'ニカホシ', '水沢', 'ミズサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県にかほ市畑', '05', '05214', '0180433', '秋田県', 'アキタケン', 'にかほ市', 'ニカホシ', '畑', 'ハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県にかほ市寺田', '05', '05214', '0180434', '秋田県', 'アキタケン', 'にかほ市', 'ニカホシ', '寺田', 'テラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県にかほ市中三地', '05', '05214', '0180435', '秋田県', 'アキタケン', 'にかほ市', 'ニカホシ', '中三地', 'ナカサンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県にかほ市樋目野', '05', '05214', '0180436', '秋田県', 'アキタケン', 'にかほ市', 'ニカホシ', '樋目野', 'ヒメノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市西目町海士剥', '05', '05210', '0180601', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '西目町海士剥', 'ニシメマチアマハギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市西目町出戸', '05', '05210', '0180602', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '西目町出戸', 'ニシメマチデト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市西目町西目', '05', '05210', '0180603', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '西目町西目', 'ニシメマチニシメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市西目町沼田', '05', '05210', '0180604', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '西目町沼田', 'ニシメマチヌマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市岩谷町', '05', '05210', '0180711', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '岩谷町', 'イワヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市大谷', '05', '05210', '0180721', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '大谷', 'オオタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市中館', '05', '05210', '0180722', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '中館', 'ナカダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市牛寺', '05', '05210', '0180723', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '牛寺', 'ウシデラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市深沢', '05', '05210', '0180724', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '深沢', 'フカサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市米坂', '05', '05210', '0180725', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '米坂', 'ヨネザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市岩谷麓', '05', '05210', '0180726', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '岩谷麓', 'イワヤフモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市大内三川', '05', '05210', '0180731', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '大内三川', 'オオウチサンカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市徳沢', '05', '05210', '0180732', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '徳沢', 'トクサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市大倉沢', '05', '05210', '0180733', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '大倉沢', 'オオクラザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市北福田', '05', '05210', '0180734', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '北福田', 'キタフクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市加賀沢', '05', '05210', '0180841', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '加賀沢', 'カガサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市新沢', '05', '05210', '0180842', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '新沢', 'シンサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市中帳', '05', '05210', '0180843', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '中帳', 'ナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市高尾', '05', '05210', '0180844', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '高尾', 'タカオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市中俣', '05', '05210', '0180845', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '中俣', 'ナカノマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市平岫', '05', '05210', '0180851', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '平岫', 'ヒラグキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市葛岡', '05', '05210', '0180852', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '葛岡', 'クズオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市長坂', '05', '05210', '0180853', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '長坂', 'ナガサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市及位', '05', '05210', '0180854', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '及位', 'ノゾキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市松本', '05', '05210', '0180855', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '松本', 'マツモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市中田代', '05', '05210', '0180901', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '中田代', 'ナカタシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市新田', '05', '05210', '0180902', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '新田', 'シンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市小栗山', '05', '05210', '0180903', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '小栗山', 'コグリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市岩野目沢', '05', '05210', '0180904', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '岩野目沢', 'イワノメザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市滝', '05', '05210', '0180905', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '滝', 'タキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市羽広', '05', '05210', '0180906', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '羽広', 'ハビロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市坂部', '05', '05210', '0180907', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '坂部', 'サカベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都三鷹市', '13', '13204', '1810000', '東京都', 'トウキョウト', '三鷹市', 'ミタカシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('8809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都三鷹市井の頭', '13', '13204', '1810001', '東京都', 'トウキョウト', '三鷹市', 'ミタカシ', '井の頭', 'イノカシラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都三鷹市牟礼', '13', '13204', '1810002', '東京都', 'トウキョウト', '三鷹市', 'ミタカシ', '牟礼', 'ムレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都三鷹市北野', '13', '13204', '1810003', '東京都', 'トウキョウト', '三鷹市', 'ミタカシ', '北野', 'キタノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都三鷹市新川', '13', '13204', '1810004', '東京都', 'トウキョウト', '三鷹市', 'ミタカシ', '新川', 'シンカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都三鷹市中原', '13', '13204', '1810005', '東京都', 'トウキョウト', '三鷹市', 'ミタカシ', '中原', 'ナカハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都三鷹市井口', '13', '13204', '1810011', '東京都', 'トウキョウト', '三鷹市', 'ミタカシ', '井口', 'イグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都三鷹市上連雀', '13', '13204', '1810012', '東京都', 'トウキョウト', '三鷹市', 'ミタカシ', '上連雀', 'カミレンジャク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都三鷹市下連雀', '13', '13204', '1810013', '東京都', 'トウキョウト', '三鷹市', 'ミタカシ', '下連雀', 'シモレンジャク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都三鷹市野崎', '13', '13204', '1810014', '東京都', 'トウキョウト', '三鷹市', 'ミタカシ', '野崎', 'ノザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都三鷹市大沢', '13', '13204', '1810015', '東京都', 'トウキョウト', '三鷹市', 'ミタカシ', '大沢', 'オオサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都三鷹市深大寺', '13', '13204', '1810016', '東京都', 'トウキョウト', '三鷹市', 'ミタカシ', '深大寺', 'ジンダイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市岩城滝俣', '05', '05210', '0181211', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '岩城滝俣', 'イワキタキノマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市岩城福俣', '05', '05210', '0181212', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '岩城福俣', 'イワキフクノマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市岩城泉田', '05', '05210', '0181213', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '岩城泉田', 'イワキイズミタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市岩城富田', '05', '05210', '0181214', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '岩城富田', 'イワキトミタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市岩城赤平', '05', '05210', '0181215', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '岩城赤平', 'イワキアカヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市岩城亀田愛宕町', '05', '05210', '0181216', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '岩城亀田愛宕町', 'イワキカメダアタゴマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市岩城亀田亀田町', '05', '05210', '0181217', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '岩城亀田亀田町', 'イワキカメダカメダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市岩城亀田大町', '05', '05210', '0181218', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '岩城亀田大町', 'イワキカメダオオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市岩城亀田最上町', '05', '05210', '0181221', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '岩城亀田最上町', 'イワキカメダモガミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市岩城上蛇田', '05', '05210', '0181222', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '岩城上蛇田', 'イワキカミヘビタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市岩城下蛇田', '05', '05210', '0181223', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '岩城下蛇田', 'イワキシモヘビタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市岩城六呂田', '05', '05210', '0181224', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '岩城六呂田', 'イワキロクロダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市岩城上黒川', '05', '05210', '0181225', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '岩城上黒川', 'イワキカミクロカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市岩城下黒川', '05', '05210', '0181226', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '岩城下黒川', 'イワキシモクロカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市岩城内道川', '05', '05210', '0181301', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '岩城内道川', 'イワキウチミチカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市岩城勝手', '05', '05210', '0181302', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '岩城勝手', 'イワキカッテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市岩城君ケ野', '05', '05210', '0181303', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '岩城君ケ野', 'イワキキミガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市岩城道川', '05', '05210', '0181304', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '岩城道川', 'イワキミチカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県由利本荘市岩城二古', '05', '05210', '0181305', '秋田県', 'アキタケン', '由利本荘市', 'ユリホンジョウシ', '岩城二古', 'イワキフタゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県潟上市', '05', '05211', '0181400', '秋田県', 'アキタケン', '潟上市', 'カタガミシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('8842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県潟上市昭和大久保', '05', '05211', '0181401', '秋田県', 'アキタケン', '潟上市', 'カタガミシ', '昭和大久保', 'ショウワオオクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県潟上市昭和乱橋', '05', '05211', '0181402', '秋田県', 'アキタケン', '潟上市', 'カタガミシ', '昭和乱橋', 'ショウワミダレバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県潟上市昭和八丁目', '05', '05211', '0181403', '秋田県', 'アキタケン', '潟上市', 'カタガミシ', '昭和八丁目', 'ショウワハッチョウメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県潟上市昭和豊川上虻川', '05', '05211', '0181411', '秋田県', 'アキタケン', '潟上市', 'カタガミシ', '昭和豊川上虻川', 'ショウワトヨカワカミアブカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県潟上市昭和豊川岡井戸', '05', '05211', '0181412', '秋田県', 'アキタケン', '潟上市', 'カタガミシ', '昭和豊川岡井戸', 'ショウワトヨカワオカイド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県潟上市昭和豊川船橋', '05', '05211', '0181413', '秋田県', 'アキタケン', '潟上市', 'カタガミシ', '昭和豊川船橋', 'ショウワトヨカワフナバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県潟上市昭和豊川槻木', '05', '05211', '0181414', '秋田県', 'アキタケン', '潟上市', 'カタガミシ', '昭和豊川槻木', 'ショウワトヨカワツキノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県潟上市昭和豊川竜毛', '05', '05211', '0181415', '秋田県', 'アキタケン', '潟上市', 'カタガミシ', '昭和豊川竜毛', 'ショウワトヨカワリュウゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県潟上市昭和豊川山田', '05', '05211', '0181416', '秋田県', 'アキタケン', '潟上市', 'カタガミシ', '昭和豊川山田', 'ショウワトヨカワヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県南秋田郡井川町', '05', '05366', '0181500', '秋田県', 'アキタケン', '南秋田郡井川町', 'ミナミアキタグンイカワマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('8852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県潟上市飯田川金山', '05', '05211', '0181501', '秋田県', 'アキタケン', '潟上市', 'カタガミシ', '飯田川金山', 'イイタガワカネヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県潟上市飯田川下虻川', '05', '05211', '0181502', '秋田県', 'アキタケン', '潟上市', 'カタガミシ', '飯田川下虻川', 'イイタガワシモアブカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県潟上市飯田川和田妹川', '05', '05211', '0181503', '秋田県', 'アキタケン', '潟上市', 'カタガミシ', '飯田川和田妹川', 'イイタガワワダイモカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県潟上市飯田川飯塚', '05', '05211', '0181504', '秋田県', 'アキタケン', '潟上市', 'カタガミシ', '飯田川飯塚', 'イイタガワイイヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県南秋田郡井川町今戸', '05', '05366', '0181511', '秋田県', 'アキタケン', '南秋田郡井川町', 'ミナミアキタグンイカワマチ', '今戸', 'イマド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県南秋田郡井川町北川尻', '05', '05366', '0181512', '秋田県', 'アキタケン', '南秋田郡井川町', 'ミナミアキタグンイカワマチ', '北川尻', 'キタカワシリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県南秋田郡井川町黒坪', '05', '05366', '0181513', '秋田県', 'アキタケン', '南秋田郡井川町', 'ミナミアキタグンイカワマチ', '黒坪', 'クロツボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県南秋田郡井川町宇治木', '05', '05366', '0181514', '秋田県', 'アキタケン', '南秋田郡井川町', 'ミナミアキタグンイカワマチ', '宇治木', 'ウジキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県南秋田郡井川町小竹花', '05', '05366', '0181515', '秋田県', 'アキタケン', '南秋田郡井川町', 'ミナミアキタグンイカワマチ', '小竹花', 'コダケハナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県南秋田郡井川町浜井川', '05', '05366', '0181516', '秋田県', 'アキタケン', '南秋田郡井川町', 'ミナミアキタグンイカワマチ', '浜井川', 'ハマイカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県南秋田郡井川町八田大倉', '05', '05366', '0181521', '秋田県', 'アキタケン', '南秋田郡井川町', 'ミナミアキタグンイカワマチ', '八田大倉', 'ハッタオオクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県南秋田郡井川町保野子', '05', '05366', '0181522', '秋田県', 'アキタケン', '南秋田郡井川町', 'ミナミアキタグンイカワマチ', '保野子', 'ホノコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県南秋田郡井川町坂本', '05', '05366', '0181523', '秋田県', 'アキタケン', '南秋田郡井川町', 'ミナミアキタグンイカワマチ', '坂本', 'サカモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県南秋田郡井川町大麦', '05', '05366', '0181524', '秋田県', 'アキタケン', '南秋田郡井川町', 'ミナミアキタグンイカワマチ', '大麦', 'オオムギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県南秋田郡井川町赤沢', '05', '05366', '0181525', '秋田県', 'アキタケン', '南秋田郡井川町', 'ミナミアキタグンイカワマチ', '赤沢', 'アカサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県南秋田郡井川町寺沢', '05', '05366', '0181526', '秋田県', 'アキタケン', '南秋田郡井川町', 'ミナミアキタグンイカワマチ', '寺沢', 'テラサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県南秋田郡井川町井内', '05', '05366', '0181527', '秋田県', 'アキタケン', '南秋田郡井川町', 'ミナミアキタグンイカワマチ', '井内', 'イナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県南秋田郡井川町葹田', '05', '05366', '0181528', '秋田県', 'アキタケン', '南秋田郡井川町', 'ミナミアキタグンイカワマチ', '葹田', 'ナモミダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県南秋田郡八郎潟町', '05', '05363', '0181600', '秋田県', 'アキタケン', '南秋田郡八郎潟町', 'ミナミアキタグンハチロウガタマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('8873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県南秋田郡八郎潟町真坂', '05', '05363', '0181601', '秋田県', 'アキタケン', '南秋田郡八郎潟町', 'ミナミアキタグンハチロウガタマチ', '真坂', 'マサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県南秋田郡八郎潟町浦大町', '05', '05363', '0181602', '秋田県', 'アキタケン', '南秋田郡八郎潟町', 'ミナミアキタグンハチロウガタマチ', '浦大町', 'ウラオオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県南秋田郡八郎潟町小池', '05', '05363', '0181603', '秋田県', 'アキタケン', '南秋田郡八郎潟町', 'ミナミアキタグンハチロウガタマチ', '小池', 'コイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県南秋田郡八郎潟町野田', '05', '05363', '0181604', '秋田県', 'アキタケン', '南秋田郡八郎潟町', 'ミナミアキタグンハチロウガタマチ', '野田', 'ノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県南秋田郡八郎潟町川崎', '05', '05363', '0181605', '秋田県', 'アキタケン', '南秋田郡八郎潟町', 'ミナミアキタグンハチロウガタマチ', '川崎', 'カワサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県南秋田郡八郎潟町夜叉袋', '05', '05363', '0181606', '秋田県', 'アキタケン', '南秋田郡八郎潟町', 'ミナミアキタグンハチロウガタマチ', '夜叉袋', 'ヤシャフクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県南秋田郡八郎潟町上沖谷地', '05', '05363', '0181611', '秋田県', 'アキタケン', '南秋田郡八郎潟町', 'ミナミアキタグンハチロウガタマチ', '上沖谷地', 'カミオキヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県南秋田郡八郎潟町昼根下', '05', '05363', '0181612', '秋田県', 'アキタケン', '南秋田郡八郎潟町', 'ミナミアキタグンハチロウガタマチ', '昼根下', 'ヒルネシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県南秋田郡八郎潟町上昼根', '05', '05363', '0181613', '秋田県', 'アキタケン', '南秋田郡八郎潟町', 'ミナミアキタグンハチロウガタマチ', '上昼根', 'カミヒルネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県南秋田郡八郎潟町中田', '05', '05363', '0181614', '秋田県', 'アキタケン', '南秋田郡八郎潟町', 'ミナミアキタグンハチロウガタマチ', '中田', 'ナカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県南秋田郡八郎潟町蒲沼', '05', '05363', '0181615', '秋田県', 'アキタケン', '南秋田郡八郎潟町', 'ミナミアキタグンハチロウガタマチ', '蒲沼', 'ガマヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県南秋田郡八郎潟町大道', '05', '05363', '0181616', '秋田県', 'アキタケン', '南秋田郡八郎潟町', 'ミナミアキタグンハチロウガタマチ', '大道', 'オオミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県南秋田郡八郎潟町イカリ', '05', '05363', '0181617', '秋田県', 'アキタケン', '南秋田郡八郎潟町', 'ミナミアキタグンハチロウガタマチ', 'イカリ', 'イカリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県南秋田郡八郎潟町川口', '05', '05363', '0181618', '秋田県', 'アキタケン', '南秋田郡八郎潟町', 'ミナミアキタグンハチロウガタマチ', '川口', 'カワグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県南秋田郡八郎潟町家の後', '05', '05363', '0181621', '秋田県', 'アキタケン', '南秋田郡八郎潟町', 'ミナミアキタグンハチロウガタマチ', '家の後', 'イエノウシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県南秋田郡八郎潟町一日市', '05', '05363', '0181622', '秋田県', 'アキタケン', '南秋田郡八郎潟町', 'ミナミアキタグンハチロウガタマチ', '一日市', 'ヒトイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県南秋田郡八郎潟町下川原', '05', '05363', '0181623', '秋田県', 'アキタケン', '南秋田郡八郎潟町', 'ミナミアキタグンハチロウガタマチ', '下川原', 'シモカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県南秋田郡八郎潟町中久保', '05', '05363', '0181624', '秋田県', 'アキタケン', '南秋田郡八郎潟町', 'ミナミアキタグンハチロウガタマチ', '中久保', 'ナカクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県南秋田郡八郎潟町久保見', '05', '05363', '0181625', '秋田県', 'アキタケン', '南秋田郡八郎潟町', 'ミナミアキタグンハチロウガタマチ', '久保見', 'クボミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県南秋田郡八郎潟町細川', '05', '05363', '0181626', '秋田県', 'アキタケン', '南秋田郡八郎潟町', 'ミナミアキタグンハチロウガタマチ', '細川', 'ホソカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県南秋田郡八郎潟町押切', '05', '05363', '0181627', '秋田県', 'アキタケン', '南秋田郡八郎潟町', 'ミナミアキタグンハチロウガタマチ', '押切', 'オシキリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県南秋田郡八郎潟町島ノ内', '05', '05363', '0181628', '秋田県', 'アキタケン', '南秋田郡八郎潟町', 'ミナミアキタグンハチロウガタマチ', '島ノ内', 'シマノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県南秋田郡八郎潟町中嶋', '05', '05363', '0181629', '秋田県', 'アキタケン', '南秋田郡八郎潟町', 'ミナミアキタグンハチロウガタマチ', '中嶋', 'ナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県南秋田郡八郎潟町八幡沼', '05', '05363', '0181631', '秋田県', 'アキタケン', '南秋田郡八郎潟町', 'ミナミアキタグンハチロウガタマチ', '八幡沼', 'ハチマヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県南秋田郡八郎潟町長沼', '05', '05363', '0181632', '秋田県', 'アキタケン', '南秋田郡八郎潟町', 'ミナミアキタグンハチロウガタマチ', '長沼', 'ナガヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県南秋田郡八郎潟町中谷地', '05', '05363', '0181633', '秋田県', 'アキタケン', '南秋田郡八郎潟町', 'ミナミアキタグンハチロウガタマチ', '中谷地', 'ナカヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県南秋田郡八郎潟町軒嶋', '05', '05363', '0181634', '秋田県', 'アキタケン', '南秋田郡八郎潟町', 'ミナミアキタグンハチロウガタマチ', '軒嶋', 'ノキシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県南秋田郡八郎潟町洲先', '05', '05363', '0181635', '秋田県', 'アキタケン', '南秋田郡八郎潟町', 'ミナミアキタグンハチロウガタマチ', '洲先', 'スサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県南秋田郡五城目町', '05', '05361', '0181700', '秋田県', 'アキタケン', '南秋田郡五城目町', 'ミナミアキタグンゴジョウメマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('8903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県南秋田郡五城目町兎品沢', '05', '05361', '0181701', '秋田県', 'アキタケン', '南秋田郡五城目町', 'ミナミアキタグンゴジョウメマチ', '兎品沢', 'トヒンザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県南秋田郡五城目町杉ケ崎', '05', '05361', '0181702', '秋田県', 'アキタケン', '南秋田郡五城目町', 'ミナミアキタグンゴジョウメマチ', '杉ケ崎', 'スギガサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県南秋田郡五城目町羽黒前', '05', '05361', '0181703', '秋田県', 'アキタケン', '南秋田郡五城目町', 'ミナミアキタグンゴジョウメマチ', '羽黒前', 'ハグロマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県南秋田郡五城目町石田六ケ村堰添', '05', '05361', '0181704', '秋田県', 'アキタケン', '南秋田郡五城目町', 'ミナミアキタグンゴジョウメマチ', '石田六ケ村堰添', 'イシダロッカソンセキゾイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県南秋田郡五城目町上町', '05', '05361', '0181705', '秋田県', 'アキタケン', '南秋田郡五城目町', 'ミナミアキタグンゴジョウメマチ', '上町', 'ウワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県南秋田郡五城目町下タ町', '05', '05361', '0181706', '秋田県', 'アキタケン', '南秋田郡五城目町', 'ミナミアキタグンゴジョウメマチ', '下タ町', 'シタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県南秋田郡五城目町高崎', '05', '05361', '0181711', '秋田県', 'アキタケン', '南秋田郡五城目町', 'ミナミアキタグンゴジョウメマチ', '高崎', 'タカサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県南秋田郡五城目町久保', '05', '05361', '0181712', '秋田県', 'アキタケン', '南秋田郡五城目町', 'ミナミアキタグンゴジョウメマチ', '久保', 'クボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県南秋田郡五城目町馬場目', '05', '05361', '0181713', '秋田県', 'アキタケン', '南秋田郡五城目町', 'ミナミアキタグンゴジョウメマチ', '馬場目', 'ババメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県南秋田郡五城目町舘越', '05', '05361', '0181714', '秋田県', 'アキタケン', '南秋田郡五城目町', 'ミナミアキタグンゴジョウメマチ', '舘越', 'タテゴシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県南秋田郡五城目町七倉', '05', '05361', '0181721', '秋田県', 'アキタケン', '南秋田郡五城目町', 'ミナミアキタグンゴジョウメマチ', '七倉', 'ナナクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県南秋田郡五城目町鵜ノ木', '05', '05361', '0181722', '秋田県', 'アキタケン', '南秋田郡五城目町', 'ミナミアキタグンゴジョウメマチ', '鵜ノ木', 'ウノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県南秋田郡五城目町上樋口', '05', '05361', '0181723', '秋田県', 'アキタケン', '南秋田郡五城目町', 'ミナミアキタグンゴジョウメマチ', '上樋口', 'カミヒグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県南秋田郡五城目町東磯ノ目', '05', '05361', '0181724', '秋田県', 'アキタケン', '南秋田郡五城目町', 'ミナミアキタグンゴジョウメマチ', '東磯ノ目', 'ヒガシイソノメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県南秋田郡五城目町西磯ノ目', '05', '05361', '0181725', '秋田県', 'アキタケン', '南秋田郡五城目町', 'ミナミアキタグンゴジョウメマチ', '西磯ノ目', 'ニシイソノメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県南秋田郡五城目町大川石崎', '05', '05361', '0181731', '秋田県', 'アキタケン', '南秋田郡五城目町', 'ミナミアキタグンゴジョウメマチ', '大川石崎', 'オオカワイシザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県南秋田郡五城目町大川西野', '05', '05361', '0181732', '秋田県', 'アキタケン', '南秋田郡五城目町', 'ミナミアキタグンゴジョウメマチ', '大川西野', 'オオカワニシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県南秋田郡五城目町大川谷地中', '05', '05361', '0181733', '秋田県', 'アキタケン', '南秋田郡五城目町', 'ミナミアキタグンゴジョウメマチ', '大川谷地中', 'オオカワヤチナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県南秋田郡五城目町大川大川', '05', '05361', '0181734', '秋田県', 'アキタケン', '南秋田郡五城目町', 'ミナミアキタグンゴジョウメマチ', '大川大川', 'オオカワオオカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県南秋田郡五城目町大川下樋口', '05', '05361', '0181735', '秋田県', 'アキタケン', '南秋田郡五城目町', 'ミナミアキタグンゴジョウメマチ', '大川下樋口', 'オオカワシモトヨグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県南秋田郡五城目町浦大町', '05', '05361', '0181741', '秋田県', 'アキタケン', '南秋田郡五城目町', 'ミナミアキタグンゴジョウメマチ', '浦大町', 'ウラオオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県南秋田郡五城目町浦横町', '05', '05361', '0181742', '秋田県', 'アキタケン', '南秋田郡五城目町', 'ミナミアキタグンゴジョウメマチ', '浦横町', 'ウラヨコマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県南秋田郡五城目町稲荷前', '05', '05361', '0181743', '秋田県', 'アキタケン', '南秋田郡五城目町', 'ミナミアキタグンゴジョウメマチ', '稲荷前', 'イナリマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県南秋田郡五城目町神明前', '05', '05361', '0181744', '秋田県', 'アキタケン', '南秋田郡五城目町', 'ミナミアキタグンゴジョウメマチ', '神明前', 'シンメイマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県南秋田郡五城目町川崎', '05', '05361', '0181745', '秋田県', 'アキタケン', '南秋田郡五城目町', 'ミナミアキタグンゴジョウメマチ', '川崎', 'カワサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県南秋田郡五城目町小池', '05', '05361', '0181746', '秋田県', 'アキタケン', '南秋田郡五城目町', 'ミナミアキタグンゴジョウメマチ', '小池', 'コイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県南秋田郡五城目町野田', '05', '05361', '0181747', '秋田県', 'アキタケン', '南秋田郡五城目町', 'ミナミアキタグンゴジョウメマチ', '野田', 'ノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県南秋田郡五城目町内川浅見内', '05', '05361', '0181851', '秋田県', 'アキタケン', '南秋田郡五城目町', 'ミナミアキタグンゴジョウメマチ', '内川浅見内', 'ウチカワアサミナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県南秋田郡五城目町内川湯ノ又', '05', '05361', '0181852', '秋田県', 'アキタケン', '南秋田郡五城目町', 'ミナミアキタグンゴジョウメマチ', '内川湯ノ又', 'ウチカワユノマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県南秋田郡五城目町富津内中津又', '05', '05361', '0181853', '秋田県', 'アキタケン', '南秋田郡五城目町', 'ミナミアキタグンゴジョウメマチ', '富津内中津又', 'フツナイナカツマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県南秋田郡五城目町内川黒土', '05', '05361', '0181854', '秋田県', 'アキタケン', '南秋田郡五城目町', 'ミナミアキタグンゴジョウメマチ', '内川黒土', 'ウチカワクロツチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県南秋田郡五城目町富津内富田', '05', '05361', '0181855', '秋田県', 'アキタケン', '南秋田郡五城目町', 'ミナミアキタグンゴジョウメマチ', '富津内富田', 'フツナイトミタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県南秋田郡五城目町富津内下山内', '05', '05361', '0181856', '秋田県', 'アキタケン', '南秋田郡五城目町', 'ミナミアキタグンゴジョウメマチ', '富津内下山内', 'フツナイシモサンナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県南秋田郡五城目町内川小倉', '05', '05361', '0181857', '秋田県', 'アキタケン', '南秋田郡五城目町', 'ミナミアキタグンゴジョウメマチ', '内川小倉', 'ウチカワオグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都調布市', '13', '13208', '1820000', '東京都', 'トウキョウト', '調布市', 'チョウフシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('8970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都調布市緑ケ丘', '13', '13208', '1820001', '東京都', 'トウキョウト', '調布市', 'チョウフシ', '緑ケ丘', 'ミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都調布市仙川町', '13', '13208', '1820002', '東京都', 'トウキョウト', '調布市', 'チョウフシ', '仙川町', 'センガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都調布市若葉町', '13', '13208', '1820003', '東京都', 'トウキョウト', '調布市', 'チョウフシ', '若葉町', 'ワカバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都調布市入間町', '13', '13208', '1820004', '東京都', 'トウキョウト', '調布市', 'チョウフシ', '入間町', 'イリマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都調布市東つつじケ丘', '13', '13208', '1820005', '東京都', 'トウキョウト', '調布市', 'チョウフシ', '東つつじケ丘', 'ヒガシツツジガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都調布市西つつじケ丘', '13', '13208', '1820006', '東京都', 'トウキョウト', '調布市', 'チョウフシ', '西つつじケ丘', 'ニシツツジガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都調布市菊野台', '13', '13208', '1820007', '東京都', 'トウキョウト', '調布市', 'チョウフシ', '菊野台', 'キクノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都調布市深大寺北町', '13', '13208', '1820011', '東京都', 'トウキョウト', '調布市', 'チョウフシ', '深大寺北町', 'ジンダイジキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都調布市深大寺東町', '13', '13208', '1820012', '東京都', 'トウキョウト', '調布市', 'チョウフシ', '深大寺東町', 'ジンダイジヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都調布市深大寺南町', '13', '13208', '1820013', '東京都', 'トウキョウト', '調布市', 'チョウフシ', '深大寺南町', 'ジンダイジミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都調布市柴崎', '13', '13208', '1820014', '東京都', 'トウキョウト', '調布市', 'チョウフシ', '柴崎', 'シバサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都調布市八雲台', '13', '13208', '1820015', '東京都', 'トウキョウト', '調布市', 'チョウフシ', '八雲台', 'ヤグモダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都調布市佐須町', '13', '13208', '1820016', '東京都', 'トウキョウト', '調布市', 'チョウフシ', '佐須町', 'サズマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都調布市深大寺元町', '13', '13208', '1820017', '東京都', 'トウキョウト', '調布市', 'チョウフシ', '深大寺元町', 'ジンダイジモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都調布市調布ケ丘', '13', '13208', '1820021', '東京都', 'トウキョウト', '調布市', 'チョウフシ', '調布ケ丘', 'チョウフガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都調布市国領町', '13', '13208', '1820022', '東京都', 'トウキョウト', '調布市', 'チョウフシ', '国領町', 'コクリョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都調布市染地', '13', '13208', '1820023', '東京都', 'トウキョウト', '調布市', 'チョウフシ', '染地', 'ソメチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都調布市布田', '13', '13208', '1820024', '東京都', 'トウキョウト', '調布市', 'チョウフシ', '布田', 'フダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都調布市多摩川', '13', '13208', '1820025', '東京都', 'トウキョウト', '調布市', 'チョウフシ', '多摩川', 'タマガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都調布市小島町', '13', '13208', '1820026', '東京都', 'トウキョウト', '調布市', 'チョウフシ', '小島町', 'コジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都調布市野水', '13', '13208', '1820031', '東京都', 'トウキョウト', '調布市', 'チョウフシ', '野水', 'ノミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都調布市西町', '13', '13208', '1820032', '東京都', 'トウキョウト', '調布市', 'チョウフシ', '西町', 'ニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都調布市富士見町', '13', '13208', '1820033', '東京都', 'トウキョウト', '調布市', 'チョウフシ', '富士見町', 'フジミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都調布市下石原', '13', '13208', '1820034', '東京都', 'トウキョウト', '調布市', 'チョウフシ', '下石原', 'シモイシワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都調布市上石原', '13', '13208', '1820035', '東京都', 'トウキョウト', '調布市', 'チョウフシ', '上石原', 'カミイシワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都調布市飛田給', '13', '13208', '1820036', '東京都', 'トウキョウト', '調布市', 'チョウフシ', '飛田給', 'トビタキュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県山本郡三種町上岩川', '05', '05348', '0182101', '秋田県', 'アキタケン', '山本郡三種町', 'ヤマモトグンミタネチョウ', '上岩川', 'カミイワカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県山本郡三種町天瀬川', '05', '05348', '0182102', '秋田県', 'アキタケン', '山本郡三種町', 'ヤマモトグンミタネチョウ', '天瀬川', 'アマセガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県山本郡三種町鯉川', '05', '05348', '0182103', '秋田県', 'アキタケン', '山本郡三種町', 'ヤマモトグンミタネチョウ', '鯉川', 'コイカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('8999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県山本郡三種町鹿渡', '05', '05348', '0182104', '秋田県', 'アキタケン', '山本郡三種町', 'ヤマモトグンミタネチョウ', '鹿渡', 'カド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県山本郡三種町志戸橋', '05', '05348', '0182301', '秋田県', 'アキタケン', '山本郡三種町', 'ヤマモトグンミタネチョウ', '志戸橋', 'シトバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県山本郡三種町下岩川', '05', '05348', '0182302', '秋田県', 'アキタケン', '山本郡三種町', 'ヤマモトグンミタネチョウ', '下岩川', 'シモイワカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県山本郡三種町森岳', '05', '05348', '0182303', '秋田県', 'アキタケン', '山本郡三種町', 'ヤマモトグンミタネチョウ', '森岳', 'モリタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県山本郡三種町豊岡金田', '05', '05348', '0182304', '秋田県', 'アキタケン', '山本郡三種町', 'ヤマモトグンミタネチョウ', '豊岡金田', 'トヨオカキンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県山本郡三種町外岡', '05', '05348', '0182305', '秋田県', 'アキタケン', '山本郡三種町', 'ヤマモトグンミタネチョウ', '外岡', 'ソトオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県山本郡三種町', '05', '05348', '0182400', '秋田県', 'アキタケン', '山本郡三種町', 'ヤマモトグンミタネチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('9006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県山本郡三種町鵜川', '05', '05348', '0182401', '秋田県', 'アキタケン', '山本郡三種町', 'ヤマモトグンミタネチョウ', '鵜川', 'ウカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県山本郡三種町川尻', '05', '05348', '0182402', '秋田県', 'アキタケン', '山本郡三種町', 'ヤマモトグンミタネチョウ', '川尻', 'カワシリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県山本郡三種町久米岡新田', '05', '05348', '0182403', '秋田県', 'アキタケン', '山本郡三種町', 'ヤマモトグンミタネチョウ', '久米岡新田', 'クメオカシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県山本郡三種町富岡新田', '05', '05348', '0182404', '秋田県', 'アキタケン', '山本郡三種町', 'ヤマモトグンミタネチョウ', '富岡新田', 'トミオカシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県山本郡三種町芦崎', '05', '05348', '0182405', '秋田県', 'アキタケン', '山本郡三種町', 'ヤマモトグンミタネチョウ', '芦崎', 'アシザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県山本郡三種町大口', '05', '05348', '0182406', '秋田県', 'アキタケン', '山本郡三種町', 'ヤマモトグンミタネチョウ', '大口', 'オオクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県山本郡三種町浜田', '05', '05348', '0182407', '秋田県', 'アキタケン', '山本郡三種町', 'ヤマモトグンミタネチョウ', '浜田', 'ハマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県山本郡八峰町', '05', '05349', '0182500', '秋田県', 'アキタケン', '山本郡八峰町', 'ヤマモトグンハッポウチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('9015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県山本郡八峰町峰浜水沢', '05', '05349', '0182501', '秋田県', 'アキタケン', '山本郡八峰町', 'ヤマモトグンハッポウチョウ', '峰浜水沢', 'ミネハマミズサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県山本郡八峰町峰浜目名潟', '05', '05349', '0182502', '秋田県', 'アキタケン', '山本郡八峰町', 'ヤマモトグンハッポウチョウ', '峰浜目名潟', 'ミネハマメナガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県山本郡八峰町峰浜塙', '05', '05349', '0182503', '秋田県', 'アキタケン', '山本郡八峰町', 'ヤマモトグンハッポウチョウ', '峰浜塙', 'ミネハマハナワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県山本郡八峰町峰浜石川', '05', '05349', '0182504', '秋田県', 'アキタケン', '山本郡八峰町', 'ヤマモトグンハッポウチョウ', '峰浜石川', 'ミネハマイシカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県山本郡八峰町峰浜内荒巻', '05', '05349', '0182505', '秋田県', 'アキタケン', '山本郡八峰町', 'ヤマモトグンハッポウチョウ', '峰浜内荒巻', 'ミネハマウチアラマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県山本郡八峰町峰浜小手萩', '05', '05349', '0182506', '秋田県', 'アキタケン', '山本郡八峰町', 'ヤマモトグンハッポウチョウ', '峰浜小手萩', 'ミネハマコテハギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県山本郡八峰町峰浜田中', '05', '05349', '0182507', '秋田県', 'アキタケン', '山本郡八峰町', 'ヤマモトグンハッポウチョウ', '峰浜田中', 'ミネハマタナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県山本郡八峰町峰浜坂形', '05', '05349', '0182508', '秋田県', 'アキタケン', '山本郡八峰町', 'ヤマモトグンハッポウチョウ', '峰浜坂形', 'ミネハマサカガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県山本郡八峰町峰浜沼田', '05', '05349', '0182509', '秋田県', 'アキタケン', '山本郡八峰町', 'ヤマモトグンハッポウチョウ', '峰浜沼田', 'ミネハマヌマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県山本郡八峰町峰浜高野々', '05', '05349', '0182511', '秋田県', 'アキタケン', '山本郡八峰町', 'ヤマモトグンハッポウチョウ', '峰浜高野々', 'ミネハマコウヤノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県山本郡八峰町峰浜畑谷', '05', '05349', '0182512', '秋田県', 'アキタケン', '山本郡八峰町', 'ヤマモトグンハッポウチョウ', '峰浜畑谷', 'ミネハマハタヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県山本郡八峰町八森乙の水', '05', '05349', '0182601', '秋田県', 'アキタケン', '山本郡八峰町', 'ヤマモトグンハッポウチョウ', '八森乙の水', 'ハチモリオトノミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県山本郡八峰町八森チゴキ', '05', '05349', '0182602', '秋田県', 'アキタケン', '山本郡八峰町', 'ヤマモトグンハッポウチョウ', '八森チゴキ', 'ハチモリチゴキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県山本郡八峰町八森物見', '05', '05349', '0182603', '秋田県', 'アキタケン', '山本郡八峰町', 'ヤマモトグンハッポウチョウ', '八森物見', 'ハチモリモノミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県山本郡八峰町八森和田表', '05', '05349', '0182604', '秋田県', 'アキタケン', '山本郡八峰町', 'ヤマモトグンハッポウチョウ', '八森和田表', 'ハチモリワダオモテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県山本郡八峰町八森岩館塚の台', '05', '05349', '0182605', '秋田県', 'アキタケン', '山本郡八峰町', 'ヤマモトグンハッポウチョウ', '八森岩館塚の台', 'ハチモリイワダテツカノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県山本郡八峰町八森釜の上', '05', '05349', '0182606', '秋田県', 'アキタケン', '山本郡八峰町', 'ヤマモトグンハッポウチョウ', '八森釜の上', 'ハチモリカマノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県山本郡八峰町八森林の沢', '05', '05349', '0182607', '秋田県', 'アキタケン', '山本郡八峰町', 'ヤマモトグンハッポウチョウ', '八森林の沢', 'ハチモリハヤシノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県山本郡八峰町八森岩館向台', '05', '05349', '0182608', '秋田県', 'アキタケン', '山本郡八峰町', 'ヤマモトグンハッポウチョウ', '八森岩館向台', 'ハチモリイワダテムカイダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県山本郡八峰町八森門の沢', '05', '05349', '0182609', '秋田県', 'アキタケン', '山本郡八峰町', 'ヤマモトグンハッポウチョウ', '八森門の沢', 'ハチモリカドノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県山本郡八峰町八森岩館', '05', '05349', '0182611', '秋田県', 'アキタケン', '山本郡八峰町', 'ヤマモトグンハッポウチョウ', '八森岩館', 'ハチモリイワダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県山本郡八峰町八森ノケソリ', '05', '05349', '0182612', '秋田県', 'アキタケン', '山本郡八峰町', 'ヤマモトグンハッポウチョウ', '八森ノケソリ', 'ハチモリノケソリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県山本郡八峰町八森鉱山', '05', '05349', '0182613', '秋田県', 'アキタケン', '山本郡八峰町', 'ヤマモトグンハッポウチョウ', '八森鉱山', 'ハチモリコウザン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県山本郡八峰町八森小入川家の上', '05', '05349', '0182614', '秋田県', 'アキタケン', '山本郡八峰町', 'ヤマモトグンハッポウチョウ', '八森小入川家の上', 'ハチモリコイリカワイエノカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県山本郡八峰町八森伊勢鉢台', '05', '05349', '0182615', '秋田県', 'アキタケン', '山本郡八峰町', 'ヤマモトグンハッポウチョウ', '八森伊勢鉢台', 'ハチモリイセバチダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県山本郡八峰町八森三沢', '05', '05349', '0182616', '秋田県', 'アキタケン', '山本郡八峰町', 'ヤマモトグンハッポウチョウ', '八森三沢', 'ハチモリミサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県山本郡八峰町八森御所の台', '05', '05349', '0182617', '秋田県', 'アキタケン', '山本郡八峰町', 'ヤマモトグンハッポウチョウ', '八森御所の台', 'ハチモリゴショノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県山本郡八峰町八森木戸の沢', '05', '05349', '0182618', '秋田県', 'アキタケン', '山本郡八峰町', 'ヤマモトグンハッポウチョウ', '八森木戸の沢', 'ハチモリキドノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県山本郡八峰町八森長坂', '05', '05349', '0182619', '秋田県', 'アキタケン', '山本郡八峰町', 'ヤマモトグンハッポウチョウ', '八森長坂', 'ハチモリナガサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県山本郡八峰町八森茶の沢', '05', '05349', '0182621', '秋田県', 'アキタケン', '山本郡八峰町', 'ヤマモトグンハッポウチョウ', '八森茶の沢', 'ハチモリチャノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県山本郡八峰町八森家の向', '05', '05349', '0182622', '秋田県', 'アキタケン', '山本郡八峰町', 'ヤマモトグンハッポウチョウ', '八森家の向', 'ハチモリイエノムカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県山本郡八峰町八森滝ノ間', '05', '05349', '0182623', '秋田県', 'アキタケン', '山本郡八峰町', 'ヤマモトグンハッポウチョウ', '八森滝ノ間', 'ハチモリタキノマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県山本郡八峰町八森横間台', '05', '05349', '0182624', '秋田県', 'アキタケン', '山本郡八峰町', 'ヤマモトグンハッポウチョウ', '八森横間台', 'ハチモリヨコマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県山本郡八峰町八森山内台', '05', '05349', '0182625', '秋田県', 'アキタケン', '山本郡八峰町', 'ヤマモトグンハッポウチョウ', '八森山内台', 'ハチモリサンナイダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県山本郡八峰町八森横間', '05', '05349', '0182626', '秋田県', 'アキタケン', '山本郡八峰町', 'ヤマモトグンハッポウチョウ', '八森横間', 'ハチモリヨコマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県山本郡八峰町八森山内', '05', '05349', '0182627', '秋田県', 'アキタケン', '山本郡八峰町', 'ヤマモトグンハッポウチョウ', '八森山内', 'ハチモリサンナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県山本郡八峰町八森立石', '05', '05349', '0182628', '秋田県', 'アキタケン', '山本郡八峰町', 'ヤマモトグンハッポウチョウ', '八森立石', 'ハチモリタテイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県山本郡八峰町八森五輪台下段', '05', '05349', '0182631', '秋田県', 'アキタケン', '山本郡八峰町', 'ヤマモトグンハッポウチョウ', '八森五輪台下段', 'ハチモリゴリンダイゲダン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県山本郡八峰町八森三十釜', '05', '05349', '0182632', '秋田県', 'アキタケン', '山本郡八峰町', 'ヤマモトグンハッポウチョウ', '八森三十釜', 'ハチモリサンジュウガマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県山本郡八峰町八森五輪台上段', '05', '05349', '0182633', '秋田県', 'アキタケン', '山本郡八峰町', 'ヤマモトグンハッポウチョウ', '八森五輪台上段', 'ハチモリゴリンダイジョウダン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県山本郡八峰町八森滝の上', '05', '05349', '0182634', '秋田県', 'アキタケン', '山本郡八峰町', 'ヤマモトグンハッポウチョウ', '八森滝の上', 'ハチモリタキノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県山本郡八峰町八森下嘉治助台', '05', '05349', '0182635', '秋田県', 'アキタケン', '山本郡八峰町', 'ヤマモトグンハッポウチョウ', '八森下嘉治助台', 'ハチモリシモカジスケダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県山本郡八峰町八森上嘉治助台', '05', '05349', '0182636', '秋田県', 'アキタケン', '山本郡八峰町', 'ヤマモトグンハッポウチョウ', '八森上嘉治助台', 'ハチモリカミカジスケダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県山本郡八峰町八森家の後', '05', '05349', '0182637', '秋田県', 'アキタケン', '山本郡八峰町', 'ヤマモトグンハッポウチョウ', '八森家の後', 'ハチモリイエノウシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県山本郡八峰町八森茂浦', '05', '05349', '0182638', '秋田県', 'アキタケン', '山本郡八峰町', 'ヤマモトグンハッポウチョウ', '八森茂浦', 'ハチモリモウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県山本郡八峰町八森中浜', '05', '05349', '0182641', '秋田県', 'アキタケン', '山本郡八峰町', 'ヤマモトグンハッポウチョウ', '八森中浜', 'ハチモリナカハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県山本郡八峰町八森椿', '05', '05349', '0182642', '秋田県', 'アキタケン', '山本郡八峰町', 'ヤマモトグンハッポウチョウ', '八森椿', 'ハチモリツバキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県山本郡八峰町八森家の上', '05', '05349', '0182643', '秋田県', 'アキタケン', '山本郡八峰町', 'ヤマモトグンハッポウチョウ', '八森家の上', 'ハチモリイエノカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県山本郡八峰町八森椿台', '05', '05349', '0182644', '秋田県', 'アキタケン', '山本郡八峰町', 'ヤマモトグンハッポウチョウ', '八森椿台', 'ハチモリツバキダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県山本郡八峰町八森中嶋', '05', '05349', '0182645', '秋田県', 'アキタケン', '山本郡八峰町', 'ヤマモトグンハッポウチョウ', '八森中嶋', 'ハチモリナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県山本郡八峰町八森塚の台', '05', '05349', '0182646', '秋田県', 'アキタケン', '山本郡八峰町', 'ヤマモトグンハッポウチョウ', '八森塚の台', 'ハチモリツカノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県山本郡八峰町八森鹿の浦', '05', '05349', '0182647', '秋田県', 'アキタケン', '山本郡八峰町', 'ヤマモトグンハッポウチョウ', '八森鹿の浦', 'ハチモリカノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県山本郡八峰町八森泊台', '05', '05349', '0182648', '秋田県', 'アキタケン', '山本郡八峰町', 'ヤマモトグンハッポウチョウ', '八森泊台', 'ハチモリトマリダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県山本郡八峰町八森下館下', '05', '05349', '0182651', '秋田県', 'アキタケン', '山本郡八峰町', 'ヤマモトグンハッポウチョウ', '八森下館下', 'ハチモリシモタテシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県山本郡八峰町八森本館中台', '05', '05349', '0182652', '秋田県', 'アキタケン', '山本郡八峰町', 'ヤマモトグンハッポウチョウ', '八森本館中台', 'ハチモリモトダテナカダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県山本郡八峰町八森倉の沢', '05', '05349', '0182653', '秋田県', 'アキタケン', '山本郡八峰町', 'ヤマモトグンハッポウチョウ', '八森倉の沢', 'ハチモリクラノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県山本郡八峰町八森諸沢口', '05', '05349', '0182654', '秋田県', 'アキタケン', '山本郡八峰町', 'ヤマモトグンハッポウチョウ', '八森諸沢口', 'ハチモリモロサワグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県山本郡八峰町八森本館', '05', '05349', '0182655', '秋田県', 'アキタケン', '山本郡八峰町', 'ヤマモトグンハッポウチョウ', '八森本館', 'ハチモリモトダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県山本郡八峰町八森諸沢下脇', '05', '05349', '0182656', '秋田県', 'アキタケン', '山本郡八峰町', 'ヤマモトグンハッポウチョウ', '八森諸沢下脇', 'ハチモリモロサワシモワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県山本郡八峰町八森浜田', '05', '05349', '0182661', '秋田県', 'アキタケン', '山本郡八峰町', 'ヤマモトグンハッポウチョウ', '八森浜田', 'ハチモリハマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県山本郡八峰町八森新浜田', '05', '05349', '0182662', '秋田県', 'アキタケン', '山本郡八峰町', 'ヤマモトグンハッポウチョウ', '八森新浜田', 'ハチモリシンハマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県山本郡八峰町八森樋長', '05', '05349', '0182663', '秋田県', 'アキタケン', '山本郡八峰町', 'ヤマモトグンハッポウチョウ', '八森樋長', 'ハチモリトヨナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県山本郡八峰町八森古屋敷', '05', '05349', '0182664', '秋田県', 'アキタケン', '山本郡八峰町', 'ヤマモトグンハッポウチョウ', '八森古屋敷', 'ハチモリフルヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県山本郡八峰町八森寺の後川向', '05', '05349', '0182665', '秋田県', 'アキタケン', '山本郡八峰町', 'ヤマモトグンハッポウチョウ', '八森寺の後川向', 'ハチモリテラノウシロカワムカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県山本郡八峰町八森寺の後', '05', '05349', '0182666', '秋田県', 'アキタケン', '山本郡八峰町', 'ヤマモトグンハッポウチョウ', '八森寺の後', 'ハチモリテラノウシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県山本郡八峰町八森八森家後', '05', '05349', '0182667', '秋田県', 'アキタケン', '山本郡八峰町', 'ヤマモトグンハッポウチョウ', '八森八森家後', 'ハチモリハチモリイエウシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県山本郡八峰町八森湯の尻', '05', '05349', '0182671', '秋田県', 'アキタケン', '山本郡八峰町', 'ヤマモトグンハッポウチョウ', '八森湯の尻', 'ハチモリユノシリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県山本郡八峰町八森下家後', '05', '05349', '0182672', '秋田県', 'アキタケン', '山本郡八峰町', 'ヤマモトグンハッポウチョウ', '八森下家後', 'ハチモリシモイエウシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県山本郡八峰町八森中家後', '05', '05349', '0182673', '秋田県', 'アキタケン', '山本郡八峰町', 'ヤマモトグンハッポウチョウ', '八森中家後', 'ハチモリナカイエウシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県山本郡八峰町八森上家後', '05', '05349', '0182674', '秋田県', 'アキタケン', '山本郡八峰町', 'ヤマモトグンハッポウチョウ', '八森上家後', 'ハチモリカミイエウシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県山本郡八峰町八森篭田', '05', '05349', '0182675', '秋田県', 'アキタケン', '山本郡八峰町', 'ヤマモトグンハッポウチョウ', '八森篭田', 'ハチモリカゴタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県山本郡八峰町八森磯村', '05', '05349', '0182676', '秋田県', 'アキタケン', '山本郡八峰町', 'ヤマモトグンハッポウチョウ', '八森磯村', 'ハチモリイソムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県山本郡八峰町八森八森後', '05', '05349', '0182677', '秋田県', 'アキタケン', '山本郡八峰町', 'ヤマモトグンハッポウチョウ', '八森八森後', 'ハチモリハチモリウシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県山本郡八峰町八森八森', '05', '05349', '0182678', '秋田県', 'アキタケン', '山本郡八峰町', 'ヤマモトグンハッポウチョウ', '八森八森', 'ハチモリハチモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市常盤', '05', '05202', '0182801', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '常盤', 'トキワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市天内', '05', '05202', '0182802', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '天内', 'アマナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市外割田', '05', '05202', '0182803', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '外割田', 'トワリダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市槐', '05', '05202', '0182804', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '槐', 'サイカチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市轟', '05', '05202', '0182805', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '轟', 'トドロキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市久喜沢', '05', '05202', '0182806', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '久喜沢', 'クキサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市産物', '05', '05202', '0182811', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '産物', 'サンブツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市大曲', '05', '05202', '0182812', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '大曲', 'オオマガリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市上悪土', '05', '05202', '0182813', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '上悪土', 'カミアクド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市狐森', '05', '05202', '0182814', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '狐森', 'キツネモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市東面', '05', '05202', '0182815', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '東面', 'トウメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都府中市', '13', '13206', '1830000', '東京都', 'トウキョウト', '府中市', 'フチュウシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('9119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都府中市浅間町', '13', '13206', '1830001', '東京都', 'トウキョウト', '府中市', 'フチュウシ', '浅間町', 'センゲンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都府中市多磨町', '13', '13206', '1830002', '東京都', 'トウキョウト', '府中市', 'フチュウシ', '多磨町', 'タマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都府中市朝日町', '13', '13206', '1830003', '東京都', 'トウキョウト', '府中市', 'フチュウシ', '朝日町', 'アサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都府中市紅葉丘', '13', '13206', '1830004', '東京都', 'トウキョウト', '府中市', 'フチュウシ', '紅葉丘', 'モミジガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都府中市若松町', '13', '13206', '1830005', '東京都', 'トウキョウト', '府中市', 'フチュウシ', '若松町', 'ワカマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都府中市緑町', '13', '13206', '1830006', '東京都', 'トウキョウト', '府中市', 'フチュウシ', '緑町', 'ミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都府中市白糸台', '13', '13206', '1830011', '東京都', 'トウキョウト', '府中市', 'フチュウシ', '白糸台', 'シライトダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都府中市押立町', '13', '13206', '1830012', '東京都', 'トウキョウト', '府中市', 'フチュウシ', '押立町', 'オシタテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都府中市小柳町', '13', '13206', '1830013', '東京都', 'トウキョウト', '府中市', 'フチュウシ', '小柳町', 'コヤナギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都府中市是政', '13', '13206', '1830014', '東京都', 'トウキョウト', '府中市', 'フチュウシ', '是政', 'コレマサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都府中市清水が丘', '13', '13206', '1830015', '東京都', 'トウキョウト', '府中市', 'フチュウシ', '清水が丘', 'シミズガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都府中市八幡町', '13', '13206', '1830016', '東京都', 'トウキョウト', '府中市', 'フチュウシ', '八幡町', 'ハチマンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都府中市片町', '13', '13206', '1830021', '東京都', 'トウキョウト', '府中市', 'フチュウシ', '片町', 'カタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都府中市宮西町', '13', '13206', '1830022', '東京都', 'トウキョウト', '府中市', 'フチュウシ', '宮西町', 'ミヤニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都府中市宮町', '13', '13206', '1830023', '東京都', 'トウキョウト', '府中市', 'フチュウシ', '宮町', 'ミヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都府中市日吉町', '13', '13206', '1830024', '東京都', 'トウキョウト', '府中市', 'フチュウシ', '日吉町', 'ヒヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都府中市矢崎町', '13', '13206', '1830025', '東京都', 'トウキョウト', '府中市', 'フチュウシ', '矢崎町', 'ヤザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都府中市南町', '13', '13206', '1830026', '東京都', 'トウキョウト', '府中市', 'フチュウシ', '南町', 'ミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都府中市本町', '13', '13206', '1830027', '東京都', 'トウキョウト', '府中市', 'フチュウシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都府中市西府町', '13', '13206', '1830031', '東京都', 'トウキョウト', '府中市', 'フチュウシ', '西府町', 'ニシフチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都府中市本宿町', '13', '13206', '1830032', '東京都', 'トウキョウト', '府中市', 'フチュウシ', '本宿町', 'ホンシュクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都府中市分梅町', '13', '13206', '1830033', '東京都', 'トウキョウト', '府中市', 'フチュウシ', '分梅町', 'ブバイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都府中市住吉町', '13', '13206', '1830034', '東京都', 'トウキョウト', '府中市', 'フチュウシ', '住吉町', 'スミヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都府中市四谷', '13', '13206', '1830035', '東京都', 'トウキョウト', '府中市', 'フチュウシ', '四谷', 'ヨツヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都府中市日新町', '13', '13206', '1830036', '東京都', 'トウキョウト', '府中市', 'フチュウシ', '日新町', 'ニッシンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都府中市北山町', '13', '13206', '1830041', '東京都', 'トウキョウト', '府中市', 'フチュウシ', '北山町', 'キタヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都府中市武蔵台', '13', '13206', '1830042', '東京都', 'トウキョウト', '府中市', 'フチュウシ', '武蔵台', 'ムサシダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都府中市東芝町', '13', '13206', '1830043', '東京都', 'トウキョウト', '府中市', 'フチュウシ', '東芝町', 'トウシバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都府中市日鋼町', '13', '13206', '1830044', '東京都', 'トウキョウト', '府中市', 'フチュウシ', '日鋼町', 'ニッコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都府中市美好町', '13', '13206', '1830045', '東京都', 'トウキョウト', '府中市', 'フチュウシ', '美好町', 'ミヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都府中市西原町', '13', '13206', '1830046', '東京都', 'トウキョウト', '府中市', 'フチュウシ', '西原町', 'ニシハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都府中市栄町', '13', '13206', '1830051', '東京都', 'トウキョウト', '府中市', 'フチュウシ', '栄町', 'サカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都府中市新町', '13', '13206', '1830052', '東京都', 'トウキョウト', '府中市', 'フチュウシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都府中市天神町', '13', '13206', '1830053', '東京都', 'トウキョウト', '府中市', 'フチュウシ', '天神町', 'テンジンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都府中市幸町', '13', '13206', '1830054', '東京都', 'トウキョウト', '府中市', 'フチュウシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都府中市府中町', '13', '13206', '1830055', '東京都', 'トウキョウト', '府中市', 'フチュウシ', '府中町', 'フチュウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都府中市寿町', '13', '13206', '1830056', '東京都', 'トウキョウト', '府中市', 'フチュウシ', '寿町', 'コトブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都府中市晴見町', '13', '13206', '1830057', '東京都', 'トウキョウト', '府中市', 'フチュウシ', '晴見町', 'ハルミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市二ツ井町麻生', '05', '05202', '0183101', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '二ツ井町麻生', 'フタツイマチアソウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市二ツ井町小繋', '05', '05202', '0183102', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '二ツ井町小繋', 'フタツイマチコツナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市二ツ井町荷上場', '05', '05202', '0183103', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '二ツ井町荷上場', 'フタツイマチニアゲバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市二ツ井町沢口', '05', '05202', '0183104', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '二ツ井町沢口', 'フタツイマチサワグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市二ツ井町上山崎', '05', '05202', '0183105', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '二ツ井町上山崎', 'フタツイマチカミヤマザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市二ツ井町濁川', '05', '05202', '0183106', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '二ツ井町濁川', 'フタツイマチニゴリカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市二ツ井町苅又石', '05', '05202', '0183107', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '二ツ井町苅又石', 'フタツイマチカリマタイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市二ツ井町田代', '05', '05202', '0183111', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '二ツ井町田代', 'フタツイマチタシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市二ツ井町小掛', '05', '05202', '0183112', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '二ツ井町小掛', 'フタツイマチコガケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市二ツ井町仁鮒', '05', '05202', '0183113', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '二ツ井町仁鮒', 'フタツイマチニブナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市二ツ井町桜台', '05', '05202', '0183114', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '二ツ井町桜台', 'フタツイマチサクラダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市二ツ井町海道上', '05', '05202', '0183115', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '二ツ井町海道上', 'フタツイマチカイドウウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市二ツ井町家後', '05', '05202', '0183116', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '二ツ井町家後', 'フタツイマチイエウシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市二ツ井町塚台', '05', '05202', '0183117', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '二ツ井町塚台', 'フタツイマチツカノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市二ツ井町上台', '05', '05202', '0183118', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '二ツ井町上台', 'フタツイマチウワダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市二ツ井町薄井', '05', '05202', '0183119', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '二ツ井町薄井', 'フタツイマチウスイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市二ツ井町飛根富根', '05', '05202', '0183121', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '二ツ井町飛根', 'フタツイマチトブネ', null, null, '富根', 'トミネ');
INSERT INTO `ms_addresses` VALUES ('9174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市二ツ井町飛根', '05', '05202', '0183122', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '二ツ井町飛根', 'フタツイマチトブネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市二ツ井町駒形', '05', '05202', '0183123', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '二ツ井町駒形', 'フタツイマチコマガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市二ツ井町切石', '05', '05202', '0183124', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '二ツ井町切石', 'フタツイマチキリイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市二ツ井町茶屋下', '05', '05202', '0183125', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '二ツ井町茶屋下', 'フタツイマチチャヤシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市二ツ井町狐台', '05', '05202', '0183126', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '二ツ井町狐台', 'フタツイマチキツネダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市二ツ井町稗川原', '05', '05202', '0183127', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '二ツ井町稗川原', 'フタツイマチヒエカワハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市二ツ井町下稗柄', '05', '05202', '0183128', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '二ツ井町下稗柄', 'フタツイマチシモヒエガラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市二ツ井町稗柄', '05', '05202', '0183129', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '二ツ井町稗柄', 'フタツイマチヒエガラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市二ツ井町梅内', '05', '05202', '0183131', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '二ツ井町梅内', 'フタツイマチウメナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市二ツ井町種', '05', '05202', '0183132', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '二ツ井町種', 'フタツイマチタネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市二ツ井町種竹原', '05', '05202', '0183133', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '二ツ井町種', 'フタツイマチタネ', null, null, '竹原', 'タケハラ');
INSERT INTO `ms_addresses` VALUES ('9185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市二ツ井町高関', '05', '05202', '0183134', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '二ツ井町高関', 'フタツイマチタカセキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市二ツ井町山根', '05', '05202', '0183135', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '二ツ井町山根', 'フタツイマチヤマネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市二ツ井町五千苅', '05', '05202', '0183141', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '二ツ井町五千苅', 'フタツイマチゴセンガリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市二ツ井町上野', '05', '05202', '0183142', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '二ツ井町上野', 'フタツイマチウワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市二ツ井町太田面', '05', '05202', '0183143', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '二ツ井町太田面', 'フタツイマチオオタモテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市二ツ井町中坪', '05', '05202', '0183144', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '二ツ井町中坪', 'フタツイマチナカツボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市二ツ井町道上中坪', '05', '05202', '0183145', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '二ツ井町道上中坪', 'フタツイマチミチカミナカツボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市二ツ井町中坪道下', '05', '05202', '0183146', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '二ツ井町中坪道下', 'フタツイマチナカツボミチシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市二ツ井町小槻木', '05', '05202', '0183147', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '二ツ井町小槻木', 'フタツイマチコツキノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市二ツ井町槻ノ木', '05', '05202', '0183148', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '二ツ井町槻ノ木', 'フタツイマチツキノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市二ツ井町三千苅', '05', '05202', '0183151', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '二ツ井町三千苅', 'フタツイマチサンゼンガリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市二ツ井町下野家後', '05', '05202', '0183152', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '二ツ井町下野家後', 'フタツイマチシモノイエウシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市二ツ井町滑良子川端', '05', '05202', '0183153', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '二ツ井町滑良子川端', 'フタツイマチナメラコカワバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市二ツ井町町尻', '05', '05202', '0183154', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '二ツ井町町尻', 'フタツイマチマチジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市二ツ井町比井野', '05', '05202', '0183155', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '二ツ井町比井野', 'フタツイマチヒイノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市二ツ井町下野川端', '05', '05202', '0183156', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '二ツ井町下野川端', 'フタツイマチシモノカワバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県能代市二ツ井町下野', '05', '05202', '0183157', '秋田県', 'アキタケン', '能代市', 'ノシロシ', '二ツ井町下野', 'フタツイマチシモノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県山本郡藤里町', '05', '05346', '0183200', '秋田県', 'アキタケン', '山本郡藤里町', 'ヤマモトグンフジサトマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('9204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県山本郡藤里町藤琴', '05', '05346', '0183201', '秋田県', 'アキタケン', '山本郡藤里町', 'ヤマモトグンフジサトマチ', '藤琴', 'フジコト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県山本郡藤里町太良', '05', '05346', '0183202', '秋田県', 'アキタケン', '山本郡藤里町', 'ヤマモトグンフジサトマチ', '太良', 'ダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県山本郡藤里町大沢', '05', '05346', '0183203', '秋田県', 'アキタケン', '山本郡藤里町', 'ヤマモトグンフジサトマチ', '大沢', 'オオサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県山本郡藤里町矢坂', '05', '05346', '0183204', '秋田県', 'アキタケン', '山本郡藤里町', 'ヤマモトグンフジサトマチ', '矢坂', 'ヤサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県山本郡藤里町粕毛', '05', '05346', '0183205', '秋田県', 'アキタケン', '山本郡藤里町', 'ヤマモトグンフジサトマチ', '粕毛', 'カスゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県北秋田市', '05', '05213', '0183300', '秋田県', 'アキタケン', '北秋田市', 'キタアキタシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('9210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県北秋田市綴子', '05', '05213', '0183301', '秋田県', 'アキタケン', '北秋田市', 'キタアキタシ', '綴子', 'ツヅレコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県北秋田市栄', '05', '05213', '0183302', '秋田県', 'アキタケン', '北秋田市', 'キタアキタシ', '栄', 'サカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県北秋田市材木町', '05', '05213', '0183311', '秋田県', 'アキタケン', '北秋田市', 'キタアキタシ', '材木町', 'ザイモクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県北秋田市花園町', '05', '05213', '0183312', '秋田県', 'アキタケン', '北秋田市', 'キタアキタシ', '花園町', 'ハナゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県北秋田市旭町', '05', '05213', '0183313', '秋田県', 'アキタケン', '北秋田市', 'キタアキタシ', '旭町', 'アサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県北秋田市伊勢町', '05', '05213', '0183314', '秋田県', 'アキタケン', '北秋田市', 'キタアキタシ', '伊勢町', 'イセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県北秋田市宮前町', '05', '05213', '0183315', '秋田県', 'アキタケン', '北秋田市', 'キタアキタシ', '宮前町', 'ミヤマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県北秋田市東横町', '05', '05213', '0183316', '秋田県', 'アキタケン', '北秋田市', 'キタアキタシ', '東横町', 'ヒガシヨコマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県北秋田市松葉町', '05', '05213', '0183321', '秋田県', 'アキタケン', '北秋田市', 'キタアキタシ', '松葉町', 'マツバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県北秋田市住吉町', '05', '05213', '0183322', '秋田県', 'アキタケン', '北秋田市', 'キタアキタシ', '住吉町', 'スミヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県北秋田市米代町', '05', '05213', '0183323', '秋田県', 'アキタケン', '北秋田市', 'キタアキタシ', '米代町', 'ヨネシロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県北秋田市大町', '05', '05213', '0183324', '秋田県', 'アキタケン', '北秋田市', 'キタアキタシ', '大町', 'オオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県北秋田市元町', '05', '05213', '0183325', '秋田県', 'アキタケン', '北秋田市', 'キタアキタシ', '元町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県北秋田市鷹巣', '05', '05213', '0183331', '秋田県', 'アキタケン', '北秋田市', 'キタアキタシ', '鷹巣', 'タカノス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県北秋田市平崎上岱', '05', '05213', '0183332', '秋田県', 'アキタケン', '北秋田市', 'キタアキタシ', '平崎上岱', 'ヒラサキカミタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県北秋田市坊沢', '05', '05213', '0183333', '秋田県', 'アキタケン', '北秋田市', 'キタアキタシ', '坊沢', 'ボウザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県北秋田市黒沢', '05', '05213', '0183341', '秋田県', 'アキタケン', '北秋田市', 'キタアキタシ', '黒沢', 'クロサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県北秋田市前山', '05', '05213', '0183342', '秋田県', 'アキタケン', '北秋田市', 'キタアキタシ', '前山', 'マエヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県北秋田市今泉', '05', '05213', '0183343', '秋田県', 'アキタケン', '北秋田市', 'キタアキタシ', '今泉', 'イマイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県北秋田市小森', '05', '05213', '0183451', '秋田県', 'アキタケン', '北秋田市', 'キタアキタシ', '小森', 'コモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県北秋田市七日市', '05', '05213', '0183452', '秋田県', 'アキタケン', '北秋田市', 'キタアキタシ', '七日市', 'ナヌカイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県北秋田市中屋敷', '05', '05213', '0183453', '秋田県', 'アキタケン', '北秋田市', 'キタアキタシ', '中屋敷', 'ナカヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県北秋田市脇神', '05', '05213', '0183454', '秋田県', 'アキタケン', '北秋田市', 'キタアキタシ', '脇神', 'ワキガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市岩瀬', '05', '05204', '0183501', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '岩瀬', 'イワセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市山田', '05', '05204', '0183502', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '山田', 'ヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市外川原', '05', '05204', '0183503', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '外川原', 'ソトカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市長坂', '05', '05204', '0183504', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '長坂', 'ナガサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市早口', '05', '05204', '0183505', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '早口', 'ハヤグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市山瀬', '05', '05204', '0183506', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '山瀬', 'ヤマセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都小金井市', '13', '13210', '1840000', '東京都', 'トウキョウト', '小金井市', 'コガネイシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('9279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都小金井市関野町', '13', '13210', '1840001', '東京都', 'トウキョウト', '小金井市', 'コガネイシ', '関野町', 'セキノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都小金井市梶野町', '13', '13210', '1840002', '東京都', 'トウキョウト', '小金井市', 'コガネイシ', '梶野町', 'カジノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都小金井市緑町', '13', '13210', '1840003', '東京都', 'トウキョウト', '小金井市', 'コガネイシ', '緑町', 'ミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都小金井市本町', '13', '13210', '1840004', '東京都', 'トウキョウト', '小金井市', 'コガネイシ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都小金井市桜町', '13', '13210', '1840005', '東京都', 'トウキョウト', '小金井市', 'コガネイシ', '桜町', 'サクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都小金井市東町', '13', '13210', '1840011', '東京都', 'トウキョウト', '小金井市', 'コガネイシ', '東町', 'ヒガシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都小金井市中町', '13', '13210', '1840012', '東京都', 'トウキョウト', '小金井市', 'コガネイシ', '中町', 'ナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都小金井市前原町', '13', '13210', '1840013', '東京都', 'トウキョウト', '小金井市', 'コガネイシ', '前原町', 'マエハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都小金井市貫井南町', '13', '13210', '1840014', '東京都', 'トウキョウト', '小金井市', 'コガネイシ', '貫井南町', 'ヌクイミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都小金井市貫井北町', '13', '13210', '1840015', '東京都', 'トウキョウト', '小金井市', 'コガネイシ', '貫井北町', 'ヌクイキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県北秋田市増沢', '05', '05213', '0184201', '秋田県', 'アキタケン', '北秋田市', 'キタアキタシ', '増沢', 'マスザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県北秋田市八幡岱新田', '05', '05213', '0184202', '秋田県', 'アキタケン', '北秋田市', 'キタアキタシ', '八幡岱新田', 'ハチマンタイシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県北秋田市木戸石', '05', '05213', '0184203', '秋田県', 'アキタケン', '北秋田市', 'キタアキタシ', '木戸石', 'キドイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県北秋田市川井', '05', '05213', '0184211', '秋田県', 'アキタケン', '北秋田市', 'キタアキタシ', '川井', 'カワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県北秋田市下杉', '05', '05213', '0184221', '秋田県', 'アキタケン', '北秋田市', 'キタアキタシ', '下杉', 'シモスギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県北秋田市上杉', '05', '05213', '0184231', '秋田県', 'アキタケン', '北秋田市', 'キタアキタシ', '上杉', 'カミスギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県北秋田市道城', '05', '05213', '0184241', '秋田県', 'アキタケン', '北秋田市', 'キタアキタシ', '道城', 'ドウジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県北秋田市鎌沢', '05', '05213', '0184251', '秋田県', 'アキタケン', '北秋田市', 'キタアキタシ', '鎌沢', 'カマノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県北秋田市芹沢', '05', '05213', '0184261', '秋田県', 'アキタケン', '北秋田市', 'キタアキタシ', '芹沢', 'セリサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県北秋田市三里', '05', '05213', '0184262', '秋田県', 'アキタケン', '北秋田市', 'キタアキタシ', '三里', 'ミッサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県北秋田市三木田', '05', '05213', '0184263', '秋田県', 'アキタケン', '北秋田市', 'キタアキタシ', '三木田', 'ミツキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県北秋田市福田', '05', '05213', '0184271', '秋田県', 'アキタケン', '北秋田市', 'キタアキタシ', '福田', 'フクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県北秋田市新田目', '05', '05213', '0184272', '秋田県', 'アキタケン', '北秋田市', 'キタアキタシ', '新田目', 'ニイダメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県北秋田市根田', '05', '05213', '0184273', '秋田県', 'アキタケン', '北秋田市', 'キタアキタシ', '根田', 'コンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県北秋田市羽根山', '05', '05213', '0184281', '秋田県', 'アキタケン', '北秋田市', 'キタアキタシ', '羽根山', 'ハネヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県北秋田市李岱', '05', '05213', '0184282', '秋田県', 'アキタケン', '北秋田市', 'キタアキタシ', '李岱', 'スモモダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県北秋田市米内沢', '05', '05213', '0184301', '秋田県', 'アキタケン', '北秋田市', 'キタアキタシ', '米内沢', 'ヨナイザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県北秋田市浦田', '05', '05213', '0184302', '秋田県', 'アキタケン', '北秋田市', 'キタアキタシ', '浦田', 'ウラタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県北秋田市本城', '05', '05213', '0184303', '秋田県', 'アキタケン', '北秋田市', 'キタアキタシ', '本城', 'ホンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県北秋田郡上小阿仁村', '05', '05327', '0184400', '秋田県', 'アキタケン', '北秋田郡上小阿仁村', 'キタアキタグンカミコアニムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('9313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県北秋田郡上小阿仁村沖田面', '05', '05327', '0184401', '秋田県', 'アキタケン', '北秋田郡上小阿仁村', 'キタアキタグンカミコアニムラ', '沖田面', 'オキタオモテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県北秋田郡上小阿仁村福舘', '05', '05327', '0184411', '秋田県', 'アキタケン', '北秋田郡上小阿仁村', 'キタアキタグンカミコアニムラ', '福舘', 'フクダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県北秋田郡上小阿仁村五反沢', '05', '05327', '0184412', '秋田県', 'アキタケン', '北秋田郡上小阿仁村', 'キタアキタグンカミコアニムラ', '五反沢', 'ゴタンザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県北秋田郡上小阿仁村杉花', '05', '05327', '0184413', '秋田県', 'アキタケン', '北秋田郡上小阿仁村', 'キタアキタグンカミコアニムラ', '杉花', 'スギハナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県北秋田郡上小阿仁村小沢田', '05', '05327', '0184421', '秋田県', 'アキタケン', '北秋田郡上小阿仁村', 'キタアキタグンカミコアニムラ', '小沢田', 'コサワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県北秋田郡上小阿仁村堂川', '05', '05327', '0184422', '秋田県', 'アキタケン', '北秋田郡上小阿仁村', 'キタアキタグンカミコアニムラ', '堂川', 'ドウガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県北秋田郡上小阿仁村仏社', '05', '05327', '0184423', '秋田県', 'アキタケン', '北秋田郡上小阿仁村', 'キタアキタグンカミコアニムラ', '仏社', 'ブッシャ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県北秋田郡上小阿仁村大林', '05', '05327', '0184431', '秋田県', 'アキタケン', '北秋田郡上小阿仁村', 'キタアキタグンカミコアニムラ', '大林', 'オオバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県北秋田郡上小阿仁村南沢', '05', '05327', '0184432', '秋田県', 'アキタケン', '北秋田郡上小阿仁村', 'キタアキタグンカミコアニムラ', '南沢', 'ミナミザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県北秋田市森吉', '05', '05213', '0184511', '秋田県', 'アキタケン', '北秋田市', 'キタアキタシ', '森吉', 'モリヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県北秋田市根森田', '05', '05213', '0184512', '秋田県', 'アキタケン', '北秋田市', 'キタアキタシ', '根森田', 'ネモリタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県北秋田市小又', '05', '05213', '0184513', '秋田県', 'アキタケン', '北秋田市', 'キタアキタシ', '小又', 'コマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県北秋田市五味堀', '05', '05213', '0184514', '秋田県', 'アキタケン', '北秋田市', 'キタアキタシ', '五味堀', 'ゴミホリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県北秋田市阿仁前田', '05', '05213', '0184515', '秋田県', 'アキタケン', '北秋田市', 'キタアキタシ', '阿仁前田', 'アニマエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県北秋田市桂瀬', '05', '05213', '0184516', '秋田県', 'アキタケン', '北秋田市', 'キタアキタシ', '桂瀬', 'カツラセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県北秋田市阿仁吉田', '05', '05213', '0184601', '秋田県', 'アキタケン', '北秋田市', 'キタアキタシ', '阿仁吉田', 'アニヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県北秋田市阿仁小渕', '05', '05213', '0184602', '秋田県', 'アキタケン', '北秋田市', 'キタアキタシ', '阿仁小渕', 'アニコブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県北秋田市阿仁小様', '05', '05213', '0184603', '秋田県', 'アキタケン', '北秋田市', 'キタアキタシ', '阿仁小様', 'アニコザマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県北秋田市阿仁三枚鉱山', '05', '05213', '0184604', '秋田県', 'アキタケン', '北秋田市', 'キタアキタシ', '阿仁三枚鉱山', 'アニサンマイコウザン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県北秋田市阿仁水無', '05', '05213', '0184611', '秋田県', 'アキタケン', '北秋田市', 'キタアキタシ', '阿仁水無', 'アニミズナシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県北秋田市阿仁真木沢鉱山', '05', '05213', '0184612', '秋田県', 'アキタケン', '北秋田市', 'キタアキタシ', '阿仁真木沢鉱山', 'アニマギサワコウザン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県北秋田市阿仁銀山', '05', '05213', '0184613', '秋田県', 'アキタケン', '北秋田市', 'キタアキタシ', '阿仁銀山', 'アニギンザン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県北秋田市阿仁荒瀬', '05', '05213', '0184621', '秋田県', 'アキタケン', '北秋田市', 'キタアキタシ', '阿仁荒瀬', 'アニアラセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県北秋田市阿仁小沢鉱山', '05', '05213', '0184622', '秋田県', 'アキタケン', '北秋田市', 'キタアキタシ', '阿仁小沢鉱山', 'アニコサワコウザン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県北秋田市阿仁荒瀬川櫃畑', '05', '05213', '0184623', '秋田県', 'アキタケン', '北秋田市', 'キタアキタシ', '阿仁荒瀬川櫃畑', 'アニアラセガワヒツハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県北秋田市阿仁鍵ノ滝', '05', '05213', '0184624', '秋田県', 'アキタケン', '北秋田市', 'キタアキタシ', '阿仁鍵ノ滝', 'アニカギノタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県北秋田市阿仁打当', '05', '05213', '0184731', '秋田県', 'アキタケン', '北秋田市', 'キタアキタシ', '阿仁打当', 'アニウットウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県北秋田市阿仁中村', '05', '05213', '0184732', '秋田県', 'アキタケン', '北秋田市', 'キタアキタシ', '阿仁中村', 'アニナカムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県北秋田市阿仁戸鳥内', '05', '05213', '0184733', '秋田県', 'アキタケン', '北秋田市', 'キタアキタシ', '阿仁戸鳥内', 'アニトトリナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県北秋田市阿仁長畑', '05', '05213', '0184734', '秋田県', 'アキタケン', '北秋田市', 'キタアキタシ', '阿仁長畑', 'アニナガハタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県北秋田市阿仁比立内', '05', '05213', '0184735', '秋田県', 'アキタケン', '北秋田市', 'キタアキタシ', '阿仁比立内', 'アニヒタチナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県北秋田市阿仁幸屋', '05', '05213', '0184741', '秋田県', 'アキタケン', '北秋田市', 'キタアキタシ', '阿仁幸屋', 'アニコウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県北秋田市阿仁幸屋渡', '05', '05213', '0184742', '秋田県', 'アキタケン', '北秋田市', 'キタアキタシ', '阿仁幸屋渡', 'アニコウヤワタリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県北秋田市阿仁笑内', '05', '05213', '0184743', '秋田県', 'アキタケン', '北秋田市', 'キタアキタシ', '阿仁笑内', 'アニオカシナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県北秋田市阿仁根子', '05', '05213', '0184744', '秋田県', 'アキタケン', '北秋田市', 'キタアキタシ', '阿仁根子', 'アニネッコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県北秋田市阿仁萱草', '05', '05213', '0184745', '秋田県', 'アキタケン', '北秋田市', 'キタアキタシ', '阿仁萱草', 'アニカヤクサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県北秋田市阿仁伏影', '05', '05213', '0184746', '秋田県', 'アキタケン', '北秋田市', 'キタアキタシ', '阿仁伏影', 'アニフシカゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都国分寺市', '13', '13214', '1850000', '東京都', 'トウキョウト', '国分寺市', 'コクブンジシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('9375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都国分寺市北町', '13', '13214', '1850001', '東京都', 'トウキョウト', '国分寺市', 'コクブンジシ', '北町', 'キタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都国分寺市東戸倉', '13', '13214', '1850002', '東京都', 'トウキョウト', '国分寺市', 'コクブンジシ', '東戸倉', 'ヒガシトクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都国分寺市戸倉', '13', '13214', '1850003', '東京都', 'トウキョウト', '国分寺市', 'コクブンジシ', '戸倉', 'トクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都国分寺市新町', '13', '13214', '1850004', '東京都', 'トウキョウト', '国分寺市', 'コクブンジシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都国分寺市並木町', '13', '13214', '1850005', '東京都', 'トウキョウト', '国分寺市', 'コクブンジシ', '並木町', 'ナミキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都国分寺市本多', '13', '13214', '1850011', '東京都', 'トウキョウト', '国分寺市', 'コクブンジシ', '本多', 'ホンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都国分寺市本町', '13', '13214', '1850012', '東京都', 'トウキョウト', '国分寺市', 'コクブンジシ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都国分寺市西恋ケ窪', '13', '13214', '1850013', '東京都', 'トウキョウト', '国分寺市', 'コクブンジシ', '西恋ケ窪', 'ニシコイガクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都国分寺市東恋ケ窪', '13', '13214', '1850014', '東京都', 'トウキョウト', '国分寺市', 'コクブンジシ', '東恋ケ窪', 'ヒガシコイガクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都国分寺市南町', '13', '13214', '1850021', '東京都', 'トウキョウト', '国分寺市', 'コクブンジシ', '南町', 'ミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都国分寺市東元町', '13', '13214', '1850022', '東京都', 'トウキョウト', '国分寺市', 'コクブンジシ', '東元町', 'ヒガシモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都国分寺市西元町', '13', '13214', '1850023', '東京都', 'トウキョウト', '国分寺市', 'コクブンジシ', '西元町', 'ニシモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都国分寺市泉町', '13', '13214', '1850024', '東京都', 'トウキョウト', '国分寺市', 'コクブンジシ', '泉町', 'イズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都国分寺市富士本', '13', '13214', '1850031', '東京都', 'トウキョウト', '国分寺市', 'コクブンジシ', '富士本', 'フジモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都国分寺市日吉町', '13', '13214', '1850032', '東京都', 'トウキョウト', '国分寺市', 'コクブンジシ', '日吉町', 'ヒヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都国分寺市内藤', '13', '13214', '1850033', '東京都', 'トウキョウト', '国分寺市', 'コクブンジシ', '内藤', 'ナイトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都国分寺市光町', '13', '13214', '1850034', '東京都', 'トウキョウト', '国分寺市', 'コクブンジシ', '光町', 'ヒカリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都国分寺市西町', '13', '13214', '1850035', '東京都', 'トウキョウト', '国分寺市', 'コクブンジシ', '西町', 'ニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都国分寺市高木町', '13', '13214', '1850036', '東京都', 'トウキョウト', '国分寺市', 'コクブンジシ', '高木町', 'タカギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県鹿角市八幡平', '05', '05209', '0185141', '秋田県', 'アキタケン', '鹿角市', 'カヅノシ', '八幡平', 'ハチマンタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県鹿角市', '05', '05209', '0185200', '秋田県', 'アキタケン', '鹿角市', 'カヅノシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('9397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県鹿角市花輪', '05', '05209', '0185201', '秋田県', 'アキタケン', '鹿角市', 'カヅノシ', '花輪', 'ハナワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県鹿角市尾去沢', '05', '05209', '0185202', '秋田県', 'アキタケン', '鹿角市', 'カヅノシ', '尾去沢', 'オサリザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県鹿角市十和田山根', '05', '05209', '0185331', '秋田県', 'アキタケン', '鹿角市', 'カヅノシ', '十和田山根', 'トワダヤマネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県鹿角市十和田上向', '05', '05209', '0185332', '秋田県', 'アキタケン', '鹿角市', 'カヅノシ', '十和田上向', 'トワダウワムカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県鹿角市十和田岡田', '05', '05209', '0185333', '秋田県', 'アキタケン', '鹿角市', 'カヅノシ', '十和田岡田', 'トワダオカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県鹿角市十和田毛馬内', '05', '05209', '0185334', '秋田県', 'アキタケン', '鹿角市', 'カヅノシ', '十和田毛馬内', 'トワダケマナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県鹿角市十和田瀬田石', '05', '05209', '0185335', '秋田県', 'アキタケン', '鹿角市', 'カヅノシ', '十和田瀬田石', 'トワダセタイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県鹿角市十和田錦木', '05', '05209', '0185336', '秋田県', 'アキタケン', '鹿角市', 'カヅノシ', '十和田錦木', 'トワダニシキギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県鹿角市十和田末広', '05', '05209', '0185337', '秋田県', 'アキタケン', '鹿角市', 'カヅノシ', '十和田末広', 'トワダスエヒロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県鹿角市十和田大湯', '05', '05209', '0185421', '秋田県', 'アキタケン', '鹿角市', 'カヅノシ', '十和田大湯', 'トワダオオユ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県鹿角市十和田草木', '05', '05209', '0185422', '秋田県', 'アキタケン', '鹿角市', 'カヅノシ', '十和田草木', 'トワダクサギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県十和田市奥瀬青撫', '02', '02206', '0185501', '青森県', 'アオモリケン', '十和田市', 'トワダシ', '奥瀬', 'オクセ', null, null, '青撫', 'アオブナ');
INSERT INTO `ms_addresses` VALUES ('9411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県十和田市奥瀬小畳石', '02', '02206', '0185501', '青森県', 'アオモリケン', '十和田市', 'トワダシ', '奥瀬', 'オクセ', null, null, '小畳石', 'コタタミイシ');
INSERT INTO `ms_addresses` VALUES ('9412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県十和田市奥瀬十和田', '02', '02206', '0185501', '青森県', 'アオモリケン', '十和田市', 'トワダシ', '奥瀬', 'オクセ', null, null, '十和田', 'トワダ');
INSERT INTO `ms_addresses` VALUES ('9413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県十和田市奥瀬十和田湖畔宇樽部', '02', '02206', '0185501', '青森県', 'アオモリケン', '十和田市', 'トワダシ', '奥瀬', 'オクセ', null, null, '十和田湖畔宇樽部', 'トワダコハンウタルベ');
INSERT INTO `ms_addresses` VALUES ('9414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県十和田市奥瀬十和田湖畔子ノ口', '02', '02206', '0185501', '青森県', 'アオモリケン', '十和田市', 'トワダシ', '奥瀬', 'オクセ', null, null, '十和田湖畔子ノ口', 'トワダコハンネノクチ');
INSERT INTO `ms_addresses` VALUES ('9415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県十和田市奥瀬十和田湖畔休屋', '02', '02206', '0185501', '青森県', 'アオモリケン', '十和田市', 'トワダシ', '奥瀬', 'オクセ', null, null, '十和田湖畔休屋', 'トワダコハンヤスミヤ');
INSERT INTO `ms_addresses` VALUES ('9416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県鹿角郡小坂町十和田湖', '05', '05303', '0185511', '秋田県', 'アキタケン', '鹿角郡小坂町', 'カヅノグンコサカマチ', '十和田湖', 'トワダコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市十二所', '05', '05204', '0185601', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '十二所', 'ジュウニショ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市道目木', '05', '05204', '0185602', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '道目木', 'ドウメキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市曲田', '05', '05204', '0185603', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '曲田', 'マガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市軽井沢', '05', '05204', '0185604', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '軽井沢', 'カルイザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市猿間', '05', '05204', '0185605', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '猿間', 'サルマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市葛原', '05', '05204', '0185606', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '葛原', 'クズワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市比内町扇田', '05', '05204', '0185701', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '比内町扇田', 'ヒナイマチオウギタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市比内町味噌内', '05', '05204', '0185711', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '比内町味噌内', 'ヒナイマチミソナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市比内町新館', '05', '05204', '0185712', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '比内町新館', 'ヒナイマチニイダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市比内町独鈷', '05', '05204', '0185721', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '比内町独鈷', 'ヒナイマチトッコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市比内町中野', '05', '05204', '0185722', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '比内町中野', 'ヒナイマチナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市比内町笹館', '05', '05204', '0185731', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '比内町笹館', 'ヒナイマチササダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市比内町谷地中', '05', '05204', '0185732', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '比内町谷地中', 'ヒナイマチヤチナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市比内町達子', '05', '05204', '0185741', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '比内町達子', 'ヒナイマチタッコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市比内町白沢水沢', '05', '05204', '0185742', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '比内町白沢水沢', 'ヒナイマチシラサワミズサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市比内町小坪沢', '05', '05204', '0185743', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '比内町小坪沢', 'ヒナイマチオツボザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市比内町八木橋', '05', '05204', '0185744', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '比内町八木橋', 'ヒナイマチヤギハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市比内町片貝', '05', '05204', '0185745', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '比内町片貝', 'ヒナイマチカタガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市二井田', '05', '05204', '0185751', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '二井田', 'ニイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市本宮', '05', '05204', '0185752', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '本宮', 'モトミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市比内前田', '05', '05204', '0185753', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '比内前田', 'ヒナイマエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市大子内', '05', '05204', '0185754', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '大子内', 'オオシナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市杉沢', '05', '05204', '0185755', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '杉沢', 'スギサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市下川原', '05', '05204', '0185756', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '下川原', 'シタカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大館市比内町大葛', '05', '05204', '0185851', '秋田県', 'アキタケン', '大館市', 'オオダテシ', '比内町大葛', 'ヒナイマチオオクゾ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都国立市', '13', '13215', '1860000', '東京都', 'トウキョウト', '国立市', 'クニタチシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('9458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都国立市北', '13', '13215', '1860001', '東京都', 'トウキョウト', '国立市', 'クニタチシ', '北', 'キタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都国立市東', '13', '13215', '1860002', '東京都', 'トウキョウト', '国立市', 'クニタチシ', '東', 'ヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都国立市富士見台', '13', '13215', '1860003', '東京都', 'トウキョウト', '国立市', 'クニタチシ', '富士見台', 'フジミダイ', null, null, null, null), ('9461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都国立市中', '13', '13215', '1860004', '東京都', 'トウキョウト', '国立市', 'クニタチシ', '中', 'ナカ', null, null, null, null), ('9462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都国立市西', '13', '13215', '1860005', '東京都', 'トウキョウト', '国立市', 'クニタチシ', '西', 'ニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都国立市谷保', '13', '13215', '1860011', '東京都', 'トウキョウト', '国立市', 'クニタチシ', '谷保', 'ヤホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都国立市泉', '13', '13215', '1860012', '東京都', 'トウキョウト', '国立市', 'クニタチシ', '泉', 'イズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都国立市青柳', '13', '13215', '1860013', '東京都', 'トウキョウト', '国立市', 'クニタチシ', '青柳', 'アオヤギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都国立市石田', '13', '13215', '1860014', '東京都', 'トウキョウト', '国立市', 'クニタチシ', '石田', 'イシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都国立市矢川', '13', '13215', '1860015', '東京都', 'トウキョウト', '国立市', 'クニタチシ', '矢川', 'ヤガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都小平市', '13', '13211', '1870000', '東京都', 'トウキョウト', '小平市', 'コダイラシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('9486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都小平市大沼町', '13', '13211', '1870001', '東京都', 'トウキョウト', '小平市', 'コダイラシ', '大沼町', 'オオヌマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都小平市花小金井', '13', '13211', '1870002', '東京都', 'トウキョウト', '小平市', 'コダイラシ', '花小金井', 'ハナコガネイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都小平市花小金井南町', '13', '13211', '1870003', '東京都', 'トウキョウト', '小平市', 'コダイラシ', '花小金井南町', 'ハナコガネイミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都小平市天神町', '13', '13211', '1870004', '東京都', 'トウキョウト', '小平市', 'コダイラシ', '天神町', 'テンジンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都小平市鈴木町', '13', '13211', '1870011', '東京都', 'トウキョウト', '小平市', 'コダイラシ', '鈴木町', 'スズキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都小平市御幸町', '13', '13211', '1870012', '東京都', 'トウキョウト', '小平市', 'コダイラシ', '御幸町', 'ミユキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都小平市回田町', '13', '13211', '1870013', '東京都', 'トウキョウト', '小平市', 'コダイラシ', '回田町', 'メグリタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都小平市上水南町', '13', '13211', '1870021', '東京都', 'トウキョウト', '小平市', 'コダイラシ', '上水南町', 'ジョウスイミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都小平市上水本町', '13', '13211', '1870022', '東京都', 'トウキョウト', '小平市', 'コダイラシ', '上水本町', 'ジョウスイホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都小平市上水新町', '13', '13211', '1870023', '東京都', 'トウキョウト', '小平市', 'コダイラシ', '上水新町', 'ジョウスイシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都小平市たかの台', '13', '13211', '1870024', '東京都', 'トウキョウト', '小平市', 'コダイラシ', 'たかの台', 'タカノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都小平市津田町', '13', '13211', '1870025', '東京都', 'トウキョウト', '小平市', 'コダイラシ', '津田町', 'ツダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都小平市小川東町', '13', '13211', '1870031', '東京都', 'トウキョウト', '小平市', 'コダイラシ', '小川東町', 'オガワヒガシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都小平市小川町', '13', '13211', '1870032', '東京都', 'トウキョウト', '小平市', 'コダイラシ', '小川町', 'オガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都小平市中島町', '13', '13211', '1870033', '東京都', 'トウキョウト', '小平市', 'コダイラシ', '中島町', 'ナカジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都小平市栄町', '13', '13211', '1870034', '東京都', 'トウキョウト', '小平市', 'コダイラシ', '栄町', 'サカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都小平市小川西町', '13', '13211', '1870035', '東京都', 'トウキョウト', '小平市', 'コダイラシ', '小川西町', 'オガワニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都小平市美園町', '13', '13211', '1870041', '東京都', 'トウキョウト', '小平市', 'コダイラシ', '美園町', 'ミソノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都小平市仲町', '13', '13211', '1870042', '東京都', 'トウキョウト', '小平市', 'コダイラシ', '仲町', 'ナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都小平市学園東町', '13', '13211', '1870043', '東京都', 'トウキョウト', '小平市', 'コダイラシ', '学園東町', 'ガクエンヒガシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都小平市喜平町', '13', '13211', '1870044', '東京都', 'トウキョウト', '小平市', 'コダイラシ', '喜平町', 'キヘイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都小平市学園西町', '13', '13211', '1870045', '東京都', 'トウキョウト', '小平市', 'コダイラシ', '学園西町', 'ガクエンニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都西東京市谷戸町', '13', '13229', '1880001', '東京都', 'トウキョウト', '西東京市', 'ニシトウキョウシ', '谷戸町', 'ヤトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都西東京市緑町', '13', '13229', '1880002', '東京都', 'トウキョウト', '西東京市', 'ニシトウキョウシ', '緑町', 'ミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都西東京市北原町', '13', '13229', '1880003', '東京都', 'トウキョウト', '西東京市', 'ニシトウキョウシ', '北原町', 'キタハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都西東京市西原町', '13', '13229', '1880004', '東京都', 'トウキョウト', '西東京市', 'ニシトウキョウシ', '西原町', 'ニシハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都西東京市田無町', '13', '13229', '1880011', '東京都', 'トウキョウト', '西東京市', 'ニシトウキョウシ', '田無町', 'タナシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都西東京市南町', '13', '13229', '1880012', '東京都', 'トウキョウト', '西東京市', 'ニシトウキョウシ', '南町', 'ミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都西東京市向台町', '13', '13229', '1880013', '東京都', 'トウキョウト', '西東京市', 'ニシトウキョウシ', '向台町', 'ムコウダイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都西東京市芝久保町', '13', '13229', '1880014', '東京都', 'トウキョウト', '西東京市', 'ニシトウキョウシ', '芝久保町', 'シバクボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都東村山市', '13', '13213', '1890000', '東京都', 'トウキョウト', '東村山市', 'ヒガシムラヤマシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('9550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都東村山市秋津町', '13', '13213', '1890001', '東京都', 'トウキョウト', '東村山市', 'ヒガシムラヤマシ', '秋津町', 'アキツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都東村山市青葉町', '13', '13213', '1890002', '東京都', 'トウキョウト', '東村山市', 'ヒガシムラヤマシ', '青葉町', 'アオバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都東村山市久米川町', '13', '13213', '1890003', '東京都', 'トウキョウト', '東村山市', 'ヒガシムラヤマシ', '久米川町', 'クメガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都東村山市恩多町', '13', '13213', '1890011', '東京都', 'トウキョウト', '東村山市', 'ヒガシムラヤマシ', '恩多町', 'オンタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都東村山市萩山町', '13', '13213', '1890012', '東京都', 'トウキョウト', '東村山市', 'ヒガシムラヤマシ', '萩山町', 'ハギヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都東村山市栄町', '13', '13213', '1890013', '東京都', 'トウキョウト', '東村山市', 'ヒガシムラヤマシ', '栄町', 'サカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都東村山市本町', '13', '13213', '1890014', '東京都', 'トウキョウト', '東村山市', 'ヒガシムラヤマシ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都東村山市諏訪町', '13', '13213', '1890021', '東京都', 'トウキョウト', '東村山市', 'ヒガシムラヤマシ', '諏訪町', 'スワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都東村山市野口町', '13', '13213', '1890022', '東京都', 'トウキョウト', '東村山市', 'ヒガシムラヤマシ', '野口町', 'ノグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都東村山市美住町', '13', '13213', '1890023', '東京都', 'トウキョウト', '東村山市', 'ヒガシムラヤマシ', '美住町', 'ミスミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都東村山市富士見町', '13', '13213', '1890024', '東京都', 'トウキョウト', '東村山市', 'ヒガシムラヤマシ', '富士見町', 'フジミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都東村山市廻田町', '13', '13213', '1890025', '東京都', 'トウキョウト', '東村山市', 'ヒガシムラヤマシ', '廻田町', 'メグリタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都東村山市多摩湖町', '13', '13213', '1890026', '東京都', 'トウキョウト', '東村山市', 'ヒガシムラヤマシ', '多摩湖町', 'タマコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都立川市', '13', '13202', '1900000', '東京都', 'トウキョウト', '立川市', 'タチカワシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('9571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都立川市若葉町', '13', '13202', '1900001', '東京都', 'トウキョウト', '立川市', 'タチカワシ', '若葉町', 'ワカバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都立川市幸町', '13', '13202', '1900002', '東京都', 'トウキョウト', '立川市', 'タチカワシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都立川市栄町', '13', '13202', '1900003', '東京都', 'トウキョウト', '立川市', 'タチカワシ', '栄町', 'サカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都立川市柏町', '13', '13202', '1900004', '東京都', 'トウキョウト', '立川市', 'タチカワシ', '柏町', 'カシワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都立川市高松町', '13', '13202', '1900011', '東京都', 'トウキョウト', '立川市', 'タチカワシ', '高松町', 'タカマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都立川市曙町', '13', '13202', '1900012', '東京都', 'トウキョウト', '立川市', 'タチカワシ', '曙町', 'アケボノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都立川市富士見町', '13', '13202', '1900013', '東京都', 'トウキョウト', '立川市', 'タチカワシ', '富士見町', 'フジミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都立川市緑町', '13', '13202', '1900014', '東京都', 'トウキョウト', '立川市', 'タチカワシ', '緑町', 'ミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都立川市泉町', '13', '13202', '1900015', '東京都', 'トウキョウト', '立川市', 'タチカワシ', '泉町', 'イズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都立川市羽衣町', '13', '13202', '1900021', '東京都', 'トウキョウト', '立川市', 'タチカワシ', '羽衣町', 'ハゴロモチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都立川市錦町', '13', '13202', '1900022', '東京都', 'トウキョウト', '立川市', 'タチカワシ', '錦町', 'ニシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都立川市柴崎町', '13', '13202', '1900023', '東京都', 'トウキョウト', '立川市', 'タチカワシ', '柴崎町', 'シバサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都立川市砂川町', '13', '13202', '1900031', '東京都', 'トウキョウト', '立川市', 'タチカワシ', '砂川町', 'スナガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都立川市上砂町', '13', '13202', '1900032', '東京都', 'トウキョウト', '立川市', 'タチカワシ', '上砂町', 'カミスナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都立川市一番町', '13', '13202', '1900033', '東京都', 'トウキョウト', '立川市', 'タチカワシ', '一番町', 'イチバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都立川市西砂町', '13', '13202', '1900034', '東京都', 'トウキョウト', '立川市', 'タチカワシ', '西砂町', 'ニシスナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都あきる野市', '13', '13228', '1900100', '東京都', 'トウキョウト', 'あきる野市', 'アキルノシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('9588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都西多摩郡日の出町', '13', '13305', '1900100', '東京都', 'トウキョウト', '西多摩郡日の出町', 'ニシタマグンヒノデマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('9589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都あきる野市横沢', '13', '13228', '1900141', '東京都', 'トウキョウト', 'あきる野市', 'アキルノシ', '横沢', 'ヨコサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都あきる野市伊奈', '13', '13228', '1900142', '東京都', 'トウキョウト', 'あきる野市', 'アキルノシ', '伊奈', 'イナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都あきる野市上ノ台', '13', '13228', '1900143', '東京都', 'トウキョウト', 'あきる野市', 'アキルノシ', '上ノ台', 'ウエノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都あきる野市山田', '13', '13228', '1900144', '東京都', 'トウキョウト', 'あきる野市', 'アキルノシ', '山田', 'ヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都あきる野市小和田', '13', '13228', '1900151', '東京都', 'トウキョウト', 'あきる野市', 'アキルノシ', '小和田', 'コワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都あきる野市留原', '13', '13228', '1900152', '東京都', 'トウキョウト', 'あきる野市', 'アキルノシ', '留原', 'トトハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都あきる野市小峰台', '13', '13228', '1900153', '東京都', 'トウキョウト', 'あきる野市', 'アキルノシ', '小峰台', 'コミネダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都あきる野市高尾', '13', '13228', '1900154', '東京都', 'トウキョウト', 'あきる野市', 'アキルノシ', '高尾', 'タカオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都あきる野市網代', '13', '13228', '1900155', '東京都', 'トウキョウト', 'あきる野市', 'アキルノシ', '網代', 'アジロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都あきる野市入野', '13', '13228', '1900161', '東京都', 'トウキョウト', 'あきる野市', 'アキルノシ', '入野', 'イリノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都あきる野市三内', '13', '13228', '1900162', '東京都', 'トウキョウト', 'あきる野市', 'アキルノシ', '三内', 'サンナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都あきる野市舘谷', '13', '13228', '1900163', '東京都', 'トウキョウト', 'あきる野市', 'アキルノシ', '舘谷', 'タテヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都あきる野市五日市', '13', '13228', '1900164', '東京都', 'トウキョウト', 'あきる野市', 'アキルノシ', '五日市', 'イツカイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都あきる野市小中野', '13', '13228', '1900165', '東京都', 'トウキョウト', 'あきる野市', 'アキルノシ', '小中野', 'コナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都あきる野市舘谷台', '13', '13228', '1900166', '東京都', 'トウキョウト', 'あきる野市', 'アキルノシ', '舘谷台', 'タテヤダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都あきる野市養沢', '13', '13228', '1900171', '東京都', 'トウキョウト', 'あきる野市', 'アキルノシ', '養沢', 'ヨウザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都あきる野市深沢', '13', '13228', '1900172', '東京都', 'トウキョウト', 'あきる野市', 'アキルノシ', '深沢', 'フカサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都あきる野市戸倉', '13', '13228', '1900173', '東京都', 'トウキョウト', 'あきる野市', 'アキルノシ', '戸倉', 'トクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都あきる野市乙津', '13', '13228', '1900174', '東京都', 'トウキョウト', 'あきる野市', 'アキルノシ', '乙津', 'オツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都西多摩郡日の出町大久野', '13', '13305', '1900181', '東京都', 'トウキョウト', '西多摩郡日の出町', 'ニシタマグンヒノデマチ', '大久野', 'オオグノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都西多摩郡日の出町平井', '13', '13305', '1900182', '東京都', 'トウキョウト', '西多摩郡日の出町', 'ニシタマグンヒノデマチ', '平井', 'ヒライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都西多摩郡檜原村', '13', '13307', '1900200', '東京都', 'トウキョウト', '西多摩郡檜原村', 'ニシタマグンヒノハラムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('9612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都西多摩郡檜原村倉掛', '13', '13307', '1900201', '東京都', 'トウキョウト', '西多摩郡檜原村', 'ニシタマグンヒノハラムラ', '倉掛', 'クラカケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都西多摩郡檜原村藤原', '13', '13307', '1900202', '東京都', 'トウキョウト', '西多摩郡檜原村', 'ニシタマグンヒノハラムラ', '藤原', 'フジワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都西多摩郡檜原村神戸', '13', '13307', '1900203', '東京都', 'トウキョウト', '西多摩郡檜原村', 'ニシタマグンヒノハラムラ', '神戸', 'カノト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都西多摩郡檜原村小沢', '13', '13307', '1900204', '東京都', 'トウキョウト', '西多摩郡檜原村', 'ニシタマグンヒノハラムラ', '小沢', 'オザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都西多摩郡檜原村樋里', '13', '13307', '1900205', '東京都', 'トウキョウト', '西多摩郡檜原村', 'ニシタマグンヒノハラムラ', '樋里', 'ヒザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都西多摩郡檜原村三都郷', '13', '13307', '1900211', '東京都', 'トウキョウト', '西多摩郡檜原村', 'ニシタマグンヒノハラムラ', '三都郷', 'ミツゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都西多摩郡檜原村上元郷', '13', '13307', '1900212', '東京都', 'トウキョウト', '西多摩郡檜原村', 'ニシタマグンヒノハラムラ', '上元郷', 'カミモトゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都西多摩郡檜原村下元郷', '13', '13307', '1900213', '東京都', 'トウキョウト', '西多摩郡檜原村', 'ニシタマグンヒノハラムラ', '下元郷', 'シモモトゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都西多摩郡檜原村本宿', '13', '13307', '1900214', '東京都', 'トウキョウト', '西多摩郡檜原村', 'ニシタマグンヒノハラムラ', '本宿', 'モトシュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都西多摩郡檜原村数馬', '13', '13307', '1900221', '東京都', 'トウキョウト', '西多摩郡檜原村', 'ニシタマグンヒノハラムラ', '数馬', 'カズマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都西多摩郡檜原村人里', '13', '13307', '1900222', '東京都', 'トウキョウト', '西多摩郡檜原村', 'ニシタマグンヒノハラムラ', '人里', 'ヘンボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都西多摩郡檜原村南郷', '13', '13307', '1900223', '東京都', 'トウキョウト', '西多摩郡檜原村', 'ニシタマグンヒノハラムラ', '南郷', 'ナンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市上院内', '05', '05207', '0190111', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '上院内', 'カミインナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市下院内', '05', '05207', '0190112', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '下院内', 'シモインナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市院内銀山町', '05', '05207', '0190113', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '院内銀山町', 'インナイギンザンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都西多摩郡瑞穂町', '13', '13303', '1901200', '東京都', 'トウキョウト', '西多摩郡瑞穂町', 'ニシタマグンミズホマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('9628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都西多摩郡瑞穂町二本木', '13', '13303', '1901201', '東京都', 'トウキョウト', '西多摩郡瑞穂町', 'ニシタマグンミズホマチ', '二本木', 'ニホンギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都西多摩郡瑞穂町駒形富士山', '13', '13303', '1901202', '東京都', 'トウキョウト', '西多摩郡瑞穂町', 'ニシタマグンミズホマチ', '駒形富士山', 'コマガタフジヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都西多摩郡瑞穂町高根', '13', '13303', '1901203', '東京都', 'トウキョウト', '西多摩郡瑞穂町', 'ニシタマグンミズホマチ', '高根', 'タカネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都西多摩郡瑞穂町富士山栗原新田', '13', '13303', '1901204', '東京都', 'トウキョウト', '西多摩郡瑞穂町', 'ニシタマグンミズホマチ', '富士山栗原新田', 'フジヤマクリハラシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都西多摩郡瑞穂町石畑', '13', '13303', '1901211', '東京都', 'トウキョウト', '西多摩郡瑞穂町', 'ニシタマグンミズホマチ', '石畑', 'イシハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都西多摩郡瑞穂町殿ケ谷', '13', '13303', '1901212', '東京都', 'トウキョウト', '西多摩郡瑞穂町', 'ニシタマグンミズホマチ', '殿ケ谷', 'トノガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都西多摩郡瑞穂町武蔵', '13', '13303', '1901213', '東京都', 'トウキョウト', '西多摩郡瑞穂町', 'ニシタマグンミズホマチ', '武蔵', 'ムサシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都西多摩郡瑞穂町むさし野', '13', '13303', '1901214', '東京都', 'トウキョウト', '西多摩郡瑞穂町', 'ニシタマグンミズホマチ', 'むさし野', 'ムサシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都西多摩郡瑞穂町箱根ケ崎', '13', '13303', '1901221', '東京都', 'トウキョウト', '西多摩郡瑞穂町', 'ニシタマグンミズホマチ', '箱根ケ崎', 'ハコネガサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都西多摩郡瑞穂町箱根ケ崎東松原', '13', '13303', '1901222', '東京都', 'トウキョウト', '西多摩郡瑞穂町', 'ニシタマグンミズホマチ', '箱根ケ崎東松原', 'ハコネガサキヒガシマツバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都西多摩郡瑞穂町箱根ケ崎西松原', '13', '13303', '1901223', '東京都', 'トウキョウト', '西多摩郡瑞穂町', 'ニシタマグンミズホマチ', '箱根ケ崎西松原', 'ハコネガサキニシマツバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都西多摩郡瑞穂町南平', '13', '13303', '1901224', '東京都', 'トウキョウト', '西多摩郡瑞穂町', 'ニシタマグンミズホマチ', '南平', 'ミナミダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都西多摩郡瑞穂町長岡長谷部', '13', '13303', '1901231', '東京都', 'トウキョウト', '西多摩郡瑞穂町', 'ニシタマグンミズホマチ', '長岡長谷部', 'ナガオカハセベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都西多摩郡瑞穂町長岡', '13', '13303', '1901232', '東京都', 'トウキョウト', '西多摩郡瑞穂町', 'ニシタマグンミズホマチ', '長岡', 'ナガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都西多摩郡瑞穂町長岡下師岡', '13', '13303', '1901233', '東京都', 'トウキョウト', '西多摩郡瑞穂町', 'ニシタマグンミズホマチ', '長岡下師岡', 'ナガオカシモモロオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都西多摩郡瑞穂町長岡藤橋', '13', '13303', '1901234', '東京都', 'トウキョウト', '西多摩郡瑞穂町', 'ニシタマグンミズホマチ', '長岡藤橋', 'ナガオカフジハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市泉沢', '05', '05207', '0190201', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '泉沢', 'イズミサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市桑崎', '05', '05207', '0190202', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '桑崎', 'クワガサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市寺沢', '05', '05207', '0190203', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '寺沢', 'テラサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市横堀', '05', '05207', '0190204', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '横堀', 'ヨコボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市小野', '05', '05207', '0190205', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '小野', 'オノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市秋ノ宮', '05', '05207', '0190321', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '秋ノ宮', 'アキノミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市酒蒔', '05', '05207', '0190401', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '酒蒔', 'サカマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市相川', '05', '05207', '0190402', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '相川', 'アイカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市宇留院内', '05', '05207', '0190403', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '宇留院内', 'ウルインナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市高松', '05', '05207', '0190404', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '高松', 'タカマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県湯沢市皆瀬水上沢', '05', '05207', '0190481', '秋田県', 'アキタケン', '湯沢市', 'ユザワシ', '皆瀬', 'ミナセ', null, null, '水上沢', 'ミズカミサワ');
INSERT INTO `ms_addresses` VALUES ('9659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市十文字町腕越', '05', '05203', '0190501', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '十文字町腕越', 'ジュウモンジマチウデコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市十文字町西原2番町', '05', '05203', '0190502', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '十文字町西原2番町', 'ジュウモンジマチニシハラ02バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市十文字町西原1番町', '05', '05203', '0190503', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '十文字町西原1番町', 'ジュウモンジマチニシハラ01バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市十文字町仁井田', '05', '05203', '0190505', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '十文字町仁井田', 'ジュウモンジマチニイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市十文字町佐賀会', '05', '05203', '0190506', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '十文字町佐賀会', 'ジュウモンジマチサガエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市十文字町上鍋倉', '05', '05203', '0190507', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '十文字町上鍋倉', 'ジュウモンジマチカミナベクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市十文字町十五野新田', '05', '05203', '0190508', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '十文字町十五野新田', 'ジュウモンジマチジュウゴノシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市十文字町梨木', '05', '05203', '0190509', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '十文字町梨木', 'ジュウモンジマチナシノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市十文字町鼎', '05', '05203', '0190511', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '十文字町鼎', 'ジュウモンジマチカナエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市十文字町越前', '05', '05203', '0190512', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '十文字町越前', 'ジュウモンジマチエツゼン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市十文字町植田', '05', '05203', '0190513', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '十文字町植田', 'ジュウモンジマチウエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市十文字町睦合', '05', '05203', '0190514', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '十文字町睦合', 'ジュウモンジマチムツアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市十文字町谷地新田', '05', '05203', '0190515', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '十文字町谷地新田', 'ジュウモンジマチヤチシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市十文字町源太左馬', '05', '05203', '0190516', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '十文字町源太左馬', 'ジュウモンジマチゲンダサマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市十文字町木下', '05', '05203', '0190517', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '十文字町木下', 'ジュウモンジマチキジタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市十文字町宝竜', '05', '05203', '0190518', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '十文字町宝竜', 'ジュウモンジマチホウリュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市十文字町西下', '05', '05203', '0190521', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '十文字町西下', 'ジュウモンジマチニシシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市十文字町西上', '05', '05203', '0190522', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '十文字町西上', 'ジュウモンジマチニシカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市十文字町十文字', '05', '05203', '0190523', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '十文字町十文字', 'ジュウモンジマチジュウモンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市十文字町本町', '05', '05203', '0190524', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '十文字町本町', 'ジュウモンジマチモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市十文字町曙町', '05', '05203', '0190525', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '十文字町曙町', 'ジュウモンジマチアケボノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市十文字町通町', '05', '05203', '0190526', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '十文字町通町', 'ジュウモンジマチトオリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市十文字町大道東', '05', '05203', '0190527', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '十文字町大道東', 'ジュウモンジマチダイドウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市十文字町栄町', '05', '05203', '0190528', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '十文字町栄町', 'ジュウモンジマチサカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市十文字町海道下', '05', '05203', '0190529', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '十文字町海道下', 'ジュウモンジマチカイドウシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市十文字町上佐吉開', '05', '05203', '0190531', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '十文字町上佐吉開', 'ジュウモンジマチカミサキチビラキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市十文字町麻当', '05', '05203', '0190532', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '十文字町麻当', 'ジュウモンジマチマトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市十文字町下佐吉開', '05', '05203', '0190533', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '十文字町下佐吉開', 'ジュウモンジマチシモサキチビラキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市増田町増田', '05', '05203', '0190701', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '増田町増田', 'マスダマチマスダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市増田町亀田', '05', '05203', '0190702', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '増田町亀田', 'マスダマチカメダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市増田町吉野', '05', '05203', '0190703', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '増田町吉野', 'マスダマチヨシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市増田町湯野沢', '05', '05203', '0190704', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '増田町湯野沢', 'マスダマチユノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市増田町狙半内', '05', '05203', '0190705', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '増田町狙半内', 'マスダマチサルハンナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市増田町荻袋', '05', '05203', '0190711', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '増田町荻袋', 'マスダマチオギノフクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市増田町熊渕', '05', '05203', '0190712', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '増田町熊渕', 'マスダマチクマノフチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市増田町三又', '05', '05203', '0190713', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '増田町三又', 'マスダマチミツマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市増田町戸波', '05', '05203', '0190714', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '増田町戸波', 'マスダマチトナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市増田町八木', '05', '05203', '0190715', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '増田町八木', 'マスダマチヤギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県雄勝郡東成瀬村', '05', '05464', '0190800', '秋田県', 'アキタケン', '雄勝郡東成瀬村', 'オガチグンヒガシナルセムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('9700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県雄勝郡東成瀬村田子内', '05', '05464', '0190801', '秋田県', 'アキタケン', '雄勝郡東成瀬村', 'オガチグンヒガシナルセムラ', '田子内', 'タゴナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県雄勝郡東成瀬村岩井川', '05', '05464', '0190802', '秋田県', 'アキタケン', '雄勝郡東成瀬村', 'オガチグンヒガシナルセムラ', '岩井川', 'イワイカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県雄勝郡東成瀬村椿川', '05', '05464', '0190803', '秋田県', 'アキタケン', '雄勝郡東成瀬村', 'オガチグンヒガシナルセムラ', '椿川', 'ツバキカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都日野市', '13', '13212', '1910000', '東京都', 'トウキョウト', '日野市', 'ヒノシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('9761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都日野市栄町', '13', '13212', '1910001', '東京都', 'トウキョウト', '日野市', 'ヒノシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都日野市新町', '13', '13212', '1910002', '東京都', 'トウキョウト', '日野市', 'ヒノシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都日野市日野台', '13', '13212', '1910003', '東京都', 'トウキョウト', '日野市', 'ヒノシ', '日野台', 'ヒノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都日野市日野本町', '13', '13212', '1910011', '東京都', 'トウキョウト', '日野市', 'ヒノシ', '日野本町', 'ヒノホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都日野市日野', '13', '13212', '1910012', '東京都', 'トウキョウト', '日野市', 'ヒノシ', '日野', 'ヒノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都日野市宮', '13', '13212', '1910013', '東京都', 'トウキョウト', '日野市', 'ヒノシ', '宮', 'ミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都日野市上田', '13', '13212', '1910014', '東京都', 'トウキョウト', '日野市', 'ヒノシ', '上田', 'カミダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都日野市川辺堀之内', '13', '13212', '1910015', '東京都', 'トウキョウト', '日野市', 'ヒノシ', '川辺堀之内', 'カワベホリノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都日野市神明', '13', '13212', '1910016', '東京都', 'トウキョウト', '日野市', 'ヒノシ', '神明', 'シンメイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都日野市石田', '13', '13212', '1910021', '東京都', 'トウキョウト', '日野市', 'ヒノシ', '石田', 'イシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都日野市新井', '13', '13212', '1910022', '東京都', 'トウキョウト', '日野市', 'ヒノシ', '新井', 'アライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都日野市下田', '13', '13212', '1910023', '東京都', 'トウキョウト', '日野市', 'ヒノシ', '下田', 'シモダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都日野市万願寺', '13', '13212', '1910024', '東京都', 'トウキョウト', '日野市', 'ヒノシ', '万願寺', 'マンガンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都日野市高幡', '13', '13212', '1910031', '東京都', 'トウキョウト', '日野市', 'ヒノシ', '高幡', 'タカハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都日野市三沢', '13', '13212', '1910032', '東京都', 'トウキョウト', '日野市', 'ヒノシ', '三沢', 'ミサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都日野市百草', '13', '13212', '1910033', '東京都', 'トウキョウト', '日野市', 'ヒノシ', '百草', 'モグサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都日野市落川', '13', '13212', '1910034', '東京都', 'トウキョウト', '日野市', 'ヒノシ', '落川', 'オチカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都日野市南平', '13', '13212', '1910041', '東京都', 'トウキョウト', '日野市', 'ヒノシ', '南平', 'ミナミダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都日野市程久保', '13', '13212', '1910042', '東京都', 'トウキョウト', '日野市', 'ヒノシ', '程久保', 'ホドクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都日野市平山', '13', '13212', '1910043', '東京都', 'トウキョウト', '日野市', 'ヒノシ', '平山', 'ヒラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都日野市豊田', '13', '13212', '1910051', '東京都', 'トウキョウト', '日野市', 'ヒノシ', '豊田', 'トヨダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都日野市東豊田', '13', '13212', '1910052', '東京都', 'トウキョウト', '日野市', 'ヒノシ', '東豊田', 'ヒガシトヨダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都日野市豊田', '13', '13212', '1910053', '東京都', 'トウキョウト', '日野市', 'ヒノシ', '豊田', 'トヨダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都日野市東平山', '13', '13212', '1910054', '東京都', 'トウキョウト', '日野市', 'ヒノシ', '東平山', 'ヒガシヒラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都日野市西平山', '13', '13212', '1910055', '東京都', 'トウキョウト', '日野市', 'ヒノシ', '西平山', 'ニシヒラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都日野市大坂上', '13', '13212', '1910061', '東京都', 'トウキョウト', '日野市', 'ヒノシ', '大坂上', 'オオサカウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都日野市多摩平', '13', '13212', '1910062', '東京都', 'トウキョウト', '日野市', 'ヒノシ', '多摩平', 'タマダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都日野市さくら町', '13', '13212', '1910063', '東京都', 'トウキョウト', '日野市', 'ヒノシ', 'さくら町', 'サクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都日野市富士町', '13', '13212', '1910064', '東京都', 'トウキョウト', '日野市', 'ヒノシ', '富士町', 'フジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都日野市旭が丘', '13', '13212', '1910065', '東京都', 'トウキョウト', '日野市', 'ヒノシ', '旭が丘', 'アサヒガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市山内大松川', '05', '05203', '0191101', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '山内大松川', 'サンナイオオマツカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市山内小松川', '05', '05203', '0191102', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '山内小松川', 'サンナイコマツカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市山内黒沢', '05', '05203', '0191103', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '山内黒沢', 'サンナイクロサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市山内三又', '05', '05203', '0191104', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '山内三又', 'サンナイミツマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市山内南郷', '05', '05203', '0191105', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '山内南郷', 'サンナイナンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市山内平野沢', '05', '05203', '0191106', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '山内平野沢', 'サンナイヒラノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市山内筏', '05', '05203', '0191107', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '山内筏', 'サンナイイカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市山内土渕', '05', '05203', '0191108', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '山内土渕', 'サンナイツチブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県横手市山内大沢', '05', '05203', '0191109', '秋田県', 'アキタケン', '横手市', 'ヨコテシ', '山内大沢', 'サンナイオオサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県仙北郡美郷町南町', '05', '05434', '0191231', '秋田県', 'アキタケン', '仙北郡美郷町', 'センボクグンミサトチョウ', '南町', 'ミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県仙北郡美郷町天神堂', '05', '05434', '0191232', '秋田県', 'アキタケン', '仙北郡美郷町', 'センボクグンミサトチョウ', '天神堂', 'テンジンドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県仙北郡美郷町境田', '05', '05434', '0191233', '秋田県', 'アキタケン', '仙北郡美郷町', 'センボクグンミサトチョウ', '境田', 'サカイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県仙北郡美郷町飯詰', '05', '05434', '0191234', '秋田県', 'アキタケン', '仙北郡美郷町', 'センボクグンミサトチョウ', '飯詰', 'イイヅメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県仙北郡美郷町金沢西根', '05', '05434', '0191235', '秋田県', 'アキタケン', '仙北郡美郷町', 'センボクグンミサトチョウ', '金沢西根', 'カネザワニシネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県仙北郡美郷町上深井', '05', '05434', '0191236', '秋田県', 'アキタケン', '仙北郡美郷町', 'センボクグンミサトチョウ', '上深井', 'カミフカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県仙北郡美郷町佐野', '05', '05434', '0191237', '秋田県', 'アキタケン', '仙北郡美郷町', 'センボクグンミサトチョウ', '佐野', 'サノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県仙北郡美郷町野荒町', '05', '05434', '0191301', '秋田県', 'アキタケン', '仙北郡美郷町', 'センボクグンミサトチョウ', '野荒町', 'ノアラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県仙北郡美郷町金沢', '05', '05434', '0191302', '秋田県', 'アキタケン', '仙北郡美郷町', 'センボクグンミサトチョウ', '金沢', 'カネザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県仙北郡美郷町', '05', '05434', '0191400', '秋田県', 'アキタケン', '仙北郡美郷町', 'センボクグンミサトチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('9811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県仙北郡美郷町鑓田', '05', '05434', '0191401', '秋田県', 'アキタケン', '仙北郡美郷町', 'センボクグンミサトチョウ', '鑓田', 'ヤリダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県仙北郡美郷町野中', '05', '05434', '0191402', '秋田県', 'アキタケン', '仙北郡美郷町', 'センボクグンミサトチョウ', '野中', 'ノナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県仙北郡美郷町六郷東根', '05', '05434', '0191403', '秋田県', 'アキタケン', '仙北郡美郷町', 'センボクグンミサトチョウ', '六郷東根', 'ロクゴウヒガシネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県仙北郡美郷町六郷', '05', '05434', '0191404', '秋田県', 'アキタケン', '仙北郡美郷町', 'センボクグンミサトチョウ', '六郷', 'ロクゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県仙北郡美郷町浪花', '05', '05434', '0191501', '秋田県', 'アキタケン', '仙北郡美郷町', 'センボクグンミサトチョウ', '浪花', 'ナニワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県仙北郡美郷町千屋', '05', '05434', '0191502', '秋田県', 'アキタケン', '仙北郡美郷町', 'センボクグンミサトチョウ', '千屋', 'センヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県仙北郡美郷町黒沢', '05', '05434', '0191511', '秋田県', 'アキタケン', '仙北郡美郷町', 'センボクグンミサトチョウ', '黒沢', 'クロサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県仙北郡美郷町本堂城回', '05', '05434', '0191512', '秋田県', 'アキタケン', '仙北郡美郷町', 'センボクグンミサトチョウ', '本堂城回', 'ホンドウシロマワリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県仙北郡美郷町中野', '05', '05434', '0191521', '秋田県', 'アキタケン', '仙北郡美郷町', 'センボクグンミサトチョウ', '中野', 'ナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県仙北郡美郷町金沢東根', '05', '05434', '0191522', '秋田県', 'アキタケン', '仙北郡美郷町', 'センボクグンミサトチョウ', '金沢東根', 'カネザワヒガシネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県仙北郡美郷町畑屋', '05', '05434', '0191531', '秋田県', 'アキタケン', '仙北郡美郷町', 'センボクグンミサトチョウ', '畑屋', 'ハタヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県仙北郡美郷町羽貫谷地', '05', '05434', '0191532', '秋田県', 'アキタケン', '仙北郡美郷町', 'センボクグンミサトチョウ', '羽貫谷地', 'ハヌキヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県仙北郡美郷町安城寺', '05', '05434', '0191533', '秋田県', 'アキタケン', '仙北郡美郷町', 'センボクグンミサトチョウ', '安城寺', 'アンジョウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県仙北郡美郷町土崎', '05', '05434', '0191541', '秋田県', 'アキタケン', '仙北郡美郷町', 'センボクグンミサトチョウ', '土崎', 'ツチザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県仙北郡美郷町小荒川', '05', '05434', '0191542', '秋田県', 'アキタケン', '仙北郡美郷町', 'センボクグンミサトチョウ', '小荒川', 'コアラカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市太田町横沢', '05', '05212', '0191601', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '太田町横沢', 'オオタチョウヨコサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市太田町三本扇', '05', '05212', '0191602', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '太田町三本扇', 'オオタチョウサンボンオウギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市太田町中里', '05', '05212', '0191603', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '太田町中里', 'オオタチョウナカサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市太田町駒場', '05', '05212', '0191604', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '太田町駒場', 'オオタチョウコマバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市太田町国見', '05', '05212', '0191605', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '太田町国見', 'オオタチョウクニミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市太田町斉内', '05', '05212', '0191611', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '太田町斉内', 'オオタチョウサイナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市太田町小神成', '05', '05212', '0191612', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '太田町小神成', 'オオタチョウコガナリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市太田町太田', '05', '05212', '0191613', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '太田町太田', 'オオタチョウオオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市太田町東今泉', '05', '05212', '0191614', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '太田町東今泉', 'オオタチョウヒガシイマイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市太田町川口', '05', '05212', '0191615', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '太田町川口', 'オオタチョウカワグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市太田町永代', '05', '05212', '0191616', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '太田町永代', 'オオタチョウエイダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市神宮寺', '05', '05212', '0191701', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '神宮寺', 'ジングウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市北楢岡', '05', '05212', '0191702', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '北楢岡', 'キタナラオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外物渡台', '05', '05212', '0191801', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外物渡台', 'ナンガイブツドダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外小春木沢', '05', '05212', '0191802', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外小春木沢', 'ナンガイコハルキザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外坊田石兀ノ下', '05', '05212', '0191803', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外坊田石兀ノ下', 'ナンガイボウダイシハゲノシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外西野', '05', '05212', '0191804', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外西野', 'ナンガイニシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外西板戸', '05', '05212', '0191805', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外西板戸', 'ナンガイニシイタド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外十二袋', '05', '05212', '0191806', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外十二袋', 'ナンガイジュウニフクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外川口本町', '05', '05212', '0191807', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外川口本町', 'ナンガイカワグチホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外川口', '05', '05212', '0191808', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外川口', 'ナンガイカワグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外本宿', '05', '05212', '0191811', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外本宿', 'ナンガイモトシュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外沖田', '05', '05212', '0191812', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外沖田', 'ナンガイオキダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外猿ケ瀬出野', '05', '05212', '0191813', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外猿ケ瀬出野', 'ナンガイサルガセデノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外下木直', '05', '05212', '0191814', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外下木直', 'ナンガイシモキジキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外平形', '05', '05212', '0191815', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外平形', 'ナンガイヒラカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外上木直', '05', '05212', '0191816', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外上木直', 'ナンガイカミキジキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外木直沢', '05', '05212', '0191817', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外木直沢', 'ナンガイキジキザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外田屋村', '05', '05212', '0191822', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外田屋村', 'ナンガイタヤムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外宮田', '05', '05212', '0191824', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外宮田', 'ナンガイミヤタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外坊田', '05', '05212', '0191825', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外坊田', 'ナンガイボウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外田中田', '05', '05212', '0191826', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外田中田', 'ナンガイタナカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外田中田山根', '05', '05212', '0191827', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外田中田山根', 'ナンガイタナカタヤマネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外壇ノ平山', '05', '05212', '0191831', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外壇ノ平山', 'ナンガイダンノヒラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外北田山田ケ沢', '05', '05212', '0191832', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外北田山田ケ沢', 'ナンガイキタダヤマダガサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外揚土山', '05', '05212', '0191834', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外揚土山', 'ナンガイアゲツチヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外北田黒瀬', '05', '05212', '0191834', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外北田黒瀬', 'ナンガイキタダクロセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外揚土', '05', '05212', '0191835', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外揚土', 'ナンガイアゲツチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外大杉山岸', '05', '05212', '0191841', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外大杉山岸', 'ナンガイオオスギヤマギシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外大杉', '05', '05212', '0191842', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外大杉', 'ナンガイオオスギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外大杉二タ又杉', '05', '05212', '0191843', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外大杉二タ又杉', 'ナンガイオオスギフタマタスギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外梨木田', '05', '05212', '0191846', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外梨木田', 'ナンガイナシキダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外小出', '05', '05212', '0191847', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外小出', 'ナンガイコイデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外鞦田', '05', '05212', '0191848', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外鞦田', 'ナンガイシリガイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外山王台', '05', '05212', '0191851', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外山王台', 'ナンガイサンオウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外太田', '05', '05212', '0191852', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外太田', 'ナンガイオオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外坊田黒沢', '05', '05212', '0191853', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外坊田黒沢', 'ナンガイボウダクロサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外大畑', '05', '05212', '0191855', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外大畑', 'ナンガイオオバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外大畑深山', '05', '05212', '0191856', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外大畑深山', 'ナンガイオオバタミヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外大畑潜沢', '05', '05212', '0191857', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外大畑潜沢', 'ナンガイオオバタクグリサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外赤平六郎沢', '05', '05212', '0191858', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外赤平六郎沢', 'ナンガイアカヒラロクロウサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外寺沢', '05', '05212', '0191861', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外寺沢', 'ナンガイテラサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外和合', '05', '05212', '0191862', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外和合', 'ナンガイワゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外赤平貝沼', '05', '05212', '0191863', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外赤平貝沼', 'ナンガイアカヒラカイヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外赤平大道東', '05', '05212', '0191864', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外赤平大道東', 'ナンガイアカヒラダイドウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外赤平後野', '05', '05212', '0191865', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外赤平後野', 'ナンガイアカヒラウシロノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外赤平台野', '05', '05212', '0191866', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外赤平台野', 'ナンガイアカヒラダイノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外赤平平家', '05', '05212', '0191868', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外赤平平家', 'ナンガイアカヒラヘイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外谷地田', '05', '05212', '0191871', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外谷地田', 'ナンガイヤチダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外上中宿', '05', '05212', '0191872', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外上中宿', 'ナンガイカミナカシュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外田中', '05', '05212', '0191873', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外田中', 'ナンガイタナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外中宿', '05', '05212', '0191874', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外中宿', 'ナンガイナカシュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外落合', '05', '05212', '0191875', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外落合', 'ナンガイオチアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外新屋布', '05', '05212', '0191876', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外新屋布', 'ナンガイアラヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外水沢', '05', '05212', '0191877', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外水沢', 'ナンガイミズサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外及位', '05', '05212', '0191878', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外及位', 'ナンガイノゾキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外葎沢', '05', '05212', '0191881', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外葎沢', 'ナンガイムグラサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外大和野', '05', '05212', '0191882', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外大和野', 'ナンガイオオワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外平沢', '05', '05212', '0191883', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外平沢', 'ナンガイヒラサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外林ノ沢', '05', '05212', '0191884', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外林ノ沢', 'ナンガイハヤシノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外無尻橋', '05', '05212', '0191885', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外無尻橋', 'ナンガイムジリバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外西ノ又', '05', '05212', '0191886', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外西ノ又', 'ナンガイニシノマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外中渡', '05', '05212', '0191887', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外中渡', 'ナンガイナカワタリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外土場', '05', '05212', '0191888', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外土場', 'ナンガイドバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外悪戸野', '05', '05212', '0191901', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外悪戸野', 'ナンガイアクトノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外下袋', '05', '05212', '0191902', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外下袋', 'ナンガイシモブクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外下鎌田', '05', '05212', '0191903', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外下鎌田', 'ナンガイシモカマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外中袋', '05', '05212', '0191904', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外中袋', 'ナンガイナカブクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外大向', '05', '05212', '0191905', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外大向', 'ナンガイオオムカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外金屋', '05', '05212', '0191906', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外金屋', 'ナンガイカナヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外上鎌田', '05', '05212', '0191907', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外上鎌田', 'ナンガイカミカマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外上野', '05', '05212', '0191908', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外上野', 'ナンガイウエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外杉橋', '05', '05212', '0191909', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外杉橋', 'ナンガイスギハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外坊村', '05', '05212', '0191911', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外坊村', 'ナンガイボウムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外丸木橋', '05', '05212', '0191912', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外丸木橋', 'ナンガイマルキバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外湯神台', '05', '05212', '0191913', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外湯神台', 'ナンガイユガミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外湯ノ又', '05', '05212', '0191914', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外湯ノ又', 'ナンガイユノマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外下湯ノ又', '05', '05212', '0191915', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外下湯ノ又', 'ナンガイシモユノマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外石仏', '05', '05212', '0191916', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外石仏', 'ナンガイイシボトケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外薬師堂', '05', '05212', '0191917', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外薬師堂', 'ナンガイヤクシドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外広表', '05', '05212', '0191918', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外広表', 'ナンガイヒロオモテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外中野', '05', '05212', '0191921', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外中野', 'ナンガイナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外上中野', '05', '05212', '0191922', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外上中野', 'ナンガイカミナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外巣ノ沢', '05', '05212', '0191923', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外巣ノ沢', 'ナンガイスノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外巣ノ沢石切場', '05', '05212', '0191924', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外巣ノ沢石切場', 'ナンガイスノサワイシキリバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外上巣ノ沢', '05', '05212', '0191925', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外上巣ノ沢', 'ナンガイカミスノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外上桑台', '05', '05212', '0191926', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外上桑台', 'ナンガイカミクワダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外中桑台', '05', '05212', '0191927', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外中桑台', 'ナンガイナカクワダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外滝中田表', '05', '05212', '0191928', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外滝中田表', 'ナンガイタキナカタオモテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外中野山', '05', '05212', '0191929', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外中野山', 'ナンガイナカノヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外下滝', '05', '05212', '0191931', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外下滝', 'ナンガイシモタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外大黒森', '05', '05212', '0191932', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外大黒森', 'ナンガイオオクロモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外滝ノ沢', '05', '05212', '0191933', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外滝ノ沢', 'ナンガイタキノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外田尻', '05', '05212', '0191934', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外田尻', 'ナンガイタジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外大平', '05', '05212', '0191935', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外大平', 'ナンガイオオヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外中荒沢', '05', '05212', '0191936', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外中荒沢', 'ナンガイナカアラサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外小荒沢', '05', '05212', '0191937', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外小荒沢', 'ナンガイコアラサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外下荒沢', '05', '05212', '0191938', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外下荒沢', 'ナンガイシモアラサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外水上沢', '05', '05212', '0191939', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外水上沢', 'ナンガイミズカミザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外松木田', '05', '05212', '0191941', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外松木田', 'ナンガイマツキダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外岩倉', '05', '05212', '0191942', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外岩倉', 'ナンガイイワクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外一ト刎', '05', '05212', '0191943', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外一ト刎', 'ナンガイヒトハネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外湯元', '05', '05212', '0191944', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外湯元', 'ナンガイユモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外岩瀬', '05', '05212', '0191945', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外岩瀬', 'ナンガイイワセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外十二ノ前', '05', '05212', '0191946', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外十二ノ前', 'ナンガイジュウニノマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外下釜坂', '05', '05212', '0191947', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外下釜坂', 'ナンガイシモカマサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外上釜坂', '05', '05212', '0191948', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外上釜坂', 'ナンガイカミカマサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外赤畑', '05', '05212', '0191949', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外赤畑', 'ナンガイアカハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外黒滝', '05', '05212', '0191951', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外黒滝', 'ナンガイクロタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外下荒又', '05', '05212', '0191952', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外下荒又', 'ナンガイシモアラマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外外小友', '05', '05212', '0191953', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外外小友', 'ナンガイソトオトモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外中荒又', '05', '05212', '0191954', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外中荒又', 'ナンガイナカアラマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外外山', '05', '05212', '0191955', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外外山', 'ナンガイソトヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外上荒又', '05', '05212', '0191956', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外上荒又', 'ナンガイカミアラマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外小浪滝', '05', '05212', '0191957', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外小浪滝', 'ナンガイザンザラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外向ノ沢', '05', '05212', '0191958', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外向ノ沢', 'ナンガイムカイノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外大柳', '05', '05212', '0191961', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外大柳', 'ナンガイオオヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外若林', '05', '05212', '0191962', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外若林', 'ナンガイワカバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市南外西ノ又滝ノ沢', '05', '05212', '0191963', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '南外西ノ又滝ノ沢', 'ナンガイニシノマタタキノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市', '13', '13201', '1920000', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('9971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市戸吹町', '13', '13201', '1920001', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '戸吹町', 'トブキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市高月町', '13', '13201', '1920002', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '高月町', 'タカツキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市丹木町', '13', '13201', '1920003', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '丹木町', 'タンギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市加住町', '13', '13201', '1920004', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '加住町', 'カスミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市宮下町', '13', '13201', '1920005', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '宮下町', 'ミヤシタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市滝山町', '13', '13201', '1920011', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '滝山町', 'タキヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市左入町', '13', '13201', '1920012', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '左入町', 'サニュウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市梅坪町', '13', '13201', '1920013', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '梅坪町', 'ウメツボマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市みつい台', '13', '13201', '1920014', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', 'みつい台', 'ミツイダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市中野町', '13', '13201', '1920015', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '中野町', 'ナカノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市谷野町', '13', '13201', '1920016', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '谷野町', 'ヤノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市丸山町', '13', '13201', '1920021', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '丸山町', 'マルヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市平町', '13', '13201', '1920022', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '平町', 'タイラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市久保山町', '13', '13201', '1920023', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '久保山町', 'クボヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市宇津木町', '13', '13201', '1920024', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '宇津木町', 'ウツキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市尾崎町', '13', '13201', '1920025', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '尾崎町', 'オサキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市小宮町', '13', '13201', '1920031', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '小宮町', 'コミヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市石川町', '13', '13201', '1920032', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '石川町', 'イシカワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市高倉町', '13', '13201', '1920033', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '高倉町', 'タカクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市大谷町', '13', '13201', '1920034', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '大谷町', 'オオヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市中野上町', '13', '13201', '1920041', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '中野上町', 'ナカノカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市中野山王', '13', '13201', '1920042', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '中野山王', 'ナカノサンノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市暁町', '13', '13201', '1920043', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '暁町', 'アカツキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市富士見町', '13', '13201', '1920044', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '富士見町', 'フジミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市大和田町', '13', '13201', '1920045', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '大和田町', 'オオワダマチ', null, null, null, null), ('9996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市明神町', '13', '13201', '1920046', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '明神町', 'ミョウジンチョウ', null, null, null, null), ('9997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市元本郷町', '13', '13201', '1920051', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '元本郷町', 'モトホンゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市本郷町', '13', '13201', '1920052', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '本郷町', 'ホンゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('9999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市八幡町', '13', '13201', '1920053', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '八幡町', 'ハチマンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市小門町', '13', '13201', '1920054', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '小門町', 'オカドマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市八木町', '13', '13201', '1920055', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '八木町', 'ヤギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市追分町', '13', '13201', '1920056', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '追分町', 'オイワケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市平岡町', '13', '13201', '1920061', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '平岡町', 'ヒラオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市大横町', '13', '13201', '1920062', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '大横町', 'オオヨコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市元横山町', '13', '13201', '1920063', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '元横山町', 'モトヨコヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市田町', '13', '13201', '1920064', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '田町', 'タマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市新町', '13', '13201', '1920065', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '新町', 'シンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市本町', '13', '13201', '1920066', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市八日町', '13', '13201', '1920071', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '八日町', 'ヨウカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市南町', '13', '13201', '1920072', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '南町', 'ミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市寺町', '13', '13201', '1920073', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '寺町', 'テラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市天神町', '13', '13201', '1920074', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '天神町', 'テンジンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市南新町', '13', '13201', '1920075', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '南新町', 'ミナミシンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市横山町', '13', '13201', '1920081', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '横山町', 'ヨコヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市東町', '13', '13201', '1920082', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '東町', 'アズマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市旭町', '13', '13201', '1920083', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '旭町', 'アサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市三崎町', '13', '13201', '1920084', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '三崎町', 'ミサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市中町', '13', '13201', '1920085', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '中町', 'ナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市上川町', '13', '13201', '1920151', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '上川町', 'カミカワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市美山町', '13', '13201', '1920152', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '美山町', 'ミヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市西寺方町', '13', '13201', '1920153', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '西寺方町', 'ニシテラカタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市下恩方町', '13', '13201', '1920154', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '下恩方町', 'シモオンガタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市小津町', '13', '13201', '1920155', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '小津町', 'オツマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市上恩方町', '13', '13201', '1920156', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '上恩方町', 'カミオンガタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市東中野', '13', '13201', '1920351', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '東中野', 'ヒガシナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市大塚', '13', '13201', '1920352', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '大塚', 'オオツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市鹿島', '13', '13201', '1920353', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '鹿島', 'カシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市松が谷', '13', '13201', '1920354', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '松が谷', 'マツガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市堀之内', '13', '13201', '1920355', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '堀之内', 'ホリノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市越野', '13', '13201', '1920361', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '越野', 'コシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市松木', '13', '13201', '1920362', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '松木', 'マツギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市別所', '13', '13201', '1920363', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '別所', 'ベッショ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市南大沢', '13', '13201', '1920364', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '南大沢', 'ミナミオオサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市南陽台', '13', '13201', '1920371', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '南陽台', 'ナンヨウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市下柚木', '13', '13201', '1920372', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '下柚木', 'シモユギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市上柚木', '13', '13201', '1920373', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '上柚木', 'カミユギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市中山', '13', '13201', '1920374', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '中山', 'ナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市鑓水', '13', '13201', '1920375', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '鑓水', 'ヤリミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市上野町', '13', '13201', '1920902', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '上野町', 'ウエノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市万町', '13', '13201', '1920903', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '万町', 'ヨロズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市子安町', '13', '13201', '1920904', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '子安町', 'コヤスマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市北野町', '13', '13201', '1920906', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '北野町', 'キタノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市長沼町', '13', '13201', '1920907', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '長沼町', 'ナガヌママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市打越町', '13', '13201', '1920911', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '打越町', 'ウチコシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市絹ケ丘', '13', '13201', '1920912', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '絹ケ丘', 'キヌガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市北野台', '13', '13201', '1920913', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '北野台', 'キタノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市片倉町', '13', '13201', '1920914', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '片倉町', 'カタクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市宇津貫町', '13', '13201', '1920915', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '宇津貫町', 'ウツヌキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市みなみ野', '13', '13201', '1920916', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', 'みなみ野', 'ミナミノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市西片倉', '13', '13201', '1920917', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '西片倉', 'ニシカタクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市兵衛', '13', '13201', '1920918', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '兵衛', 'ヒョウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市七国', '13', '13201', '1920919', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '七国', 'ナナクニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市大沢郷寺', '05', '05212', '0192103', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '大沢郷寺', 'オオサワゴウテラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市土川', '05', '05212', '0192111', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '土川', 'ツチカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市刈和野', '05', '05212', '0192112', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '刈和野', 'カリワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市北野目', '05', '05212', '0192121', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '北野目', 'キタノメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市高城', '05', '05212', '0192122', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '高城', 'タカジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市寺館', '05', '05212', '0192123', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '寺館', 'テラダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市円行寺', '05', '05212', '0192201', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '円行寺', 'エンギョウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市大沢郷宿', '05', '05212', '0192202', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '大沢郷宿', 'オオサワゴウシュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市正手沢', '05', '05212', '0192204', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '正手沢', 'ショウテザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市杉山田', '05', '05212', '0192205', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '杉山田', 'スギヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市大巻', '05', '05212', '0192331', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '大巻', 'オオマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市九升田', '05', '05212', '0192332', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '九升田', 'クショウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市金山沢', '05', '05212', '0192333', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '金山沢', 'カネヤマサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市木原田', '05', '05212', '0192334', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '木原田', 'キハラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市強首', '05', '05212', '0192335', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '強首', 'コワクビ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市協和船岡', '05', '05212', '0192401', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '協和船岡', 'キョウワフナオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市協和船沢', '05', '05212', '0192402', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '協和船沢', 'キョウワフネサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市協和境', '05', '05212', '0192411', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '協和境', 'キョウワサカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市協和荒川', '05', '05212', '0192412', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '協和荒川', 'キョウワアラカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市協和上淀川', '05', '05212', '0192413', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '協和上淀川', 'キョウワカミヨドカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市協和峰吉川', '05', '05212', '0192431', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '協和峰吉川', 'キョウワミネヨシカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市協和小種', '05', '05212', '0192441', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '協和小種', 'キョウワコタネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市協和下淀川', '05', '05212', '0192442', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '協和下淀川', 'キョウワシモヨドカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市協和中淀川', '05', '05212', '0192443', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '協和中淀川', 'キョウワナカヨドカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県大仙市協和稲沢', '05', '05212', '0192521', '秋田県', 'アキタケン', '大仙市', 'ダイセンシ', '協和稲沢', 'キョウワイナザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市河辺和田', '05', '05201', '0192601', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '河辺和田', 'カワベワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市河辺戸島', '05', '05201', '0192611', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '河辺戸島', 'カワベトシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市河辺畑谷', '05', '05201', '0192612', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '河辺畑谷', 'カワベハタヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市河辺松渕', '05', '05201', '0192613', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '河辺松渕', 'カワベマツブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市河辺豊成', '05', '05201', '0192614', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '河辺豊成', 'カワベトヨナリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市河辺諸井', '05', '05201', '0192621', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '河辺諸井', 'カワベモロイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市河辺高岡', '05', '05201', '0192622', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '河辺高岡', 'カワベタカオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市河辺赤平', '05', '05201', '0192623', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '河辺赤平', 'カワベアカヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市河辺大沢', '05', '05201', '0192624', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '河辺大沢', 'カワベオオサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市河辺北野田高屋', '05', '05201', '0192625', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '河辺北野田高屋', 'カワベキタノダコウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市河辺神内', '05', '05201', '0192631', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '河辺神内', 'カワベジンナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市河辺大張野', '05', '05201', '0192632', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '河辺大張野', 'カワベオオバリノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市河辺岩見', '05', '05201', '0192741', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '河辺岩見', 'カワベイワミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '秋田県秋田市河辺三内', '05', '05201', '0192742', '秋田県', 'アキタケン', '秋田市', 'アキタシ', '河辺三内', 'カワベサンナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市川口町', '13', '13201', '1930801', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '川口町', 'カワグチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市犬目町', '13', '13201', '1930802', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '犬目町', 'イヌメマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市楢原町', '13', '13201', '1930803', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '楢原町', 'ナラハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市清川町', '13', '13201', '1930804', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '清川町', 'キヨカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市上壱分方町', '13', '13201', '1930811', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '上壱分方町', 'カミイチブカタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市諏訪町', '13', '13201', '1930812', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '諏訪町', 'スワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市四谷町', '13', '13201', '1930813', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '四谷町', 'ヨツヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市泉町', '13', '13201', '1930814', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '泉町', 'イズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市叶谷町', '13', '13201', '1930815', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '叶谷町', 'カノウヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市大楽寺町', '13', '13201', '1930816', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '大楽寺町', 'ダイラクジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市川町', '13', '13201', '1930821', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '川町', 'カワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市弐分方町', '13', '13201', '1930822', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '弐分方町', 'ニブカタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市横川町', '13', '13201', '1930823', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '横川町', 'ヨコカワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市長房町', '13', '13201', '1930824', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '長房町', 'ナガブサマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市城山手', '13', '13201', '1930825', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '城山手', 'シロヤマテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市元八王子町', '13', '13201', '1930826', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '元八王子町', 'モトハチオウジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市並木町', '13', '13201', '1930831', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '並木町', 'ナミキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市散田町', '13', '13201', '1930832', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '散田町', 'サンダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市めじろ台', '13', '13201', '1930833', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', 'めじろ台', 'メジロダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市東浅川町', '13', '13201', '1930834', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '東浅川町', 'ヒガシアサカワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市千人町', '13', '13201', '1930835', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '千人町', 'センニンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市日吉町', '13', '13201', '1930836', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '日吉町', 'ヒヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市裏高尾町', '13', '13201', '1930841', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '裏高尾町', 'ウラタカオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市西浅川町', '13', '13201', '1930842', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '西浅川町', 'ニシアサカワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市廿里町', '13', '13201', '1930843', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '廿里町', 'トドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市高尾町', '13', '13201', '1930844', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '高尾町', 'タカオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市初沢町', '13', '13201', '1930845', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '初沢町', 'ハツザワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市南浅川町', '13', '13201', '1930846', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '南浅川町', 'ミナミアサカワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市台町', '13', '13201', '1930931', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '台町', 'ダイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市緑町', '13', '13201', '1930932', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '緑町', 'ミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市山田町', '13', '13201', '1930933', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '山田町', 'ヤマタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市小比企町', '13', '13201', '1930934', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '小比企町', 'コビキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市大船町', '13', '13201', '1930935', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '大船町', 'オオフネマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市狭間町', '13', '13201', '1930941', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '狭間町', 'ハザママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市椚田町', '13', '13201', '1930942', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '椚田町', 'クヌギダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市寺田町', '13', '13201', '1930943', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '寺田町', 'テラダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都八王子市館町', '13', '13201', '1930944', '東京都', 'トウキョウト', '八王子市', 'ハチオウジシ', '館町', 'タテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都町田市', '13', '13209', '1940000', '東京都', 'トウキョウト', '町田市', 'マチダシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('10198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都町田市つくし野', '13', '13209', '1940001', '東京都', 'トウキョウト', '町田市', 'マチダシ', 'つくし野', 'ツクシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都町田市南つくし野', '13', '13209', '1940002', '東京都', 'トウキョウト', '町田市', 'マチダシ', '南つくし野', 'ミナミツクシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都町田市小川', '13', '13209', '1940003', '東京都', 'トウキョウト', '町田市', 'マチダシ', '小川', 'オガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都町田市鶴間', '13', '13209', '1940004', '東京都', 'トウキョウト', '町田市', 'マチダシ', '鶴間', 'ツルマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都町田市成瀬が丘', '13', '13209', '1940011', '東京都', 'トウキョウト', '町田市', 'マチダシ', '成瀬が丘', 'ナルセガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都町田市金森', '13', '13209', '1940012', '東京都', 'トウキョウト', '町田市', 'マチダシ', '金森', 'カナモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都町田市原町田', '13', '13209', '1940013', '東京都', 'トウキョウト', '町田市', 'マチダシ', '原町田', 'ハラマチダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都町田市高ケ坂', '13', '13209', '1940014', '東京都', 'トウキョウト', '町田市', 'マチダシ', '高ケ坂', 'コウガサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都町田市中町', '13', '13209', '1940021', '東京都', 'トウキョウト', '町田市', 'マチダシ', '中町', 'ナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都町田市森野', '13', '13209', '1940022', '東京都', 'トウキョウト', '町田市', 'マチダシ', '森野', 'モリノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都町田市旭町', '13', '13209', '1940023', '東京都', 'トウキョウト', '町田市', 'マチダシ', '旭町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都町田市南大谷', '13', '13209', '1940031', '東京都', 'トウキョウト', '町田市', 'マチダシ', '南大谷', 'ミナミオオヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都町田市本町田', '13', '13209', '1940032', '東京都', 'トウキョウト', '町田市', 'マチダシ', '本町田', 'ホンマチダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都町田市木曽町', '13', '13209', '1940033', '東京都', 'トウキョウト', '町田市', 'マチダシ', '木曽町', 'キソマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都町田市根岸町', '13', '13209', '1940034', '東京都', 'トウキョウト', '町田市', 'マチダシ', '根岸町', 'ネギシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都町田市忠生', '13', '13209', '1940035', '東京都', 'トウキョウト', '町田市', 'マチダシ', '忠生', 'タダオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都町田市木曽東', '13', '13209', '1940036', '東京都', 'トウキョウト', '町田市', 'マチダシ', '木曽東', 'キソヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都町田市木曽西', '13', '13209', '1940037', '東京都', 'トウキョウト', '町田市', 'マチダシ', '木曽西', 'キソニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都町田市根岸', '13', '13209', '1940038', '東京都', 'トウキョウト', '町田市', 'マチダシ', '根岸', 'ネギシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都町田市玉川学園', '13', '13209', '1940041', '東京都', 'トウキョウト', '町田市', 'マチダシ', '玉川学園', 'タマガワガクエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都町田市東玉川学園', '13', '13209', '1940042', '東京都', 'トウキョウト', '町田市', 'マチダシ', '東玉川学園', 'ヒガシタマガワガクエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都町田市成瀬台', '13', '13209', '1940043', '東京都', 'トウキョウト', '町田市', 'マチダシ', '成瀬台', 'ナルセダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都町田市成瀬', '13', '13209', '1940044', '東京都', 'トウキョウト', '町田市', 'マチダシ', '成瀬', 'ナルセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都町田市南成瀬', '13', '13209', '1940045', '東京都', 'トウキョウト', '町田市', 'マチダシ', '南成瀬', 'ミナミナルセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都町田市上小山田町', '13', '13209', '1940201', '東京都', 'トウキョウト', '町田市', 'マチダシ', '上小山田町', 'カミオヤマダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都町田市下小山田町', '13', '13209', '1940202', '東京都', 'トウキョウト', '町田市', 'マチダシ', '下小山田町', 'シモオヤマダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都町田市図師町', '13', '13209', '1940203', '東京都', 'トウキョウト', '町田市', 'マチダシ', '図師町', 'ズシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都町田市小山田桜台', '13', '13209', '1940204', '東京都', 'トウキョウト', '町田市', 'マチダシ', '小山田桜台', 'オヤマダサクラダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都町田市相原町', '13', '13209', '1940211', '東京都', 'トウキョウト', '町田市', 'マチダシ', '相原町', 'アイハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都町田市小山町', '13', '13209', '1940212', '東京都', 'トウキョウト', '町田市', 'マチダシ', '小山町', 'オヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都町田市常盤町', '13', '13209', '1940213', '東京都', 'トウキョウト', '町田市', 'マチダシ', '常盤町', 'トキワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都町田市矢部町', '13', '13209', '1940214', '東京都', 'トウキョウト', '町田市', 'マチダシ', '矢部町', 'ヤベマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都町田市小山ケ丘', '13', '13209', '1940215', '東京都', 'トウキョウト', '町田市', 'マチダシ', '小山ケ丘', 'オヤマガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都町田市真光寺町', '13', '13209', '1950051', '東京都', 'トウキョウト', '町田市', 'マチダシ', '真光寺町', 'シンコウジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都町田市広袴町', '13', '13209', '1950052', '東京都', 'トウキョウト', '町田市', 'マチダシ', '広袴町', 'ヒロハカママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都町田市能ケ谷町', '13', '13209', '1950053', '東京都', 'トウキョウト', '町田市', 'マチダシ', '能ケ谷町', 'ノウガヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都町田市三輪町', '13', '13209', '1950054', '東京都', 'トウキョウト', '町田市', 'マチダシ', '三輪町', 'ミワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都町田市三輪緑山', '13', '13209', '1950055', '東京都', 'トウキョウト', '町田市', 'マチダシ', '三輪緑山', 'ミワミドリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都町田市広袴', '13', '13209', '1950056', '東京都', 'トウキョウト', '町田市', 'マチダシ', '広袴', 'ヒロバカマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都町田市真光寺', '13', '13209', '1950057', '東京都', 'トウキョウト', '町田市', 'マチダシ', '真光寺', 'シンコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都町田市鶴川', '13', '13209', '1950061', '東京都', 'トウキョウト', '町田市', 'マチダシ', '鶴川', 'ツルカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都町田市大蔵町', '13', '13209', '1950062', '東京都', 'トウキョウト', '町田市', 'マチダシ', '大蔵町', 'オオクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都町田市野津田町', '13', '13209', '1950063', '東京都', 'トウキョウト', '町田市', 'マチダシ', '野津田町', 'ノヅタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都町田市小野路町', '13', '13209', '1950064', '東京都', 'トウキョウト', '町田市', 'マチダシ', '小野路町', 'オノジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都町田市金井町', '13', '13209', '1950071', '東京都', 'トウキョウト', '町田市', 'マチダシ', '金井町', 'カナイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都町田市金井', '13', '13209', '1950072', '東京都', 'トウキョウト', '町田市', 'マチダシ', '金井', 'カナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都町田市薬師台', '13', '13209', '1950073', '東京都', 'トウキョウト', '町田市', 'マチダシ', '薬師台', 'ヤクシダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都町田市山崎町', '13', '13209', '1950074', '東京都', 'トウキョウト', '町田市', 'マチダシ', '山崎町', 'ヤマサキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都昭島市', '13', '13207', '1960000', '東京都', 'トウキョウト', '昭島市', 'アキシマシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('10287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都昭島市美堀町', '13', '13207', '1960001', '東京都', 'トウキョウト', '昭島市', 'アキシマシ', '美堀町', 'ミホリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都昭島市拝島町', '13', '13207', '1960002', '東京都', 'トウキョウト', '昭島市', 'アキシマシ', '拝島町', 'ハイジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都昭島市松原町', '13', '13207', '1960003', '東京都', 'トウキョウト', '昭島市', 'アキシマシ', '松原町', 'マツバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都昭島市緑町', '13', '13207', '1960004', '東京都', 'トウキョウト', '昭島市', 'アキシマシ', '緑町', 'ミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都昭島市上川原町', '13', '13207', '1960011', '東京都', 'トウキョウト', '昭島市', 'アキシマシ', '上川原町', 'ジョウガワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都昭島市つつじが丘', '13', '13207', '1960012', '東京都', 'トウキョウト', '昭島市', 'アキシマシ', 'つつじが丘', 'ツツジガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都昭島市大神町', '13', '13207', '1960013', '東京都', 'トウキョウト', '昭島市', 'アキシマシ', '大神町', 'オオガミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都昭島市田中町', '13', '13207', '1960014', '東京都', 'トウキョウト', '昭島市', 'アキシマシ', '田中町', 'タナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都昭島市昭和町', '13', '13207', '1960015', '東京都', 'トウキョウト', '昭島市', 'アキシマシ', '昭和町', 'ショウワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都昭島市武蔵野', '13', '13207', '1960021', '東京都', 'トウキョウト', '昭島市', 'アキシマシ', '武蔵野', 'ムサシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都昭島市中神町', '13', '13207', '1960022', '東京都', 'トウキョウト', '昭島市', 'アキシマシ', '中神町', 'ナカガミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都昭島市築地町', '13', '13207', '1960023', '東京都', 'トウキョウト', '昭島市', 'アキシマシ', '築地町', 'ツイジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都昭島市宮沢町', '13', '13207', '1960024', '東京都', 'トウキョウト', '昭島市', 'アキシマシ', '宮沢町', 'ミヤザワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都昭島市朝日町', '13', '13207', '1960025', '東京都', 'トウキョウト', '昭島市', 'アキシマシ', '朝日町', 'アサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都昭島市福島町', '13', '13207', '1960031', '東京都', 'トウキョウト', '昭島市', 'アキシマシ', '福島町', 'フクジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都昭島市郷地町', '13', '13207', '1960032', '東京都', 'トウキョウト', '昭島市', 'アキシマシ', '郷地町', 'ゴウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都昭島市東町', '13', '13207', '1960033', '東京都', 'トウキョウト', '昭島市', 'アキシマシ', '東町', 'アズマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都昭島市玉川町', '13', '13207', '1960034', '東京都', 'トウキョウト', '昭島市', 'アキシマシ', '玉川町', 'タマガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都福生市', '13', '13218', '1970000', '東京都', 'トウキョウト', '福生市', 'フッサシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('10320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都福生市横田基地内', '13', '13218', '1970001', '東京都', 'トウキョウト', '福生市', 'フッサシ', '横田基地内', 'ヨコタキチナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都福生市熊川二宮', '13', '13218', '1970002', '東京都', 'トウキョウト', '福生市', 'フッサシ', '熊川二宮', 'クマガワニノミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都福生市熊川', '13', '13218', '1970003', '東京都', 'トウキョウト', '福生市', 'フッサシ', '熊川', 'クマガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都福生市南田園', '13', '13218', '1970004', '東京都', 'トウキョウト', '福生市', 'フッサシ', '南田園', 'ミナミデンエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都福生市北田園', '13', '13218', '1970005', '東京都', 'トウキョウト', '福生市', 'フッサシ', '北田園', 'キタデンエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都福生市福生', '13', '13218', '1970011', '東京都', 'トウキョウト', '福生市', 'フッサシ', '福生', 'フッサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都福生市加美平', '13', '13218', '1970012', '東京都', 'トウキョウト', '福生市', 'フッサシ', '加美平', 'カミダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都福生市武蔵野台', '13', '13218', '1970013', '東京都', 'トウキョウト', '福生市', 'フッサシ', '武蔵野台', 'ムサシノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都福生市福生二宮', '13', '13218', '1970014', '東京都', 'トウキョウト', '福生市', 'フッサシ', '福生二宮', 'フッサニノミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都福生市東町', '13', '13218', '1970021', '東京都', 'トウキョウト', '福生市', 'フッサシ', '東町', 'ヒガシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都福生市本町', '13', '13218', '1970022', '東京都', 'トウキョウト', '福生市', 'フッサシ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都福生市志茂', '13', '13218', '1970023', '東京都', 'トウキョウト', '福生市', 'フッサシ', '志茂', 'シモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都福生市牛浜', '13', '13218', '1970024', '東京都', 'トウキョウト', '福生市', 'フッサシ', '牛浜', 'ウシハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都あきる野市菅生', '13', '13228', '1970801', '東京都', 'トウキョウト', 'あきる野市', 'アキルノシ', '菅生', 'スガオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都あきる野市草花', '13', '13228', '1970802', '東京都', 'トウキョウト', 'あきる野市', 'アキルノシ', '草花', 'クサバナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都あきる野市瀬戸岡', '13', '13228', '1970803', '東京都', 'トウキョウト', 'あきる野市', 'アキルノシ', '瀬戸岡', 'セドオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都あきる野市秋川', '13', '13228', '1970804', '東京都', 'トウキョウト', 'あきる野市', 'アキルノシ', '秋川', 'アキガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都あきる野市原小宮', '13', '13228', '1970811', '東京都', 'トウキョウト', 'あきる野市', 'アキルノシ', '原小宮', 'ハラコミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都あきる野市平沢', '13', '13228', '1970812', '東京都', 'トウキョウト', 'あきる野市', 'アキルノシ', '平沢', 'ヒラサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都あきる野市平沢東', '13', '13228', '1970813', '東京都', 'トウキョウト', 'あきる野市', 'アキルノシ', '平沢東', 'ヒラサワヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都あきる野市二宮', '13', '13228', '1970814', '東京都', 'トウキョウト', 'あきる野市', 'アキルノシ', '二宮', 'ニノミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都あきる野市二宮東', '13', '13228', '1970815', '東京都', 'トウキョウト', 'あきる野市', 'アキルノシ', '二宮東', 'ニノミヤヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都あきる野市平沢西', '13', '13228', '1970816', '東京都', 'トウキョウト', 'あきる野市', 'アキルノシ', '平沢西', 'ヒラサワニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都あきる野市小川', '13', '13228', '1970821', '東京都', 'トウキョウト', 'あきる野市', 'アキルノシ', '小川', 'オガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都あきる野市小川東', '13', '13228', '1970822', '東京都', 'トウキョウト', 'あきる野市', 'アキルノシ', '小川東', 'オガワヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都あきる野市野辺', '13', '13228', '1970823', '東京都', 'トウキョウト', 'あきる野市', 'アキルノシ', '野辺', 'ノベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都あきる野市切欠', '13', '13228', '1970824', '東京都', 'トウキョウト', 'あきる野市', 'アキルノシ', '切欠', 'キッカケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都あきる野市雨間', '13', '13228', '1970825', '東京都', 'トウキョウト', 'あきる野市', 'アキルノシ', '雨間', 'アメマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都あきる野市牛沼', '13', '13228', '1970826', '東京都', 'トウキョウト', 'あきる野市', 'アキルノシ', '牛沼', 'ウシヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都あきる野市油平', '13', '13228', '1970827', '東京都', 'トウキョウト', 'あきる野市', 'アキルノシ', '油平', 'アブラダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都あきる野市秋留', '13', '13228', '1970828', '東京都', 'トウキョウト', 'あきる野市', 'アキルノシ', '秋留', 'アキル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都あきる野市下代継', '13', '13228', '1970831', '東京都', 'トウキョウト', 'あきる野市', 'アキルノシ', '下代継', 'シモヨツギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都あきる野市上代継', '13', '13228', '1970832', '東京都', 'トウキョウト', 'あきる野市', 'アキルノシ', '上代継', 'カミヨツギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都あきる野市渕上', '13', '13228', '1970833', '東京都', 'トウキョウト', 'あきる野市', 'アキルノシ', '渕上', 'フチガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都あきる野市引田', '13', '13228', '1970834', '東京都', 'トウキョウト', 'あきる野市', 'アキルノシ', '引田', 'ヒキダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都青梅市', '13', '13205', '1980000', '東京都', 'トウキョウト', '青梅市', 'オウメシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('10362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都西多摩郡奥多摩町', '13', '13308', '1980000', '東京都', 'トウキョウト', '西多摩郡奥多摩町', 'ニシタマグンオクタママチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('10363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都青梅市成木', '13', '13205', '1980001', '東京都', 'トウキョウト', '青梅市', 'オウメシ', '成木', 'ナリキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都青梅市富岡', '13', '13205', '1980002', '東京都', 'トウキョウト', '青梅市', 'オウメシ', '富岡', 'トミオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都青梅市小曾木', '13', '13205', '1980003', '東京都', 'トウキョウト', '青梅市', 'オウメシ', '小曾木', 'オソキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都青梅市根ケ布', '13', '13205', '1980004', '東京都', 'トウキョウト', '青梅市', 'オウメシ', '根ケ布', 'ネカブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都青梅市黒沢', '13', '13205', '1980005', '東京都', 'トウキョウト', '青梅市', 'オウメシ', '黒沢', 'クロサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都青梅市塩船', '13', '13205', '1980011', '東京都', 'トウキョウト', '青梅市', 'オウメシ', '塩船', 'シオブネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都青梅市谷野', '13', '13205', '1980012', '東京都', 'トウキョウト', '青梅市', 'オウメシ', '谷野', 'ヤノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都青梅市木野下', '13', '13205', '1980013', '東京都', 'トウキョウト', '青梅市', 'オウメシ', '木野下', 'キノシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都青梅市大門', '13', '13205', '1980014', '東京都', 'トウキョウト', '青梅市', 'オウメシ', '大門', 'ダイモン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都青梅市吹上', '13', '13205', '1980015', '東京都', 'トウキョウト', '青梅市', 'オウメシ', '吹上', 'フキアゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都青梅市今寺', '13', '13205', '1980021', '東京都', 'トウキョウト', '青梅市', 'オウメシ', '今寺', 'イマデラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都青梅市藤橋', '13', '13205', '1980022', '東京都', 'トウキョウト', '青梅市', 'オウメシ', '藤橋', 'フジハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都青梅市今井', '13', '13205', '1980023', '東京都', 'トウキョウト', '青梅市', 'オウメシ', '今井', 'イマイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都青梅市新町', '13', '13205', '1980024', '東京都', 'トウキョウト', '青梅市', 'オウメシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都青梅市末広町', '13', '13205', '1980025', '東京都', 'トウキョウト', '青梅市', 'オウメシ', '末広町', 'スエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都青梅市師岡町', '13', '13205', '1980031', '東京都', 'トウキョウト', '青梅市', 'オウメシ', '師岡町', 'モロオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都青梅市野上町', '13', '13205', '1980032', '東京都', 'トウキョウト', '青梅市', 'オウメシ', '野上町', 'ノガミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都青梅市河辺町', '13', '13205', '1980036', '東京都', 'トウキョウト', '青梅市', 'オウメシ', '河辺町', 'カベマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都青梅市勝沼', '13', '13205', '1980041', '東京都', 'トウキョウト', '青梅市', 'オウメシ', '勝沼', 'カツヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都青梅市東青梅', '13', '13205', '1980042', '東京都', 'トウキョウト', '青梅市', 'オウメシ', '東青梅', 'ヒガシオウメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都青梅市千ケ瀬町', '13', '13205', '1980043', '東京都', 'トウキョウト', '青梅市', 'オウメシ', '千ケ瀬町', 'チガセマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都青梅市西分町', '13', '13205', '1980044', '東京都', 'トウキョウト', '青梅市', 'オウメシ', '西分町', 'ニシワケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都青梅市日向和田', '13', '13205', '1980046', '東京都', 'トウキョウト', '青梅市', 'オウメシ', '日向和田', 'ヒナタワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都青梅市友田町', '13', '13205', '1980051', '東京都', 'トウキョウト', '青梅市', 'オウメシ', '友田町', 'トモダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都青梅市長淵', '13', '13205', '1980052', '東京都', 'トウキョウト', '青梅市', 'オウメシ', '長淵', 'ナガブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都青梅市駒木町', '13', '13205', '1980053', '東京都', 'トウキョウト', '青梅市', 'オウメシ', '駒木町', 'コマキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都青梅市畑中', '13', '13205', '1980061', '東京都', 'トウキョウト', '青梅市', 'オウメシ', '畑中', 'ハタナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都青梅市和田町', '13', '13205', '1980062', '東京都', 'トウキョウト', '青梅市', 'オウメシ', '和田町', 'ワダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都青梅市梅郷', '13', '13205', '1980063', '東京都', 'トウキョウト', '青梅市', 'オウメシ', '梅郷', 'バイゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都青梅市柚木町', '13', '13205', '1980064', '東京都', 'トウキョウト', '青梅市', 'オウメシ', '柚木町', 'ユギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都青梅市上町', '13', '13205', '1980081', '東京都', 'トウキョウト', '青梅市', 'オウメシ', '上町', 'カミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都青梅市仲町', '13', '13205', '1980082', '東京都', 'トウキョウト', '青梅市', 'オウメシ', '仲町', 'ナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都青梅市本町', '13', '13205', '1980083', '東京都', 'トウキョウト', '青梅市', 'オウメシ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都青梅市住江町', '13', '13205', '1980084', '東京都', 'トウキョウト', '青梅市', 'オウメシ', '住江町', 'スミエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都青梅市滝ノ上町', '13', '13205', '1980085', '東京都', 'トウキョウト', '青梅市', 'オウメシ', '滝ノ上町', 'タキノウエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都青梅市大柳町', '13', '13205', '1980086', '東京都', 'トウキョウト', '青梅市', 'オウメシ', '大柳町', 'オオヤナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都青梅市天ケ瀬町', '13', '13205', '1980087', '東京都', 'トウキョウト', '青梅市', 'オウメシ', '天ケ瀬町', 'アマガセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都青梅市裏宿町', '13', '13205', '1980088', '東京都', 'トウキョウト', '青梅市', 'オウメシ', '裏宿町', 'ウラジュクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都青梅市森下町', '13', '13205', '1980089', '東京都', 'トウキョウト', '青梅市', 'オウメシ', '森下町', 'モリシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都西多摩郡奥多摩町大丹波', '13', '13308', '1980101', '東京都', 'トウキョウト', '西多摩郡奥多摩町', 'ニシタマグンオクタママチ', '大丹波', 'オオタバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都西多摩郡奥多摩町川井', '13', '13308', '1980102', '東京都', 'トウキョウト', '西多摩郡奥多摩町', 'ニシタマグンオクタママチ', '川井', 'カワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都西多摩郡奥多摩町梅沢', '13', '13308', '1980103', '東京都', 'トウキョウト', '西多摩郡奥多摩町', 'ニシタマグンオクタママチ', '梅沢', 'ウメザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都西多摩郡奥多摩町丹三郎', '13', '13308', '1980104', '東京都', 'トウキョウト', '西多摩郡奥多摩町', 'ニシタマグンオクタママチ', '丹三郎', 'タンザブロウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都西多摩郡奥多摩町小丹波', '13', '13308', '1980105', '東京都', 'トウキョウト', '西多摩郡奥多摩町', 'ニシタマグンオクタママチ', '小丹波', 'コタバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都西多摩郡奥多摩町棚沢', '13', '13308', '1980106', '東京都', 'トウキョウト', '西多摩郡奥多摩町', 'ニシタマグンオクタママチ', '棚沢', 'タナザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都西多摩郡奥多摩町白丸', '13', '13308', '1980107', '東京都', 'トウキョウト', '西多摩郡奥多摩町', 'ニシタマグンオクタママチ', '白丸', 'シロマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都青梅市二俣尾', '13', '13205', '1980171', '東京都', 'トウキョウト', '青梅市', 'オウメシ', '二俣尾', 'フタマタオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都青梅市沢井', '13', '13205', '1980172', '東京都', 'トウキョウト', '青梅市', 'オウメシ', '沢井', 'サワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都青梅市御岳本町', '13', '13205', '1980173', '東京都', 'トウキョウト', '青梅市', 'オウメシ', '御岳本町', 'ミタケホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都青梅市御岳', '13', '13205', '1980174', '東京都', 'トウキョウト', '青梅市', 'オウメシ', '御岳', 'ミタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都青梅市御岳山', '13', '13205', '1980175', '東京都', 'トウキョウト', '青梅市', 'オウメシ', '御岳山', 'ミタケサン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都西多摩郡奥多摩町日原', '13', '13308', '1980211', '東京都', 'トウキョウト', '西多摩郡奥多摩町', 'ニシタマグンオクタママチ', '日原', 'ニッパラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都西多摩郡奥多摩町氷川', '13', '13308', '1980212', '東京都', 'トウキョウト', '西多摩郡奥多摩町', 'ニシタマグンオクタママチ', '氷川', 'ヒカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都西多摩郡奥多摩町海沢', '13', '13308', '1980213', '東京都', 'トウキョウト', '西多摩郡奥多摩町', 'ニシタマグンオクタママチ', '海沢', 'ウナザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都西多摩郡奥多摩町留浦', '13', '13308', '1980221', '東京都', 'トウキョウト', '西多摩郡奥多摩町', 'ニシタマグンオクタママチ', '留浦', 'トズラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都西多摩郡奥多摩町境', '13', '13308', '1980222', '東京都', 'トウキョウト', '西多摩郡奥多摩町', 'ニシタマグンオクタママチ', '境', 'サカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都西多摩郡奥多摩町原', '13', '13308', '1980223', '東京都', 'トウキョウト', '西多摩郡奥多摩町', 'ニシタマグンオクタママチ', '原', 'ハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都西多摩郡奥多摩町河内', '13', '13308', '1980224', '東京都', 'トウキョウト', '西多摩郡奥多摩町', 'ニシタマグンオクタママチ', '河内', 'コウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都西多摩郡奥多摩町川野', '13', '13308', '1980225', '東京都', 'トウキョウト', '西多摩郡奥多摩町', 'ニシタマグンオクタママチ', '川野', 'カワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市', '03', '03201', '0200000', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('10440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市上米内', '03', '03201', '0200001', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '上米内', 'カミヨナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市桜台', '03', '03201', '0200002', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '桜台', 'サクラダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市下米内', '03', '03201', '0200003', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '下米内', 'シモヨナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市山岸', '03', '03201', '0200004', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '山岸', 'ヤマギシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市紅葉が丘', '03', '03201', '0200005', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '紅葉が丘', 'モミジガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市三ツ割', '03', '03201', '0200011', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '三ツ割', 'ミツワリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市岩清水', '03', '03201', '0200012', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '岩清水', 'イワシミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市愛宕町', '03', '03201', '0200013', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '愛宕町', 'アタゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市愛宕下', '03', '03201', '0200014', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '愛宕下', 'アタゴシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市本町通', '03', '03201', '0200015', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '本町通', 'ホンチョウドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市名須川町', '03', '03201', '0200016', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '名須川町', 'ナスカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市中央通', '03', '03201', '0200021', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '中央通', 'チュウオウドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市大通', '03', '03201', '0200022', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '大通', 'オオドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市内丸', '03', '03201', '0200023', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '内丸', 'ウチマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市菜園', '03', '03201', '0200024', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '菜園', 'サイエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市大沢川原', '03', '03201', '0200025', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '大沢川原', 'オオサワカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市開運橋通', '03', '03201', '0200026', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '開運橋通', 'カイウンバシドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市北夕顔瀬町', '03', '03201', '0200031', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '北夕顔瀬町', 'キタユウガオセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市夕顔瀬町', '03', '03201', '0200032', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '夕顔瀬町', 'ユウガオセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市盛岡駅前北通', '03', '03201', '0200033', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '盛岡駅前北通', 'モリオカエキマエキタドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市盛岡駅前通', '03', '03201', '0200034', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '盛岡駅前通', 'モリオカエキマエドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市境田町', '03', '03201', '0200041', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '境田町', 'サカイダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市新田町', '03', '03201', '0200042', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '新田町', 'シンデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市中川町', '03', '03201', '0200043', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '中川町', 'ナカガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市城西町', '03', '03201', '0200044', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '城西町', 'ジョウセイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市盛岡駅西通', '03', '03201', '0200045', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '盛岡駅西通', 'モリオカエキニシトオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市下太田', '03', '03201', '0200051', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '下太田', 'シモオオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市中太田', '03', '03201', '0200052', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '中太田', 'ナカオオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市上太田', '03', '03201', '0200053', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '上太田', 'カミオオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市猪去', '03', '03201', '0200054', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '猪去', 'イサリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市繋', '03', '03201', '0200055', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '繋', 'ツナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市北山', '03', '03201', '0200061', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '北山', 'キタヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市長田町', '03', '03201', '0200062', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '長田町', 'ナガタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市材木町', '03', '03201', '0200063', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '材木町', 'ザイモクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市梨木町', '03', '03201', '0200064', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '梨木町', 'ナシノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市西下台町', '03', '03201', '0200065', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '西下台町', 'ニシシタダイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市上田1丁目', '03', '03201', '0200066', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '上田', 'ウエダ', null, null, '1丁目', '01チョウメ');
INSERT INTO `ms_addresses` VALUES ('10477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市上田2丁目', '03', '03201', '0200066', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '上田', 'ウエダ', null, null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('10478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市上田3丁目', '03', '03201', '0200066', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '上田', 'ウエダ', null, null, '3丁目', '03チョウメ');
INSERT INTO `ms_addresses` VALUES ('10479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市上田4丁目', '03', '03201', '0200066', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '上田', 'ウエダ', null, null, '4丁目', '04チョウメ');
INSERT INTO `ms_addresses` VALUES ('10480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市上田北山', '03', '03201', '0200066', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '上田', 'ウエダ', null, null, '北山', 'キタヤマ');
INSERT INTO `ms_addresses` VALUES ('10481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県岩手郡滝沢村', '03', '03305', '0200100', '岩手県', 'イワテケン', '岩手郡滝沢村', 'イワテグンタキザワムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('10482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市岩脇町', '03', '03201', '0200101', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '岩脇町', 'イワワキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市上田', '03', '03201', '0200102', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '上田', 'ウエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市西松園', '03', '03201', '0200103', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '西松園', 'ニシマツゾノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市小鳥沢', '03', '03201', '0200104', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '小鳥沢', 'コトリザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市北松園', '03', '03201', '0200105', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '北松園', 'キタマツゾノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市東松園', '03', '03201', '0200106', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '東松園', 'ヒガシマツゾノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市松園', '03', '03201', '0200107', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '松園', 'マツゾノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市東黒石野', '03', '03201', '0200108', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '東黒石野', 'ヒガシクロイシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市黒石野', '03', '03201', '0200111', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '黒石野', 'クロイシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市東緑が丘', '03', '03201', '0200112', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '東緑が丘', 'ヒガシミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市上田堤', '03', '03201', '0200113', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '上田堤', 'ウエダツツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市高松', '03', '03201', '0200114', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '高松', 'タカマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市館向町', '03', '03201', '0200115', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '館向町', 'タテムカイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市箱清水', '03', '03201', '0200116', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '箱清水', 'ハコシミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市緑が丘', '03', '03201', '0200117', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '緑が丘', 'ミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市月が丘', '03', '03201', '0200121', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '月が丘', 'ツキガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市みたけ', '03', '03201', '0200122', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', 'みたけ', 'ミタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市下厨川', '03', '03201', '0200123', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '下厨川', 'シモクリヤガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市厨川', '03', '03201', '0200124', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '厨川', 'クリヤガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市上堂', '03', '03201', '0200125', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '上堂', 'カミドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市安倍館町', '03', '03201', '0200126', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '安倍館町', 'アベタテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市前九年', '03', '03201', '0200127', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '前九年', 'ゼンクネン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市中堤町', '03', '03201', '0200131', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '中堤町', 'ナカツツミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市西青山', '03', '03201', '0200132', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '西青山', 'ニシアオヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市青山', '03', '03201', '0200133', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '青山', 'アオヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市南青山町', '03', '03201', '0200134', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '南青山町', 'ミナミアオヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市大新町', '03', '03201', '0200135', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '大新町', 'ダイシンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市北天昌寺町', '03', '03201', '0200136', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '北天昌寺町', 'キタテンショウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市天昌寺町', '03', '03201', '0200137', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '天昌寺町', 'テンショウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市中屋敷町', '03', '03201', '0200141', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '中屋敷町', 'ナカヤシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市稲荷町', '03', '03201', '0200142', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '稲荷町', 'イナリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市上厨川', '03', '03201', '0200143', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '上厨川', 'カミクリヤガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市土淵', '03', '03201', '0200144', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '土淵', 'ツチブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市平賀新田', '03', '03201', '0200145', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '平賀新田', 'ヒラカシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市長橋町', '03', '03201', '0200146', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '長橋町', 'ナガハシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市大館町', '03', '03201', '0200147', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '大館町', 'オオダテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市前潟', '03', '03201', '0200148', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '前潟', 'マエガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県岩手郡滝沢村大釜', '03', '03305', '0200151', '岩手県', 'イワテケン', '岩手郡滝沢村', 'イワテグンタキザワムラ', '大釜', 'オオガマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県岩手郡滝沢村篠木', '03', '03305', '0200161', '岩手県', 'イワテケン', '岩手郡滝沢村', 'イワテグンタキザワムラ', '篠木', 'シノギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県岩手郡滝沢村大沢', '03', '03305', '0200171', '岩手県', 'イワテケン', '岩手郡滝沢村', 'イワテグンタキザワムラ', '大沢', 'オオサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県岩手郡滝沢村鵜飼', '03', '03305', '0200172', '岩手県', 'イワテケン', '岩手郡滝沢村', 'イワテグンタキザワムラ', '鵜飼', 'ウカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県岩手郡滝沢村滝沢', '03', '03305', '0200173', '岩手県', 'イワテケン', '岩手郡滝沢村', 'イワテグンタキザワムラ', '滝沢', 'タキザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市玉山区日戸', '03', '03201', '0200201', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '玉山区日戸', 'タマヤマクヒノト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市玉山区玉山', '03', '03201', '0200202', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '玉山区玉山', 'タマヤマクタマヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市玉山区川又', '03', '03201', '0200203', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '玉山区川又', 'タマヤマクカワマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市玉山区上田', '03', '03201', '0200204', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '玉山区上田', 'タマヤマクウエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市簗川', '03', '03201', '0200311', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '簗川', 'ヤナガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市砂子沢', '03', '03201', '0200312', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '砂子沢', 'イサゴザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市根田茂', '03', '03201', '0200313', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '根田茂', 'ネダモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市手代森', '03', '03201', '0200401', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '手代森', 'テシロモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市黒川', '03', '03201', '0200402', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '黒川', 'クロカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市乙部', '03', '03201', '0200403', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '乙部', 'オトベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市大ケ生', '03', '03201', '0200404', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '大ケ生', 'オオガユウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県岩手郡雫石町', '03', '03301', '0200500', '岩手県', 'イワテケン', '岩手郡雫石町', 'イワテグンシズクイシチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('10552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県岩手郡雫石町仁佐瀬', '03', '03301', '0200501', '岩手県', 'イワテケン', '岩手郡雫石町', 'イワテグンシズクイシチョウ', '仁佐瀬', 'ニサセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県岩手郡雫石町板橋', '03', '03301', '0200502', '岩手県', 'イワテケン', '岩手郡雫石町', 'イワテグンシズクイシチョウ', '板橋', 'イタバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県岩手郡雫石町七ツ森', '03', '03301', '0200503', '岩手県', 'イワテケン', '岩手郡雫石町', 'イワテグンシズクイシチョウ', '七ツ森', 'ナナツモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県岩手郡雫石町中沼', '03', '03301', '0200504', '岩手県', 'イワテケン', '岩手郡雫石町', 'イワテグンシズクイシチョウ', '中沼', 'ナカヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県岩手郡雫石町中黒沢川', '03', '03301', '0200505', '岩手県', 'イワテケン', '岩手郡雫石町', 'イワテグンシズクイシチョウ', '中黒沢川', 'ナカクロサワガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県岩手郡雫石町沼返', '03', '03301', '0200506', '岩手県', 'イワテケン', '岩手郡雫石町', 'イワテグンシズクイシチョウ', '沼返', 'ヌマガエシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県岩手郡雫石町丸谷地', '03', '03301', '0200507', '岩手県', 'イワテケン', '岩手郡雫石町', 'イワテグンシズクイシチョウ', '丸谷地', 'マルヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県岩手郡雫石町長畑', '03', '03301', '0200511', '岩手県', 'イワテケン', '岩手郡雫石町', 'イワテグンシズクイシチョウ', '長畑', 'ナガハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県岩手郡雫石町塩ケ森', '03', '03301', '0200512', '岩手県', 'イワテケン', '岩手郡雫石町', 'イワテグンシズクイシチョウ', '塩ケ森', 'シオガモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県岩手郡雫石町下兎野', '03', '03301', '0200513', '岩手県', 'イワテケン', '岩手郡雫石町', 'イワテグンシズクイシチョウ', '下兎野', 'シモウサギノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県岩手郡雫石町野中', '03', '03301', '0200514', '岩手県', 'イワテケン', '岩手郡雫石町', 'イワテグンシズクイシチョウ', '野中', 'ノナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県岩手郡雫石町下長根', '03', '03301', '0200515', '岩手県', 'イワテケン', '岩手郡雫石町', 'イワテグンシズクイシチョウ', '下長根', 'シモナガネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県岩手郡雫石町黒沢川', '03', '03301', '0200517', '岩手県', 'イワテケン', '岩手郡雫石町', 'イワテグンシズクイシチョウ', '黒沢川', 'クロサワガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県岩手郡雫石町下町東', '03', '03301', '0200520', '岩手県', 'イワテケン', '岩手郡雫石町', 'イワテグンシズクイシチョウ', '下町東', 'シモマチヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県岩手郡雫石町麁津田', '03', '03301', '0200521', '岩手県', 'イワテケン', '岩手郡雫石町', 'イワテグンシズクイシチョウ', '麁津田', 'ソツダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県岩手郡雫石町下久保', '03', '03301', '0200522', '岩手県', 'イワテケン', '岩手郡雫石町', 'イワテグンシズクイシチョウ', '下久保', 'シモクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県岩手郡雫石町根堀', '03', '03301', '0200523', '岩手県', 'イワテケン', '岩手郡雫石町', 'イワテグンシズクイシチョウ', '根堀', 'ネホリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県岩手郡雫石町寺の下', '03', '03301', '0200524', '岩手県', 'イワテケン', '岩手郡雫石町', 'イワテグンシズクイシチョウ', '寺の下', 'テラノシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県岩手郡雫石町源大堂', '03', '03301', '0200525', '岩手県', 'イワテケン', '岩手郡雫石町', 'イワテグンシズクイシチョウ', '源大堂', 'ゲンダイドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県岩手郡雫石町中町', '03', '03301', '0200527', '岩手県', 'イワテケン', '岩手郡雫石町', 'イワテグンシズクイシチョウ', '中町', 'ナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県岩手郡雫石町下町', '03', '03301', '0200528', '岩手県', 'イワテケン', '岩手郡雫石町', 'イワテグンシズクイシチョウ', '下町', 'シモマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県岩手郡雫石町下町西', '03', '03301', '0200529', '岩手県', 'イワテケン', '岩手郡雫石町', 'イワテグンシズクイシチョウ', '下町西', 'シモマチニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県岩手郡雫石町上町南', '03', '03301', '0200530', '岩手県', 'イワテケン', '岩手郡雫石町', 'イワテグンシズクイシチョウ', '上町南', 'カミマチミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県岩手郡雫石町麻見田', '03', '03301', '0200531', '岩手県', 'イワテケン', '岩手郡雫石町', 'イワテグンシズクイシチョウ', '麻見田', 'マミダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県岩手郡雫石町払川', '03', '03301', '0200532', '岩手県', 'イワテケン', '岩手郡雫石町', 'イワテグンシズクイシチョウ', '払川', 'ハライガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県岩手郡雫石町林', '03', '03301', '0200533', '岩手県', 'イワテケン', '岩手郡雫石町', 'イワテグンシズクイシチョウ', '林', 'ハヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県岩手郡雫石町川原', '03', '03301', '0200534', '岩手県', 'イワテケン', '岩手郡雫石町', 'イワテグンシズクイシチョウ', '川原', 'カワハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県岩手郡雫石町小日谷地', '03', '03301', '0200535', '岩手県', 'イワテケン', '岩手郡雫石町', 'イワテグンシズクイシチョウ', '小日谷地', 'コビヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県岩手郡雫石町八卦', '03', '03301', '0200536', '岩手県', 'イワテケン', '岩手郡雫石町', 'イワテグンシズクイシチョウ', '八卦', 'ハツケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県岩手郡雫石町上町西', '03', '03301', '0200537', '岩手県', 'イワテケン', '岩手郡雫石町', 'イワテグンシズクイシチョウ', '上町西', 'カミマチニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県岩手郡雫石町上町北', '03', '03301', '0200538', '岩手県', 'イワテケン', '岩手郡雫石町', 'イワテグンシズクイシチョウ', '上町北', 'カミマチキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県岩手郡雫石町上町東', '03', '03301', '0200539', '岩手県', 'イワテケン', '岩手郡雫石町', 'イワテグンシズクイシチョウ', '上町東', 'カミマチヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県岩手郡雫石町千刈田', '03', '03301', '0200541', '岩手県', 'イワテケン', '岩手郡雫石町', 'イワテグンシズクイシチョウ', '千刈田', 'センガリダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県岩手郡雫石町万田渡', '03', '03301', '0200542', '岩手県', 'イワテケン', '岩手郡雫石町', 'イワテグンシズクイシチョウ', '万田渡', 'マンダワタリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県岩手郡雫石町高前田', '03', '03301', '0200543', '岩手県', 'イワテケン', '岩手郡雫石町', 'イワテグンシズクイシチョウ', '高前田', 'タカマエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県岩手郡雫石町柿木', '03', '03301', '0200544', '岩手県', 'イワテケン', '岩手郡雫石町', 'イワテグンシズクイシチョウ', '柿木', 'カキキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県岩手郡雫石町谷地', '03', '03301', '0200545', '岩手県', 'イワテケン', '岩手郡雫石町', 'イワテグンシズクイシチョウ', '谷地', 'ヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県岩手郡雫石町稲荷下', '03', '03301', '0200546', '岩手県', 'イワテケン', '岩手郡雫石町', 'イワテグンシズクイシチョウ', '稲荷下', 'イナリシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県岩手郡雫石町晴山', '03', '03301', '0200547', '岩手県', 'イワテケン', '岩手郡雫石町', 'イワテグンシズクイシチョウ', '晴山', 'ハレヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県岩手郡雫石町笹森', '03', '03301', '0200551', '岩手県', 'イワテケン', '岩手郡雫石町', 'イワテグンシズクイシチョウ', '笹森', 'ササモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県岩手郡雫石町下平', '03', '03301', '0200552', '岩手県', 'イワテケン', '岩手郡雫石町', 'イワテグンシズクイシチョウ', '下平', 'シモダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県岩手郡雫石町下曽根田', '03', '03301', '0200553', '岩手県', 'イワテケン', '岩手郡雫石町', 'イワテグンシズクイシチョウ', '下曽根田', 'シモソネダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県岩手郡雫石町町裏', '03', '03301', '0200554', '岩手県', 'イワテケン', '岩手郡雫石町', 'イワテグンシズクイシチョウ', '町裏', 'マチウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県岩手郡雫石町上曽根田', '03', '03301', '0200555', '岩手県', 'イワテケン', '岩手郡雫石町', 'イワテグンシズクイシチョウ', '上曽根田', 'カミソネダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県岩手郡雫石町名子', '03', '03301', '0200556', '岩手県', 'イワテケン', '岩手郡雫石町', 'イワテグンシズクイシチョウ', '名子', 'ナゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県岩手郡雫石町上平', '03', '03301', '0200557', '岩手県', 'イワテケン', '岩手郡雫石町', 'イワテグンシズクイシチョウ', '上平', 'カミダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県岩手郡雫石町下笹森', '03', '03301', '0200558', '岩手県', 'イワテケン', '岩手郡雫石町', 'イワテグンシズクイシチョウ', '下笹森', 'シモササモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県岩手郡雫石町上笹森', '03', '03301', '0200559', '岩手県', 'イワテケン', '岩手郡雫石町', 'イワテグンシズクイシチョウ', '上笹森', 'カミササモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県岩手郡雫石町繋', '03', '03301', '0200571', '岩手県', 'イワテケン', '岩手郡雫石町', 'イワテグンシズクイシチョウ', '繋', 'ツナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県岩手郡雫石町西安庭', '03', '03301', '0200572', '岩手県', 'イワテケン', '岩手郡雫石町', 'イワテグンシズクイシチョウ', '西安庭', 'ニシアニワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県岩手郡雫石町南畑', '03', '03301', '0200573', '岩手県', 'イワテケン', '岩手郡雫石町', 'イワテグンシズクイシチョウ', '南畑', 'ミナミハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県岩手郡雫石町鶯宿', '03', '03301', '0200574', '岩手県', 'イワテケン', '岩手郡雫石町', 'イワテグンシズクイシチョウ', '鶯宿', 'オウシュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県岩手郡雫石町御明神', '03', '03301', '0200581', '岩手県', 'イワテケン', '岩手郡雫石町', 'イワテグンシズクイシチョウ', '御明神', 'オミョウジン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県岩手郡雫石町橋場', '03', '03301', '0200582', '岩手県', 'イワテケン', '岩手郡雫石町', 'イワテグンシズクイシチョウ', '橋場', 'ハシバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県岩手郡雫石町上野', '03', '03301', '0200583', '岩手県', 'イワテケン', '岩手郡雫石町', 'イワテグンシズクイシチョウ', '上野', 'ウワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県岩手郡雫石町西根', '03', '03301', '0200584', '岩手県', 'イワテケン', '岩手郡雫石町', 'イワテグンシズクイシチョウ', '西根', 'ニシネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県岩手郡雫石町長山', '03', '03301', '0200585', '岩手県', 'イワテケン', '岩手郡雫石町', 'イワテグンシズクイシチョウ', '長山', 'ナガヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市浅岸', '03', '03201', '0200801', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '浅岸', 'アサギシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市つつじが丘', '03', '03201', '0200802', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', 'つつじが丘', 'ツツジガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市新庄', '03', '03201', '0200803', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '新庄', 'シンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市東桜山', '03', '03201', '0200804', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '東桜山', 'ヒガシサクラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市東新庄', '03', '03201', '0200805', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '東新庄', 'ヒガシシンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市新庄町', '03', '03201', '0200806', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '新庄町', 'シンジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市加賀野', '03', '03201', '0200807', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '加賀野', 'カガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市川目町', '03', '03201', '0200811', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '川目町', 'カワメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市川目', '03', '03201', '0200812', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '川目', 'カワメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市東山', '03', '03201', '0200813', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '東山', 'ヒガシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市東中野町', '03', '03201', '0200814', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '東中野町', 'ヒガシナカノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市小杉山', '03', '03201', '0200815', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '小杉山', 'コスギヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市中野', '03', '03201', '0200816', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '中野', 'ナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市東中野', '03', '03201', '0200817', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '東中野', 'ヒガシナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市山王町', '03', '03201', '0200821', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '山王町', 'サンノウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市茶畑', '03', '03201', '0200822', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '茶畑', 'チャバタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市門', '03', '03201', '0200823', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '門', 'カド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市東安庭', '03', '03201', '0200824', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '東安庭', 'ヒガシアニワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市高崩', '03', '03201', '0200825', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '高崩', 'タカクズレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市神子田町', '03', '03201', '0200826', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '神子田町', 'ミコダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市鉈屋町', '03', '03201', '0200827', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '鉈屋町', 'ナタヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市大慈寺町', '03', '03201', '0200828', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '大慈寺町', 'ダイジジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市三本柳', '03', '03201', '0200831', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '三本柳', 'サンボンヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市東見前', '03', '03201', '0200832', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '東見前', 'ヒガシミルマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市西見前', '03', '03201', '0200833', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '西見前', 'ニシミルマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市永井', '03', '03201', '0200834', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '永井', 'ナガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市津志田', '03', '03201', '0200835', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '津志田', 'ツシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市津志田西', '03', '03201', '0200836', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '津志田西', 'ツシダニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市津志田町', '03', '03201', '0200837', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '津志田町', 'ツシダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市津志田中央', '03', '03201', '0200838', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '津志田中央', 'ツシダチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市津志田南', '03', '03201', '0200839', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '津志田南', 'ツシダミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市羽場', '03', '03201', '0200841', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '羽場', 'ハバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市湯沢', '03', '03201', '0200842', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '湯沢', 'ユザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市湯沢西', '03', '03201', '0200843', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '湯沢西', 'ユザワニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市湯沢東', '03', '03201', '0200844', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '湯沢東', 'ユザワヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市湯沢南', '03', '03201', '0200845', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '湯沢南', 'ユザワミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市流通センター北', '03', '03201', '0200846', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '流通センター北', 'リュウツウセンターキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市向中野', '03', '03201', '0200851', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '向中野', 'ムカイナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市飯岡新田', '03', '03201', '0200852', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '飯岡新田', 'イイオカシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市下飯岡', '03', '03201', '0200853', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '下飯岡', 'シモイイオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市上飯岡', '03', '03201', '0200854', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '上飯岡', 'カミイイオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市上鹿妻', '03', '03201', '0200855', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '上鹿妻', 'カミカヅマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市下鹿妻', '03', '03201', '0200856', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '下鹿妻', 'シモカヅマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市仙北', '03', '03201', '0200861', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '仙北', 'センボク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市東仙北', '03', '03201', '0200862', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '東仙北', 'ヒガシセンボク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市南仙北', '03', '03201', '0200863', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '南仙北', 'ミナミセンボク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市西仙北', '03', '03201', '0200864', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '西仙北', 'ニシセンボク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市仙北町', '03', '03201', '0200865', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '仙北町', 'センボクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市本宮', '03', '03201', '0200866', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '本宮', 'モトミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市中ノ橋通', '03', '03201', '0200871', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '中ノ橋通', 'ナカノハシドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市八幡町', '03', '03201', '0200872', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '八幡町', 'ハチマンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市松尾町', '03', '03201', '0200873', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '松尾町', 'マツオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市南大通', '03', '03201', '0200874', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '南大通', 'ミナミオオドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市清水町', '03', '03201', '0200875', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '清水町', 'シミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市馬場町', '03', '03201', '0200876', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '馬場町', 'ババチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市下ノ橋町', '03', '03201', '0200877', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '下ノ橋町', 'シモノハシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市肴町', '03', '03201', '0200878', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '肴町', 'サカナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市天神町', '03', '03201', '0200881', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '天神町', 'テンジンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市住吉町', '03', '03201', '0200882', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '住吉町', 'スミヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市志家町', '03', '03201', '0200883', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '志家町', 'シケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市神明町', '03', '03201', '0200884', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '神明町', 'シンメイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市紺屋町', '03', '03201', '0200885', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '紺屋町', 'コンヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市若園町', '03', '03201', '0200886', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '若園町', 'ワカソノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市上ノ橋町', '03', '03201', '0200887', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '上ノ橋町', 'カミノハシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県紫波郡矢巾町流通センター南', '03', '03322', '0200891', '岩手県', 'イワテケン', '紫波郡矢巾町', 'シワグンヤハバチョウ', '流通センター南', 'リュウツウセンターミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都狛江市', '13', '13219', '2010000', '東京都', 'トウキョウト', '狛江市', 'コマエシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('10679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都狛江市西野川', '13', '13219', '2010001', '東京都', 'トウキョウト', '狛江市', 'コマエシ', '西野川', 'ニシノガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都狛江市東野川', '13', '13219', '2010002', '東京都', 'トウキョウト', '狛江市', 'コマエシ', '東野川', 'ヒガシノガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都狛江市和泉本町', '13', '13219', '2010003', '東京都', 'トウキョウト', '狛江市', 'コマエシ', '和泉本町', 'イズミホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都狛江市岩戸北', '13', '13219', '2010004', '東京都', 'トウキョウト', '狛江市', 'コマエシ', '岩戸北', 'イワドキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都狛江市岩戸南', '13', '13219', '2010005', '東京都', 'トウキョウト', '狛江市', 'コマエシ', '岩戸南', 'イワドミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都狛江市西和泉', '13', '13219', '2010011', '東京都', 'トウキョウト', '狛江市', 'コマエシ', '西和泉', 'ニシイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都狛江市中和泉', '13', '13219', '2010012', '東京都', 'トウキョウト', '狛江市', 'コマエシ', '中和泉', 'ナカイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都狛江市元和泉', '13', '13219', '2010013', '東京都', 'トウキョウト', '狛江市', 'コマエシ', '元和泉', 'モトイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都狛江市東和泉', '13', '13219', '2010014', '東京都', 'トウキョウト', '狛江市', 'コマエシ', '東和泉', 'ヒガシイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都狛江市猪方', '13', '13219', '2010015', '東京都', 'トウキョウト', '狛江市', 'コマエシ', '猪方', 'イノガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都狛江市駒井町', '13', '13219', '2010016', '東京都', 'トウキョウト', '狛江市', 'コマエシ', '駒井町', 'コマイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都西東京市', '13', '13229', '2020000', '東京都', 'トウキョウト', '西東京市', 'ニシトウキョウシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('10699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都西東京市ひばりが丘', '13', '13229', '2020001', '東京都', 'トウキョウト', '西東京市', 'ニシトウキョウシ', 'ひばりが丘', 'ヒバリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都西東京市ひばりが丘北', '13', '13229', '2020002', '東京都', 'トウキョウト', '西東京市', 'ニシトウキョウシ', 'ひばりが丘北', 'ヒバリガオカキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都西東京市北町', '13', '13229', '2020003', '東京都', 'トウキョウト', '西東京市', 'ニシトウキョウシ', '北町', 'キタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都西東京市下保谷', '13', '13229', '2020004', '東京都', 'トウキョウト', '西東京市', 'ニシトウキョウシ', '下保谷', 'シモホウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都西東京市住吉町', '13', '13229', '2020005', '東京都', 'トウキョウト', '西東京市', 'ニシトウキョウシ', '住吉町', 'スミヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都西東京市栄町', '13', '13229', '2020006', '東京都', 'トウキョウト', '西東京市', 'ニシトウキョウシ', '栄町', 'サカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都西東京市泉町', '13', '13229', '2020011', '東京都', 'トウキョウト', '西東京市', 'ニシトウキョウシ', '泉町', 'イズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都西東京市東町', '13', '13229', '2020012', '東京都', 'トウキョウト', '西東京市', 'ニシトウキョウシ', '東町', 'ヒガシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都西東京市中町', '13', '13229', '2020013', '東京都', 'トウキョウト', '西東京市', 'ニシトウキョウシ', '中町', 'ナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都西東京市富士町', '13', '13229', '2020014', '東京都', 'トウキョウト', '西東京市', 'ニシトウキョウシ', '富士町', 'フジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都西東京市保谷町', '13', '13229', '2020015', '東京都', 'トウキョウト', '西東京市', 'ニシトウキョウシ', '保谷町', 'ホウヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都西東京市東伏見', '13', '13229', '2020021', '東京都', 'トウキョウト', '西東京市', 'ニシトウキョウシ', '東伏見', 'ヒガシフシミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都西東京市柳沢', '13', '13229', '2020022', '東京都', 'トウキョウト', '西東京市', 'ニシトウキョウシ', '柳沢', 'ヤギサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都西東京市新町', '13', '13229', '2020023', '東京都', 'トウキョウト', '西東京市', 'ニシトウキョウシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都東久留米市', '13', '13222', '2030000', '東京都', 'トウキョウト', '東久留米市', 'ヒガシクルメシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('10718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都東久留米市上の原', '13', '13222', '2030001', '東京都', 'トウキョウト', '東久留米市', 'ヒガシクルメシ', '上の原', 'ウエノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都東久留米市神宝町', '13', '13222', '2030002', '東京都', 'トウキョウト', '東久留米市', 'ヒガシクルメシ', '神宝町', 'シンホウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都東久留米市金山町', '13', '13222', '2030003', '東京都', 'トウキョウト', '東久留米市', 'ヒガシクルメシ', '金山町', 'カナヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都東久留米市氷川台', '13', '13222', '2030004', '東京都', 'トウキョウト', '東久留米市', 'ヒガシクルメシ', '氷川台', 'ヒカワダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都東久留米市大門町', '13', '13222', '2030011', '東京都', 'トウキョウト', '東久留米市', 'ヒガシクルメシ', '大門町', 'ダイモンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都東久留米市浅間町', '13', '13222', '2030012', '東京都', 'トウキョウト', '東久留米市', 'ヒガシクルメシ', '浅間町', 'センゲンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都東久留米市新川町', '13', '13222', '2030013', '東京都', 'トウキョウト', '東久留米市', 'ヒガシクルメシ', '新川町', 'シンカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都東久留米市東本町', '13', '13222', '2030014', '東京都', 'トウキョウト', '東久留米市', 'ヒガシクルメシ', '東本町', 'ヒガシホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都東久留米市学園町', '13', '13222', '2030021', '東京都', 'トウキョウト', '東久留米市', 'ヒガシクルメシ', '学園町', 'ガクエンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都東久留米市ひばりが丘団地', '13', '13222', '2030022', '東京都', 'トウキョウト', '東久留米市', 'ヒガシクルメシ', 'ひばりが丘団地', 'ヒバリガオカダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都東久留米市南沢', '13', '13222', '2030023', '東京都', 'トウキョウト', '東久留米市', 'ヒガシクルメシ', '南沢', 'ミナミサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都東久留米市南町', '13', '13222', '2030031', '東京都', 'トウキョウト', '東久留米市', 'ヒガシクルメシ', '南町', 'ミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都東久留米市前沢', '13', '13222', '2030032', '東京都', 'トウキョウト', '東久留米市', 'ヒガシクルメシ', '前沢', 'マエサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都東久留米市滝山', '13', '13222', '2030033', '東京都', 'トウキョウト', '東久留米市', 'ヒガシクルメシ', '滝山', 'タキヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都東久留米市弥生', '13', '13222', '2030034', '東京都', 'トウキョウト', '東久留米市', 'ヒガシクルメシ', '弥生', 'ヤヨイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都東久留米市野火止', '13', '13222', '2030041', '東京都', 'トウキョウト', '東久留米市', 'ヒガシクルメシ', '野火止', 'ノビドメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都東久留米市八幡町', '13', '13222', '2030042', '東京都', 'トウキョウト', '東久留米市', 'ヒガシクルメシ', '八幡町', 'ハチマンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都東久留米市下里', '13', '13222', '2030043', '東京都', 'トウキョウト', '東久留米市', 'ヒガシクルメシ', '下里', 'シモサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都東久留米市柳窪', '13', '13222', '2030044', '東京都', 'トウキョウト', '東久留米市', 'ヒガシクルメシ', '柳窪', 'ヤナギクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都東久留米市小山', '13', '13222', '2030051', '東京都', 'トウキョウト', '東久留米市', 'ヒガシクルメシ', '小山', 'コヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都東久留米市幸町', '13', '13222', '2030052', '東京都', 'トウキョウト', '東久留米市', 'ヒガシクルメシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都東久留米市本町', '13', '13222', '2030053', '東京都', 'トウキョウト', '東久留米市', 'ヒガシクルメシ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都東久留米市中央町', '13', '13222', '2030054', '東京都', 'トウキョウト', '東久留米市', 'ヒガシクルメシ', '中央町', 'チュウオウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都清瀬市', '13', '13221', '2040000', '東京都', 'トウキョウト', '清瀬市', 'キヨセシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('10749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都清瀬市下宿', '13', '13221', '2040001', '東京都', 'トウキョウト', '清瀬市', 'キヨセシ', '下宿', 'シタジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都清瀬市旭が丘', '13', '13221', '2040002', '東京都', 'トウキョウト', '清瀬市', 'キヨセシ', '旭が丘', 'アサヒガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都清瀬市中里', '13', '13221', '2040003', '東京都', 'トウキョウト', '清瀬市', 'キヨセシ', '中里', 'ナカザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都清瀬市野塩', '13', '13221', '2040004', '東京都', 'トウキョウト', '清瀬市', 'キヨセシ', '野塩', 'ノシオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都清瀬市下清戸', '13', '13221', '2040011', '東京都', 'トウキョウト', '清瀬市', 'キヨセシ', '下清戸', 'シモキヨト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都清瀬市中清戸', '13', '13221', '2040012', '東京都', 'トウキョウト', '清瀬市', 'キヨセシ', '中清戸', 'ナカキヨト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都清瀬市上清戸', '13', '13221', '2040013', '東京都', 'トウキョウト', '清瀬市', 'キヨセシ', '上清戸', 'カミキヨト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都清瀬市元町', '13', '13221', '2040021', '東京都', 'トウキョウト', '清瀬市', 'キヨセシ', '元町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都清瀬市松山', '13', '13221', '2040022', '東京都', 'トウキョウト', '清瀬市', 'キヨセシ', '松山', 'マツヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都清瀬市竹丘', '13', '13221', '2040023', '東京都', 'トウキョウト', '清瀬市', 'キヨセシ', '竹丘', 'タケオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都清瀬市梅園', '13', '13221', '2040024', '東京都', 'トウキョウト', '清瀬市', 'キヨセシ', '梅園', 'ウメゾノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都羽村市', '13', '13227', '2050000', '東京都', 'トウキョウト', '羽村市', 'ハムラシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('10770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都羽村市小作台', '13', '13227', '2050001', '東京都', 'トウキョウト', '羽村市', 'ハムラシ', '小作台', 'オザクダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都羽村市栄町', '13', '13227', '2050002', '東京都', 'トウキョウト', '羽村市', 'ハムラシ', '栄町', 'サカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都羽村市緑ケ丘', '13', '13227', '2050003', '東京都', 'トウキョウト', '羽村市', 'ハムラシ', '緑ケ丘', 'ミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都羽村市五ノ神', '13', '13227', '2050011', '東京都', 'トウキョウト', '羽村市', 'ハムラシ', '五ノ神', 'ゴノカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都羽村市羽', '13', '13227', '2050012', '東京都', 'トウキョウト', '羽村市', 'ハムラシ', '羽', 'ハネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都羽村市富士見平', '13', '13227', '2050013', '東京都', 'トウキョウト', '羽村市', 'ハムラシ', '富士見平', 'フジミダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都羽村市羽東', '13', '13227', '2050014', '東京都', 'トウキョウト', '羽村市', 'ハムラシ', '羽東', 'ハネヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都羽村市羽中', '13', '13227', '2050015', '東京都', 'トウキョウト', '羽村市', 'ハムラシ', '羽中', 'ハネナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都羽村市羽加美', '13', '13227', '2050016', '東京都', 'トウキョウト', '羽村市', 'ハムラシ', '羽加美', 'ハネカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都羽村市羽西', '13', '13227', '2050017', '東京都', 'トウキョウト', '羽村市', 'ハムラシ', '羽西', 'ハネニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都羽村市川崎', '13', '13227', '2050021', '東京都', 'トウキョウト', '羽村市', 'ハムラシ', '川崎', 'カワサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都羽村市双葉町', '13', '13227', '2050022', '東京都', 'トウキョウト', '羽村市', 'ハムラシ', '双葉町', 'フタバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都羽村市神明台', '13', '13227', '2050023', '東京都', 'トウキョウト', '羽村市', 'ハムラシ', '神明台', 'シンメイダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都羽村市玉川', '13', '13227', '2050024', '東京都', 'トウキョウト', '羽村市', 'ハムラシ', '玉川', 'タマガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都多摩市', '13', '13224', '2060000', '東京都', 'トウキョウト', '多摩市', 'タマシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('10796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都稲城市', '13', '13225', '2060000', '東京都', 'トウキョウト', '稲城市', 'イナギシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('10797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都多摩市和田', '13', '13224', '2060001', '東京都', 'トウキョウト', '多摩市', 'タマシ', '和田', 'ワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都多摩市一ノ宮', '13', '13224', '2060002', '東京都', 'トウキョウト', '多摩市', 'タマシ', '一ノ宮', 'イチノミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都多摩市東寺方', '13', '13224', '2060003', '東京都', 'トウキョウト', '多摩市', 'タマシ', '東寺方', 'ヒガシテラガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都多摩市百草', '13', '13224', '2060004', '東京都', 'トウキョウト', '多摩市', 'タマシ', '百草', 'モグサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都多摩市関戸', '13', '13224', '2060011', '東京都', 'トウキョウト', '多摩市', 'タマシ', '関戸', 'セキド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都多摩市貝取', '13', '13224', '2060012', '東京都', 'トウキョウト', '多摩市', 'タマシ', '貝取', 'カイドリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都多摩市桜ケ丘', '13', '13224', '2060013', '東京都', 'トウキョウト', '多摩市', 'タマシ', '桜ケ丘', 'サクラガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都多摩市乞田', '13', '13224', '2060014', '東京都', 'トウキョウト', '多摩市', 'タマシ', '乞田', 'コッタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都多摩市落川', '13', '13224', '2060015', '東京都', 'トウキョウト', '多摩市', 'タマシ', '落川', 'オチカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都多摩市連光寺', '13', '13224', '2060021', '東京都', 'トウキョウト', '多摩市', 'タマシ', '連光寺', 'レンコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都多摩市聖ケ丘', '13', '13224', '2060022', '東京都', 'トウキョウト', '多摩市', 'タマシ', '聖ケ丘', 'ヒジリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都多摩市馬引沢', '13', '13224', '2060023', '東京都', 'トウキョウト', '多摩市', 'タマシ', '馬引沢', 'マヒキザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都多摩市諏訪', '13', '13224', '2060024', '東京都', 'トウキョウト', '多摩市', 'タマシ', '諏訪', 'スワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都多摩市永山', '13', '13224', '2060025', '東京都', 'トウキョウト', '多摩市', 'タマシ', '永山', 'ナガヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都多摩市豊ケ丘', '13', '13224', '2060031', '東京都', 'トウキョウト', '多摩市', 'タマシ', '豊ケ丘', 'トヨガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都多摩市南野', '13', '13224', '2060032', '東京都', 'トウキョウト', '多摩市', 'タマシ', '南野', 'ミナミノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都多摩市落合', '13', '13224', '2060033', '東京都', 'トウキョウト', '多摩市', 'タマシ', '落合', 'オチアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都多摩市鶴牧', '13', '13224', '2060034', '東京都', 'トウキョウト', '多摩市', 'タマシ', '鶴牧', 'ツルマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都多摩市唐木田', '13', '13224', '2060035', '東京都', 'トウキョウト', '多摩市', 'タマシ', '唐木田', 'カラキダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都多摩市中沢', '13', '13224', '2060036', '東京都', 'トウキョウト', '多摩市', 'タマシ', '中沢', 'ナカザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都多摩市愛宕', '13', '13224', '2060041', '東京都', 'トウキョウト', '多摩市', 'タマシ', '愛宕', 'アタゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都多摩市山王下', '13', '13224', '2060042', '東京都', 'トウキョウト', '多摩市', 'タマシ', '山王下', 'サンノウシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都稲城市大丸', '13', '13225', '2060801', '東京都', 'トウキョウト', '稲城市', 'イナギシ', '大丸', 'オオマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都稲城市東長沼', '13', '13225', '2060802', '東京都', 'トウキョウト', '稲城市', 'イナギシ', '東長沼', 'ヒガシナガヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都稲城市向陽台', '13', '13225', '2060803', '東京都', 'トウキョウト', '稲城市', 'イナギシ', '向陽台', 'コウヨウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都稲城市百村', '13', '13225', '2060804', '東京都', 'トウキョウト', '稲城市', 'イナギシ', '百村', 'モムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都稲城市押立', '13', '13225', '2060811', '東京都', 'トウキョウト', '稲城市', 'イナギシ', '押立', 'オシタテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都稲城市矢野口', '13', '13225', '2060812', '東京都', 'トウキョウト', '稲城市', 'イナギシ', '矢野口', 'ヤノクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都稲城市長峰', '13', '13225', '2060821', '東京都', 'トウキョウト', '稲城市', 'イナギシ', '長峰', 'ナガミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都稲城市坂浜', '13', '13225', '2060822', '東京都', 'トウキョウト', '稲城市', 'イナギシ', '坂浜', 'サカハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都稲城市平尾', '13', '13225', '2060823', '東京都', 'トウキョウト', '稲城市', 'イナギシ', '平尾', 'ヒラオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都稲城市若葉台', '13', '13225', '2060824', '東京都', 'トウキョウト', '稲城市', 'イナギシ', '若葉台', 'ワカバダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都東大和市', '13', '13220', '2070000', '東京都', 'トウキョウト', '東大和市', 'ヒガシヤマトシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('10856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都東大和市多摩湖', '13', '13220', '2070001', '東京都', 'トウキョウト', '東大和市', 'ヒガシヤマトシ', '多摩湖', 'タマコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都東大和市湖畔', '13', '13220', '2070002', '東京都', 'トウキョウト', '東大和市', 'ヒガシヤマトシ', '湖畔', 'コハン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都東大和市狭山', '13', '13220', '2070003', '東京都', 'トウキョウト', '東大和市', 'ヒガシヤマトシ', '狭山', 'サヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都東大和市清水', '13', '13220', '2070004', '東京都', 'トウキョウト', '東大和市', 'ヒガシヤマトシ', '清水', 'シミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都東大和市高木', '13', '13220', '2070005', '東京都', 'トウキョウト', '東大和市', 'ヒガシヤマトシ', '高木', 'タカギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都東大和市清原', '13', '13220', '2070011', '東京都', 'トウキョウト', '東大和市', 'ヒガシヤマトシ', '清原', 'キヨハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都東大和市新堀', '13', '13220', '2070012', '東京都', 'トウキョウト', '東大和市', 'ヒガシヤマトシ', '新堀', 'シンボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都東大和市向原', '13', '13220', '2070013', '東京都', 'トウキョウト', '東大和市', 'ヒガシヤマトシ', '向原', 'ムコウハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都東大和市南街', '13', '13220', '2070014', '東京都', 'トウキョウト', '東大和市', 'ヒガシヤマトシ', '南街', 'ナンガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都東大和市中央', '13', '13220', '2070015', '東京都', 'トウキョウト', '東大和市', 'ヒガシヤマトシ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都東大和市仲原', '13', '13220', '2070016', '東京都', 'トウキョウト', '東大和市', 'ヒガシヤマトシ', '仲原', 'ナカハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都東大和市立野', '13', '13220', '2070021', '東京都', 'トウキョウト', '東大和市', 'ヒガシヤマトシ', '立野', 'タテノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都東大和市桜が丘', '13', '13220', '2070022', '東京都', 'トウキョウト', '東大和市', 'ヒガシヤマトシ', '桜が丘', 'サクラガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都東大和市上北台', '13', '13220', '2070023', '東京都', 'トウキョウト', '東大和市', 'ヒガシヤマトシ', '上北台', 'カミキタダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都東大和市奈良橋', '13', '13220', '2070031', '東京都', 'トウキョウト', '東大和市', 'ヒガシヤマトシ', '奈良橋', 'ナラハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都東大和市蔵敷', '13', '13220', '2070032', '東京都', 'トウキョウト', '東大和市', 'ヒガシヤマトシ', '蔵敷', 'ゾウシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都東大和市芋窪', '13', '13220', '2070033', '東京都', 'トウキョウト', '東大和市', 'ヒガシヤマトシ', '芋窪', 'イモクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都武蔵村山市', '13', '13223', '2080000', '東京都', 'トウキョウト', '武蔵村山市', 'ムサシムラヤマシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('10877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都武蔵村山市中藤', '13', '13223', '2080001', '東京都', 'トウキョウト', '武蔵村山市', 'ムサシムラヤマシ', '中藤', 'ナカトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都武蔵村山市神明', '13', '13223', '2080002', '東京都', 'トウキョウト', '武蔵村山市', 'ムサシムラヤマシ', '神明', 'シンメイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都武蔵村山市中央', '13', '13223', '2080003', '東京都', 'トウキョウト', '武蔵村山市', 'ムサシムラヤマシ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都武蔵村山市本町', '13', '13223', '2080004', '東京都', 'トウキョウト', '武蔵村山市', 'ムサシムラヤマシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都武蔵村山市学園', '13', '13223', '2080011', '東京都', 'トウキョウト', '武蔵村山市', 'ムサシムラヤマシ', '学園', 'ガクエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都武蔵村山市緑が丘', '13', '13223', '2080012', '東京都', 'トウキョウト', '武蔵村山市', 'ムサシムラヤマシ', '緑が丘', 'ミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都武蔵村山市大南', '13', '13223', '2080013', '東京都', 'トウキョウト', '武蔵村山市', 'ムサシムラヤマシ', '大南', 'オオミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都武蔵村山市三ツ藤', '13', '13223', '2080021', '東京都', 'トウキョウト', '武蔵村山市', 'ムサシムラヤマシ', '三ツ藤', 'ミツフジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都武蔵村山市榎', '13', '13223', '2080022', '東京都', 'トウキョウト', '武蔵村山市', 'ムサシムラヤマシ', '榎', 'エノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都武蔵村山市伊奈平', '13', '13223', '2080023', '東京都', 'トウキョウト', '武蔵村山市', 'ムサシムラヤマシ', '伊奈平', 'イナダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都武蔵村山市岸', '13', '13223', '2080031', '東京都', 'トウキョウト', '武蔵村山市', 'ムサシムラヤマシ', '岸', 'キシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都武蔵村山市三ツ木1丁目', '13', '13223', '2080032', '東京都', 'トウキョウト', '武蔵村山市', 'ムサシムラヤマシ', '三ツ木', 'ミツギ', null, null, '1丁目', '01チョウメ');
INSERT INTO `ms_addresses` VALUES ('10889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都武蔵村山市三ツ木2丁目', '13', '13223', '2080032', '東京都', 'トウキョウト', '武蔵村山市', 'ムサシムラヤマシ', '三ツ木', 'ミツギ', null, null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('10890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都武蔵村山市三ツ木3丁目', '13', '13223', '2080032', '東京都', 'トウキョウト', '武蔵村山市', 'ムサシムラヤマシ', '三ツ木', 'ミツギ', null, null, '3丁目', '03チョウメ');
INSERT INTO `ms_addresses` VALUES ('10891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都武蔵村山市三ツ木4丁目', '13', '13223', '2080032', '東京都', 'トウキョウト', '武蔵村山市', 'ムサシムラヤマシ', '三ツ木', 'ミツギ', null, null, '4丁目', '04チョウメ');
INSERT INTO `ms_addresses` VALUES ('10892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都武蔵村山市三ツ木5丁目', '13', '13223', '2080032', '東京都', 'トウキョウト', '武蔵村山市', 'ムサシムラヤマシ', '三ツ木', 'ミツギ', null, null, '5丁目', '05チョウメ');
INSERT INTO `ms_addresses` VALUES ('10893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都武蔵村山市三ツ木', '13', '13223', '2080033', '東京都', 'トウキョウト', '武蔵村山市', 'ムサシムラヤマシ', '三ツ木', 'ミツギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都武蔵村山市残堀', '13', '13223', '2080034', '東京都', 'トウキョウト', '武蔵村山市', 'ムサシムラヤマシ', '残堀', 'ザンボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '東京都武蔵村山市中原', '13', '13223', '2080035', '東京都', 'トウキョウト', '武蔵村山市', 'ムサシムラヤマシ', '中原', 'ナカハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区屯田1条', '01', '01102', '0020851', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '屯田1条', 'トンデン01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区屯田2条', '01', '01102', '0020852', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '屯田2条', 'トンデン02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区屯田3条', '01', '01102', '0020853', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '屯田3条', 'トンデン03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区屯田4条', '01', '01102', '0020854', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '屯田4条', 'トンデン04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区屯田5条', '01', '01102', '0020855', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '屯田5条', 'トンデン05ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区屯田6条', '01', '01102', '0020856', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '屯田6条', 'トンデン06ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区屯田7条', '01', '01102', '0020857', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '屯田7条', 'トンデン07ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区屯田8条', '01', '01102', '0020858', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '屯田8条', 'トンデン08ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区屯田9条', '01', '01102', '0020859', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '屯田9条', 'トンデン09ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区屯田10条', '01', '01102', '0020860', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '屯田10条', 'トンデン10ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区屯田11条', '01', '01102', '0020861', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '屯田11条', 'トンデン11ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区屯田町', '01', '01102', '0020865', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '屯田町', 'トンデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市', '03', '03209', '0210000', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('10979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市川崎区', '14', '14131', '2100000', '神奈川県', 'カナガワケン', '川崎市川崎区', 'カワサキシカワサキク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('10980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市川崎区本町', '14', '14131', '2100001', '神奈川県', 'カナガワケン', '川崎市川崎区', 'カワサキシカワサキク', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市川崎区榎町', '14', '14131', '2100002', '神奈川県', 'カナガワケン', '川崎市川崎区', 'カワサキシカワサキク', '榎町', 'エノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市川崎区堀之内町', '14', '14131', '2100003', '神奈川県', 'カナガワケン', '川崎市川崎区', 'カワサキシカワサキク', '堀之内町', 'ホリノウチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市川崎区宮本町', '14', '14131', '2100004', '神奈川県', 'カナガワケン', '川崎市川崎区', 'カワサキシカワサキク', '宮本町', 'ミヤモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市川崎区東田町', '14', '14131', '2100005', '神奈川県', 'カナガワケン', '川崎市川崎区', 'カワサキシカワサキク', '東田町', 'ヒガシダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市川崎区砂子', '14', '14131', '2100006', '神奈川県', 'カナガワケン', '川崎市川崎区', 'カワサキシカワサキク', '砂子', 'イサゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市川崎区駅前本町', '14', '14131', '2100007', '神奈川県', 'カナガワケン', '川崎市川崎区', 'カワサキシカワサキク', '駅前本町', 'エキマエホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市新町', '03', '03209', '0210001', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市川崎区富士見', '14', '14131', '2100011', '神奈川県', 'カナガワケン', '川崎市川崎区', 'カワサキシカワサキク', '富士見', 'フジミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市川崎区宮前町', '14', '14131', '2100012', '神奈川県', 'カナガワケン', '川崎市川崎区', 'カワサキシカワサキク', '宮前町', 'ミヤマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市川崎区新川通', '14', '14131', '2100013', '神奈川県', 'カナガワケン', '川崎市川崎区', 'カワサキシカワサキク', '新川通', 'シンカワドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市川崎区貝塚', '14', '14131', '2100014', '神奈川県', 'カナガワケン', '川崎市川崎区', 'カワサキシカワサキク', '貝塚', 'カイヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市川崎区南町', '14', '14131', '2100015', '神奈川県', 'カナガワケン', '川崎市川崎区', 'カワサキシカワサキク', '南町', 'ミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市中里', '03', '03209', '0210002', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '中里', 'ナカサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市川崎区元木', '14', '14131', '2100021', '神奈川県', 'カナガワケン', '川崎市川崎区', 'カワサキシカワサキク', '元木', 'モトギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市川崎区池田', '14', '14131', '2100022', '神奈川県', 'カナガワケン', '川崎市川崎区', 'カワサキシカワサキク', '池田', 'イケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市川崎区小川町', '14', '14131', '2100023', '神奈川県', 'カナガワケン', '川崎市川崎区', 'カワサキシカワサキク', '小川町', 'オガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市川崎区日進町', '14', '14131', '2100024', '神奈川県', 'カナガワケン', '川崎市川崎区', 'カワサキシカワサキク', '日進町', 'ニッシンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市川崎区下並木', '14', '14131', '2100025', '神奈川県', 'カナガワケン', '川崎市川崎区', 'カワサキシカワサキク', '下並木', 'シモナミキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('10999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市川崎区堤根', '14', '14131', '2100026', '神奈川県', 'カナガワケン', '川崎市川崎区', 'カワサキシカワサキク', '堤根', 'ツツミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市東五代', '03', '03209', '0210003', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '東五代', 'ヒガシゴダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市町浦', '03', '03209', '0210004', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '町浦', 'マチウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市中里沢田', '03', '03209', '0210005', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '中里', 'ナカサト', null, null, '沢田', 'サワダ');
INSERT INTO `ms_addresses` VALUES ('11003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市上坊', '03', '03209', '0210006', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '上坊', 'ジョウボウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市上日照', '03', '03209', '0210007', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '上日照', 'カミヒデリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市石畑', '03', '03209', '0210008', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '石畑', 'イシバタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市山目町', '03', '03209', '0210011', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '山目町', 'ヤマノメマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市宮前町', '03', '03209', '0210012', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '宮前町', 'ミヤマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市宮下町', '03', '03209', '0210013', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '宮下町', 'ミヤシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市蘭梅町', '03', '03209', '0210014', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '蘭梅町', 'ランバイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市中央町', '03', '03209', '0210021', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '中央町', 'チュウオウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市五代町', '03', '03209', '0210022', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '五代町', 'ゴダイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市銅谷町', '03', '03209', '0210023', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '銅谷町', 'ドウヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市幸町', '03', '03209', '0210024', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市山目向野', '03', '03209', '0210025', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '山目', 'ヤマノメ', null, null, '向野', 'ムカイノ');
INSERT INTO `ms_addresses` VALUES ('11015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市山目前田', '03', '03209', '0210026', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '山目', 'ヤマノメ', null, null, '前田', 'マエダ');
INSERT INTO `ms_addresses` VALUES ('11016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市竹山町', '03', '03209', '0210027', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '竹山町', 'タケヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市青葉', '03', '03209', '0210031', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '青葉', 'アオバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市末広', '03', '03209', '0210032', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '末広', 'スエヒロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市山目里前', '03', '03209', '0210033', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '山目', 'ヤマノメ', null, null, '里前', 'サトマエ');
INSERT INTO `ms_addresses` VALUES ('11020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市山目立沢', '03', '03209', '0210034', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '山目', 'ヤマノメ', null, null, '立沢', 'タチザワ');
INSERT INTO `ms_addresses` VALUES ('11021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市山目才天', '03', '03209', '0210035', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '山目', 'ヤマノメ', null, null, '才天', 'サイテン');
INSERT INTO `ms_addresses` VALUES ('11022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市山目十二神', '03', '03209', '0210036', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '山目', 'ヤマノメ', null, null, '十二神', 'ジュウニジン');
INSERT INTO `ms_addresses` VALUES ('11023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市赤荻', '03', '03209', '0210041', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '赤荻', 'アコオギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市山目三反田', '03', '03209', '0210051', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '山目', 'ヤマノメ', null, null, '三反田', 'サンタンダ');
INSERT INTO `ms_addresses` VALUES ('11025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市寿町', '03', '03209', '0210052', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '寿町', 'コトブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市山目中野', '03', '03209', '0210053', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '山目', 'ヤマノメ', null, null, '中野', 'ナカノ');
INSERT INTO `ms_addresses` VALUES ('11027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市山目境', '03', '03209', '0210054', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '山目', 'ヤマノメ', null, null, '境', 'サカイ');
INSERT INTO `ms_addresses` VALUES ('11028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市山目泥田', '03', '03209', '0210055', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '山目', 'ヤマノメ', null, null, '泥田', 'ドロタ');
INSERT INTO `ms_addresses` VALUES ('11029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市山目泥田山下', '03', '03209', '0210056', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '山目', 'ヤマノメ', null, null, '泥田山下', 'ドロタヤマシタ');
INSERT INTO `ms_addresses` VALUES ('11030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市山目館', '03', '03209', '0210061', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '山目', 'ヤマノメ', null, null, '館', 'タテ');
INSERT INTO `ms_addresses` VALUES ('11031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市山目寺前', '03', '03209', '0210062', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '山目', 'ヤマノメ', null, null, '寺前', 'テラマエ');
INSERT INTO `ms_addresses` VALUES ('11032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市山目大槻', '03', '03209', '0210063', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '山目', 'ヤマノメ', null, null, '大槻', 'オオツキ');
INSERT INTO `ms_addresses` VALUES ('11033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市山目沢内', '03', '03209', '0210064', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '山目', 'ヤマノメ', null, null, '沢内', 'サワウチ');
INSERT INTO `ms_addresses` VALUES ('11034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市川崎区鈴木町', '14', '14131', '2100801', '神奈川県', 'カナガワケン', '川崎市川崎区', 'カワサキシカワサキク', '鈴木町', 'スズキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市川崎区大師駅前', '14', '14131', '2100802', '神奈川県', 'カナガワケン', '川崎市川崎区', 'カワサキシカワサキク', '大師駅前', 'ダイシエキマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市川崎区川中島', '14', '14131', '2100803', '神奈川県', 'カナガワケン', '川崎市川崎区', 'カワサキシカワサキク', '川中島', 'カワナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市川崎区藤崎', '14', '14131', '2100804', '神奈川県', 'カナガワケン', '川崎市川崎区', 'カワサキシカワサキク', '藤崎', 'フジサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市川崎区伊勢町', '14', '14131', '2100805', '神奈川県', 'カナガワケン', '川崎市川崎区', 'カワサキシカワサキク', '伊勢町', 'イセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市川崎区中島', '14', '14131', '2100806', '神奈川県', 'カナガワケン', '川崎市川崎区', 'カワサキシカワサキク', '中島', 'ナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市川崎区港町', '14', '14131', '2100807', '神奈川県', 'カナガワケン', '川崎市川崎区', 'カワサキシカワサキク', '港町', 'ミナトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市川崎区旭町', '14', '14131', '2100808', '神奈川県', 'カナガワケン', '川崎市川崎区', 'カワサキシカワサキク', '旭町', 'アサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市川崎区大師河原', '14', '14131', '2100811', '神奈川県', 'カナガワケン', '川崎市川崎区', 'カワサキシカワサキク', '大師河原', 'ダイシガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市川崎区東門前', '14', '14131', '2100812', '神奈川県', 'カナガワケン', '川崎市川崎区', 'カワサキシカワサキク', '東門前', 'ヒガシモンゼン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市川崎区昭和', '14', '14131', '2100813', '神奈川県', 'カナガワケン', '川崎市川崎区', 'カワサキシカワサキク', '昭和', 'ショウワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市川崎区台町', '14', '14131', '2100814', '神奈川県', 'カナガワケン', '川崎市川崎区', 'カワサキシカワサキク', '台町', 'ダイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市川崎区大師公園', '14', '14131', '2100815', '神奈川県', 'カナガワケン', '川崎市川崎区', 'カワサキシカワサキク', '大師公園', 'ダイシコウエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市川崎区大師町', '14', '14131', '2100816', '神奈川県', 'カナガワケン', '川崎市川崎区', 'カワサキシカワサキク', '大師町', 'ダイシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市川崎区大師本町', '14', '14131', '2100817', '神奈川県', 'カナガワケン', '川崎市川崎区', 'カワサキシカワサキク', '大師本町', 'ダイシホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市川崎区中瀬', '14', '14131', '2100818', '神奈川県', 'カナガワケン', '川崎市川崎区', 'カワサキシカワサキク', '中瀬', 'ナカゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市川崎区殿町', '14', '14131', '2100821', '神奈川県', 'カナガワケン', '川崎市川崎区', 'カワサキシカワサキク', '殿町', 'トノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市川崎区田町', '14', '14131', '2100822', '神奈川県', 'カナガワケン', '川崎市川崎区', 'カワサキシカワサキク', '田町', 'タマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市川崎区江川', '14', '14131', '2100823', '神奈川県', 'カナガワケン', '川崎市川崎区', 'カワサキシカワサキク', '江川', 'エガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市川崎区日ノ出', '14', '14131', '2100824', '神奈川県', 'カナガワケン', '川崎市川崎区', 'カワサキシカワサキク', '日ノ出', 'ヒノデ', null, null, null, null), ('11054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市川崎区出来野', '14', '14131', '2100825', '神奈川県', 'カナガワケン', '川崎市川崎区', 'カワサキシカワサキク', '出来野', 'デキノ', null, null, null, null), ('11055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市川崎区塩浜', '14', '14131', '2100826', '神奈川県', 'カナガワケン', '川崎市川崎区', 'カワサキシカワサキク', '塩浜', 'シオハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市川崎区四谷下町', '14', '14131', '2100827', '神奈川県', 'カナガワケン', '川崎市川崎区', 'カワサキシカワサキク', '四谷下町', 'ヨツヤシモチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市川崎区四谷上町', '14', '14131', '2100828', '神奈川県', 'カナガワケン', '川崎市川崎区', 'カワサキシカワサキク', '四谷上町', 'ヨツヤカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市川崎区観音', '14', '14131', '2100831', '神奈川県', 'カナガワケン', '川崎市川崎区', 'カワサキシカワサキク', '観音', 'カンノン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市川崎区池上新町', '14', '14131', '2100832', '神奈川県', 'カナガワケン', '川崎市川崎区', 'カワサキシカワサキク', '池上新町', 'イケガミシンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市川崎区桜本', '14', '14131', '2100833', '神奈川県', 'カナガワケン', '川崎市川崎区', 'カワサキシカワサキク', '桜本', 'サクラモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市川崎区大島', '14', '14131', '2100834', '神奈川県', 'カナガワケン', '川崎市川崎区', 'カワサキシカワサキク', '大島', 'オオシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市川崎区追分町', '14', '14131', '2100835', '神奈川県', 'カナガワケン', '川崎市川崎区', 'カワサキシカワサキク', '追分町', 'オイワケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市川崎区大島上町', '14', '14131', '2100836', '神奈川県', 'カナガワケン', '川崎市川崎区', 'カワサキシカワサキク', '大島上町', 'オオシマカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市川崎区渡田', '14', '14131', '2100837', '神奈川県', 'カナガワケン', '川崎市川崎区', 'カワサキシカワサキク', '渡田', 'ワタリダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市川崎区境町', '14', '14131', '2100838', '神奈川県', 'カナガワケン', '川崎市川崎区', 'カワサキシカワサキク', '境町', 'サカイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市川崎区渡田向町', '14', '14131', '2100841', '神奈川県', 'カナガワケン', '川崎市川崎区', 'カワサキシカワサキク', '渡田向町', 'ワタリダムカイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市川崎区渡田東町', '14', '14131', '2100842', '神奈川県', 'カナガワケン', '川崎市川崎区', 'カワサキシカワサキク', '渡田東町', 'ワタリダヒガシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市川崎区小田栄', '14', '14131', '2100843', '神奈川県', 'カナガワケン', '川崎市川崎区', 'カワサキシカワサキク', '小田栄', 'オダサカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市川崎区渡田新町', '14', '14131', '2100844', '神奈川県', 'カナガワケン', '川崎市川崎区', 'カワサキシカワサキク', '渡田新町', 'ワタリダシンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市川崎区渡田山王町', '14', '14131', '2100845', '神奈川県', 'カナガワケン', '川崎市川崎区', 'カワサキシカワサキク', '渡田山王町', 'ワタリダサンノウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市川崎区小田', '14', '14131', '2100846', '神奈川県', 'カナガワケン', '川崎市川崎区', 'カワサキシカワサキク', '小田', 'オダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市川崎区浅田', '14', '14131', '2100847', '神奈川県', 'カナガワケン', '川崎市川崎区', 'カワサキシカワサキク', '浅田', 'アサダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市川崎区京町', '14', '14131', '2100848', '神奈川県', 'カナガワケン', '川崎市川崎区', 'カワサキシカワサキク', '京町', 'キョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市川崎区浜町', '14', '14131', '2100851', '神奈川県', 'カナガワケン', '川崎市川崎区', 'カワサキシカワサキク', '浜町', 'ハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市川崎区鋼管通', '14', '14131', '2100852', '神奈川県', 'カナガワケン', '川崎市川崎区', 'カワサキシカワサキク', '鋼管通', 'コウカンドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市川崎区田島町', '14', '14131', '2100853', '神奈川県', 'カナガワケン', '川崎市川崎区', 'カワサキシカワサキク', '田島町', 'タジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市川崎区浅野町', '14', '14131', '2100854', '神奈川県', 'カナガワケン', '川崎市川崎区', 'カワサキシカワサキク', '浅野町', 'アサノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市川崎区南渡田町', '14', '14131', '2100855', '神奈川県', 'カナガワケン', '川崎市川崎区', 'カワサキシカワサキク', '南渡田町', 'ミナミワタリダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市川崎区田辺新田', '14', '14131', '2100856', '神奈川県', 'カナガワケン', '川崎市川崎区', 'カワサキシカワサキク', '田辺新田', 'タナベシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市川崎区白石町', '14', '14131', '2100857', '神奈川県', 'カナガワケン', '川崎市川崎区', 'カワサキシカワサキク', '白石町', 'シライシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市川崎区大川町', '14', '14131', '2100858', '神奈川県', 'カナガワケン', '川崎市川崎区', 'カワサキシカワサキク', '大川町', 'オオカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市川崎区小島町', '14', '14131', '2100861', '神奈川県', 'カナガワケン', '川崎市川崎区', 'カワサキシカワサキク', '小島町', 'コジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市川崎区浮島町', '14', '14131', '2100862', '神奈川県', 'カナガワケン', '川崎市川崎区', 'カワサキシカワサキク', '浮島町', 'ウキシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市川崎区夜光', '14', '14131', '2100863', '神奈川県', 'カナガワケン', '川崎市川崎区', 'カワサキシカワサキク', '夜光', 'ヤコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市川崎区池上町', '14', '14131', '2100864', '神奈川県', 'カナガワケン', '川崎市川崎区', 'カワサキシカワサキク', '池上町', 'イケガミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市川崎区千鳥町', '14', '14131', '2100865', '神奈川県', 'カナガワケン', '川崎市川崎区', 'カワサキシカワサキク', '千鳥町', 'チドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市川崎区水江町', '14', '14131', '2100866', '神奈川県', 'カナガワケン', '川崎市川崎区', 'カワサキシカワサキク', '水江町', 'ミズエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市川崎区扇町', '14', '14131', '2100867', '神奈川県', 'カナガワケン', '川崎市川崎区', 'カワサキシカワサキク', '扇町', 'オウギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市川崎区扇島', '14', '14131', '2100868', '神奈川県', 'カナガワケン', '川崎市川崎区', 'カワサキシカワサキク', '扇島', 'オオギシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市川崎区東扇島', '14', '14131', '2100869', '神奈川県', 'カナガワケン', '川崎市川崎区', 'カワサキシカワサキク', '東扇島', 'ヒガシオオギシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市厳美町', '03', '03209', '0210101', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '厳美町', 'ゲンビチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市萩荘赤猪子', '03', '03209', '0210102', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '萩荘', 'ハギショウ', null, null, '赤猪子', 'アカイノコ');
INSERT INTO `ms_addresses` VALUES ('11093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市萩荘芦ノ口', '03', '03209', '0210102', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '萩荘', 'ハギショウ', null, null, '芦ノ口', 'アシノクチ');
INSERT INTO `ms_addresses` VALUES ('11094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市萩荘甘蕨', '03', '03209', '0210102', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '萩荘', 'ハギショウ', null, null, '甘蕨', 'アマワラビ');
INSERT INTO `ms_addresses` VALUES ('11095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市萩荘老流', '03', '03209', '0210102', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '萩荘', 'ハギショウ', null, null, '老流', 'オイナガレ');
INSERT INTO `ms_addresses` VALUES ('11096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市萩荘大沢', '03', '03209', '0210102', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '萩荘', 'ハギショウ', null, null, '大沢', 'オオサワ');
INSERT INTO `ms_addresses` VALUES ('11097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市萩荘上宇津野', '03', '03209', '0210102', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '萩荘', 'ハギショウ', null, null, '上宇津野', 'カミウツノ');
INSERT INTO `ms_addresses` VALUES ('11098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市萩荘上本郷', '03', '03209', '0210102', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '萩荘', 'ハギショウ', null, null, '上本郷', 'カミホンゴウ');
INSERT INTO `ms_addresses` VALUES ('11099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市萩荘上要害', '03', '03209', '0210102', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '萩荘', 'ハギショウ', null, null, '上要害', 'カミヨウガイ');
INSERT INTO `ms_addresses` VALUES ('11100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市萩荘化粧坂', '03', '03209', '0210102', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '萩荘', 'ハギショウ', null, null, '化粧坂', 'ケショウザカ');
INSERT INTO `ms_addresses` VALUES ('11101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市萩荘三月田', '03', '03209', '0210102', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '萩荘', 'ハギショウ', null, null, '三月田', 'サンガツダ');
INSERT INTO `ms_addresses` VALUES ('11102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市萩荘下宇津野', '03', '03209', '0210102', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '萩荘', 'ハギショウ', null, null, '下宇津野', 'シモウツノ');
INSERT INTO `ms_addresses` VALUES ('11103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市萩荘下本郷', '03', '03209', '0210102', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '萩荘', 'ハギショウ', null, null, '下本郷', 'シモホンゴウ');
INSERT INTO `ms_addresses` VALUES ('11104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市萩荘外山', '03', '03209', '0210102', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '萩荘', 'ハギショウ', null, null, '外山', 'ソデヤマ');
INSERT INTO `ms_addresses` VALUES ('11105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市萩荘堂の沢', '03', '03209', '0210102', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '萩荘', 'ハギショウ', null, null, '堂の沢', 'ドウノサワ');
INSERT INTO `ms_addresses` VALUES ('11106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市萩荘栃倉', '03', '03209', '0210102', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '萩荘', 'ハギショウ', null, null, '栃倉', 'トチクラ');
INSERT INTO `ms_addresses` VALUES ('11107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市萩荘栃倉南', '03', '03209', '0210102', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '萩荘', 'ハギショウ', null, null, '栃倉南', 'トチクラミナミ');
INSERT INTO `ms_addresses` VALUES ('11108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市萩荘長倉', '03', '03209', '0210102', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '萩荘', 'ハギショウ', null, null, '長倉', 'ナガクラ');
INSERT INTO `ms_addresses` VALUES ('11109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市萩荘中沢', '03', '03209', '0210102', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '萩荘', 'ハギショウ', null, null, '中沢', 'ナカザワ');
INSERT INTO `ms_addresses` VALUES ('11110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市萩荘八森', '03', '03209', '0210102', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '萩荘', 'ハギショウ', null, null, '八森', 'ハチモリ');
INSERT INTO `ms_addresses` VALUES ('11111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市萩荘馬場', '03', '03209', '0210102', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '萩荘', 'ハギショウ', null, null, '馬場', 'ババ');
INSERT INTO `ms_addresses` VALUES ('11112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市萩荘平場', '03', '03209', '0210102', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '萩荘', 'ハギショウ', null, null, '平場', 'ヒラバ');
INSERT INTO `ms_addresses` VALUES ('11113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市萩荘広面', '03', '03209', '0210102', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '萩荘', 'ハギショウ', null, null, '広面', 'ヒロオモテ');
INSERT INTO `ms_addresses` VALUES ('11114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市萩荘古釜場', '03', '03209', '0210102', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '萩荘', 'ハギショウ', null, null, '古釜場', 'フルカマバ');
INSERT INTO `ms_addresses` VALUES ('11115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市萩荘曲淵', '03', '03209', '0210102', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '萩荘', 'ハギショウ', null, null, '曲淵', 'マガリフチ');
INSERT INTO `ms_addresses` VALUES ('11116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市萩荘松原', '03', '03209', '0210102', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '萩荘', 'ハギショウ', null, null, '松原', 'マツバラ');
INSERT INTO `ms_addresses` VALUES ('11117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市萩荘南沢', '03', '03209', '0210102', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '萩荘', 'ハギショウ', null, null, '南沢', 'ミナミザワ');
INSERT INTO `ms_addresses` VALUES ('11118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市萩荘谷起', '03', '03209', '0210102', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '萩荘', 'ハギショウ', null, null, '谷起', 'ヤギ');
INSERT INTO `ms_addresses` VALUES ('11119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市萩荘八瀬', '03', '03209', '0210102', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '萩荘', 'ハギショウ', null, null, '八瀬', 'ヤセ');
INSERT INTO `ms_addresses` VALUES ('11120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市萩荘焼切', '03', '03209', '0210102', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '萩荘', 'ハギショウ', null, null, '焼切', 'ヤッキリ');
INSERT INTO `ms_addresses` VALUES ('11121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市萩荘八幡', '03', '03209', '0210102', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '萩荘', 'ハギショウ', null, null, '八幡', 'ヤハタ');
INSERT INTO `ms_addresses` VALUES ('11122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市萩荘山ノ沢', '03', '03209', '0210102', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '萩荘', 'ハギショウ', null, null, '山ノ沢', 'ヤマノサワ');
INSERT INTO `ms_addresses` VALUES ('11123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市舞川', '03', '03209', '0210221', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '舞川', 'マイカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市桜街', '03', '03209', '0210801', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '桜街', 'サクラコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市北十軒街', '03', '03209', '0210802', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '北十軒街', 'キタジュッケンコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市南十軒街', '03', '03209', '0210803', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '南十軒街', 'ミナミジュッケンコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市五十人町', '03', '03209', '0210804', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '五十人町', 'ゴジュウニンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市豊町', '03', '03209', '0210805', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '豊町', 'ユタカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市下大槻街', '03', '03209', '0210806', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '下大槻街', 'シモオオツキコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市東花王町', '03', '03209', '0210807', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '東花王町', 'ヒガシカオウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市久保', '03', '03209', '0210811', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '久保', 'クボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市樋渡', '03', '03209', '0210812', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '樋渡', 'ヒワタシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市南ほうりょう', '03', '03209', '0210813', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '南ほうりょう', 'ミナミホウリョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市北ほうりょう', '03', '03209', '0210814', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '北ほうりょう', 'キタホウリョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市要害', '03', '03209', '0210815', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '要害', 'ヨウガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市三関', '03', '03209', '0210821', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '三関', 'サンノセキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市東台', '03', '03209', '0210822', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '東台', 'ヒガシダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市沼田', '03', '03209', '0210831', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '沼田', 'ヌマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市散田', '03', '03209', '0210832', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '散田', 'サンタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市柄貝', '03', '03209', '0210833', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '柄貝', 'カラカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市宇南', '03', '03209', '0210834', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '宇南', 'ウナン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市二本木', '03', '03209', '0210835', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '二本木', 'ニホンギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市鳴神', '03', '03209', '0210836', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '鳴神', 'ナルガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市吸川街', '03', '03209', '0210841', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '吸川街', 'スイカワコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市柳町', '03', '03209', '0210842', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '柳町', 'ヤナギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市深町', '03', '03209', '0210843', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '深町', 'フカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市反町', '03', '03209', '0210844', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '反町', 'タンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市関が丘', '03', '03209', '0210851', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '関が丘', 'セキガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市沢', '03', '03209', '0210852', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '沢', 'サワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市相去', '03', '03209', '0210853', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '相去', 'アイサリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市西沢', '03', '03209', '0210854', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '西沢', 'ニシザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市機織山', '03', '03209', '0210861', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '機織山', 'ハタオリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市千代田町', '03', '03209', '0210862', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '千代田町', 'チヨダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市南町', '03', '03209', '0210863', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '南町', 'ミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市旭町', '03', '03209', '0210864', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '旭町', 'アサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市新山', '03', '03209', '0210865', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '新山', 'ニイヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市南新町', '03', '03209', '0210866', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '南新町', 'ミナミシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市駅前', '03', '03209', '0210867', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '駅前', 'エキマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市八幡町', '03', '03209', '0210871', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '八幡町', 'ハチマンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市宮坂町', '03', '03209', '0210872', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '宮坂町', 'ミヤサカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市台町', '03', '03209', '0210873', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '台町', 'ダイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市釣山', '03', '03209', '0210874', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '釣山', 'ツリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市高崎町', '03', '03209', '0210875', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '高崎町', 'タカサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市広街', '03', '03209', '0210876', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '広街', 'ヒロコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市城内', '03', '03209', '0210877', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '城内', 'ジョウナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市大町', '03', '03209', '0210881', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '大町', 'オオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市上大槻街', '03', '03209', '0210882', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '上大槻街', 'カミオオツキコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市新大町', '03', '03209', '0210883', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '新大町', 'シンオオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市大手町', '03', '03209', '0210884', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '大手町', 'オオテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市田村町', '03', '03209', '0210885', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '田村町', 'タムラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市桜木町', '03', '03209', '0210891', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '桜木町', 'サクラギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市東地主町', '03', '03209', '0210892', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '東地主町', 'ヒガシジシュマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市地主町', '03', '03209', '0210893', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '地主町', 'ジシュマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市磐井町', '03', '03209', '0210894', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '磐井町', 'イワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市真柴', '03', '03209', '0210901', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '真柴', 'マシバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市萩荘', '03', '03209', '0210902', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '萩荘', 'ハギショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市中原区', '14', '14133', '2110000', '神奈川県', 'カナガワケン', '川崎市中原区', 'カワサキシナカハラク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('11228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市中原区上丸子八幡町', '14', '14133', '2110001', '神奈川県', 'カナガワケン', '川崎市中原区', 'カワサキシナカハラク', '上丸子八幡町', 'カミマルコハチマンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市中原区上丸子山王町', '14', '14133', '2110002', '神奈川県', 'カナガワケン', '川崎市中原区', 'カワサキシナカハラク', '上丸子山王町', 'カミマルコサンノウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市中原区上丸子', '14', '14133', '2110003', '神奈川県', 'カナガワケン', '川崎市中原区', 'カワサキシナカハラク', '上丸子', 'カミマルコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市中原区新丸子東', '14', '14133', '2110004', '神奈川県', 'カナガワケン', '川崎市中原区', 'カワサキシナカハラク', '新丸子東', 'シンマルコヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市中原区新丸子町', '14', '14133', '2110005', '神奈川県', 'カナガワケン', '川崎市中原区', 'カワサキシナカハラク', '新丸子町', 'シンマルコマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市中原区丸子通', '14', '14133', '2110006', '神奈川県', 'カナガワケン', '川崎市中原区', 'カワサキシナカハラク', '丸子通', 'マルコドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市中原区上丸子天神町', '14', '14133', '2110007', '神奈川県', 'カナガワケン', '川崎市中原区', 'カワサキシナカハラク', '上丸子天神町', 'カミマルコテンジンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市中原区下沼部', '14', '14133', '2110011', '神奈川県', 'カナガワケン', '川崎市中原区', 'カワサキシナカハラク', '下沼部', 'シモヌマベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市中原区中丸子', '14', '14133', '2110012', '神奈川県', 'カナガワケン', '川崎市中原区', 'カワサキシナカハラク', '中丸子', 'ナカマルコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市中原区上平間', '14', '14133', '2110013', '神奈川県', 'カナガワケン', '川崎市中原区', 'カワサキシナカハラク', '上平間', 'カミヒラマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市中原区田尻町', '14', '14133', '2110014', '神奈川県', 'カナガワケン', '川崎市中原区', 'カワサキシナカハラク', '田尻町', 'タジリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市中原区北谷町', '14', '14133', '2110015', '神奈川県', 'カナガワケン', '川崎市中原区', 'カワサキシナカハラク', '北谷町', 'キタヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市中原区市ノ坪', '14', '14133', '2110016', '神奈川県', 'カナガワケン', '川崎市中原区', 'カワサキシナカハラク', '市ノ坪', 'イチノツボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市中原区木月住吉町', '14', '14133', '2110021', '神奈川県', 'カナガワケン', '川崎市中原区', 'カワサキシナカハラク', '木月住吉町', 'キヅキスミヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市中原区苅宿', '14', '14133', '2110022', '神奈川県', 'カナガワケン', '川崎市中原区', 'カワサキシナカハラク', '苅宿', 'カリヤド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市中原区大倉町', '14', '14133', '2110023', '神奈川県', 'カナガワケン', '川崎市中原区', 'カワサキシナカハラク', '大倉町', 'オオクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市中原区西加瀬', '14', '14133', '2110024', '神奈川県', 'カナガワケン', '川崎市中原区', 'カワサキシナカハラク', '西加瀬', 'ニシカセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市中原区木月', '14', '14133', '2110025', '神奈川県', 'カナガワケン', '川崎市中原区', 'カワサキシナカハラク', '木月', 'キヅキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市中原区木月大町', '14', '14133', '2110031', '神奈川県', 'カナガワケン', '川崎市中原区', 'カワサキシナカハラク', '木月大町', 'キヅキオオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市中原区木月伊勢町', '14', '14133', '2110032', '神奈川県', 'カナガワケン', '川崎市中原区', 'カワサキシナカハラク', '木月伊勢町', 'キヅキイセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市中原区木月祗園町', '14', '14133', '2110033', '神奈川県', 'カナガワケン', '川崎市中原区', 'カワサキシナカハラク', '木月祗園町', 'キヅキギオンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市中原区井田中ノ町', '14', '14133', '2110034', '神奈川県', 'カナガワケン', '川崎市中原区', 'カワサキシナカハラク', '井田中ノ町', 'イダナカノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市中原区井田', '14', '14133', '2110035', '神奈川県', 'カナガワケン', '川崎市中原区', 'カワサキシナカハラク', '井田', 'イダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市中原区井田杉山町', '14', '14133', '2110036', '神奈川県', 'カナガワケン', '川崎市中原区', 'カワサキシナカハラク', '井田杉山町', 'イダスギヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市中原区井田三舞町', '14', '14133', '2110037', '神奈川県', 'カナガワケン', '川崎市中原区', 'カワサキシナカハラク', '井田三舞町', 'イダサンマイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市中原区下小田中', '14', '14133', '2110041', '神奈川県', 'カナガワケン', '川崎市中原区', 'カワサキシナカハラク', '下小田中', 'シモコダナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市中原区下新城', '14', '14133', '2110042', '神奈川県', 'カナガワケン', '川崎市中原区', 'カワサキシナカハラク', '下新城', 'シモシンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市中原区新城中町', '14', '14133', '2110043', '神奈川県', 'カナガワケン', '川崎市中原区', 'カワサキシナカハラク', '新城中町', 'シンジョウナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市中原区新城', '14', '14133', '2110044', '神奈川県', 'カナガワケン', '川崎市中原区', 'カワサキシナカハラク', '新城', 'シンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市中原区上新城', '14', '14133', '2110045', '神奈川県', 'カナガワケン', '川崎市中原区', 'カワサキシナカハラク', '上新城', 'カミシンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市中原区宮内', '14', '14133', '2110051', '神奈川県', 'カナガワケン', '川崎市中原区', 'カワサキシナカハラク', '宮内', 'ミヤウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市中原区等々力', '14', '14133', '2110052', '神奈川県', 'カナガワケン', '川崎市中原区', 'カワサキシナカハラク', '等々力', 'トドロキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市中原区上小田中', '14', '14133', '2110053', '神奈川県', 'カナガワケン', '川崎市中原区', 'カワサキシナカハラク', '上小田中', 'カミコダナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市中原区小杉', '14', '14133', '2110061', '神奈川県', 'カナガワケン', '川崎市中原区', 'カワサキシナカハラク', '小杉', 'コスギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市中原区小杉陣屋町', '14', '14133', '2110062', '神奈川県', 'カナガワケン', '川崎市中原区', 'カワサキシナカハラク', '小杉陣屋町', 'コスギジンヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市中原区小杉町', '14', '14133', '2110063', '神奈川県', 'カナガワケン', '川崎市中原区', 'カワサキシナカハラク', '小杉町', 'コスギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市中原区今井南町', '14', '14133', '2110064', '神奈川県', 'カナガワケン', '川崎市中原区', 'カワサキシナカハラク', '今井南町', 'イマイミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市中原区今井仲町', '14', '14133', '2110065', '神奈川県', 'カナガワケン', '川崎市中原区', 'カワサキシナカハラク', '今井仲町', 'イマイナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市中原区今井西町', '14', '14133', '2110066', '神奈川県', 'カナガワケン', '川崎市中原区', 'カワサキシナカハラク', '今井西町', 'イマイニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市中原区今井上町', '14', '14133', '2110067', '神奈川県', 'カナガワケン', '川崎市中原区', 'カワサキシナカハラク', '今井上町', 'イマイカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市中原区小杉御殿町', '14', '14133', '2110068', '神奈川県', 'カナガワケン', '川崎市中原区', 'カワサキシナカハラク', '小杉御殿町', 'コスギゴテンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市幸区', '14', '14132', '2120000', '神奈川県', 'カナガワケン', '川崎市幸区', 'カワサキシサイワイク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('11290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市幸区小向東芝町', '14', '14132', '2120001', '神奈川県', 'カナガワケン', '川崎市幸区', 'カワサキシサイワイク', '小向東芝町', 'コムカイトウシバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市幸区小向仲野町', '14', '14132', '2120002', '神奈川県', 'カナガワケン', '川崎市幸区', 'カワサキシサイワイク', '小向仲野町', 'コムカイナカノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市幸区小向町', '14', '14132', '2120003', '神奈川県', 'カナガワケン', '川崎市幸区', 'カワサキシサイワイク', '小向町', 'コムカイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市幸区小向西町', '14', '14132', '2120004', '神奈川県', 'カナガワケン', '川崎市幸区', 'カワサキシサイワイク', '小向西町', 'コムカイニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市幸区戸手', '14', '14132', '2120005', '神奈川県', 'カナガワケン', '川崎市幸区', 'カワサキシサイワイク', '戸手', 'トテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市幸区遠藤町', '14', '14132', '2120006', '神奈川県', 'カナガワケン', '川崎市幸区', 'カワサキシサイワイク', '遠藤町', 'エンドウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市幸区河原町', '14', '14132', '2120007', '神奈川県', 'カナガワケン', '川崎市幸区', 'カワサキシサイワイク', '河原町', 'カワラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市幸区幸町', '14', '14132', '2120011', '神奈川県', 'カナガワケン', '川崎市幸区', 'カワサキシサイワイク', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市幸区中幸町', '14', '14132', '2120012', '神奈川県', 'カナガワケン', '川崎市幸区', 'カワサキシサイワイク', '中幸町', 'ナカサイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市幸区堀川町', '14', '14132', '2120013', '神奈川県', 'カナガワケン', '川崎市幸区', 'カワサキシサイワイク', '堀川町', 'ホリカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市幸区大宮町', '14', '14132', '2120014', '神奈川県', 'カナガワケン', '川崎市幸区', 'カワサキシサイワイク', '大宮町', 'オオミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市幸区柳町', '14', '14132', '2120015', '神奈川県', 'カナガワケン', '川崎市幸区', 'カワサキシサイワイク', '柳町', 'ヤナギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市幸区南幸町', '14', '14132', '2120016', '神奈川県', 'カナガワケン', '川崎市幸区', 'カワサキシサイワイク', '南幸町', 'ミナミサイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市幸区都町', '14', '14132', '2120021', '神奈川県', 'カナガワケン', '川崎市幸区', 'カワサキシサイワイク', '都町', 'ミヤコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市幸区神明町', '14', '14132', '2120022', '神奈川県', 'カナガワケン', '川崎市幸区', 'カワサキシサイワイク', '神明町', 'シンメイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市幸区戸手本町', '14', '14132', '2120023', '神奈川県', 'カナガワケン', '川崎市幸区', 'カワサキシサイワイク', '戸手本町', 'トデホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市幸区塚越', '14', '14132', '2120024', '神奈川県', 'カナガワケン', '川崎市幸区', 'カワサキシサイワイク', '塚越', 'ツカゴシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市幸区古川町', '14', '14132', '2120025', '神奈川県', 'カナガワケン', '川崎市幸区', 'カワサキシサイワイク', '古川町', 'フルカワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市幸区紺屋町', '14', '14132', '2120026', '神奈川県', 'カナガワケン', '川崎市幸区', 'カワサキシサイワイク', '紺屋町', 'コンヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市幸区新塚越', '14', '14132', '2120027', '神奈川県', 'カナガワケン', '川崎市幸区', 'カワサキシサイワイク', '新塚越', 'シンツカゴシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市幸区新小倉', '14', '14132', '2120031', '神奈川県', 'カナガワケン', '川崎市幸区', 'カワサキシサイワイク', '新小倉', 'シンオグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市幸区新川崎', '14', '14132', '2120032', '神奈川県', 'カナガワケン', '川崎市幸区', 'カワサキシサイワイク', '新川崎', 'シンカワサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市幸区東小倉', '14', '14132', '2120033', '神奈川県', 'カナガワケン', '川崎市幸区', 'カワサキシサイワイク', '東小倉', 'ヒガシオグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市幸区東古市場', '14', '14132', '2120051', '神奈川県', 'カナガワケン', '川崎市幸区', 'カワサキシサイワイク', '東古市場', 'ヒガシフルイチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市幸区古市場', '14', '14132', '2120052', '神奈川県', 'カナガワケン', '川崎市幸区', 'カワサキシサイワイク', '古市場', 'フルイチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市幸区下平間', '14', '14132', '2120053', '神奈川県', 'カナガワケン', '川崎市幸区', 'カワサキシサイワイク', '下平間', 'シモヒラマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市幸区小倉', '14', '14132', '2120054', '神奈川県', 'カナガワケン', '川崎市幸区', 'カワサキシサイワイク', '小倉', 'オグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市幸区南加瀬', '14', '14132', '2120055', '神奈川県', 'カナガワケン', '川崎市幸区', 'カワサキシサイワイク', '南加瀬', 'ミナミカセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市幸区矢上', '14', '14132', '2120056', '神奈川県', 'カナガワケン', '川崎市幸区', 'カワサキシサイワイク', '矢上', 'ヤガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市幸区北加瀬', '14', '14132', '2120057', '神奈川県', 'カナガワケン', '川崎市幸区', 'カワサキシサイワイク', '北加瀬', 'キタカセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市幸区鹿島田', '14', '14132', '2120058', '神奈川県', 'カナガワケン', '川崎市幸区', 'カワサキシサイワイク', '鹿島田', 'カシマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市高津区', '14', '14134', '2130000', '神奈川県', 'カナガワケン', '川崎市高津区', 'カワサキシタカツク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('11354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市高津区溝口', '14', '14134', '2130001', '神奈川県', 'カナガワケン', '川崎市高津区', 'カワサキシタカツク', '溝口', 'ミゾノクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市高津区二子', '14', '14134', '2130002', '神奈川県', 'カナガワケン', '川崎市高津区', 'カワサキシタカツク', '二子', 'フタゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市高津区瀬田', '14', '14134', '2130003', '神奈川県', 'カナガワケン', '川崎市高津区', 'カワサキシタカツク', '瀬田', 'セタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市高津区諏訪', '14', '14134', '2130004', '神奈川県', 'カナガワケン', '川崎市高津区', 'カワサキシタカツク', '諏訪', 'スワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市高津区北見方', '14', '14134', '2130005', '神奈川県', 'カナガワケン', '川崎市高津区', 'カワサキシタカツク', '北見方', 'キタミカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市高津区下野毛', '14', '14134', '2130006', '神奈川県', 'カナガワケン', '川崎市高津区', 'カワサキシタカツク', '下野毛', 'シモノゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市高津区久本', '14', '14134', '2130011', '神奈川県', 'カナガワケン', '川崎市高津区', 'カワサキシタカツク', '久本', 'ヒサモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市高津区坂戸', '14', '14134', '2130012', '神奈川県', 'カナガワケン', '川崎市高津区', 'カワサキシタカツク', '坂戸', 'サカド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市高津区末長', '14', '14134', '2130013', '神奈川県', 'カナガワケン', '川崎市高津区', 'カワサキシタカツク', '末長', 'スエナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市高津区新作', '14', '14134', '2130014', '神奈川県', 'カナガワケン', '川崎市高津区', 'カワサキシタカツク', '新作', 'シンサク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市高津区梶ケ谷', '14', '14134', '2130015', '神奈川県', 'カナガワケン', '川崎市高津区', 'カワサキシタカツク', '梶ケ谷', 'カジガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市高津区千年新町', '14', '14134', '2130021', '神奈川県', 'カナガワケン', '川崎市高津区', 'カワサキシタカツク', '千年新町', 'チトセシンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市高津区千年', '14', '14134', '2130022', '神奈川県', 'カナガワケン', '川崎市高津区', 'カワサキシタカツク', '千年', 'チトセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市高津区子母口', '14', '14134', '2130023', '神奈川県', 'カナガワケン', '川崎市高津区', 'カワサキシタカツク', '子母口', 'シボクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市高津区明津', '14', '14134', '2130024', '神奈川県', 'カナガワケン', '川崎市高津区', 'カワサキシタカツク', '明津', 'アクツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市高津区蟹ケ谷', '14', '14134', '2130025', '神奈川県', 'カナガワケン', '川崎市高津区', 'カワサキシタカツク', '蟹ケ谷', 'カニガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市高津区久末', '14', '14134', '2130026', '神奈川県', 'カナガワケン', '川崎市高津区', 'カワサキシタカツク', '久末', 'ヒサスエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市高津区野川', '14', '14134', '2130027', '神奈川県', 'カナガワケン', '川崎市高津区', 'カワサキシタカツク', '野川', 'ノガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市高津区宇奈根', '14', '14134', '2130031', '神奈川県', 'カナガワケン', '川崎市高津区', 'カワサキシタカツク', '宇奈根', 'ウナネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市高津区久地', '14', '14134', '2130032', '神奈川県', 'カナガワケン', '川崎市高津区', 'カワサキシタカツク', '久地', 'クジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市高津区下作延', '14', '14134', '2130033', '神奈川県', 'カナガワケン', '川崎市高津区', 'カワサキシタカツク', '下作延', 'シモサクノベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市高津区上作延', '14', '14134', '2130034', '神奈川県', 'カナガワケン', '川崎市高津区', 'カワサキシタカツク', '上作延', 'カミサクノベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市高津区向ケ丘', '14', '14134', '2130035', '神奈川県', 'カナガワケン', '川崎市高津区', 'カワサキシタカツク', '向ケ丘', 'ムカイガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市多摩区', '14', '14135', '2140000', '神奈川県', 'カナガワケン', '川崎市多摩区', 'カワサキシタマク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('11410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市多摩区菅', '14', '14135', '2140001', '神奈川県', 'カナガワケン', '川崎市多摩区', 'カワサキシタマク', '菅', 'スゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市多摩区菅野戸呂', '14', '14135', '2140002', '神奈川県', 'カナガワケン', '川崎市多摩区', 'カワサキシタマク', '菅野戸呂', 'スゲノトロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市多摩区菅稲田堤', '14', '14135', '2140003', '神奈川県', 'カナガワケン', '川崎市多摩区', 'カワサキシタマク', '菅稲田堤', 'スゲイナダヅツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市多摩区菅馬場', '14', '14135', '2140004', '神奈川県', 'カナガワケン', '川崎市多摩区', 'カワサキシタマク', '菅馬場', 'スゲバンバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市多摩区寺尾台', '14', '14135', '2140005', '神奈川県', 'カナガワケン', '川崎市多摩区', 'カワサキシタマク', '寺尾台', 'テラオダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市多摩区菅仙谷', '14', '14135', '2140006', '神奈川県', 'カナガワケン', '川崎市多摩区', 'カワサキシタマク', '菅仙谷', 'スゲセンゴク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市多摩区菅城下', '14', '14135', '2140007', '神奈川県', 'カナガワケン', '川崎市多摩区', 'カワサキシタマク', '菅城下', 'スゲシロシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市多摩区菅北浦', '14', '14135', '2140008', '神奈川県', 'カナガワケン', '川崎市多摩区', 'カワサキシタマク', '菅北浦', 'スゲキタウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市多摩区布田', '14', '14135', '2140011', '神奈川県', 'カナガワケン', '川崎市多摩区', 'カワサキシタマク', '布田', 'フダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市多摩区中野島', '14', '14135', '2140012', '神奈川県', 'カナガワケン', '川崎市多摩区', 'カワサキシタマク', '中野島', 'ナカノシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市多摩区登戸新町', '14', '14135', '2140013', '神奈川県', 'カナガワケン', '川崎市多摩区', 'カワサキシタマク', '登戸新町', 'ノボリトシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市多摩区登戸', '14', '14135', '2140014', '神奈川県', 'カナガワケン', '川崎市多摩区', 'カワサキシタマク', '登戸', 'ノボリト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市多摩区宿河原', '14', '14135', '2140021', '神奈川県', 'カナガワケン', '川崎市多摩区', 'カワサキシタマク', '宿河原', 'シュクガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市多摩区堰', '14', '14135', '2140022', '神奈川県', 'カナガワケン', '川崎市多摩区', 'カワサキシタマク', '堰', 'セキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市多摩区長尾', '14', '14135', '2140023', '神奈川県', 'カナガワケン', '川崎市多摩区', 'カワサキシタマク', '長尾', 'ナガオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市多摩区東生田', '14', '14135', '2140031', '神奈川県', 'カナガワケン', '川崎市多摩区', 'カワサキシタマク', '東生田', 'ヒガシイクタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市多摩区枡形', '14', '14135', '2140032', '神奈川県', 'カナガワケン', '川崎市多摩区', 'カワサキシタマク', '枡形', 'マスガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市多摩区東三田', '14', '14135', '2140033', '神奈川県', 'カナガワケン', '川崎市多摩区', 'カワサキシタマク', '東三田', 'ヒガシミタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市多摩区三田', '14', '14135', '2140034', '神奈川県', 'カナガワケン', '川崎市多摩区', 'カワサキシタマク', '三田', 'ミタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市多摩区長沢', '14', '14135', '2140035', '神奈川県', 'カナガワケン', '川崎市多摩区', 'カワサキシタマク', '長沢', 'ナガサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市多摩区南生田', '14', '14135', '2140036', '神奈川県', 'カナガワケン', '川崎市多摩区', 'カワサキシタマク', '南生田', 'ミナミイクタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市多摩区西生田', '14', '14135', '2140037', '神奈川県', 'カナガワケン', '川崎市多摩区', 'カワサキシタマク', '西生田', 'ニシイクタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市多摩区生田', '14', '14135', '2140038', '神奈川県', 'カナガワケン', '川崎市多摩区', 'カワサキシタマク', '生田', 'イクタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市多摩区栗谷', '14', '14135', '2140039', '神奈川県', 'カナガワケン', '川崎市多摩区', 'カワサキシタマク', '栗谷', 'クリヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市麻生区', '14', '14137', '2150000', '神奈川県', 'カナガワケン', '川崎市麻生区', 'カワサキシアサオク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('11443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市麻生区細山', '14', '14137', '2150001', '神奈川県', 'カナガワケン', '川崎市麻生区', 'カワサキシアサオク', '細山', 'ホソヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市麻生区多摩美', '14', '14137', '2150002', '神奈川県', 'カナガワケン', '川崎市麻生区', 'カワサキシアサオク', '多摩美', 'タマミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市麻生区高石', '14', '14137', '2150003', '神奈川県', 'カナガワケン', '川崎市麻生区', 'カワサキシアサオク', '高石', 'タカイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市麻生区万福寺', '14', '14137', '2150004', '神奈川県', 'カナガワケン', '川崎市麻生区', 'カワサキシアサオク', '万福寺', 'マンプクジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市麻生区千代ケ丘', '14', '14137', '2150005', '神奈川県', 'カナガワケン', '川崎市麻生区', 'カワサキシアサオク', '千代ケ丘', 'チヨガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市麻生区金程', '14', '14137', '2150006', '神奈川県', 'カナガワケン', '川崎市麻生区', 'カワサキシアサオク', '金程', 'カナホド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市麻生区向原', '14', '14137', '2150007', '神奈川県', 'カナガワケン', '川崎市麻生区', 'カワサキシアサオク', '向原', 'ムカイバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市麻生区百合丘', '14', '14137', '2150011', '神奈川県', 'カナガワケン', '川崎市麻生区', 'カワサキシアサオク', '百合丘', 'ユリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市麻生区東百合丘', '14', '14137', '2150012', '神奈川県', 'カナガワケン', '川崎市麻生区', 'カワサキシアサオク', '東百合丘', 'ヒガシユリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市麻生区王禅寺', '14', '14137', '2150013', '神奈川県', 'カナガワケン', '川崎市麻生区', 'カワサキシアサオク', '王禅寺', 'オウゼンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市麻生区白山', '14', '14137', '2150014', '神奈川県', 'カナガワケン', '川崎市麻生区', 'カワサキシアサオク', '白山', 'ハクサン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市麻生区虹ケ丘', '14', '14137', '2150015', '神奈川県', 'カナガワケン', '川崎市麻生区', 'カワサキシアサオク', '虹ケ丘', 'ニジガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市麻生区早野', '14', '14137', '2150016', '神奈川県', 'カナガワケン', '川崎市麻生区', 'カワサキシアサオク', '早野', 'ハヤノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市麻生区王禅寺西', '14', '14137', '2150017', '神奈川県', 'カナガワケン', '川崎市麻生区', 'カワサキシアサオク', '王禅寺西', 'オウゼンジニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市麻生区王禅寺東', '14', '14137', '2150018', '神奈川県', 'カナガワケン', '川崎市麻生区', 'カワサキシアサオク', '王禅寺東', 'オウゼンジヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市麻生区上麻生', '14', '14137', '2150021', '神奈川県', 'カナガワケン', '川崎市麻生区', 'カワサキシアサオク', '上麻生', 'カミアサオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市麻生区下麻生', '14', '14137', '2150022', '神奈川県', 'カナガワケン', '川崎市麻生区', 'カワサキシアサオク', '下麻生', 'シモアサオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市麻生区片平', '14', '14137', '2150023', '神奈川県', 'カナガワケン', '川崎市麻生区', 'カワサキシアサオク', '片平', 'カタヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市麻生区白鳥', '14', '14137', '2150024', '神奈川県', 'カナガワケン', '川崎市麻生区', 'カワサキシアサオク', '白鳥', 'シラトリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市麻生区五力田', '14', '14137', '2150025', '神奈川県', 'カナガワケン', '川崎市麻生区', 'カワサキシアサオク', '五力田', 'ゴリキダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市麻生区古沢', '14', '14137', '2150026', '神奈川県', 'カナガワケン', '川崎市麻生区', 'カワサキシアサオク', '古沢', 'フルサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市麻生区岡上', '14', '14137', '2150027', '神奈川県', 'カナガワケン', '川崎市麻生区', 'カワサキシアサオク', '岡上', 'オカガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市麻生区栗平', '14', '14137', '2150031', '神奈川県', 'カナガワケン', '川崎市麻生区', 'カワサキシアサオク', '栗平', 'クリヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市麻生区栗木台', '14', '14137', '2150032', '神奈川県', 'カナガワケン', '川崎市麻生区', 'カワサキシアサオク', '栗木台', 'クリギダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市麻生区栗木', '14', '14137', '2150033', '神奈川県', 'カナガワケン', '川崎市麻生区', 'カワサキシアサオク', '栗木', 'クリギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市麻生区南黒川', '14', '14137', '2150034', '神奈川県', 'カナガワケン', '川崎市麻生区', 'カワサキシアサオク', '南黒川', 'ミナミクロカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市麻生区黒川', '14', '14137', '2150035', '神奈川県', 'カナガワケン', '川崎市麻生区', 'カワサキシアサオク', '黒川', 'クロカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市麻生区はるひ野', '14', '14137', '2150036', '神奈川県', 'カナガワケン', '川崎市麻生区', 'カワサキシアサオク', 'はるひ野', 'ハルヒノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市宮前区', '14', '14136', '2160000', '神奈川県', 'カナガワケン', '川崎市宮前区', 'カワサキシミヤマエク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('11486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市宮前区野川', '14', '14136', '2160001', '神奈川県', 'カナガワケン', '川崎市宮前区', 'カワサキシミヤマエク', '野川', 'ノガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市宮前区東有馬', '14', '14136', '2160002', '神奈川県', 'カナガワケン', '川崎市宮前区', 'カワサキシミヤマエク', '東有馬', 'ヒガシアリマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市宮前区有馬', '14', '14136', '2160003', '神奈川県', 'カナガワケン', '川崎市宮前区', 'カワサキシミヤマエク', '有馬', 'アリマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市宮前区鷺沼', '14', '14136', '2160004', '神奈川県', 'カナガワケン', '川崎市宮前区', 'カワサキシミヤマエク', '鷺沼', 'サギヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市宮前区土橋', '14', '14136', '2160005', '神奈川県', 'カナガワケン', '川崎市宮前区', 'カワサキシミヤマエク', '土橋', 'ツチハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市宮前区宮前平', '14', '14136', '2160006', '神奈川県', 'カナガワケン', '川崎市宮前区', 'カワサキシミヤマエク', '宮前平', 'ミヤマエダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市宮前区小台', '14', '14136', '2160007', '神奈川県', 'カナガワケン', '川崎市宮前区', 'カワサキシミヤマエク', '小台', 'コダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市宮前区犬蔵', '14', '14136', '2160011', '神奈川県', 'カナガワケン', '川崎市宮前区', 'カワサキシミヤマエク', '犬蔵', 'イヌクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市宮前区水沢', '14', '14136', '2160012', '神奈川県', 'カナガワケン', '川崎市宮前区', 'カワサキシミヤマエク', '水沢', 'ミズサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市宮前区潮見台', '14', '14136', '2160013', '神奈川県', 'カナガワケン', '川崎市宮前区', 'カワサキシミヤマエク', '潮見台', 'シオミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市宮前区菅生ケ丘', '14', '14136', '2160014', '神奈川県', 'カナガワケン', '川崎市宮前区', 'カワサキシミヤマエク', '菅生ケ丘', 'スガオガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市宮前区菅生', '14', '14136', '2160015', '神奈川県', 'カナガワケン', '川崎市宮前区', 'カワサキシミヤマエク', '菅生', 'スガオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市宮前区五所塚', '14', '14136', '2160021', '神奈川県', 'カナガワケン', '川崎市宮前区', 'カワサキシミヤマエク', '五所塚', 'ゴショヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市宮前区平', '14', '14136', '2160022', '神奈川県', 'カナガワケン', '川崎市宮前区', 'カワサキシミヤマエク', '平', 'タイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市宮前区けやき平', '14', '14136', '2160023', '神奈川県', 'カナガワケン', '川崎市宮前区', 'カワサキシミヤマエク', 'けやき平', 'ケヤキダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市宮前区南平台', '14', '14136', '2160024', '神奈川県', 'カナガワケン', '川崎市宮前区', 'カワサキシミヤマエク', '南平台', 'ナンペイダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市宮前区白幡台', '14', '14136', '2160025', '神奈川県', 'カナガワケン', '川崎市宮前区', 'カワサキシミヤマエク', '白幡台', 'シラハタダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市宮前区初山', '14', '14136', '2160026', '神奈川県', 'カナガワケン', '川崎市宮前区', 'カワサキシミヤマエク', '初山', 'ハツヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市宮前区神木本町', '14', '14136', '2160031', '神奈川県', 'カナガワケン', '川崎市宮前区', 'カワサキシミヤマエク', '神木本町', 'シボクホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市宮前区神木', '14', '14136', '2160032', '神奈川県', 'カナガワケン', '川崎市宮前区', 'カワサキシミヤマエク', '神木', 'シボク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市宮前区宮崎', '14', '14136', '2160033', '神奈川県', 'カナガワケン', '川崎市宮前区', 'カワサキシミヤマエク', '宮崎', 'ミヤザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市宮前区梶ケ谷', '14', '14136', '2160034', '神奈川県', 'カナガワケン', '川崎市宮前区', 'カワサキシミヤマエク', '梶ケ谷', 'カジガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県川崎市宮前区馬絹', '14', '14136', '2160035', '神奈川県', 'カナガワケン', '川崎市宮前区', 'カワサキシミヤマエク', '馬絹', 'マギヌ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県大船渡市', '03', '03203', '0220000', '岩手県', 'イワテケン', '大船渡市', 'オオフナトシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('11537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区', '14', '14103', '2200000', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('11538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区北軽井沢', '14', '14103', '2200001', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', '北軽井沢', 'キタカルイザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区南軽井沢', '14', '14103', '2200002', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', '南軽井沢', 'ミナミカルイザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区楠町', '14', '14103', '2200003', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', '楠町', 'クスノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区北幸', '14', '14103', '2200004', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', '北幸', 'キタサイワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区南幸', '14', '14103', '2200005', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', '南幸', 'ミナミサイワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区宮ケ谷', '14', '14103', '2200006', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', '宮ケ谷', 'ミヤガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県大船渡市末崎町', '03', '03203', '0220001', '岩手県', 'イワテケン', '大船渡市', 'オオフナトシ', '末崎町', 'マッサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区高島', '14', '14103', '2200011', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', '高島', 'タカシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらい', '14', '14103', '2200012', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区緑町', '14', '14103', '2200013', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', '緑町', 'ミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県大船渡市大船渡町', '03', '03203', '0220002', '岩手県', 'イワテケン', '大船渡市', 'オオフナトシ', '大船渡町', 'オオフナトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区桜木町4丁目', '14', '14103', '2200021', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', '桜木町', 'サクラギチョウ', null, null, '4丁目', '04チョウメ');
INSERT INTO `ms_addresses` VALUES ('11550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区桜木町5丁目', '14', '14103', '2200021', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', '桜木町', 'サクラギチョウ', null, null, '5丁目', '05チョウメ');
INSERT INTO `ms_addresses` VALUES ('11551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区桜木町6丁目', '14', '14103', '2200021', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', '桜木町', 'サクラギチョウ', null, null, '6丁目', '06チョウメ');
INSERT INTO `ms_addresses` VALUES ('11552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区桜木町7丁目', '14', '14103', '2200021', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', '桜木町', 'サクラギチョウ', null, null, '7丁目', '07チョウメ');
INSERT INTO `ms_addresses` VALUES ('11553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区花咲町4丁目', '14', '14103', '2200022', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', '花咲町', 'ハナサキチョウ', null, null, '4丁目', '04チョウメ');
INSERT INTO `ms_addresses` VALUES ('11554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区花咲町5丁目', '14', '14103', '2200022', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', '花咲町', 'ハナサキチョウ', null, null, '5丁目', '05チョウメ');
INSERT INTO `ms_addresses` VALUES ('11555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区花咲町6丁目', '14', '14103', '2200022', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', '花咲町', 'ハナサキチョウ', null, null, '6丁目', '06チョウメ');
INSERT INTO `ms_addresses` VALUES ('11556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区花咲町7丁目', '14', '14103', '2200022', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', '花咲町', 'ハナサキチョウ', null, null, '7丁目', '07チョウメ');
INSERT INTO `ms_addresses` VALUES ('11557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区平沼', '14', '14103', '2200023', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', '平沼', 'ヒラヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区西平沼町', '14', '14103', '2200024', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', '西平沼町', 'ニシヒラヌマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県大船渡市盛町', '03', '03203', '0220003', '岩手県', 'イワテケン', '大船渡市', 'オオフナトシ', '盛町', 'サカリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区宮崎町', '14', '14103', '2200031', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', '宮崎町', 'ミヤザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区老松町', '14', '14103', '2200032', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', '老松町', 'オイマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区東ケ丘', '14', '14103', '2200033', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', '東ケ丘', 'アズマガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区赤門町', '14', '14103', '2200034', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', '赤門町', 'アカモンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区霞ケ丘', '14', '14103', '2200035', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', '霞ケ丘', 'カスミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県大船渡市猪川町', '03', '03203', '0220004', '岩手県', 'イワテケン', '大船渡市', 'オオフナトシ', '猪川町', 'イカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区戸部本町', '14', '14103', '2200041', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', '戸部本町', 'トベホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区戸部町', '14', '14103', '2200042', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', '戸部町', 'トベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区御所山町', '14', '14103', '2200043', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', '御所山町', 'ゴショヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区紅葉ケ丘', '14', '14103', '2200044', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', '紅葉ケ丘', 'モミジガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区伊勢町', '14', '14103', '2200045', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', '伊勢町', 'イセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区西戸部町', '14', '14103', '2200046', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', '西戸部町', 'ニシトベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県大船渡市日頃市町', '03', '03203', '0220005', '岩手県', 'イワテケン', '大船渡市', 'オオフナトシ', '日頃市町', 'ヒコロイチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区中央', '14', '14103', '2200051', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区西前町', '14', '14103', '2200052', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', '西前町', 'ニシマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区藤棚町', '14', '14103', '2200053', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', '藤棚町', 'フジダナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区境之谷', '14', '14103', '2200054', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', '境之谷', 'サカイノタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区浜松町', '14', '14103', '2200055', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', '浜松町', 'ハママツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県大船渡市立根町', '03', '03203', '0220006', '岩手県', 'イワテケン', '大船渡市', 'オオフナトシ', '立根町', 'タッコンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区久保町', '14', '14103', '2200061', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', '久保町', 'クボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区東久保町', '14', '14103', '2200062', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', '東久保町', 'ヒガシクボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区元久保町', '14', '14103', '2200063', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', '元久保町', 'モトクボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県大船渡市赤崎町', '03', '03203', '0220007', '岩手県', 'イワテケン', '大船渡市', 'オオフナトシ', '赤崎町', 'アカサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区浅間台', '14', '14103', '2200071', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', '浅間台', 'センゲンダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区浅間町', '14', '14103', '2200072', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', '浅間町', 'センゲンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区岡野', '14', '14103', '2200073', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', '岡野', 'オカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区南浅間町', '14', '14103', '2200074', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', '南浅間町', 'ミナミセンゲンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市城山町町屋', '14', '14209', '2200101', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '城山町町屋', 'シロヤマチョウマチヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市城山町原宿', '14', '14209', '2200102', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '城山町原宿', 'シロヤマチョウハラジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市城山町原宿南', '14', '14209', '2200103', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '城山町原宿南', 'シロヤマチョウハラジュクミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市城山町向原', '14', '14209', '2200104', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '城山町向原', 'シロヤマチョウムカイハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市城山町久保沢', '14', '14209', '2200105', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '城山町久保沢', 'シロヤマチョウクボサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市城山町広田', '14', '14209', '2200106', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '城山町広田', 'シロヤマチョウヒロタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市城山町川尻', '14', '14209', '2200111', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '城山町川尻', 'シロヤマチョウカワシリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市城山町若葉台', '14', '14209', '2200112', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '城山町若葉台', 'シロヤマチョウワカバダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市城山町谷ヶ原', '14', '14209', '2200113', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '城山町谷ヶ原', 'シロヤマチョウタニガハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市城山町葉山島', '14', '14209', '2200114', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '城山町葉山島', 'シロヤマチョウハヤマジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市城山町小倉', '14', '14209', '2200115', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '城山町小倉', 'シロヤマチョウオグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市城山町城山', '14', '14209', '2200116', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '城山町城山', 'シロヤマチョウシロヤマ', null, null, null, null), ('11599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市城山町中沢', '14', '14209', '2200117', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '城山町中沢', 'シロヤマチョウナカザワ', null, null, null, null), ('11601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市津久井町三井', '14', '14209', '2200201', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '津久井町三井', 'ツクイチョウミイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市津久井町太井', '14', '14209', '2200202', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '津久井町太井', 'ツクイチョウオオイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市津久井町根小屋', '14', '14209', '2200203', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '津久井町根小屋', 'ツクイチョウネゴヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市津久井町長竹', '14', '14209', '2200204', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '津久井町長竹', 'ツクイチョウナガタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市津久井町鳥屋', '14', '14209', '2200205', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '津久井町鳥屋', 'ツクイチョウトヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市津久井町青山', '14', '14209', '2200206', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '津久井町青山', 'ツクイチョウアオヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市津久井町中野', '14', '14209', '2200207', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '津久井町中野', 'ツクイチョウナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市津久井町又野', '14', '14209', '2200208', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '津久井町又野', 'ツクイチョウマタノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市津久井町三ケ木', '14', '14209', '2200209', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '津久井町三ケ木', 'ツクイチョウミカゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市津久井町青野原', '14', '14209', '2200411', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '津久井町青野原', 'ツクイチョウアオノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市津久井町青根', '14', '14209', '2200412', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '津久井町青根', 'ツクイチョウアオネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県大船渡市三陸町越喜来', '03', '03203', '0220101', '岩手県', 'イワテケン', '大船渡市', 'オオフナトシ', '三陸町越喜来', 'サンリクチョウオキライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県大船渡市三陸町吉浜', '03', '03203', '0220102', '岩手県', 'イワテケン', '大船渡市', 'オオフナトシ', '三陸町吉浜', 'サンリクチョウヨシハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県大船渡市三陸町綾里', '03', '03203', '0220211', '岩手県', 'イワテケン', '大船渡市', 'オオフナトシ', '三陸町綾里', 'サンリクチョウリョウリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいクイーンズタワーA　1階', '14', '14103', '2206001', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'クイーンズタワーA　1階', 'クイーンズタワーA　01カイ');
INSERT INTO `ms_addresses` VALUES ('11618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいクイーンズタワーA　2階', '14', '14103', '2206002', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'クイーンズタワーA　2階', 'クイーンズタワーA　02カイ');
INSERT INTO `ms_addresses` VALUES ('11619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいクイーンズタワーA　3階', '14', '14103', '2206003', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'クイーンズタワーA　3階', 'クイーンズタワーA　03カイ');
INSERT INTO `ms_addresses` VALUES ('11620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいクイーンズタワーA　4階', '14', '14103', '2206004', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'クイーンズタワーA　4階', 'クイーンズタワーA　04カイ');
INSERT INTO `ms_addresses` VALUES ('11621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいクイーンズタワーA　5階', '14', '14103', '2206005', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'クイーンズタワーA　5階', 'クイーンズタワーA　05カイ');
INSERT INTO `ms_addresses` VALUES ('11622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいクイーンズタワーA　6階', '14', '14103', '2206006', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'クイーンズタワーA　6階', 'クイーンズタワーA　06カイ');
INSERT INTO `ms_addresses` VALUES ('11623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいクイーンズタワーA　7階', '14', '14103', '2206007', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'クイーンズタワーA　7階', 'クイーンズタワーA　07カイ');
INSERT INTO `ms_addresses` VALUES ('11624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいクイーンズタワーA　8階', '14', '14103', '2206008', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'クイーンズタワーA　8階', 'クイーンズタワーA　08カイ');
INSERT INTO `ms_addresses` VALUES ('11625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいクイーンズタワーA　9階', '14', '14103', '2206009', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'クイーンズタワーA　9階', 'クイーンズタワーA　09カイ');
INSERT INTO `ms_addresses` VALUES ('11626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいクイーンズタワーA　10階', '14', '14103', '2206010', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'クイーンズタワーA　10階', 'クイーンズタワーA　10カイ');
INSERT INTO `ms_addresses` VALUES ('11627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいクイーンズタワーA　11階', '14', '14103', '2206011', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'クイーンズタワーA　11階', 'クイーンズタワーA　11カイ');
INSERT INTO `ms_addresses` VALUES ('11628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいクイーンズタワーA　12階', '14', '14103', '2206012', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'クイーンズタワーA　12階', 'クイーンズタワーA　12カイ');
INSERT INTO `ms_addresses` VALUES ('11629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいクイーンズタワーA　13階', '14', '14103', '2206013', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'クイーンズタワーA　13階', 'クイーンズタワーA　13カイ');
INSERT INTO `ms_addresses` VALUES ('11630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいクイーンズタワーA　14階', '14', '14103', '2206014', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'クイーンズタワーA　14階', 'クイーンズタワーA　14カイ');
INSERT INTO `ms_addresses` VALUES ('11631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいクイーンズタワーA　15階', '14', '14103', '2206015', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'クイーンズタワーA　15階', 'クイーンズタワーA　15カイ');
INSERT INTO `ms_addresses` VALUES ('11632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいクイーンズタワーA　16階', '14', '14103', '2206016', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'クイーンズタワーA　16階', 'クイーンズタワーA　16カイ');
INSERT INTO `ms_addresses` VALUES ('11633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいクイーンズタワーA　17階', '14', '14103', '2206017', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'クイーンズタワーA　17階', 'クイーンズタワーA　17カイ');
INSERT INTO `ms_addresses` VALUES ('11634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいクイーンズタワーA　18階', '14', '14103', '2206018', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'クイーンズタワーA　18階', 'クイーンズタワーA　18カイ');
INSERT INTO `ms_addresses` VALUES ('11635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいクイーンズタワーA　19階', '14', '14103', '2206019', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'クイーンズタワーA　19階', 'クイーンズタワーA　19カイ');
INSERT INTO `ms_addresses` VALUES ('11636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいクイーンズタワーA　20階', '14', '14103', '2206020', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'クイーンズタワーA　20階', 'クイーンズタワーA　20カイ');
INSERT INTO `ms_addresses` VALUES ('11637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいクイーンズタワーA　21階', '14', '14103', '2206021', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'クイーンズタワーA　21階', 'クイーンズタワーA　21カイ');
INSERT INTO `ms_addresses` VALUES ('11638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいクイーンズタワーA　22階', '14', '14103', '2206022', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'クイーンズタワーA　22階', 'クイーンズタワーA　22カイ');
INSERT INTO `ms_addresses` VALUES ('11639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいクイーンズタワーA　23階', '14', '14103', '2206023', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'クイーンズタワーA　23階', 'クイーンズタワーA　23カイ');
INSERT INTO `ms_addresses` VALUES ('11640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいクイーンズタワーA　24階', '14', '14103', '2206024', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'クイーンズタワーA　24階', 'クイーンズタワーA　24カイ');
INSERT INTO `ms_addresses` VALUES ('11641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいクイーンズタワーA　25階', '14', '14103', '2206025', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'クイーンズタワーA　25階', 'クイーンズタワーA　25カイ');
INSERT INTO `ms_addresses` VALUES ('11642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいクイーンズタワーA　26階', '14', '14103', '2206026', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'クイーンズタワーA　26階', 'クイーンズタワーA　26カイ');
INSERT INTO `ms_addresses` VALUES ('11643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいクイーンズタワーA　27階', '14', '14103', '2206027', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'クイーンズタワーA　27階', 'クイーンズタワーA　27カイ');
INSERT INTO `ms_addresses` VALUES ('11644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいクイーンズタワーA　28階', '14', '14103', '2206028', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'クイーンズタワーA　28階', 'クイーンズタワーA　28カイ');
INSERT INTO `ms_addresses` VALUES ('11645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいクイーンズタワーA　29階', '14', '14103', '2206029', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'クイーンズタワーA　29階', 'クイーンズタワーA　29カイ');
INSERT INTO `ms_addresses` VALUES ('11646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいクイーンズタワーA　30階', '14', '14103', '2206030', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'クイーンズタワーA　30階', 'クイーンズタワーA　30カイ');
INSERT INTO `ms_addresses` VALUES ('11647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいクイーンズタワーA　31階', '14', '14103', '2206031', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'クイーンズタワーA　31階', 'クイーンズタワーA　31カイ');
INSERT INTO `ms_addresses` VALUES ('11648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいクイーンズタワーA　32階', '14', '14103', '2206032', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'クイーンズタワーA　32階', 'クイーンズタワーA　32カイ');
INSERT INTO `ms_addresses` VALUES ('11649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいクイーンズタワーA　33階', '14', '14103', '2206033', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'クイーンズタワーA　33階', 'クイーンズタワーA　33カイ');
INSERT INTO `ms_addresses` VALUES ('11650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいクイーンズタワーA　34階', '14', '14103', '2206034', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'クイーンズタワーA　34階', 'クイーンズタワーA　34カイ');
INSERT INTO `ms_addresses` VALUES ('11651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいクイーンズタワーA　35階', '14', '14103', '2206035', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'クイーンズタワーA　35階', 'クイーンズタワーA　35カイ');
INSERT INTO `ms_addresses` VALUES ('11652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいクイーンズタワーA　', '14', '14103', '2206090', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'クイーンズタワーA　', 'クイーンズタワーA　');
INSERT INTO `ms_addresses` VALUES ('11653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいクイーンズタワーB　1階', '14', '14103', '2206101', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'クイーンズタワーB　1階', 'クイーンズタワーB　01カイ');
INSERT INTO `ms_addresses` VALUES ('11654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいクイーンズタワーB　2階', '14', '14103', '2206102', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'クイーンズタワーB　2階', 'クイーンズタワーB　02カイ');
INSERT INTO `ms_addresses` VALUES ('11655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいクイーンズタワーB　3階', '14', '14103', '2206103', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'クイーンズタワーB　3階', 'クイーンズタワーB　03カイ');
INSERT INTO `ms_addresses` VALUES ('11656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいクイーンズタワーB　4階', '14', '14103', '2206104', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'クイーンズタワーB　4階', 'クイーンズタワーB　04カイ');
INSERT INTO `ms_addresses` VALUES ('11657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいクイーンズタワーB　5階', '14', '14103', '2206105', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'クイーンズタワーB　5階', 'クイーンズタワーB　05カイ');
INSERT INTO `ms_addresses` VALUES ('11658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいクイーンズタワーB　6階', '14', '14103', '2206106', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'クイーンズタワーB　6階', 'クイーンズタワーB　06カイ');
INSERT INTO `ms_addresses` VALUES ('11659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいクイーンズタワーB　7階', '14', '14103', '2206107', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'クイーンズタワーB　7階', 'クイーンズタワーB　07カイ');
INSERT INTO `ms_addresses` VALUES ('11660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいクイーンズタワーB　8階', '14', '14103', '2206108', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'クイーンズタワーB　8階', 'クイーンズタワーB　08カイ');
INSERT INTO `ms_addresses` VALUES ('11661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいクイーンズタワーB　9階', '14', '14103', '2206109', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'クイーンズタワーB　9階', 'クイーンズタワーB　09カイ');
INSERT INTO `ms_addresses` VALUES ('11662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいクイーンズタワーB　10階', '14', '14103', '2206110', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'クイーンズタワーB　10階', 'クイーンズタワーB　10カイ');
INSERT INTO `ms_addresses` VALUES ('11663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいクイーンズタワーB　11階', '14', '14103', '2206111', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'クイーンズタワーB　11階', 'クイーンズタワーB　11カイ');
INSERT INTO `ms_addresses` VALUES ('11664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいクイーンズタワーB　12階', '14', '14103', '2206112', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'クイーンズタワーB　12階', 'クイーンズタワーB　12カイ');
INSERT INTO `ms_addresses` VALUES ('11665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいクイーンズタワーB　13階', '14', '14103', '2206113', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'クイーンズタワーB　13階', 'クイーンズタワーB　13カイ');
INSERT INTO `ms_addresses` VALUES ('11666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいクイーンズタワーB　14階', '14', '14103', '2206114', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'クイーンズタワーB　14階', 'クイーンズタワーB　14カイ');
INSERT INTO `ms_addresses` VALUES ('11667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいクイーンズタワーB　15階', '14', '14103', '2206115', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'クイーンズタワーB　15階', 'クイーンズタワーB　15カイ');
INSERT INTO `ms_addresses` VALUES ('11668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいクイーンズタワーB　16階', '14', '14103', '2206116', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'クイーンズタワーB　16階', 'クイーンズタワーB　16カイ');
INSERT INTO `ms_addresses` VALUES ('11669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいクイーンズタワーB　17階', '14', '14103', '2206117', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'クイーンズタワーB　17階', 'クイーンズタワーB　17カイ');
INSERT INTO `ms_addresses` VALUES ('11670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいクイーンズタワーB　18階', '14', '14103', '2206118', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'クイーンズタワーB　18階', 'クイーンズタワーB　18カイ');
INSERT INTO `ms_addresses` VALUES ('11671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいクイーンズタワーB　19階', '14', '14103', '2206119', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'クイーンズタワーB　19階', 'クイーンズタワーB　19カイ');
INSERT INTO `ms_addresses` VALUES ('11672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいクイーンズタワーB　20階', '14', '14103', '2206120', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'クイーンズタワーB　20階', 'クイーンズタワーB　20カイ');
INSERT INTO `ms_addresses` VALUES ('11673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいクイーンズタワーB　21階', '14', '14103', '2206121', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'クイーンズタワーB　21階', 'クイーンズタワーB　21カイ');
INSERT INTO `ms_addresses` VALUES ('11674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいクイーンズタワーB　22階', '14', '14103', '2206122', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'クイーンズタワーB　22階', 'クイーンズタワーB　22カイ');
INSERT INTO `ms_addresses` VALUES ('11675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいクイーンズタワーB　23階', '14', '14103', '2206123', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'クイーンズタワーB　23階', 'クイーンズタワーB　23カイ');
INSERT INTO `ms_addresses` VALUES ('11676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいクイーンズタワーB　24階', '14', '14103', '2206124', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'クイーンズタワーB　24階', 'クイーンズタワーB　24カイ');
INSERT INTO `ms_addresses` VALUES ('11677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいクイーンズタワーB　25階', '14', '14103', '2206125', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'クイーンズタワーB　25階', 'クイーンズタワーB　25カイ');
INSERT INTO `ms_addresses` VALUES ('11678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいクイーンズタワーB　26階', '14', '14103', '2206126', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'クイーンズタワーB　26階', 'クイーンズタワーB　26カイ');
INSERT INTO `ms_addresses` VALUES ('11679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいクイーンズタワーB　27階', '14', '14103', '2206127', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'クイーンズタワーB　27階', 'クイーンズタワーB　27カイ');
INSERT INTO `ms_addresses` VALUES ('11680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいクイーンズタワーB　28階', '14', '14103', '2206128', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'クイーンズタワーB　28階', 'クイーンズタワーB　28カイ');
INSERT INTO `ms_addresses` VALUES ('11681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいクイーンズタワーB　', '14', '14103', '2206190', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'クイーンズタワーB　', 'クイーンズタワーB　');
INSERT INTO `ms_addresses` VALUES ('11682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいクイーンズタワーC　1階', '14', '14103', '2206201', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'クイーンズタワーC　1階', 'クイーンズタワーC　01カイ');
INSERT INTO `ms_addresses` VALUES ('11683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいクイーンズタワーC　2階', '14', '14103', '2206202', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'クイーンズタワーC　2階', 'クイーンズタワーC　02カイ');
INSERT INTO `ms_addresses` VALUES ('11684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいクイーンズタワーC　3階', '14', '14103', '2206203', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'クイーンズタワーC　3階', 'クイーンズタワーC　03カイ');
INSERT INTO `ms_addresses` VALUES ('11685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいクイーンズタワーC　4階', '14', '14103', '2206204', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'クイーンズタワーC　4階', 'クイーンズタワーC　04カイ');
INSERT INTO `ms_addresses` VALUES ('11686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいクイーンズタワーC　5階', '14', '14103', '2206205', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'クイーンズタワーC　5階', 'クイーンズタワーC　05カイ');
INSERT INTO `ms_addresses` VALUES ('11687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいクイーンズタワーC　6階', '14', '14103', '2206206', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'クイーンズタワーC　6階', 'クイーンズタワーC　06カイ');
INSERT INTO `ms_addresses` VALUES ('11688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいクイーンズタワーC　7階', '14', '14103', '2206207', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'クイーンズタワーC　7階', 'クイーンズタワーC　07カイ');
INSERT INTO `ms_addresses` VALUES ('11689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいクイーンズタワーC　8階', '14', '14103', '2206208', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'クイーンズタワーC　8階', 'クイーンズタワーC　08カイ');
INSERT INTO `ms_addresses` VALUES ('11690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいクイーンズタワーC　9階', '14', '14103', '2206209', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'クイーンズタワーC　9階', 'クイーンズタワーC　09カイ');
INSERT INTO `ms_addresses` VALUES ('11691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいクイーンズタワーC　10階', '14', '14103', '2206210', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'クイーンズタワーC　10階', 'クイーンズタワーC　10カイ');
INSERT INTO `ms_addresses` VALUES ('11692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいクイーンズタワーC　11階', '14', '14103', '2206211', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'クイーンズタワーC　11階', 'クイーンズタワーC　11カイ');
INSERT INTO `ms_addresses` VALUES ('11693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいクイーンズタワーC　12階', '14', '14103', '2206212', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'クイーンズタワーC　12階', 'クイーンズタワーC　12カイ');
INSERT INTO `ms_addresses` VALUES ('11694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいクイーンズタワーC　13階', '14', '14103', '2206213', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'クイーンズタワーC　13階', 'クイーンズタワーC　13カイ');
INSERT INTO `ms_addresses` VALUES ('11695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいクイーンズタワーC　14階', '14', '14103', '2206214', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'クイーンズタワーC　14階', 'クイーンズタワーC　14カイ');
INSERT INTO `ms_addresses` VALUES ('11696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいクイーンズタワーC　15階', '14', '14103', '2206215', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'クイーンズタワーC　15階', 'クイーンズタワーC　15カイ');
INSERT INTO `ms_addresses` VALUES ('11697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいクイーンズタワーC　16階', '14', '14103', '2206216', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'クイーンズタワーC　16階', 'クイーンズタワーC　16カイ');
INSERT INTO `ms_addresses` VALUES ('11698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいクイーンズタワーC　17階', '14', '14103', '2206217', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'クイーンズタワーC　17階', 'クイーンズタワーC　17カイ');
INSERT INTO `ms_addresses` VALUES ('11699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいクイーンズタワーC　18階', '14', '14103', '2206218', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'クイーンズタワーC　18階', 'クイーンズタワーC　18カイ');
INSERT INTO `ms_addresses` VALUES ('11700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいクイーンズタワーC　19階', '14', '14103', '2206219', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'クイーンズタワーC　19階', 'クイーンズタワーC　19カイ');
INSERT INTO `ms_addresses` VALUES ('11701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいクイーンズタワーC　20階', '14', '14103', '2206220', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'クイーンズタワーC　20階', 'クイーンズタワーC　20カイ');
INSERT INTO `ms_addresses` VALUES ('11702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいクイーンズタワーC　21階', '14', '14103', '2206221', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'クイーンズタワーC　21階', 'クイーンズタワーC　21カイ');
INSERT INTO `ms_addresses` VALUES ('11703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいクイーンズタワーC　', '14', '14103', '2206290', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'クイーンズタワーC　', 'クイーンズタワーC　');
INSERT INTO `ms_addresses` VALUES ('11705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいランドマークタワー　1階', '14', '14103', '2208101', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'ランドマークタワー　1階', 'ランドマークタワー　01カイ');
INSERT INTO `ms_addresses` VALUES ('11706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいランドマークタワー　2階', '14', '14103', '2208102', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'ランドマークタワー　2階', 'ランドマークタワー　02カイ');
INSERT INTO `ms_addresses` VALUES ('11707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいランドマークタワー　3階', '14', '14103', '2208103', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'ランドマークタワー　3階', 'ランドマークタワー　03カイ');
INSERT INTO `ms_addresses` VALUES ('11708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいランドマークタワー　4階', '14', '14103', '2208104', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'ランドマークタワー　4階', 'ランドマークタワー　04カイ');
INSERT INTO `ms_addresses` VALUES ('11709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいランドマークタワー　5階', '14', '14103', '2208105', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'ランドマークタワー　5階', 'ランドマークタワー　05カイ');
INSERT INTO `ms_addresses` VALUES ('11710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいランドマークタワー　6階', '14', '14103', '2208106', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'ランドマークタワー　6階', 'ランドマークタワー　06カイ');
INSERT INTO `ms_addresses` VALUES ('11711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいランドマークタワー　7階', '14', '14103', '2208107', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'ランドマークタワー　7階', 'ランドマークタワー　07カイ');
INSERT INTO `ms_addresses` VALUES ('11712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいランドマークタワー　8階', '14', '14103', '2208108', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'ランドマークタワー　8階', 'ランドマークタワー　08カイ');
INSERT INTO `ms_addresses` VALUES ('11713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいランドマークタワー　9階', '14', '14103', '2208109', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'ランドマークタワー　9階', 'ランドマークタワー　09カイ');
INSERT INTO `ms_addresses` VALUES ('11714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいランドマークタワー　10階', '14', '14103', '2208110', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'ランドマークタワー　10階', 'ランドマークタワー　10カイ');
INSERT INTO `ms_addresses` VALUES ('11715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいランドマークタワー　11階', '14', '14103', '2208111', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'ランドマークタワー　11階', 'ランドマークタワー　11カイ');
INSERT INTO `ms_addresses` VALUES ('11716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいランドマークタワー　12階', '14', '14103', '2208112', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'ランドマークタワー　12階', 'ランドマークタワー　12カイ');
INSERT INTO `ms_addresses` VALUES ('11717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいランドマークタワー　13階', '14', '14103', '2208113', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'ランドマークタワー　13階', 'ランドマークタワー　13カイ');
INSERT INTO `ms_addresses` VALUES ('11718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいランドマークタワー　14階', '14', '14103', '2208114', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'ランドマークタワー　14階', 'ランドマークタワー　14カイ');
INSERT INTO `ms_addresses` VALUES ('11719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいランドマークタワー　15階', '14', '14103', '2208115', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'ランドマークタワー　15階', 'ランドマークタワー　15カイ');
INSERT INTO `ms_addresses` VALUES ('11720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいランドマークタワー　16階', '14', '14103', '2208116', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'ランドマークタワー　16階', 'ランドマークタワー　16カイ');
INSERT INTO `ms_addresses` VALUES ('11721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいランドマークタワー　17階', '14', '14103', '2208117', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'ランドマークタワー　17階', 'ランドマークタワー　17カイ');
INSERT INTO `ms_addresses` VALUES ('11722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいランドマークタワー　18階', '14', '14103', '2208118', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'ランドマークタワー　18階', 'ランドマークタワー　18カイ');
INSERT INTO `ms_addresses` VALUES ('11723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいランドマークタワー　19階', '14', '14103', '2208119', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'ランドマークタワー　19階', 'ランドマークタワー　19カイ');
INSERT INTO `ms_addresses` VALUES ('11724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいランドマークタワー　20階', '14', '14103', '2208120', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'ランドマークタワー　20階', 'ランドマークタワー　20カイ');
INSERT INTO `ms_addresses` VALUES ('11725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいランドマークタワー　21階', '14', '14103', '2208121', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'ランドマークタワー　21階', 'ランドマークタワー　21カイ');
INSERT INTO `ms_addresses` VALUES ('11726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいランドマークタワー　22階', '14', '14103', '2208122', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'ランドマークタワー　22階', 'ランドマークタワー　22カイ');
INSERT INTO `ms_addresses` VALUES ('11727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいランドマークタワー　23階', '14', '14103', '2208123', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'ランドマークタワー　23階', 'ランドマークタワー　23カイ');
INSERT INTO `ms_addresses` VALUES ('11728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいランドマークタワー　24階', '14', '14103', '2208124', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'ランドマークタワー　24階', 'ランドマークタワー　24カイ');
INSERT INTO `ms_addresses` VALUES ('11729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいランドマークタワー　25階', '14', '14103', '2208125', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'ランドマークタワー　25階', 'ランドマークタワー　25カイ');
INSERT INTO `ms_addresses` VALUES ('11730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいランドマークタワー　26階', '14', '14103', '2208126', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'ランドマークタワー　26階', 'ランドマークタワー　26カイ');
INSERT INTO `ms_addresses` VALUES ('11731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいランドマークタワー　27階', '14', '14103', '2208127', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'ランドマークタワー　27階', 'ランドマークタワー　27カイ');
INSERT INTO `ms_addresses` VALUES ('11732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいランドマークタワー　28階', '14', '14103', '2208128', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'ランドマークタワー　28階', 'ランドマークタワー　28カイ');
INSERT INTO `ms_addresses` VALUES ('11733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいランドマークタワー　29階', '14', '14103', '2208129', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'ランドマークタワー　29階', 'ランドマークタワー　29カイ');
INSERT INTO `ms_addresses` VALUES ('11734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいランドマークタワー　30階', '14', '14103', '2208130', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'ランドマークタワー　30階', 'ランドマークタワー　30カイ');
INSERT INTO `ms_addresses` VALUES ('11735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいランドマークタワー　31階', '14', '14103', '2208131', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'ランドマークタワー　31階', 'ランドマークタワー　31カイ');
INSERT INTO `ms_addresses` VALUES ('11736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいランドマークタワー　32階', '14', '14103', '2208132', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'ランドマークタワー　32階', 'ランドマークタワー　32カイ');
INSERT INTO `ms_addresses` VALUES ('11737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいランドマークタワー　33階', '14', '14103', '2208133', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'ランドマークタワー　33階', 'ランドマークタワー　33カイ');
INSERT INTO `ms_addresses` VALUES ('11738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいランドマークタワー　34階', '14', '14103', '2208134', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'ランドマークタワー　34階', 'ランドマークタワー　34カイ');
INSERT INTO `ms_addresses` VALUES ('11739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいランドマークタワー　35階', '14', '14103', '2208135', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'ランドマークタワー　35階', 'ランドマークタワー　35カイ');
INSERT INTO `ms_addresses` VALUES ('11740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいランドマークタワー　36階', '14', '14103', '2208136', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'ランドマークタワー　36階', 'ランドマークタワー　36カイ');
INSERT INTO `ms_addresses` VALUES ('11741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいランドマークタワー　37階', '14', '14103', '2208137', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'ランドマークタワー　37階', 'ランドマークタワー　37カイ');
INSERT INTO `ms_addresses` VALUES ('11742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいランドマークタワー　38階', '14', '14103', '2208138', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'ランドマークタワー　38階', 'ランドマークタワー　38カイ');
INSERT INTO `ms_addresses` VALUES ('11743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいランドマークタワー　39階', '14', '14103', '2208139', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'ランドマークタワー　39階', 'ランドマークタワー　39カイ');
INSERT INTO `ms_addresses` VALUES ('11744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいランドマークタワー　40階', '14', '14103', '2208140', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'ランドマークタワー　40階', 'ランドマークタワー　40カイ');
INSERT INTO `ms_addresses` VALUES ('11745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいランドマークタワー　41階', '14', '14103', '2208141', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'ランドマークタワー　41階', 'ランドマークタワー　41カイ');
INSERT INTO `ms_addresses` VALUES ('11746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいランドマークタワー　42階', '14', '14103', '2208142', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'ランドマークタワー　42階', 'ランドマークタワー　42カイ');
INSERT INTO `ms_addresses` VALUES ('11747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいランドマークタワー　43階', '14', '14103', '2208143', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'ランドマークタワー　43階', 'ランドマークタワー　43カイ');
INSERT INTO `ms_addresses` VALUES ('11748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいランドマークタワー　44階', '14', '14103', '2208144', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'ランドマークタワー　44階', 'ランドマークタワー　44カイ');
INSERT INTO `ms_addresses` VALUES ('11749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいランドマークタワー　45階', '14', '14103', '2208145', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'ランドマークタワー　45階', 'ランドマークタワー　45カイ');
INSERT INTO `ms_addresses` VALUES ('11750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいランドマークタワー　46階', '14', '14103', '2208146', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'ランドマークタワー　46階', 'ランドマークタワー　46カイ');
INSERT INTO `ms_addresses` VALUES ('11751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいランドマークタワー　47階', '14', '14103', '2208147', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'ランドマークタワー　47階', 'ランドマークタワー　47カイ');
INSERT INTO `ms_addresses` VALUES ('11752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいランドマークタワー　48階', '14', '14103', '2208148', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'ランドマークタワー　48階', 'ランドマークタワー　48カイ');
INSERT INTO `ms_addresses` VALUES ('11753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいランドマークタワー　49階', '14', '14103', '2208149', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'ランドマークタワー　49階', 'ランドマークタワー　49カイ');
INSERT INTO `ms_addresses` VALUES ('11754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいランドマークタワー　50階', '14', '14103', '2208150', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'ランドマークタワー　50階', 'ランドマークタワー　50カイ');
INSERT INTO `ms_addresses` VALUES ('11755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいランドマークタワー　51階', '14', '14103', '2208151', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'ランドマークタワー　51階', 'ランドマークタワー　51カイ');
INSERT INTO `ms_addresses` VALUES ('11756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいランドマークタワー　52階', '14', '14103', '2208152', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'ランドマークタワー　52階', 'ランドマークタワー　52カイ');
INSERT INTO `ms_addresses` VALUES ('11757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいランドマークタワー　53階', '14', '14103', '2208153', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'ランドマークタワー　53階', 'ランドマークタワー　53カイ');
INSERT INTO `ms_addresses` VALUES ('11758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいランドマークタワー　54階', '14', '14103', '2208154', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'ランドマークタワー　54階', 'ランドマークタワー　54カイ');
INSERT INTO `ms_addresses` VALUES ('11759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいランドマークタワー　55階', '14', '14103', '2208155', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'ランドマークタワー　55階', 'ランドマークタワー　55カイ');
INSERT INTO `ms_addresses` VALUES ('11760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいランドマークタワー　56階', '14', '14103', '2208156', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'ランドマークタワー　56階', 'ランドマークタワー　56カイ');
INSERT INTO `ms_addresses` VALUES ('11761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいランドマークタワー　57階', '14', '14103', '2208157', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'ランドマークタワー　57階', 'ランドマークタワー　57カイ');
INSERT INTO `ms_addresses` VALUES ('11762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいランドマークタワー　58階', '14', '14103', '2208158', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'ランドマークタワー　58階', 'ランドマークタワー　58カイ');
INSERT INTO `ms_addresses` VALUES ('11763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいランドマークタワー　59階', '14', '14103', '2208159', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'ランドマークタワー　59階', 'ランドマークタワー　59カイ');
INSERT INTO `ms_addresses` VALUES ('11764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいランドマークタワー　60階', '14', '14103', '2208160', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'ランドマークタワー　60階', 'ランドマークタワー　60カイ');
INSERT INTO `ms_addresses` VALUES ('11765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいランドマークタワー　61階', '14', '14103', '2208161', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'ランドマークタワー　61階', 'ランドマークタワー　61カイ');
INSERT INTO `ms_addresses` VALUES ('11766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいランドマークタワー　62階', '14', '14103', '2208162', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'ランドマークタワー　62階', 'ランドマークタワー　62カイ');
INSERT INTO `ms_addresses` VALUES ('11767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいランドマークタワー　63階', '14', '14103', '2208163', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'ランドマークタワー　63階', 'ランドマークタワー　63カイ');
INSERT INTO `ms_addresses` VALUES ('11768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいランドマークタワー　64階', '14', '14103', '2208164', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'ランドマークタワー　64階', 'ランドマークタワー　64カイ');
INSERT INTO `ms_addresses` VALUES ('11769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいランドマークタワー　65階', '14', '14103', '2208165', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'ランドマークタワー　65階', 'ランドマークタワー　65カイ');
INSERT INTO `ms_addresses` VALUES ('11770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいランドマークタワー　66階', '14', '14103', '2208166', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'ランドマークタワー　66階', 'ランドマークタワー　66カイ');
INSERT INTO `ms_addresses` VALUES ('11771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいランドマークタワー　67階', '14', '14103', '2208167', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'ランドマークタワー　67階', 'ランドマークタワー　67カイ');
INSERT INTO `ms_addresses` VALUES ('11772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいランドマークタワー　68階', '14', '14103', '2208168', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'ランドマークタワー　68階', 'ランドマークタワー　68カイ');
INSERT INTO `ms_addresses` VALUES ('11773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいランドマークタワー　69階', '14', '14103', '2208169', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'ランドマークタワー　69階', 'ランドマークタワー　69カイ');
INSERT INTO `ms_addresses` VALUES ('11774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいランドマークタワー　70階', '14', '14103', '2208170', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'ランドマークタワー　70階', 'ランドマークタワー　70カイ');
INSERT INTO `ms_addresses` VALUES ('11775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市西区みなとみらいランドマークタワー　', '14', '14103', '2208190', '神奈川県', 'カナガワケン', '横浜市西区', 'ヨコハマシニシク', 'みなとみらい', 'ミナトミライ', null, null, 'ランドマークタワー　', 'ランドマークタワー　');
INSERT INTO `ms_addresses` VALUES ('11810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市神奈川区', '14', '14102', '2210000', '神奈川県', 'カナガワケン', '横浜市神奈川区', 'ヨコハマシカナガワク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('11811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市神奈川区西寺尾', '14', '14102', '2210001', '神奈川県', 'カナガワケン', '横浜市神奈川区', 'ヨコハマシカナガワク', '西寺尾', 'ニシテラオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市神奈川区大口通', '14', '14102', '2210002', '神奈川県', 'カナガワケン', '横浜市神奈川区', 'ヨコハマシカナガワク', '大口通', 'オオグチドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市神奈川区大口仲町', '14', '14102', '2210003', '神奈川県', 'カナガワケン', '横浜市神奈川区', 'ヨコハマシカナガワク', '大口仲町', 'オオグチナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市神奈川区西大口', '14', '14102', '2210004', '神奈川県', 'カナガワケン', '横浜市神奈川区', 'ヨコハマシカナガワク', '西大口', 'ニシオオグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市神奈川区松見町', '14', '14102', '2210005', '神奈川県', 'カナガワケン', '横浜市神奈川区', 'ヨコハマシカナガワク', '松見町', 'マツミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市神奈川区神之木台', '14', '14102', '2210011', '神奈川県', 'カナガワケン', '横浜市神奈川区', 'ヨコハマシカナガワク', '神之木台', 'カミノキダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市神奈川区子安台', '14', '14102', '2210012', '神奈川県', 'カナガワケン', '横浜市神奈川区', 'ヨコハマシカナガワク', '子安台', 'コヤスダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市神奈川区新子安', '14', '14102', '2210013', '神奈川県', 'カナガワケン', '横浜市神奈川区', 'ヨコハマシカナガワク', '新子安', 'シンコヤス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市神奈川区入江', '14', '14102', '2210014', '神奈川県', 'カナガワケン', '横浜市神奈川区', 'ヨコハマシカナガワク', '入江', 'イリエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市神奈川区神之木町', '14', '14102', '2210015', '神奈川県', 'カナガワケン', '横浜市神奈川区', 'ヨコハマシカナガワク', '神之木町', 'カミノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市神奈川区子安通', '14', '14102', '2210021', '神奈川県', 'カナガワケン', '横浜市神奈川区', 'ヨコハマシカナガワク', '子安通', 'コヤスドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市神奈川区守屋町', '14', '14102', '2210022', '神奈川県', 'カナガワケン', '横浜市神奈川区', 'ヨコハマシカナガワク', '守屋町', 'モリヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市神奈川区宝町', '14', '14102', '2210023', '神奈川県', 'カナガワケン', '横浜市神奈川区', 'ヨコハマシカナガワク', '宝町', 'タカラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市神奈川区恵比須町', '14', '14102', '2210024', '神奈川県', 'カナガワケン', '横浜市神奈川区', 'ヨコハマシカナガワク', '恵比須町', 'エビスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市神奈川区新浦島町', '14', '14102', '2210031', '神奈川県', 'カナガワケン', '横浜市神奈川区', 'ヨコハマシカナガワク', '新浦島町', 'シンウラシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市神奈川区出田町', '14', '14102', '2210032', '神奈川県', 'カナガワケン', '横浜市神奈川区', 'ヨコハマシカナガワク', '出田町', 'イズタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市神奈川区鈴繁町', '14', '14102', '2210033', '神奈川県', 'カナガワケン', '横浜市神奈川区', 'ヨコハマシカナガワク', '鈴繁町', 'スズシゲチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市神奈川区瑞穂町', '14', '14102', '2210034', '神奈川県', 'カナガワケン', '横浜市神奈川区', 'ヨコハマシカナガワク', '瑞穂町', 'ミズホチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市神奈川区星野町', '14', '14102', '2210035', '神奈川県', 'カナガワケン', '横浜市神奈川区', 'ヨコハマシカナガワク', '星野町', 'ホシノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市神奈川区千若町', '14', '14102', '2210036', '神奈川県', 'カナガワケン', '横浜市神奈川区', 'ヨコハマシカナガワク', '千若町', 'チワカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市神奈川区亀住町', '14', '14102', '2210041', '神奈川県', 'カナガワケン', '横浜市神奈川区', 'ヨコハマシカナガワク', '亀住町', 'カメズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市神奈川区浦島町', '14', '14102', '2210042', '神奈川県', 'カナガワケン', '横浜市神奈川区', 'ヨコハマシカナガワク', '浦島町', 'ウラシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市神奈川区新町', '14', '14102', '2210043', '神奈川県', 'カナガワケン', '横浜市神奈川区', 'ヨコハマシカナガワク', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市神奈川区東神奈川', '14', '14102', '2210044', '神奈川県', 'カナガワケン', '横浜市神奈川区', 'ヨコハマシカナガワク', '東神奈川', 'ヒガシカナガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市神奈川区神奈川', '14', '14102', '2210045', '神奈川県', 'カナガワケン', '横浜市神奈川区', 'ヨコハマシカナガワク', '神奈川', 'カナガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市神奈川区神奈川本町', '14', '14102', '2210046', '神奈川県', 'カナガワケン', '横浜市神奈川区', 'ヨコハマシカナガワク', '神奈川本町', 'カナガワホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市神奈川区幸ケ谷', '14', '14102', '2210051', '神奈川県', 'カナガワケン', '横浜市神奈川区', 'ヨコハマシカナガワク', '幸ケ谷', 'コウガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市神奈川区栄町', '14', '14102', '2210052', '神奈川県', 'カナガワケン', '横浜市神奈川区', 'ヨコハマシカナガワク', '栄町', 'サカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市神奈川区橋本町', '14', '14102', '2210053', '神奈川県', 'カナガワケン', '横浜市神奈川区', 'ヨコハマシカナガワク', '橋本町', 'ハシモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市神奈川区山内町', '14', '14102', '2210054', '神奈川県', 'カナガワケン', '横浜市神奈川区', 'ヨコハマシカナガワク', '山内町', 'ヤマノウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市神奈川区大野町', '14', '14102', '2210055', '神奈川県', 'カナガワケン', '横浜市神奈川区', 'ヨコハマシカナガワク', '大野町', 'オオノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市神奈川区金港町', '14', '14102', '2210056', '神奈川県', 'カナガワケン', '横浜市神奈川区', 'ヨコハマシカナガワク', '金港町', 'キンコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市神奈川区青木町', '14', '14102', '2210057', '神奈川県', 'カナガワケン', '横浜市神奈川区', 'ヨコハマシカナガワク', '青木町', 'アオキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市神奈川区七島町', '14', '14102', '2210061', '神奈川県', 'カナガワケン', '横浜市神奈川区', 'ヨコハマシカナガワク', '七島町', 'ナナシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市神奈川区浦島丘', '14', '14102', '2210062', '神奈川県', 'カナガワケン', '横浜市神奈川区', 'ヨコハマシカナガワク', '浦島丘', 'ウラシマオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市神奈川区立町', '14', '14102', '2210063', '神奈川県', 'カナガワケン', '横浜市神奈川区', 'ヨコハマシカナガワク', '立町', 'タテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市神奈川区鳥越', '14', '14102', '2210064', '神奈川県', 'カナガワケン', '横浜市神奈川区', 'ヨコハマシカナガワク', '鳥越', 'トリゴエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市神奈川区白楽', '14', '14102', '2210065', '神奈川県', 'カナガワケン', '横浜市神奈川区', 'ヨコハマシカナガワク', '白楽', 'ハクラク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市神奈川区白幡仲町', '14', '14102', '2210071', '神奈川県', 'カナガワケン', '横浜市神奈川区', 'ヨコハマシカナガワク', '白幡仲町', 'シラハタナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市神奈川区白幡東町', '14', '14102', '2210072', '神奈川県', 'カナガワケン', '横浜市神奈川区', 'ヨコハマシカナガワク', '白幡東町', 'シラハタヒガシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市神奈川区白幡南町', '14', '14102', '2210073', '神奈川県', 'カナガワケン', '横浜市神奈川区', 'ヨコハマシカナガワク', '白幡南町', 'シラハタミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市神奈川区白幡西町', '14', '14102', '2210074', '神奈川県', 'カナガワケン', '横浜市神奈川区', 'ヨコハマシカナガワク', '白幡西町', 'シラハタニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市神奈川区白幡上町', '14', '14102', '2210075', '神奈川県', 'カナガワケン', '横浜市神奈川区', 'ヨコハマシカナガワク', '白幡上町', 'シラハタカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市神奈川区白幡町', '14', '14102', '2210076', '神奈川県', 'カナガワケン', '横浜市神奈川区', 'ヨコハマシカナガワク', '白幡町', 'シラハタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市神奈川区白幡向町', '14', '14102', '2210077', '神奈川県', 'カナガワケン', '横浜市神奈川区', 'ヨコハマシカナガワク', '白幡向町', 'シラハタムカイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市神奈川区神大寺', '14', '14102', '2210801', '神奈川県', 'カナガワケン', '横浜市神奈川区', 'ヨコハマシカナガワク', '神大寺', 'カンダイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市神奈川区六角橋', '14', '14102', '2210802', '神奈川県', 'カナガワケン', '横浜市神奈川区', 'ヨコハマシカナガワク', '六角橋', 'ロクカクバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市神奈川区中丸', '14', '14102', '2210803', '神奈川県', 'カナガワケン', '横浜市神奈川区', 'ヨコハマシカナガワク', '中丸', 'ナカマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市神奈川区栗田谷', '14', '14102', '2210804', '神奈川県', 'カナガワケン', '横浜市神奈川区', 'ヨコハマシカナガワク', '栗田谷', 'クリタヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市神奈川区斎藤分町', '14', '14102', '2210811', '神奈川県', 'カナガワケン', '横浜市神奈川区', 'ヨコハマシカナガワク', '斎藤分町', 'サイトウブンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市神奈川区平川町', '14', '14102', '2210812', '神奈川県', 'カナガワケン', '横浜市神奈川区', 'ヨコハマシカナガワク', '平川町', 'ヒラカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市神奈川区二本榎', '14', '14102', '2210813', '神奈川県', 'カナガワケン', '横浜市神奈川区', 'ヨコハマシカナガワク', '二本榎', 'ニホンエノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市神奈川区旭ケ丘', '14', '14102', '2210814', '神奈川県', 'カナガワケン', '横浜市神奈川区', 'ヨコハマシカナガワク', '旭ケ丘', 'アサヒガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市神奈川区富家町', '14', '14102', '2210821', '神奈川県', 'カナガワケン', '横浜市神奈川区', 'ヨコハマシカナガワク', '富家町', 'トミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市神奈川区西神奈川', '14', '14102', '2210822', '神奈川県', 'カナガワケン', '横浜市神奈川区', 'ヨコハマシカナガワク', '西神奈川', 'ニシカナガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市神奈川区二ツ谷町', '14', '14102', '2210823', '神奈川県', 'カナガワケン', '横浜市神奈川区', 'ヨコハマシカナガワク', '二ツ谷町', 'フタツヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市神奈川区広台太田町', '14', '14102', '2210824', '神奈川県', 'カナガワケン', '横浜市神奈川区', 'ヨコハマシカナガワク', '広台太田町', 'ヒロダイオオタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市神奈川区反町', '14', '14102', '2210825', '神奈川県', 'カナガワケン', '横浜市神奈川区', 'ヨコハマシカナガワク', '反町', 'タンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市神奈川区上反町', '14', '14102', '2210831', '神奈川県', 'カナガワケン', '横浜市神奈川区', 'ヨコハマシカナガワク', '上反町', 'カミタンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市神奈川区桐畑', '14', '14102', '2210832', '神奈川県', 'カナガワケン', '横浜市神奈川区', 'ヨコハマシカナガワク', '桐畑', 'キリバタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市神奈川区高島台', '14', '14102', '2210833', '神奈川県', 'カナガワケン', '横浜市神奈川区', 'ヨコハマシカナガワク', '高島台', 'タカシマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市神奈川区台町', '14', '14102', '2210834', '神奈川県', 'カナガワケン', '横浜市神奈川区', 'ヨコハマシカナガワク', '台町', 'ダイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市神奈川区鶴屋町', '14', '14102', '2210835', '神奈川県', 'カナガワケン', '横浜市神奈川区', 'ヨコハマシカナガワク', '鶴屋町', 'ツルヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市神奈川区松本町', '14', '14102', '2210841', '神奈川県', 'カナガワケン', '横浜市神奈川区', 'ヨコハマシカナガワク', '松本町', 'マツモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市神奈川区泉町', '14', '14102', '2210842', '神奈川県', 'カナガワケン', '横浜市神奈川区', 'ヨコハマシカナガワク', '泉町', 'イズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市神奈川区松ケ丘', '14', '14102', '2210843', '神奈川県', 'カナガワケン', '横浜市神奈川区', 'ヨコハマシカナガワク', '松ケ丘', 'マツガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市神奈川区沢渡', '14', '14102', '2210844', '神奈川県', 'カナガワケン', '横浜市神奈川区', 'ヨコハマシカナガワク', '沢渡', 'サワタリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市神奈川区三ツ沢中町', '14', '14102', '2210851', '神奈川県', 'カナガワケン', '横浜市神奈川区', 'ヨコハマシカナガワク', '三ツ沢中町', 'ミツザワナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市神奈川区三ツ沢下町', '14', '14102', '2210852', '神奈川県', 'カナガワケン', '横浜市神奈川区', 'ヨコハマシカナガワク', '三ツ沢下町', 'ミツザワシモマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市神奈川区三ツ沢東町', '14', '14102', '2210853', '神奈川県', 'カナガワケン', '横浜市神奈川区', 'ヨコハマシカナガワク', '三ツ沢東町', 'ミツザワヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市神奈川区三ツ沢南町', '14', '14102', '2210854', '神奈川県', 'カナガワケン', '横浜市神奈川区', 'ヨコハマシカナガワク', '三ツ沢南町', 'ミツザワミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市神奈川区三ツ沢西町', '14', '14102', '2210855', '神奈川県', 'カナガワケン', '横浜市神奈川区', 'ヨコハマシカナガワク', '三ツ沢西町', 'ミツザワニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市神奈川区三ツ沢上町', '14', '14102', '2210856', '神奈川県', 'カナガワケン', '横浜市神奈川区', 'ヨコハマシカナガワク', '三ツ沢上町', 'ミツザワカミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市神奈川区三枚町', '14', '14102', '2210862', '神奈川県', 'カナガワケン', '横浜市神奈川区', 'ヨコハマシカナガワク', '三枚町', 'サンマイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市神奈川区羽沢町', '14', '14102', '2210863', '神奈川県', 'カナガワケン', '横浜市神奈川区', 'ヨコハマシカナガワク', '羽沢町', 'ハザワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市神奈川区菅田町', '14', '14102', '2210864', '神奈川県', 'カナガワケン', '横浜市神奈川区', 'ヨコハマシカナガワク', '菅田町', 'スゲタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市神奈川区片倉', '14', '14102', '2210865', '神奈川県', 'カナガワケン', '横浜市神奈川区', 'ヨコハマシカナガワク', '片倉', 'カタクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市神奈川区羽沢南', '14', '14102', '2210866', '神奈川県', 'カナガワケン', '横浜市神奈川区', 'ヨコハマシカナガワク', '羽沢南', 'ハザワミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市港北区', '14', '14109', '2220000', '神奈川県', 'カナガワケン', '横浜市港北区', 'ヨコハマシコウホクク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('11915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市港北区樽町', '14', '14109', '2220001', '神奈川県', 'カナガワケン', '横浜市港北区', 'ヨコハマシコウホクク', '樽町', 'タルマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市港北区師岡町', '14', '14109', '2220002', '神奈川県', 'カナガワケン', '横浜市港北区', 'ヨコハマシコウホクク', '師岡町', 'モロオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市港北区大曽根', '14', '14109', '2220003', '神奈川県', 'カナガワケン', '横浜市港北区', 'ヨコハマシコウホクク', '大曽根', 'オオソネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市港北区大曽根台', '14', '14109', '2220004', '神奈川県', 'カナガワケン', '横浜市港北区', 'ヨコハマシコウホクク', '大曽根台', 'オオソネダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市港北区菊名', '14', '14109', '2220011', '神奈川県', 'カナガワケン', '横浜市港北区', 'ヨコハマシコウホクク', '菊名', 'キクナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市港北区富士塚', '14', '14109', '2220012', '神奈川県', 'カナガワケン', '横浜市港北区', 'ヨコハマシコウホクク', '富士塚', 'フジヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市港北区錦が丘', '14', '14109', '2220013', '神奈川県', 'カナガワケン', '横浜市港北区', 'ヨコハマシコウホクク', '錦が丘', 'ニシキガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市港北区篠原北', '14', '14109', '2220021', '神奈川県', 'カナガワケン', '横浜市港北区', 'ヨコハマシコウホクク', '篠原北', 'シノハラキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市港北区篠原東', '14', '14109', '2220022', '神奈川県', 'カナガワケン', '横浜市港北区', 'ヨコハマシコウホクク', '篠原東', 'シノハラヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市港北区仲手原', '14', '14109', '2220023', '神奈川県', 'カナガワケン', '横浜市港北区', 'ヨコハマシコウホクク', '仲手原', 'ナカテハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市港北区篠原台町', '14', '14109', '2220024', '神奈川県', 'カナガワケン', '横浜市港北区', 'ヨコハマシコウホクク', '篠原台町', 'シノハラダイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市港北区篠原西町', '14', '14109', '2220025', '神奈川県', 'カナガワケン', '横浜市港北区', 'ヨコハマシコウホクク', '篠原西町', 'シノハラニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市港北区篠原町', '14', '14109', '2220026', '神奈川県', 'カナガワケン', '横浜市港北区', 'ヨコハマシコウホクク', '篠原町', 'シノハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市港北区太尾町', '14', '14109', '2220031', '神奈川県', 'カナガワケン', '横浜市港北区', 'ヨコハマシコウホクク', '太尾町', 'フトオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市港北区大豆戸町', '14', '14109', '2220032', '神奈川県', 'カナガワケン', '横浜市港北区', 'ヨコハマシコウホクク', '大豆戸町', 'マメドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市港北区新横浜', '14', '14109', '2220033', '神奈川県', 'カナガワケン', '横浜市港北区', 'ヨコハマシコウホクク', '新横浜', 'シンヨコハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市港北区岸根町', '14', '14109', '2220034', '神奈川県', 'カナガワケン', '横浜市港北区', 'ヨコハマシコウホクク', '岸根町', 'キシネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市港北区鳥山町', '14', '14109', '2220035', '神奈川県', 'カナガワケン', '横浜市港北区', 'ヨコハマシコウホクク', '鳥山町', 'トリヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市港北区小机町', '14', '14109', '2220036', '神奈川県', 'カナガワケン', '横浜市港北区', 'ヨコハマシコウホクク', '小机町', 'コヅクエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市港北区大倉山', '14', '14109', '2220037', '神奈川県', 'カナガワケン', '横浜市港北区', 'ヨコハマシコウホクク', '大倉山', 'オオクラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市港北区箕輪町', '14', '14109', '2230051', '神奈川県', 'カナガワケン', '横浜市港北区', 'ヨコハマシコウホクク', '箕輪町', 'ミノワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市港北区綱島東', '14', '14109', '2230052', '神奈川県', 'カナガワケン', '横浜市港北区', 'ヨコハマシコウホクク', '綱島東', 'ツナシマヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市港北区綱島西', '14', '14109', '2230053', '神奈川県', 'カナガワケン', '横浜市港北区', 'ヨコハマシコウホクク', '綱島西', 'ツナシマニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市港北区綱島台', '14', '14109', '2230054', '神奈川県', 'カナガワケン', '横浜市港北区', 'ヨコハマシコウホクク', '綱島台', 'ツナシマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市港北区綱島上町', '14', '14109', '2230055', '神奈川県', 'カナガワケン', '横浜市港北区', 'ヨコハマシコウホクク', '綱島上町', 'ツナシマカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市港北区新吉田町', '14', '14109', '2230056', '神奈川県', 'カナガワケン', '横浜市港北区', 'ヨコハマシコウホクク', '新吉田町', 'シンヨシダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市港北区新羽町', '14', '14109', '2230057', '神奈川県', 'カナガワケン', '横浜市港北区', 'ヨコハマシコウホクク', '新羽町', 'ニッパチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市港北区新吉田東', '14', '14109', '2230058', '神奈川県', 'カナガワケン', '横浜市港北区', 'ヨコハマシコウホクク', '新吉田東', 'シンヨシダヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市港北区北新横浜', '14', '14109', '2230059', '神奈川県', 'カナガワケン', '横浜市港北区', 'ヨコハマシコウホクク', '北新横浜', 'キタシンヨコハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市港北区日吉', '14', '14109', '2230061', '神奈川県', 'カナガワケン', '横浜市港北区', 'ヨコハマシコウホクク', '日吉', 'ヒヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市港北区日吉本町', '14', '14109', '2230062', '神奈川県', 'カナガワケン', '横浜市港北区', 'ヨコハマシコウホクク', '日吉本町', 'ヒヨシホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市港北区高田町', '14', '14109', '2230063', '神奈川県', 'カナガワケン', '横浜市港北区', 'ヨコハマシコウホクク', '高田町', 'タカタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市港北区下田町', '14', '14109', '2230064', '神奈川県', 'カナガワケン', '横浜市港北区', 'ヨコハマシコウホクク', '下田町', 'シモダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市港北区高田東', '14', '14109', '2230065', '神奈川県', 'カナガワケン', '横浜市港北区', 'ヨコハマシコウホクク', '高田東', 'タカタヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('11981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市港北区高田西', '14', '14109', '2230066', '神奈川県', 'カナガワケン', '横浜市港北区', 'ヨコハマシコウホクク', '高田西', 'タカタニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市都筑区', '14', '14118', '2240000', '神奈川県', 'カナガワケン', '横浜市都筑区', 'ヨコハマシツヅキク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('12018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市都筑区中川', '14', '14118', '2240001', '神奈川県', 'カナガワケン', '横浜市都筑区', 'ヨコハマシツヅキク', '中川', 'ナカガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市都筑区中川中央', '14', '14118', '2240003', '神奈川県', 'カナガワケン', '横浜市都筑区', 'ヨコハマシツヅキク', '中川中央', 'ナカガワチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市都筑区荏田東町', '14', '14118', '2240004', '神奈川県', 'カナガワケン', '横浜市都筑区', 'ヨコハマシツヅキク', '荏田東町', 'エダヒガシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市都筑区荏田東', '14', '14118', '2240006', '神奈川県', 'カナガワケン', '横浜市都筑区', 'ヨコハマシツヅキク', '荏田東', 'エダヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市都筑区荏田南', '14', '14118', '2240007', '神奈川県', 'カナガワケン', '横浜市都筑区', 'ヨコハマシツヅキク', '荏田南', 'エダミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市都筑区荏田南町', '14', '14118', '2240008', '神奈川県', 'カナガワケン', '横浜市都筑区', 'ヨコハマシツヅキク', '荏田南町', 'エダミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市都筑区牛久保町', '14', '14118', '2240011', '神奈川県', 'カナガワケン', '横浜市都筑区', 'ヨコハマシツヅキク', '牛久保町', 'ウシクボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市都筑区牛久保', '14', '14118', '2240012', '神奈川県', 'カナガワケン', '横浜市都筑区', 'ヨコハマシツヅキク', '牛久保', 'ウシクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市都筑区すみれが丘', '14', '14118', '2240013', '神奈川県', 'カナガワケン', '横浜市都筑区', 'ヨコハマシツヅキク', 'すみれが丘', 'スミレガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市都筑区牛久保東', '14', '14118', '2240014', '神奈川県', 'カナガワケン', '横浜市都筑区', 'ヨコハマシツヅキク', '牛久保東', 'ウシクボヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市都筑区牛久保西', '14', '14118', '2240015', '神奈川県', 'カナガワケン', '横浜市都筑区', 'ヨコハマシツヅキク', '牛久保西', 'ウシクボニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市都筑区あゆみが丘', '14', '14118', '2240016', '神奈川県', 'カナガワケン', '横浜市都筑区', 'ヨコハマシツヅキク', 'あゆみが丘', 'アユミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市都筑区北山田', '14', '14118', '2240021', '神奈川県', 'カナガワケン', '横浜市都筑区', 'ヨコハマシツヅキク', '北山田', 'キタヤマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市都筑区東山田', '14', '14118', '2240023', '神奈川県', 'カナガワケン', '横浜市都筑区', 'ヨコハマシツヅキク', '東山田', 'ヒガシヤマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市都筑区東山田町', '14', '14118', '2240024', '神奈川県', 'カナガワケン', '横浜市都筑区', 'ヨコハマシツヅキク', '東山田町', 'ヒガシヤマタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市都筑区早渕', '14', '14118', '2240025', '神奈川県', 'カナガワケン', '横浜市都筑区', 'ヨコハマシツヅキク', '早渕', 'ハヤブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市都筑区南山田町', '14', '14118', '2240026', '神奈川県', 'カナガワケン', '横浜市都筑区', 'ヨコハマシツヅキク', '南山田町', 'ミナミヤマタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市都筑区大棚町', '14', '14118', '2240027', '神奈川県', 'カナガワケン', '横浜市都筑区', 'ヨコハマシツヅキク', '大棚町', 'オオダナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市都筑区大棚西', '14', '14118', '2240028', '神奈川県', 'カナガワケン', '横浜市都筑区', 'ヨコハマシツヅキク', '大棚西', 'オオダナニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市都筑区南山田', '14', '14118', '2240029', '神奈川県', 'カナガワケン', '横浜市都筑区', 'ヨコハマシツヅキク', '南山田', 'ミナミヤマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市都筑区茅ケ崎町', '14', '14118', '2240031', '神奈川県', 'カナガワケン', '横浜市都筑区', 'ヨコハマシツヅキク', '茅ケ崎町', 'チガサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市都筑区茅ケ崎中央', '14', '14118', '2240032', '神奈川県', 'カナガワケン', '横浜市都筑区', 'ヨコハマシツヅキク', '茅ケ崎中央', 'チガサキチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市都筑区茅ケ崎東', '14', '14118', '2240033', '神奈川県', 'カナガワケン', '横浜市都筑区', 'ヨコハマシツヅキク', '茅ケ崎東', 'チガサキヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市都筑区勝田町', '14', '14118', '2240034', '神奈川県', 'カナガワケン', '横浜市都筑区', 'ヨコハマシツヅキク', '勝田町', 'カチダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市都筑区新栄町', '14', '14118', '2240035', '神奈川県', 'カナガワケン', '横浜市都筑区', 'ヨコハマシツヅキク', '新栄町', 'シンエイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市都筑区勝田南', '14', '14118', '2240036', '神奈川県', 'カナガワケン', '横浜市都筑区', 'ヨコハマシツヅキク', '勝田南', 'カチダミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市都筑区茅ケ崎南', '14', '14118', '2240037', '神奈川県', 'カナガワケン', '横浜市都筑区', 'ヨコハマシツヅキク', '茅ケ崎南', 'チガサキミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市都筑区仲町台', '14', '14118', '2240041', '神奈川県', 'カナガワケン', '横浜市都筑区', 'ヨコハマシツヅキク', '仲町台', 'ナカマチダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市都筑区大熊町', '14', '14118', '2240042', '神奈川県', 'カナガワケン', '横浜市都筑区', 'ヨコハマシツヅキク', '大熊町', 'オオクマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市都筑区折本町', '14', '14118', '2240043', '神奈川県', 'カナガワケン', '横浜市都筑区', 'ヨコハマシツヅキク', '折本町', 'オリモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市都筑区川向町', '14', '14118', '2240044', '神奈川県', 'カナガワケン', '横浜市都筑区', 'ヨコハマシツヅキク', '川向町', 'カワムコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市都筑区東方町', '14', '14118', '2240045', '神奈川県', 'カナガワケン', '横浜市都筑区', 'ヨコハマシツヅキク', '東方町', 'ヒガシカタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市都筑区桜並木', '14', '14118', '2240046', '神奈川県', 'カナガワケン', '横浜市都筑区', 'ヨコハマシツヅキク', '桜並木', 'サクラナミキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市都筑区富士見が丘', '14', '14118', '2240051', '神奈川県', 'カナガワケン', '横浜市都筑区', 'ヨコハマシツヅキク', '富士見が丘', 'フジミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市都筑区二の丸', '14', '14118', '2240052', '神奈川県', 'カナガワケン', '横浜市都筑区', 'ヨコハマシツヅキク', '二の丸', 'ニノマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市都筑区池辺町', '14', '14118', '2240053', '神奈川県', 'カナガワケン', '横浜市都筑区', 'ヨコハマシツヅキク', '池辺町', 'イコノベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市都筑区佐江戸町', '14', '14118', '2240054', '神奈川県', 'カナガワケン', '横浜市都筑区', 'ヨコハマシツヅキク', '佐江戸町', 'サエドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市都筑区加賀原', '14', '14118', '2240055', '神奈川県', 'カナガワケン', '横浜市都筑区', 'ヨコハマシツヅキク', '加賀原', 'カガハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市都筑区川和台', '14', '14118', '2240056', '神奈川県', 'カナガワケン', '横浜市都筑区', 'ヨコハマシツヅキク', '川和台', 'カワワダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市都筑区川和町', '14', '14118', '2240057', '神奈川県', 'カナガワケン', '横浜市都筑区', 'ヨコハマシツヅキク', '川和町', 'カワワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市都筑区大丸', '14', '14118', '2240061', '神奈川県', 'カナガワケン', '横浜市都筑区', 'ヨコハマシツヅキク', '大丸', 'オオマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市都筑区葛が谷', '14', '14118', '2240062', '神奈川県', 'カナガワケン', '横浜市都筑区', 'ヨコハマシツヅキク', '葛が谷', 'クズガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市都筑区長坂', '14', '14118', '2240063', '神奈川県', 'カナガワケン', '横浜市都筑区', 'ヨコハマシツヅキク', '長坂', 'ナガサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市都筑区平台', '14', '14118', '2240064', '神奈川県', 'カナガワケン', '横浜市都筑区', 'ヨコハマシツヅキク', '平台', 'ヒラダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市都筑区高山', '14', '14118', '2240065', '神奈川県', 'カナガワケン', '横浜市都筑区', 'ヨコハマシツヅキク', '高山', 'タカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市都筑区見花山', '14', '14118', '2240066', '神奈川県', 'カナガワケン', '横浜市都筑区', 'ヨコハマシツヅキク', '見花山', 'ミハナヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市青葉区美しが丘西', '14', '14117', '2250001', '神奈川県', 'カナガワケン', '横浜市青葉区', 'ヨコハマシアオバク', '美しが丘西', 'ウツクシガオカニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市青葉区美しが丘', '14', '14117', '2250002', '神奈川県', 'カナガワケン', '横浜市青葉区', 'ヨコハマシアオバク', '美しが丘', 'ウツクシガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市青葉区新石川', '14', '14117', '2250003', '神奈川県', 'カナガワケン', '横浜市青葉区', 'ヨコハマシアオバク', '新石川', 'シンイシカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市青葉区元石川町', '14', '14117', '2250004', '神奈川県', 'カナガワケン', '横浜市青葉区', 'ヨコハマシアオバク', '元石川町', 'モトイシカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市青葉区荏子田', '14', '14117', '2250005', '神奈川県', 'カナガワケン', '横浜市青葉区', 'ヨコハマシアオバク', '荏子田', 'エコダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市青葉区あざみ野', '14', '14117', '2250011', '神奈川県', 'カナガワケン', '横浜市青葉区', 'ヨコハマシアオバク', 'あざみ野', 'アザミノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市青葉区あざみ野南', '14', '14117', '2250012', '神奈川県', 'カナガワケン', '横浜市青葉区', 'ヨコハマシアオバク', 'あざみ野南', 'アザミノミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市青葉区荏田町', '14', '14117', '2250013', '神奈川県', 'カナガワケン', '横浜市青葉区', 'ヨコハマシアオバク', '荏田町', 'エダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市青葉区荏田西', '14', '14117', '2250014', '神奈川県', 'カナガワケン', '横浜市青葉区', 'ヨコハマシアオバク', '荏田西', 'エダニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市青葉区荏田北', '14', '14117', '2250015', '神奈川県', 'カナガワケン', '横浜市青葉区', 'ヨコハマシアオバク', '荏田北', 'エダキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市青葉区みすずが丘', '14', '14117', '2250016', '神奈川県', 'カナガワケン', '横浜市青葉区', 'ヨコハマシアオバク', 'みすずが丘', 'ミスズガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市青葉区すすき野', '14', '14117', '2250021', '神奈川県', 'カナガワケン', '横浜市青葉区', 'ヨコハマシアオバク', 'すすき野', 'ススキノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市青葉区黒須田', '14', '14117', '2250022', '神奈川県', 'カナガワケン', '横浜市青葉区', 'ヨコハマシアオバク', '黒須田', 'クロスダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市青葉区大場町', '14', '14117', '2250023', '神奈川県', 'カナガワケン', '横浜市青葉区', 'ヨコハマシアオバク', '大場町', 'オオバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市青葉区市ケ尾町', '14', '14117', '2250024', '神奈川県', 'カナガワケン', '横浜市青葉区', 'ヨコハマシアオバク', '市ケ尾町', 'イチガオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市青葉区鉄町', '14', '14117', '2250025', '神奈川県', 'カナガワケン', '横浜市青葉区', 'ヨコハマシアオバク', '鉄町', 'クロガネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市青葉区もみの木台', '14', '14117', '2250026', '神奈川県', 'カナガワケン', '横浜市青葉区', 'ヨコハマシアオバク', 'もみの木台', 'モミノキダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市緑区', '14', '14113', '2260000', '神奈川県', 'カナガワケン', '横浜市緑区', 'ヨコハマシミドリク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('12115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市緑区東本郷町', '14', '14113', '2260001', '神奈川県', 'カナガワケン', '横浜市緑区', 'ヨコハマシミドリク', '東本郷町', 'ヒガシホンゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市緑区東本郷', '14', '14113', '2260002', '神奈川県', 'カナガワケン', '横浜市緑区', 'ヨコハマシミドリク', '東本郷', 'ヒガシホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市緑区鴨居', '14', '14113', '2260003', '神奈川県', 'カナガワケン', '横浜市緑区', 'ヨコハマシミドリク', '鴨居', 'カモイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市緑区鴨居町', '14', '14113', '2260004', '神奈川県', 'カナガワケン', '横浜市緑区', 'ヨコハマシミドリク', '鴨居町', 'カモイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市緑区竹山', '14', '14113', '2260005', '神奈川県', 'カナガワケン', '横浜市緑区', 'ヨコハマシミドリク', '竹山', 'タケヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市緑区白山', '14', '14113', '2260006', '神奈川県', 'カナガワケン', '横浜市緑区', 'ヨコハマシミドリク', '白山', 'ハクサン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市緑区中山町', '14', '14113', '2260011', '神奈川県', 'カナガワケン', '横浜市緑区', 'ヨコハマシミドリク', '中山町', 'ナカヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市緑区上山', '14', '14113', '2260012', '神奈川県', 'カナガワケン', '横浜市緑区', 'ヨコハマシミドリク', '上山', 'カミヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市緑区寺山町', '14', '14113', '2260013', '神奈川県', 'カナガワケン', '横浜市緑区', 'ヨコハマシミドリク', '寺山町', 'テラヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市緑区台村町', '14', '14113', '2260014', '神奈川県', 'カナガワケン', '横浜市緑区', 'ヨコハマシミドリク', '台村町', 'ダイムラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市緑区三保町', '14', '14113', '2260015', '神奈川県', 'カナガワケン', '横浜市緑区', 'ヨコハマシミドリク', '三保町', 'ミホチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市緑区霧が丘', '14', '14113', '2260016', '神奈川県', 'カナガワケン', '横浜市緑区', 'ヨコハマシミドリク', '霧が丘', 'キリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市緑区新治町', '14', '14113', '2260017', '神奈川県', 'カナガワケン', '横浜市緑区', 'ヨコハマシミドリク', '新治町', 'ニイハルチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市緑区長津田みなみ台', '14', '14113', '2260018', '神奈川県', 'カナガワケン', '横浜市緑区', 'ヨコハマシミドリク', '長津田みなみ台', 'ナガツタミナミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市緑区北八朔町', '14', '14113', '2260021', '神奈川県', 'カナガワケン', '横浜市緑区', 'ヨコハマシミドリク', '北八朔町', 'キタハッサクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市緑区青砥町', '14', '14113', '2260022', '神奈川県', 'カナガワケン', '横浜市緑区', 'ヨコハマシミドリク', '青砥町', 'アオトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市緑区小山町', '14', '14113', '2260023', '神奈川県', 'カナガワケン', '横浜市緑区', 'ヨコハマシミドリク', '小山町', 'コヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市緑区西八朔町', '14', '14113', '2260024', '神奈川県', 'カナガワケン', '横浜市緑区', 'ヨコハマシミドリク', '西八朔町', 'ニシハッサクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市緑区十日市場町', '14', '14113', '2260025', '神奈川県', 'カナガワケン', '横浜市緑区', 'ヨコハマシミドリク', '十日市場町', 'トオカイチバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市緑区長津田町', '14', '14113', '2260026', '神奈川県', 'カナガワケン', '横浜市緑区', 'ヨコハマシミドリク', '長津田町', 'ナガツタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市緑区長津田', '14', '14113', '2260027', '神奈川県', 'カナガワケン', '横浜市緑区', 'ヨコハマシミドリク', '長津田', 'ナガツタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市緑区いぶき野', '14', '14113', '2260028', '神奈川県', 'カナガワケン', '横浜市緑区', 'ヨコハマシミドリク', 'いぶき野', 'イブキノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市緑区森の台', '14', '14113', '2260029', '神奈川県', 'カナガワケン', '横浜市緑区', 'ヨコハマシミドリク', '森の台', 'モリノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市青葉区', '14', '14117', '2270000', '神奈川県', 'カナガワケン', '横浜市青葉区', 'ヨコハマシアオバク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('12146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市青葉区寺家町', '14', '14117', '2270031', '神奈川県', 'カナガワケン', '横浜市青葉区', 'ヨコハマシアオバク', '寺家町', 'ジケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市青葉区成合町', '14', '14117', '2270032', '神奈川県', 'カナガワケン', '横浜市青葉区', 'ヨコハマシアオバク', '成合町', 'ナリアイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市青葉区鴨志田町', '14', '14117', '2270033', '神奈川県', 'カナガワケン', '横浜市青葉区', 'ヨコハマシアオバク', '鴨志田町', 'カモシダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市青葉区桂台', '14', '14117', '2270034', '神奈川県', 'カナガワケン', '横浜市青葉区', 'ヨコハマシアオバク', '桂台', 'カツラダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市青葉区すみよし台', '14', '14117', '2270035', '神奈川県', 'カナガワケン', '横浜市青葉区', 'ヨコハマシアオバク', 'すみよし台', 'スミヨシダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市青葉区奈良町', '14', '14117', '2270036', '神奈川県', 'カナガワケン', '横浜市青葉区', 'ヨコハマシアオバク', '奈良町', 'ナラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市青葉区緑山', '14', '14117', '2270037', '神奈川県', 'カナガワケン', '横浜市青葉区', 'ヨコハマシアオバク', '緑山', 'ミドリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市青葉区奈良', '14', '14117', '2270038', '神奈川県', 'カナガワケン', '横浜市青葉区', 'ヨコハマシアオバク', '奈良', 'ナラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市青葉区上谷本町', '14', '14117', '2270041', '神奈川県', 'カナガワケン', '横浜市青葉区', 'ヨコハマシアオバク', '上谷本町', 'カミヤモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市青葉区下谷本町', '14', '14117', '2270042', '神奈川県', 'カナガワケン', '横浜市青葉区', 'ヨコハマシアオバク', '下谷本町', 'シモヤモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市青葉区藤が丘', '14', '14117', '2270043', '神奈川県', 'カナガワケン', '横浜市青葉区', 'ヨコハマシアオバク', '藤が丘', 'フジガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市青葉区もえぎ野', '14', '14117', '2270044', '神奈川県', 'カナガワケン', '横浜市青葉区', 'ヨコハマシアオバク', 'もえぎ野', 'モエギノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市青葉区若草台', '14', '14117', '2270045', '神奈川県', 'カナガワケン', '横浜市青葉区', 'ヨコハマシアオバク', '若草台', 'ワカクサダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市青葉区たちばな台', '14', '14117', '2270046', '神奈川県', 'カナガワケン', '横浜市青葉区', 'ヨコハマシアオバク', 'たちばな台', 'タチバナダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市青葉区みたけ台', '14', '14117', '2270047', '神奈川県', 'カナガワケン', '横浜市青葉区', 'ヨコハマシアオバク', 'みたけ台', 'ミタケダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市青葉区柿の木台', '14', '14117', '2270048', '神奈川県', 'カナガワケン', '横浜市青葉区', 'ヨコハマシアオバク', '柿の木台', 'カキノキダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市青葉区千草台', '14', '14117', '2270051', '神奈川県', 'カナガワケン', '横浜市青葉区', 'ヨコハマシアオバク', '千草台', 'チグサダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市青葉区梅が丘', '14', '14117', '2270052', '神奈川県', 'カナガワケン', '横浜市青葉区', 'ヨコハマシアオバク', '梅が丘', 'ウメガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市青葉区さつきが丘', '14', '14117', '2270053', '神奈川県', 'カナガワケン', '横浜市青葉区', 'ヨコハマシアオバク', 'さつきが丘', 'サツキガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市青葉区しらとり台', '14', '14117', '2270054', '神奈川県', 'カナガワケン', '横浜市青葉区', 'ヨコハマシアオバク', 'しらとり台', 'シラトリダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市青葉区つつじが丘', '14', '14117', '2270055', '神奈川県', 'カナガワケン', '横浜市青葉区', 'ヨコハマシアオバク', 'つつじが丘', 'ツツジガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市青葉区桜台', '14', '14117', '2270061', '神奈川県', 'カナガワケン', '横浜市青葉区', 'ヨコハマシアオバク', '桜台', 'サクラダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市青葉区青葉台', '14', '14117', '2270062', '神奈川県', 'カナガワケン', '横浜市青葉区', 'ヨコハマシアオバク', '青葉台', 'アオバダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市青葉区榎が丘', '14', '14117', '2270063', '神奈川県', 'カナガワケン', '横浜市青葉区', 'ヨコハマシアオバク', '榎が丘', 'エノキガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市青葉区田奈町', '14', '14117', '2270064', '神奈川県', 'カナガワケン', '横浜市青葉区', 'ヨコハマシアオバク', '田奈町', 'タナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市青葉区恩田町', '14', '14117', '2270065', '神奈川県', 'カナガワケン', '横浜市青葉区', 'ヨコハマシアオバク', '恩田町', 'オンダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市青葉区あかね台', '14', '14117', '2270066', '神奈川県', 'カナガワケン', '横浜市青葉区', 'ヨコハマシアオバク', 'あかね台', 'アカネダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市青葉区松風台', '14', '14117', '2270067', '神奈川県', 'カナガワケン', '横浜市青葉区', 'ヨコハマシアオバク', '松風台', 'マツカゼダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県座間市', '14', '14216', '2280000', '神奈川県', 'カナガワケン', '座間市', 'ザマシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('12183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県座間市相模が丘', '14', '14216', '2280001', '神奈川県', 'カナガワケン', '座間市', 'ザマシ', '相模が丘', 'サガミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県座間市小松原', '14', '14216', '2280002', '神奈川県', 'カナガワケン', '座間市', 'ザマシ', '小松原', 'コマツバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県座間市ひばりが丘', '14', '14216', '2280003', '神奈川県', 'カナガワケン', '座間市', 'ザマシ', 'ひばりが丘', 'ヒバリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県座間市東原', '14', '14216', '2280004', '神奈川県', 'カナガワケン', '座間市', 'ザマシ', '東原', 'ヒガシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県座間市さがみ野', '14', '14216', '2280005', '神奈川県', 'カナガワケン', '座間市', 'ザマシ', 'さがみ野', 'サガミノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県座間市相武台', '14', '14216', '2280011', '神奈川県', 'カナガワケン', '座間市', 'ザマシ', '相武台', 'ソウブダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県座間市広野台', '14', '14216', '2280012', '神奈川県', 'カナガワケン', '座間市', 'ザマシ', '広野台', 'ヒロノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県座間市栗原', '14', '14216', '2280013', '神奈川県', 'カナガワケン', '座間市', 'ザマシ', '栗原', 'クリハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県座間市栗原中央', '14', '14216', '2280014', '神奈川県', 'カナガワケン', '座間市', 'ザマシ', '栗原中央', 'クリハラチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県座間市南栗原', '14', '14216', '2280015', '神奈川県', 'カナガワケン', '座間市', 'ザマシ', '南栗原', 'ミナミクリハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県座間市西栗原', '14', '14216', '2280016', '神奈川県', 'カナガワケン', '座間市', 'ザマシ', '西栗原', 'ニシクリハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県座間市緑ケ丘', '14', '14216', '2280021', '神奈川県', 'カナガワケン', '座間市', 'ザマシ', '緑ケ丘', 'ミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県座間市明王', '14', '14216', '2280022', '神奈川県', 'カナガワケン', '座間市', 'ザマシ', '明王', 'ミョウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県座間市立野台', '14', '14216', '2280023', '神奈川県', 'カナガワケン', '座間市', 'ザマシ', '立野台', 'タツノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県座間市入谷', '14', '14216', '2280024', '神奈川県', 'カナガワケン', '座間市', 'ザマシ', '入谷', 'イリヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県座間市四ツ谷', '14', '14216', '2280025', '神奈川県', 'カナガワケン', '座間市', 'ザマシ', '四ツ谷', 'ヨツヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県座間市新田宿', '14', '14216', '2280026', '神奈川県', 'カナガワケン', '座間市', 'ザマシ', '新田宿', 'シンデンジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県座間市座間', '14', '14216', '2280027', '神奈川県', 'カナガワケン', '座間市', 'ザマシ', '座間', 'ザマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市鵜野森', '14', '14209', '2280801', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '鵜野森', 'ウノモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市上鶴間', '14', '14209', '2280802', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '上鶴間', 'カミツルマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市相模大野', '14', '14209', '2280803', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '相模大野', 'サガミオオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市旭町', '14', '14209', '2280804', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '旭町', 'アサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市豊町', '14', '14209', '2280805', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '豊町', 'ユタカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市栄町', '14', '14209', '2280806', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '栄町', 'サカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市文京', '14', '14209', '2280807', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '文京', 'ブンキョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市東林間', '14', '14209', '2280811', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '東林間', 'ヒガシリンカン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市相南', '14', '14209', '2280812', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '相南', 'ソウナン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市松が枝町', '14', '14209', '2280813', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '松が枝町', 'マツガエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市南台', '14', '14209', '2280814', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '南台', 'ミナミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市桜台', '14', '14209', '2280815', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '桜台', 'サクラダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市双葉', '14', '14209', '2280816', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '双葉', 'フタバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市御園', '14', '14209', '2280817', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '御園', 'ミソノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市上鶴間本町', '14', '14209', '2280818', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '上鶴間本町', 'カミツルマホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市相模台', '14', '14209', '2280821', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '相模台', 'サガミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市相模台団地', '14', '14209', '2280822', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '相模台団地', 'サガミダイダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市相武台団地', '14', '14209', '2280823', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '相武台団地', 'ソウブダイダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市相武台', '14', '14209', '2280824', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '相武台', 'ソウブダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市新磯野', '14', '14209', '2280825', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '新磯野', 'アライソノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市新戸', '14', '14209', '2280826', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '新戸', 'シンド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市磯部', '14', '14209', '2280827', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '磯部', 'イソベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市麻溝台', '14', '14209', '2280828', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '麻溝台', 'アサミゾダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市北里', '14', '14209', '2280829', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '北里', 'キタザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市', '14', '14209', '2290000', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('12256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市上矢部', '14', '14209', '2290001', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '上矢部', 'カミヤベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市淵野辺本町', '14', '14209', '2290002', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '淵野辺本町', 'フチノベホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市東淵野辺', '14', '14209', '2290003', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '東淵野辺', 'ヒガシフチノベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市古淵', '14', '14209', '2290004', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '古淵', 'コブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市淵野辺', '14', '14209', '2290006', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '淵野辺', 'フチノベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市矢部新町', '14', '14209', '2290007', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '矢部新町', 'ヤベシンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市大野台', '14', '14209', '2290011', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '大野台', 'オオノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市西大沼', '14', '14209', '2290012', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '西大沼', 'ニシオオヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市東大沼', '14', '14209', '2290013', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '東大沼', 'ヒガシオオヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市若松', '14', '14209', '2290014', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '若松', 'ワカマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市下溝', '14', '14209', '2290015', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '下溝', 'シモミゾ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市当麻', '14', '14209', '2290016', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '当麻', 'タイマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市高根', '14', '14209', '2290021', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '高根', 'タカネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市由野台', '14', '14209', '2290022', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '由野台', 'ヨシノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市松が丘', '14', '14209', '2290023', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '松が丘', 'マツガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市青葉', '14', '14209', '2290024', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '青葉', 'アオバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市緑が丘', '14', '14209', '2290025', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '緑が丘', 'ミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市陽光台', '14', '14209', '2290026', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '陽光台', 'ヨウコウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市光が丘', '14', '14209', '2290027', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '光が丘', 'ヒカリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市並木', '14', '14209', '2290028', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '並木', 'ナミキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市弥栄', '14', '14209', '2290029', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '弥栄', 'ヤエイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市相模原', '14', '14209', '2290031', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '相模原', 'サガミハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市矢部', '14', '14209', '2290032', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '矢部', 'ヤベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市鹿沼台', '14', '14209', '2290033', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '鹿沼台', 'カヌマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市共和', '14', '14209', '2290034', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '共和', 'キョウワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市相生', '14', '14209', '2290035', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '相生', 'アイオイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市富士見', '14', '14209', '2290036', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '富士見', 'フジミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市千代田', '14', '14209', '2290037', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '千代田', 'チヨダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市星が丘', '14', '14209', '2290038', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '星が丘', 'ホシガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市中央', '14', '14209', '2290039', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市相模湖町与瀬', '14', '14209', '2290101', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '相模湖町与瀬', 'サガミコチョウヨセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市相模湖町与瀬本町', '14', '14209', '2290102', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '相模湖町与瀬本町', 'サガミコチョウヨセホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市相模湖町小原', '14', '14209', '2290103', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '相模湖町小原', 'サガミコチョウオバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市相模湖町千木良', '14', '14209', '2290104', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '相模湖町千木良', 'サガミコチョウチギラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市相模湖町若柳', '14', '14209', '2290105', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '相模湖町若柳', 'サガミコチョウワカヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市相模湖町寸沢嵐', '14', '14209', '2290106', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '相模湖町寸沢嵐', 'サガミコチョウスワラシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市藤野町佐野川', '14', '14209', '2290201', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '藤野町佐野川', 'フジノチョウサノガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市藤野町澤井', '14', '14209', '2290202', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '藤野町澤井', 'フジノチョウサワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市藤野町吉野', '14', '14209', '2290203', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '藤野町吉野', 'フジノチョウヨシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市藤野町小渕', '14', '14209', '2290204', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '藤野町小渕', 'フジノチョウオブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市藤野町日連', '14', '14209', '2290205', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '藤野町日連', 'フジノチョウヒヅレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市藤野町牧野', '14', '14209', '2290206', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '藤野町牧野', 'フジノチョウマギノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市藤野町名倉', '14', '14209', '2290207', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '藤野町名倉', 'フジノチョウナグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市相模湖町寸沢嵐新戸', '14', '14209', '2290211', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '相模湖町寸沢嵐', 'サガミコチョウスワラシ', null, null, '新戸', 'シンド');
INSERT INTO `ms_addresses` VALUES ('12303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市相原', '14', '14209', '2291101', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '相原', 'アイハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市元橋本町', '14', '14209', '2291102', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '元橋本町', 'モトハシモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市橋本', '14', '14209', '2291103', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '橋本', 'ハシモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市東橋本', '14', '14209', '2291104', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '東橋本', 'ヒガシハシモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市小山', '14', '14209', '2291105', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '小山', 'オヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市大山町', '14', '14209', '2291106', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '大山町', 'オオヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市宮下本町', '14', '14209', '2291111', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '宮下本町', 'ミヤシモホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市宮下', '14', '14209', '2291112', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '宮下', 'ミヤシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市すすきの町', '14', '14209', '2291113', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', 'すすきの町', 'ススキノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市向陽町', '14', '14209', '2291114', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '向陽町', 'コウヨウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市氷川町', '14', '14209', '2291115', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '氷川町', 'ヒカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市清新', '14', '14209', '2291116', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '清新', 'セイシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市小町通', '14', '14209', '2291117', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '小町通', 'コマチドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市横山台', '14', '14209', '2291121', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '横山台', 'ヨコヤマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市横山', '14', '14209', '2291122', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '横山', 'ヨコヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市上溝', '14', '14209', '2291123', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '上溝', 'カミミゾ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市田名', '14', '14209', '2291124', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '田名', 'タナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市田名塩田', '14', '14209', '2291125', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '田名塩田', 'タナシオダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市水郷田名', '14', '14209', '2291126', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '水郷田名', 'スイゴウタナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市西橋本', '14', '14209', '2291131', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '西橋本', 'ニシハシモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市橋本台', '14', '14209', '2291132', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '橋本台', 'ハシモトダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市南橋本', '14', '14209', '2291133', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '南橋本', 'ミナミハシモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市下九沢', '14', '14209', '2291134', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '下九沢', 'シモクザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市大島', '14', '14209', '2291135', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '大島', 'オオシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市上九沢', '14', '14209', '2291136', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '上九沢', 'カミクザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県相模原市二本松', '14', '14209', '2291137', '神奈川県', 'カナガワケン', '相模原市', 'サガミハラシ', '二本松', 'ニホンマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市', '03', '03215', '0230000', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('12351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市鶴見区', '14', '14101', '2300000', '神奈川県', 'カナガワケン', '横浜市鶴見区', 'ヨコハマシツルミク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('12352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市鶴見区矢向', '14', '14101', '2300001', '神奈川県', 'カナガワケン', '横浜市鶴見区', 'ヨコハマシツルミク', '矢向', 'ヤコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市鶴見区江ケ崎町', '14', '14101', '2300002', '神奈川県', 'カナガワケン', '横浜市鶴見区', 'ヨコハマシツルミク', '江ケ崎町', 'エガサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市鶴見区尻手', '14', '14101', '2300003', '神奈川県', 'カナガワケン', '横浜市鶴見区', 'ヨコハマシツルミク', '尻手', 'シッテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市鶴見区元宮', '14', '14101', '2300004', '神奈川県', 'カナガワケン', '横浜市鶴見区', 'ヨコハマシツルミク', '元宮', 'モトミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区卸町', '03', '03215', '0230001', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区卸町', 'ミズサワクオロシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市鶴見区上末吉', '14', '14101', '2300011', '神奈川県', 'カナガワケン', '横浜市鶴見区', 'ヨコハマシツルミク', '上末吉', 'カミスエヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市鶴見区下末吉', '14', '14101', '2300012', '神奈川県', 'カナガワケン', '横浜市鶴見区', 'ヨコハマシツルミク', '下末吉', 'シモスエヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市鶴見区三ツ池公園', '14', '14101', '2300013', '神奈川県', 'カナガワケン', '横浜市鶴見区', 'ヨコハマシツルミク', '三ツ池公園', 'ミツイケコウエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市鶴見区諏訪坂', '14', '14101', '2300014', '神奈川県', 'カナガワケン', '横浜市鶴見区', 'ヨコハマシツルミク', '諏訪坂', 'スワザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市鶴見区寺谷', '14', '14101', '2300015', '神奈川県', 'カナガワケン', '横浜市鶴見区', 'ヨコハマシツルミク', '寺谷', 'テラヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市鶴見区東寺尾北台', '14', '14101', '2300016', '神奈川県', 'カナガワケン', '横浜市鶴見区', 'ヨコハマシツルミク', '東寺尾北台', 'ヒガシテラオキタダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市鶴見区東寺尾中台', '14', '14101', '2300017', '神奈川県', 'カナガワケン', '横浜市鶴見区', 'ヨコハマシツルミク', '東寺尾中台', 'ヒガシテラオナカダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市鶴見区東寺尾東台', '14', '14101', '2300018', '神奈川県', 'カナガワケン', '横浜市鶴見区', 'ヨコハマシツルミク', '東寺尾東台', 'ヒガシテラオヒガシダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区水沢工業団地', '03', '03215', '0230002', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区水沢工業団地', 'ミズサワクミズサワコウギョウダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市鶴見区市場上町', '14', '14101', '2300021', '神奈川県', 'カナガワケン', '横浜市鶴見区', 'ヨコハマシツルミク', '市場上町', 'イチバカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市鶴見区市場東中町', '14', '14101', '2300022', '神奈川県', 'カナガワケン', '横浜市鶴見区', 'ヨコハマシツルミク', '市場東中町', 'イチバヒガシナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市鶴見区市場西中町', '14', '14101', '2300023', '神奈川県', 'カナガワケン', '横浜市鶴見区', 'ヨコハマシツルミク', '市場西中町', 'イチバニシナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市鶴見区市場下町', '14', '14101', '2300024', '神奈川県', 'カナガワケン', '横浜市鶴見区', 'ヨコハマシツルミク', '市場下町', 'イチバシモチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市鶴見区市場大和町', '14', '14101', '2300025', '神奈川県', 'カナガワケン', '横浜市鶴見区', 'ヨコハマシツルミク', '市場大和町', 'イチバヤマトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市鶴見区市場富士見町', '14', '14101', '2300026', '神奈川県', 'カナガワケン', '横浜市鶴見区', 'ヨコハマシツルミク', '市場富士見町', 'イチバフジミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市鶴見区菅沢町', '14', '14101', '2300027', '神奈川県', 'カナガワケン', '横浜市鶴見区', 'ヨコハマシツルミク', '菅沢町', 'スガサワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区佐倉河', '03', '03215', '0230003', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区佐倉河', 'ミズサワクサクラカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市鶴見区平安町', '14', '14101', '2300031', '神奈川県', 'カナガワケン', '横浜市鶴見区', 'ヨコハマシツルミク', '平安町', 'ヘイアンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市鶴見区大東町', '14', '14101', '2300032', '神奈川県', 'カナガワケン', '横浜市鶴見区', 'ヨコハマシツルミク', '大東町', 'ダイトウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市鶴見区朝日町', '14', '14101', '2300033', '神奈川県', 'カナガワケン', '横浜市鶴見区', 'ヨコハマシツルミク', '朝日町', 'アサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市鶴見区寛政町', '14', '14101', '2300034', '神奈川県', 'カナガワケン', '横浜市鶴見区', 'ヨコハマシツルミク', '寛政町', 'カンセイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市鶴見区安善町', '14', '14101', '2300035', '神奈川県', 'カナガワケン', '横浜市鶴見区', 'ヨコハマシツルミク', '安善町', 'アンゼンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市鶴見区浜町', '14', '14101', '2300036', '神奈川県', 'カナガワケン', '横浜市鶴見区', 'ヨコハマシツルミク', '浜町', 'ハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市鶴見区向井町', '14', '14101', '2300037', '神奈川県', 'カナガワケン', '横浜市鶴見区', 'ヨコハマシツルミク', '向井町', 'ムカイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市鶴見区栄町通', '14', '14101', '2300038', '神奈川県', 'カナガワケン', '横浜市鶴見区', 'ヨコハマシツルミク', '栄町通', 'サカエチョウドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市鶴見区潮田町', '14', '14101', '2300041', '神奈川県', 'カナガワケン', '横浜市鶴見区', 'ヨコハマシツルミク', '潮田町', 'ウシオダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市鶴見区仲通', '14', '14101', '2300042', '神奈川県', 'カナガワケン', '横浜市鶴見区', 'ヨコハマシツルミク', '仲通', 'ナカドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市鶴見区汐入町', '14', '14101', '2300043', '神奈川県', 'カナガワケン', '横浜市鶴見区', 'ヨコハマシツルミク', '汐入町', 'シオイリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市鶴見区弁天町', '14', '14101', '2300044', '神奈川県', 'カナガワケン', '横浜市鶴見区', 'ヨコハマシツルミク', '弁天町', 'ベンテンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市鶴見区末広町', '14', '14101', '2300045', '神奈川県', 'カナガワケン', '横浜市鶴見区', 'ヨコハマシツルミク', '末広町', 'スエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市鶴見区小野町', '14', '14101', '2300046', '神奈川県', 'カナガワケン', '横浜市鶴見区', 'ヨコハマシツルミク', '小野町', 'オノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市鶴見区下野谷町', '14', '14101', '2300047', '神奈川県', 'カナガワケン', '横浜市鶴見区', 'ヨコハマシツルミク', '下野谷町', 'シタノヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市鶴見区本町通', '14', '14101', '2300048', '神奈川県', 'カナガワケン', '横浜市鶴見区', 'ヨコハマシツルミク', '本町通', 'ホンチョウドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市鶴見区鶴見中央', '14', '14101', '2300051', '神奈川県', 'カナガワケン', '横浜市鶴見区', 'ヨコハマシツルミク', '鶴見中央', 'ツルミチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市鶴見区生麦', '14', '14101', '2300052', '神奈川県', 'カナガワケン', '横浜市鶴見区', 'ヨコハマシツルミク', '生麦', 'ナマムギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市鶴見区大黒町', '14', '14101', '2300053', '神奈川県', 'カナガワケン', '横浜市鶴見区', 'ヨコハマシツルミク', '大黒町', 'ダイコクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市鶴見区大黒ふ頭', '14', '14101', '2300054', '神奈川県', 'カナガワケン', '横浜市鶴見区', 'ヨコハマシツルミク', '大黒ふ頭', 'ダイコクフトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市鶴見区扇島', '14', '14101', '2300055', '神奈川県', 'カナガワケン', '横浜市鶴見区', 'ヨコハマシツルミク', '扇島', 'オウギシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市鶴見区佃野町', '14', '14101', '2300061', '神奈川県', 'カナガワケン', '横浜市鶴見区', 'ヨコハマシツルミク', '佃野町', 'ツクノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市鶴見区豊岡町', '14', '14101', '2300062', '神奈川県', 'カナガワケン', '横浜市鶴見区', 'ヨコハマシツルミク', '豊岡町', 'トヨオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市鶴見区鶴見', '14', '14101', '2300063', '神奈川県', 'カナガワケン', '横浜市鶴見区', 'ヨコハマシツルミク', '鶴見', 'ツルミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市鶴見区駒岡', '14', '14101', '2300071', '神奈川県', 'カナガワケン', '横浜市鶴見区', 'ヨコハマシツルミク', '駒岡', 'コマオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市鶴見区梶山', '14', '14101', '2300072', '神奈川県', 'カナガワケン', '横浜市鶴見区', 'ヨコハマシツルミク', '梶山', 'カジヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市鶴見区獅子ケ谷', '14', '14101', '2300073', '神奈川県', 'カナガワケン', '横浜市鶴見区', 'ヨコハマシツルミク', '獅子ケ谷', 'シシガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市鶴見区北寺尾', '14', '14101', '2300074', '神奈川県', 'カナガワケン', '横浜市鶴見区', 'ヨコハマシツルミク', '北寺尾', 'キタテラオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市鶴見区上の宮', '14', '14101', '2300075', '神奈川県', 'カナガワケン', '横浜市鶴見区', 'ヨコハマシツルミク', '上の宮', 'カミノミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市鶴見区馬場', '14', '14101', '2300076', '神奈川県', 'カナガワケン', '横浜市鶴見区', 'ヨコハマシツルミク', '馬場', 'ババ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市鶴見区東寺尾', '14', '14101', '2300077', '神奈川県', 'カナガワケン', '横浜市鶴見区', 'ヨコハマシツルミク', '東寺尾', 'ヒガシテラオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市鶴見区岸谷', '14', '14101', '2300078', '神奈川県', 'カナガワケン', '横浜市鶴見区', 'ヨコハマシツルミク', '岸谷', 'キシヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区稲荷田', '03', '03215', '0230011', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区稲荷田', 'ミズサワクイナリダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区斉勝田', '03', '03215', '0230012', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区斉勝田', 'ミズサワクサイカツダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区一本柳', '03', '03215', '0230013', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区一本柳', 'ミズサワクイッポンヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区地蔵田', '03', '03215', '0230014', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区地蔵田', 'ミズサワクジゾウデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区五千刈', '03', '03215', '0230015', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区五千刈', 'ミズサワクゴセンガリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区平沢', '03', '03215', '0230016', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区平沢', 'ミズサワクヒラサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区渋田', '03', '03215', '0230017', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区渋田', 'ミズサワクシブタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区小中', '03', '03215', '0230018', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区小中', 'ミズサワクコナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区築舘', '03', '03215', '0230019', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区築舘', 'ミズサワクツキダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区欠ノ下', '03', '03215', '0230021', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区欠ノ下', 'ミズサワクカケノシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区中城', '03', '03215', '0230022', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区中城', 'ミズサワクナカシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区八反町', '03', '03215', '0230023', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区八反町', 'ミズサワクハッタンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区名残', '03', '03215', '0230024', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区名残', 'ミズサワクナゴリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区高網', '03', '03215', '0230025', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区高網', 'ミズサワクコウアミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区里鎗', '03', '03215', '0230026', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区里鎗', 'ミズサワクサトヤリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区幅下', '03', '03215', '0230027', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区幅下', 'ミズサワクハバシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区北丑沢', '03', '03215', '0230031', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区北丑沢', 'ミズサワクキタウシザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区多賀', '03', '03215', '0230032', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区多賀', 'ミズサワクタガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区不断町', '03', '03215', '0230033', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区不断町', 'ミズサワクフダンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区川口町', '03', '03215', '0230034', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区川口町', 'ミズサワクカワグチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区赤土田', '03', '03215', '0230035', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区赤土田', 'ミズサワクアカツチダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区北栗林', '03', '03215', '0230036', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区北栗林', 'ミズサワクキタクリバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区南丑沢', '03', '03215', '0230037', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区南丑沢', 'ミズサワクミナミウシザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区秋葉町', '03', '03215', '0230041', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区秋葉町', 'ミズサワクアキバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区柳町', '03', '03215', '0230042', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区柳町', 'ミズサワクヤナギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区道合', '03', '03215', '0230043', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区道合', 'ミズサワクミチアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区三本木', '03', '03215', '0230044', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区三本木', 'ミズサワクサンボンギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区大町', '03', '03215', '0230045', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区大町', 'ミズサワクオオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区川原小路', '03', '03215', '0230046', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区川原小路', 'ミズサワクカワラコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区立町', '03', '03215', '0230047', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区立町', 'ミズサワクタチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区勝手町', '03', '03215', '0230051', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区勝手町', 'ミズサワクカッテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区搦手丁', '03', '03215', '0230052', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区搦手丁', 'ミズサワクカラメテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区大手町', '03', '03215', '0230053', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区大手町', 'ミズサワクオオテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区吉小路', '03', '03215', '0230054', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区吉小路', 'ミズサワクキチコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区虚空蔵小路', '03', '03215', '0230055', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区虚空蔵小路', 'ミズサワクコクゾウコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区久田', '03', '03215', '0230056', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区久田', 'ミズサワクキュウデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区上町', '03', '03215', '0230057', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区上町', 'ミズサワクウワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区堀ノ内', '03', '03215', '0230058', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区堀ノ内', 'ミズサワクホリノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区長町', '03', '03215', '0230061', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区長町', 'ミズサワクナガマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区小石田', '03', '03215', '0230062', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区小石田', 'ミズサワクコイシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区聖天', '03', '03215', '0230063', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区聖天', 'ミズサワクショウテン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区土器田', '03', '03215', '0230064', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区土器田', 'ミズサワクドキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区水山', '03', '03215', '0230065', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区水山', 'ミズサワクミズヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区前田袋', '03', '03215', '0230066', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区前田袋', 'ミズサワクマエタブクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区二反田', '03', '03215', '0230067', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区二反田', 'ミズサワクニタンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区黒子', '03', '03215', '0230071', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区黒子', 'ミズサワククロコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区樋渡', '03', '03215', '0230072', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区樋渡', 'ミズサワクヒワタシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区寺領', '03', '03215', '0230073', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区寺領', 'ミズサワクジリョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区極楽', '03', '03215', '0230074', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区極楽', 'ミズサワクゴクラク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区水ノ口', '03', '03215', '0230075', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区水ノ口', 'ミズサワクミノクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区造道', '03', '03215', '0230076', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区造道', 'ミズサワクツクリミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区桑畑', '03', '03215', '0230077', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区桑畑', 'ミズサワククワバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区橇町', '03', '03215', '0230081', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区橇町', 'ミズサワクソリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区東半郷', '03', '03215', '0230082', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区東半郷', 'ミズサワクヒガシハンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区前郷', '03', '03215', '0230083', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区前郷', 'ミズサワクゼンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区大上', '03', '03215', '0230084', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区大上', 'ミズサワクオオガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区踊子', '03', '03215', '0230085', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区踊子', 'ミズサワクオドリコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区谷地中', '03', '03215', '0230086', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区谷地中', 'ミズサワクヤチナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区高谷宿', '03', '03215', '0230087', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区高谷宿', 'ミズサワクコウヤシュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区高山', '03', '03215', '0230091', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区高山', 'ミズサワクタカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区北半郷', '03', '03215', '0230092', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区北半郷', 'ミズサワクキタハンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区水神', '03', '03215', '0230093', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区水神', 'ミズサワクミズガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区五輪', '03', '03215', '0230094', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区五輪', 'ミズサワクゴリン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区雀田', '03', '03215', '0230095', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区雀田', 'ミズサワクスズメダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区向田', '03', '03215', '0230096', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区向田', 'ミズサワクムカイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区黒石町', '03', '03215', '0230101', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区黒石町', 'ミズサワククロイシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区羽田町駅東', '03', '03215', '0230102', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区羽田町駅東', 'ミズサワクハダチョウエキヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区羽田町駅南', '03', '03215', '0230103', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区羽田町駅南', 'ミズサワクハダチョウエキミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区羽田町駅前', '03', '03215', '0230104', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区羽田町駅前', 'ミズサワクハダチョウエキマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区羽田町宝生', '03', '03215', '0230105', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区羽田町宝生', 'ミズサワクハダチョウホウショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区羽田町久保', '03', '03215', '0230106', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区羽田町久保', 'ミズサワクハダチョウクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区羽田町宝柳木', '03', '03215', '0230107', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区羽田町宝柳木', 'ミズサワクハダチョウホウリュウギ', null, null, null, null), ('12478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区羽田町向畑', '03', '03215', '0230108', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区羽田町向畑', 'ミズサワクハダチョウムカイハタ', null, null, null, null), ('12479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区羽田町', '03', '03215', '0230132', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区羽田町', 'ミズサワクハダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市江刺区田原', '03', '03215', '0230171', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '江刺区田原', 'エサシクタワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市胆沢区南都田', '03', '03215', '0230401', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '胆沢区南都田', 'イサワクナツタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市胆沢区小山', '03', '03215', '0230402', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '胆沢区小山', 'イサワクオヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市胆沢区若柳', '03', '03215', '0230403', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '胆沢区若柳', 'イサワクワカヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区横町', '03', '03215', '0230801', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区横町', 'ミズサワクヨコマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区大畑小路', '03', '03215', '0230802', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区大畑小路', 'ミズサワクオオバタケコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区田小路', '03', '03215', '0230803', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区田小路', 'ミズサワクタコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区谷地明円', '03', '03215', '0230804', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区谷地明円', 'ミズサワクヤチミョウエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区斉の神', '03', '03215', '0230805', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区斉の神', 'ミズサワクサイノカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区日高西', '03', '03215', '0230806', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区日高西', 'ミズサワクヒタカニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区新小路', '03', '03215', '0230807', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区新小路', 'ミズサワクシンコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区日高小路', '03', '03215', '0230808', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区日高小路', 'ミズサワクヒタカコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区寺小路', '03', '03215', '0230811', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区寺小路', 'ミズサワクテラコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区寺脇', '03', '03215', '0230812', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区寺脇', 'ミズサワクテラワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区中町', '03', '03215', '0230813', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区中町', 'ミズサワクナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区袋町', '03', '03215', '0230814', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区袋町', 'ミズサワクフクロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区天文台通り', '03', '03215', '0230815', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区天文台通り', 'ミズサワクテンモンダイドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区西町', '03', '03215', '0230816', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区西町', 'ミズサワクニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区宮下町', '03', '03215', '0230817', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区宮下町', 'ミズサワクミヤシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区東町', '03', '03215', '0230818', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区東町', 'ミズサワクアズマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区神明町', '03', '03215', '0230821', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区神明町', 'ミズサワクシンメイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区東中通り', '03', '03215', '0230822', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区東中通り', 'ミズサワクヒガシナカドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区朝日町', '03', '03215', '0230823', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区朝日町', 'ミズサワクアサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区泉町', '03', '03215', '0230824', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区泉町', 'ミズサワクイズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区台町', '03', '03215', '0230825', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区台町', 'ミズサワクダイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区中田町', '03', '03215', '0230826', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区中田町', 'ミズサワクナカダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区太日通り', '03', '03215', '0230827', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区太日通り', 'ミズサワクタイニチドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区東大通り', '03', '03215', '0230828', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区東大通り', 'ミズサワクヒガシオオドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区花園町', '03', '03215', '0230829', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区花園町', 'ミズサワクハナゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区姉体町', '03', '03215', '0230831', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区姉体町', 'ミズサワクアネタイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区羽田町草井沼', '03', '03215', '0230832', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区羽田町', 'ミズサワクハダチョウ', null, null, '草井沼', 'クサイヌマ');
INSERT INTO `ms_addresses` VALUES ('12513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区羽田町下沼', '03', '03215', '0230832', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区羽田町', 'ミズサワクハダチョウ', null, null, '下沼', 'シモヌマ');
INSERT INTO `ms_addresses` VALUES ('12514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区羽田町元谷木', '03', '03215', '0230832', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区羽田町', 'ミズサワクハダチョウ', null, null, '元谷木', 'モトヤギ');
INSERT INTO `ms_addresses` VALUES ('12515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区羽田町谷木', '03', '03215', '0230832', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区羽田町', 'ミズサワクハダチョウ', null, null, '谷木', 'ヤギ');
INSERT INTO `ms_addresses` VALUES ('12516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区上姉体', '03', '03215', '0230833', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区上姉体', 'ミズサワクカミアネタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区真城', '03', '03215', '0230841', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区真城', 'ミズサワクシンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区真城が丘', '03', '03215', '0230842', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区真城が丘', 'ミズサワクシンジョウガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区南町', '03', '03215', '0230851', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区南町', 'ミズサワクミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区山崎町', '03', '03215', '0230852', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区山崎町', 'ミズサワクヤマザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区東上野町', '03', '03215', '0230853', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区東上野町', 'ミズサワクヒガシウワノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区大鐘町', '03', '03215', '0230854', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区大鐘町', 'ミズサワクオオガネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区南大鐘', '03', '03215', '0230855', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区南大鐘', 'ミズサワクミナミオオガネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区西上野町', '03', '03215', '0230856', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区西上野町', 'ミズサワクニシウワノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区中上野町', '03', '03215', '0230857', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区中上野町', 'ミズサワクナカウワノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区星ガ丘町', '03', '03215', '0230861', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区星ガ丘町', 'ミズサワクホシガオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区福吉町', '03', '03215', '0230862', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区福吉町', 'ミズサワクフクヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区川端', '03', '03215', '0230863', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区川端', 'ミズサワクカワバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区龍ケ馬場', '03', '03215', '0230864', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区龍ケ馬場', 'ミズサワクリュウガババ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区桜屋敷', '03', '03215', '0230865', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区桜屋敷', 'ミズサワクサクラヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区堰合', '03', '03215', '0230866', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区堰合', 'ミズサワクセキアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区大橋', '03', '03215', '0230867', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区大橋', 'ミズサワクオオハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区外谷地', '03', '03215', '0230871', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区外谷地', 'ミズサワクソトヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区桜屋敷西', '03', '03215', '0230872', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区桜屋敷西', 'ミズサワクサクラヤシキニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区笹森谷地', '03', '03215', '0230873', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区笹森谷地', 'ミズサワクササモリヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区見分森', '03', '03215', '0230874', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区見分森', 'ミズサワクミワケモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区森下', '03', '03215', '0230875', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区森下', 'ミズサワクモリシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区鶴淵', '03', '03215', '0230876', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区鶴淵', 'ミズサワクツルブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区袖谷地', '03', '03215', '0230877', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区袖谷地', 'ミズサワクソデヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区北田', '03', '03215', '0230881', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区北田', 'ミズサワクキタダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区福原', '03', '03215', '0230882', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区福原', 'ミズサワクフクワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区町裏', '03', '03215', '0230883', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区町裏', 'ミズサワクマチウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区前谷地', '03', '03215', '0230884', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区前谷地', 'ミズサワクマエヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区西田', '03', '03215', '0230885', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区西田', 'ミズサワクニシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区南矢中', '03', '03215', '0230886', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区南矢中', 'ミズサワクミナミヤナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区矢中', '03', '03215', '0230887', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区矢中', 'ミズサワクヤナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区八反田', '03', '03215', '0230888', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区八反田', 'ミズサワクハッタンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区高屋敷', '03', '03215', '0230889', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区高屋敷', 'ミズサワクタカヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区内匠田', '03', '03215', '0230891', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区内匠田', 'ミズサワクタクミダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区釜田', '03', '03215', '0230892', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区釜田', 'ミズサワクカマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区蓬田', '03', '03215', '0230893', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区蓬田', 'ミズサワクヨモギダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区大明神', '03', '03215', '0230894', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区大明神', 'ミズサワクダイミョウジン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区足袋針', '03', '03215', '0230895', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区足袋針', 'ミズサワクタビハリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区西光田', '03', '03215', '0230896', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区西光田', 'ミズサワクニシコウデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区桜川', '03', '03215', '0230897', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区桜川', 'ミズサワクサクラカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市水沢区後田', '03', '03215', '0230898', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '水沢区後田', 'ミズサワクウシロダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区', '14', '14104', '2310000', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('12573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区新港', '14', '14104', '2310001', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '新港', 'シンコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区海岸通', '14', '14104', '2310002', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '海岸通', 'カイガンドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区北仲通', '14', '14104', '2310003', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '北仲通', 'キタナカドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区元浜町', '14', '14104', '2310004', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '元浜町', 'モトハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区本町', '14', '14104', '2310005', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区南仲通', '14', '14104', '2310006', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '南仲通', 'ミナミナカドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区弁天通', '14', '14104', '2310007', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '弁天通', 'ベンテンドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区太田町', '14', '14104', '2310011', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '太田町', 'オオタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区相生町', '14', '14104', '2310012', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '相生町', 'アイオイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区住吉町', '14', '14104', '2310013', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '住吉町', 'スミヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区常盤町', '14', '14104', '2310014', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '常盤町', 'トキワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区尾上町', '14', '14104', '2310015', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '尾上町', 'オノエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区真砂町', '14', '14104', '2310016', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '真砂町', 'マサゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区港町', '14', '14104', '2310017', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '港町', 'ミナトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区日本大通', '14', '14104', '2310021', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '日本大通', 'ニホンオオドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区横浜公園', '14', '14104', '2310022', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '横浜公園', 'ヨコハマコウエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区山下町', '14', '14104', '2310023', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '山下町', 'ヤマシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区吉浜町', '14', '14104', '2310024', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '吉浜町', 'ヨシハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区松影町', '14', '14104', '2310025', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '松影町', 'マツカゲチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区寿町', '14', '14104', '2310026', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '寿町', 'コトブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区扇町', '14', '14104', '2310027', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '扇町', 'オウギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区翁町', '14', '14104', '2310028', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '翁町', 'オキナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区万代町', '14', '14104', '2310031', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '万代町', 'バンダイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区不老町', '14', '14104', '2310032', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '不老町', 'フロウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区長者町', '14', '14104', '2310033', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '長者町', 'チョウジャマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区三吉町', '14', '14104', '2310034', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '三吉町', 'ミヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区千歳町', '14', '14104', '2310035', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '千歳町', 'チトセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区山田町', '14', '14104', '2310036', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '山田町', 'ヤマダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区富士見町', '14', '14104', '2310037', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '富士見町', 'フジミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区山吹町', '14', '14104', '2310038', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '山吹町', 'ヤマブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区吉田町', '14', '14104', '2310041', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '吉田町', 'ヨシダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区福富町西通', '14', '14104', '2310042', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '福富町西通', 'フクトミチョウニシドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区福富町仲通', '14', '14104', '2310043', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '福富町仲通', 'フクトミチョウナカドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区福富町東通', '14', '14104', '2310044', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '福富町東通', 'フクトミチョウヒガシドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区伊勢佐木町', '14', '14104', '2310045', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '伊勢佐木町', 'イセザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区末広町', '14', '14104', '2310046', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '末広町', 'スエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区羽衣町', '14', '14104', '2310047', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '羽衣町', 'ハゴロモチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区蓬莱町', '14', '14104', '2310048', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '蓬莱町', 'ホウライチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区赤門町', '14', '14104', '2310051', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '赤門町', 'アカモンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区英町', '14', '14104', '2310052', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '英町', 'ハナブサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区初音町', '14', '14104', '2310053', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '初音町', 'ハツネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区黄金町', '14', '14104', '2310054', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '黄金町', 'コガネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区末吉町', '14', '14104', '2310055', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '末吉町', 'スエヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区若葉町', '14', '14104', '2310056', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '若葉町', 'ワカバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区曙町', '14', '14104', '2310057', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '曙町', 'アケボノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区弥生町', '14', '14104', '2310058', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '弥生町', 'ヤヨイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区内田町', '14', '14104', '2310061', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '内田町', 'ウチダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区桜木町', '14', '14104', '2310062', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '桜木町', 'サクラギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区花咲町', '14', '14104', '2310063', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '花咲町', 'ハナサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区野毛町', '14', '14104', '2310064', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '野毛町', 'ノゲチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区宮川町', '14', '14104', '2310065', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '宮川町', 'ミヤガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区日ノ出町', '14', '14104', '2310066', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '日ノ出町', 'ヒノデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区新山下', '14', '14104', '2310801', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '新山下', 'シンヤマシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区小港町', '14', '14104', '2310802', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '小港町', 'コミナトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区本牧十二天', '14', '14104', '2310803', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '本牧十二天', 'ホンモクジュウニテン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区本牧宮原', '14', '14104', '2310804', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '本牧宮原', 'ホンモクミヤバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区和田山', '14', '14104', '2310805', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '和田山', 'ワダヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区本牧町', '14', '14104', '2310806', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '本牧町', 'ホンモクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区本牧ふ頭', '14', '14104', '2310811', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '本牧ふ頭', 'ホンモクフトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区錦町', '14', '14104', '2310812', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '錦町', 'ニシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区かもめ町', '14', '14104', '2310813', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', 'かもめ町', 'カモメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区豊浦町', '14', '14104', '2310814', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '豊浦町', 'トヨウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区千鳥町', '14', '14104', '2310815', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '千鳥町', 'チドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区南本牧', '14', '14104', '2310816', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '南本牧', 'ミナミホンモク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区本牧原', '14', '14104', '2310821', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '本牧原', 'ホンモクハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区本牧元町', '14', '14104', '2310822', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '本牧元町', 'ホンモクモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区本牧大里町', '14', '14104', '2310823', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '本牧大里町', 'ホンモクオオサトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区本牧三之谷', '14', '14104', '2310824', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '本牧三之谷', 'ホンモクサンノタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区本牧間門', '14', '14104', '2310825', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '本牧間門', 'ホンモクマカド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区本牧荒井', '14', '14104', '2310826', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '本牧荒井', 'ホンモクアライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区本牧和田', '14', '14104', '2310827', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '本牧和田', 'ホンモクワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区矢口台', '14', '14104', '2310831', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '矢口台', 'ヤグチダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区本牧緑ケ丘', '14', '14104', '2310832', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '本牧緑ケ丘', 'ホンモクミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区本牧満坂', '14', '14104', '2310833', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '本牧満坂', 'ホンモクマンザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区池袋', '14', '14104', '2310834', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '池袋', 'イケブクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区根岸加曽台', '14', '14104', '2310835', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '根岸加曽台', 'ネギシカゾウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区根岸町', '14', '14104', '2310836', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '根岸町', 'ネギシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区滝之上', '14', '14104', '2310837', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '滝之上', 'タキノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区豆口台', '14', '14104', '2310838', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '豆口台', 'マメグチダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区仲尾台', '14', '14104', '2310839', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '仲尾台', 'ナカオダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区妙香寺台', '14', '14104', '2310841', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '妙香寺台', 'ミョウコウジダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区上野町', '14', '14104', '2310842', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '上野町', 'ウエノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区本郷町', '14', '14104', '2310843', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '本郷町', 'ホンゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区西之谷町', '14', '14104', '2310844', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '西之谷町', 'ニシノヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区立野', '14', '14104', '2310845', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '立野', 'タテノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区大和町', '14', '14104', '2310846', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '大和町', 'ヤマトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区竹之丸', '14', '14104', '2310847', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '竹之丸', 'タケノマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区鷺山', '14', '14104', '2310848', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '鷺山', 'サギヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区麦田町', '14', '14104', '2310849', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '麦田町', 'ムギタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区山元町', '14', '14104', '2310851', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '山元町', 'ヤマモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区西竹之丸', '14', '14104', '2310852', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '西竹之丸', 'ニシタケノマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区根岸台', '14', '14104', '2310853', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '根岸台', 'ネギシダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区根岸旭台', '14', '14104', '2310854', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '根岸旭台', 'ネギシアサヒダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区寺久保', '14', '14104', '2310855', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '寺久保', 'テラクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区簑沢', '14', '14104', '2310856', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '簑沢', 'ミノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区塚越', '14', '14104', '2310857', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '塚越', 'ツカゴシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区大芝台', '14', '14104', '2310858', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '大芝台', 'オオシバダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区大平町', '14', '14104', '2310859', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '大平町', 'オオヒラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区元町', '14', '14104', '2310861', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '元町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区山手町', '14', '14104', '2310862', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '山手町', 'ヤマテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区諏訪町', '14', '14104', '2310863', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '諏訪町', 'スワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区千代崎町', '14', '14104', '2310864', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '千代崎町', 'チヨザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区北方町', '14', '14104', '2310865', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '北方町', 'キタガタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区柏葉', '14', '14104', '2310866', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '柏葉', 'カシワバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区打越', '14', '14104', '2310867', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '打越', 'ウチコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市中区石川町', '14', '14104', '2310868', '神奈川県', 'カナガワケン', '横浜市中区', 'ヨコハマシナカク', '石川町', 'イシカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市江刺区岩谷堂', '03', '03215', '0231101', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '江刺区岩谷堂', 'エサシクイワヤドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市江刺区八日町', '03', '03215', '0231102', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '江刺区八日町', 'エサシクヨウカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市江刺区西大通り', '03', '03215', '0231103', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '江刺区西大通り', 'エサシクニシオオドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市江刺区豊田町', '03', '03215', '0231104', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '江刺区豊田町', 'エサシクトヨタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市江刺区杉ノ町', '03', '03215', '0231105', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '江刺区杉ノ町', 'エサシクスギノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市江刺区大通り', '03', '03215', '0231111', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '江刺区大通り', 'エサシクオオドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市江刺区南大通り', '03', '03215', '0231112', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '江刺区南大通り', 'エサシクミナミオオドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市江刺区中町', '03', '03215', '0231113', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '江刺区中町', 'エサシクナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市江刺区川原町', '03', '03215', '0231114', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '江刺区川原町', 'エサシクカワラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市江刺区本町', '03', '03215', '0231115', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '江刺区本町', 'エサシクホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市江刺区重染寺', '03', '03215', '0231116', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '江刺区重染寺', 'エサシクチョウゼンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市江刺区南町', '03', '03215', '0231117', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '江刺区南町', 'エサシクミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市江刺区栄町', '03', '03215', '0231118', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '江刺区栄町', 'エサシクサカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市江刺区男石', '03', '03215', '0231121', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '江刺区男石', 'エサシクオトコイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市江刺区舘山', '03', '03215', '0231122', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '江刺区舘山', 'エサシクタテヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市江刺区前田町', '03', '03215', '0231123', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '江刺区前田町', 'エサシクマエダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市江刺区六日町', '03', '03215', '0231124', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '江刺区六日町', 'エサシクムイカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市江刺区銭町', '03', '03215', '0231125', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '江刺区銭町', 'エサシクゼニマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市江刺区愛宕', '03', '03215', '0231131', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '江刺区愛宕', 'エサシクオダキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市江刺区稲瀬', '03', '03215', '0231132', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '江刺区稲瀬', 'エサシクイナセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市江刺区広瀬', '03', '03215', '0231133', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '江刺区広瀬', 'エサシクヒロセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市江刺区玉里', '03', '03215', '0231134', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '江刺区玉里', 'エサシクタマサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市江刺区梁川', '03', '03215', '0231341', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '江刺区梁川', 'エサシクヤナガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市江刺区米里', '03', '03215', '0231551', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '江刺区米里', 'エサシクヨネサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市江刺区伊手', '03', '03215', '0231761', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '江刺区伊手', 'エサシクイデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市江刺区藤里', '03', '03215', '0231762', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '江刺区藤里', 'エサシクフジサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市南区', '14', '14105', '2320000', '神奈川県', 'カナガワケン', '横浜市南区', 'ヨコハマシミナミク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('12743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市南区伏見町', '14', '14105', '2320001', '神奈川県', 'カナガワケン', '横浜市南区', 'ヨコハマシミナミク', '伏見町', 'フシミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市南区三春台', '14', '14105', '2320002', '神奈川県', 'カナガワケン', '横浜市南区', 'ヨコハマシミナミク', '三春台', 'ミハルダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市南区西中町', '14', '14105', '2320003', '神奈川県', 'カナガワケン', '横浜市南区', 'ヨコハマシミナミク', '西中町', 'ニシナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市南区前里町', '14', '14105', '2320004', '神奈川県', 'カナガワケン', '横浜市南区', 'ヨコハマシミナミク', '前里町', 'マエサトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市南区白金町', '14', '14105', '2320005', '神奈川県', 'カナガワケン', '横浜市南区', 'ヨコハマシミナミク', '白金町', 'シロガネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市南区南太田', '14', '14105', '2320006', '神奈川県', 'カナガワケン', '横浜市南区', 'ヨコハマシミナミク', '南太田', 'ミナミオオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市南区清水ケ丘', '14', '14105', '2320007', '神奈川県', 'カナガワケン', '横浜市南区', 'ヨコハマシミナミク', '清水ケ丘', 'シミズガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市南区庚台', '14', '14105', '2320008', '神奈川県', 'カナガワケン', '横浜市南区', 'ヨコハマシミナミク', '庚台', 'カノエダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市南区日枝町', '14', '14105', '2320011', '神奈川県', 'カナガワケン', '横浜市南区', 'ヨコハマシミナミク', '日枝町', 'ヒエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市南区南吉田町', '14', '14105', '2320012', '神奈川県', 'カナガワケン', '横浜市南区', 'ヨコハマシミナミク', '南吉田町', 'ミナミヨシダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市南区山王町', '14', '14105', '2320013', '神奈川県', 'カナガワケン', '横浜市南区', 'ヨコハマシミナミク', '山王町', 'サンノウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市南区吉野町', '14', '14105', '2320014', '神奈川県', 'カナガワケン', '横浜市南区', 'ヨコハマシミナミク', '吉野町', 'ヨシノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市南区共進町', '14', '14105', '2320015', '神奈川県', 'カナガワケン', '横浜市南区', 'ヨコハマシミナミク', '共進町', 'キョウシンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市南区宮元町', '14', '14105', '2320016', '神奈川県', 'カナガワケン', '横浜市南区', 'ヨコハマシミナミク', '宮元町', 'ミヤモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市南区宿町', '14', '14105', '2320017', '神奈川県', 'カナガワケン', '横浜市南区', 'ヨコハマシミナミク', '宿町', 'シュクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市南区花之木町', '14', '14105', '2320018', '神奈川県', 'カナガワケン', '横浜市南区', 'ヨコハマシミナミク', '花之木町', 'ハナノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市南区真金町', '14', '14105', '2320021', '神奈川県', 'カナガワケン', '横浜市南区', 'ヨコハマシミナミク', '真金町', 'マガネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市南区高根町', '14', '14105', '2320022', '神奈川県', 'カナガワケン', '横浜市南区', 'ヨコハマシミナミク', '高根町', 'タカネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市南区白妙町', '14', '14105', '2320023', '神奈川県', 'カナガワケン', '横浜市南区', 'ヨコハマシミナミク', '白妙町', 'シロタエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市南区浦舟町', '14', '14105', '2320024', '神奈川県', 'カナガワケン', '横浜市南区', 'ヨコハマシミナミク', '浦舟町', 'ウラフネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市南区高砂町', '14', '14105', '2320025', '神奈川県', 'カナガワケン', '横浜市南区', 'ヨコハマシミナミク', '高砂町', 'タカサゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市南区二葉町', '14', '14105', '2320026', '神奈川県', 'カナガワケン', '横浜市南区', 'ヨコハマシミナミク', '二葉町', 'フタバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市南区新川町', '14', '14105', '2320027', '神奈川県', 'カナガワケン', '横浜市南区', 'ヨコハマシミナミク', '新川町', 'シンカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市南区永楽町', '14', '14105', '2320031', '神奈川県', 'カナガワケン', '横浜市南区', 'ヨコハマシミナミク', '永楽町', 'エイラクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市南区万世町', '14', '14105', '2320032', '神奈川県', 'カナガワケン', '横浜市南区', 'ヨコハマシミナミク', '万世町', 'マンセイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市南区中村町', '14', '14105', '2320033', '神奈川県', 'カナガワケン', '横浜市南区', 'ヨコハマシミナミク', '中村町', 'ナカムラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市南区唐沢', '14', '14105', '2320034', '神奈川県', 'カナガワケン', '横浜市南区', 'ヨコハマシミナミク', '唐沢', 'カラサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市南区平楽', '14', '14105', '2320035', '神奈川県', 'カナガワケン', '横浜市南区', 'ヨコハマシミナミク', '平楽', 'ヘイラク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市南区山谷', '14', '14105', '2320036', '神奈川県', 'カナガワケン', '横浜市南区', 'ヨコハマシミナミク', '山谷', 'サンヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市南区八幡町', '14', '14105', '2320037', '神奈川県', 'カナガワケン', '横浜市南区', 'ヨコハマシミナミク', '八幡町', 'ハチマンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市南区睦町', '14', '14105', '2320041', '神奈川県', 'カナガワケン', '横浜市南区', 'ヨコハマシミナミク', '睦町', 'ムツミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市南区堀ノ内町', '14', '14105', '2320042', '神奈川県', 'カナガワケン', '横浜市南区', 'ヨコハマシミナミク', '堀ノ内町', 'ホリノウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市南区蒔田町', '14', '14105', '2320043', '神奈川県', 'カナガワケン', '横浜市南区', 'ヨコハマシミナミク', '蒔田町', 'マイタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市南区榎町', '14', '14105', '2320044', '神奈川県', 'カナガワケン', '横浜市南区', 'ヨコハマシミナミク', '榎町', 'エノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市南区東蒔田町', '14', '14105', '2320045', '神奈川県', 'カナガワケン', '横浜市南区', 'ヨコハマシミナミク', '東蒔田町', 'ヒガシマイタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市南区井土ケ谷上町', '14', '14105', '2320051', '神奈川県', 'カナガワケン', '横浜市南区', 'ヨコハマシミナミク', '井土ケ谷上町', 'イドガヤカミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市南区井土ケ谷中町', '14', '14105', '2320052', '神奈川県', 'カナガワケン', '横浜市南区', 'ヨコハマシミナミク', '井土ケ谷中町', 'イドガヤナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市南区井土ケ谷下町', '14', '14105', '2320053', '神奈川県', 'カナガワケン', '横浜市南区', 'ヨコハマシミナミク', '井土ケ谷下町', 'イドガヤシモマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市南区大橋町', '14', '14105', '2320054', '神奈川県', 'カナガワケン', '横浜市南区', 'ヨコハマシミナミク', '大橋町', 'オオハシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市南区中島町', '14', '14105', '2320055', '神奈川県', 'カナガワケン', '横浜市南区', 'ヨコハマシミナミク', '中島町', 'ナカジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市南区通町', '14', '14105', '2320056', '神奈川県', 'カナガワケン', '横浜市南区', 'ヨコハマシミナミク', '通町', 'トオリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市南区若宮町', '14', '14105', '2320057', '神奈川県', 'カナガワケン', '横浜市南区', 'ヨコハマシミナミク', '若宮町', 'ワカミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市南区大岡', '14', '14105', '2320061', '神奈川県', 'カナガワケン', '横浜市南区', 'ヨコハマシミナミク', '大岡', 'オオオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市南区中里町', '14', '14105', '2320062', '神奈川県', 'カナガワケン', '横浜市南区', 'ヨコハマシミナミク', '中里町', 'ナカザトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市南区中里', '14', '14105', '2320063', '神奈川県', 'カナガワケン', '横浜市南区', 'ヨコハマシミナミク', '中里', 'ナカザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市南区別所', '14', '14105', '2320064', '神奈川県', 'カナガワケン', '横浜市南区', 'ヨコハマシミナミク', '別所', 'ベッシヨ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市南区別所中里台', '14', '14105', '2320065', '神奈川県', 'カナガワケン', '横浜市南区', 'ヨコハマシミナミク', '別所中里台', 'ベッショナカザトダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市南区六ツ川', '14', '14105', '2320066', '神奈川県', 'カナガワケン', '横浜市南区', 'ヨコハマシミナミク', '六ツ川', 'ムツカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市南区弘明寺町', '14', '14105', '2320067', '神奈川県', 'カナガワケン', '横浜市南区', 'ヨコハマシミナミク', '弘明寺町', 'グミョウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市南区永田北', '14', '14105', '2320071', '神奈川県', 'カナガワケン', '横浜市南区', 'ヨコハマシミナミク', '永田北', 'ナガタキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市南区永田東', '14', '14105', '2320072', '神奈川県', 'カナガワケン', '横浜市南区', 'ヨコハマシミナミク', '永田東', 'ナガタヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市南区永田南', '14', '14105', '2320073', '神奈川県', 'カナガワケン', '横浜市南区', 'ヨコハマシミナミク', '永田南', 'ナガタミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市南区永田山王台', '14', '14105', '2320074', '神奈川県', 'カナガワケン', '横浜市南区', 'ヨコハマシミナミク', '永田山王台', 'ナガタサンノウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市南区永田みなみ台', '14', '14105', '2320075', '神奈川県', 'カナガワケン', '横浜市南区', 'ヨコハマシミナミク', '永田みなみ台', 'ナガタミナミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市南区永田台', '14', '14105', '2320076', '神奈川県', 'カナガワケン', '横浜市南区', 'ヨコハマシミナミク', '永田台', 'ナガタダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市港南区', '14', '14111', '2330000', '神奈川県', 'カナガワケン', '横浜市港南区', 'ヨコハマシコウナンク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('12810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市港南区上大岡東', '14', '14111', '2330001', '神奈川県', 'カナガワケン', '横浜市港南区', 'ヨコハマシコウナンク', '上大岡東', 'カミオオオカヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市港南区上大岡西', '14', '14111', '2330002', '神奈川県', 'カナガワケン', '横浜市港南区', 'ヨコハマシコウナンク', '上大岡西', 'カミオオオカニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市港南区港南', '14', '14111', '2330003', '神奈川県', 'カナガワケン', '横浜市港南区', 'ヨコハマシコウナンク', '港南', 'コウナン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市港南区港南中央通', '14', '14111', '2330004', '神奈川県', 'カナガワケン', '横浜市港南区', 'ヨコハマシコウナンク', '港南中央通', 'コウナンチュウオウドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市港南区東芹が谷', '14', '14111', '2330005', '神奈川県', 'カナガワケン', '横浜市港南区', 'ヨコハマシコウナンク', '東芹が谷', 'ヒガシセリガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市港南区芹が谷', '14', '14111', '2330006', '神奈川県', 'カナガワケン', '横浜市港南区', 'ヨコハマシコウナンク', '芹が谷', 'セリガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市港南区大久保', '14', '14111', '2330007', '神奈川県', 'カナガワケン', '横浜市港南区', 'ヨコハマシコウナンク', '大久保', 'オオクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市港南区最戸', '14', '14111', '2330008', '神奈川県', 'カナガワケン', '横浜市港南区', 'ヨコハマシコウナンク', '最戸', 'サイド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市港南区東永谷', '14', '14111', '2330011', '神奈川県', 'カナガワケン', '横浜市港南区', 'ヨコハマシコウナンク', '東永谷', 'ヒガシナガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市港南区上永谷', '14', '14111', '2330012', '神奈川県', 'カナガワケン', '横浜市港南区', 'ヨコハマシコウナンク', '上永谷', 'カミナガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市港南区丸山台', '14', '14111', '2330013', '神奈川県', 'カナガワケン', '横浜市港南区', 'ヨコハマシコウナンク', '丸山台', 'マルヤマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市港南区上永谷町', '14', '14111', '2330014', '神奈川県', 'カナガワケン', '横浜市港南区', 'ヨコハマシコウナンク', '上永谷町', 'カミナガヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市港南区日限山', '14', '14111', '2330015', '神奈川県', 'カナガワケン', '横浜市港南区', 'ヨコハマシコウナンク', '日限山', 'ヒギリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市港南区下永谷', '14', '14111', '2330016', '神奈川県', 'カナガワケン', '横浜市港南区', 'ヨコハマシコウナンク', '下永谷', 'シモナガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市港南区日野', '14', '14111', '2340051', '神奈川県', 'カナガワケン', '横浜市港南区', 'ヨコハマシコウナンク', '日野', 'ヒノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市港南区笹下', '14', '14111', '2340052', '神奈川県', 'カナガワケン', '横浜市港南区', 'ヨコハマシコウナンク', '笹下', 'ササゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市港南区日野中央', '14', '14111', '2340053', '神奈川県', 'カナガワケン', '横浜市港南区', 'ヨコハマシコウナンク', '日野中央', 'ヒノチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市港南区港南台', '14', '14111', '2340054', '神奈川県', 'カナガワケン', '横浜市港南区', 'ヨコハマシコウナンク', '港南台', 'コウナンダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市港南区日野南', '14', '14111', '2340055', '神奈川県', 'カナガワケン', '横浜市港南区', 'ヨコハマシコウナンク', '日野南', 'ヒノミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市港南区野庭町', '14', '14111', '2340056', '神奈川県', 'カナガワケン', '横浜市港南区', 'ヨコハマシコウナンク', '野庭町', 'ノバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市磯子区', '14', '14107', '2350000', '神奈川県', 'カナガワケン', '横浜市磯子区', 'ヨコハマシイソゴク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('12837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市磯子区上町', '14', '14107', '2350001', '神奈川県', 'カナガワケン', '横浜市磯子区', 'ヨコハマシイソゴク', '上町', 'カミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市磯子区馬場町', '14', '14107', '2350002', '神奈川県', 'カナガワケン', '横浜市磯子区', 'ヨコハマシイソゴク', '馬場町', 'ババチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市磯子区坂下町', '14', '14107', '2350003', '神奈川県', 'カナガワケン', '横浜市磯子区', 'ヨコハマシイソゴク', '坂下町', 'サカシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市磯子区下町', '14', '14107', '2350004', '神奈川県', 'カナガワケン', '横浜市磯子区', 'ヨコハマシイソゴク', '下町', 'シモチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市磯子区東町', '14', '14107', '2350005', '神奈川県', 'カナガワケン', '横浜市磯子区', 'ヨコハマシイソゴク', '東町', 'ヒガシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市磯子区鳳町', '14', '14107', '2350006', '神奈川県', 'カナガワケン', '横浜市磯子区', 'ヨコハマシイソゴク', '鳳町', 'オオトリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市磯子区西町', '14', '14107', '2350007', '神奈川県', 'カナガワケン', '横浜市磯子区', 'ヨコハマシイソゴク', '西町', 'ニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市磯子区原町', '14', '14107', '2350008', '神奈川県', 'カナガワケン', '横浜市磯子区', 'ヨコハマシイソゴク', '原町', 'ハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市磯子区丸山', '14', '14107', '2350011', '神奈川県', 'カナガワケン', '横浜市磯子区', 'ヨコハマシイソゴク', '丸山', 'マルヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市磯子区滝頭', '14', '14107', '2350012', '神奈川県', 'カナガワケン', '横浜市磯子区', 'ヨコハマシイソゴク', '滝頭', 'タキガシラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市磯子区広地町', '14', '14107', '2350013', '神奈川県', 'カナガワケン', '横浜市磯子区', 'ヨコハマシイソゴク', '広地町', 'ヒロチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市磯子区中浜町', '14', '14107', '2350014', '神奈川県', 'カナガワケン', '横浜市磯子区', 'ヨコハマシイソゴク', '中浜町', 'ナカハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市磯子区久木町', '14', '14107', '2350015', '神奈川県', 'カナガワケン', '横浜市磯子区', 'ヨコハマシイソゴク', '久木町', 'ヒサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市磯子区磯子', '14', '14107', '2350016', '神奈川県', 'カナガワケン', '横浜市磯子区', 'ヨコハマシイソゴク', '磯子', 'イソゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市磯子区新磯子町', '14', '14107', '2350017', '神奈川県', 'カナガワケン', '横浜市磯子区', 'ヨコハマシイソゴク', '新磯子町', 'シンイソゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市磯子区新森町', '14', '14107', '2350018', '神奈川県', 'カナガワケン', '横浜市磯子区', 'ヨコハマシイソゴク', '新森町', 'シンモリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市磯子区磯子台', '14', '14107', '2350019', '神奈川県', 'カナガワケン', '横浜市磯子区', 'ヨコハマシイソゴク', '磯子台', 'イソゴダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市磯子区岡村', '14', '14107', '2350021', '神奈川県', 'カナガワケン', '横浜市磯子区', 'ヨコハマシイソゴク', '岡村', 'オカムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市磯子区汐見台', '14', '14107', '2350022', '神奈川県', 'カナガワケン', '横浜市磯子区', 'ヨコハマシイソゴク', '汐見台', 'シオミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市磯子区森', '14', '14107', '2350023', '神奈川県', 'カナガワケン', '横浜市磯子区', 'ヨコハマシイソゴク', '森', 'モリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市磯子区森が丘', '14', '14107', '2350024', '神奈川県', 'カナガワケン', '横浜市磯子区', 'ヨコハマシイソゴク', '森が丘', 'モリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市磯子区新中原町', '14', '14107', '2350031', '神奈川県', 'カナガワケン', '横浜市磯子区', 'ヨコハマシイソゴク', '新中原町', 'シンナカハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市磯子区新杉田町', '14', '14107', '2350032', '神奈川県', 'カナガワケン', '横浜市磯子区', 'ヨコハマシイソゴク', '新杉田町', 'シンスギタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市磯子区杉田', '14', '14107', '2350033', '神奈川県', 'カナガワケン', '横浜市磯子区', 'ヨコハマシイソゴク', '杉田', 'スギタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市磯子区杉田坪呑', '14', '14107', '2350034', '神奈川県', 'カナガワケン', '横浜市磯子区', 'ヨコハマシイソゴク', '杉田坪呑', 'スギタツボノミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市磯子区田中', '14', '14107', '2350035', '神奈川県', 'カナガワケン', '横浜市磯子区', 'ヨコハマシイソゴク', '田中', 'タナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市磯子区中原', '14', '14107', '2350036', '神奈川県', 'カナガワケン', '横浜市磯子区', 'ヨコハマシイソゴク', '中原', 'ナカハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市磯子区栗木', '14', '14107', '2350041', '神奈川県', 'カナガワケン', '横浜市磯子区', 'ヨコハマシイソゴク', '栗木', 'クリキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市磯子区上中里町', '14', '14107', '2350042', '神奈川県', 'カナガワケン', '横浜市磯子区', 'ヨコハマシイソゴク', '上中里町', 'カミナカザトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市磯子区氷取沢町', '14', '14107', '2350043', '神奈川県', 'カナガワケン', '横浜市磯子区', 'ヨコハマシイソゴク', '氷取沢町', 'ヒトリザワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市磯子区峰町', '14', '14107', '2350044', '神奈川県', 'カナガワケン', '横浜市磯子区', 'ヨコハマシイソゴク', '峰町', 'ミネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市磯子区洋光台', '14', '14107', '2350045', '神奈川県', 'カナガワケン', '横浜市磯子区', 'ヨコハマシイソゴク', '洋光台', 'ヨウコウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市金沢区', '14', '14108', '2360000', '神奈川県', 'カナガワケン', '横浜市金沢区', 'ヨコハマシカナザワク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('12876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市金沢区昭和町', '14', '14108', '2360001', '神奈川県', 'カナガワケン', '横浜市金沢区', 'ヨコハマシカナザワク', '昭和町', 'ショウワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市金沢区鳥浜町', '14', '14108', '2360002', '神奈川県', 'カナガワケン', '横浜市金沢区', 'ヨコハマシカナザワク', '鳥浜町', 'トリハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市金沢区幸浦', '14', '14108', '2360003', '神奈川県', 'カナガワケン', '横浜市金沢区', 'ヨコハマシカナザワク', '幸浦', 'サチウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市金沢区福浦', '14', '14108', '2360004', '神奈川県', 'カナガワケン', '横浜市金沢区', 'ヨコハマシカナザワク', '福浦', 'フクウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市金沢区並木', '14', '14108', '2360005', '神奈川県', 'カナガワケン', '横浜市金沢区', 'ヨコハマシカナザワク', '並木', 'ナミキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市金沢区八景島', '14', '14108', '2360006', '神奈川県', 'カナガワケン', '横浜市金沢区', 'ヨコハマシカナザワク', '八景島', 'ハッケイジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市金沢区白帆', '14', '14108', '2360007', '神奈川県', 'カナガワケン', '横浜市金沢区', 'ヨコハマシカナザワク', '白帆', 'シラホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市金沢区長浜', '14', '14108', '2360011', '神奈川県', 'カナガワケン', '横浜市金沢区', 'ヨコハマシカナザワク', '長浜', 'ナガハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市金沢区柴町', '14', '14108', '2360012', '神奈川県', 'カナガワケン', '横浜市金沢区', 'ヨコハマシカナザワク', '柴町', 'シバマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市金沢区海の公園', '14', '14108', '2360013', '神奈川県', 'カナガワケン', '横浜市金沢区', 'ヨコハマシカナザワク', '海の公園', 'ウミノコウエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市金沢区寺前', '14', '14108', '2360014', '神奈川県', 'カナガワケン', '横浜市金沢区', 'ヨコハマシカナザワク', '寺前', 'テラマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市金沢区金沢町', '14', '14108', '2360015', '神奈川県', 'カナガワケン', '横浜市金沢区', 'ヨコハマシカナザワク', '金沢町', 'カナザワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市金沢区谷津町', '14', '14108', '2360016', '神奈川県', 'カナガワケン', '横浜市金沢区', 'ヨコハマシカナザワク', '谷津町', 'ヤツマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市金沢区西柴', '14', '14108', '2360017', '神奈川県', 'カナガワケン', '横浜市金沢区', 'ヨコハマシカナザワク', '西柴', 'ニシシバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市金沢区泥亀', '14', '14108', '2360021', '神奈川県', 'カナガワケン', '横浜市金沢区', 'ヨコハマシカナザワク', '泥亀', 'デイキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市金沢区町屋町', '14', '14108', '2360022', '神奈川県', 'カナガワケン', '横浜市金沢区', 'ヨコハマシカナザワク', '町屋町', 'マチヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市金沢区平潟町', '14', '14108', '2360023', '神奈川県', 'カナガワケン', '横浜市金沢区', 'ヨコハマシカナザワク', '平潟町', 'ヒラカタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市金沢区乙舳町', '14', '14108', '2360024', '神奈川県', 'カナガワケン', '横浜市金沢区', 'ヨコハマシカナザワク', '乙舳町', 'オツトモチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市金沢区野島町', '14', '14108', '2360025', '神奈川県', 'カナガワケン', '横浜市金沢区', 'ヨコハマシカナザワク', '野島町', 'ノジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市金沢区柳町', '14', '14108', '2360026', '神奈川県', 'カナガワケン', '横浜市金沢区', 'ヨコハマシカナザワク', '柳町', 'ヤナギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市金沢区瀬戸', '14', '14108', '2360027', '神奈川県', 'カナガワケン', '横浜市金沢区', 'ヨコハマシカナザワク', '瀬戸', 'セト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市金沢区洲崎町', '14', '14108', '2360028', '神奈川県', 'カナガワケン', '横浜市金沢区', 'ヨコハマシカナザワク', '洲崎町', 'スサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市金沢区六浦', '14', '14108', '2360031', '神奈川県', 'カナガワケン', '横浜市金沢区', 'ヨコハマシカナザワク', '六浦', 'ムツウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市金沢区六浦町', '14', '14108', '2360032', '神奈川県', 'カナガワケン', '横浜市金沢区', 'ヨコハマシカナザワク', '六浦町', 'ムツウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市金沢区東朝比奈', '14', '14108', '2360033', '神奈川県', 'カナガワケン', '横浜市金沢区', 'ヨコハマシカナザワク', '東朝比奈', 'ヒガシアサヒナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市金沢区朝比奈町', '14', '14108', '2360034', '神奈川県', 'カナガワケン', '横浜市金沢区', 'ヨコハマシカナザワク', '朝比奈町', 'アサヒナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市金沢区大道', '14', '14108', '2360035', '神奈川県', 'カナガワケン', '横浜市金沢区', 'ヨコハマシカナザワク', '大道', 'ダイドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市金沢区みず木町', '14', '14108', '2360036', '神奈川県', 'カナガワケン', '横浜市金沢区', 'ヨコハマシカナザワク', 'みず木町', 'ミズキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市金沢区六浦東', '14', '14108', '2360037', '神奈川県', 'カナガワケン', '横浜市金沢区', 'ヨコハマシカナザワク', '六浦東', 'ムツウラヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市金沢区六浦南', '14', '14108', '2360038', '神奈川県', 'カナガワケン', '横浜市金沢区', 'ヨコハマシカナザワク', '六浦南', 'ムツウラミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市金沢区釜利谷町', '14', '14108', '2360041', '神奈川県', 'カナガワケン', '横浜市金沢区', 'ヨコハマシカナザワク', '釜利谷町', 'カマリヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市金沢区釜利谷東', '14', '14108', '2360042', '神奈川県', 'カナガワケン', '横浜市金沢区', 'ヨコハマシカナザワク', '釜利谷東', 'カマリヤヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市金沢区大川', '14', '14108', '2360043', '神奈川県', 'カナガワケン', '横浜市金沢区', 'ヨコハマシカナザワク', '大川', 'オオカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市金沢区高舟台', '14', '14108', '2360044', '神奈川県', 'カナガワケン', '横浜市金沢区', 'ヨコハマシカナザワク', '高舟台', 'タカフネダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市金沢区釜利谷南', '14', '14108', '2360045', '神奈川県', 'カナガワケン', '横浜市金沢区', 'ヨコハマシカナザワク', '釜利谷南', 'カマリヤミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市金沢区釜利谷西', '14', '14108', '2360046', '神奈川県', 'カナガワケン', '横浜市金沢区', 'ヨコハマシカナザワク', '釜利谷西', 'カマリヤニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市金沢区富岡東', '14', '14108', '2360051', '神奈川県', 'カナガワケン', '横浜市金沢区', 'ヨコハマシカナザワク', '富岡東', 'トミオカヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市金沢区富岡西', '14', '14108', '2360052', '神奈川県', 'カナガワケン', '横浜市金沢区', 'ヨコハマシカナザワク', '富岡西', 'トミオカニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市金沢区能見台通', '14', '14108', '2360053', '神奈川県', 'カナガワケン', '横浜市金沢区', 'ヨコハマシカナザワク', '能見台通', 'ノウケンダイドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市金沢区堀口', '14', '14108', '2360054', '神奈川県', 'カナガワケン', '横浜市金沢区', 'ヨコハマシカナザワク', '堀口', 'ホリグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市金沢区片吹', '14', '14108', '2360055', '神奈川県', 'カナガワケン', '横浜市金沢区', 'ヨコハマシカナザワク', '片吹', 'カタブキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市金沢区能見台森', '14', '14108', '2360056', '神奈川県', 'カナガワケン', '横浜市金沢区', 'ヨコハマシカナザワク', '能見台森', 'ノウケンダイモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市金沢区能見台', '14', '14108', '2360057', '神奈川県', 'カナガワケン', '横浜市金沢区', 'ヨコハマシカナザワク', '能見台', 'ノウケンダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市金沢区能見台東', '14', '14108', '2360058', '神奈川県', 'カナガワケン', '横浜市金沢区', 'ヨコハマシカナザワク', '能見台東', 'ノウケンダイヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市夏島町', '14', '14201', '2370061', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '夏島町', 'ナツシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市浦郷町', '14', '14201', '2370062', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '浦郷町', 'ウラゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市追浜東町', '14', '14201', '2370063', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '追浜東町', 'オッパマヒガシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市追浜町', '14', '14201', '2370064', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '追浜町', 'オッパマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市追浜南町', '14', '14201', '2370065', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '追浜南町', 'オッパマミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市湘南鷹取', '14', '14201', '2370066', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '湘南鷹取', 'ショウナンタカトリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市鷹取', '14', '14201', '2370067', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '鷹取', 'タカトリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市追浜本町', '14', '14201', '2370068', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '追浜本町', 'オッパマホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市田浦港町', '14', '14201', '2370071', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '田浦港町', 'タウラミナトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市長浦町', '14', '14201', '2370072', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '長浦町', 'ナガウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市田浦泉町', '14', '14201', '2370073', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '田浦泉町', 'タウライズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市田浦大作町', '14', '14201', '2370074', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '田浦大作町', 'タウラオオサクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市田浦町', '14', '14201', '2370075', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '田浦町', 'タウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市船越町', '14', '14201', '2370076', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '船越町', 'フナコシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市浜見台', '14', '14201', '2370077', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '浜見台', 'ハマミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市箱崎町', '14', '14201', '2370078', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '箱崎町', 'ハコザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市港が丘', '14', '14201', '2370079', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '港が丘', 'ミナトガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市', '14', '14201', '2380000', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('12952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市泊町', '14', '14201', '2380001', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '泊町', 'トマリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市楠ケ浦町', '14', '14201', '2380002', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '楠ケ浦町', 'クスガウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市稲岡町', '14', '14201', '2380003', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '稲岡町', 'イナオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市小川町', '14', '14201', '2380004', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '小川町', 'オガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市新港町', '14', '14201', '2380005', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '新港町', 'シンコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市日の出町', '14', '14201', '2380006', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '日の出町', 'ヒノデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市若松町', '14', '14201', '2380007', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '若松町', 'ワカマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市大滝町', '14', '14201', '2380008', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '大滝町', 'オオダキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市米が浜通', '14', '14201', '2380011', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '米が浜通', 'ヨネガハマドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市安浦町', '14', '14201', '2380012', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '安浦町', 'ヤスウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市平成町', '14', '14201', '2380013', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '平成町', 'ヘイセイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市三春町', '14', '14201', '2380014', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '三春町', 'ミハルチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市田戸台', '14', '14201', '2380015', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '田戸台', 'タドダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市深田台', '14', '14201', '2380016', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '深田台', 'フカダダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市上町', '14', '14201', '2380017', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '上町', 'ウワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市緑が丘', '14', '14201', '2380018', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '緑が丘', 'ミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市猿島', '14', '14201', '2380019', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '猿島', 'サルシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市富士見町', '14', '14201', '2380021', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '富士見町', 'フジミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市公郷町', '14', '14201', '2380022', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '公郷町', 'クゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市森崎', '14', '14201', '2380023', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '森崎', 'モリサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市大矢部', '14', '14201', '2380024', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '大矢部', 'オオヤベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市衣笠町', '14', '14201', '2380025', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '衣笠町', 'キヌカサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市小矢部', '14', '14201', '2380026', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '小矢部', 'コヤベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市衣笠栄町', '14', '14201', '2380031', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '衣笠栄町', 'キヌカササカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市平作', '14', '14201', '2380032', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '平作', 'ヒラサク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市阿部倉', '14', '14201', '2380033', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '阿部倉', 'アベクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市金谷', '14', '14201', '2380034', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '金谷', 'カネヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市池上', '14', '14201', '2380035', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '池上', 'イケガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市山中町', '14', '14201', '2380036', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '山中町', 'ヤマナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市本町', '14', '14201', '2380041', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市汐入町', '14', '14201', '2380042', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '汐入町', 'シオイリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市坂本町', '14', '14201', '2380043', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '坂本町', 'サカモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市逸見が丘', '14', '14201', '2380044', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '逸見が丘', 'ヘミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市東逸見町', '14', '14201', '2380045', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '東逸見町', 'ヒガシヘミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市西逸見町', '14', '14201', '2380046', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '西逸見町', 'ニシヘミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市吉倉町', '14', '14201', '2380047', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '吉倉町', 'ヨシクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市安針台', '14', '14201', '2380048', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '安針台', 'アンジンダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市不入斗町', '14', '14201', '2380051', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '不入斗町', 'イリヤマズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市佐野町', '14', '14201', '2380052', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '佐野町', 'サノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市望洋台', '14', '14201', '2380053', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '望洋台', 'ボウヨウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市汐見台', '14', '14201', '2380054', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '汐見台', 'シオミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市平和台', '14', '14201', '2380055', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '平和台', 'ヘイワダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市鶴が丘', '14', '14201', '2380056', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '鶴が丘', 'ツルガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県三浦市南下浦町上宮田', '14', '14210', '2380101', '神奈川県', 'カナガワケン', '三浦市', 'ミウラシ', '南下浦町上宮田', 'ミナミシタウラマチカミミヤダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県三浦市南下浦町菊名', '14', '14210', '2380102', '神奈川県', 'カナガワケン', '三浦市', 'ミウラシ', '南下浦町菊名', 'ミナミシタウラマチキクナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県三浦市南下浦町金田', '14', '14210', '2380103', '神奈川県', 'カナガワケン', '三浦市', 'ミウラシ', '南下浦町金田', 'ミナミシタウラマチカネダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県三浦市南下浦町松輪', '14', '14210', '2380104', '神奈川県', 'カナガワケン', '三浦市', 'ミウラシ', '南下浦町松輪', 'ミナミシタウラマチマツワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('12999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県三浦市南下浦町毘沙門', '14', '14210', '2380105', '神奈川県', 'カナガワケン', '三浦市', 'ミウラシ', '南下浦町毘沙門', 'ミナミシタウラマチビシャモン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県三浦市初声町下宮田', '14', '14210', '2380111', '神奈川県', 'カナガワケン', '三浦市', 'ミウラシ', '初声町下宮田', 'ハッセマチシモミヤダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県三浦市初声町三戸', '14', '14210', '2380112', '神奈川県', 'カナガワケン', '三浦市', 'ミウラシ', '初声町三戸', 'ハッセマチミト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県三浦市初声町入江', '14', '14210', '2380113', '神奈川県', 'カナガワケン', '三浦市', 'ミウラシ', '初声町入江', 'ハッセマチイリエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県三浦市初声町和田', '14', '14210', '2380114', '神奈川県', 'カナガワケン', '三浦市', 'ミウラシ', '初声町和田', 'ハッセマチワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県三浦市初声町高円坊', '14', '14210', '2380115', '神奈川県', 'カナガワケン', '三浦市', 'ミウラシ', '初声町高円坊', 'ハッセマチコウエンボウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県三浦市', '14', '14210', '2380200', '神奈川県', 'カナガワケン', '三浦市', 'ミウラシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('13006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県三浦市三崎町六合', '14', '14210', '2380221', '神奈川県', 'カナガワケン', '三浦市', 'ミウラシ', '三崎町六合', 'ミサキマチムツアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県三浦市岬陽町', '14', '14210', '2380222', '神奈川県', 'カナガワケン', '三浦市', 'ミウラシ', '岬陽町', 'コウヨウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県三浦市原町', '14', '14210', '2380223', '神奈川県', 'カナガワケン', '三浦市', 'ミウラシ', '原町', 'ハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県三浦市三崎町諸磯', '14', '14210', '2380224', '神奈川県', 'カナガワケン', '三浦市', 'ミウラシ', '三崎町諸磯', 'ミサキマチモロイソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県三浦市三崎町小網代', '14', '14210', '2380225', '神奈川県', 'カナガワケン', '三浦市', 'ミウラシ', '三崎町小網代', 'ミサキマチコアジロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県三浦市宮川町', '14', '14210', '2380231', '神奈川県', 'カナガワケン', '三浦市', 'ミウラシ', '宮川町', 'ミヤガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県三浦市晴海町', '14', '14210', '2380232', '神奈川県', 'カナガワケン', '三浦市', 'ミウラシ', '晴海町', 'ハルミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県三浦市向ケ崎町', '14', '14210', '2380233', '神奈川県', 'カナガワケン', '三浦市', 'ミウラシ', '向ケ崎町', 'ムコウガサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県三浦市諏訪町', '14', '14210', '2380234', '神奈川県', 'カナガワケン', '三浦市', 'ミウラシ', '諏訪町', 'スワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県三浦市城山町', '14', '14210', '2380235', '神奈川県', 'カナガワケン', '三浦市', 'ミウラシ', '城山町', 'シロヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県三浦市栄町', '14', '14210', '2380236', '神奈川県', 'カナガワケン', '三浦市', 'ミウラシ', '栄町', 'サカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県三浦市三崎町城ケ島', '14', '14210', '2380237', '神奈川県', 'カナガワケン', '三浦市', 'ミウラシ', '三崎町城ケ島', 'ミサキマチジョウガシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県三浦市天神町', '14', '14210', '2380241', '神奈川県', 'カナガワケン', '三浦市', 'ミウラシ', '天神町', 'テンジンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県三浦市東岡町', '14', '14210', '2380242', '神奈川県', 'カナガワケン', '三浦市', 'ミウラシ', '東岡町', 'ヒガシオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県三浦市三崎', '14', '14210', '2380243', '神奈川県', 'カナガワケン', '三浦市', 'ミウラシ', '三崎', 'ミサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県三浦市白石町', '14', '14210', '2380244', '神奈川県', 'カナガワケン', '三浦市', 'ミウラシ', '白石町', 'シライシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県三浦市海外町', '14', '14210', '2380245', '神奈川県', 'カナガワケン', '三浦市', 'ミウラシ', '海外町', 'カイトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県三浦市尾上町', '14', '14210', '2380246', '神奈川県', 'カナガワケン', '三浦市', 'ミウラシ', '尾上町', 'オガミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市太田和', '14', '14201', '2380311', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '太田和', 'オオタワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市山科台', '14', '14201', '2380312', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '山科台', 'ヤマシナダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市武', '14', '14201', '2380313', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '武', 'タケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市須軽谷', '14', '14201', '2380314', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '須軽谷', 'スガルヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市林', '14', '14201', '2380315', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '林', 'ハヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市長井', '14', '14201', '2380316', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '長井', 'ナガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市御幸浜', '14', '14201', '2380317', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '御幸浜', 'ミユキハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市馬堀海岸', '14', '14201', '2390801', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '馬堀海岸', 'マボリカイガン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市馬堀町', '14', '14201', '2390802', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '馬堀町', 'マボリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市桜が丘', '14', '14201', '2390803', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '桜が丘', 'サクラガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市吉井', '14', '14201', '2390804', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '吉井', 'ヨシイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市舟倉', '14', '14201', '2390805', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '舟倉', 'フナグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市池田町', '14', '14201', '2390806', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '池田町', 'イケダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市根岸町', '14', '14201', '2390807', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '根岸町', 'ネギシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市大津町', '14', '14201', '2390808', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '大津町', 'オオツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市走水', '14', '14201', '2390811', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '走水', 'ハシリミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市小原台', '14', '14201', '2390812', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '小原台', 'オバラダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市鴨居', '14', '14201', '2390813', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '鴨居', 'カモイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市二葉', '14', '14201', '2390814', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '二葉', 'フタバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市浦上台', '14', '14201', '2390815', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '浦上台', 'ウラガミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市光風台', '14', '14201', '2390820', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '光風台', 'コウフウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市東浦賀', '14', '14201', '2390821', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '東浦賀', 'ヒガシウラガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市浦賀', '14', '14201', '2390822', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '浦賀', 'ウラガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市浦賀丘', '14', '14201', '2390823', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '浦賀丘', 'ウラガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市西浦賀', '14', '14201', '2390824', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '西浦賀', 'ニシウラガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市南浦賀', '14', '14201', '2390825', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '南浦賀', 'ミナミウラガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市長瀬', '14', '14201', '2390826', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '長瀬', 'ナガセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市久里浜台', '14', '14201', '2390827', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '久里浜台', 'クリハマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市久比里', '14', '14201', '2390828', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '久比里', 'クビリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市若宮台', '14', '14201', '2390829', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '若宮台', 'ワカミヤダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市久里浜', '14', '14201', '2390831', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '久里浜', 'クリハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市神明町', '14', '14201', '2390832', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '神明町', 'シンメイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市ハイランド', '14', '14201', '2390833', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', 'ハイランド', 'ハイランド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市久村', '14', '14201', '2390834', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '久村', 'クムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市佐原', '14', '14201', '2390835', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '佐原', 'サハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市内川', '14', '14201', '2390836', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '内川', 'ウチカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市内川新田', '14', '14201', '2390837', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '内川新田', 'ウチカワシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市野比', '14', '14201', '2390841', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '野比', 'ノビ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市長沢', '14', '14201', '2390842', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '長沢', 'ナガサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市津久井', '14', '14201', '2390843', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '津久井', 'ツクイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市岩戸', '14', '14201', '2390844', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '岩戸', 'イワト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市粟田', '14', '14201', '2390845', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '粟田', 'アワタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市グリーンハイツ', '14', '14201', '2390846', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', 'グリーンハイツ', 'グリーンハイツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市光の丘', '14', '14201', '2390847', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '光の丘', 'ヒカリノオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県北上市', '03', '03206', '0240000', '岩手県', 'イワテケン', '北上市', 'キタカミシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('13094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市保土ケ谷区', '14', '14106', '2400000', '神奈川県', 'カナガワケン', '横浜市保土ケ谷区', 'ヨコハマシホドガヤク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('13095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市保土ケ谷区川辺町', '14', '14106', '2400001', '神奈川県', 'カナガワケン', '横浜市保土ケ谷区', 'ヨコハマシホドガヤク', '川辺町', 'カワベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市保土ケ谷区宮田町', '14', '14106', '2400002', '神奈川県', 'カナガワケン', '横浜市保土ケ谷区', 'ヨコハマシホドガヤク', '宮田町', 'ミヤタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市保土ケ谷区天王町', '14', '14106', '2400003', '神奈川県', 'カナガワケン', '横浜市保土ケ谷区', 'ヨコハマシホドガヤク', '天王町', 'テンノウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市保土ケ谷区岩間町', '14', '14106', '2400004', '神奈川県', 'カナガワケン', '横浜市保土ケ谷区', 'ヨコハマシホドガヤク', '岩間町', 'イワマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市保土ケ谷区神戸町', '14', '14106', '2400005', '神奈川県', 'カナガワケン', '横浜市保土ケ谷区', 'ヨコハマシホドガヤク', '神戸町', 'ゴウドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市保土ケ谷区星川', '14', '14106', '2400006', '神奈川県', 'カナガワケン', '横浜市保土ケ谷区', 'ヨコハマシホドガヤク', '星川', 'ホシカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市保土ケ谷区明神台', '14', '14106', '2400007', '神奈川県', 'カナガワケン', '横浜市保土ケ谷区', 'ヨコハマシホドガヤク', '明神台', 'ミョウジンダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県北上市飯豊', '03', '03206', '0240001', '岩手県', 'イワテケン', '北上市', 'キタカミシ', '飯豊', 'イイトヨ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市保土ケ谷区桜ケ丘', '14', '14106', '2400011', '神奈川県', 'カナガワケン', '横浜市保土ケ谷区', 'ヨコハマシホドガヤク', '桜ケ丘', 'サクラガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市保土ケ谷区月見台', '14', '14106', '2400012', '神奈川県', 'カナガワケン', '横浜市保土ケ谷区', 'ヨコハマシホドガヤク', '月見台', 'ツキミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市保土ケ谷区帷子町', '14', '14106', '2400013', '神奈川県', 'カナガワケン', '横浜市保土ケ谷区', 'ヨコハマシホドガヤク', '帷子町', 'カタビラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市保土ケ谷区霞台', '14', '14106', '2400014', '神奈川県', 'カナガワケン', '横浜市保土ケ谷区', 'ヨコハマシホドガヤク', '霞台', 'カスミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市保土ケ谷区岩崎町', '14', '14106', '2400015', '神奈川県', 'カナガワケン', '横浜市保土ケ谷区', 'ヨコハマシホドガヤク', '岩崎町', 'イワサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市保土ケ谷区初音ケ丘', '14', '14106', '2400016', '神奈川県', 'カナガワケン', '横浜市保土ケ谷区', 'ヨコハマシホドガヤク', '初音ケ丘', 'ハツネガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市保土ケ谷区花見台', '14', '14106', '2400017', '神奈川県', 'カナガワケン', '横浜市保土ケ谷区', 'ヨコハマシホドガヤク', '花見台', 'ハナミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県北上市北工業団地', '03', '03206', '0240002', '岩手県', 'イワテケン', '北上市', 'キタカミシ', '北工業団地', 'キタコウギョウダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市保土ケ谷区保土ケ谷町', '14', '14106', '2400021', '神奈川県', 'カナガワケン', '横浜市保土ケ谷区', 'ヨコハマシホドガヤク', '保土ケ谷町', 'ホドガヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市保土ケ谷区西久保町', '14', '14106', '2400022', '神奈川県', 'カナガワケン', '横浜市保土ケ谷区', 'ヨコハマシホドガヤク', '西久保町', 'ニシクボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市保土ケ谷区岩井町', '14', '14106', '2400023', '神奈川県', 'カナガワケン', '横浜市保土ケ谷区', 'ヨコハマシホドガヤク', '岩井町', 'イワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市保土ケ谷区瀬戸ケ谷町', '14', '14106', '2400024', '神奈川県', 'カナガワケン', '横浜市保土ケ谷区', 'ヨコハマシホドガヤク', '瀬戸ケ谷町', 'セトガヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市保土ケ谷区狩場町', '14', '14106', '2400025', '神奈川県', 'カナガワケン', '横浜市保土ケ谷区', 'ヨコハマシホドガヤク', '狩場町', 'カリバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市保土ケ谷区権太坂', '14', '14106', '2400026', '神奈川県', 'カナガワケン', '横浜市保土ケ谷区', 'ヨコハマシホドガヤク', '権太坂', 'ゴンタザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県北上市成田', '03', '03206', '0240003', '岩手県', 'イワテケン', '北上市', 'キタカミシ', '成田', 'ナリタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市保土ケ谷区藤塚町', '14', '14106', '2400031', '神奈川県', 'カナガワケン', '横浜市保土ケ谷区', 'ヨコハマシホドガヤク', '藤塚町', 'フジヅカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市保土ケ谷区法泉', '14', '14106', '2400032', '神奈川県', 'カナガワケン', '横浜市保土ケ谷区', 'ヨコハマシホドガヤク', '法泉', 'ホウセン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市保土ケ谷区境木本町', '14', '14106', '2400033', '神奈川県', 'カナガワケン', '横浜市保土ケ谷区', 'ヨコハマシホドガヤク', '境木本町', 'サカイギホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市保土ケ谷区境木町', '14', '14106', '2400034', '神奈川県', 'カナガワケン', '横浜市保土ケ谷区', 'ヨコハマシホドガヤク', '境木町', 'サカイギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市保土ケ谷区今井町', '14', '14106', '2400035', '神奈川県', 'カナガワケン', '横浜市保土ケ谷区', 'ヨコハマシホドガヤク', '今井町', 'イマイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市保土ケ谷区新桜ケ丘', '14', '14106', '2400036', '神奈川県', 'カナガワケン', '横浜市保土ケ谷区', 'ヨコハマシホドガヤク', '新桜ケ丘', 'シンサクラガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県北上市村崎野', '03', '03206', '0240004', '岩手県', 'イワテケン', '北上市', 'キタカミシ', '村崎野', 'ムラサキノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市保土ケ谷区東川島町', '14', '14106', '2400041', '神奈川県', 'カナガワケン', '横浜市保土ケ谷区', 'ヨコハマシホドガヤク', '東川島町', 'ヒガシカワシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市保土ケ谷区上星川', '14', '14106', '2400042', '神奈川県', 'カナガワケン', '横浜市保土ケ谷区', 'ヨコハマシホドガヤク', '上星川', 'カミホシカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市保土ケ谷区坂本町', '14', '14106', '2400043', '神奈川県', 'カナガワケン', '横浜市保土ケ谷区', 'ヨコハマシホドガヤク', '坂本町', 'サカモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市保土ケ谷区仏向町', '14', '14106', '2400044', '神奈川県', 'カナガワケン', '横浜市保土ケ谷区', 'ヨコハマシホドガヤク', '仏向町', 'ブッコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市保土ケ谷区川島町', '14', '14106', '2400045', '神奈川県', 'カナガワケン', '横浜市保土ケ谷区', 'ヨコハマシホドガヤク', '川島町', 'カワシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市保土ケ谷区上菅田町', '14', '14106', '2400051', '神奈川県', 'カナガワケン', '横浜市保土ケ谷区', 'ヨコハマシホドガヤク', '上菅田町', 'カミスゲダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市保土ケ谷区西谷町', '14', '14106', '2400052', '神奈川県', 'カナガワケン', '横浜市保土ケ谷区', 'ヨコハマシホドガヤク', '西谷町', 'ニシヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市保土ケ谷区新井町', '14', '14106', '2400053', '神奈川県', 'カナガワケン', '横浜市保土ケ谷区', 'ヨコハマシホドガヤク', '新井町', 'アライチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市保土ケ谷区峰沢町', '14', '14106', '2400061', '神奈川県', 'カナガワケン', '横浜市保土ケ谷区', 'ヨコハマシホドガヤク', '峰沢町', 'ミネザワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市保土ケ谷区岡沢町', '14', '14106', '2400062', '神奈川県', 'カナガワケン', '横浜市保土ケ谷区', 'ヨコハマシホドガヤク', '岡沢町', 'オカザワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市保土ケ谷区鎌谷町', '14', '14106', '2400063', '神奈川県', 'カナガワケン', '横浜市保土ケ谷区', 'ヨコハマシホドガヤク', '鎌谷町', 'カマヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市保土ケ谷区峰岡町', '14', '14106', '2400064', '神奈川県', 'カナガワケン', '横浜市保土ケ谷区', 'ヨコハマシホドガヤク', '峰岡町', 'ミネオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市保土ケ谷区和田', '14', '14106', '2400065', '神奈川県', 'カナガワケン', '横浜市保土ケ谷区', 'ヨコハマシホドガヤク', '和田', 'ワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市保土ケ谷区釜台町', '14', '14106', '2400066', '神奈川県', 'カナガワケン', '横浜市保土ケ谷区', 'ヨコハマシホドガヤク', '釜台町', 'カマダイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市保土ケ谷区常盤台', '14', '14106', '2400067', '神奈川県', 'カナガワケン', '横浜市保土ケ谷区', 'ヨコハマシホドガヤク', '常盤台', 'トキワダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県三浦郡葉山町', '14', '14301', '2400100', '神奈川県', 'カナガワケン', '三浦郡葉山町', 'ミウラグンハヤママチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('13141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市長坂', '14', '14201', '2400101', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '長坂', 'ナガサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市荻野', '14', '14201', '2400102', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '荻野', 'オギノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市佐島', '14', '14201', '2400103', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '佐島', 'サジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市芦名', '14', '14201', '2400104', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '芦名', 'アシナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市秋谷', '14', '14201', '2400105', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '秋谷', 'アキヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市子安', '14', '14201', '2400106', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '子安', 'コヤス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市湘南国際村', '14', '14201', '2400107', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '湘南国際村', 'ショウナンコクサイムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横須賀市佐島の丘', '14', '14201', '2400108', '神奈川県', 'カナガワケン', '横須賀市', 'ヨコスカシ', '佐島の丘', 'サジマノオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県北上市堤ケ丘', '03', '03206', '0240011', '岩手県', 'イワテケン', '北上市', 'キタカミシ', '堤ケ丘', 'ツツミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県三浦郡葉山町一色', '14', '14301', '2400111', '神奈川県', 'カナガワケン', '三浦郡葉山町', 'ミウラグンハヤママチ', '一色', 'イッシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県三浦郡葉山町堀内', '14', '14301', '2400112', '神奈川県', 'カナガワケン', '三浦郡葉山町', 'ミウラグンハヤママチ', '堀内', 'ホリウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県三浦郡葉山町長柄', '14', '14301', '2400113', '神奈川県', 'カナガワケン', '三浦郡葉山町', 'ミウラグンハヤママチ', '長柄', 'ナガエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県三浦郡葉山町木古庭', '14', '14301', '2400114', '神奈川県', 'カナガワケン', '三浦郡葉山町', 'ミウラグンハヤママチ', '木古庭', 'キコバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県三浦郡葉山町上山口', '14', '14301', '2400115', '神奈川県', 'カナガワケン', '三浦郡葉山町', 'ミウラグンハヤママチ', '上山口', 'カミヤマグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県三浦郡葉山町下山口', '14', '14301', '2400116', '神奈川県', 'カナガワケン', '三浦郡葉山町', 'ミウラグンハヤママチ', '下山口', 'シモヤマグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県北上市常盤台', '03', '03206', '0240012', '岩手県', 'イワテケン', '北上市', 'キタカミシ', '常盤台', 'トキワダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県北上市藤沢', '03', '03206', '0240013', '岩手県', 'イワテケン', '北上市', 'キタカミシ', '藤沢', 'フジサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県北上市流通センター', '03', '03206', '0240014', '岩手県', 'イワテケン', '北上市', 'キタカミシ', '流通センター', 'リュウツウセンター', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県北上市上野町', '03', '03206', '0240021', '岩手県', 'イワテケン', '北上市', 'キタカミシ', '上野町', 'ウエノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県北上市黒沢尻', '03', '03206', '0240022', '岩手県', 'イワテケン', '北上市', 'キタカミシ', '黒沢尻', 'クロサワジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県北上市里分', '03', '03206', '0240023', '岩手県', 'イワテケン', '北上市', 'キタカミシ', '里分', 'サトブン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県北上市中野町', '03', '03206', '0240024', '岩手県', 'イワテケン', '北上市', 'キタカミシ', '中野町', 'ナカノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県北上市孫屋敷', '03', '03206', '0240025', '岩手県', 'イワテケン', '北上市', 'キタカミシ', '孫屋敷', 'マゴヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県北上市青柳町', '03', '03206', '0240031', '岩手県', 'イワテケン', '北上市', 'キタカミシ', '青柳町', 'アオヤギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県北上市川岸', '03', '03206', '0240032', '岩手県', 'イワテケン', '北上市', 'キタカミシ', '川岸', 'カワギシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県北上市幸町', '03', '03206', '0240033', '岩手県', 'イワテケン', '北上市', 'キタカミシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県北上市諏訪町', '03', '03206', '0240034', '岩手県', 'イワテケン', '北上市', 'キタカミシ', '諏訪町', 'スワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県北上市花園町', '03', '03206', '0240035', '岩手県', 'イワテケン', '北上市', 'キタカミシ', '花園町', 'ハナゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県北上市稲瀬町', '03', '03206', '0240041', '岩手県', 'イワテケン', '北上市', 'キタカミシ', '稲瀬町', 'イナセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県北上市黒岩', '03', '03206', '0240042', '岩手県', 'イワテケン', '北上市', 'キタカミシ', '黒岩', 'クロイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県北上市立花', '03', '03206', '0240043', '岩手県', 'イワテケン', '北上市', 'キタカミシ', '立花', 'タチバナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県北上市平沢', '03', '03206', '0240044', '岩手県', 'イワテケン', '北上市', 'キタカミシ', '平沢', 'ヒラサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県北上市湯沢', '03', '03206', '0240045', '岩手県', 'イワテケン', '北上市', 'キタカミシ', '湯沢', 'ユザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県北上市相去町', '03', '03206', '0240051', '岩手県', 'イワテケン', '北上市', 'キタカミシ', '相去町', 'アイサリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県北上市大堤北', '03', '03206', '0240052', '岩手県', 'イワテケン', '北上市', 'キタカミシ', '大堤北', 'オオツツミキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県北上市大堤西', '03', '03206', '0240053', '岩手県', 'イワテケン', '北上市', 'キタカミシ', '大堤西', 'オオツツミニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県北上市大堤東', '03', '03206', '0240054', '岩手県', 'イワテケン', '北上市', 'キタカミシ', '大堤東', 'オオツツミヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県北上市大堤南', '03', '03206', '0240055', '岩手県', 'イワテケン', '北上市', 'キタカミシ', '大堤南', 'オオツツミミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県北上市鬼柳町', '03', '03206', '0240056', '岩手県', 'イワテケン', '北上市', 'キタカミシ', '鬼柳町', 'オニヤナギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県北上市上鬼柳', '03', '03206', '0240057', '岩手県', 'イワテケン', '北上市', 'キタカミシ', '上鬼柳', 'カミオニヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県北上市下鬼柳', '03', '03206', '0240058', '岩手県', 'イワテケン', '北上市', 'キタカミシ', '下鬼柳', 'シモオニヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県北上市大通り', '03', '03206', '0240061', '岩手県', 'イワテケン', '北上市', 'キタカミシ', '大通り', 'オオドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県北上市鍛冶町', '03', '03206', '0240062', '岩手県', 'イワテケン', '北上市', 'キタカミシ', '鍛冶町', 'カジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県北上市九年橋', '03', '03206', '0240063', '岩手県', 'イワテケン', '北上市', 'キタカミシ', '九年橋', 'クネンバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県北上市若宮町', '03', '03206', '0240064', '岩手県', 'イワテケン', '北上市', 'キタカミシ', '若宮町', 'ワカミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県北上市上江釣子', '03', '03206', '0240071', '岩手県', 'イワテケン', '北上市', 'キタカミシ', '上江釣子', 'カミエヅリコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県北上市北鬼柳', '03', '03206', '0240072', '岩手県', 'イワテケン', '北上市', 'キタカミシ', '北鬼柳', 'キタオニヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県北上市下江釣子', '03', '03206', '0240073', '岩手県', 'イワテケン', '北上市', 'キタカミシ', '下江釣子', 'シモエヅリコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県北上市滑田', '03', '03206', '0240074', '岩手県', 'イワテケン', '北上市', 'キタカミシ', '滑田', 'ナメシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県北上市新平', '03', '03206', '0240075', '岩手県', 'イワテケン', '北上市', 'キタカミシ', '新平', 'ニツペイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県北上市鳩岡崎', '03', '03206', '0240076', '岩手県', 'イワテケン', '北上市', 'キタカミシ', '鳩岡崎', 'ハトオカザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県北上市有田町', '03', '03206', '0240081', '岩手県', 'イワテケン', '北上市', 'キタカミシ', '有田町', 'アリタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県北上市町分', '03', '03206', '0240082', '岩手県', 'イワテケン', '北上市', 'キタカミシ', '町分', 'マチブン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県北上市柳原町', '03', '03206', '0240083', '岩手県', 'イワテケン', '北上市', 'キタカミシ', '柳原町', 'ヤナギハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県北上市さくら通り', '03', '03206', '0240084', '岩手県', 'イワテケン', '北上市', 'キタカミシ', 'さくら通り', 'サクラドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県北上市大曲町', '03', '03206', '0240091', '岩手県', 'イワテケン', '北上市', 'キタカミシ', '大曲町', 'オオマガリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県北上市新穀町', '03', '03206', '0240092', '岩手県', 'イワテケン', '北上市', 'キタカミシ', '新穀町', 'シンコクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県北上市本石町', '03', '03206', '0240093', '岩手県', 'イワテケン', '北上市', 'キタカミシ', '本石町', 'ホンゴクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県北上市本通り', '03', '03206', '0240094', '岩手県', 'イワテケン', '北上市', 'キタカミシ', '本通り', 'ホンドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県北上市芳町', '03', '03206', '0240095', '岩手県', 'イワテケン', '北上市', 'キタカミシ', '芳町', 'ヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県北上市臥牛', '03', '03206', '0240101', '岩手県', 'イワテケン', '北上市', 'キタカミシ', '臥牛', 'フシウシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県北上市北工業団地', '03', '03206', '0240102', '岩手県', 'イワテケン', '北上市', 'キタカミシ', '北工業団地', 'キタコウギョウダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県北上市更木', '03', '03206', '0240103', '岩手県', 'イワテケン', '北上市', 'キタカミシ', '更木', 'サラキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県北上市二子町', '03', '03206', '0240104', '岩手県', 'イワテケン', '北上市', 'キタカミシ', '二子町', 'フタゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県北上市小鳥崎', '03', '03206', '0240105', '岩手県', 'イワテケン', '北上市', 'キタカミシ', '小鳥崎', 'コトリザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県北上市口内町', '03', '03206', '0240211', '岩手県', 'イワテケン', '北上市', 'キタカミシ', '口内町', 'クチナイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県北上市和賀町岩崎', '03', '03206', '0240321', '岩手県', 'イワテケン', '北上市', 'キタカミシ', '和賀町岩崎', 'ワガチョウイワサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県北上市和賀町岩崎新田', '03', '03206', '0240322', '岩手県', 'イワテケン', '北上市', 'キタカミシ', '和賀町岩崎新田', 'ワガチョウイワサキシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県北上市和賀町煤孫', '03', '03206', '0240323', '岩手県', 'イワテケン', '北上市', 'キタカミシ', '和賀町煤孫', 'ワガチョウススマゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県北上市和賀町山口', '03', '03206', '0240324', '岩手県', 'イワテケン', '北上市', 'キタカミシ', '和賀町山口', 'ワガチョウヤマグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県北上市和賀町岩沢', '03', '03206', '0240325', '岩手県', 'イワテケン', '北上市', 'キタカミシ', '和賀町岩沢', 'ワガチョウイワサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県北上市和賀町仙人', '03', '03206', '0240326', '岩手県', 'イワテケン', '北上市', 'キタカミシ', '和賀町仙人', 'ワガチョウセンニン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県北上市和賀町横川目', '03', '03206', '0240331', '岩手県', 'イワテケン', '北上市', 'キタカミシ', '和賀町横川目', 'ワガチョウヨコカワメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県北上市和賀町竪川目', '03', '03206', '0240332', '岩手県', 'イワテケン', '北上市', 'キタカミシ', '和賀町竪川目', 'ワガチョウタテカワメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県北上市和賀町長沼', '03', '03206', '0240333', '岩手県', 'イワテケン', '北上市', 'キタカミシ', '和賀町長沼', 'ワガチョウナガヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県北上市和賀町藤根', '03', '03206', '0240334', '岩手県', 'イワテケン', '北上市', 'キタカミシ', '和賀町藤根', 'ワガチョウフジネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県北上市和賀町後藤', '03', '03206', '0240335', '岩手県', 'イワテケン', '北上市', 'キタカミシ', '和賀町後藤', 'ワガチョウゴトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県和賀郡西和賀町杉名畑44地割', '03', '03366', '0240341', '岩手県', 'イワテケン', '和賀郡西和賀町', 'ワガグンニシワガマチ', '杉名畑', 'スギナハタ', null, null, '44地割', '44チワリ');
INSERT INTO `ms_addresses` VALUES ('13236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市旭区', '14', '14112', '2410000', '神奈川県', 'カナガワケン', '横浜市旭区', 'ヨコハマシアサヒク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('13237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市旭区上白根町', '14', '14112', '2410001', '神奈川県', 'カナガワケン', '横浜市旭区', 'ヨコハマシアサヒク', '上白根町', 'カミシラネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市旭区上白根', '14', '14112', '2410002', '神奈川県', 'カナガワケン', '横浜市旭区', 'ヨコハマシアサヒク', '上白根', 'カミシラネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市旭区白根町', '14', '14112', '2410003', '神奈川県', 'カナガワケン', '横浜市旭区', 'ヨコハマシアサヒク', '白根町', 'シラネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市旭区中白根', '14', '14112', '2410004', '神奈川県', 'カナガワケン', '横浜市旭区', 'ヨコハマシアサヒク', '中白根', 'ナカシラネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市旭区白根', '14', '14112', '2410005', '神奈川県', 'カナガワケン', '横浜市旭区', 'ヨコハマシアサヒク', '白根', 'シラネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市旭区川島町', '14', '14112', '2410011', '神奈川県', 'カナガワケン', '横浜市旭区', 'ヨコハマシアサヒク', '川島町', 'カワシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市旭区西川島町', '14', '14112', '2410012', '神奈川県', 'カナガワケン', '横浜市旭区', 'ヨコハマシアサヒク', '西川島町', 'ニシカワシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市旭区三反田町', '14', '14112', '2410013', '神奈川県', 'カナガワケン', '横浜市旭区', 'ヨコハマシアサヒク', '三反田町', 'サンタンダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市旭区市沢町', '14', '14112', '2410014', '神奈川県', 'カナガワケン', '横浜市旭区', 'ヨコハマシアサヒク', '市沢町', 'イチザワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市旭区小高町', '14', '14112', '2410015', '神奈川県', 'カナガワケン', '横浜市旭区', 'ヨコハマシアサヒク', '小高町', 'オタカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市旭区鶴ケ峰本町', '14', '14112', '2410021', '神奈川県', 'カナガワケン', '横浜市旭区', 'ヨコハマシアサヒク', '鶴ケ峰本町', 'ツルガミネホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市旭区鶴ケ峰', '14', '14112', '2410022', '神奈川県', 'カナガワケン', '横浜市旭区', 'ヨコハマシアサヒク', '鶴ケ峰', 'ツルガミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市旭区本宿町', '14', '14112', '2410023', '神奈川県', 'カナガワケン', '横浜市旭区', 'ヨコハマシアサヒク', '本宿町', 'ホンジュクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市旭区本村町', '14', '14112', '2410024', '神奈川県', 'カナガワケン', '横浜市旭区', 'ヨコハマシアサヒク', '本村町', 'ホンムラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市旭区四季美台', '14', '14112', '2410025', '神奈川県', 'カナガワケン', '横浜市旭区', 'ヨコハマシアサヒク', '四季美台', 'シキミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市旭区今宿西町', '14', '14112', '2410031', '神奈川県', 'カナガワケン', '横浜市旭区', 'ヨコハマシアサヒク', '今宿西町', 'イマジュクニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市旭区今宿東町', '14', '14112', '2410032', '神奈川県', 'カナガワケン', '横浜市旭区', 'ヨコハマシアサヒク', '今宿東町', 'イマジュクヒガシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市旭区今川町', '14', '14112', '2410033', '神奈川県', 'カナガワケン', '横浜市旭区', 'ヨコハマシアサヒク', '今川町', 'イマガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市旭区今宿南町', '14', '14112', '2410034', '神奈川県', 'カナガワケン', '横浜市旭区', 'ヨコハマシアサヒク', '今宿南町', 'イマジュクミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市旭区若葉台', '14', '14112', '2410801', '神奈川県', 'カナガワケン', '横浜市旭区', 'ヨコハマシアサヒク', '若葉台', 'ワカバダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市旭区上川井町', '14', '14112', '2410802', '神奈川県', 'カナガワケン', '横浜市旭区', 'ヨコハマシアサヒク', '上川井町', 'カミカワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市旭区川井本町', '14', '14112', '2410803', '神奈川県', 'カナガワケン', '横浜市旭区', 'ヨコハマシアサヒク', '川井本町', 'カワイホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市旭区川井宿町', '14', '14112', '2410804', '神奈川県', 'カナガワケン', '横浜市旭区', 'ヨコハマシアサヒク', '川井宿町', 'カワイシュクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市旭区都岡町', '14', '14112', '2410805', '神奈川県', 'カナガワケン', '横浜市旭区', 'ヨコハマシアサヒク', '都岡町', 'ツオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市旭区下川井町', '14', '14112', '2410806', '神奈川県', 'カナガワケン', '横浜市旭区', 'ヨコハマシアサヒク', '下川井町', 'シモカワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市旭区矢指町', '14', '14112', '2410811', '神奈川県', 'カナガワケン', '横浜市旭区', 'ヨコハマシアサヒク', '矢指町', 'ヤサシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市旭区金が谷', '14', '14112', '2410812', '神奈川県', 'カナガワケン', '横浜市旭区', 'ヨコハマシアサヒク', '金が谷', 'カネガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市旭区今宿町', '14', '14112', '2410813', '神奈川県', 'カナガワケン', '横浜市旭区', 'ヨコハマシアサヒク', '今宿町', 'イマジュクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市旭区中沢', '14', '14112', '2410814', '神奈川県', 'カナガワケン', '横浜市旭区', 'ヨコハマシアサヒク', '中沢', 'ナカザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市旭区中尾', '14', '14112', '2410815', '神奈川県', 'カナガワケン', '横浜市旭区', 'ヨコハマシアサヒク', '中尾', 'ナカオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市旭区笹野台', '14', '14112', '2410816', '神奈川県', 'カナガワケン', '横浜市旭区', 'ヨコハマシアサヒク', '笹野台', 'ササノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市旭区今宿', '14', '14112', '2410817', '神奈川県', 'カナガワケン', '横浜市旭区', 'ヨコハマシアサヒク', '今宿', 'イマジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市旭区二俣川', '14', '14112', '2410821', '神奈川県', 'カナガワケン', '横浜市旭区', 'ヨコハマシアサヒク', '二俣川', 'フタマタガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市旭区さちが丘', '14', '14112', '2410822', '神奈川県', 'カナガワケン', '横浜市旭区', 'ヨコハマシアサヒク', 'さちが丘', 'サチガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市旭区善部町', '14', '14112', '2410823', '神奈川県', 'カナガワケン', '横浜市旭区', 'ヨコハマシアサヒク', '善部町', 'ゼンブチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市旭区南希望が丘', '14', '14112', '2410824', '神奈川県', 'カナガワケン', '横浜市旭区', 'ヨコハマシアサヒク', '南希望が丘', 'ミナミキボウガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市旭区中希望が丘', '14', '14112', '2410825', '神奈川県', 'カナガワケン', '横浜市旭区', 'ヨコハマシアサヒク', '中希望が丘', 'ナカキボウガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市旭区東希望が丘', '14', '14112', '2410826', '神奈川県', 'カナガワケン', '横浜市旭区', 'ヨコハマシアサヒク', '東希望が丘', 'ヒガシキボウガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市旭区左近山', '14', '14112', '2410831', '神奈川県', 'カナガワケン', '横浜市旭区', 'ヨコハマシアサヒク', '左近山', 'サコンヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市旭区桐が作', '14', '14112', '2410832', '神奈川県', 'カナガワケン', '横浜市旭区', 'ヨコハマシアサヒク', '桐が作', 'キリガサク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市旭区南本宿町', '14', '14112', '2410833', '神奈川県', 'カナガワケン', '横浜市旭区', 'ヨコハマシアサヒク', '南本宿町', 'ミナミホンジュクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市旭区大池町', '14', '14112', '2410834', '神奈川県', 'カナガワケン', '横浜市旭区', 'ヨコハマシアサヒク', '大池町', 'オオイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市旭区柏町', '14', '14112', '2410835', '神奈川県', 'カナガワケン', '横浜市旭区', 'ヨコハマシアサヒク', '柏町', 'カシワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市旭区万騎が原', '14', '14112', '2410836', '神奈川県', 'カナガワケン', '横浜市旭区', 'ヨコハマシアサヒク', '万騎が原', 'マキガハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県大和市', '14', '14213', '2420000', '神奈川県', 'カナガワケン', '大和市', 'ヤマトシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('13284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県大和市下鶴間', '14', '14213', '2420001', '神奈川県', 'カナガワケン', '大和市', 'ヤマトシ', '下鶴間', 'シモツルマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県大和市つきみ野', '14', '14213', '2420002', '神奈川県', 'カナガワケン', '大和市', 'ヤマトシ', 'つきみ野', 'ツキミノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県大和市林間', '14', '14213', '2420003', '神奈川県', 'カナガワケン', '大和市', 'ヤマトシ', '林間', 'リンカン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県大和市鶴間', '14', '14213', '2420004', '神奈川県', 'カナガワケン', '大和市', 'ヤマトシ', '鶴間', 'ツルマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県大和市西鶴間', '14', '14213', '2420005', '神奈川県', 'カナガワケン', '大和市', 'ヤマトシ', '西鶴間', 'ニシツルマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県大和市南林間', '14', '14213', '2420006', '神奈川県', 'カナガワケン', '大和市', 'ヤマトシ', '南林間', 'ミナミリンカン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県大和市中央林間', '14', '14213', '2420007', '神奈川県', 'カナガワケン', '大和市', 'ヤマトシ', '中央林間', 'チュウオウリンカン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県大和市深見', '14', '14213', '2420011', '神奈川県', 'カナガワケン', '大和市', 'ヤマトシ', '深見', 'フカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県大和市深見東', '14', '14213', '2420012', '神奈川県', 'カナガワケン', '大和市', 'ヤマトシ', '深見東', 'フカミヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県大和市深見台', '14', '14213', '2420013', '神奈川県', 'カナガワケン', '大和市', 'ヤマトシ', '深見台', 'フカミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県大和市上和田', '14', '14213', '2420014', '神奈川県', 'カナガワケン', '大和市', 'ヤマトシ', '上和田', 'カミワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県大和市下和田', '14', '14213', '2420015', '神奈川県', 'カナガワケン', '大和市', 'ヤマトシ', '下和田', 'シモワダ', null, null, null, null), ('13296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県大和市大和南', '14', '14213', '2420016', '神奈川県', 'カナガワケン', '大和市', 'ヤマトシ', '大和南', 'ヤマトミナミ', null, null, null, null), ('13297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県大和市大和東', '14', '14213', '2420017', '神奈川県', 'カナガワケン', '大和市', 'ヤマトシ', '大和東', 'ヤマトヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県大和市深見西', '14', '14213', '2420018', '神奈川県', 'カナガワケン', '大和市', 'ヤマトシ', '深見西', 'フカミニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県大和市中央', '14', '14213', '2420021', '神奈川県', 'カナガワケン', '大和市', 'ヤマトシ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県大和市柳橋', '14', '14213', '2420022', '神奈川県', 'カナガワケン', '大和市', 'ヤマトシ', '柳橋', 'ヤナギバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県大和市渋谷', '14', '14213', '2420023', '神奈川県', 'カナガワケン', '大和市', 'ヤマトシ', '渋谷', 'シブヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県大和市福田', '14', '14213', '2420024', '神奈川県', 'カナガワケン', '大和市', 'ヤマトシ', '福田', 'フクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県大和市代官', '14', '14213', '2420025', '神奈川県', 'カナガワケン', '大和市', 'ヤマトシ', '代官', 'ダイカン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県大和市草柳', '14', '14213', '2420026', '神奈川県', 'カナガワケン', '大和市', 'ヤマトシ', '草柳', 'ソウヤギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県大和市下草柳', '14', '14213', '2420027', '神奈川県', 'カナガワケン', '大和市', 'ヤマトシ', '下草柳', 'シモソウヤギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県大和市桜森', '14', '14213', '2420028', '神奈川県', 'カナガワケン', '大和市', 'ヤマトシ', '桜森', 'サクラモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県大和市上草柳', '14', '14213', '2420029', '神奈川県', 'カナガワケン', '大和市', 'ヤマトシ', '上草柳', 'カミソウヤギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県厚木市', '14', '14212', '2430000', '神奈川県', 'カナガワケン', '厚木市', 'アツギシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('13312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県厚木市東町', '14', '14212', '2430001', '神奈川県', 'カナガワケン', '厚木市', 'アツギシ', '東町', 'ヒガシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県厚木市元町', '14', '14212', '2430002', '神奈川県', 'カナガワケン', '厚木市', 'アツギシ', '元町', 'モトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県厚木市寿町', '14', '14212', '2430003', '神奈川県', 'カナガワケン', '厚木市', 'アツギシ', '寿町', 'コトブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県厚木市水引', '14', '14212', '2430004', '神奈川県', 'カナガワケン', '厚木市', 'アツギシ', '水引', 'ミズヒキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県厚木市松枝', '14', '14212', '2430005', '神奈川県', 'カナガワケン', '厚木市', 'アツギシ', '松枝', 'マツエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県厚木市吾妻町', '14', '14212', '2430006', '神奈川県', 'カナガワケン', '厚木市', 'アツギシ', '吾妻町', 'アヅマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県厚木市厚木', '14', '14212', '2430007', '神奈川県', 'カナガワケン', '厚木市', 'アツギシ', '厚木', 'アツギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県厚木市厚木町', '14', '14212', '2430011', '神奈川県', 'カナガワケン', '厚木市', 'アツギシ', '厚木町', 'アツギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県厚木市幸町', '14', '14212', '2430012', '神奈川県', 'カナガワケン', '厚木市', 'アツギシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県厚木市泉町', '14', '14212', '2430013', '神奈川県', 'カナガワケン', '厚木市', 'アツギシ', '泉町', 'イズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県厚木市旭町', '14', '14212', '2430014', '神奈川県', 'カナガワケン', '厚木市', 'アツギシ', '旭町', 'アサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県厚木市南町', '14', '14212', '2430015', '神奈川県', 'カナガワケン', '厚木市', 'アツギシ', '南町', 'ミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県厚木市田村町', '14', '14212', '2430016', '神奈川県', 'カナガワケン', '厚木市', 'アツギシ', '田村町', 'タムラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県厚木市栄町', '14', '14212', '2430017', '神奈川県', 'カナガワケン', '厚木市', 'アツギシ', '栄町', 'サカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県厚木市中町', '14', '14212', '2430018', '神奈川県', 'カナガワケン', '厚木市', 'アツギシ', '中町', 'ナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県厚木市岡田', '14', '14212', '2430021', '神奈川県', 'カナガワケン', '厚木市', 'アツギシ', '岡田', 'オカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県厚木市酒井', '14', '14212', '2430022', '神奈川県', 'カナガワケン', '厚木市', 'アツギシ', '酒井', 'サカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県厚木市戸田', '14', '14212', '2430023', '神奈川県', 'カナガワケン', '厚木市', 'アツギシ', '戸田', 'トダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県厚木市長沼', '14', '14212', '2430024', '神奈川県', 'カナガワケン', '厚木市', 'アツギシ', '長沼', 'ナガヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県厚木市上落合', '14', '14212', '2430025', '神奈川県', 'カナガワケン', '厚木市', 'アツギシ', '上落合', 'カミオチアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県厚木市下津古久', '14', '14212', '2430026', '神奈川県', 'カナガワケン', '厚木市', 'アツギシ', '下津古久', 'シモツコク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県厚木市戸室', '14', '14212', '2430031', '神奈川県', 'カナガワケン', '厚木市', 'アツギシ', '戸室', 'トムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県厚木市恩名', '14', '14212', '2430032', '神奈川県', 'カナガワケン', '厚木市', 'アツギシ', '恩名', 'オンナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県厚木市温水', '14', '14212', '2430033', '神奈川県', 'カナガワケン', '厚木市', 'アツギシ', '温水', 'ヌルミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県厚木市船子', '14', '14212', '2430034', '神奈川県', 'カナガワケン', '厚木市', 'アツギシ', '船子', 'フナコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県厚木市愛甲', '14', '14212', '2430035', '神奈川県', 'カナガワケン', '厚木市', 'アツギシ', '愛甲', 'アイコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県厚木市長谷', '14', '14212', '2430036', '神奈川県', 'カナガワケン', '厚木市', 'アツギシ', '長谷', 'ハセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県厚木市毛利台', '14', '14212', '2430037', '神奈川県', 'カナガワケン', '厚木市', 'アツギシ', '毛利台', 'モウリダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県厚木市愛名', '14', '14212', '2430038', '神奈川県', 'カナガワケン', '厚木市', 'アツギシ', '愛名', 'アイナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県厚木市温水西', '14', '14212', '2430039', '神奈川県', 'カナガワケン', '厚木市', 'アツギシ', '温水西', 'ヌルミズニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県厚木市緑ケ丘', '14', '14212', '2430041', '神奈川県', 'カナガワケン', '厚木市', 'アツギシ', '緑ケ丘', 'ミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県愛甲郡清川村', '14', '14402', '2430100', '神奈川県', 'カナガワケン', '愛甲郡清川村', 'アイコウグンキヨカワムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('13344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県愛甲郡清川村宮ケ瀬', '14', '14402', '2430111', '神奈川県', 'カナガワケン', '愛甲郡清川村', 'アイコウグンキヨカワムラ', '宮ケ瀬', 'ミヤガセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県愛甲郡清川村煤ケ谷', '14', '14402', '2430112', '神奈川県', 'カナガワケン', '愛甲郡清川村', 'アイコウグンキヨカワムラ', '煤ケ谷', 'ススガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県厚木市七沢', '14', '14212', '2430121', '神奈川県', 'カナガワケン', '厚木市', 'アツギシ', '七沢', 'ナナサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県厚木市森の里', '14', '14212', '2430122', '神奈川県', 'カナガワケン', '厚木市', 'アツギシ', '森の里', 'モリノサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県厚木市森の里青山', '14', '14212', '2430123', '神奈川県', 'カナガワケン', '厚木市', 'アツギシ', '森の里青山', 'モリノサトアオヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県厚木市森の里若宮', '14', '14212', '2430124', '神奈川県', 'カナガワケン', '厚木市', 'アツギシ', '森の里若宮', 'モリノサトワカミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県厚木市小野', '14', '14212', '2430125', '神奈川県', 'カナガワケン', '厚木市', 'アツギシ', '小野', 'オノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県厚木市岡津古久', '14', '14212', '2430126', '神奈川県', 'カナガワケン', '厚木市', 'アツギシ', '岡津古久', 'オカツコク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県厚木市上荻野', '14', '14212', '2430201', '神奈川県', 'カナガワケン', '厚木市', 'アツギシ', '上荻野', 'カミオギノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県厚木市中荻野', '14', '14212', '2430202', '神奈川県', 'カナガワケン', '厚木市', 'アツギシ', '中荻野', 'ナカオギノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県厚木市下荻野', '14', '14212', '2430203', '神奈川県', 'カナガワケン', '厚木市', 'アツギシ', '下荻野', 'シモオギノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県厚木市鳶尾', '14', '14212', '2430204', '神奈川県', 'カナガワケン', '厚木市', 'アツギシ', '鳶尾', 'トビオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県厚木市棚沢', '14', '14212', '2430205', '神奈川県', 'カナガワケン', '厚木市', 'アツギシ', '棚沢', 'タナザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県厚木市下川入', '14', '14212', '2430206', '神奈川県', 'カナガワケン', '厚木市', 'アツギシ', '下川入', 'シモカワイリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県厚木市まつかげ台', '14', '14212', '2430207', '神奈川県', 'カナガワケン', '厚木市', 'アツギシ', 'まつかげ台', 'マツカゲダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県厚木市みはる野', '14', '14212', '2430208', '神奈川県', 'カナガワケン', '厚木市', 'アツギシ', 'みはる野', 'ミハルノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県厚木市三田', '14', '14212', '2430211', '神奈川県', 'カナガワケン', '厚木市', 'アツギシ', '三田', 'サンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県厚木市及川', '14', '14212', '2430212', '神奈川県', 'カナガワケン', '厚木市', 'アツギシ', '及川', 'オイガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県厚木市飯山', '14', '14212', '2430213', '神奈川県', 'カナガワケン', '厚木市', 'アツギシ', '飯山', 'イイヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県厚木市下古沢', '14', '14212', '2430214', '神奈川県', 'カナガワケン', '厚木市', 'アツギシ', '下古沢', 'シモフルサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県厚木市上古沢', '14', '14212', '2430215', '神奈川県', 'カナガワケン', '厚木市', 'アツギシ', '上古沢', 'カミフルサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県厚木市宮の里', '14', '14212', '2430216', '神奈川県', 'カナガワケン', '厚木市', 'アツギシ', '宮の里', 'ミヤノサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県厚木市三田南', '14', '14212', '2430217', '神奈川県', 'カナガワケン', '厚木市', 'アツギシ', '三田南', 'サンダミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県愛甲郡愛川町', '14', '14401', '2430300', '神奈川県', 'カナガワケン', '愛甲郡愛川町', 'アイコウグンアイカワマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('13376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県愛甲郡愛川町角田', '14', '14401', '2430301', '神奈川県', 'カナガワケン', '愛甲郡愛川町', 'アイコウグンアイカワマチ', '角田', 'スミダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県愛甲郡愛川町春日台', '14', '14401', '2430302', '神奈川県', 'カナガワケン', '愛甲郡愛川町', 'アイコウグンアイカワマチ', '春日台', 'カスガダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県愛甲郡愛川町中津', '14', '14401', '2430303', '神奈川県', 'カナガワケン', '愛甲郡愛川町', 'アイコウグンアイカワマチ', '中津', 'ナカツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県愛甲郡愛川町棚沢', '14', '14401', '2430304', '神奈川県', 'カナガワケン', '愛甲郡愛川町', 'アイコウグンアイカワマチ', '棚沢', 'タナザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県愛甲郡愛川町八菅山', '14', '14401', '2430305', '神奈川県', 'カナガワケン', '愛甲郡愛川町', 'アイコウグンアイカワマチ', '八菅山', 'ハスゲサン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県愛甲郡愛川町田代', '14', '14401', '2430306', '神奈川県', 'カナガワケン', '愛甲郡愛川町', 'アイコウグンアイカワマチ', '田代', 'タシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県愛甲郡愛川町半原', '14', '14401', '2430307', '神奈川県', 'カナガワケン', '愛甲郡愛川町', 'アイコウグンアイカワマチ', '半原', 'ハンバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県愛甲郡愛川町三増', '14', '14401', '2430308', '神奈川県', 'カナガワケン', '愛甲郡愛川町', 'アイコウグンアイカワマチ', '三増', 'ミマセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県海老名市', '14', '14215', '2430400', '神奈川県', 'カナガワケン', '海老名市', 'エビナシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('13386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県海老名市東柏ケ谷', '14', '14215', '2430401', '神奈川県', 'カナガワケン', '海老名市', 'エビナシ', '東柏ケ谷', 'ヒガシカシワガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県海老名市柏ケ谷', '14', '14215', '2430402', '神奈川県', 'カナガワケン', '海老名市', 'エビナシ', '柏ケ谷', 'カシワガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県海老名市望地', '14', '14215', '2430403', '神奈川県', 'カナガワケン', '海老名市', 'エビナシ', '望地', 'モウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県海老名市勝瀬', '14', '14215', '2430404', '神奈川県', 'カナガワケン', '海老名市', 'エビナシ', '勝瀬', 'カツセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県海老名市国分南', '14', '14215', '2430405', '神奈川県', 'カナガワケン', '海老名市', 'エビナシ', '国分南', 'コクブミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県海老名市国分北', '14', '14215', '2430406', '神奈川県', 'カナガワケン', '海老名市', 'エビナシ', '国分北', 'コクブキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県海老名市杉久保北', '14', '14215', '2430410', '神奈川県', 'カナガワケン', '海老名市', 'エビナシ', '杉久保北', 'スギクボキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県海老名市大谷', '14', '14215', '2430411', '神奈川県', 'カナガワケン', '海老名市', 'エビナシ', '大谷', 'オオヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県海老名市浜田町', '14', '14215', '2430412', '神奈川県', 'カナガワケン', '海老名市', 'エビナシ', '浜田町', 'ハマダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県海老名市国分寺台', '14', '14215', '2430413', '神奈川県', 'カナガワケン', '海老名市', 'エビナシ', '国分寺台', 'コクブンジダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県海老名市杉久保', '14', '14215', '2430414', '神奈川県', 'カナガワケン', '海老名市', 'エビナシ', '杉久保', 'スギクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県海老名市上河内', '14', '14215', '2430415', '神奈川県', 'カナガワケン', '海老名市', 'エビナシ', '上河内', 'カミゴウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県海老名市中河内', '14', '14215', '2430416', '神奈川県', 'カナガワケン', '海老名市', 'エビナシ', '中河内', 'ナカゴウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県海老名市本郷', '14', '14215', '2430417', '神奈川県', 'カナガワケン', '海老名市', 'エビナシ', '本郷', 'ホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県海老名市大谷南', '14', '14215', '2430418', '神奈川県', 'カナガワケン', '海老名市', 'エビナシ', '大谷南', 'オオヤミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県海老名市大谷北', '14', '14215', '2430419', '神奈川県', 'カナガワケン', '海老名市', 'エビナシ', '大谷北', 'オオヤキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県海老名市さつき町', '14', '14215', '2430421', '神奈川県', 'カナガワケン', '海老名市', 'エビナシ', 'さつき町', 'サツキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県海老名市中新田', '14', '14215', '2430422', '神奈川県', 'カナガワケン', '海老名市', 'エビナシ', '中新田', 'ナカシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県海老名市今里', '14', '14215', '2430423', '神奈川県', 'カナガワケン', '海老名市', 'エビナシ', '今里', 'イマザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県海老名市社家', '14', '14215', '2430424', '神奈川県', 'カナガワケン', '海老名市', 'エビナシ', '社家', 'シャケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県海老名市中野', '14', '14215', '2430425', '神奈川県', 'カナガワケン', '海老名市', 'エビナシ', '中野', 'ナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県海老名市門沢橋', '14', '14215', '2430426', '神奈川県', 'カナガワケン', '海老名市', 'エビナシ', '門沢橋', 'カドサワバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県海老名市杉久保南', '14', '14215', '2430427', '神奈川県', 'カナガワケン', '海老名市', 'エビナシ', '杉久保南', 'スギクボミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県海老名市上今泉', '14', '14215', '2430431', '神奈川県', 'カナガワケン', '海老名市', 'エビナシ', '上今泉', 'カミイマイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県海老名市中央', '14', '14215', '2430432', '神奈川県', 'カナガワケン', '海老名市', 'エビナシ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県海老名市河原口', '14', '14215', '2430433', '神奈川県', 'カナガワケン', '海老名市', 'エビナシ', '河原口', 'カワラグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県海老名市上郷', '14', '14215', '2430434', '神奈川県', 'カナガワケン', '海老名市', 'エビナシ', '上郷', 'カミゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県海老名市下今泉', '14', '14215', '2430435', '神奈川県', 'カナガワケン', '海老名市', 'エビナシ', '下今泉', 'シモイマイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県厚木市上依知', '14', '14212', '2430801', '神奈川県', 'カナガワケン', '厚木市', 'アツギシ', '上依知', 'カミエチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県厚木市猿ケ島', '14', '14212', '2430802', '神奈川県', 'カナガワケン', '厚木市', 'アツギシ', '猿ケ島', 'サルガシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県厚木市山際', '14', '14212', '2430803', '神奈川県', 'カナガワケン', '厚木市', 'アツギシ', '山際', 'ヤマギワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県厚木市関口', '14', '14212', '2430804', '神奈川県', 'カナガワケン', '厚木市', 'アツギシ', '関口', 'セキグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県厚木市中依知', '14', '14212', '2430805', '神奈川県', 'カナガワケン', '厚木市', 'アツギシ', '中依知', 'ナカエチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県厚木市下依知', '14', '14212', '2430806', '神奈川県', 'カナガワケン', '厚木市', 'アツギシ', '下依知', 'シモエチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県厚木市金田', '14', '14212', '2430807', '神奈川県', 'カナガワケン', '厚木市', 'アツギシ', '金田', 'カネダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県厚木市妻田', '14', '14212', '2430811', '神奈川県', 'カナガワケン', '厚木市', 'アツギシ', '妻田', 'ツマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県厚木市妻田北', '14', '14212', '2430812', '神奈川県', 'カナガワケン', '厚木市', 'アツギシ', '妻田北', 'ツマダキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県厚木市妻田東', '14', '14212', '2430813', '神奈川県', 'カナガワケン', '厚木市', 'アツギシ', '妻田東', 'ツマダヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県厚木市妻田南', '14', '14212', '2430814', '神奈川県', 'カナガワケン', '厚木市', 'アツギシ', '妻田南', 'ツマダミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県厚木市妻田西', '14', '14212', '2430815', '神奈川県', 'カナガワケン', '厚木市', 'アツギシ', '妻田西', 'ツマダニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県厚木市林', '14', '14212', '2430816', '神奈川県', 'カナガワケン', '厚木市', 'アツギシ', '林', 'ハヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県厚木市王子', '14', '14212', '2430817', '神奈川県', 'カナガワケン', '厚木市', 'アツギシ', '王子', 'オウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市戸塚区', '14', '14110', '2440000', '神奈川県', 'カナガワケン', '横浜市戸塚区', 'ヨコハマシトツカク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('13457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市戸塚区鳥が丘', '14', '14110', '2440001', '神奈川県', 'カナガワケン', '横浜市戸塚区', 'ヨコハマシトツカク', '鳥が丘', 'トリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市戸塚区矢部町', '14', '14110', '2440002', '神奈川県', 'カナガワケン', '横浜市戸塚区', 'ヨコハマシトツカク', '矢部町', 'ヤベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市戸塚区戸塚町', '14', '14110', '2440003', '神奈川県', 'カナガワケン', '横浜市戸塚区', 'ヨコハマシトツカク', '戸塚町', 'トツカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市戸塚区小雀町', '14', '14110', '2440004', '神奈川県', 'カナガワケン', '横浜市戸塚区', 'ヨコハマシトツカク', '小雀町', 'コスズメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市戸塚区品濃町', '14', '14110', '2440801', '神奈川県', 'カナガワケン', '横浜市戸塚区', 'ヨコハマシトツカク', '品濃町', 'シナノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市戸塚区平戸', '14', '14110', '2440802', '神奈川県', 'カナガワケン', '横浜市戸塚区', 'ヨコハマシトツカク', '平戸', 'ヒラド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市戸塚区平戸町', '14', '14110', '2440803', '神奈川県', 'カナガワケン', '横浜市戸塚区', 'ヨコハマシトツカク', '平戸町', 'ヒラドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市戸塚区前田町', '14', '14110', '2440804', '神奈川県', 'カナガワケン', '横浜市戸塚区', 'ヨコハマシトツカク', '前田町', 'マエダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市戸塚区川上町', '14', '14110', '2440805', '神奈川県', 'カナガワケン', '横浜市戸塚区', 'ヨコハマシトツカク', '川上町', 'カワカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市戸塚区上品濃', '14', '14110', '2440806', '神奈川県', 'カナガワケン', '横浜市戸塚区', 'ヨコハマシトツカク', '上品濃', 'カミシナノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市戸塚区上柏尾町', '14', '14110', '2440811', '神奈川県', 'カナガワケン', '横浜市戸塚区', 'ヨコハマシトツカク', '上柏尾町', 'カミカシオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市戸塚区柏尾町', '14', '14110', '2440812', '神奈川県', 'カナガワケン', '横浜市戸塚区', 'ヨコハマシトツカク', '柏尾町', 'カシオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市戸塚区舞岡町', '14', '14110', '2440813', '神奈川県', 'カナガワケン', '横浜市戸塚区', 'ヨコハマシトツカク', '舞岡町', 'マイオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市戸塚区南舞岡', '14', '14110', '2440814', '神奈川県', 'カナガワケン', '横浜市戸塚区', 'ヨコハマシトツカク', '南舞岡', 'ミナミマイオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市戸塚区下倉田町', '14', '14110', '2440815', '神奈川県', 'カナガワケン', '横浜市戸塚区', 'ヨコハマシトツカク', '下倉田町', 'シモクラタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市戸塚区上倉田町', '14', '14110', '2440816', '神奈川県', 'カナガワケン', '横浜市戸塚区', 'ヨコハマシトツカク', '上倉田町', 'カミクラタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市戸塚区吉田町', '14', '14110', '2440817', '神奈川県', 'カナガワケン', '横浜市戸塚区', 'ヨコハマシトツカク', '吉田町', 'ヨシダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市栄区長沼町', '14', '14115', '2440841', '神奈川県', 'カナガワケン', '横浜市栄区', 'ヨコハマシサカエク', '長沼町', 'ナガヌマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市栄区飯島町', '14', '14115', '2440842', '神奈川県', 'カナガワケン', '横浜市栄区', 'ヨコハマシサカエク', '飯島町', 'イイジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市栄区長尾台町', '14', '14115', '2440843', '神奈川県', 'カナガワケン', '横浜市栄区', 'ヨコハマシサカエク', '長尾台町', 'ナガオダイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市栄区田谷町', '14', '14115', '2440844', '神奈川県', 'カナガワケン', '横浜市栄区', 'ヨコハマシサカエク', '田谷町', 'タヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市栄区金井町', '14', '14115', '2440845', '神奈川県', 'カナガワケン', '横浜市栄区', 'ヨコハマシサカエク', '金井町', 'カナイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市泉区', '14', '14116', '2450000', '神奈川県', 'カナガワケン', '横浜市泉区', 'ヨコハマシイズミク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('13499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市泉区池の谷', '14', '14116', '2450001', '神奈川県', 'カナガワケン', '横浜市泉区', 'ヨコハマシイズミク', '池の谷', 'イケノタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市泉区緑園', '14', '14116', '2450002', '神奈川県', 'カナガワケン', '横浜市泉区', 'ヨコハマシイズミク', '緑園', 'リョクエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市泉区岡津町', '14', '14116', '2450003', '神奈川県', 'カナガワケン', '横浜市泉区', 'ヨコハマシイズミク', '岡津町', 'オカヅチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市泉区領家', '14', '14116', '2450004', '神奈川県', 'カナガワケン', '横浜市泉区', 'ヨコハマシイズミク', '領家', 'リョウケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市泉区白百合', '14', '14116', '2450005', '神奈川県', 'カナガワケン', '横浜市泉区', 'ヨコハマシイズミク', '白百合', 'シラユリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市泉区西が岡', '14', '14116', '2450006', '神奈川県', 'カナガワケン', '横浜市泉区', 'ヨコハマシイズミク', '西が岡', 'ニシガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市泉区桂坂', '14', '14116', '2450007', '神奈川県', 'カナガワケン', '横浜市泉区', 'ヨコハマシイズミク', '桂坂', 'カツラザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市泉区弥生台', '14', '14116', '2450008', '神奈川県', 'カナガワケン', '横浜市泉区', 'ヨコハマシイズミク', '弥生台', 'ヤヨイダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市泉区新橋町', '14', '14116', '2450009', '神奈川県', 'カナガワケン', '横浜市泉区', 'ヨコハマシイズミク', '新橋町', 'シンバシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市泉区中田町', '14', '14116', '2450011', '神奈川県', 'カナガワケン', '横浜市泉区', 'ヨコハマシイズミク', '中田町', 'ナカタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市泉区中田北', '14', '14116', '2450012', '神奈川県', 'カナガワケン', '横浜市泉区', 'ヨコハマシイズミク', '中田北', 'ナカタキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市泉区中田東', '14', '14116', '2450013', '神奈川県', 'カナガワケン', '横浜市泉区', 'ヨコハマシイズミク', '中田東', 'ナカタヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市泉区中田南', '14', '14116', '2450014', '神奈川県', 'カナガワケン', '横浜市泉区', 'ヨコハマシイズミク', '中田南', 'ナカタミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市泉区中田西', '14', '14116', '2450015', '神奈川県', 'カナガワケン', '横浜市泉区', 'ヨコハマシイズミク', '中田西', 'ナカタニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市泉区和泉町', '14', '14116', '2450016', '神奈川県', 'カナガワケン', '横浜市泉区', 'ヨコハマシイズミク', '和泉町', 'イズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市泉区下飯田町', '14', '14116', '2450017', '神奈川県', 'カナガワケン', '横浜市泉区', 'ヨコハマシイズミク', '下飯田町', 'シモイイダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市泉区上飯田町', '14', '14116', '2450018', '神奈川県', 'カナガワケン', '横浜市泉区', 'ヨコハマシイズミク', '上飯田町', 'カミイイダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市戸塚区名瀬町', '14', '14110', '2450051', '神奈川県', 'カナガワケン', '横浜市戸塚区', 'ヨコハマシトツカク', '名瀬町', 'ナセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市戸塚区秋葉町', '14', '14110', '2450052', '神奈川県', 'カナガワケン', '横浜市戸塚区', 'ヨコハマシトツカク', '秋葉町', 'アキバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市戸塚区上矢部町', '14', '14110', '2450053', '神奈川県', 'カナガワケン', '横浜市戸塚区', 'ヨコハマシトツカク', '上矢部町', 'カミヤベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市戸塚区汲沢', '14', '14110', '2450061', '神奈川県', 'カナガワケン', '横浜市戸塚区', 'ヨコハマシトツカク', '汲沢', 'グミザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市戸塚区汲沢町', '14', '14110', '2450062', '神奈川県', 'カナガワケン', '横浜市戸塚区', 'ヨコハマシトツカク', '汲沢町', 'グミザワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市戸塚区原宿', '14', '14110', '2450063', '神奈川県', 'カナガワケン', '横浜市戸塚区', 'ヨコハマシトツカク', '原宿', 'ハラジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市戸塚区影取町', '14', '14110', '2450064', '神奈川県', 'カナガワケン', '横浜市戸塚区', 'ヨコハマシトツカク', '影取町', 'カゲトリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市戸塚区東俣野町', '14', '14110', '2450065', '神奈川県', 'カナガワケン', '横浜市戸塚区', 'ヨコハマシトツカク', '東俣野町', 'ヒガシマタノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市戸塚区俣野町', '14', '14110', '2450066', '神奈川県', 'カナガワケン', '横浜市戸塚区', 'ヨコハマシトツカク', '俣野町', 'マタノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市戸塚区深谷町', '14', '14110', '2450067', '神奈川県', 'カナガワケン', '横浜市戸塚区', 'ヨコハマシトツカク', '深谷町', 'フカヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市瀬谷区', '14', '14114', '2460000', '神奈川県', 'カナガワケン', '横浜市瀬谷区', 'ヨコハマシセヤク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('13539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市瀬谷区卸本町', '14', '14114', '2460001', '神奈川県', 'カナガワケン', '横浜市瀬谷区', 'ヨコハマシセヤク', '卸本町', 'オロシホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市瀬谷区北町', '14', '14114', '2460002', '神奈川県', 'カナガワケン', '横浜市瀬谷区', 'ヨコハマシセヤク', '北町', 'キタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市瀬谷区瀬谷町', '14', '14114', '2460003', '神奈川県', 'カナガワケン', '横浜市瀬谷区', 'ヨコハマシセヤク', '瀬谷町', 'セヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市瀬谷区中屋敷', '14', '14114', '2460004', '神奈川県', 'カナガワケン', '横浜市瀬谷区', 'ヨコハマシセヤク', '中屋敷', 'ナカヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市瀬谷区竹村町', '14', '14114', '2460005', '神奈川県', 'カナガワケン', '横浜市瀬谷区', 'ヨコハマシセヤク', '竹村町', 'タケムラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市瀬谷区上瀬谷町', '14', '14114', '2460006', '神奈川県', 'カナガワケン', '横浜市瀬谷区', 'ヨコハマシセヤク', '上瀬谷町', 'カミセヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市瀬谷区目黒町', '14', '14114', '2460007', '神奈川県', 'カナガワケン', '横浜市瀬谷区', 'ヨコハマシセヤク', '目黒町', 'メグロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市瀬谷区五貫目町', '14', '14114', '2460008', '神奈川県', 'カナガワケン', '横浜市瀬谷区', 'ヨコハマシセヤク', '五貫目町', 'ゴカンメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市瀬谷区東野台', '14', '14114', '2460011', '神奈川県', 'カナガワケン', '横浜市瀬谷区', 'ヨコハマシセヤク', '東野台', 'アズマノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市瀬谷区東野', '14', '14114', '2460012', '神奈川県', 'カナガワケン', '横浜市瀬谷区', 'ヨコハマシセヤク', '東野', 'アズマノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市瀬谷区相沢', '14', '14114', '2460013', '神奈川県', 'カナガワケン', '横浜市瀬谷区', 'ヨコハマシセヤク', '相沢', 'アイザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市瀬谷区中央', '14', '14114', '2460014', '神奈川県', 'カナガワケン', '横浜市瀬谷区', 'ヨコハマシセヤク', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市瀬谷区本郷', '14', '14114', '2460015', '神奈川県', 'カナガワケン', '横浜市瀬谷区', 'ヨコハマシセヤク', '本郷', 'ホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市瀬谷区二ツ橋町', '14', '14114', '2460021', '神奈川県', 'カナガワケン', '横浜市瀬谷区', 'ヨコハマシセヤク', '二ツ橋町', 'フタツバシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市瀬谷区三ツ境', '14', '14114', '2460022', '神奈川県', 'カナガワケン', '横浜市瀬谷区', 'ヨコハマシセヤク', '三ツ境', 'ミツキョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市瀬谷区阿久和東', '14', '14114', '2460023', '神奈川県', 'カナガワケン', '横浜市瀬谷区', 'ヨコハマシセヤク', '阿久和東', 'アクワヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市瀬谷区阿久和西', '14', '14114', '2460025', '神奈川県', 'カナガワケン', '横浜市瀬谷区', 'ヨコハマシセヤク', '阿久和西', 'アクワニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市瀬谷区阿久和南', '14', '14114', '2460026', '神奈川県', 'カナガワケン', '横浜市瀬谷区', 'ヨコハマシセヤク', '阿久和南', 'アクワミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市瀬谷区瀬谷', '14', '14114', '2460031', '神奈川県', 'カナガワケン', '横浜市瀬谷区', 'ヨコハマシセヤク', '瀬谷', 'セヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市瀬谷区南台', '14', '14114', '2460032', '神奈川県', 'カナガワケン', '横浜市瀬谷区', 'ヨコハマシセヤク', '南台', 'ミナミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市瀬谷区南瀬谷', '14', '14114', '2460034', '神奈川県', 'カナガワケン', '横浜市瀬谷区', 'ヨコハマシセヤク', '南瀬谷', 'ミナミセヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市瀬谷区下瀬谷', '14', '14114', '2460035', '神奈川県', 'カナガワケン', '横浜市瀬谷区', 'ヨコハマシセヤク', '下瀬谷', 'シモセヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市瀬谷区北新', '14', '14114', '2460036', '神奈川県', 'カナガワケン', '横浜市瀬谷区', 'ヨコハマシセヤク', '北新', 'キタシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市瀬谷区橋戸', '14', '14114', '2460037', '神奈川県', 'カナガワケン', '横浜市瀬谷区', 'ヨコハマシセヤク', '橋戸', 'ハシド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市瀬谷区宮沢', '14', '14114', '2460038', '神奈川県', 'カナガワケン', '横浜市瀬谷区', 'ヨコハマシセヤク', '宮沢', 'ミヤザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市栄区', '14', '14115', '2470000', '神奈川県', 'カナガワケン', '横浜市栄区', 'ヨコハマシサカエク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('13568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市栄区小菅ケ谷町', '14', '14115', '2470001', '神奈川県', 'カナガワケン', '横浜市栄区', 'ヨコハマシサカエク', '小菅ケ谷町', 'コスガヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市栄区小山台', '14', '14115', '2470002', '神奈川県', 'カナガワケン', '横浜市栄区', 'ヨコハマシサカエク', '小山台', 'コヤマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市栄区鍛冶ケ谷町', '14', '14115', '2470003', '神奈川県', 'カナガワケン', '横浜市栄区', 'ヨコハマシサカエク', '鍛冶ケ谷町', 'カジガヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市栄区柏陽', '14', '14115', '2470004', '神奈川県', 'カナガワケン', '横浜市栄区', 'ヨコハマシサカエク', '柏陽', 'ハクヨウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市栄区桂町', '14', '14115', '2470005', '神奈川県', 'カナガワケン', '横浜市栄区', 'ヨコハマシサカエク', '桂町', 'カツラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市栄区笠間', '14', '14115', '2470006', '神奈川県', 'カナガワケン', '横浜市栄区', 'ヨコハマシサカエク', '笠間', 'カサマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市栄区小菅ケ谷', '14', '14115', '2470007', '神奈川県', 'カナガワケン', '横浜市栄区', 'ヨコハマシサカエク', '小菅ケ谷', 'コスガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市栄区本郷台', '14', '14115', '2470008', '神奈川県', 'カナガワケン', '横浜市栄区', 'ヨコハマシサカエク', '本郷台', 'ホンゴウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市栄区鍛冶ケ谷', '14', '14115', '2470009', '神奈川県', 'カナガワケン', '横浜市栄区', 'ヨコハマシサカエク', '鍛冶ケ谷', 'カジガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市栄区元大橋', '14', '14115', '2470011', '神奈川県', 'カナガワケン', '横浜市栄区', 'ヨコハマシサカエク', '元大橋', 'モトオオハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市栄区若竹町', '14', '14115', '2470012', '神奈川県', 'カナガワケン', '横浜市栄区', 'ヨコハマシサカエク', '若竹町', 'ワカタケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市栄区上郷町', '14', '14115', '2470013', '神奈川県', 'カナガワケン', '横浜市栄区', 'ヨコハマシサカエク', '上郷町', 'カミゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市栄区公田町', '14', '14115', '2470014', '神奈川県', 'カナガワケン', '横浜市栄区', 'ヨコハマシサカエク', '公田町', 'クデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市栄区中野町', '14', '14115', '2470015', '神奈川県', 'カナガワケン', '横浜市栄区', 'ヨコハマシサカエク', '中野町', 'ナカノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市栄区東上郷町', '14', '14115', '2470021', '神奈川県', 'カナガワケン', '横浜市栄区', 'ヨコハマシサカエク', '東上郷町', 'ヒガシカミゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市栄区庄戸', '14', '14115', '2470022', '神奈川県', 'カナガワケン', '横浜市栄区', 'ヨコハマシサカエク', '庄戸', 'ショウド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市栄区長倉町', '14', '14115', '2470023', '神奈川県', 'カナガワケン', '横浜市栄区', 'ヨコハマシサカエク', '長倉町', 'ナガクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市栄区野七里', '14', '14115', '2470024', '神奈川県', 'カナガワケン', '横浜市栄区', 'ヨコハマシサカエク', '野七里', 'ノシチリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市栄区上之町', '14', '14115', '2470025', '神奈川県', 'カナガワケン', '横浜市栄区', 'ヨコハマシサカエク', '上之町', 'カミノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市栄区犬山町', '14', '14115', '2470026', '神奈川県', 'カナガワケン', '横浜市栄区', 'ヨコハマシサカエク', '犬山町', 'イノヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市栄区尾月', '14', '14115', '2470027', '神奈川県', 'カナガワケン', '横浜市栄区', 'ヨコハマシサカエク', '尾月', 'オヅキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市栄区亀井町', '14', '14115', '2470028', '神奈川県', 'カナガワケン', '横浜市栄区', 'ヨコハマシサカエク', '亀井町', 'カメイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市栄区桂台北', '14', '14115', '2470031', '神奈川県', 'カナガワケン', '横浜市栄区', 'ヨコハマシサカエク', '桂台北', 'カツラダイキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市栄区桂台東', '14', '14115', '2470032', '神奈川県', 'カナガワケン', '横浜市栄区', 'ヨコハマシサカエク', '桂台東', 'カツラダイヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市栄区桂台南', '14', '14115', '2470033', '神奈川県', 'カナガワケン', '横浜市栄区', 'ヨコハマシサカエク', '桂台南', 'カツラダイミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市栄区桂台中', '14', '14115', '2470034', '神奈川県', 'カナガワケン', '横浜市栄区', 'ヨコハマシサカエク', '桂台中', 'カツラダイナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県横浜市栄区桂台西', '14', '14115', '2470035', '神奈川県', 'カナガワケン', '横浜市栄区', 'ヨコハマシサカエク', '桂台西', 'カツラダイニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県鎌倉市岩瀬', '14', '14204', '2470051', '神奈川県', 'カナガワケン', '鎌倉市', 'カマクラシ', '岩瀬', 'イワセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県鎌倉市今泉', '14', '14204', '2470052', '神奈川県', 'カナガワケン', '鎌倉市', 'カマクラシ', '今泉', 'イマイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県鎌倉市今泉台', '14', '14204', '2470053', '神奈川県', 'カナガワケン', '鎌倉市', 'カマクラシ', '今泉台', 'イマイズミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県鎌倉市高野', '14', '14204', '2470054', '神奈川県', 'カナガワケン', '鎌倉市', 'カマクラシ', '高野', 'タカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県鎌倉市小袋谷', '14', '14204', '2470055', '神奈川県', 'カナガワケン', '鎌倉市', 'カマクラシ', '小袋谷', 'コブクロヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県鎌倉市大船', '14', '14204', '2470056', '神奈川県', 'カナガワケン', '鎌倉市', 'カマクラシ', '大船', 'オオフナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県鎌倉市台', '14', '14204', '2470061', '神奈川県', 'カナガワケン', '鎌倉市', 'カマクラシ', '台', 'ダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県鎌倉市山ノ内', '14', '14204', '2470062', '神奈川県', 'カナガワケン', '鎌倉市', 'カマクラシ', '山ノ内', 'ヤマノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県鎌倉市梶原', '14', '14204', '2470063', '神奈川県', 'カナガワケン', '鎌倉市', 'カマクラシ', '梶原', 'カジワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県鎌倉市寺分', '14', '14204', '2470064', '神奈川県', 'カナガワケン', '鎌倉市', 'カマクラシ', '寺分', 'テラブン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県鎌倉市上町屋', '14', '14204', '2470065', '神奈川県', 'カナガワケン', '鎌倉市', 'カマクラシ', '上町屋', 'カミマチヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県鎌倉市山崎', '14', '14204', '2470066', '神奈川県', 'カナガワケン', '鎌倉市', 'カマクラシ', '山崎', 'ヤマサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県鎌倉市玉縄', '14', '14204', '2470071', '神奈川県', 'カナガワケン', '鎌倉市', 'カマクラシ', '玉縄', 'タマナワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県鎌倉市岡本', '14', '14204', '2470072', '神奈川県', 'カナガワケン', '鎌倉市', 'カマクラシ', '岡本', 'オカモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県鎌倉市植木', '14', '14204', '2470073', '神奈川県', 'カナガワケン', '鎌倉市', 'カマクラシ', '植木', 'ウエキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県鎌倉市城廻', '14', '14204', '2470074', '神奈川県', 'カナガワケン', '鎌倉市', 'カマクラシ', '城廻', 'シロメグリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県鎌倉市関谷', '14', '14204', '2470075', '神奈川県', 'カナガワケン', '鎌倉市', 'カマクラシ', '関谷', 'セキヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県鎌倉市', '14', '14204', '2480000', '神奈川県', 'カナガワケン', '鎌倉市', 'カマクラシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('13619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県鎌倉市十二所', '14', '14204', '2480001', '神奈川県', 'カナガワケン', '鎌倉市', 'カマクラシ', '十二所', 'ジュウニソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県鎌倉市二階堂', '14', '14204', '2480002', '神奈川県', 'カナガワケン', '鎌倉市', 'カマクラシ', '二階堂', 'ニカイドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県鎌倉市浄明寺', '14', '14204', '2480003', '神奈川県', 'カナガワケン', '鎌倉市', 'カマクラシ', '浄明寺', 'ジョウミョウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県鎌倉市西御門', '14', '14204', '2480004', '神奈川県', 'カナガワケン', '鎌倉市', 'カマクラシ', '西御門', 'ニシミカド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県鎌倉市雪ノ下', '14', '14204', '2480005', '神奈川県', 'カナガワケン', '鎌倉市', 'カマクラシ', '雪ノ下', 'ユキノシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県鎌倉市小町', '14', '14204', '2480006', '神奈川県', 'カナガワケン', '鎌倉市', 'カマクラシ', '小町', 'コマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県鎌倉市大町', '14', '14204', '2480007', '神奈川県', 'カナガワケン', '鎌倉市', 'カマクラシ', '大町', 'オオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県鎌倉市扇ガ谷', '14', '14204', '2480011', '神奈川県', 'カナガワケン', '鎌倉市', 'カマクラシ', '扇ガ谷', 'オウギガヤツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県鎌倉市御成町', '14', '14204', '2480012', '神奈川県', 'カナガワケン', '鎌倉市', 'カマクラシ', '御成町', 'オナリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県鎌倉市材木座', '14', '14204', '2480013', '神奈川県', 'カナガワケン', '鎌倉市', 'カマクラシ', '材木座', 'ザイモクザ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県鎌倉市由比ガ浜', '14', '14204', '2480014', '神奈川県', 'カナガワケン', '鎌倉市', 'カマクラシ', '由比ガ浜', 'ユイガハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県鎌倉市笹目町', '14', '14204', '2480015', '神奈川県', 'カナガワケン', '鎌倉市', 'カマクラシ', '笹目町', 'ササメマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県鎌倉市長谷', '14', '14204', '2480016', '神奈川県', 'カナガワケン', '鎌倉市', 'カマクラシ', '長谷', 'ハセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県鎌倉市佐助', '14', '14204', '2480017', '神奈川県', 'カナガワケン', '鎌倉市', 'カマクラシ', '佐助', 'サスケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県鎌倉市坂ノ下', '14', '14204', '2480021', '神奈川県', 'カナガワケン', '鎌倉市', 'カマクラシ', '坂ノ下', 'サカノシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県鎌倉市常盤', '14', '14204', '2480022', '神奈川県', 'カナガワケン', '鎌倉市', 'カマクラシ', '常盤', 'トキワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県鎌倉市極楽寺', '14', '14204', '2480023', '神奈川県', 'カナガワケン', '鎌倉市', 'カマクラシ', '極楽寺', 'ゴクラクジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県鎌倉市稲村ガ崎', '14', '14204', '2480024', '神奈川県', 'カナガワケン', '鎌倉市', 'カマクラシ', '稲村ガ崎', 'イナムラガサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県鎌倉市七里ガ浜東', '14', '14204', '2480025', '神奈川県', 'カナガワケン', '鎌倉市', 'カマクラシ', '七里ガ浜東', 'シチリガハマヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県鎌倉市七里ガ浜', '14', '14204', '2480026', '神奈川県', 'カナガワケン', '鎌倉市', 'カマクラシ', '七里ガ浜', 'シチリガハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県鎌倉市笛田', '14', '14204', '2480027', '神奈川県', 'カナガワケン', '鎌倉市', 'カマクラシ', '笛田', 'フエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県鎌倉市鎌倉山', '14', '14204', '2480031', '神奈川県', 'カナガワケン', '鎌倉市', 'カマクラシ', '鎌倉山', 'カマクラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県鎌倉市津', '14', '14204', '2480032', '神奈川県', 'カナガワケン', '鎌倉市', 'カマクラシ', '津', 'ツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県鎌倉市腰越', '14', '14204', '2480033', '神奈川県', 'カナガワケン', '鎌倉市', 'カマクラシ', '腰越', 'コシゴエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県鎌倉市津西', '14', '14204', '2480034', '神奈川県', 'カナガワケン', '鎌倉市', 'カマクラシ', '津西', 'ツニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県鎌倉市西鎌倉', '14', '14204', '2480035', '神奈川県', 'カナガワケン', '鎌倉市', 'カマクラシ', '西鎌倉', 'ニシカマクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県鎌倉市手広', '14', '14204', '2480036', '神奈川県', 'カナガワケン', '鎌倉市', 'カマクラシ', '手広', 'テビロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県逗子市', '14', '14208', '2490000', '神奈川県', 'カナガワケン', '逗子市', 'ズシシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('13658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県逗子市久木', '14', '14208', '2490001', '神奈川県', 'カナガワケン', '逗子市', 'ズシシ', '久木', 'ヒサギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県逗子市山の根', '14', '14208', '2490002', '神奈川県', 'カナガワケン', '逗子市', 'ズシシ', '山の根', 'ヤマノネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県逗子市池子', '14', '14208', '2490003', '神奈川県', 'カナガワケン', '逗子市', 'ズシシ', '池子', 'イケゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県逗子市沼間', '14', '14208', '2490004', '神奈川県', 'カナガワケン', '逗子市', 'ズシシ', '沼間', 'ヌママ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県逗子市桜山', '14', '14208', '2490005', '神奈川県', 'カナガワケン', '逗子市', 'ズシシ', '桜山', 'サクラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県逗子市逗子', '14', '14208', '2490006', '神奈川県', 'カナガワケン', '逗子市', 'ズシシ', '逗子', 'ズシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県逗子市新宿', '14', '14208', '2490007', '神奈川県', 'カナガワケン', '逗子市', 'ズシシ', '新宿', 'シンジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県逗子市小坪', '14', '14208', '2490008', '神奈川県', 'カナガワケン', '逗子市', 'ズシシ', '小坪', 'コツボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市', '03', '03205', '0250000', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('13669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県小田原市', '14', '14206', '2500000', '神奈川県', 'カナガワケン', '小田原市', 'オダワラシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('13670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県小田原市扇町', '14', '14206', '2500001', '神奈川県', 'カナガワケン', '小田原市', 'オダワラシ', '扇町', 'オウギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県小田原市寿町', '14', '14206', '2500002', '神奈川県', 'カナガワケン', '小田原市', 'オダワラシ', '寿町', 'コトブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県小田原市東町', '14', '14206', '2500003', '神奈川県', 'カナガワケン', '小田原市', 'オダワラシ', '東町', 'ヒガシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県小田原市浜町', '14', '14206', '2500004', '神奈川県', 'カナガワケン', '小田原市', 'オダワラシ', '浜町', 'ハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県小田原市中町', '14', '14206', '2500005', '神奈川県', 'カナガワケン', '小田原市', 'オダワラシ', '中町', 'ナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市天下田', '03', '03205', '0250001', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '天下田', 'テンカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県小田原市栄町', '14', '14206', '2500011', '神奈川県', 'カナガワケン', '小田原市', 'オダワラシ', '栄町', 'サカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県小田原市本町', '14', '14206', '2500012', '神奈川県', 'カナガワケン', '小田原市', 'オダワラシ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県小田原市南町', '14', '14206', '2500013', '神奈川県', 'カナガワケン', '小田原市', 'オダワラシ', '南町', 'ミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県小田原市城内', '14', '14206', '2500014', '神奈川県', 'カナガワケン', '小田原市', 'オダワラシ', '城内', 'ジョウナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市西宮野目', '03', '03205', '0250002', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '西宮野目', 'ニシミヤノメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県小田原市早川', '14', '14206', '2500021', '神奈川県', 'カナガワケン', '小田原市', 'オダワラシ', '早川', 'ハヤカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県小田原市石橋', '14', '14206', '2500022', '神奈川県', 'カナガワケン', '小田原市', 'オダワラシ', '石橋', 'イシバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県小田原市米神', '14', '14206', '2500023', '神奈川県', 'カナガワケン', '小田原市', 'オダワラシ', '米神', 'コメカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県小田原市根府川', '14', '14206', '2500024', '神奈川県', 'カナガワケン', '小田原市', 'オダワラシ', '根府川', 'ネブカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県小田原市江之浦', '14', '14206', '2500025', '神奈川県', 'カナガワケン', '小田原市', 'オダワラシ', '江之浦', 'エノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市東宮野目', '03', '03205', '0250003', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '東宮野目', 'ヒガシミヤノメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県小田原市入生田', '14', '14206', '2500031', '神奈川県', 'カナガワケン', '小田原市', 'オダワラシ', '入生田', 'イリュウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県小田原市風祭', '14', '14206', '2500032', '神奈川県', 'カナガワケン', '小田原市', 'オダワラシ', '風祭', 'カザマツリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県小田原市水之尾', '14', '14206', '2500033', '神奈川県', 'カナガワケン', '小田原市', 'オダワラシ', '水之尾', 'ミズノオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県小田原市板橋', '14', '14206', '2500034', '神奈川県', 'カナガワケン', '小田原市', 'オダワラシ', '板橋', 'イタバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県小田原市南板橋', '14', '14206', '2500035', '神奈川県', 'カナガワケン', '小田原市', 'オダワラシ', '南板橋', 'ミナミイタバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市葛', '03', '03205', '0250004', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '葛', 'クズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県小田原市池上', '14', '14206', '2500041', '神奈川県', 'カナガワケン', '小田原市', 'オダワラシ', '池上', 'イケガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県小田原市荻窪', '14', '14206', '2500042', '神奈川県', 'カナガワケン', '小田原市', 'オダワラシ', '荻窪', 'オギクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県小田原市谷津', '14', '14206', '2500043', '神奈川県', 'カナガワケン', '小田原市', 'オダワラシ', '谷津', 'ヤツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県小田原市緑', '14', '14206', '2500044', '神奈川県', 'カナガワケン', '小田原市', 'オダワラシ', '緑', 'ミドリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県小田原市城山', '14', '14206', '2500045', '神奈川県', 'カナガワケン', '小田原市', 'オダワラシ', '城山', 'シロヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県小田原市十字', '14', '14206', '2500046', '神奈川県', 'カナガワケン', '小田原市', 'オダワラシ', '十字', 'ジュウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市田力', '03', '03205', '0250005', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '田力', 'タチカラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県小田原市北ノ窪', '14', '14206', '2500051', '神奈川県', 'カナガワケン', '小田原市', 'オダワラシ', '北ノ窪', 'キタノクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県小田原市府川', '14', '14206', '2500052', '神奈川県', 'カナガワケン', '小田原市', 'オダワラシ', '府川', 'フカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県小田原市穴部', '14', '14206', '2500053', '神奈川県', 'カナガワケン', '小田原市', 'オダワラシ', '穴部', 'アナベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県小田原市多古', '14', '14206', '2500054', '神奈川県', 'カナガワケン', '小田原市', 'オダワラシ', '多古', 'タコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県小田原市久野', '14', '14206', '2500055', '神奈川県', 'カナガワケン', '小田原市', 'オダワラシ', '久野', 'クノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県小田原市井細田', '14', '14206', '2500056', '神奈川県', 'カナガワケン', '小田原市', 'オダワラシ', '井細田', 'イサイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市下似内', '03', '03205', '0250006', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '下似内', 'シモニタナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市上似内', '03', '03205', '0250007', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '上似内', 'カミニタナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市空港南', '03', '03205', '0250008', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '空港南', 'クウコウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県南足柄市', '14', '14217', '2500100', '神奈川県', 'カナガワケン', '南足柄市', 'ミナミアシガラシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('13710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県南足柄市班目', '14', '14217', '2500101', '神奈川県', 'カナガワケン', '南足柄市', 'ミナミアシガラシ', '班目', 'マダラメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県南足柄市千津島', '14', '14217', '2500102', '神奈川県', 'カナガワケン', '南足柄市', 'ミナミアシガラシ', '千津島', 'センヅシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県南足柄市壗下', '14', '14217', '2500103', '神奈川県', 'カナガワケン', '南足柄市', 'ミナミアシガラシ', '壗下', 'ママシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県南足柄市向田', '14', '14217', '2500104', '神奈川県', 'カナガワケン', '南足柄市', 'ミナミアシガラシ', '向田', 'ムカイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県南足柄市関本', '14', '14217', '2500105', '神奈川県', 'カナガワケン', '南足柄市', 'ミナミアシガラシ', '関本', 'セキモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県南足柄市怒田', '14', '14217', '2500106', '神奈川県', 'カナガワケン', '南足柄市', 'ミナミアシガラシ', '怒田', 'ヌダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県南足柄市小市', '14', '14217', '2500107', '神奈川県', 'カナガワケン', '南足柄市', 'ミナミアシガラシ', '小市', 'コイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市矢沢', '03', '03205', '0250011', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '矢沢', 'ヤサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県南足柄市竹松', '14', '14217', '2500111', '神奈川県', 'カナガワケン', '南足柄市', 'ミナミアシガラシ', '竹松', 'タケマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県南足柄市和田河原', '14', '14217', '2500112', '神奈川県', 'カナガワケン', '南足柄市', 'ミナミアシガラシ', '和田河原', 'ワダガハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県南足柄市岩原', '14', '14217', '2500113', '神奈川県', 'カナガワケン', '南足柄市', 'ミナミアシガラシ', '岩原', 'イワハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県南足柄市北窪', '14', '14217', '2500114', '神奈川県', 'カナガワケン', '南足柄市', 'ミナミアシガラシ', '北窪', 'キタクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県南足柄市沼田', '14', '14217', '2500115', '神奈川県', 'カナガワケン', '南足柄市', 'ミナミアシガラシ', '沼田', 'ヌマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県南足柄市三竹', '14', '14217', '2500116', '神奈川県', 'カナガワケン', '南足柄市', 'ミナミアシガラシ', '三竹', 'ミタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県南足柄市塚原', '14', '14217', '2500117', '神奈川県', 'カナガワケン', '南足柄市', 'ミナミアシガラシ', '塚原', 'ツカハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市胡四王', '03', '03205', '0250012', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '胡四王', 'コシオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県南足柄市広町', '14', '14217', '2500121', '神奈川県', 'カナガワケン', '南足柄市', 'ミナミアシガラシ', '広町', 'ヒロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県南足柄市飯沢', '14', '14217', '2500122', '神奈川県', 'カナガワケン', '南足柄市', 'ミナミアシガラシ', '飯沢', 'イイザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県南足柄市中沼', '14', '14217', '2500123', '神奈川県', 'カナガワケン', '南足柄市', 'ミナミアシガラシ', '中沼', 'ナカヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県南足柄市生駒', '14', '14217', '2500124', '神奈川県', 'カナガワケン', '南足柄市', 'ミナミアシガラシ', '生駒', 'イコマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県南足柄市駒形新宿', '14', '14217', '2500125', '神奈川県', 'カナガワケン', '南足柄市', 'ミナミアシガラシ', '駒形新宿', 'コマガタシンシュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県南足柄市狩野', '14', '14217', '2500126', '神奈川県', 'カナガワケン', '南足柄市', 'ミナミアシガラシ', '狩野', 'カノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県南足柄市大雄町', '14', '14217', '2500127', '神奈川県', 'カナガワケン', '南足柄市', 'ミナミアシガラシ', '大雄町', 'ダイユウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市幸田', '03', '03205', '0250013', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '幸田', 'コウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県南足柄市内山', '14', '14217', '2500131', '神奈川県', 'カナガワケン', '南足柄市', 'ミナミアシガラシ', '内山', 'ウチヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県南足柄市弘西寺', '14', '14217', '2500132', '神奈川県', 'カナガワケン', '南足柄市', 'ミナミアシガラシ', '弘西寺', 'コウサイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県南足柄市福泉', '14', '14217', '2500133', '神奈川県', 'カナガワケン', '南足柄市', 'ミナミアシガラシ', '福泉', 'フクセン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県南足柄市雨坪', '14', '14217', '2500134', '神奈川県', 'カナガワケン', '南足柄市', 'ミナミアシガラシ', '雨坪', 'アマツボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県南足柄市苅野', '14', '14217', '2500135', '神奈川県', 'カナガワケン', '南足柄市', 'ミナミアシガラシ', '苅野', 'カリノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県南足柄市矢倉沢', '14', '14217', '2500136', '神奈川県', 'カナガワケン', '南足柄市', 'ミナミアシガラシ', '矢倉沢', 'ヤグラザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市高松', '03', '03205', '0250014', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '高松', 'タカマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市東十二丁目', '03', '03205', '0250015', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '東十二丁目', 'ヒガシジュウニチョウメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市高木', '03', '03205', '0250016', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '高木', 'タカキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県小田原市曽我大沢', '14', '14206', '2500201', '神奈川県', 'カナガワケン', '小田原市', 'オダワラシ', '曽我大沢', 'ソガオオサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県小田原市上曽我', '14', '14206', '2500202', '神奈川県', 'カナガワケン', '小田原市', 'オダワラシ', '上曽我', 'カミソガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県小田原市曽我岸', '14', '14206', '2500203', '神奈川県', 'カナガワケン', '小田原市', 'オダワラシ', '曽我岸', 'ソガキシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県小田原市曽我谷津', '14', '14206', '2500204', '神奈川県', 'カナガワケン', '小田原市', 'オダワラシ', '曽我谷津', 'ソガヤツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県小田原市曽我別所', '14', '14206', '2500205', '神奈川県', 'カナガワケン', '小田原市', 'オダワラシ', '曽我別所', 'ソガベッショ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県小田原市曽我原', '14', '14206', '2500206', '神奈川県', 'カナガワケン', '小田原市', 'オダワラシ', '曽我原', 'ソガハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県小田原市曽我光海', '14', '14206', '2500207', '神奈川県', 'カナガワケン', '小田原市', 'オダワラシ', '曽我光海', 'ソガコウミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県小田原市下大井', '14', '14206', '2500208', '神奈川県', 'カナガワケン', '小田原市', 'オダワラシ', '下大井', 'シモオオイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市南城', '03', '03205', '0250021', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '南城', 'ナンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県小田原市鬼柳', '14', '14206', '2500211', '神奈川県', 'カナガワケン', '小田原市', 'オダワラシ', '鬼柳', 'オニヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県小田原市西大友', '14', '14206', '2500212', '神奈川県', 'カナガワケン', '小田原市', 'オダワラシ', '西大友', 'ニシオオドモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県小田原市東大友', '14', '14206', '2500213', '神奈川県', 'カナガワケン', '小田原市', 'オダワラシ', '東大友', 'ヒガシオオドモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県小田原市永塚', '14', '14206', '2500214', '神奈川県', 'カナガワケン', '小田原市', 'オダワラシ', '永塚', 'ナガツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県小田原市千代', '14', '14206', '2500215', '神奈川県', 'カナガワケン', '小田原市', 'オダワラシ', '千代', 'チヨ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県小田原市高田', '14', '14206', '2500216', '神奈川県', 'カナガワケン', '小田原市', 'オダワラシ', '高田', 'タカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県小田原市別堀', '14', '14206', '2500217', '神奈川県', 'カナガワケン', '小田原市', 'オダワラシ', '別堀', 'ベッポリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県小田原市延清', '14', '14206', '2500218', '神奈川県', 'カナガワケン', '小田原市', 'オダワラシ', '延清', 'ノブキヨ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市十二丁目', '03', '03205', '0250022', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '十二丁目', 'ジュウニチョウメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市成田', '03', '03205', '0250023', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '成田', 'ナリタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市山の神', '03', '03205', '0250024', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '山の神', 'ヤマノカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市下根子', '03', '03205', '0250025', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '下根子', 'シモネコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市大谷地', '03', '03205', '0250026', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '大谷地', 'オオヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市不動', '03', '03205', '0250031', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '不動', 'フドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県足柄下郡箱根町湯本', '14', '14382', '2500311', '神奈川県', 'カナガワケン', '足柄下郡箱根町', 'アシガラシモグンハコネマチ', '湯本', 'ユモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県足柄下郡箱根町湯本茶屋', '14', '14382', '2500312', '神奈川県', 'カナガワケン', '足柄下郡箱根町', 'アシガラシモグンハコネマチ', '湯本茶屋', 'ユモトチャヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県足柄下郡箱根町須雲川', '14', '14382', '2500313', '神奈川県', 'カナガワケン', '足柄下郡箱根町', 'アシガラシモグンハコネマチ', '須雲川', 'スクモガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県足柄下郡箱根町畑宿', '14', '14382', '2500314', '神奈川県', 'カナガワケン', '足柄下郡箱根町', 'アシガラシモグンハコネマチ', '畑宿', 'ハタジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県足柄下郡箱根町塔之澤', '14', '14382', '2500315', '神奈川県', 'カナガワケン', '足柄下郡箱根町', 'アシガラシモグンハコネマチ', '塔之澤', 'トウノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市上諏訪', '03', '03205', '0250032', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '上諏訪', 'カミスワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市諏訪', '03', '03205', '0250033', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '諏訪', 'スワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市南諏訪町', '03', '03205', '0250034', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '南諏訪町', 'ミナミスワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市実相寺', '03', '03205', '0250035', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '実相寺', 'ジツソウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市中根子', '03', '03205', '0250036', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '中根子', 'ナカネコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市太田', '03', '03205', '0250037', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '太田', 'オオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市不動町', '03', '03205', '0250038', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '不動町', 'フドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市諏訪町', '03', '03205', '0250039', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '諏訪町', 'スワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県足柄下郡箱根町宮城野', '14', '14382', '2500401', '神奈川県', 'カナガワケン', '足柄下郡箱根町', 'アシガラシモグンハコネマチ', '宮城野', 'ミヤギノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県足柄下郡箱根町木賀', '14', '14382', '2500402', '神奈川県', 'カナガワケン', '足柄下郡箱根町', 'アシガラシモグンハコネマチ', '木賀', 'キガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県足柄下郡箱根町底倉', '14', '14382', '2500403', '神奈川県', 'カナガワケン', '足柄下郡箱根町', 'アシガラシモグンハコネマチ', '底倉', 'ソコクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県足柄下郡箱根町宮ノ下', '14', '14382', '2500404', '神奈川県', 'カナガワケン', '足柄下郡箱根町', 'アシガラシモグンハコネマチ', '宮ノ下', 'ミヤノシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県足柄下郡箱根町大平台', '14', '14382', '2500405', '神奈川県', 'カナガワケン', '足柄下郡箱根町', 'アシガラシモグンハコネマチ', '大平台', 'オオヒラダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県足柄下郡箱根町小涌谷', '14', '14382', '2500406', '神奈川県', 'カナガワケン', '足柄下郡箱根町', 'アシガラシモグンハコネマチ', '小涌谷', 'コワクダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県足柄下郡箱根町二ノ平', '14', '14382', '2500407', '神奈川県', 'カナガワケン', '足柄下郡箱根町', 'アシガラシモグンハコネマチ', '二ノ平', 'ニノタイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県足柄下郡箱根町強羅', '14', '14382', '2500408', '神奈川県', 'カナガワケン', '足柄下郡箱根町', 'アシガラシモグンハコネマチ', '強羅', 'ゴウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市膝立', '03', '03205', '0250041', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '膝立', 'ヒザタテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市円万寺', '03', '03205', '0250042', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '円万寺', 'エンマンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市上根子', '03', '03205', '0250043', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '上根子', 'カミネコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市湯口石川原', '03', '03205', '0250044', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '湯口', 'ユグチ', null, null, '石川原', 'イシカワラ');
INSERT INTO `ms_addresses` VALUES ('13801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市湯口田屋', '03', '03205', '0250044', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '湯口', 'ユグチ', null, null, '田屋', 'タヤ');
INSERT INTO `ms_addresses` VALUES ('13802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市湯口二ツ堰', '03', '03205', '0250044', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '湯口', 'ユグチ', null, null, '二ツ堰', 'フタツゼキ');
INSERT INTO `ms_addresses` VALUES ('13803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市湯口的場', '03', '03205', '0250044', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '湯口', 'ユグチ', null, null, '的場', 'マトバ');
INSERT INTO `ms_addresses` VALUES ('13804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市西晴山', '03', '03205', '0250045', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '西晴山', 'ニシハレヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市鍋倉', '03', '03205', '0250046', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '鍋倉', 'ナベクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県足柄下郡箱根町', '14', '14382', '2500500', '神奈川県', 'カナガワケン', '足柄下郡箱根町', 'アシガラシモグンハコネマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('13807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市南新田', '03', '03205', '0250051', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '南新田', 'ミナミシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市野田', '03', '03205', '0250052', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '野田', 'ノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県足柄下郡箱根町箱根', '14', '14382', '2500521', '神奈川県', 'カナガワケン', '足柄下郡箱根町', 'アシガラシモグンハコネマチ', '箱根', 'ハコネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県足柄下郡箱根町元箱根', '14', '14382', '2500522', '神奈川県', 'カナガワケン', '足柄下郡箱根町', 'アシガラシモグンハコネマチ', '元箱根', 'モトハコネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県足柄下郡箱根町芦之湯', '14', '14382', '2500523', '神奈川県', 'カナガワケン', '足柄下郡箱根町', 'アシガラシモグンハコネマチ', '芦之湯', 'アシノユ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市中北万丁目', '03', '03205', '0250053', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '中北万丁目', 'ナカキタマンチョウメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市下北万丁目', '03', '03205', '0250054', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '下北万丁目', 'シモキタマンチョウメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市南万丁目', '03', '03205', '0250055', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '南万丁目', 'ミナミマンチョウメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市上北万丁目', '03', '03205', '0250056', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '上北万丁目', 'カミキタマンチョウメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市新田', '03', '03205', '0250057', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '新田', 'シンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市一本杉', '03', '03205', '0250058', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '一本杉', 'イッポンスギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市本館', '03', '03205', '0250061', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '本館', 'モトダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市上小舟渡', '03', '03205', '0250062', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '上小舟渡', 'カミコブナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市下小舟渡', '03', '03205', '0250063', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '下小舟渡', 'シモコブナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県足柄下郡箱根町仙石原', '14', '14382', '2500631', '神奈川県', 'カナガワケン', '足柄下郡箱根町', 'アシガラシモグンハコネマチ', '仙石原', 'センゴクハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市桜台', '03', '03205', '0250064', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '桜台', 'サクラダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市星が丘', '03', '03205', '0250065', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '星が丘', 'ホシガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市松園町', '03', '03205', '0250066', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '松園町', 'マツゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市浅沢', '03', '03205', '0250067', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '浅沢', 'アサザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市下幅', '03', '03205', '0250068', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '下幅', 'シタハバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市愛宕町', '03', '03205', '0250071', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '愛宕町', 'アタゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市四日町', '03', '03205', '0250072', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '四日町', 'ヨッカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市一日市', '03', '03205', '0250073', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '一日市', 'ヒトイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市坂本町', '03', '03205', '0250074', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '坂本町', 'サカモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市花城町', '03', '03205', '0250075', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '花城町', 'カジョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市城内', '03', '03205', '0250076', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '城内', 'ジョウナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市仲町', '03', '03205', '0250077', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '仲町', 'ナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市吹張町', '03', '03205', '0250078', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '吹張町', 'フツパリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市末広町', '03', '03205', '0250079', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '末広町', 'スエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市里川口町', '03', '03205', '0250081', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '里川口町', 'サトカワグチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市御田屋町', '03', '03205', '0250082', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '御田屋町', 'オタヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市高田', '03', '03205', '0250083', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '高田', 'タカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市桜町', '03', '03205', '0250084', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '桜町', 'サクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市双葉町', '03', '03205', '0250085', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '双葉町', 'フタバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県小田原市曽比', '14', '14206', '2500851', '神奈川県', 'カナガワケン', '小田原市', 'オダワラシ', '曽比', 'ソビ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県小田原市栢山', '14', '14206', '2500852', '神奈川県', 'カナガワケン', '小田原市', 'オダワラシ', '栢山', 'カヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県小田原市堀之内', '14', '14206', '2500853', '神奈川県', 'カナガワケン', '小田原市', 'オダワラシ', '堀之内', 'ホリノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県小田原市飯田岡', '14', '14206', '2500854', '神奈川県', 'カナガワケン', '小田原市', 'オダワラシ', '飯田岡', 'イイダオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県小田原市清水新田', '14', '14206', '2500855', '神奈川県', 'カナガワケン', '小田原市', 'オダワラシ', '清水新田', 'シミズシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県小田原市新屋', '14', '14206', '2500856', '神奈川県', 'カナガワケン', '小田原市', 'オダワラシ', '新屋', 'アラヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県小田原市柳新田', '14', '14206', '2500857', '神奈川県', 'カナガワケン', '小田原市', 'オダワラシ', '柳新田', 'ヤナギシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県小田原市小台', '14', '14206', '2500858', '神奈川県', 'カナガワケン', '小田原市', 'オダワラシ', '小台', 'コダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市鍛治町', '03', '03205', '0250086', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '鍛治町', 'カジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県小田原市桑原', '14', '14206', '2500861', '神奈川県', 'カナガワケン', '小田原市', 'オダワラシ', '桑原', 'クワハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県小田原市成田', '14', '14206', '2500862', '神奈川県', 'カナガワケン', '小田原市', 'オダワラシ', '成田', 'ナルダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県小田原市飯泉', '14', '14206', '2500863', '神奈川県', 'カナガワケン', '小田原市', 'オダワラシ', '飯泉', 'イイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県小田原市穴部新田', '14', '14206', '2500864', '神奈川県', 'カナガワケン', '小田原市', 'オダワラシ', '穴部新田', 'アナベシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県小田原市蓮正寺', '14', '14206', '2500865', '神奈川県', 'カナガワケン', '小田原市', 'オダワラシ', '蓮正寺', 'レンショウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県小田原市中曽根', '14', '14206', '2500866', '神奈川県', 'カナガワケン', '小田原市', 'オダワラシ', '中曽根', 'ナカゾネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市上町', '03', '03205', '0250087', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '上町', 'カミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県小田原市下堀', '14', '14206', '2500871', '神奈川県', 'カナガワケン', '小田原市', 'オダワラシ', '下堀', 'シモボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県小田原市中里', '14', '14206', '2500872', '神奈川県', 'カナガワケン', '小田原市', 'オダワラシ', '中里', 'ナカザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県小田原市矢作', '14', '14206', '2500873', '神奈川県', 'カナガワケン', '小田原市', 'オダワラシ', '矢作', 'ヤハギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県小田原市鴨宮', '14', '14206', '2500874', '神奈川県', 'カナガワケン', '小田原市', 'オダワラシ', '鴨宮', 'カモノミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県小田原市南鴨宮', '14', '14206', '2500875', '神奈川県', 'カナガワケン', '小田原市', 'オダワラシ', '南鴨宮', 'ミナミカモノミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県小田原市中新田', '14', '14206', '2500876', '神奈川県', 'カナガワケン', '小田原市', 'オダワラシ', '中新田', 'ナカシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県小田原市上新田', '14', '14206', '2500877', '神奈川県', 'カナガワケン', '小田原市', 'オダワラシ', '上新田', 'カミシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県小田原市下新田', '14', '14206', '2500878', '神奈川県', 'カナガワケン', '小田原市', 'オダワラシ', '下新田', 'シモシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市東町', '03', '03205', '0250088', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '東町', 'アズマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市豊沢町', '03', '03205', '0250089', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '豊沢町', 'トヨサワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市西大通り', '03', '03205', '0250091', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '西大通り', 'ニシオオドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市大通り', '03', '03205', '0250092', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '大通り', 'オオドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市南川原町', '03', '03205', '0250093', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '南川原町', 'ミナミカワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市桜木町', '03', '03205', '0250094', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '桜木町', 'サクラギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市石神町', '03', '03205', '0250095', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '石神町', 'イシガミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市藤沢町', '03', '03205', '0250096', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '藤沢町', 'フジサワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市若葉町', '03', '03205', '0250097', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '若葉町', 'ワカバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市材木町', '03', '03205', '0250098', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '材木町', 'ザイモクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市轟木', '03', '03205', '0250131', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '轟木', 'トドロキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市北笹間', '03', '03205', '0250132', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '北笹間', 'キタササマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市中笹間', '03', '03205', '0250133', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '中笹間', 'ナカササマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市南笹間', '03', '03205', '0250134', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '南笹間', 'ミナミササマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市栃内', '03', '03205', '0250135', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '栃内', 'トチナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市横志田', '03', '03205', '0250136', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '横志田', 'ヨコシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市尻平川', '03', '03205', '0250137', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '尻平川', 'シリタイラガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市湯口', '03', '03205', '0250244', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '湯口', 'ユグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市豊沢', '03', '03205', '0250251', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '豊沢', 'トヨサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市鉛', '03', '03205', '0250252', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '鉛', 'ナマリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市下シ沢', '03', '03205', '0250253', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '下シ沢', 'クダシザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市北湯口', '03', '03205', '0250301', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '北湯口', 'キタユグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市糠塚', '03', '03205', '0250302', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '糠塚', 'ヌカヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市大畑', '03', '03205', '0250303', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '大畑', 'オオハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市湯本', '03', '03205', '0250304', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '湯本', 'ユモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市台', '03', '03205', '0250305', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '台', 'ダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市卸町', '03', '03205', '0250311', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '卸町', 'オロシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市二枚橋', '03', '03205', '0250312', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '二枚橋', 'ニマイバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市二枚橋町北', '03', '03205', '0250313', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '二枚橋町北', 'ニマイバシマチキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市二枚橋町大通り', '03', '03205', '0250314', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '二枚橋町大通り', 'ニマイバシマチオオドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市二枚橋町南', '03', '03205', '0250315', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '二枚橋町南', 'ニマイバシマチミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市金矢', '03', '03205', '0250321', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '金矢', 'カナヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市狼沢', '03', '03205', '0250322', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '狼沢', 'オオカミザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市椚ノ目', '03', '03205', '0250323', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '椚ノ目', 'クヌギノメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市小瀬川', '03', '03205', '0250324', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '小瀬川', 'コセガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県藤沢市', '14', '14205', '2510000', '神奈川県', 'カナガワケン', '藤沢市', 'フジサワシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('13909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県藤沢市西富', '14', '14205', '2510001', '神奈川県', 'カナガワケン', '藤沢市', 'フジサワシ', '西富', 'ニシトミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県藤沢市大鋸', '14', '14205', '2510002', '神奈川県', 'カナガワケン', '藤沢市', 'フジサワシ', '大鋸', 'ダイギリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県藤沢市柄沢', '14', '14205', '2510003', '神奈川県', 'カナガワケン', '藤沢市', 'フジサワシ', '柄沢', 'カラサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県藤沢市藤が岡', '14', '14205', '2510004', '神奈川県', 'カナガワケン', '藤沢市', 'フジサワシ', '藤が岡', 'フジガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県藤沢市渡内', '14', '14205', '2510011', '神奈川県', 'カナガワケン', '藤沢市', 'フジサワシ', '渡内', 'ワタウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県藤沢市村岡東', '14', '14205', '2510012', '神奈川県', 'カナガワケン', '藤沢市', 'フジサワシ', '村岡東', 'ムラオカヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県藤沢市小塚', '14', '14205', '2510013', '神奈川県', 'カナガワケン', '藤沢市', 'フジサワシ', '小塚', 'コツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県藤沢市宮前', '14', '14205', '2510014', '神奈川県', 'カナガワケン', '藤沢市', 'フジサワシ', '宮前', 'ミヤマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県藤沢市川名', '14', '14205', '2510015', '神奈川県', 'カナガワケン', '藤沢市', 'フジサワシ', '川名', 'カワナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県藤沢市弥勒寺', '14', '14205', '2510016', '神奈川県', 'カナガワケン', '藤沢市', 'フジサワシ', '弥勒寺', 'ミロクジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県藤沢市高谷', '14', '14205', '2510017', '神奈川県', 'カナガワケン', '藤沢市', 'フジサワシ', '高谷', 'タカヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県藤沢市鵠沼神明', '14', '14205', '2510021', '神奈川県', 'カナガワケン', '藤沢市', 'フジサワシ', '鵠沼神明', 'クゲヌマシンメイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県藤沢市鵠沼', '14', '14205', '2510022', '神奈川県', 'カナガワケン', '藤沢市', 'フジサワシ', '鵠沼', 'クゲヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県藤沢市鵠沼花沢町', '14', '14205', '2510023', '神奈川県', 'カナガワケン', '藤沢市', 'フジサワシ', '鵠沼花沢町', 'クゲヌマハナザワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県藤沢市鵠沼橘', '14', '14205', '2510024', '神奈川県', 'カナガワケン', '藤沢市', 'フジサワシ', '鵠沼橘', 'クゲヌマタチバナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県藤沢市鵠沼石上', '14', '14205', '2510025', '神奈川県', 'カナガワケン', '藤沢市', 'フジサワシ', '鵠沼石上', 'クゲヌマイシガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県藤沢市鵠沼東', '14', '14205', '2510026', '神奈川県', 'カナガワケン', '藤沢市', 'フジサワシ', '鵠沼東', 'クゲヌマヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県藤沢市鵠沼桜が岡', '14', '14205', '2510027', '神奈川県', 'カナガワケン', '藤沢市', 'フジサワシ', '鵠沼桜が岡', 'クゲヌマサクラガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県藤沢市本鵠沼', '14', '14205', '2510028', '神奈川県', 'カナガワケン', '藤沢市', 'フジサワシ', '本鵠沼', 'ホンクゲヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県藤沢市鵠沼藤が谷', '14', '14205', '2510031', '神奈川県', 'カナガワケン', '藤沢市', 'フジサワシ', '鵠沼藤が谷', 'クゲヌマフジガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県藤沢市片瀬', '14', '14205', '2510032', '神奈川県', 'カナガワケン', '藤沢市', 'フジサワシ', '片瀬', 'カタセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県藤沢市片瀬山', '14', '14205', '2510033', '神奈川県', 'カナガワケン', '藤沢市', 'フジサワシ', '片瀬山', 'カタセヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県藤沢市片瀬目白山', '14', '14205', '2510034', '神奈川県', 'カナガワケン', '藤沢市', 'フジサワシ', '片瀬目白山', 'カタセメジロヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県藤沢市片瀬海岸', '14', '14205', '2510035', '神奈川県', 'カナガワケン', '藤沢市', 'フジサワシ', '片瀬海岸', 'カタセカイガン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県藤沢市江の島', '14', '14205', '2510036', '神奈川県', 'カナガワケン', '藤沢市', 'フジサワシ', '江の島', 'エノシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県藤沢市鵠沼海岸', '14', '14205', '2510037', '神奈川県', 'カナガワケン', '藤沢市', 'フジサワシ', '鵠沼海岸', 'クゲヌマカイガン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県藤沢市鵠沼松が岡', '14', '14205', '2510038', '神奈川県', 'カナガワケン', '藤沢市', 'フジサワシ', '鵠沼松が岡', 'クゲヌママツガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県藤沢市辻堂神台', '14', '14205', '2510041', '神奈川県', 'カナガワケン', '藤沢市', 'フジサワシ', '辻堂神台', 'ツジドウカンダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県藤沢市辻堂新町', '14', '14205', '2510042', '神奈川県', 'カナガワケン', '藤沢市', 'フジサワシ', '辻堂新町', 'ツジドウシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県藤沢市辻堂元町', '14', '14205', '2510043', '神奈川県', 'カナガワケン', '藤沢市', 'フジサワシ', '辻堂元町', 'ツジドウモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県藤沢市辻堂太平台', '14', '14205', '2510044', '神奈川県', 'カナガワケン', '藤沢市', 'フジサワシ', '辻堂太平台', 'ツジドウタイヘイダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県藤沢市辻堂東海岸', '14', '14205', '2510045', '神奈川県', 'カナガワケン', '藤沢市', 'フジサワシ', '辻堂東海岸', 'ツジドウヒガシカイガン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県藤沢市辻堂西海岸', '14', '14205', '2510046', '神奈川県', 'カナガワケン', '藤沢市', 'フジサワシ', '辻堂西海岸', 'ツジドウニシカイガン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県藤沢市辻堂', '14', '14205', '2510047', '神奈川県', 'カナガワケン', '藤沢市', 'フジサワシ', '辻堂', 'ツジドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県藤沢市白旗', '14', '14205', '2510051', '神奈川県', 'カナガワケン', '藤沢市', 'フジサワシ', '白旗', 'シラハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県藤沢市藤沢', '14', '14205', '2510052', '神奈川県', 'カナガワケン', '藤沢市', 'フジサワシ', '藤沢', 'フジサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県藤沢市本町', '14', '14205', '2510053', '神奈川県', 'カナガワケン', '藤沢市', 'フジサワシ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県藤沢市朝日町', '14', '14205', '2510054', '神奈川県', 'カナガワケン', '藤沢市', 'フジサワシ', '朝日町', 'アサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県藤沢市南藤沢', '14', '14205', '2510055', '神奈川県', 'カナガワケン', '藤沢市', 'フジサワシ', '南藤沢', 'ミナミフジサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県藤沢市羽鳥', '14', '14205', '2510056', '神奈川県', 'カナガワケン', '藤沢市', 'フジサワシ', '羽鳥', 'ハトリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県藤沢市城南', '14', '14205', '2510057', '神奈川県', 'カナガワケン', '藤沢市', 'フジサワシ', '城南', 'ジョウナン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県藤沢市大庭', '14', '14205', '2510861', '神奈川県', 'カナガワケン', '藤沢市', 'フジサワシ', '大庭', 'オオバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県藤沢市稲荷', '14', '14205', '2510862', '神奈川県', 'カナガワケン', '藤沢市', 'フジサワシ', '稲荷', 'イナリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県藤沢市善行', '14', '14205', '2510871', '神奈川県', 'カナガワケン', '藤沢市', 'フジサワシ', '善行', 'ゼンギョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県藤沢市立石', '14', '14205', '2510872', '神奈川県', 'カナガワケン', '藤沢市', 'フジサワシ', '立石', 'タテイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県藤沢市みその台', '14', '14205', '2510873', '神奈川県', 'カナガワケン', '藤沢市', 'フジサワシ', 'みその台', 'ミソノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県藤沢市花の木', '14', '14205', '2510874', '神奈川県', 'カナガワケン', '藤沢市', 'フジサワシ', '花の木', 'ハナノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県藤沢市本藤沢', '14', '14205', '2510875', '神奈川県', 'カナガワケン', '藤沢市', 'フジサワシ', '本藤沢', 'ホンフジサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県藤沢市善行坂', '14', '14205', '2510876', '神奈川県', 'カナガワケン', '藤沢市', 'フジサワシ', '善行坂', 'ゼンギョウザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県藤沢市善行団地', '14', '14205', '2510877', '神奈川県', 'カナガワケン', '藤沢市', 'フジサワシ', '善行団地', 'ゼンギョウダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県藤沢市長後', '14', '14205', '2520801', '神奈川県', 'カナガワケン', '藤沢市', 'フジサワシ', '長後', 'チョウゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県藤沢市高倉', '14', '14205', '2520802', '神奈川県', 'カナガワケン', '藤沢市', 'フジサワシ', '高倉', 'タカクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県藤沢市今田', '14', '14205', '2520803', '神奈川県', 'カナガワケン', '藤沢市', 'フジサワシ', '今田', 'イマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県藤沢市湘南台', '14', '14205', '2520804', '神奈川県', 'カナガワケン', '藤沢市', 'フジサワシ', '湘南台', 'ショウナンダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県藤沢市円行', '14', '14205', '2520805', '神奈川県', 'カナガワケン', '藤沢市', 'フジサワシ', '円行', 'エンギョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県藤沢市土棚', '14', '14205', '2520806', '神奈川県', 'カナガワケン', '藤沢市', 'フジサワシ', '土棚', 'ツチダナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県藤沢市下土棚', '14', '14205', '2520807', '神奈川県', 'カナガワケン', '藤沢市', 'フジサワシ', '下土棚', 'シモツチダナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県藤沢市桐原町', '14', '14205', '2520811', '神奈川県', 'カナガワケン', '藤沢市', 'フジサワシ', '桐原町', 'キリハラチョウ', null, null, null, null), ('13991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県藤沢市西俣野', '14', '14205', '2520812', '神奈川県', 'カナガワケン', '藤沢市', 'フジサワシ', '西俣野', 'ニシマタノ', null, null, null, null), ('13992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県藤沢市亀井野', '14', '14205', '2520813', '神奈川県', 'カナガワケン', '藤沢市', 'フジサワシ', '亀井野', 'カメイノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県藤沢市天神町', '14', '14205', '2520814', '神奈川県', 'カナガワケン', '藤沢市', 'フジサワシ', '天神町', 'テンジンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県藤沢市石川', '14', '14205', '2520815', '神奈川県', 'カナガワケン', '藤沢市', 'フジサワシ', '石川', 'イシカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県藤沢市遠藤', '14', '14205', '2520816', '神奈川県', 'カナガワケン', '藤沢市', 'フジサワシ', '遠藤', 'エンドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県藤沢市用田', '14', '14205', '2520821', '神奈川県', 'カナガワケン', '藤沢市', 'フジサワシ', '用田', 'ヨウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県藤沢市葛原', '14', '14205', '2520822', '神奈川県', 'カナガワケン', '藤沢市', 'フジサワシ', '葛原', 'クズハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県藤沢市菖蒲沢', '14', '14205', '2520823', '神奈川県', 'カナガワケン', '藤沢市', 'フジサワシ', '菖蒲沢', 'ショウブサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('13999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県藤沢市打戻', '14', '14205', '2520824', '神奈川県', 'カナガワケン', '藤沢市', 'フジサワシ', '打戻', 'ウチモドリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県藤沢市獺郷', '14', '14205', '2520825', '神奈川県', 'カナガワケン', '藤沢市', 'フジサワシ', '獺郷', 'オソゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県藤沢市宮原', '14', '14205', '2520826', '神奈川県', 'カナガワケン', '藤沢市', 'フジサワシ', '宮原', 'ミヤバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県綾瀬市', '14', '14218', '2521100', '神奈川県', 'カナガワケン', '綾瀬市', 'アヤセシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('14003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県綾瀬市厚木航空基地', '14', '14218', '2521101', '神奈川県', 'カナガワケン', '綾瀬市', 'アヤセシ', '厚木航空基地', 'アツギコウクウキチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県綾瀬市本蓼川', '14', '14218', '2521102', '神奈川県', 'カナガワケン', '綾瀬市', 'アヤセシ', '本蓼川', 'ホンタテカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県綾瀬市深谷', '14', '14218', '2521103', '神奈川県', 'カナガワケン', '綾瀬市', 'アヤセシ', '深谷', 'フカヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県綾瀬市大上', '14', '14218', '2521104', '神奈川県', 'カナガワケン', '綾瀬市', 'アヤセシ', '大上', 'オオガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県綾瀬市蓼川', '14', '14218', '2521105', '神奈川県', 'カナガワケン', '綾瀬市', 'アヤセシ', '蓼川', 'タテカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県綾瀬市深谷南', '14', '14218', '2521106', '神奈川県', 'カナガワケン', '綾瀬市', 'アヤセシ', '深谷南', 'フカヤミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県綾瀬市深谷中', '14', '14218', '2521107', '神奈川県', 'カナガワケン', '綾瀬市', 'アヤセシ', '深谷中', 'フカヤナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県綾瀬市深谷上', '14', '14218', '2521108', '神奈川県', 'カナガワケン', '綾瀬市', 'アヤセシ', '深谷上', 'フカヤカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県綾瀬市上土棚北', '14', '14218', '2521111', '神奈川県', 'カナガワケン', '綾瀬市', 'アヤセシ', '上土棚北', 'カミツチダナキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県綾瀬市上土棚', '14', '14218', '2521112', '神奈川県', 'カナガワケン', '綾瀬市', 'アヤセシ', '上土棚', 'カミツチダナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県綾瀬市上土棚中', '14', '14218', '2521113', '神奈川県', 'カナガワケン', '綾瀬市', 'アヤセシ', '上土棚中', 'カミツチダナナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県綾瀬市上土棚南', '14', '14218', '2521114', '神奈川県', 'カナガワケン', '綾瀬市', 'アヤセシ', '上土棚南', 'カミツチダナミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県綾瀬市落合南', '14', '14218', '2521115', '神奈川県', 'カナガワケン', '綾瀬市', 'アヤセシ', '落合南', 'オチアイミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県綾瀬市落合北', '14', '14218', '2521116', '神奈川県', 'カナガワケン', '綾瀬市', 'アヤセシ', '落合北', 'オチアイキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県綾瀬市小園', '14', '14218', '2521121', '神奈川県', 'カナガワケン', '綾瀬市', 'アヤセシ', '小園', 'コゾノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県綾瀬市小園南', '14', '14218', '2521122', '神奈川県', 'カナガワケン', '綾瀬市', 'アヤセシ', '小園南', 'コゾノミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県綾瀬市早川', '14', '14218', '2521123', '神奈川県', 'カナガワケン', '綾瀬市', 'アヤセシ', '早川', 'ハヤカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県綾瀬市吉岡', '14', '14218', '2521124', '神奈川県', 'カナガワケン', '綾瀬市', 'アヤセシ', '吉岡', 'ヨシオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県綾瀬市吉岡東', '14', '14218', '2521125', '神奈川県', 'カナガワケン', '綾瀬市', 'アヤセシ', '吉岡東', 'ヨシオカヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県綾瀬市綾西', '14', '14218', '2521126', '神奈川県', 'カナガワケン', '綾瀬市', 'アヤセシ', '綾西', 'リョウセイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県綾瀬市早川城山', '14', '14218', '2521127', '神奈川県', 'カナガワケン', '綾瀬市', 'アヤセシ', '早川城山', 'ハヤカワシロヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県綾瀬市寺尾北', '14', '14218', '2521131', '神奈川県', 'カナガワケン', '綾瀬市', 'アヤセシ', '寺尾北', 'テラオキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県綾瀬市寺尾中', '14', '14218', '2521132', '神奈川県', 'カナガワケン', '綾瀬市', 'アヤセシ', '寺尾中', 'テラオナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県綾瀬市寺尾本町', '14', '14218', '2521133', '神奈川県', 'カナガワケン', '綾瀬市', 'アヤセシ', '寺尾本町', 'テラオホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県綾瀬市寺尾南', '14', '14218', '2521134', '神奈川県', 'カナガワケン', '綾瀬市', 'アヤセシ', '寺尾南', 'テラオミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県綾瀬市寺尾釜田', '14', '14218', '2521135', '神奈川県', 'カナガワケン', '綾瀬市', 'アヤセシ', '寺尾釜田', 'テラオカマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県綾瀬市寺尾西', '14', '14218', '2521136', '神奈川県', 'カナガワケン', '綾瀬市', 'アヤセシ', '寺尾西', 'テラオニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県綾瀬市寺尾台', '14', '14218', '2521137', '神奈川県', 'カナガワケン', '綾瀬市', 'アヤセシ', '寺尾台', 'テラオダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県茅ヶ崎市', '14', '14207', '2530000', '神奈川県', 'カナガワケン', '茅ヶ崎市', 'チガサキシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('14041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県茅ヶ崎市赤羽根', '14', '14207', '2530001', '神奈川県', 'カナガワケン', '茅ヶ崎市', 'チガサキシ', '赤羽根', 'アカバネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県茅ヶ崎市高田', '14', '14207', '2530002', '神奈川県', 'カナガワケン', '茅ヶ崎市', 'チガサキシ', '高田', 'タカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県茅ヶ崎市鶴が台', '14', '14207', '2530003', '神奈川県', 'カナガワケン', '茅ヶ崎市', 'チガサキシ', '鶴が台', 'ツルガダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県茅ヶ崎市甘沼', '14', '14207', '2530004', '神奈川県', 'カナガワケン', '茅ヶ崎市', 'チガサキシ', '甘沼', 'アマヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県茅ヶ崎市松風台', '14', '14207', '2530005', '神奈川県', 'カナガワケン', '茅ヶ崎市', 'チガサキシ', '松風台', 'マツカゼダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県茅ヶ崎市堤', '14', '14207', '2530006', '神奈川県', 'カナガワケン', '茅ヶ崎市', 'チガサキシ', '堤', 'ツツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県茅ヶ崎市行谷', '14', '14207', '2530007', '神奈川県', 'カナガワケン', '茅ヶ崎市', 'チガサキシ', '行谷', 'ナメガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県茅ヶ崎市芹沢', '14', '14207', '2530008', '神奈川県', 'カナガワケン', '茅ヶ崎市', 'チガサキシ', '芹沢', 'セリザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県茅ヶ崎市菱沼', '14', '14207', '2530011', '神奈川県', 'カナガワケン', '茅ヶ崎市', 'チガサキシ', '菱沼', 'ヒシヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県茅ヶ崎市小和田', '14', '14207', '2530012', '神奈川県', 'カナガワケン', '茅ヶ崎市', 'チガサキシ', '小和田', 'コワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県茅ヶ崎市赤松町', '14', '14207', '2530013', '神奈川県', 'カナガワケン', '茅ヶ崎市', 'チガサキシ', '赤松町', 'アカマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県茅ヶ崎市本宿町', '14', '14207', '2530014', '神奈川県', 'カナガワケン', '茅ヶ崎市', 'チガサキシ', '本宿町', 'ホンジュクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県茅ヶ崎市代官町', '14', '14207', '2530015', '神奈川県', 'カナガワケン', '茅ヶ崎市', 'チガサキシ', '代官町', 'ダイカンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県茅ヶ崎市小桜町', '14', '14207', '2530016', '神奈川県', 'カナガワケン', '茅ヶ崎市', 'チガサキシ', '小桜町', 'コザクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県茅ヶ崎市松林', '14', '14207', '2530017', '神奈川県', 'カナガワケン', '茅ヶ崎市', 'チガサキシ', '松林', 'ショウリン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県茅ヶ崎市室田', '14', '14207', '2530018', '神奈川県', 'カナガワケン', '茅ヶ崎市', 'チガサキシ', '室田', 'ムロタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県茅ヶ崎市浜竹', '14', '14207', '2530021', '神奈川県', 'カナガワケン', '茅ヶ崎市', 'チガサキシ', '浜竹', 'ハマタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県茅ヶ崎市松浪', '14', '14207', '2530022', '神奈川県', 'カナガワケン', '茅ヶ崎市', 'チガサキシ', '松浪', 'マツナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県茅ヶ崎市美住町', '14', '14207', '2530023', '神奈川県', 'カナガワケン', '茅ヶ崎市', 'チガサキシ', '美住町', 'ミスミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県茅ヶ崎市平和町', '14', '14207', '2530024', '神奈川県', 'カナガワケン', '茅ヶ崎市', 'チガサキシ', '平和町', 'ヘイワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県茅ヶ崎市松が丘', '14', '14207', '2530025', '神奈川県', 'カナガワケン', '茅ヶ崎市', 'チガサキシ', '松が丘', 'マツガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県茅ヶ崎市旭が丘', '14', '14207', '2530026', '神奈川県', 'カナガワケン', '茅ヶ崎市', 'チガサキシ', '旭が丘', 'アサヒガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県茅ヶ崎市ひばりが丘', '14', '14207', '2530027', '神奈川県', 'カナガワケン', '茅ヶ崎市', 'チガサキシ', 'ひばりが丘', 'ヒバリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県茅ヶ崎市出口町', '14', '14207', '2530028', '神奈川県', 'カナガワケン', '茅ヶ崎市', 'チガサキシ', '出口町', 'デグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県茅ヶ崎市富士見町', '14', '14207', '2530031', '神奈川県', 'カナガワケン', '茅ヶ崎市', 'チガサキシ', '富士見町', 'フジミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県茅ヶ崎市常盤町', '14', '14207', '2530032', '神奈川県', 'カナガワケン', '茅ヶ崎市', 'チガサキシ', '常盤町', 'トキワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県茅ヶ崎市汐見台', '14', '14207', '2530033', '神奈川県', 'カナガワケン', '茅ヶ崎市', 'チガサキシ', '汐見台', 'シオミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県茅ヶ崎市緑が浜', '14', '14207', '2530034', '神奈川県', 'カナガワケン', '茅ヶ崎市', 'チガサキシ', '緑が浜', 'ミドリガハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県茅ヶ崎市浜須賀', '14', '14207', '2530035', '神奈川県', 'カナガワケン', '茅ヶ崎市', 'チガサキシ', '浜須賀', 'ハマスカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県茅ヶ崎市白浜町', '14', '14207', '2530036', '神奈川県', 'カナガワケン', '茅ヶ崎市', 'チガサキシ', '白浜町', 'シラハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県茅ヶ崎市菱沼海岸', '14', '14207', '2530037', '神奈川県', 'カナガワケン', '茅ヶ崎市', 'チガサキシ', '菱沼海岸', 'ヒシヌマカイガン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県茅ヶ崎市茅ヶ崎', '14', '14207', '2530041', '神奈川県', 'カナガワケン', '茅ヶ崎市', 'チガサキシ', '茅ヶ崎', 'チガサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県茅ヶ崎市本村', '14', '14207', '2530042', '神奈川県', 'カナガワケン', '茅ヶ崎市', 'チガサキシ', '本村', 'ホンソン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県茅ヶ崎市元町', '14', '14207', '2530043', '神奈川県', 'カナガワケン', '茅ヶ崎市', 'チガサキシ', '元町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県茅ヶ崎市新栄町', '14', '14207', '2530044', '神奈川県', 'カナガワケン', '茅ヶ崎市', 'チガサキシ', '新栄町', 'シンエイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県茅ヶ崎市十間坂', '14', '14207', '2530045', '神奈川県', 'カナガワケン', '茅ヶ崎市', 'チガサキシ', '十間坂', 'ジュッケンザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県茅ヶ崎市若松町', '14', '14207', '2530051', '神奈川県', 'カナガワケン', '茅ヶ崎市', 'チガサキシ', '若松町', 'ワカマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県茅ヶ崎市幸町', '14', '14207', '2530052', '神奈川県', 'カナガワケン', '茅ヶ崎市', 'チガサキシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県茅ヶ崎市東海岸北', '14', '14207', '2530053', '神奈川県', 'カナガワケン', '茅ヶ崎市', 'チガサキシ', '東海岸北', 'ヒガシカイガンキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県茅ヶ崎市東海岸南', '14', '14207', '2530054', '神奈川県', 'カナガワケン', '茅ヶ崎市', 'チガサキシ', '東海岸南', 'ヒガシカイガンミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県茅ヶ崎市中海岸', '14', '14207', '2530055', '神奈川県', 'カナガワケン', '茅ヶ崎市', 'チガサキシ', '中海岸', 'ナカカイガン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県茅ヶ崎市共恵', '14', '14207', '2530056', '神奈川県', 'カナガワケン', '茅ヶ崎市', 'チガサキシ', '共恵', 'トモエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県茅ヶ崎市南湖', '14', '14207', '2530061', '神奈川県', 'カナガワケン', '茅ヶ崎市', 'チガサキシ', '南湖', 'ナンゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県茅ヶ崎市浜見平', '14', '14207', '2530062', '神奈川県', 'カナガワケン', '茅ヶ崎市', 'チガサキシ', '浜見平', 'ハマミダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県茅ヶ崎市柳島海岸', '14', '14207', '2530063', '神奈川県', 'カナガワケン', '茅ヶ崎市', 'チガサキシ', '柳島海岸', 'ヤナギシマカイガン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県茅ヶ崎市柳島', '14', '14207', '2530064', '神奈川県', 'カナガワケン', '茅ヶ崎市', 'チガサキシ', '柳島', 'ヤナギシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県茅ヶ崎市松尾', '14', '14207', '2530065', '神奈川県', 'カナガワケン', '茅ヶ崎市', 'チガサキシ', '松尾', 'マツオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県茅ヶ崎市萩園', '14', '14207', '2530071', '神奈川県', 'カナガワケン', '茅ヶ崎市', 'チガサキシ', '萩園', 'ハギソノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県茅ヶ崎市今宿', '14', '14207', '2530072', '神奈川県', 'カナガワケン', '茅ヶ崎市', 'チガサキシ', '今宿', 'イマジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県茅ヶ崎市中島', '14', '14207', '2530073', '神奈川県', 'カナガワケン', '茅ヶ崎市', 'チガサキシ', '中島', 'ナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県茅ヶ崎市平太夫新田', '14', '14207', '2530074', '神奈川県', 'カナガワケン', '茅ヶ崎市', 'チガサキシ', '平太夫新田', 'ヘイダユウシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県茅ヶ崎市下寺尾', '14', '14207', '2530081', '神奈川県', 'カナガワケン', '茅ヶ崎市', 'チガサキシ', '下寺尾', 'シモテラオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県茅ヶ崎市香川', '14', '14207', '2530082', '神奈川県', 'カナガワケン', '茅ヶ崎市', 'チガサキシ', '香川', 'カガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県茅ヶ崎市西久保', '14', '14207', '2530083', '神奈川県', 'カナガワケン', '茅ヶ崎市', 'チガサキシ', '西久保', 'ニシクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県茅ヶ崎市円蔵', '14', '14207', '2530084', '神奈川県', 'カナガワケン', '茅ヶ崎市', 'チガサキシ', '円蔵', 'エンゾウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県茅ヶ崎市矢畑', '14', '14207', '2530085', '神奈川県', 'カナガワケン', '茅ヶ崎市', 'チガサキシ', '矢畑', 'ヤバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県茅ヶ崎市浜之郷', '14', '14207', '2530086', '神奈川県', 'カナガワケン', '茅ヶ崎市', 'チガサキシ', '浜之郷', 'ハマノゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県茅ヶ崎市下町屋', '14', '14207', '2530087', '神奈川県', 'カナガワケン', '茅ヶ崎市', 'チガサキシ', '下町屋', 'シモマチヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県茅ヶ崎市みずき', '14', '14207', '2530088', '神奈川県', 'カナガワケン', '茅ヶ崎市', 'チガサキシ', 'みずき', 'ミズキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県高座郡寒川町', '14', '14321', '2530100', '神奈川県', 'カナガワケン', '高座郡寒川町', 'コウザグンサムカワマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('14101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県高座郡寒川町倉見', '14', '14321', '2530101', '神奈川県', 'カナガワケン', '高座郡寒川町', 'コウザグンサムカワマチ', '倉見', 'クラミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県高座郡寒川町小動', '14', '14321', '2530102', '神奈川県', 'カナガワケン', '高座郡寒川町', 'コウザグンサムカワマチ', '小動', 'コユルギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県高座郡寒川町小谷', '14', '14321', '2530103', '神奈川県', 'カナガワケン', '高座郡寒川町', 'コウザグンサムカワマチ', '小谷', 'コヤト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県高座郡寒川町大蔵', '14', '14321', '2530104', '神奈川県', 'カナガワケン', '高座郡寒川町', 'コウザグンサムカワマチ', '大蔵', 'オオゾウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県高座郡寒川町岡田', '14', '14321', '2530105', '神奈川県', 'カナガワケン', '高座郡寒川町', 'コウザグンサムカワマチ', '岡田', 'オカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県高座郡寒川町宮山', '14', '14321', '2530106', '神奈川県', 'カナガワケン', '高座郡寒川町', 'コウザグンサムカワマチ', '宮山', 'ミヤヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県高座郡寒川町一之宮', '14', '14321', '2530111', '神奈川県', 'カナガワケン', '高座郡寒川町', 'コウザグンサムカワマチ', '一之宮', 'イチノミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県高座郡寒川町中瀬', '14', '14321', '2530112', '神奈川県', 'カナガワケン', '高座郡寒川町', 'コウザグンサムカワマチ', '中瀬', 'ナカゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県高座郡寒川町大曲', '14', '14321', '2530113', '神奈川県', 'カナガワケン', '高座郡寒川町', 'コウザグンサムカワマチ', '大曲', 'オオマガリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県高座郡寒川町田端', '14', '14321', '2530114', '神奈川県', 'カナガワケン', '高座郡寒川町', 'コウザグンサムカワマチ', '田端', 'タバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市', '14', '14203', '2540000', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('14132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市大島', '14', '14203', '2540001', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', '大島', 'オオシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市横内', '14', '14203', '2540002', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', '横内', 'ヨコウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市下島', '14', '14203', '2540003', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', '下島', 'シモジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市小鍋島', '14', '14203', '2540004', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', '小鍋島', 'コナベシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市城所', '14', '14203', '2540005', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', '城所', 'キドコロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市吉際', '14', '14203', '2540011', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', '吉際', 'ヨシギワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市大神', '14', '14203', '2540012', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', '大神', 'オオカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市田村', '14', '14203', '2540013', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', '田村', 'タムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市四之宮', '14', '14203', '2540014', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', '四之宮', 'シノミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市八幡', '14', '14203', '2540015', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', '八幡', 'ヤワタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市東八幡', '14', '14203', '2540016', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', '東八幡', 'ヒガシヤワタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市東真土', '14', '14203', '2540018', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', '東真土', 'ヒガシシンド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市西真土', '14', '14203', '2540019', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', '西真土', 'ニシシンド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市長瀞', '14', '14203', '2540021', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', '長瀞', 'ナガトロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市須賀', '14', '14203', '2540022', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', '須賀', 'スカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市馬入', '14', '14203', '2540023', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', '馬入', 'バニュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市馬入本町', '14', '14203', '2540024', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', '馬入本町', 'バニュウホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市榎木町', '14', '14203', '2540025', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', '榎木町', 'エノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市中堂', '14', '14203', '2540026', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', '中堂', 'ナカドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市堤町', '14', '14203', '2540027', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', '堤町', 'ツツミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市天沼', '14', '14203', '2540031', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', '天沼', 'アマヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市八千代町', '14', '14203', '2540032', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', '八千代町', 'ヤチヨチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市老松町', '14', '14203', '2540033', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', '老松町', 'オイマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市宝町', '14', '14203', '2540034', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', '宝町', 'タカラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市宮の前', '14', '14203', '2540035', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', '宮の前', 'ミヤノマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市宮松町', '14', '14203', '2540036', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', '宮松町', 'ミヤマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市浅間町', '14', '14203', '2540041', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', '浅間町', 'センゲンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市明石町', '14', '14203', '2540042', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', '明石町', 'アカシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市紅谷町', '14', '14203', '2540043', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', '紅谷町', 'ベニヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市錦町', '14', '14203', '2540044', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', '錦町', 'ニシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市見附町', '14', '14203', '2540045', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', '見附町', 'ミツケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市立野町', '14', '14203', '2540046', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', '立野町', 'タツノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市追分', '14', '14203', '2540047', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', '追分', 'オイワケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市豊原町', '14', '14203', '2540051', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', '豊原町', 'トヨハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市平塚', '14', '14203', '2540052', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', '平塚', 'ヒラツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市桜ケ丘', '14', '14203', '2540053', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', '桜ケ丘', 'サクラガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市中里', '14', '14203', '2540054', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', '中里', 'ナカザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市上平塚', '14', '14203', '2540055', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', '上平塚', 'カミヒラツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市御殿', '14', '14203', '2540061', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', '御殿', 'ゴテン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市富士見町', '14', '14203', '2540062', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', '富士見町', 'フジミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市諏訪町', '14', '14203', '2540063', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', '諏訪町', 'スワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市達上ケ丘', '14', '14203', '2540064', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', '達上ケ丘', 'タンジョウガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市南原', '14', '14203', '2540065', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', '南原', 'ミナミハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市中原上宿', '14', '14203', '2540071', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', '中原上宿', 'ナカハラカミジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市中原下宿', '14', '14203', '2540072', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', '中原下宿', 'ナカハラシモジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市西八幡', '14', '14203', '2540073', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', '西八幡', 'ニシヤワタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市大原', '14', '14203', '2540074', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', '大原', 'オオハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市中原', '14', '14203', '2540075', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', '中原', 'ナカハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市新町', '14', '14203', '2540076', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市東中原', '14', '14203', '2540077', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', '東中原', 'ヒガシナカハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市豊田打間木', '14', '14203', '2540081', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', '豊田打間木', 'トヨダウチマギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市東豊田', '14', '14203', '2540082', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', '東豊田', 'ヒガシトヨダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市豊田小嶺', '14', '14203', '2540083', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', '豊田小嶺', 'トヨダコミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市南豊田', '14', '14203', '2540084', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', '南豊田', 'ミナミトヨダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市豊田宮下', '14', '14203', '2540085', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', '豊田宮下', 'トヨダミヤシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市豊田平等寺', '14', '14203', '2540086', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', '豊田平等寺', 'トヨダビョウドウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市豊田本郷', '14', '14203', '2540087', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', '豊田本郷', 'トヨダホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市北豊田', '14', '14203', '2540088', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', '北豊田', 'キタトヨダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市久領堤', '14', '14203', '2540801', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', '久領堤', 'クリョウヅツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市札場町', '14', '14203', '2540802', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', '札場町', 'フダバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市千石河岸', '14', '14203', '2540803', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', '千石河岸', 'センゴクカシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市幸町', '14', '14203', '2540804', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市高浜台', '14', '14203', '2540805', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', '高浜台', 'タカハマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市夕陽ケ丘', '14', '14203', '2540806', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', '夕陽ケ丘', 'ユウヒガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市代官町', '14', '14203', '2540807', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', '代官町', 'ダイカンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市八重咲町', '14', '14203', '2540811', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', '八重咲町', 'ヤエザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市松風町', '14', '14203', '2540812', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', '松風町', 'マツカゼチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市袖ケ浜', '14', '14203', '2540813', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', '袖ケ浜', 'ソデガハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市龍城ケ丘', '14', '14203', '2540814', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', '龍城ケ丘', 'リュウジョウガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市桃浜町', '14', '14203', '2540815', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', '桃浜町', 'モモハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市黒部丘', '14', '14203', '2540821', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', '黒部丘', 'クロベオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市菫平', '14', '14203', '2540822', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', '菫平', 'スミレダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市虹ケ浜', '14', '14203', '2540823', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', '虹ケ浜', 'ニジガハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市花水台', '14', '14203', '2540824', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', '花水台', 'ハナミズダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市撫子原', '14', '14203', '2540825', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', '撫子原', 'ナデシコハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市唐ケ原', '14', '14203', '2540826', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', '唐ケ原', 'トウガハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市纒', '14', '14203', '2540901', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', '纒', 'マトイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市徳延', '14', '14203', '2540902', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', '徳延', 'トクノブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市河内', '14', '14203', '2540903', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', '河内', 'コウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市根坂間', '14', '14203', '2540904', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', '根坂間', 'ネザカマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市日向岡', '14', '14203', '2540905', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', '日向岡', 'ヒナタオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市公所', '14', '14203', '2540906', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', '公所', 'グゾ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市山下', '14', '14203', '2540911', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', '山下', 'ヤマシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市高根', '14', '14203', '2540912', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', '高根', 'タカネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市万田', '14', '14203', '2540913', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', '万田', 'マンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市高村', '14', '14203', '2540914', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', '高村', 'タカムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市出縄', '14', '14203', '2540915', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', '出縄', 'イデナワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県中郡大磯町', '14', '14341', '2550000', '神奈川県', 'カナガワケン', '中郡大磯町', 'ナカグンオオイソマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('14233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県中郡大磯町高麗', '14', '14341', '2550001', '神奈川県', 'カナガワケン', '中郡大磯町', 'ナカグンオオイソマチ', '高麗', 'コマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県中郡大磯町東町', '14', '14341', '2550002', '神奈川県', 'カナガワケン', '中郡大磯町', 'ナカグンオオイソマチ', '東町', 'ヒガシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県中郡大磯町大磯', '14', '14341', '2550003', '神奈川県', 'カナガワケン', '中郡大磯町', 'ナカグンオオイソマチ', '大磯', 'オオイソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県中郡大磯町東小磯', '14', '14341', '2550004', '神奈川県', 'カナガワケン', '中郡大磯町', 'ナカグンオオイソマチ', '東小磯', 'ヒガシコイソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県中郡大磯町西小磯', '14', '14341', '2550005', '神奈川県', 'カナガワケン', '中郡大磯町', 'ナカグンオオイソマチ', '西小磯', 'ニシコイソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県小田原市沼代', '14', '14206', '2560801', '神奈川県', 'カナガワケン', '小田原市', 'オダワラシ', '沼代', 'ヌマシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県小田原市小竹', '14', '14206', '2560802', '神奈川県', 'カナガワケン', '小田原市', 'オダワラシ', '小竹', 'オダケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県小田原市中村原', '14', '14206', '2560803', '神奈川県', 'カナガワケン', '小田原市', 'オダワラシ', '中村原', 'ナカムラハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県小田原市羽根尾', '14', '14206', '2560804', '神奈川県', 'カナガワケン', '小田原市', 'オダワラシ', '羽根尾', 'ハネオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県小田原市上町', '14', '14206', '2560805', '神奈川県', 'カナガワケン', '小田原市', 'オダワラシ', '上町', 'カノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県小田原市小船', '14', '14206', '2560806', '神奈川県', 'カナガワケン', '小田原市', 'オダワラシ', '小船', 'オブネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県小田原市山西', '14', '14206', '2560807', '神奈川県', 'カナガワケン', '小田原市', 'オダワラシ', '山西', 'ヤマニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県小田原市東ヶ丘', '14', '14206', '2560808', '神奈川県', 'カナガワケン', '小田原市', 'オダワラシ', '東ヶ丘', 'ヒガシガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県小田原市田島', '14', '14206', '2560811', '神奈川県', 'カナガワケン', '小田原市', 'オダワラシ', '田島', 'タジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県小田原市国府津', '14', '14206', '2560812', '神奈川県', 'カナガワケン', '小田原市', 'オダワラシ', '国府津', 'コウヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県小田原市前川', '14', '14206', '2560813', '神奈川県', 'カナガワケン', '小田原市', 'オダワラシ', '前川', 'マエカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県小田原市川匂', '14', '14206', '2560814', '神奈川県', 'カナガワケン', '小田原市', 'オダワラシ', '川匂', 'カワワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県小田原市小八幡', '14', '14206', '2560815', '神奈川県', 'カナガワケン', '小田原市', 'オダワラシ', '小八幡', 'コヤワタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県小田原市酒匂', '14', '14206', '2560816', '神奈川県', 'カナガワケン', '小田原市', 'オダワラシ', '酒匂', 'サカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県小田原市西酒匂', '14', '14206', '2560817', '神奈川県', 'カナガワケン', '小田原市', 'オダワラシ', '西酒匂', 'ニシサカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県秦野市', '14', '14211', '2570000', '神奈川県', 'カナガワケン', '秦野市', 'ハダノシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('14256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県秦野市鶴巻北', '14', '14211', '2570001', '神奈川県', 'カナガワケン', '秦野市', 'ハダノシ', '鶴巻北', 'ツルマキキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県秦野市鶴巻南', '14', '14211', '2570002', '神奈川県', 'カナガワケン', '秦野市', 'ハダノシ', '鶴巻南', 'ツルマキミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県秦野市南矢名', '14', '14211', '2570003', '神奈川県', 'カナガワケン', '秦野市', 'ハダノシ', '南矢名', 'ミナミヤナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県秦野市下大槻', '14', '14211', '2570004', '神奈川県', 'カナガワケン', '秦野市', 'ハダノシ', '下大槻', 'シモオオヅキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県秦野市上大槻', '14', '14211', '2570005', '神奈川県', 'カナガワケン', '秦野市', 'ハダノシ', '上大槻', 'カミオオヅキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県秦野市北矢名', '14', '14211', '2570006', '神奈川県', 'カナガワケン', '秦野市', 'ハダノシ', '北矢名', 'キタヤナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県秦野市鶴巻', '14', '14211', '2570007', '神奈川県', 'カナガワケン', '秦野市', 'ハダノシ', '鶴巻', 'ツルマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県秦野市尾尻', '14', '14211', '2570011', '神奈川県', 'カナガワケン', '秦野市', 'ハダノシ', '尾尻', 'オジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県秦野市西大竹', '14', '14211', '2570012', '神奈川県', 'カナガワケン', '秦野市', 'ハダノシ', '西大竹', 'ニシオオダケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県秦野市南が丘', '14', '14211', '2570013', '神奈川県', 'カナガワケン', '秦野市', 'ハダノシ', '南が丘', 'ミナミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県秦野市今泉', '14', '14211', '2570014', '神奈川県', 'カナガワケン', '秦野市', 'ハダノシ', '今泉', 'イマイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県秦野市平沢', '14', '14211', '2570015', '神奈川県', 'カナガワケン', '秦野市', 'ハダノシ', '平沢', 'ヒラサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県秦野市栃窪', '14', '14211', '2570016', '神奈川県', 'カナガワケン', '秦野市', 'ハダノシ', '栃窪', 'トチクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県秦野市立野台', '14', '14211', '2570017', '神奈川県', 'カナガワケン', '秦野市', 'ハダノシ', '立野台', 'タテノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県秦野市今泉台', '14', '14211', '2570018', '神奈川県', 'カナガワケン', '秦野市', 'ハダノシ', '今泉台', 'イマイズミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県秦野市蓑毛', '14', '14211', '2570021', '神奈川県', 'カナガワケン', '秦野市', 'ハダノシ', '蓑毛', 'ミノゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県秦野市小蓑毛', '14', '14211', '2570022', '神奈川県', 'カナガワケン', '秦野市', 'ハダノシ', '小蓑毛', 'コミノゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県秦野市寺山', '14', '14211', '2570023', '神奈川県', 'カナガワケン', '秦野市', 'ハダノシ', '寺山', 'テラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県秦野市名古木', '14', '14211', '2570024', '神奈川県', 'カナガワケン', '秦野市', 'ハダノシ', '名古木', 'ナガヌキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県秦野市落合', '14', '14211', '2570025', '神奈川県', 'カナガワケン', '秦野市', 'ハダノシ', '落合', 'オチアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県秦野市下落合', '14', '14211', '2570026', '神奈川県', 'カナガワケン', '秦野市', 'ハダノシ', '下落合', 'シモオチアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県秦野市西田原', '14', '14211', '2570027', '神奈川県', 'カナガワケン', '秦野市', 'ハダノシ', '西田原', 'ニシタワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県秦野市東田原', '14', '14211', '2570028', '神奈川県', 'カナガワケン', '秦野市', 'ハダノシ', '東田原', 'ヒガシタワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県秦野市曽屋', '14', '14211', '2570031', '神奈川県', 'カナガワケン', '秦野市', 'ハダノシ', '曽屋', 'ソヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県秦野市河原町', '14', '14211', '2570032', '神奈川県', 'カナガワケン', '秦野市', 'ハダノシ', '河原町', 'カワラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県秦野市室町', '14', '14211', '2570033', '神奈川県', 'カナガワケン', '秦野市', 'ハダノシ', '室町', 'ムロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県秦野市大秦町', '14', '14211', '2570034', '神奈川県', 'カナガワケン', '秦野市', 'ハダノシ', '大秦町', 'タイシンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県秦野市本町', '14', '14211', '2570035', '神奈川県', 'カナガワケン', '秦野市', 'ハダノシ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県秦野市元町', '14', '14211', '2570036', '神奈川県', 'カナガワケン', '秦野市', 'ハダノシ', '元町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県秦野市末広町', '14', '14211', '2570037', '神奈川県', 'カナガワケン', '秦野市', 'ハダノシ', '末広町', 'スエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県秦野市入船町', '14', '14211', '2570041', '神奈川県', 'カナガワケン', '秦野市', 'ハダノシ', '入船町', 'イリフネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県秦野市寿町', '14', '14211', '2570042', '神奈川県', 'カナガワケン', '秦野市', 'ハダノシ', '寿町', 'コトブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県秦野市栄町', '14', '14211', '2570043', '神奈川県', 'カナガワケン', '秦野市', 'ハダノシ', '栄町', 'サカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県秦野市文京町', '14', '14211', '2570044', '神奈川県', 'カナガワケン', '秦野市', 'ハダノシ', '文京町', 'ブンキョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県秦野市桜町', '14', '14211', '2570045', '神奈川県', 'カナガワケン', '秦野市', 'ハダノシ', '桜町', 'サクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県秦野市ひばりケ丘', '14', '14211', '2570046', '神奈川県', 'カナガワケン', '秦野市', 'ハダノシ', 'ひばりケ丘', 'ヒバリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県秦野市水神町', '14', '14211', '2570047', '神奈川県', 'カナガワケン', '秦野市', 'ハダノシ', '水神町', 'スイジンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県秦野市幸町', '14', '14211', '2570048', '神奈川県', 'カナガワケン', '秦野市', 'ハダノシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県秦野市今川町', '14', '14211', '2570051', '神奈川県', 'カナガワケン', '秦野市', 'ハダノシ', '今川町', 'イマガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県秦野市上今川町', '14', '14211', '2570052', '神奈川県', 'カナガワケン', '秦野市', 'ハダノシ', '上今川町', 'カミイマガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県秦野市清水町', '14', '14211', '2570053', '神奈川県', 'カナガワケン', '秦野市', 'ハダノシ', '清水町', 'シミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県秦野市緑町', '14', '14211', '2570054', '神奈川県', 'カナガワケン', '秦野市', 'ハダノシ', '緑町', 'ミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県秦野市鈴張町', '14', '14211', '2570055', '神奈川県', 'カナガワケン', '秦野市', 'ハダノシ', '鈴張町', 'スズハリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県秦野市新町', '14', '14211', '2570056', '神奈川県', 'カナガワケン', '秦野市', 'ハダノシ', '新町', 'シンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県秦野市富士見町', '14', '14211', '2570057', '神奈川県', 'カナガワケン', '秦野市', 'ハダノシ', '富士見町', 'フジミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県愛甲郡清川村煤ケ谷丹沢山札掛', '14', '14402', '2570061', '神奈川県', 'カナガワケン', '愛甲郡清川村', 'アイコウグンキヨカワムラ', '煤ケ谷', 'ススガヤ', null, null, '丹沢山札掛', 'タンザワヤマフダカケ');
INSERT INTO `ms_addresses` VALUES ('14315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県足柄上郡大井町', '14', '14362', '2580000', '神奈川県', 'カナガワケン', '足柄上郡大井町', 'アシガラカミグンオオイマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('14316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県足柄上郡松田町', '14', '14363', '2580000', '神奈川県', 'カナガワケン', '足柄上郡松田町', 'アシガラカミグンマツダマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('14317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県足柄上郡開成町', '14', '14366', '2580000', '神奈川県', 'カナガワケン', '足柄上郡開成町', 'アシガラカミグンカイセイマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('14318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県足柄上郡松田町寄', '14', '14363', '2580001', '神奈川県', 'カナガワケン', '足柄上郡松田町', 'アシガラカミグンマツダマチ', '寄', 'ヤドリキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県足柄上郡松田町神山', '14', '14363', '2580002', '神奈川県', 'カナガワケン', '足柄上郡松田町', 'アシガラカミグンマツダマチ', '神山', 'コウヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県足柄上郡松田町松田惣領', '14', '14363', '2580003', '神奈川県', 'カナガワケン', '足柄上郡松田町', 'アシガラカミグンマツダマチ', '松田惣領', 'マツダソウリョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県足柄上郡松田町松田庶子', '14', '14363', '2580004', '神奈川県', 'カナガワケン', '足柄上郡松田町', 'アシガラカミグンマツダマチ', '松田庶子', 'マツダソシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県足柄上郡大井町篠窪', '14', '14362', '2580011', '神奈川県', 'カナガワケン', '足柄上郡大井町', 'アシガラカミグンオオイマチ', '篠窪', 'シノクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県足柄上郡大井町柳', '14', '14362', '2580012', '神奈川県', 'カナガワケン', '足柄上郡大井町', 'アシガラカミグンオオイマチ', '柳', 'ヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県足柄上郡大井町高尾', '14', '14362', '2580013', '神奈川県', 'カナガワケン', '足柄上郡大井町', 'アシガラカミグンオオイマチ', '高尾', 'タカオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県足柄上郡大井町赤田', '14', '14362', '2580014', '神奈川県', 'カナガワケン', '足柄上郡大井町', 'アシガラカミグンオオイマチ', '赤田', 'アカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県足柄上郡大井町山田', '14', '14362', '2580015', '神奈川県', 'カナガワケン', '足柄上郡大井町', 'アシガラカミグンオオイマチ', '山田', 'ヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県足柄上郡大井町上大井', '14', '14362', '2580016', '神奈川県', 'カナガワケン', '足柄上郡大井町', 'アシガラカミグンオオイマチ', '上大井', 'カミオオイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県足柄上郡大井町西大井', '14', '14362', '2580017', '神奈川県', 'カナガワケン', '足柄上郡大井町', 'アシガラカミグンオオイマチ', '西大井', 'ニシオオイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県足柄上郡大井町金手', '14', '14362', '2580018', '神奈川県', 'カナガワケン', '足柄上郡大井町', 'アシガラカミグンオオイマチ', '金手', 'カナデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県足柄上郡大井町金子', '14', '14362', '2580019', '神奈川県', 'カナガワケン', '足柄上郡大井町', 'アシガラカミグンオオイマチ', '金子', 'カネコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県足柄上郡開成町吉田島', '14', '14366', '2580021', '神奈川県', 'カナガワケン', '足柄上郡開成町', 'アシガラカミグンカイセイマチ', '吉田島', 'ヨシダジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県足柄上郡開成町牛島', '14', '14366', '2580022', '神奈川県', 'カナガワケン', '足柄上郡開成町', 'アシガラカミグンカイセイマチ', '牛島', 'ウシジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県足柄上郡開成町宮台', '14', '14366', '2580023', '神奈川県', 'カナガワケン', '足柄上郡開成町', 'アシガラカミグンカイセイマチ', '宮台', 'ミヤノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県足柄上郡開成町中之名', '14', '14366', '2580024', '神奈川県', 'カナガワケン', '足柄上郡開成町', 'アシガラカミグンカイセイマチ', '中之名', 'ナカノミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県足柄上郡開成町円通寺', '14', '14366', '2580025', '神奈川県', 'カナガワケン', '足柄上郡開成町', 'アシガラカミグンカイセイマチ', '円通寺', 'エンツウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県足柄上郡開成町延沢', '14', '14366', '2580026', '神奈川県', 'カナガワケン', '足柄上郡開成町', 'アシガラカミグンカイセイマチ', '延沢', 'ノブサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県足柄上郡開成町岡野', '14', '14366', '2580027', '神奈川県', 'カナガワケン', '足柄上郡開成町', 'アシガラカミグンカイセイマチ', '岡野', 'オカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県足柄上郡開成町金井島', '14', '14366', '2580028', '神奈川県', 'カナガワケン', '足柄上郡開成町', 'アシガラカミグンカイセイマチ', '金井島', 'カナイシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県足柄上郡山北町', '14', '14364', '2580100', '神奈川県', 'カナガワケン', '足柄上郡山北町', 'アシガラカミグンヤマキタマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('14340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県足柄上郡山北町向原', '14', '14364', '2580111', '神奈川県', 'カナガワケン', '足柄上郡山北町', 'アシガラカミグンヤマキタマチ', '向原', 'ムコウハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県足柄上郡山北町岸', '14', '14364', '2580112', '神奈川県', 'カナガワケン', '足柄上郡山北町', 'アシガラカミグンヤマキタマチ', '岸', 'キシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県足柄上郡山北町山北', '14', '14364', '2580113', '神奈川県', 'カナガワケン', '足柄上郡山北町', 'アシガラカミグンヤマキタマチ', '山北', 'ヤマキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県足柄上郡山北町平山', '14', '14364', '2580114', '神奈川県', 'カナガワケン', '足柄上郡山北町', 'アシガラカミグンヤマキタマチ', '平山', 'ヒラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県足柄上郡山北町谷ケ', '14', '14364', '2580115', '神奈川県', 'カナガワケン', '足柄上郡山北町', 'アシガラカミグンヤマキタマチ', '谷ケ', 'ヤガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県足柄上郡山北町皆瀬川', '14', '14364', '2580121', '神奈川県', 'カナガワケン', '足柄上郡山北町', 'アシガラカミグンヤマキタマチ', '皆瀬川', 'ミナセガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県足柄上郡山北町都夫良野', '14', '14364', '2580122', '神奈川県', 'カナガワケン', '足柄上郡山北町', 'アシガラカミグンヤマキタマチ', '都夫良野', 'ツブラノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県足柄上郡山北町湯触', '14', '14364', '2580123', '神奈川県', 'カナガワケン', '足柄上郡山北町', 'アシガラカミグンヤマキタマチ', '湯触', 'ユブレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県足柄上郡山北町川西', '14', '14364', '2580124', '神奈川県', 'カナガワケン', '足柄上郡山北町', 'アシガラカミグンヤマキタマチ', '川西', 'カワニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県足柄上郡山北町山市場', '14', '14364', '2580125', '神奈川県', 'カナガワケン', '足柄上郡山北町', 'アシガラカミグンヤマキタマチ', '山市場', 'ヤマイチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県足柄上郡山北町神縄', '14', '14364', '2580126', '神奈川県', 'カナガワケン', '足柄上郡山北町', 'アシガラカミグンヤマキタマチ', '神縄', 'カミナワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県足柄上郡山北町中川', '14', '14364', '2580201', '神奈川県', 'カナガワケン', '足柄上郡山北町', 'アシガラカミグンヤマキタマチ', '中川', 'ナカガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県足柄上郡山北町玄倉', '14', '14364', '2580202', '神奈川県', 'カナガワケン', '足柄上郡山北町', 'アシガラカミグンヤマキタマチ', '玄倉', 'クロクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県足柄上郡山北町神尾田', '14', '14364', '2580203', '神奈川県', 'カナガワケン', '足柄上郡山北町', 'アシガラカミグンヤマキタマチ', '神尾田', 'カミオダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県足柄上郡山北町世附', '14', '14364', '2580204', '神奈川県', 'カナガワケン', '足柄上郡山北町', 'アシガラカミグンヤマキタマチ', '世附', 'ヨヅク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県中郡二宮町', '14', '14342', '2590100', '神奈川県', 'カナガワケン', '中郡二宮町', 'ナカグンニノミヤマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('14366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県足柄上郡中井町', '14', '14361', '2590100', '神奈川県', 'カナガワケン', '足柄上郡中井町', 'アシガラカミグンナカイマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('14367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県中郡大磯町寺坂', '14', '14341', '2590101', '神奈川県', 'カナガワケン', '中郡大磯町', 'ナカグンオオイソマチ', '寺坂', 'テラサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県中郡大磯町生沢', '14', '14341', '2590102', '神奈川県', 'カナガワケン', '中郡大磯町', 'ナカグンオオイソマチ', '生沢', 'イクサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県中郡大磯町虫窪', '14', '14341', '2590103', '神奈川県', 'カナガワケン', '中郡大磯町', 'ナカグンオオイソマチ', '虫窪', 'ムシクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県中郡大磯町西久保', '14', '14341', '2590104', '神奈川県', 'カナガワケン', '中郡大磯町', 'ナカグンオオイソマチ', '西久保', 'ニシクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県中郡大磯町黒岩', '14', '14341', '2590105', '神奈川県', 'カナガワケン', '中郡大磯町', 'ナカグンオオイソマチ', '黒岩', 'クロイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県中郡大磯町国府本郷', '14', '14341', '2590111', '神奈川県', 'カナガワケン', '中郡大磯町', 'ナカグンオオイソマチ', '国府本郷', 'コクフホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県中郡大磯町国府新宿', '14', '14341', '2590112', '神奈川県', 'カナガワケン', '中郡大磯町', 'ナカグンオオイソマチ', '国府新宿', 'コクフシンシュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県中郡大磯町石神台', '14', '14341', '2590113', '神奈川県', 'カナガワケン', '中郡大磯町', 'ナカグンオオイソマチ', '石神台', 'イシガミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県中郡大磯町月京', '14', '14341', '2590114', '神奈川県', 'カナガワケン', '中郡大磯町', 'ナカグンオオイソマチ', '月京', 'ガッキョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県中郡二宮町松根', '14', '14342', '2590121', '神奈川県', 'カナガワケン', '中郡二宮町', 'ナカグンニノミヤマチ', '松根', 'マツネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県中郡二宮町富士見が丘', '14', '14342', '2590122', '神奈川県', 'カナガワケン', '中郡二宮町', 'ナカグンニノミヤマチ', '富士見が丘', 'フジミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県中郡二宮町二宮', '14', '14342', '2590123', '神奈川県', 'カナガワケン', '中郡二宮町', 'ナカグンニノミヤマチ', '二宮', 'ニノミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県中郡二宮町山西', '14', '14342', '2590124', '神奈川県', 'カナガワケン', '中郡二宮町', 'ナカグンニノミヤマチ', '山西', 'ヤマニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県中郡二宮町川匂', '14', '14342', '2590125', '神奈川県', 'カナガワケン', '中郡二宮町', 'ナカグンニノミヤマチ', '川匂', 'カワワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県中郡二宮町中里', '14', '14342', '2590131', '神奈川県', 'カナガワケン', '中郡二宮町', 'ナカグンニノミヤマチ', '中里', 'ナカザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県中郡二宮町緑が丘', '14', '14342', '2590132', '神奈川県', 'カナガワケン', '中郡二宮町', 'ナカグンニノミヤマチ', '緑が丘', 'ミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県中郡二宮町百合が丘', '14', '14342', '2590133', '神奈川県', 'カナガワケン', '中郡二宮町', 'ナカグンニノミヤマチ', '百合が丘', 'ユリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県中郡二宮町一色', '14', '14342', '2590134', '神奈川県', 'カナガワケン', '中郡二宮町', 'ナカグンニノミヤマチ', '一色', 'イシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県足柄上郡中井町遠藤', '14', '14361', '2590141', '神奈川県', 'カナガワケン', '足柄上郡中井町', 'アシガラカミグンナカイマチ', '遠藤', 'エンドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県足柄上郡中井町久所', '14', '14361', '2590142', '神奈川県', 'カナガワケン', '足柄上郡中井町', 'アシガラカミグンナカイマチ', '久所', 'グゾ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県足柄上郡中井町北田', '14', '14361', '2590143', '神奈川県', 'カナガワケン', '足柄上郡中井町', 'アシガラカミグンナカイマチ', '北田', 'キタダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県足柄上郡中井町半分形', '14', '14361', '2590144', '神奈川県', 'カナガワケン', '足柄上郡中井町', 'アシガラカミグンナカイマチ', '半分形', 'ハブガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県足柄上郡中井町田中', '14', '14361', '2590145', '神奈川県', 'カナガワケン', '足柄上郡中井町', 'アシガラカミグンナカイマチ', '田中', 'タナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県足柄上郡中井町古怒田', '14', '14361', '2590146', '神奈川県', 'カナガワケン', '足柄上郡中井町', 'アシガラカミグンナカイマチ', '古怒田', 'コヌタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県足柄上郡中井町鴨沢', '14', '14361', '2590147', '神奈川県', 'カナガワケン', '足柄上郡中井町', 'アシガラカミグンナカイマチ', '鴨沢', 'カモザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県足柄上郡中井町雑色', '14', '14361', '2590148', '神奈川県', 'カナガワケン', '足柄上郡中井町', 'アシガラカミグンナカイマチ', '雑色', 'ゾウシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県足柄上郡中井町井ノ口', '14', '14361', '2590151', '神奈川県', 'カナガワケン', '足柄上郡中井町', 'アシガラカミグンナカイマチ', '井ノ口', 'イノクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県足柄上郡中井町藤沢', '14', '14361', '2590152', '神奈川県', 'カナガワケン', '足柄上郡中井町', 'アシガラカミグンナカイマチ', '藤沢', 'フジサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県足柄上郡中井町比奈窪', '14', '14361', '2590153', '神奈川県', 'カナガワケン', '足柄上郡中井町', 'アシガラカミグンナカイマチ', '比奈窪', 'ヒナクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県足柄上郡中井町岩倉', '14', '14361', '2590154', '神奈川県', 'カナガワケン', '足柄上郡中井町', 'アシガラカミグンナカイマチ', '岩倉', 'イワクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県足柄上郡中井町松本', '14', '14361', '2590155', '神奈川県', 'カナガワケン', '足柄上郡中井町', 'アシガラカミグンナカイマチ', '松本', 'マツモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県足柄上郡中井町境別所', '14', '14361', '2590156', '神奈川県', 'カナガワケン', '足柄上郡中井町', 'アシガラカミグンナカイマチ', '境別所', 'サカイベッショ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県足柄上郡中井町境', '14', '14361', '2590157', '神奈川県', 'カナガワケン', '足柄上郡中井町', 'アシガラカミグンナカイマチ', '境', 'サカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県足柄下郡真鶴町', '14', '14383', '2590200', '神奈川県', 'カナガワケン', '足柄下郡真鶴町', 'アシガラシモグンマナヅルマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('14407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県足柄下郡真鶴町真鶴', '14', '14383', '2590201', '神奈川県', 'カナガワケン', '足柄下郡真鶴町', 'アシガラシモグンマナヅルマチ', '真鶴', 'マナツル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県足柄下郡真鶴町岩', '14', '14383', '2590202', '神奈川県', 'カナガワケン', '足柄下郡真鶴町', 'アシガラシモグンマナヅルマチ', '岩', 'イワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県足柄下郡湯河原町', '14', '14384', '2590300', '神奈川県', 'カナガワケン', '足柄下郡湯河原町', 'アシガラシモグンユガワラマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('14410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県足柄下郡湯河原町中央', '14', '14384', '2590301', '神奈川県', 'カナガワケン', '足柄下郡湯河原町', 'アシガラシモグンユガワラマチ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県足柄下郡湯河原町門川', '14', '14384', '2590302', '神奈川県', 'カナガワケン', '足柄下郡湯河原町', 'アシガラシモグンユガワラマチ', '門川', 'モンガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県足柄下郡湯河原町土肥', '14', '14384', '2590303', '神奈川県', 'カナガワケン', '足柄下郡湯河原町', 'アシガラシモグンユガワラマチ', '土肥', 'ドイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県足柄下郡湯河原町宮下', '14', '14384', '2590304', '神奈川県', 'カナガワケン', '足柄下郡湯河原町', 'アシガラシモグンユガワラマチ', '宮下', 'ミヤシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県足柄下郡湯河原町城堀', '14', '14384', '2590305', '神奈川県', 'カナガワケン', '足柄下郡湯河原町', 'アシガラシモグンユガワラマチ', '城堀', 'シロホリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県足柄下郡湯河原町福浦', '14', '14384', '2590311', '神奈川県', 'カナガワケン', '足柄下郡湯河原町', 'アシガラシモグンユガワラマチ', '福浦', 'フクウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県足柄下郡湯河原町吉浜', '14', '14384', '2590312', '神奈川県', 'カナガワケン', '足柄下郡湯河原町', 'アシガラシモグンユガワラマチ', '吉浜', 'ヨシハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県足柄下郡湯河原町鍛冶屋', '14', '14384', '2590313', '神奈川県', 'カナガワケン', '足柄下郡湯河原町', 'アシガラシモグンユガワラマチ', '鍛冶屋', 'カジヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県足柄下郡湯河原町宮上', '14', '14384', '2590314', '神奈川県', 'カナガワケン', '足柄下郡湯河原町', 'アシガラシモグンユガワラマチ', '宮上', 'ミヤカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県足柄下郡湯河原町福浦吉浜', '14', '14384', '2590316', '神奈川県', 'カナガワケン', '足柄下郡湯河原町', 'アシガラシモグンユガワラマチ', '福浦吉浜', 'フクウラヨシハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県足柄下郡湯河原町福浦鍛冶屋', '14', '14384', '2590317', '神奈川県', 'カナガワケン', '足柄下郡湯河原町', 'アシガラシモグンユガワラマチ', '福浦鍛冶屋', 'フクウラカジヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県足柄下郡湯河原町吉浜福浦', '14', '14384', '2590318', '神奈川県', 'カナガワケン', '足柄下郡湯河原町', 'アシガラシモグンユガワラマチ', '吉浜福浦', 'ヨシハマフクウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県伊勢原市', '14', '14214', '2591100', '神奈川県', 'カナガワケン', '伊勢原市', 'イセハラシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('14427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県伊勢原市日向', '14', '14214', '2591101', '神奈川県', 'カナガワケン', '伊勢原市', 'イセハラシ', '日向', 'ヒナタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県伊勢原市子易', '14', '14214', '2591102', '神奈川県', 'カナガワケン', '伊勢原市', 'イセハラシ', '子易', 'コヤス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県伊勢原市三ノ宮', '14', '14214', '2591103', '神奈川県', 'カナガワケン', '伊勢原市', 'イセハラシ', '三ノ宮', 'サンノミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県伊勢原市坪ノ内', '14', '14214', '2591104', '神奈川県', 'カナガワケン', '伊勢原市', 'イセハラシ', '坪ノ内', 'ツボノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県伊勢原市大住台', '14', '14214', '2591105', '神奈川県', 'カナガワケン', '伊勢原市', 'イセハラシ', '大住台', 'オオスミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県伊勢原市善波', '14', '14214', '2591106', '神奈川県', 'カナガワケン', '伊勢原市', 'イセハラシ', '善波', 'ゼンバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県伊勢原市大山', '14', '14214', '2591107', '神奈川県', 'カナガワケン', '伊勢原市', 'イセハラシ', '大山', 'オオヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県伊勢原市西富岡', '14', '14214', '2591111', '神奈川県', 'カナガワケン', '伊勢原市', 'イセハラシ', '西富岡', 'ニシトミオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県伊勢原市東富岡', '14', '14214', '2591112', '神奈川県', 'カナガワケン', '伊勢原市', 'イセハラシ', '東富岡', 'ヒガシトミオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県伊勢原市粟窪', '14', '14214', '2591113', '神奈川県', 'カナガワケン', '伊勢原市', 'イセハラシ', '粟窪', 'アワクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県伊勢原市高森', '14', '14214', '2591114', '神奈川県', 'カナガワケン', '伊勢原市', 'イセハラシ', '高森', 'タカモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県伊勢原市高森台', '14', '14214', '2591115', '神奈川県', 'カナガワケン', '伊勢原市', 'イセハラシ', '高森台', 'タカモリダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県伊勢原市石田', '14', '14214', '2591116', '神奈川県', 'カナガワケン', '伊勢原市', 'イセハラシ', '石田', 'イシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県伊勢原市東成瀬', '14', '14214', '2591117', '神奈川県', 'カナガワケン', '伊勢原市', 'イセハラシ', '東成瀬', 'ヒガシナルセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県伊勢原市見附島', '14', '14214', '2591118', '神奈川県', 'カナガワケン', '伊勢原市', 'イセハラシ', '見附島', 'ミツケジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県伊勢原市下落合', '14', '14214', '2591121', '神奈川県', 'カナガワケン', '伊勢原市', 'イセハラシ', '下落合', 'シモオチアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県伊勢原市小稲葉', '14', '14214', '2591122', '神奈川県', 'カナガワケン', '伊勢原市', 'イセハラシ', '小稲葉', 'コイナバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県伊勢原市下谷', '14', '14214', '2591123', '神奈川県', 'カナガワケン', '伊勢原市', 'イセハラシ', '下谷', 'シモヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県伊勢原市上平間', '14', '14214', '2591124', '神奈川県', 'カナガワケン', '伊勢原市', 'イセハラシ', '上平間', 'カミヒラマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県伊勢原市下平間', '14', '14214', '2591125', '神奈川県', 'カナガワケン', '伊勢原市', 'イセハラシ', '下平間', 'シモヒラマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県伊勢原市沼目', '14', '14214', '2591126', '神奈川県', 'カナガワケン', '伊勢原市', 'イセハラシ', '沼目', 'ヌマメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県伊勢原市上谷', '14', '14214', '2591127', '神奈川県', 'カナガワケン', '伊勢原市', 'イセハラシ', '上谷', 'カミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県伊勢原市歌川', '14', '14214', '2591128', '神奈川県', 'カナガワケン', '伊勢原市', 'イセハラシ', '歌川', 'ウタガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県伊勢原市伊勢原', '14', '14214', '2591131', '神奈川県', 'カナガワケン', '伊勢原市', 'イセハラシ', '伊勢原', 'イセハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県伊勢原市桜台', '14', '14214', '2591132', '神奈川県', 'カナガワケン', '伊勢原市', 'イセハラシ', '桜台', 'サクラダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県伊勢原市東大竹', '14', '14214', '2591133', '神奈川県', 'カナガワケン', '伊勢原市', 'イセハラシ', '東大竹', 'ヒガシオオダケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県伊勢原市八幡台', '14', '14214', '2591134', '神奈川県', 'カナガワケン', '伊勢原市', 'イセハラシ', '八幡台', 'ハチマンダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県伊勢原市岡崎', '14', '14214', '2591135', '神奈川県', 'カナガワケン', '伊勢原市', 'イセハラシ', '岡崎', 'オカザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県伊勢原市串橋', '14', '14214', '2591136', '神奈川県', 'カナガワケン', '伊勢原市', 'イセハラシ', '串橋', 'クシハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県伊勢原市笠窪', '14', '14214', '2591137', '神奈川県', 'カナガワケン', '伊勢原市', 'イセハラシ', '笠窪', 'カサクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県伊勢原市神戸', '14', '14214', '2591138', '神奈川県', 'カナガワケン', '伊勢原市', 'イセハラシ', '神戸', 'ゴウド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県伊勢原市上粕屋', '14', '14214', '2591141', '神奈川県', 'カナガワケン', '伊勢原市', 'イセハラシ', '上粕屋', 'カミカスヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県伊勢原市田中', '14', '14214', '2591142', '神奈川県', 'カナガワケン', '伊勢原市', 'イセハラシ', '田中', 'タナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県伊勢原市下糟屋', '14', '14214', '2591143', '神奈川県', 'カナガワケン', '伊勢原市', 'イセハラシ', '下糟屋', 'シモカスヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県伊勢原市池端', '14', '14214', '2591144', '神奈川県', 'カナガワケン', '伊勢原市', 'イセハラシ', '池端', 'イケバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県伊勢原市板戸', '14', '14214', '2591145', '神奈川県', 'カナガワケン', '伊勢原市', 'イセハラシ', '板戸', 'イタド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県伊勢原市鈴川', '14', '14214', '2591146', '神奈川県', 'カナガワケン', '伊勢原市', 'イセハラシ', '鈴川', 'スズカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県伊勢原市白根', '14', '14214', '2591147', '神奈川県', 'カナガワケン', '伊勢原市', 'イセハラシ', '白根', 'シラネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市南金目', '14', '14203', '2591201', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', '南金目', 'ミナミカナメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市千須谷', '14', '14203', '2591202', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', '千須谷', 'センズヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市下吉沢', '14', '14203', '2591203', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', '下吉沢', 'シモキチサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市上吉沢', '14', '14203', '2591204', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', '上吉沢', 'カミキチサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市土屋', '14', '14203', '2591205', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', '土屋', 'ツチヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市真田', '14', '14203', '2591206', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', '真田', 'サナダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市北金目', '14', '14203', '2591207', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', '北金目', 'キタカナメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市ふじみ野', '14', '14203', '2591211', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', 'ふじみ野', 'フジミノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市岡崎', '14', '14203', '2591212', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', '岡崎', 'オカザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市片岡', '14', '14203', '2591213', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', '片岡', 'カタオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市飯島', '14', '14203', '2591214', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', '飯島', 'イイジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市寺田縄', '14', '14203', '2591215', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', '寺田縄', 'テラダナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市入野', '14', '14203', '2591216', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', '入野', 'イノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市長持', '14', '14203', '2591217', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', '長持', 'ナガモチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市入部', '14', '14203', '2591218', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', '入部', 'イリブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市広川', '14', '14203', '2591219', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', '広川', 'ヒロカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県平塚市めぐみが丘', '14', '14203', '2591220', '神奈川県', 'カナガワケン', '平塚市', 'ヒラツカシ', 'めぐみが丘', 'メグミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県秦野市羽根', '14', '14211', '2591301', '神奈川県', 'カナガワケン', '秦野市', 'ハダノシ', '羽根', 'ハネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県秦野市菩提', '14', '14211', '2591302', '神奈川県', 'カナガワケン', '秦野市', 'ハダノシ', '菩提', 'ボダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県秦野市三屋', '14', '14211', '2591303', '神奈川県', 'カナガワケン', '秦野市', 'ハダノシ', '三屋', 'サンヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県秦野市堀山下', '14', '14211', '2591304', '神奈川県', 'カナガワケン', '秦野市', 'ハダノシ', '堀山下', 'ホリヤマシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県秦野市堀川', '14', '14211', '2591305', '神奈川県', 'カナガワケン', '秦野市', 'ハダノシ', '堀川', 'ホリカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県秦野市戸川', '14', '14211', '2591306', '神奈川県', 'カナガワケン', '秦野市', 'ハダノシ', '戸川', 'トカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県秦野市横野', '14', '14211', '2591307', '神奈川県', 'カナガワケン', '秦野市', 'ハダノシ', '横野', 'ヨコノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県秦野市弥生町', '14', '14211', '2591311', '神奈川県', 'カナガワケン', '秦野市', 'ハダノシ', '弥生町', 'ヤヨイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県秦野市春日町', '14', '14211', '2591312', '神奈川県', 'カナガワケン', '秦野市', 'ハダノシ', '春日町', 'カスガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県秦野市松原町', '14', '14211', '2591313', '神奈川県', 'カナガワケン', '秦野市', 'ハダノシ', '松原町', 'マツバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県秦野市若松町', '14', '14211', '2591314', '神奈川県', 'カナガワケン', '秦野市', 'ハダノシ', '若松町', 'ワカマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県秦野市柳町', '14', '14211', '2591315', '神奈川県', 'カナガワケン', '秦野市', 'ハダノシ', '柳町', 'ヤナギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県秦野市沼代新町', '14', '14211', '2591316', '神奈川県', 'カナガワケン', '秦野市', 'ハダノシ', '沼代新町', 'ヌマシロシンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県秦野市並木町', '14', '14211', '2591317', '神奈川県', 'カナガワケン', '秦野市', 'ハダノシ', '並木町', 'ナミキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県秦野市曲松', '14', '14211', '2591321', '神奈川県', 'カナガワケン', '秦野市', 'ハダノシ', '曲松', 'マガリマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県秦野市渋沢', '14', '14211', '2591322', '神奈川県', 'カナガワケン', '秦野市', 'ハダノシ', '渋沢', 'シブサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県秦野市栃窪', '14', '14211', '2591323', '神奈川県', 'カナガワケン', '秦野市', 'ハダノシ', '栃窪', 'トチクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県秦野市千村', '14', '14211', '2591324', '神奈川県', 'カナガワケン', '秦野市', 'ハダノシ', '千村', 'チムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県秦野市萩が丘', '14', '14211', '2591325', '神奈川県', 'カナガワケン', '秦野市', 'ハダノシ', '萩が丘', 'ハギガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県秦野市渋沢上', '14', '14211', '2591326', '神奈川県', 'カナガワケン', '秦野市', 'ハダノシ', '渋沢上', 'シブサワカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県秦野市堀西', '14', '14211', '2591331', '神奈川県', 'カナガワケン', '秦野市', 'ハダノシ', '堀西', 'ホリニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県秦野市菖蒲', '14', '14211', '2591332', '神奈川県', 'カナガワケン', '秦野市', 'ハダノシ', '菖蒲', 'ショウブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県秦野市八沢', '14', '14211', '2591333', '神奈川県', 'カナガワケン', '秦野市', 'ハダノシ', '八沢', 'ハッサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県秦野市柳川', '14', '14211', '2591334', '神奈川県', 'カナガワケン', '秦野市', 'ハダノシ', '柳川', 'ヤナガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '神奈川県秦野市三廻部', '14', '14211', '2591335', '神奈川県', 'カナガワケン', '秦野市', 'ハダノシ', '三廻部', 'ミクルベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県釜石市', '03', '03211', '0260000', '岩手県', 'イワテケン', '釜石市', 'カマイシシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('14520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市中央区', '12', '12101', '2600000', '千葉県', 'チバケン', '千葉市中央区', 'チバシチュウオウク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('14521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市中央区都町', '12', '12101', '2600001', '千葉県', 'チバケン', '千葉市中央区', 'チバシチュウオウク', '都町', 'ミヤコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市中央区旭町', '12', '12101', '2600002', '千葉県', 'チバケン', '千葉市中央区', 'チバシチュウオウク', '旭町', 'アサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市中央区鶴沢町', '12', '12101', '2600003', '千葉県', 'チバケン', '千葉市中央区', 'チバシチュウオウク', '鶴沢町', 'ツルサワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市中央区東本町', '12', '12101', '2600004', '千葉県', 'チバケン', '千葉市中央区', 'チバシチュウオウク', '東本町', 'ヒガシホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市中央区道場南', '12', '12101', '2600005', '千葉県', 'チバケン', '千葉市中央区', 'チバシチュウオウク', '道場南', 'ドウジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市中央区道場北', '12', '12101', '2600006', '千葉県', 'チバケン', '千葉市中央区', 'チバシチュウオウク', '道場北', 'ドウジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市中央区祐光', '12', '12101', '2600007', '千葉県', 'チバケン', '千葉市中央区', 'チバシチュウオウク', '祐光', 'ユウコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県釜石市平田', '03', '03211', '0260001', '岩手県', 'イワテケン', '釜石市', 'カマイシシ', '平田', 'ヘイタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市中央区亀井町', '12', '12101', '2600011', '千葉県', 'チバケン', '千葉市中央区', 'チバシチュウオウク', '亀井町', 'カメイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市中央区本町', '12', '12101', '2600012', '千葉県', 'チバケン', '千葉市中央区', 'チバシチュウオウク', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市中央区中央', '12', '12101', '2600013', '千葉県', 'チバケン', '千葉市中央区', 'チバシチュウオウク', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市中央区本千葉町', '12', '12101', '2600014', '千葉県', 'チバケン', '千葉市中央区', 'チバシチュウオウク', '本千葉町', 'ホンチバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市中央区富士見', '12', '12101', '2600015', '千葉県', 'チバケン', '千葉市中央区', 'チバシチュウオウク', '富士見', 'フジミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市中央区栄町', '12', '12101', '2600016', '千葉県', 'チバケン', '千葉市中央区', 'チバシチュウオウク', '栄町', 'サカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市中央区要町', '12', '12101', '2600017', '千葉県', 'チバケン', '千葉市中央区', 'チバシチュウオウク', '要町', 'カナメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市中央区院内', '12', '12101', '2600018', '千葉県', 'チバケン', '千葉市中央区', 'チバシチュウオウク', '院内', 'インナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県釜石市大平町', '03', '03211', '0260002', '岩手県', 'イワテケン', '釜石市', 'カマイシシ', '大平町', 'オオダイラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市中央区新宿', '12', '12101', '2600021', '千葉県', 'チバケン', '千葉市中央区', 'チバシチュウオウク', '新宿', 'シンジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市中央区神明町', '12', '12101', '2600022', '千葉県', 'チバケン', '千葉市中央区', 'チバシチュウオウク', '神明町', 'シンメイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市中央区出洲港', '12', '12101', '2600023', '千葉県', 'チバケン', '千葉市中央区', 'チバシチュウオウク', '出洲港', 'デズミナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市中央区中央港', '12', '12101', '2600024', '千葉県', 'チバケン', '千葉市中央区', 'チバシチュウオウク', '中央港', 'チュウオウコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市中央区問屋町', '12', '12101', '2600025', '千葉県', 'チバケン', '千葉市中央区', 'チバシチュウオウク', '問屋町', 'トンヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市中央区千葉港', '12', '12101', '2600026', '千葉県', 'チバケン', '千葉市中央区', 'チバシチュウオウク', '千葉港', 'チバミナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市中央区新田町', '12', '12101', '2600027', '千葉県', 'チバケン', '千葉市中央区', 'チバシチュウオウク', '新田町', 'シンデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市中央区新町', '12', '12101', '2600028', '千葉県', 'チバケン', '千葉市中央区', 'チバシチュウオウク', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県釜石市嬉石町', '03', '03211', '0260003', '岩手県', 'イワテケン', '釜石市', 'カマイシシ', '嬉石町', 'ウレイシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市中央区新千葉', '12', '12101', '2600031', '千葉県', 'チバケン', '千葉市中央区', 'チバシチュウオウク', '新千葉', 'シンチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市中央区登戸', '12', '12101', '2600032', '千葉県', 'チバケン', '千葉市中央区', 'チバシチュウオウク', '登戸', 'ノブト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市中央区春日', '12', '12101', '2600033', '千葉県', 'チバケン', '千葉市中央区', 'チバシチュウオウク', '春日', 'カスガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市中央区汐見丘町', '12', '12101', '2600034', '千葉県', 'チバケン', '千葉市中央区', 'チバシチュウオウク', '汐見丘町', 'シオミガオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県釜石市松原町', '03', '03211', '0260004', '岩手県', 'イワテケン', '釜石市', 'カマイシシ', '松原町', 'マツバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市中央区東千葉', '12', '12101', '2600041', '千葉県', 'チバケン', '千葉市中央区', 'チバシチュウオウク', '東千葉', 'ヒガシチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市中央区椿森', '12', '12101', '2600042', '千葉県', 'チバケン', '千葉市中央区', 'チバシチュウオウク', '椿森', 'ツバキモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市中央区松波', '12', '12101', '2600044', '千葉県', 'チバケン', '千葉市中央区', 'チバシチュウオウク', '松波', 'マツナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市中央区弁天', '12', '12101', '2600045', '千葉県', 'チバケン', '千葉市中央区', 'チバシチュウオウク', '弁天', 'ベンテン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県釜石市港町', '03', '03211', '0260011', '岩手県', 'イワテケン', '釜石市', 'カマイシシ', '港町', 'ミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県釜石市魚河岸', '03', '03211', '0260012', '岩手県', 'イワテケン', '釜石市', 'カマイシシ', '魚河岸', 'ウオガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県釜石市浜町', '03', '03211', '0260013', '岩手県', 'イワテケン', '釜石市', 'カマイシシ', '浜町', 'ハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県釜石市東前町', '03', '03211', '0260014', '岩手県', 'イワテケン', '釜石市', 'カマイシシ', '東前町', 'ヒガシマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県釜石市新浜町', '03', '03211', '0260015', '岩手県', 'イワテケン', '釜石市', 'カマイシシ', '新浜町', 'シンハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県釜石市只越町', '03', '03211', '0260021', '岩手県', 'イワテケン', '釜石市', 'カマイシシ', '只越町', 'タダコエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県釜石市大只越町', '03', '03211', '0260022', '岩手県', 'イワテケン', '釜石市', 'カマイシシ', '大只越町', 'オオタダコエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県釜石市天神町', '03', '03211', '0260023', '岩手県', 'イワテケン', '釜石市', 'カマイシシ', '天神町', 'テンジンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県釜石市大町', '03', '03211', '0260024', '岩手県', 'イワテケン', '釜石市', 'カマイシシ', '大町', 'オオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県釜石市大渡町', '03', '03211', '0260025', '岩手県', 'イワテケン', '釜石市', 'カマイシシ', '大渡町', 'オオワタリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県釜石市釜石', '03', '03211', '0260026', '岩手県', 'イワテケン', '釜石市', 'カマイシシ', '釜石', 'カマイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県釜石市鈴子町', '03', '03211', '0260031', '岩手県', 'イワテケン', '釜石市', 'カマイシシ', '鈴子町', 'スズコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県釜石市千鳥町', '03', '03211', '0260032', '岩手県', 'イワテケン', '釜石市', 'カマイシシ', '千鳥町', 'チドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県釜石市駒木町', '03', '03211', '0260033', '岩手県', 'イワテケン', '釜石市', 'カマイシシ', '駒木町', 'コマギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県釜石市中妻町', '03', '03211', '0260034', '岩手県', 'イワテケン', '釜石市', 'カマイシシ', '中妻町', 'ナカヅマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県釜石市八雲町', '03', '03211', '0260035', '岩手県', 'イワテケン', '釜石市', 'カマイシシ', '八雲町', 'ヤグモチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県釜石市上中島町', '03', '03211', '0260041', '岩手県', 'イワテケン', '釜石市', 'カマイシシ', '上中島町', 'カミナカシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県釜石市源太沢町', '03', '03211', '0260042', '岩手県', 'イワテケン', '釜石市', 'カマイシシ', '源太沢町', 'ゲンタサワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県釜石市新町', '03', '03211', '0260043', '岩手県', 'イワテケン', '釜石市', 'カマイシシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県釜石市住吉町', '03', '03211', '0260044', '岩手県', 'イワテケン', '釜石市', 'カマイシシ', '住吉町', 'スミヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県釜石市小川町', '03', '03211', '0260045', '岩手県', 'イワテケン', '釜石市', 'カマイシシ', '小川町', 'コガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県釜石市桜木町', '03', '03211', '0260046', '岩手県', 'イワテケン', '釜石市', 'カマイシシ', '桜木町', 'サクラギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県釜石市礼ケ口町', '03', '03211', '0260051', '岩手県', 'イワテケン', '釜石市', 'カマイシシ', '礼ケ口町', 'レイガグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県釜石市小佐野町', '03', '03211', '0260052', '岩手県', 'イワテケン', '釜石市', 'カマイシシ', '小佐野町', 'コサノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県釜石市定内町', '03', '03211', '0260053', '岩手県', 'イワテケン', '釜石市', 'カマイシシ', '定内町', 'サダナイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県釜石市野田町', '03', '03211', '0260054', '岩手県', 'イワテケン', '釜石市', 'カマイシシ', '野田町', 'ノダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県釜石市甲子町', '03', '03211', '0260055', '岩手県', 'イワテケン', '釜石市', 'カマイシシ', '甲子町', 'カッシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県釜石市唐丹町鍋倉', '03', '03211', '0260061', '岩手県', 'イワテケン', '釜石市', 'カマイシシ', '唐丹町', 'トウニチョウ', null, null, '鍋倉', 'ナベクラ');
INSERT INTO `ms_addresses` VALUES ('14584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市中央区仁戸名町', '12', '12101', '2600801', '千葉県', 'チバケン', '千葉市中央区', 'チバシチュウオウク', '仁戸名町', 'ニトナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市中央区川戸町', '12', '12101', '2600802', '千葉県', 'チバケン', '千葉市中央区', 'チバシチュウオウク', '川戸町', 'カワドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市中央区花輪町', '12', '12101', '2600803', '千葉県', 'チバケン', '千葉市中央区', 'チバシチュウオウク', '花輪町', 'ハナワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市中央区赤井町', '12', '12101', '2600804', '千葉県', 'チバケン', '千葉市中央区', 'チバシチュウオウク', '赤井町', 'アカイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市中央区宮崎町', '12', '12101', '2600805', '千葉県', 'チバケン', '千葉市中央区', 'チバシチュウオウク', '宮崎町', 'ミヤザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市中央区宮崎', '12', '12101', '2600806', '千葉県', 'チバケン', '千葉市中央区', 'チバシチュウオウク', '宮崎', 'ミヤザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市中央区松ケ丘町', '12', '12101', '2600807', '千葉県', 'チバケン', '千葉市中央区', 'チバシチュウオウク', '松ケ丘町', 'マツガオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市中央区星久喜町', '12', '12101', '2600808', '千葉県', 'チバケン', '千葉市中央区', 'チバシチュウオウク', '星久喜町', 'ホシグキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市中央区大森町', '12', '12101', '2600811', '千葉県', 'チバケン', '千葉市中央区', 'チバシチュウオウク', '大森町', 'オオモリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市中央区大巌寺町', '12', '12101', '2600812', '千葉県', 'チバケン', '千葉市中央区', 'チバシチュウオウク', '大巌寺町', 'ダイガンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市中央区生実町', '12', '12101', '2600813', '千葉県', 'チバケン', '千葉市中央区', 'チバシチュウオウク', '生実町', 'オユミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市中央区南生実町', '12', '12101', '2600814', '千葉県', 'チバケン', '千葉市中央区', 'チバシチュウオウク', '南生実町', 'ミナミオユミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市中央区今井町', '12', '12101', '2600815', '千葉県', 'チバケン', '千葉市中央区', 'チバシチュウオウク', '今井町', 'イマイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市中央区鵜の森町', '12', '12101', '2600816', '千葉県', 'チバケン', '千葉市中央区', 'チバシチュウオウク', '鵜の森町', 'ウノモリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市中央区若草', '12', '12101', '2600821', '千葉県', 'チバケン', '千葉市中央区', 'チバシチュウオウク', '若草', 'ワカクサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市中央区蘇我', '12', '12101', '2600822', '千葉県', 'チバケン', '千葉市中央区', 'チバシチュウオウク', '蘇我', 'ソガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市中央区蘇我町', '12', '12101', '2600822', '千葉県', 'チバケン', '千葉市中央区', 'チバシチュウオウク', '蘇我町', 'ソガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市中央区塩田町', '12', '12101', '2600823', '千葉県', 'チバケン', '千葉市中央区', 'チバシチュウオウク', '塩田町', 'シオダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市中央区浜野町', '12', '12101', '2600824', '千葉県', 'チバケン', '千葉市中央区', 'チバシチュウオウク', '浜野町', 'ハマノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市中央区村田町', '12', '12101', '2600825', '千葉県', 'チバケン', '千葉市中央区', 'チバシチュウオウク', '村田町', 'ムラタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市中央区新浜町', '12', '12101', '2600826', '千葉県', 'チバケン', '千葉市中央区', 'チバシチュウオウク', '新浜町', 'ニイハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市中央区港町', '12', '12101', '2600831', '千葉県', 'チバケン', '千葉市中央区', 'チバシチュウオウク', '港町', 'ミナトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市中央区寒川町', '12', '12101', '2600832', '千葉県', 'チバケン', '千葉市中央区', 'チバシチュウオウク', '寒川町', 'サムガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市中央区稲荷町', '12', '12101', '2600833', '千葉県', 'チバケン', '千葉市中央区', 'チバシチュウオウク', '稲荷町', 'イナリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市中央区今井', '12', '12101', '2600834', '千葉県', 'チバケン', '千葉市中央区', 'チバシチュウオウク', '今井', 'イマイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市中央区川崎町', '12', '12101', '2600835', '千葉県', 'チバケン', '千葉市中央区', 'チバシチュウオウク', '川崎町', 'カワサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市中央区白旗', '12', '12101', '2600841', '千葉県', 'チバケン', '千葉市中央区', 'チバシチュウオウク', '白旗', 'シラハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市中央区南町', '12', '12101', '2600842', '千葉県', 'チバケン', '千葉市中央区', 'チバシチュウオウク', '南町', 'ミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市中央区末広', '12', '12101', '2600843', '千葉県', 'チバケン', '千葉市中央区', 'チバシチュウオウク', '末広', 'スエヒロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市中央区千葉寺町', '12', '12101', '2600844', '千葉県', 'チバケン', '千葉市中央区', 'チバシチュウオウク', '千葉寺町', 'チバデラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市中央区矢作町', '12', '12101', '2600851', '千葉県', 'チバケン', '千葉市中央区', 'チバシチュウオウク', '矢作町', 'ヤハギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市中央区青葉町', '12', '12101', '2600852', '千葉県', 'チバケン', '千葉市中央区', 'チバシチュウオウク', '青葉町', 'アオバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市中央区葛城', '12', '12101', '2600853', '千葉県', 'チバケン', '千葉市中央区', 'チバシチュウオウク', '葛城', 'カツラギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市中央区長洲', '12', '12101', '2600854', '千葉県', 'チバケン', '千葉市中央区', 'チバシチュウオウク', '長洲', 'ナガズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市中央区市場町', '12', '12101', '2600855', '千葉県', 'チバケン', '千葉市中央区', 'チバシチュウオウク', '市場町', 'イチバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市中央区亥鼻', '12', '12101', '2600856', '千葉県', 'チバケン', '千葉市中央区', 'チバシチュウオウク', '亥鼻', 'イノハナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市中央区亀岡町', '12', '12101', '2600857', '千葉県', 'チバケン', '千葉市中央区', 'チバシチュウオウク', '亀岡町', 'カメオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県釜石市唐丹町', '03', '03211', '0260121', '岩手県', 'イワテケン', '釜石市', 'カマイシシ', '唐丹町', 'トウニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県釜石市鵜住居町', '03', '03211', '0260301', '岩手県', 'イワテケン', '釜石市', 'カマイシシ', '鵜住居町', 'ウノズマイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県釜石市片岸町', '03', '03211', '0260302', '岩手県', 'イワテケン', '釜石市', 'カマイシシ', '片岸町', 'カタギシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県釜石市箱崎町', '03', '03211', '0260303', '岩手県', 'イワテケン', '釜石市', 'カマイシシ', '箱崎町', 'ハコザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県釜石市両石町', '03', '03211', '0260304', '岩手県', 'イワテケン', '釜石市', 'カマイシシ', '両石町', 'リョウイシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県釜石市橋野町', '03', '03211', '0260411', '岩手県', 'イワテケン', '釜石市', 'カマイシシ', '橋野町', 'ハシノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県釜石市栗林町', '03', '03211', '0260412', '岩手県', 'イワテケン', '釜石市', 'カマイシシ', '栗林町', 'クリバヤシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市美浜区', '12', '12106', '2610000', '千葉県', 'チバケン', '千葉市美浜区', 'チバシミハマク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('14720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市美浜区幸町', '12', '12106', '2610001', '千葉県', 'チバケン', '千葉市美浜区', 'チバシミハマク', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市美浜区新港', '12', '12106', '2610002', '千葉県', 'チバケン', '千葉市美浜区', 'チバシミハマク', '新港', 'シンミナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市美浜区高浜', '12', '12106', '2610003', '千葉県', 'チバケン', '千葉市美浜区', 'チバシミハマク', '高浜', 'タカハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市美浜区高洲', '12', '12106', '2610004', '千葉県', 'チバケン', '千葉市美浜区', 'チバシミハマク', '高洲', 'タカス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市美浜区稲毛海岸', '12', '12106', '2610005', '千葉県', 'チバケン', '千葉市美浜区', 'チバシミハマク', '稲毛海岸', 'イナゲカイガン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市美浜区真砂', '12', '12106', '2610011', '千葉県', 'チバケン', '千葉市美浜区', 'チバシミハマク', '真砂', 'マサゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市美浜区磯辺', '12', '12106', '2610012', '千葉県', 'チバケン', '千葉市美浜区', 'チバシミハマク', '磯辺', 'イソベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市美浜区打瀬', '12', '12106', '2610013', '千葉県', 'チバケン', '千葉市美浜区', 'チバシミハマク', '打瀬', 'ウタセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市美浜区若葉', '12', '12106', '2610014', '千葉県', 'チバケン', '千葉市美浜区', 'チバシミハマク', '若葉', 'ワカバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市美浜区ひび野', '12', '12106', '2610021', '千葉県', 'チバケン', '千葉市美浜区', 'チバシミハマク', 'ひび野', 'ヒビノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市美浜区美浜', '12', '12106', '2610022', '千葉県', 'チバケン', '千葉市美浜区', 'チバシミハマク', '美浜', 'ミハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市美浜区中瀬', '12', '12106', '2610023', '千葉県', 'チバケン', '千葉市美浜区', 'チバシミハマク', '中瀬', 'ナカセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市美浜区豊砂', '12', '12106', '2610024', '千葉県', 'チバケン', '千葉市美浜区', 'チバシミハマク', '豊砂', 'トヨスナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市美浜区浜田', '12', '12106', '2610025', '千葉県', 'チバケン', '千葉市美浜区', 'チバシミハマク', '浜田', 'ハマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市美浜区幕張西', '12', '12106', '2610026', '千葉県', 'チバケン', '千葉市美浜区', 'チバシミハマク', '幕張西', 'マクハリニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市美浜区中瀬ワールドビジネスガーデン　1階', '12', '12106', '2617101', '千葉県', 'チバケン', '千葉市美浜区', 'チバシミハマク', '中瀬', 'ナカセ', null, null, 'ワールドビジネスガーデン　1階', 'ワールドビジネスガーデン　01カイ');
INSERT INTO `ms_addresses` VALUES ('14736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市美浜区中瀬ワールドビジネスガーデン　2階', '12', '12106', '2617102', '千葉県', 'チバケン', '千葉市美浜区', 'チバシミハマク', '中瀬', 'ナカセ', null, null, 'ワールドビジネスガーデン　2階', 'ワールドビジネスガーデン　02カイ');
INSERT INTO `ms_addresses` VALUES ('14737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市美浜区中瀬ワールドビジネスガーデン　3階', '12', '12106', '2617103', '千葉県', 'チバケン', '千葉市美浜区', 'チバシミハマク', '中瀬', 'ナカセ', null, null, 'ワールドビジネスガーデン　3階', 'ワールドビジネスガーデン　03カイ');
INSERT INTO `ms_addresses` VALUES ('14738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市美浜区中瀬ワールドビジネスガーデン　4階', '12', '12106', '2617104', '千葉県', 'チバケン', '千葉市美浜区', 'チバシミハマク', '中瀬', 'ナカセ', null, null, 'ワールドビジネスガーデン　4階', 'ワールドビジネスガーデン　04カイ');
INSERT INTO `ms_addresses` VALUES ('14739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市美浜区中瀬ワールドビジネスガーデン　5階', '12', '12106', '2617105', '千葉県', 'チバケン', '千葉市美浜区', 'チバシミハマク', '中瀬', 'ナカセ', null, null, 'ワールドビジネスガーデン　5階', 'ワールドビジネスガーデン　05カイ');
INSERT INTO `ms_addresses` VALUES ('14740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市美浜区中瀬ワールドビジネスガーデン　6階', '12', '12106', '2617106', '千葉県', 'チバケン', '千葉市美浜区', 'チバシミハマク', '中瀬', 'ナカセ', null, null, 'ワールドビジネスガーデン　6階', 'ワールドビジネスガーデン　06カイ');
INSERT INTO `ms_addresses` VALUES ('14741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市美浜区中瀬ワールドビジネスガーデン　7階', '12', '12106', '2617107', '千葉県', 'チバケン', '千葉市美浜区', 'チバシミハマク', '中瀬', 'ナカセ', null, null, 'ワールドビジネスガーデン　7階', 'ワールドビジネスガーデン　07カイ');
INSERT INTO `ms_addresses` VALUES ('14742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市美浜区中瀬ワールドビジネスガーデン　8階', '12', '12106', '2617108', '千葉県', 'チバケン', '千葉市美浜区', 'チバシミハマク', '中瀬', 'ナカセ', null, null, 'ワールドビジネスガーデン　8階', 'ワールドビジネスガーデン　08カイ');
INSERT INTO `ms_addresses` VALUES ('14743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市美浜区中瀬ワールドビジネスガーデン　9階', '12', '12106', '2617109', '千葉県', 'チバケン', '千葉市美浜区', 'チバシミハマク', '中瀬', 'ナカセ', null, null, 'ワールドビジネスガーデン　9階', 'ワールドビジネスガーデン　09カイ');
INSERT INTO `ms_addresses` VALUES ('14744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市美浜区中瀬ワールドビジネスガーデン　10階', '12', '12106', '2617110', '千葉県', 'チバケン', '千葉市美浜区', 'チバシミハマク', '中瀬', 'ナカセ', null, null, 'ワールドビジネスガーデン　10階', 'ワールドビジネスガーデン　10カイ');
INSERT INTO `ms_addresses` VALUES ('14745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市美浜区中瀬ワールドビジネスガーデン　11階', '12', '12106', '2617111', '千葉県', 'チバケン', '千葉市美浜区', 'チバシミハマク', '中瀬', 'ナカセ', null, null, 'ワールドビジネスガーデン　11階', 'ワールドビジネスガーデン　11カイ');
INSERT INTO `ms_addresses` VALUES ('14746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市美浜区中瀬ワールドビジネスガーデン　12階', '12', '12106', '2617112', '千葉県', 'チバケン', '千葉市美浜区', 'チバシミハマク', '中瀬', 'ナカセ', null, null, 'ワールドビジネスガーデン　12階', 'ワールドビジネスガーデン　12カイ');
INSERT INTO `ms_addresses` VALUES ('14747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市美浜区中瀬ワールドビジネスガーデン　13階', '12', '12106', '2617113', '千葉県', 'チバケン', '千葉市美浜区', 'チバシミハマク', '中瀬', 'ナカセ', null, null, 'ワールドビジネスガーデン　13階', 'ワールドビジネスガーデン　13カイ');
INSERT INTO `ms_addresses` VALUES ('14748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市美浜区中瀬ワールドビジネスガーデン　14階', '12', '12106', '2617114', '千葉県', 'チバケン', '千葉市美浜区', 'チバシミハマク', '中瀬', 'ナカセ', null, null, 'ワールドビジネスガーデン　14階', 'ワールドビジネスガーデン　14カイ');
INSERT INTO `ms_addresses` VALUES ('14749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市美浜区中瀬ワールドビジネスガーデン　15階', '12', '12106', '2617115', '千葉県', 'チバケン', '千葉市美浜区', 'チバシミハマク', '中瀬', 'ナカセ', null, null, 'ワールドビジネスガーデン　15階', 'ワールドビジネスガーデン　15カイ');
INSERT INTO `ms_addresses` VALUES ('14750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市美浜区中瀬ワールドビジネスガーデン　16階', '12', '12106', '2617116', '千葉県', 'チバケン', '千葉市美浜区', 'チバシミハマク', '中瀬', 'ナカセ', null, null, 'ワールドビジネスガーデン　16階', 'ワールドビジネスガーデン　16カイ');
INSERT INTO `ms_addresses` VALUES ('14751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市美浜区中瀬ワールドビジネスガーデン　17階', '12', '12106', '2617117', '千葉県', 'チバケン', '千葉市美浜区', 'チバシミハマク', '中瀬', 'ナカセ', null, null, 'ワールドビジネスガーデン　17階', 'ワールドビジネスガーデン　17カイ');
INSERT INTO `ms_addresses` VALUES ('14752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市美浜区中瀬ワールドビジネスガーデン　18階', '12', '12106', '2617118', '千葉県', 'チバケン', '千葉市美浜区', 'チバシミハマク', '中瀬', 'ナカセ', null, null, 'ワールドビジネスガーデン　18階', 'ワールドビジネスガーデン　18カイ');
INSERT INTO `ms_addresses` VALUES ('14753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市美浜区中瀬ワールドビジネスガーデン　19階', '12', '12106', '2617119', '千葉県', 'チバケン', '千葉市美浜区', 'チバシミハマク', '中瀬', 'ナカセ', null, null, 'ワールドビジネスガーデン　19階', 'ワールドビジネスガーデン　19カイ');
INSERT INTO `ms_addresses` VALUES ('14754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市美浜区中瀬ワールドビジネスガーデン　20階', '12', '12106', '2617120', '千葉県', 'チバケン', '千葉市美浜区', 'チバシミハマク', '中瀬', 'ナカセ', null, null, 'ワールドビジネスガーデン　20階', 'ワールドビジネスガーデン　20カイ');
INSERT INTO `ms_addresses` VALUES ('14755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市美浜区中瀬ワールドビジネスガーデン　21階', '12', '12106', '2617121', '千葉県', 'チバケン', '千葉市美浜区', 'チバシミハマク', '中瀬', 'ナカセ', null, null, 'ワールドビジネスガーデン　21階', 'ワールドビジネスガーデン　21カイ');
INSERT INTO `ms_addresses` VALUES ('14756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市美浜区中瀬ワールドビジネスガーデン　22階', '12', '12106', '2617122', '千葉県', 'チバケン', '千葉市美浜区', 'チバシミハマク', '中瀬', 'ナカセ', null, null, 'ワールドビジネスガーデン　22階', 'ワールドビジネスガーデン　22カイ');
INSERT INTO `ms_addresses` VALUES ('14757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市美浜区中瀬ワールドビジネスガーデン　23階', '12', '12106', '2617123', '千葉県', 'チバケン', '千葉市美浜区', 'チバシミハマク', '中瀬', 'ナカセ', null, null, 'ワールドビジネスガーデン　23階', 'ワールドビジネスガーデン　23カイ');
INSERT INTO `ms_addresses` VALUES ('14758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市美浜区中瀬ワールドビジネスガーデン　24階', '12', '12106', '2617124', '千葉県', 'チバケン', '千葉市美浜区', 'チバシミハマク', '中瀬', 'ナカセ', null, null, 'ワールドビジネスガーデン　24階', 'ワールドビジネスガーデン　24カイ');
INSERT INTO `ms_addresses` VALUES ('14759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市美浜区中瀬ワールドビジネスガーデン　25階', '12', '12106', '2617125', '千葉県', 'チバケン', '千葉市美浜区', 'チバシミハマク', '中瀬', 'ナカセ', null, null, 'ワールドビジネスガーデン　25階', 'ワールドビジネスガーデン　25カイ');
INSERT INTO `ms_addresses` VALUES ('14760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市美浜区中瀬ワールドビジネスガーデン　26階', '12', '12106', '2617126', '千葉県', 'チバケン', '千葉市美浜区', 'チバシミハマク', '中瀬', 'ナカセ', null, null, 'ワールドビジネスガーデン　26階', 'ワールドビジネスガーデン　26カイ');
INSERT INTO `ms_addresses` VALUES ('14761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市美浜区中瀬ワールドビジネスガーデン　27階', '12', '12106', '2617127', '千葉県', 'チバケン', '千葉市美浜区', 'チバシミハマク', '中瀬', 'ナカセ', null, null, 'ワールドビジネスガーデン　27階', 'ワールドビジネスガーデン　27カイ');
INSERT INTO `ms_addresses` VALUES ('14762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市美浜区中瀬ワールドビジネスガーデン　28階', '12', '12106', '2617128', '千葉県', 'チバケン', '千葉市美浜区', 'チバシミハマク', '中瀬', 'ナカセ', null, null, 'ワールドビジネスガーデン　28階', 'ワールドビジネスガーデン　28カイ');
INSERT INTO `ms_addresses` VALUES ('14763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市美浜区中瀬ワールドビジネスガーデン　29階', '12', '12106', '2617129', '千葉県', 'チバケン', '千葉市美浜区', 'チバシミハマク', '中瀬', 'ナカセ', null, null, 'ワールドビジネスガーデン　29階', 'ワールドビジネスガーデン　29カイ');
INSERT INTO `ms_addresses` VALUES ('14764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市美浜区中瀬ワールドビジネスガーデン　30階', '12', '12106', '2617130', '千葉県', 'チバケン', '千葉市美浜区', 'チバシミハマク', '中瀬', 'ナカセ', null, null, 'ワールドビジネスガーデン　30階', 'ワールドビジネスガーデン　30カイ');
INSERT INTO `ms_addresses` VALUES ('14765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市美浜区中瀬ワールドビジネスガーデン　31階', '12', '12106', '2617131', '千葉県', 'チバケン', '千葉市美浜区', 'チバシミハマク', '中瀬', 'ナカセ', null, null, 'ワールドビジネスガーデン　31階', 'ワールドビジネスガーデン　31カイ');
INSERT INTO `ms_addresses` VALUES ('14766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市美浜区中瀬ワールドビジネスガーデン　32階', '12', '12106', '2617132', '千葉県', 'チバケン', '千葉市美浜区', 'チバシミハマク', '中瀬', 'ナカセ', null, null, 'ワールドビジネスガーデン　32階', 'ワールドビジネスガーデン　32カイ');
INSERT INTO `ms_addresses` VALUES ('14767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市美浜区中瀬ワールドビジネスガーデン　33階', '12', '12106', '2617133', '千葉県', 'チバケン', '千葉市美浜区', 'チバシミハマク', '中瀬', 'ナカセ', null, null, 'ワールドビジネスガーデン　33階', 'ワールドビジネスガーデン　33カイ');
INSERT INTO `ms_addresses` VALUES ('14768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市美浜区中瀬ワールドビジネスガーデン　34階', '12', '12106', '2617134', '千葉県', 'チバケン', '千葉市美浜区', 'チバシミハマク', '中瀬', 'ナカセ', null, null, 'ワールドビジネスガーデン　34階', 'ワールドビジネスガーデン　34カイ');
INSERT INTO `ms_addresses` VALUES ('14769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市美浜区中瀬ワールドビジネスガーデン　35階', '12', '12106', '2617135', '千葉県', 'チバケン', '千葉市美浜区', 'チバシミハマク', '中瀬', 'ナカセ', null, null, 'ワールドビジネスガーデン　35階', 'ワールドビジネスガーデン　35カイ');
INSERT INTO `ms_addresses` VALUES ('14770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市美浜区中瀬ワールドビジネスガーデン　', '12', '12106', '2617190', '千葉県', 'チバケン', '千葉市美浜区', 'チバシミハマク', '中瀬', 'ナカセ', null, null, 'ワールドビジネスガーデン　', 'ワールドビジネスガーデン　');
INSERT INTO `ms_addresses` VALUES ('14799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市花見川区', '12', '12102', '2620000', '千葉県', 'チバケン', '千葉市花見川区', 'チバシハナミガワク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('14800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市花見川区横戸町', '12', '12102', '2620001', '千葉県', 'チバケン', '千葉市花見川区', 'チバシハナミガワク', '横戸町', 'ヨコドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市花見川区内山町', '12', '12102', '2620002', '千葉県', 'チバケン', '千葉市花見川区', 'チバシハナミガワク', '内山町', 'ウチヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市花見川区宇那谷町', '12', '12102', '2620003', '千葉県', 'チバケン', '千葉市花見川区', 'チバシハナミガワク', '宇那谷町', 'ウナヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市花見川区大日町', '12', '12102', '2620004', '千葉県', 'チバケン', '千葉市花見川区', 'チバシハナミガワク', '大日町', 'ダイニチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市花見川区こてはし台', '12', '12102', '2620005', '千葉県', 'チバケン', '千葉市花見川区', 'チバシハナミガワク', 'こてはし台', 'コテハシダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市花見川区横戸台', '12', '12102', '2620006', '千葉県', 'チバケン', '千葉市花見川区', 'チバシハナミガワク', '横戸台', 'ヨコドダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市花見川区三角町', '12', '12102', '2620011', '千葉県', 'チバケン', '千葉市花見川区', 'チバシハナミガワク', '三角町', 'サンカクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市花見川区千種町', '12', '12102', '2620012', '千葉県', 'チバケン', '千葉市花見川区', 'チバシハナミガワク', '千種町', 'チグサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市花見川区犢橋町', '12', '12102', '2620013', '千葉県', 'チバケン', '千葉市花見川区', 'チバシハナミガワク', '犢橋町', 'コテハシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市花見川区さつきが丘', '12', '12102', '2620014', '千葉県', 'チバケン', '千葉市花見川区', 'チバシハナミガワク', 'さつきが丘', 'サツキガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市花見川区宮野木台', '12', '12102', '2620015', '千葉県', 'チバケン', '千葉市花見川区', 'チバシハナミガワク', '宮野木台', 'ミヤノギダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市花見川区西小中台', '12', '12102', '2620016', '千葉県', 'チバケン', '千葉市花見川区', 'チバシハナミガワク', '西小中台', 'ニシコナカダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市花見川区朝日ケ丘町', '12', '12102', '2620017', '千葉県', 'チバケン', '千葉市花見川区', 'チバシハナミガワク', '朝日ケ丘町', 'アサヒガオカチョウ', null, null, null, null), ('14813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市花見川区畑町', '12', '12102', '2620018', '千葉県', 'チバケン', '千葉市花見川区', 'チバシハナミガワク', '畑町', 'ハタマチ', null, null, null, null), ('14814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市花見川区朝日ケ丘', '12', '12102', '2620019', '千葉県', 'チバケン', '千葉市花見川区', 'チバシハナミガワク', '朝日ケ丘', 'アサヒガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市花見川区花園町', '12', '12102', '2620021', '千葉県', 'チバケン', '千葉市花見川区', 'チバシハナミガワク', '花園町', 'ハナゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市花見川区南花園', '12', '12102', '2620022', '千葉県', 'チバケン', '千葉市花見川区', 'チバシハナミガワク', '南花園', 'ミナミハナゾノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市花見川区検見川町', '12', '12102', '2620023', '千葉県', 'チバケン', '千葉市花見川区', 'チバシハナミガワク', '検見川町', 'ケミガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市花見川区浪花町', '12', '12102', '2620024', '千葉県', 'チバケン', '千葉市花見川区', 'チバシハナミガワク', '浪花町', 'ナニワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市花見川区花園', '12', '12102', '2620025', '千葉県', 'チバケン', '千葉市花見川区', 'チバシハナミガワク', '花園', 'ハナゾノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市花見川区瑞穂', '12', '12102', '2620026', '千葉県', 'チバケン', '千葉市花見川区', 'チバシハナミガワク', '瑞穂', 'ミズホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市花見川区武石町', '12', '12102', '2620031', '千葉県', 'チバケン', '千葉市花見川区', 'チバシハナミガワク', '武石町', 'タケイシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市花見川区幕張町', '12', '12102', '2620032', '千葉県', 'チバケン', '千葉市花見川区', 'チバシハナミガワク', '幕張町', 'マクハリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市花見川区幕張本郷', '12', '12102', '2620033', '千葉県', 'チバケン', '千葉市花見川区', 'チバシハナミガワク', '幕張本郷', 'マクハリホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市花見川区柏井町', '12', '12102', '2620041', '千葉県', 'チバケン', '千葉市花見川区', 'チバシハナミガワク', '柏井町', 'カシワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市花見川区花島町', '12', '12102', '2620042', '千葉県', 'チバケン', '千葉市花見川区', 'チバシハナミガワク', '花島町', 'ハナシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市花見川区天戸町', '12', '12102', '2620043', '千葉県', 'チバケン', '千葉市花見川区', 'チバシハナミガワク', '天戸町', 'アマドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市花見川区長作町', '12', '12102', '2620044', '千葉県', 'チバケン', '千葉市花見川区', 'チバシハナミガワク', '長作町', 'ナガサクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市花見川区作新台', '12', '12102', '2620045', '千葉県', 'チバケン', '千葉市花見川区', 'チバシハナミガワク', '作新台', 'サクシンダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市花見川区花見川', '12', '12102', '2620046', '千葉県', 'チバケン', '千葉市花見川区', 'チバシハナミガワク', '花見川', 'ハナミガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市花見川区長作台', '12', '12102', '2620047', '千葉県', 'チバケン', '千葉市花見川区', 'チバシハナミガワク', '長作台', 'ナガサクダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市花見川区柏井', '12', '12102', '2620048', '千葉県', 'チバケン', '千葉市花見川区', 'チバシハナミガワク', '柏井', 'カシワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市稲毛区', '12', '12103', '2630000', '千葉県', 'チバケン', '千葉市稲毛区', 'チバシイナゲク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('14847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市稲毛区長沼原町', '12', '12103', '2630001', '千葉県', 'チバケン', '千葉市稲毛区', 'チバシイナゲク', '長沼原町', 'ナガヌマハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市稲毛区山王町', '12', '12103', '2630002', '千葉県', 'チバケン', '千葉市稲毛区', 'チバシイナゲク', '山王町', 'サンノウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市稲毛区小深町', '12', '12103', '2630003', '千葉県', 'チバケン', '千葉市稲毛区', 'チバシイナゲク', '小深町', 'コブケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市稲毛区六方町', '12', '12103', '2630004', '千葉県', 'チバケン', '千葉市稲毛区', 'チバシイナゲク', '六方町', 'ロッポウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市稲毛区長沼町', '12', '12103', '2630005', '千葉県', 'チバケン', '千葉市稲毛区', 'チバシイナゲク', '長沼町', 'ナガヌマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市稲毛区天台町', '12', '12103', '2630011', '千葉県', 'チバケン', '千葉市稲毛区', 'チバシイナゲク', '天台町', 'テンダイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市稲毛区萩台町', '12', '12103', '2630012', '千葉県', 'チバケン', '千葉市稲毛区', 'チバシイナゲク', '萩台町', 'ハギダイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市稲毛区千草台', '12', '12103', '2630013', '千葉県', 'チバケン', '千葉市稲毛区', 'チバシイナゲク', '千草台', 'チグサダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市稲毛区作草部町', '12', '12103', '2630014', '千葉県', 'チバケン', '千葉市稲毛区', 'チバシイナゲク', '作草部町', 'サクサベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市稲毛区作草部', '12', '12103', '2630015', '千葉県', 'チバケン', '千葉市稲毛区', 'チバシイナゲク', '作草部', 'サクサベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市稲毛区天台', '12', '12103', '2630016', '千葉県', 'チバケン', '千葉市稲毛区', 'チバシイナゲク', '天台', 'テンダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市稲毛区轟町', '12', '12103', '2630021', '千葉県', 'チバケン', '千葉市稲毛区', 'チバシイナゲク', '轟町', 'トドロキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市稲毛区弥生町', '12', '12103', '2630022', '千葉県', 'チバケン', '千葉市稲毛区', 'チバシイナゲク', '弥生町', 'ヤヨイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市稲毛区緑町', '12', '12103', '2630023', '千葉県', 'チバケン', '千葉市稲毛区', 'チバシイナゲク', '緑町', 'ミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市稲毛区穴川', '12', '12103', '2630024', '千葉県', 'チバケン', '千葉市稲毛区', 'チバシイナゲク', '穴川', 'アナガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市稲毛区穴川町', '12', '12103', '2630025', '千葉県', 'チバケン', '千葉市稲毛区', 'チバシイナゲク', '穴川町', 'アナガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市稲毛区稲毛東', '12', '12103', '2630031', '千葉県', 'チバケン', '千葉市稲毛区', 'チバシイナゲク', '稲毛東', 'イナゲヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市稲毛区稲毛台町', '12', '12103', '2630032', '千葉県', 'チバケン', '千葉市稲毛区', 'チバシイナゲク', '稲毛台町', 'イナゲダイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市稲毛区稲丘町', '12', '12103', '2630033', '千葉県', 'チバケン', '千葉市稲毛区', 'チバシイナゲク', '稲丘町', 'イナオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市稲毛区稲毛', '12', '12103', '2630034', '千葉県', 'チバケン', '千葉市稲毛区', 'チバシイナゲク', '稲毛', 'イナゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市稲毛区稲毛町', '12', '12103', '2630035', '千葉県', 'チバケン', '千葉市稲毛区', 'チバシイナゲク', '稲毛町', 'イナゲチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市稲毛区黒砂台', '12', '12103', '2630041', '千葉県', 'チバケン', '千葉市稲毛区', 'チバシイナゲク', '黒砂台', 'クロスナダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市稲毛区黒砂', '12', '12103', '2630042', '千葉県', 'チバケン', '千葉市稲毛区', 'チバシイナゲク', '黒砂', 'クロスナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市稲毛区小仲台', '12', '12103', '2630043', '千葉県', 'チバケン', '千葉市稲毛区', 'チバシイナゲク', '小仲台', 'コナカダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市稲毛区小中台町', '12', '12103', '2630044', '千葉県', 'チバケン', '千葉市稲毛区', 'チバシイナゲク', '小中台町', 'コナカダイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市稲毛区園生町', '12', '12103', '2630051', '千葉県', 'チバケン', '千葉市稲毛区', 'チバシイナゲク', '園生町', 'ソンノウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市稲毛区あやめ台', '12', '12103', '2630052', '千葉県', 'チバケン', '千葉市稲毛区', 'チバシイナゲク', 'あやめ台', 'アヤメダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市稲毛区柏台', '12', '12103', '2630053', '千葉県', 'チバケン', '千葉市稲毛区', 'チバシイナゲク', '柏台', 'カシワダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市稲毛区宮野木町', '12', '12103', '2630054', '千葉県', 'チバケン', '千葉市稲毛区', 'チバシイナゲク', '宮野木町', 'ミヤノギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市若葉区', '12', '12104', '2640000', '千葉県', 'チバケン', '千葉市若葉区', 'チバシワカバク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('14885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市若葉区金親町', '12', '12104', '2640001', '千葉県', 'チバケン', '千葉市若葉区', 'チバシワカバク', '金親町', 'カネオヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市若葉区千城台東', '12', '12104', '2640002', '千葉県', 'チバケン', '千葉市若葉区', 'チバシワカバク', '千城台東', 'チシロダイヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市若葉区千城台南', '12', '12104', '2640003', '千葉県', 'チバケン', '千葉市若葉区', 'チバシワカバク', '千城台南', 'チシロダイミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市若葉区千城台西', '12', '12104', '2640004', '千葉県', 'チバケン', '千葉市若葉区', 'チバシワカバク', '千城台西', 'チシロダイニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市若葉区千城台北', '12', '12104', '2640005', '千葉県', 'チバケン', '千葉市若葉区', 'チバシワカバク', '千城台北', 'チシロダイキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市若葉区小倉台', '12', '12104', '2640006', '千葉県', 'チバケン', '千葉市若葉区', 'チバシワカバク', '小倉台', 'オグラダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市若葉区小倉町', '12', '12104', '2640007', '千葉県', 'チバケン', '千葉市若葉区', 'チバシワカバク', '小倉町', 'オグラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市若葉区大草町', '12', '12104', '2640011', '千葉県', 'チバケン', '千葉市若葉区', 'チバシワカバク', '大草町', 'オオクサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市若葉区坂月町', '12', '12104', '2640012', '千葉県', 'チバケン', '千葉市若葉区', 'チバシワカバク', '坂月町', 'サカヅキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市若葉区太田町', '12', '12104', '2640013', '千葉県', 'チバケン', '千葉市若葉区', 'チバシワカバク', '太田町', 'オオタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市若葉区北大宮台', '12', '12104', '2640014', '千葉県', 'チバケン', '千葉市若葉区', 'チバシワカバク', '北大宮台', 'キタオオミヤダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市若葉区大宮台', '12', '12104', '2640015', '千葉県', 'チバケン', '千葉市若葉区', 'チバシワカバク', '大宮台', 'オオミヤダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市若葉区大宮町', '12', '12104', '2640016', '千葉県', 'チバケン', '千葉市若葉区', 'チバシワカバク', '大宮町', 'オオミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市若葉区加曽利町', '12', '12104', '2640017', '千葉県', 'チバケン', '千葉市若葉区', 'チバシワカバク', '加曽利町', 'カソリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市若葉区若松町', '12', '12104', '2640021', '千葉県', 'チバケン', '千葉市若葉区', 'チバシワカバク', '若松町', 'ワカマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市若葉区貝塚町', '12', '12104', '2640023', '千葉県', 'チバケン', '千葉市若葉区', 'チバシワカバク', '貝塚町', 'カイヅカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市若葉区高品町', '12', '12104', '2640024', '千葉県', 'チバケン', '千葉市若葉区', 'チバシワカバク', '高品町', 'タカシナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市若葉区都賀', '12', '12104', '2640025', '千葉県', 'チバケン', '千葉市若葉区', 'チバシワカバク', '都賀', 'ツガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市若葉区西都賀', '12', '12104', '2640026', '千葉県', 'チバケン', '千葉市若葉区', 'チバシワカバク', '西都賀', 'ニシツガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市若葉区若松台', '12', '12104', '2640027', '千葉県', 'チバケン', '千葉市若葉区', 'チバシワカバク', '若松台', 'ワカマツダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市若葉区桜木', '12', '12104', '2640028', '千葉県', 'チバケン', '千葉市若葉区', 'チバシワカバク', '桜木', 'サクラギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市若葉区桜木北', '12', '12104', '2640029', '千葉県', 'チバケン', '千葉市若葉区', 'チバシワカバク', '桜木北', 'サクラギキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市若葉区愛生町', '12', '12104', '2640031', '千葉県', 'チバケン', '千葉市若葉区', 'チバシワカバク', '愛生町', 'アイオイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市若葉区みつわ台', '12', '12104', '2640032', '千葉県', 'チバケン', '千葉市若葉区', 'チバシワカバク', 'みつわ台', 'ミツワダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市若葉区都賀の台', '12', '12104', '2640033', '千葉県', 'チバケン', '千葉市若葉区', 'チバシワカバク', '都賀の台', 'ツガノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市若葉区原町', '12', '12104', '2640034', '千葉県', 'チバケン', '千葉市若葉区', 'チバシワカバク', '原町', 'ハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市若葉区東寺山町', '12', '12104', '2640035', '千葉県', 'チバケン', '千葉市若葉区', 'チバシワカバク', '東寺山町', 'ヒガシテラヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市若葉区殿台町', '12', '12104', '2640036', '千葉県', 'チバケン', '千葉市若葉区', 'チバシワカバク', '殿台町', 'トノダイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市若葉区源町', '12', '12104', '2640037', '千葉県', 'チバケン', '千葉市若葉区', 'チバシワカバク', '源町', 'ミナモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市若葉区富田町', '12', '12104', '2650041', '千葉県', 'チバケン', '千葉市若葉区', 'チバシワカバク', '富田町', 'トミタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市若葉区古泉町', '12', '12104', '2650042', '千葉県', 'チバケン', '千葉市若葉区', 'チバシワカバク', '古泉町', 'コイズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市若葉区中田町', '12', '12104', '2650043', '千葉県', 'チバケン', '千葉市若葉区', 'チバシワカバク', '中田町', 'ナカタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市若葉区下泉町', '12', '12104', '2650044', '千葉県', 'チバケン', '千葉市若葉区', 'チバシワカバク', '下泉町', 'シモイズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市若葉区上泉町', '12', '12104', '2650045', '千葉県', 'チバケン', '千葉市若葉区', 'チバシワカバク', '上泉町', 'カミイズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市若葉区小間子町', '12', '12104', '2650046', '千葉県', 'チバケン', '千葉市若葉区', 'チバシワカバク', '小間子町', 'オマゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市若葉区中野町', '12', '12104', '2650051', '千葉県', 'チバケン', '千葉市若葉区', 'チバシワカバク', '中野町', 'ナカノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市若葉区和泉町', '12', '12104', '2650052', '千葉県', 'チバケン', '千葉市若葉区', 'チバシワカバク', '和泉町', 'イズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市若葉区野呂町', '12', '12104', '2650053', '千葉県', 'チバケン', '千葉市若葉区', 'チバシワカバク', '野呂町', 'ノロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市若葉区高根町', '12', '12104', '2650061', '千葉県', 'チバケン', '千葉市若葉区', 'チバシワカバク', '高根町', 'タカネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市若葉区川井町', '12', '12104', '2650062', '千葉県', 'チバケン', '千葉市若葉区', 'チバシワカバク', '川井町', 'カワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市若葉区五十土町', '12', '12104', '2650063', '千葉県', 'チバケン', '千葉市若葉区', 'チバシワカバク', '五十土町', 'イカヅチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市若葉区大広町', '12', '12104', '2650064', '千葉県', 'チバケン', '千葉市若葉区', 'チバシワカバク', '大広町', 'オオヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市若葉区佐和町', '12', '12104', '2650065', '千葉県', 'チバケン', '千葉市若葉区', 'チバシワカバク', '佐和町', 'サワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市若葉区多部田町', '12', '12104', '2650066', '千葉県', 'チバケン', '千葉市若葉区', 'チバシワカバク', '多部田町', 'タベタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市若葉区北谷津町', '12', '12104', '2650067', '千葉県', 'チバケン', '千葉市若葉区', 'チバシワカバク', '北谷津町', 'キタヤツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市若葉区旦谷町', '12', '12104', '2650071', '千葉県', 'チバケン', '千葉市若葉区', 'チバシワカバク', '旦谷町', 'ダンヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市若葉区谷当町', '12', '12104', '2650072', '千葉県', 'チバケン', '千葉市若葉区', 'チバシワカバク', '谷当町', 'ヤトウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市若葉区更科町', '12', '12104', '2650073', '千葉県', 'チバケン', '千葉市若葉区', 'チバシワカバク', '更科町', 'サラシナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市若葉区御殿町', '12', '12104', '2650074', '千葉県', 'チバケン', '千葉市若葉区', 'チバシワカバク', '御殿町', 'ゴテンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市若葉区大井戸町', '12', '12104', '2650075', '千葉県', 'チバケン', '千葉市若葉区', 'チバシワカバク', '大井戸町', 'オオイドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市若葉区下田町', '12', '12104', '2650076', '千葉県', 'チバケン', '千葉市若葉区', 'チバシワカバク', '下田町', 'シモダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市若葉区御成台', '12', '12104', '2650077', '千葉県', 'チバケン', '千葉市若葉区', 'チバシワカバク', '御成台', 'オナリダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市緑区', '12', '12105', '2660000', '千葉県', 'チバケン', '千葉市緑区', 'チバシミドリク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('14949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市緑区東山科町', '12', '12105', '2660001', '千葉県', 'チバケン', '千葉市緑区', 'チバシミドリク', '東山科町', 'ヒガシヤマシナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市緑区平山町', '12', '12105', '2660002', '千葉県', 'チバケン', '千葉市緑区', 'チバシミドリク', '平山町', 'ヒラヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市緑区高田町', '12', '12105', '2660003', '千葉県', 'チバケン', '千葉市緑区', 'チバシミドリク', '高田町', 'タカダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市緑区平川町', '12', '12105', '2660004', '千葉県', 'チバケン', '千葉市緑区', 'チバシミドリク', '平川町', 'ヒラカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市緑区誉田町', '12', '12105', '2660005', '千葉県', 'チバケン', '千葉市緑区', 'チバシミドリク', '誉田町', 'ホンダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市緑区大膳野町', '12', '12105', '2660006', '千葉県', 'チバケン', '千葉市緑区', 'チバシミドリク', '大膳野町', 'ダイゼンノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市緑区辺田町', '12', '12105', '2660007', '千葉県', 'チバケン', '千葉市緑区', 'チバシミドリク', '辺田町', 'ヘタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市緑区鎌取町', '12', '12105', '2660011', '千葉県', 'チバケン', '千葉市緑区', 'チバシミドリク', '鎌取町', 'カマトリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市緑区大金沢町', '12', '12105', '2660014', '千葉県', 'チバケン', '千葉市緑区', 'チバシミドリク', '大金沢町', 'オオカネザワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市緑区小金沢町', '12', '12105', '2660015', '千葉県', 'チバケン', '千葉市緑区', 'チバシミドリク', '小金沢町', 'コカネザワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市緑区椎名崎町', '12', '12105', '2660016', '千葉県', 'チバケン', '千葉市緑区', 'チバシミドリク', '椎名崎町', 'シイナザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市緑区刈田子町', '12', '12105', '2660021', '千葉県', 'チバケン', '千葉市緑区', 'チバシミドリク', '刈田子町', 'カリタゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市緑区富岡町', '12', '12105', '2660022', '千葉県', 'チバケン', '千葉市緑区', 'チバシミドリク', '富岡町', 'トミオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市緑区茂呂町', '12', '12105', '2660023', '千葉県', 'チバケン', '千葉市緑区', 'チバシミドリク', '茂呂町', 'モロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市緑区中西町', '12', '12105', '2660024', '千葉県', 'チバケン', '千葉市緑区', 'チバシミドリク', '中西町', 'ナカニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市緑区落井町', '12', '12105', '2660025', '千葉県', 'チバケン', '千葉市緑区', 'チバシミドリク', '落井町', 'オチイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市緑区古市場町', '12', '12105', '2660026', '千葉県', 'チバケン', '千葉市緑区', 'チバシミドリク', '古市場町', 'フルイチバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市緑区おゆみ野', '12', '12105', '2660031', '千葉県', 'チバケン', '千葉市緑区', 'チバシミドリク', 'おゆみ野', 'オユミノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市緑区おゆみ野中央', '12', '12105', '2660032', '千葉県', 'チバケン', '千葉市緑区', 'チバシミドリク', 'おゆみ野中央', 'オユミノチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市緑区おゆみ野南', '12', '12105', '2660033', '千葉県', 'チバケン', '千葉市緑区', 'チバシミドリク', 'おゆみ野南', 'オユミノミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市緑区おゆみ野有吉', '12', '12105', '2660034', '千葉県', 'チバケン', '千葉市緑区', 'チバシミドリク', 'おゆみ野有吉', 'オユミノアリヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市緑区上大和田町', '12', '12105', '2670051', '千葉県', 'チバケン', '千葉市緑区', 'チバシミドリク', '上大和田町', 'カミオオワダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市緑区下大和田町', '12', '12105', '2670052', '千葉県', 'チバケン', '千葉市緑区', 'チバシミドリク', '下大和田町', 'シモオオワダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市緑区高津戸町', '12', '12105', '2670053', '千葉県', 'チバケン', '千葉市緑区', 'チバシミドリク', '高津戸町', 'タカツドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市緑区大高町', '12', '12105', '2670054', '千葉県', 'チバケン', '千葉市緑区', 'チバシミドリク', '大高町', 'オオタカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市緑区越智町', '12', '12105', '2670055', '千葉県', 'チバケン', '千葉市緑区', 'チバシミドリク', '越智町', 'オチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市緑区大野台', '12', '12105', '2670056', '千葉県', 'チバケン', '千葉市緑区', 'チバシミドリク', '大野台', 'オオノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市緑区大木戸町', '12', '12105', '2670057', '千葉県', 'チバケン', '千葉市緑区', 'チバシミドリク', '大木戸町', 'オオキドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市緑区土気町', '12', '12105', '2670061', '千葉県', 'チバケン', '千葉市緑区', 'チバシミドリク', '土気町', 'トケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市緑区小食土町', '12', '12105', '2670062', '千葉県', 'チバケン', '千葉市緑区', 'チバシミドリク', '小食土町', 'ヤサシドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市緑区小山町', '12', '12105', '2670063', '千葉県', 'チバケン', '千葉市緑区', 'チバシミドリク', '小山町', 'オヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市緑区板倉町', '12', '12105', '2670064', '千葉県', 'チバケン', '千葉市緑区', 'チバシミドリク', '板倉町', 'イタクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市緑区大椎町', '12', '12105', '2670065', '千葉県', 'チバケン', '千葉市緑区', 'チバシミドリク', '大椎町', 'オオジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県千葉市緑区あすみが丘', '12', '12105', '2670066', '千葉県', 'チバケン', '千葉市緑区', 'チバシミドリク', 'あすみが丘', 'アスミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市', '03', '03202', '0270000', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('14989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市', '12', '12207', '2700000', '千葉県', 'チバケン', '松戸市', 'マツドシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('14990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市幸田', '12', '12207', '2700001', '千葉県', 'チバケン', '松戸市', 'マツドシ', '幸田', 'コウデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市平賀', '12', '12207', '2700002', '千葉県', 'チバケン', '松戸市', 'マツドシ', '平賀', 'ヒラガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市東平賀', '12', '12207', '2700003', '千葉県', 'チバケン', '松戸市', 'マツドシ', '東平賀', 'ヒガシヒラガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市殿平賀', '12', '12207', '2700004', '千葉県', 'チバケン', '松戸市', 'マツドシ', '殿平賀', 'トノヒラガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市大谷口', '12', '12207', '2700005', '千葉県', 'チバケン', '松戸市', 'マツドシ', '大谷口', 'オオヤグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市大金平', '12', '12207', '2700006', '千葉県', 'チバケン', '松戸市', 'マツドシ', '大金平', 'オオガネダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市中金杉', '12', '12207', '2700007', '千葉県', 'チバケン', '松戸市', 'マツドシ', '中金杉', 'ナカカナスギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市日立浜町', '03', '03202', '0270001', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '日立浜町', 'ヒタチハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市根木内', '12', '12207', '2700011', '千葉県', 'チバケン', '松戸市', 'マツドシ', '根木内', 'ネギウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('14999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市久保平賀', '12', '12207', '2700012', '千葉県', 'チバケン', '松戸市', 'マツドシ', '久保平賀', 'クボヒラガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市小金きよしケ丘', '12', '12207', '2700013', '千葉県', 'チバケン', '松戸市', 'マツドシ', '小金きよしケ丘', 'コガネキヨシガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市小金', '12', '12207', '2700014', '千葉県', 'チバケン', '松戸市', 'マツドシ', '小金', 'コガネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市小金上総町', '12', '12207', '2700015', '千葉県', 'チバケン', '松戸市', 'マツドシ', '小金上総町', 'コガネカズサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市小金清志町', '12', '12207', '2700016', '千葉県', 'チバケン', '松戸市', 'マツドシ', '小金清志町', 'コガネキヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市幸谷', '12', '12207', '2700017', '千葉県', 'チバケン', '松戸市', 'マツドシ', '幸谷', 'コウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市上総内', '12', '12207', '2700018', '千葉県', 'チバケン', '松戸市', 'マツドシ', '上総内', 'カズサウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市山根町', '03', '03202', '0270002', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '山根町', 'ヤマネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市小金原', '12', '12207', '2700021', '千葉県', 'チバケン', '松戸市', 'マツドシ', '小金原', 'コガネハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市栗ケ沢', '12', '12207', '2700022', '千葉県', 'チバケン', '松戸市', 'マツドシ', '栗ケ沢', 'クリガサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市八ケ崎', '12', '12207', '2700023', '千葉県', 'チバケン', '松戸市', 'マツドシ', '八ケ崎', 'ハチガサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市八ケ崎緑町', '12', '12207', '2700024', '千葉県', 'チバケン', '松戸市', 'マツドシ', '八ケ崎緑町', 'ハチガサキミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市中和倉', '12', '12207', '2700025', '千葉県', 'チバケン', '松戸市', 'マツドシ', '中和倉', 'ナカワクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市三ケ月', '12', '12207', '2700026', '千葉県', 'チバケン', '松戸市', 'マツドシ', '三ケ月', 'ミコゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市二ツ木', '12', '12207', '2700027', '千葉県', 'チバケン', '松戸市', 'マツドシ', '二ツ木', 'フタツギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市二ツ木二葉町', '12', '12207', '2700028', '千葉県', 'チバケン', '松戸市', 'マツドシ', '二ツ木二葉町', 'フタツギフタバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市港町', '03', '03202', '0270003', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '港町', 'ミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市横須賀', '12', '12207', '2700031', '千葉県', 'チバケン', '松戸市', 'マツドシ', '横須賀', 'ヨコスカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市新松戸北', '12', '12207', '2700032', '千葉県', 'チバケン', '松戸市', 'マツドシ', '新松戸北', 'シンマツドキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市新松戸東', '12', '12207', '2700033', '千葉県', 'チバケン', '松戸市', 'マツドシ', '新松戸東', 'シンマツドヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市新松戸', '12', '12207', '2700034', '千葉県', 'チバケン', '松戸市', 'マツドシ', '新松戸', 'シンマツド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市新松戸南', '12', '12207', '2700035', '千葉県', 'チバケン', '松戸市', 'マツドシ', '新松戸南', 'シンマツドミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市大谷口新田', '12', '12207', '2700036', '千葉県', 'チバケン', '松戸市', 'マツドシ', '大谷口新田', 'オオヤグチシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市臨港通', '03', '03202', '0270004', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '臨港通', 'リンコウドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市光岸地', '03', '03202', '0270005', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '光岸地', 'コウガンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市鍬ケ崎', '03', '03202', '0270006', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '鍬ケ崎', 'クワガサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市日影町', '03', '03202', '0270007', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '日影町', 'ヒカゲチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市熊野町', '03', '03202', '0270008', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '熊野町', 'クマノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市蛸の浜町', '03', '03202', '0270009', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '蛸の浜町', 'タコノハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県流山市', '12', '12220', '2700100', '千葉県', 'チバケン', '流山市', 'ナガレヤマシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('15029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県流山市東深井', '12', '12220', '2700101', '千葉県', 'チバケン', '流山市', 'ナガレヤマシ', '東深井', 'ヒガシフカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県流山市こうのす台', '12', '12220', '2700102', '千葉県', 'チバケン', '流山市', 'ナガレヤマシ', 'こうのす台', 'コウノスダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県流山市美原', '12', '12220', '2700103', '千葉県', 'チバケン', '流山市', 'ナガレヤマシ', '美原', 'ミハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県流山市平方原新田', '12', '12220', '2700104', '千葉県', 'チバケン', '流山市', 'ナガレヤマシ', '平方原新田', 'ヒラカタハラシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県流山市平方', '12', '12220', '2700105', '千葉県', 'チバケン', '流山市', 'ナガレヤマシ', '平方', 'ヒラカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県流山市平方村新田', '12', '12220', '2700106', '千葉県', 'チバケン', '流山市', 'ナガレヤマシ', '平方村新田', 'ヒラカタムラシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県流山市西深井', '12', '12220', '2700107', '千葉県', 'チバケン', '流山市', 'ナガレヤマシ', '西深井', 'ニシフカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県流山市深井新田', '12', '12220', '2700108', '千葉県', 'チバケン', '流山市', 'ナガレヤマシ', '深井新田', 'フカイシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県流山市江戸川台東', '12', '12220', '2700111', '千葉県', 'チバケン', '流山市', 'ナガレヤマシ', '江戸川台東', 'エドガワダイヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県流山市青田', '12', '12220', '2700112', '千葉県', 'チバケン', '流山市', 'ナガレヤマシ', '青田', 'アオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県流山市駒木台', '12', '12220', '2700113', '千葉県', 'チバケン', '流山市', 'ナガレヤマシ', '駒木台', 'コマギダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県流山市東初石', '12', '12220', '2700114', '千葉県', 'チバケン', '流山市', 'ナガレヤマシ', '東初石', 'ヒガシハツイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県流山市江戸川台西', '12', '12220', '2700115', '千葉県', 'チバケン', '流山市', 'ナガレヤマシ', '江戸川台西', 'エドガワダイニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県流山市中野久木', '12', '12220', '2700116', '千葉県', 'チバケン', '流山市', 'ナガレヤマシ', '中野久木', 'ナカノクキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県流山市北', '12', '12220', '2700117', '千葉県', 'チバケン', '流山市', 'ナガレヤマシ', '北', 'キタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県流山市小屋', '12', '12220', '2700118', '千葉県', 'チバケン', '流山市', 'ナガレヤマシ', '小屋', 'コヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県流山市西初石', '12', '12220', '2700121', '千葉県', 'チバケン', '流山市', 'ナガレヤマシ', '西初石', 'ニシハツイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県流山市大畔', '12', '12220', '2700122', '千葉県', 'チバケン', '流山市', 'ナガレヤマシ', '大畔', 'オオグロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県流山市若葉台', '12', '12220', '2700123', '千葉県', 'チバケン', '流山市', 'ナガレヤマシ', '若葉台', 'ワカバダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県流山市南', '12', '12220', '2700124', '千葉県', 'チバケン', '流山市', 'ナガレヤマシ', '南', 'ミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県流山市上新宿', '12', '12220', '2700125', '千葉県', 'チバケン', '流山市', 'ナガレヤマシ', '上新宿', 'カミシンシュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県流山市上新宿新田', '12', '12220', '2700126', '千葉県', 'チバケン', '流山市', 'ナガレヤマシ', '上新宿新田', 'カミシンシュクシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県流山市富士見台', '12', '12220', '2700127', '千葉県', 'チバケン', '流山市', 'ナガレヤマシ', '富士見台', 'フジミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県流山市美田', '12', '12220', '2700131', '千葉県', 'チバケン', '流山市', 'ナガレヤマシ', '美田', 'ミタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県流山市駒木', '12', '12220', '2700132', '千葉県', 'チバケン', '流山市', 'ナガレヤマシ', '駒木', 'コマギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県流山市十太夫', '12', '12220', '2700133', '千葉県', 'チバケン', '流山市', 'ナガレヤマシ', '十太夫', 'ジュウダユウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県流山市長崎', '12', '12220', '2700134', '千葉県', 'チバケン', '流山市', 'ナガレヤマシ', '長崎', 'ナガサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県流山市野々下', '12', '12220', '2700135', '千葉県', 'チバケン', '流山市', 'ナガレヤマシ', '野々下', 'ノノシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県流山市古間木', '12', '12220', '2700136', '千葉県', 'チバケン', '流山市', 'ナガレヤマシ', '古間木', 'フルマギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県流山市市野谷', '12', '12220', '2700137', '千葉県', 'チバケン', '流山市', 'ナガレヤマシ', '市野谷', 'イチノヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県流山市松ケ丘', '12', '12220', '2700141', '千葉県', 'チバケン', '流山市', 'ナガレヤマシ', '松ケ丘', 'マツガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県流山市西松ケ丘', '12', '12220', '2700142', '千葉県', 'チバケン', '流山市', 'ナガレヤマシ', '西松ケ丘', 'ニシマツガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県流山市向小金', '12', '12220', '2700143', '千葉県', 'チバケン', '流山市', 'ナガレヤマシ', '向小金', 'ムカイコガネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県流山市前ケ崎', '12', '12220', '2700144', '千葉県', 'チバケン', '流山市', 'ナガレヤマシ', '前ケ崎', 'マエガサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県流山市名都借', '12', '12220', '2700145', '千葉県', 'チバケン', '流山市', 'ナガレヤマシ', '名都借', 'ナズカリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県流山市芝崎', '12', '12220', '2700146', '千葉県', 'チバケン', '流山市', 'ナガレヤマシ', '芝崎', 'シバサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県流山市後平井', '12', '12220', '2700151', '千葉県', 'チバケン', '流山市', 'ナガレヤマシ', '後平井', 'ウシロヒライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県流山市前平井', '12', '12220', '2700152', '千葉県', 'チバケン', '流山市', 'ナガレヤマシ', '前平井', 'マエヒライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県流山市中', '12', '12220', '2700153', '千葉県', 'チバケン', '流山市', 'ナガレヤマシ', '中', 'ナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県流山市思井', '12', '12220', '2700154', '千葉県', 'チバケン', '流山市', 'ナガレヤマシ', '思井', 'オモイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県流山市宮園', '12', '12220', '2700155', '千葉県', 'チバケン', '流山市', 'ナガレヤマシ', '宮園', 'ミヤゾノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県流山市西平井', '12', '12220', '2700156', '千葉県', 'チバケン', '流山市', 'ナガレヤマシ', '西平井', 'ニシヒライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県流山市平和台', '12', '12220', '2700157', '千葉県', 'チバケン', '流山市', 'ナガレヤマシ', '平和台', 'ヘイワダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県流山市鰭ケ崎', '12', '12220', '2700161', '千葉県', 'チバケン', '流山市', 'ナガレヤマシ', '鰭ケ崎', 'ヒレガサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県流山市木', '12', '12220', '2700162', '千葉県', 'チバケン', '流山市', 'ナガレヤマシ', '木', 'キ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県流山市南流山', '12', '12220', '2700163', '千葉県', 'チバケン', '流山市', 'ナガレヤマシ', '南流山', 'ミナミナガレヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県流山市流山', '12', '12220', '2700164', '千葉県', 'チバケン', '流山市', 'ナガレヤマシ', '流山', 'ナガレヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県流山市上貝塚', '12', '12220', '2700171', '千葉県', 'チバケン', '流山市', 'ナガレヤマシ', '上貝塚', 'カミカイヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県流山市桐ケ谷', '12', '12220', '2700172', '千葉県', 'チバケン', '流山市', 'ナガレヤマシ', '桐ケ谷', 'キリガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県流山市谷', '12', '12220', '2700173', '千葉県', 'チバケン', '流山市', 'ナガレヤマシ', '谷', 'タニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県流山市下花輪', '12', '12220', '2700174', '千葉県', 'チバケン', '流山市', 'ナガレヤマシ', '下花輪', 'シモハナワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県流山市三輪野山', '12', '12220', '2700175', '千葉県', 'チバケン', '流山市', 'ナガレヤマシ', '三輪野山', 'ミワノヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県流山市加', '12', '12220', '2700176', '千葉県', 'チバケン', '流山市', 'ナガレヤマシ', '加', 'カ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県野田市関宿三軒家', '12', '12208', '2700201', '千葉県', 'チバケン', '野田市', 'ノダシ', '関宿三軒家', 'セキヤドサンゲンヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県野田市関宿台町', '12', '12208', '2700202', '千葉県', 'チバケン', '野田市', 'ノダシ', '関宿台町', 'セキヤドダイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県野田市関宿元町', '12', '12208', '2700203', '千葉県', 'チバケン', '野田市', 'ノダシ', '関宿元町', 'セキヤドモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県野田市関宿内町', '12', '12208', '2700204', '千葉県', 'チバケン', '野田市', 'ノダシ', '関宿内町', 'セキヤドウチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県野田市関宿江戸町', '12', '12208', '2700205', '千葉県', 'チバケン', '野田市', 'ノダシ', '関宿江戸町', 'セキヤドエドマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県野田市関宿町', '12', '12208', '2700206', '千葉県', 'チバケン', '野田市', 'ノダシ', '関宿町', 'セキヤドマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市藤原', '03', '03202', '0270021', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '藤原', 'フジワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県野田市東高野', '12', '12208', '2700211', '千葉県', 'チバケン', '野田市', 'ノダシ', '東高野', 'ヒガシゴウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県野田市新田戸', '12', '12208', '2700212', '千葉県', 'チバケン', '野田市', 'ノダシ', '新田戸', 'ニッタド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県野田市桐ケ作', '12', '12208', '2700213', '千葉県', 'チバケン', '野田市', 'ノダシ', '桐ケ作', 'キリガサク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県野田市柏寺', '12', '12208', '2700214', '千葉県', 'チバケン', '野田市', 'ノダシ', '柏寺', 'カシワデラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県野田市中戸', '12', '12208', '2700215', '千葉県', 'チバケン', '野田市', 'ノダシ', '中戸', 'ナカト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県野田市西高野', '12', '12208', '2700216', '千葉県', 'チバケン', '野田市', 'ノダシ', '西高野', 'ニシゴウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県野田市はやま', '12', '12208', '2700217', '千葉県', 'チバケン', '野田市', 'ノダシ', 'はやま', 'ハヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市磯鶏石崎', '03', '03202', '0270022', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '磯鶏石崎', 'ソケイイシザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県野田市古布内', '12', '12208', '2700221', '千葉県', 'チバケン', '野田市', 'ノダシ', '古布内', 'コブウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県野田市木間ケ瀬', '12', '12208', '2700222', '千葉県', 'チバケン', '野田市', 'ノダシ', '木間ケ瀬', 'キマガセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県野田市岡田', '12', '12208', '2700223', '千葉県', 'チバケン', '野田市', 'ノダシ', '岡田', 'オカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県野田市丸井', '12', '12208', '2700224', '千葉県', 'チバケン', '野田市', 'ノダシ', '丸井', 'マルイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県野田市平井', '12', '12208', '2700225', '千葉県', 'チバケン', '野田市', 'ノダシ', '平井', 'ヒライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県野田市東宝珠花', '12', '12208', '2700226', '千葉県', 'チバケン', '野田市', 'ノダシ', '東宝珠花', 'ヒガシホウシュバナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県野田市親野井', '12', '12208', '2700227', '千葉県', 'チバケン', '野田市', 'ノダシ', '親野井', 'オヤノイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県野田市次木', '12', '12208', '2700228', '千葉県', 'チバケン', '野田市', 'ノダシ', '次木', 'ナミキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市磯鶏沖', '03', '03202', '0270023', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '磯鶏沖', 'ソケイオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県野田市小山', '12', '12208', '2700231', '千葉県', 'チバケン', '野田市', 'ノダシ', '小山', 'オヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県野田市莚打', '12', '12208', '2700232', '千葉県', 'チバケン', '野田市', 'ノダシ', '莚打', 'ムシロウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県野田市船形', '12', '12208', '2700233', '千葉県', 'チバケン', '野田市', 'ノダシ', '船形', 'フナカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県野田市日の出町', '12', '12208', '2700234', '千葉県', 'チバケン', '野田市', 'ノダシ', '日の出町', 'ヒノデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県野田市尾崎', '12', '12208', '2700235', '千葉県', 'チバケン', '野田市', 'ノダシ', '尾崎', 'オサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県野田市東金野井', '12', '12208', '2700236', '千葉県', 'チバケン', '野田市', 'ノダシ', '東金野井', 'ヒガシカナノイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県野田市中里', '12', '12208', '2700237', '千葉県', 'チバケン', '野田市', 'ノダシ', '中里', 'ナカザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県野田市尾崎台', '12', '12208', '2700238', '千葉県', 'チバケン', '野田市', 'ノダシ', '尾崎台', 'オザキダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市磯鶏', '03', '03202', '0270024', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '磯鶏', 'ソケイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市実田', '03', '03202', '0270025', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '実田', 'ミタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市上村', '03', '03202', '0270026', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '上村', 'ワムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市磯鶏西', '03', '03202', '0270027', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '磯鶏西', 'ソケイニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市神林', '03', '03202', '0270028', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '神林', 'カンバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市藤の川', '03', '03202', '0270029', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '藤の川', 'フジノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市八木沢', '03', '03202', '0270031', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '八木沢', 'ヤギサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市高浜', '03', '03202', '0270032', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '高浜', 'タカハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市金浜', '03', '03202', '0270033', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '金浜', 'カネハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市長沢', '03', '03202', '0270034', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '長沢', 'ナガサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市花輪', '03', '03202', '0270035', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '花輪', 'ハナワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市田鎖', '03', '03202', '0270036', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '田鎖', 'タクサリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市松山', '03', '03202', '0270037', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '松山', 'マツヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市小山田', '03', '03202', '0270038', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '小山田', 'コヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市河南', '03', '03202', '0270039', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '河南', 'カナン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市西ケ丘', '03', '03202', '0270041', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '西ケ丘', 'ニシガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市神田沢町', '03', '03202', '0270042', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '神田沢町', 'カンダザワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市千徳町', '03', '03202', '0270043', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '千徳町', 'セントクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市上鼻', '03', '03202', '0270044', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '上鼻', 'カンパナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市老木', '03', '03202', '0270045', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '老木', 'ロウキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市花原市', '03', '03202', '0270046', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '花原市', 'ケバライチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市根市', '03', '03202', '0270047', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '根市', 'ネイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市板屋', '03', '03202', '0270048', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '板屋', 'イタヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市南町', '03', '03202', '0270051', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '南町', 'ミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市宮町', '03', '03202', '0270052', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '宮町', 'ミヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市長町', '03', '03202', '0270053', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '長町', 'ナガマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市太田', '03', '03202', '0270054', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '太田', 'オオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市長根', '03', '03202', '0270055', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '長根', 'ナガネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市近内', '03', '03202', '0270056', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '近内', 'チカナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市千徳', '03', '03202', '0270058', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '千徳', 'セントク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市西町', '03', '03202', '0270061', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '西町', 'ニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市泉町', '03', '03202', '0270062', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '泉町', 'イズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市山口', '03', '03202', '0270063', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '山口', 'ヤマグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市宮園', '03', '03202', '0270064', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '宮園', 'ミヤゾノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市黒森町', '03', '03202', '0270065', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '黒森町', 'クロモリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市田の神', '03', '03202', '0270066', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '田の神', 'タノカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市田代', '03', '03202', '0270067', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '田代', 'タシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市小沢', '03', '03202', '0270071', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '小沢', 'コザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市五月町', '03', '03202', '0270072', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '五月町', 'サツキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市緑ケ丘', '03', '03202', '0270073', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '緑ケ丘', 'ミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市保久田', '03', '03202', '0270074', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '保久田', 'ホクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市和見町', '03', '03202', '0270075', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '和見町', 'ワミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市栄町', '03', '03202', '0270076', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '栄町', 'サカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市舘合町', '03', '03202', '0270077', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '舘合町', 'タテアイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市鴨崎町', '03', '03202', '0270078', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '鴨崎町', 'カモザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市新川町', '03', '03202', '0270081', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '新川町', 'シンカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市向町', '03', '03202', '0270082', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '向町', 'ムカイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市大通', '03', '03202', '0270083', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '大通', 'オオドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市末広町', '03', '03202', '0270084', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '末広町', 'スエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市黒田町', '03', '03202', '0270085', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '黒田町', 'クロタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市新町', '03', '03202', '0270086', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '新町', 'アラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市横町', '03', '03202', '0270087', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '横町', 'ヨコマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市沢田', '03', '03202', '0270088', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '沢田', 'サワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市本町', '03', '03202', '0270089', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '本町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市築地', '03', '03202', '0270091', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '築地', 'ツキジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市愛宕', '03', '03202', '0270092', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '愛宕', 'アタゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市中里団地', '03', '03202', '0270093', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '中里団地', 'ナカサトダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市日の出町', '03', '03202', '0270094', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '日の出町', 'ヒノデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市佐原', '03', '03202', '0270095', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '佐原', 'サバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市崎鍬ケ崎', '03', '03202', '0270096', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '崎鍬ケ崎', 'サキクワガサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市崎山', '03', '03202', '0270097', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '崎山', 'サキヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県我孫子市', '12', '12222', '2701100', '千葉県', 'チバケン', '我孫子市', 'アビコシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('15178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県我孫子市布佐', '12', '12222', '2701101', '千葉県', 'チバケン', '我孫子市', 'アビコシ', '布佐', 'フサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県我孫子市都', '12', '12222', '2701102', '千葉県', 'チバケン', '我孫子市', 'アビコシ', '都', 'ミヤコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県我孫子市布佐酉町', '12', '12222', '2701103', '千葉県', 'チバケン', '我孫子市', 'アビコシ', '布佐酉町', 'フサトリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県我孫子市新々田', '12', '12222', '2701104', '千葉県', 'チバケン', '我孫子市', 'アビコシ', '新々田', 'シンシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県我孫子市三河屋新田', '12', '12222', '2701105', '千葉県', 'チバケン', '我孫子市', 'アビコシ', '三河屋新田', 'ミカワヤシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県我孫子市相島新田', '12', '12222', '2701106', '千葉県', 'チバケン', '我孫子市', 'アビコシ', '相島新田', 'アイジマシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県我孫子市布佐下新田', '12', '12222', '2701107', '千葉県', 'チバケン', '我孫子市', 'アビコシ', '布佐下新田', 'フサシタシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県我孫子市布佐平和台', '12', '12222', '2701108', '千葉県', 'チバケン', '我孫子市', 'アビコシ', '布佐平和台', 'フサヘイワダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市重茂', '03', '03202', '0270111', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '重茂', 'オモエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県我孫子市古戸', '12', '12222', '2701111', '千葉県', 'チバケン', '我孫子市', 'アビコシ', '古戸', 'フルド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県我孫子市新木', '12', '12222', '2701112', '千葉県', 'チバケン', '我孫子市', 'アビコシ', '新木', 'アラキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県我孫子市江蔵地', '12', '12222', '2701113', '千葉県', 'チバケン', '我孫子市', 'アビコシ', '江蔵地', 'エゾウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県我孫子市新木野', '12', '12222', '2701114', '千葉県', 'チバケン', '我孫子市', 'アビコシ', '新木野', 'アラキノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県我孫子市大作新田', '12', '12222', '2701115', '千葉県', 'チバケン', '我孫子市', 'アビコシ', '大作新田', 'オオサクシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県我孫子市浅間前新田', '12', '12222', '2701116', '千葉県', 'チバケン', '我孫子市', 'アビコシ', '浅間前新田', 'センゲンマエシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県我孫子市下沼田', '12', '12222', '2701117', '千葉県', 'チバケン', '我孫子市', 'アビコシ', '下沼田', 'シモヌマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県我孫子市新木村下', '12', '12222', '2701118', '千葉県', 'チバケン', '我孫子市', 'アビコシ', '新木村下', 'アラキムラシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県我孫子市南新木', '12', '12222', '2701119', '千葉県', 'チバケン', '我孫子市', 'アビコシ', '南新木', 'ミナミアラキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市音部', '03', '03202', '0270112', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '音部', 'オトベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県我孫子市中峠', '12', '12222', '2701121', '千葉県', 'チバケン', '我孫子市', 'アビコシ', '中峠', 'ナカビョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県我孫子市中里', '12', '12222', '2701122', '千葉県', 'チバケン', '我孫子市', 'アビコシ', '中里', 'ナカザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県我孫子市日秀', '12', '12222', '2701123', '千葉県', 'チバケン', '我孫子市', 'アビコシ', '日秀', 'ヒビリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県我孫子市日秀新田', '12', '12222', '2701124', '千葉県', 'チバケン', '我孫子市', 'アビコシ', '日秀新田', 'ヒビリシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県我孫子市中沼田', '12', '12222', '2701125', '千葉県', 'チバケン', '我孫子市', 'アビコシ', '中沼田', 'ナカヌマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県我孫子市中里新田', '12', '12222', '2701126', '千葉県', 'チバケン', '我孫子市', 'アビコシ', '中里新田', 'ナカザトシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県我孫子市中峠村下', '12', '12222', '2701127', '千葉県', 'チバケン', '我孫子市', 'アビコシ', '中峠村下', 'ナカビョウムラシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県我孫子市中峠台', '12', '12222', '2701128', '千葉県', 'チバケン', '我孫子市', 'アビコシ', '中峠台', 'ナカビョウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県我孫子市都部', '12', '12222', '2701131', '千葉県', 'チバケン', '我孫子市', 'アビコシ', '都部', 'イチブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県我孫子市湖北台', '12', '12222', '2701132', '千葉県', 'チバケン', '我孫子市', 'アビコシ', '湖北台', 'コホクダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県我孫子市上沼田', '12', '12222', '2701133', '千葉県', 'チバケン', '我孫子市', 'アビコシ', '上沼田', 'カミヌマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県我孫子市都部村新田', '12', '12222', '2701134', '千葉県', 'チバケン', '我孫子市', 'アビコシ', '都部村新田', 'イチブムラシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県我孫子市都部新田', '12', '12222', '2701135', '千葉県', 'チバケン', '我孫子市', 'アビコシ', '都部新田', 'イチブシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県我孫子市岡発戸新田', '12', '12222', '2701136', '千葉県', 'チバケン', '我孫子市', 'アビコシ', '岡発戸新田', 'オカホットシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県我孫子市岡発戸', '12', '12222', '2701137', '千葉県', 'チバケン', '我孫子市', 'アビコシ', '岡発戸', 'オカホット', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県我孫子市下ケ戸', '12', '12222', '2701138', '千葉県', 'チバケン', '我孫子市', 'アビコシ', '下ケ戸', 'サゲト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県我孫子市栄', '12', '12222', '2701141', '千葉県', 'チバケン', '我孫子市', 'アビコシ', '栄', 'サカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県我孫子市泉', '12', '12222', '2701142', '千葉県', 'チバケン', '我孫子市', 'アビコシ', '泉', 'イズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県我孫子市天王台', '12', '12222', '2701143', '千葉県', 'チバケン', '我孫子市', 'アビコシ', '天王台', 'テンノウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県我孫子市東我孫子', '12', '12222', '2701144', '千葉県', 'チバケン', '我孫子市', 'アビコシ', '東我孫子', 'ヒガシアビコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県我孫子市高野山', '12', '12222', '2701145', '千葉県', 'チバケン', '我孫子市', 'アビコシ', '高野山', 'コウノヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県我孫子市高野山新田', '12', '12222', '2701146', '千葉県', 'チバケン', '我孫子市', 'アビコシ', '高野山新田', 'コウノヤマシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県我孫子市若松', '12', '12222', '2701147', '千葉県', 'チバケン', '我孫子市', 'アビコシ', '若松', 'ワカマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県我孫子市本町', '12', '12222', '2701151', '千葉県', 'チバケン', '我孫子市', 'アビコシ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県我孫子市寿', '12', '12222', '2701152', '千葉県', 'チバケン', '我孫子市', 'アビコシ', '寿', 'コトブキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県我孫子市緑', '12', '12222', '2701153', '千葉県', 'チバケン', '我孫子市', 'アビコシ', '緑', 'ミドリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県我孫子市白山', '12', '12222', '2701154', '千葉県', 'チバケン', '我孫子市', 'アビコシ', '白山', 'ハクサン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県我孫子市我孫子新田', '12', '12222', '2701155', '千葉県', 'チバケン', '我孫子市', 'アビコシ', '我孫子新田', 'アビコシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県我孫子市根戸新田', '12', '12222', '2701156', '千葉県', 'チバケン', '我孫子市', 'アビコシ', '根戸新田', 'ネドシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県我孫子市呼塚新田', '12', '12222', '2701157', '千葉県', 'チバケン', '我孫子市', 'アビコシ', '呼塚新田', 'ヨバツカシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県我孫子市船戸', '12', '12222', '2701158', '千葉県', 'チバケン', '我孫子市', 'アビコシ', '船戸', 'フナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県我孫子市布施下', '12', '12222', '2701161', '千葉県', 'チバケン', '我孫子市', 'アビコシ', '布施下', 'フセシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県我孫子市布施', '12', '12222', '2701162', '千葉県', 'チバケン', '我孫子市', 'アビコシ', '布施', 'フセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県我孫子市久寺家', '12', '12222', '2701163', '千葉県', 'チバケン', '我孫子市', 'アビコシ', '久寺家', 'クジケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県我孫子市つくし野', '12', '12222', '2701164', '千葉県', 'チバケン', '我孫子市', 'アビコシ', 'つくし野', 'ツクシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県我孫子市並木', '12', '12222', '2701165', '千葉県', 'チバケン', '我孫子市', 'アビコシ', '並木', 'ナミキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県我孫子市我孫子', '12', '12222', '2701166', '千葉県', 'チバケン', '我孫子市', 'アビコシ', '我孫子', 'アビコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県我孫子市台田', '12', '12222', '2701167', '千葉県', 'チバケン', '我孫子市', 'アビコシ', '台田', 'ダイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県我孫子市根戸', '12', '12222', '2701168', '千葉県', 'チバケン', '我孫子市', 'アビコシ', '根戸', 'ネド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県我孫子市弁天下', '12', '12222', '2701171', '千葉県', 'チバケン', '我孫子市', 'アビコシ', '弁天下', 'ベンテンシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県我孫子市北新田', '12', '12222', '2701172', '千葉県', 'チバケン', '我孫子市', 'アビコシ', '北新田', 'キタシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県我孫子市青山', '12', '12222', '2701173', '千葉県', 'チバケン', '我孫子市', 'アビコシ', '青山', 'アオヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県我孫子市日の出', '12', '12222', '2701174', '千葉県', 'チバケン', '我孫子市', 'アビコシ', '日の出', 'ヒノデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県我孫子市青山台', '12', '12222', '2701175', '千葉県', 'チバケン', '我孫子市', 'アビコシ', '青山台', 'アオヤマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県我孫子市柴崎台', '12', '12222', '2701176', '千葉県', 'チバケン', '我孫子市', 'アビコシ', '柴崎台', 'シバサキダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県我孫子市柴崎', '12', '12222', '2701177', '千葉県', 'チバケン', '我孫子市', 'アビコシ', '柴崎', 'シバサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県我孫子市南青山', '12', '12222', '2701178', '千葉県', 'チバケン', '我孫子市', 'アビコシ', '南青山', 'ミナミアオヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印西市', '12', '12231', '2701300', '千葉県', 'チバケン', '印西市', 'インザイシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('15249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印西市小林北', '12', '12231', '2701313', '千葉県', 'チバケン', '印西市', 'インザイシ', '小林北', 'コバヤシキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印西市小林浅間', '12', '12231', '2701315', '千葉県', 'チバケン', '印西市', 'インザイシ', '小林浅間', 'コバヤシセンゲン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印西市小林大門下', '12', '12231', '2701316', '千葉県', 'チバケン', '印西市', 'インザイシ', '小林大門下', 'コバヤシダイモンシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印西市小林', '12', '12231', '2701318', '千葉県', 'チバケン', '印西市', 'インザイシ', '小林', 'コバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印西市相嶋', '12', '12231', '2701321', '千葉県', 'チバケン', '印西市', 'インザイシ', '相嶋', 'アイジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印西市浅間前', '12', '12231', '2701322', '千葉県', 'チバケン', '印西市', 'インザイシ', '浅間前', 'センゲンマエ', null, null, null, null), ('15255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印西市木下東', '12', '12231', '2701323', '千葉県', 'チバケン', '印西市', 'インザイシ', '木下東', 'キオロシヒガシ', null, null, null, null), ('15256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印西市平岡', '12', '12231', '2701324', '千葉県', 'チバケン', '印西市', 'インザイシ', '平岡', 'ヒラオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印西市竹袋', '12', '12231', '2701325', '千葉県', 'チバケン', '印西市', 'インザイシ', '竹袋', 'タケフクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印西市木下', '12', '12231', '2701326', '千葉県', 'チバケン', '印西市', 'インザイシ', '木下', 'キオロシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印西市大森', '12', '12231', '2701327', '千葉県', 'チバケン', '印西市', 'インザイシ', '大森', 'オオモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印西市木下南', '12', '12231', '2701328', '千葉県', 'チバケン', '印西市', 'インザイシ', '木下南', 'キオロシミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印西市別所', '12', '12231', '2701332', '千葉県', 'チバケン', '印西市', 'インザイシ', '別所', 'ベッショ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印西市宗甫', '12', '12231', '2701333', '千葉県', 'チバケン', '印西市', 'インザイシ', '宗甫', 'ソウホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印西市西の原', '12', '12231', '2701334', '千葉県', 'チバケン', '印西市', 'インザイシ', '西の原', 'ニシノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印西市原', '12', '12231', '2701335', '千葉県', 'チバケン', '印西市', 'インザイシ', '原', 'ハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印西市東の原', '12', '12231', '2701336', '千葉県', 'チバケン', '印西市', 'インザイシ', '東の原', 'ヒガシノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印西市草深', '12', '12231', '2701337', '千葉県', 'チバケン', '印西市', 'インザイシ', '草深', 'ソウフケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印西市松崎台', '12', '12231', '2701338', '千葉県', 'チバケン', '印西市', 'インザイシ', '松崎台', 'マツザキダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印西市中央南', '12', '12231', '2701340', '千葉県', 'チバケン', '印西市', 'インザイシ', '中央南', 'チュウオウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印西市原山', '12', '12231', '2701341', '千葉県', 'チバケン', '印西市', 'インザイシ', '原山', 'ハラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印西市高花', '12', '12231', '2701342', '千葉県', 'チバケン', '印西市', 'インザイシ', '高花', 'タカバナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印西市結縁寺', '12', '12231', '2701343', '千葉県', 'チバケン', '印西市', 'インザイシ', '結縁寺', 'ケツエンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印西市松崎', '12', '12231', '2701344', '千葉県', 'チバケン', '印西市', 'インザイシ', '松崎', 'マツザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印西市船尾', '12', '12231', '2701345', '千葉県', 'チバケン', '印西市', 'インザイシ', '船尾', 'フナオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印西市多々羅田', '12', '12231', '2701346', '千葉県', 'チバケン', '印西市', 'インザイシ', '多々羅田', 'タタラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印西市内野', '12', '12231', '2701347', '千葉県', 'チバケン', '印西市', 'インザイシ', '内野', 'ウチノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印西市戸神', '12', '12231', '2701348', '千葉県', 'チバケン', '印西市', 'インザイシ', '戸神', 'トガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印西市戸神台', '12', '12231', '2701349', '千葉県', 'チバケン', '印西市', 'インザイシ', '戸神台', 'トガミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印西市中央北', '12', '12231', '2701350', '千葉県', 'チバケン', '印西市', 'インザイシ', '中央北', 'チュウオウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印西市和泉', '12', '12231', '2701351', '千葉県', 'チバケン', '印西市', 'インザイシ', '和泉', 'イズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印西市大塚', '12', '12231', '2701352', '千葉県', 'チバケン', '印西市', 'インザイシ', '大塚', 'オオツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印西市泉', '12', '12231', '2701353', '千葉県', 'チバケン', '印西市', 'インザイシ', '泉', 'イズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印西市武西', '12', '12231', '2701354', '千葉県', 'チバケン', '印西市', 'インザイシ', '武西', 'ムザイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印西市武西学園台', '12', '12231', '2701355', '千葉県', 'チバケン', '印西市', 'インザイシ', '武西学園台', 'ムザイガクエンダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印西市小倉台', '12', '12231', '2701356', '千葉県', 'チバケン', '印西市', 'インザイシ', '小倉台', 'オグラダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印西市牧の木戸', '12', '12231', '2701357', '千葉県', 'チバケン', '印西市', 'インザイシ', '牧の木戸', 'マキノキド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印西市小倉', '12', '12231', '2701358', '千葉県', 'チバケン', '印西市', 'インザイシ', '小倉', 'オグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印西市木刈', '12', '12231', '2701359', '千葉県', 'チバケン', '印西市', 'インザイシ', '木刈', 'キカリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印西市発作', '12', '12231', '2701361', '千葉県', 'チバケン', '印西市', 'インザイシ', '発作', 'ホッサク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印西市亀成', '12', '12231', '2701362', '千葉県', 'チバケン', '印西市', 'インザイシ', '亀成', 'カメナリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印西市鹿黒', '12', '12231', '2701363', '千葉県', 'チバケン', '印西市', 'インザイシ', '鹿黒', 'カグロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印西市浦幡新田', '12', '12231', '2701364', '千葉県', 'チバケン', '印西市', 'インザイシ', '浦幡新田', 'ウラハタシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印西市高西新田', '12', '12231', '2701365', '千葉県', 'チバケン', '印西市', 'インザイシ', '高西新田', 'コウサイシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印西市白幡', '12', '12231', '2701366', '千葉県', 'チバケン', '印西市', 'インザイシ', '白幡', 'シラハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印西市浦部', '12', '12231', '2701367', '千葉県', 'チバケン', '印西市', 'インザイシ', '浦部', 'ウラベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印西市浦部村新田', '12', '12231', '2701368', '千葉県', 'チバケン', '印西市', 'インザイシ', '浦部村新田', 'ウラベムラシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県白井市', '12', '12232', '2701400', '千葉県', 'チバケン', '白井市', 'シロイシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('15306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県白井市今井', '12', '12232', '2701401', '千葉県', 'チバケン', '白井市', 'シロイシ', '今井', 'イマイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県白井市平塚', '12', '12232', '2701402', '千葉県', 'チバケン', '白井市', 'シロイシ', '平塚', 'ヒラツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県白井市河原子', '12', '12232', '2701403', '千葉県', 'チバケン', '白井市', 'シロイシ', '河原子', 'カワラゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県白井市折立', '12', '12232', '2701404', '千葉県', 'チバケン', '白井市', 'シロイシ', '折立', 'オリタテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県白井市富塚', '12', '12232', '2701405', '千葉県', 'チバケン', '白井市', 'シロイシ', '富塚', 'トミツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県白井市中', '12', '12232', '2701406', '千葉県', 'チバケン', '白井市', 'シロイシ', '中', 'ナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県白井市名内', '12', '12232', '2701407', '千葉県', 'チバケン', '白井市', 'シロイシ', '名内', 'ナウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県白井市西白井', '12', '12232', '2701408', '千葉県', 'チバケン', '白井市', 'シロイシ', '西白井', 'ニシシロイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県白井市十余一', '12', '12232', '2701411', '千葉県', 'チバケン', '白井市', 'シロイシ', '十余一', 'トヨイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県白井市桜台', '12', '12232', '2701412', '千葉県', 'チバケン', '白井市', 'シロイシ', '桜台', 'サクラダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県白井市武西', '12', '12232', '2701413', '千葉県', 'チバケン', '白井市', 'シロイシ', '武西', 'ムザイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県白井市谷田', '12', '12232', '2701414', '千葉県', 'チバケン', '白井市', 'シロイシ', '谷田', 'ヤタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県白井市清戸', '12', '12232', '2701415', '千葉県', 'チバケン', '白井市', 'シロイシ', '清戸', 'キヨド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県白井市神々廻', '12', '12232', '2701416', '千葉県', 'チバケン', '白井市', 'シロイシ', '神々廻', 'シシバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県白井市白井', '12', '12232', '2701421', '千葉県', 'チバケン', '白井市', 'シロイシ', '白井', 'シロイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県白井市復', '12', '12232', '2701422', '千葉県', 'チバケン', '白井市', 'シロイシ', '復', 'フク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県白井市南山', '12', '12232', '2701423', '千葉県', 'チバケン', '白井市', 'シロイシ', '南山', 'ミナミヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県白井市堀込', '12', '12232', '2701424', '千葉県', 'チバケン', '白井市', 'シロイシ', '堀込', 'ホリゴメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県白井市池の上', '12', '12232', '2701425', '千葉県', 'チバケン', '白井市', 'シロイシ', '池の上', 'イケノカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県白井市笹塚', '12', '12232', '2701426', '千葉県', 'チバケン', '白井市', 'シロイシ', '笹塚', 'ササヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県白井市根', '12', '12232', '2701431', '千葉県', 'チバケン', '白井市', 'シロイシ', '根', 'ネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県白井市冨士', '12', '12232', '2701432', '千葉県', 'チバケン', '白井市', 'シロイシ', '冨士', 'フジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県白井市けやき台', '12', '12232', '2701433', '千葉県', 'チバケン', '白井市', 'シロイシ', 'けやき台', 'ケヤキダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県白井市大山口', '12', '12232', '2701434', '千葉県', 'チバケン', '白井市', 'シロイシ', '大山口', 'オオヤマグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県白井市清水口', '12', '12232', '2701435', '千葉県', 'チバケン', '白井市', 'シロイシ', '清水口', 'シミズグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県白井市七次台', '12', '12232', '2701436', '千葉県', 'チバケン', '白井市', 'シロイシ', '七次台', 'ナナツギダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県白井市木', '12', '12232', '2701437', '千葉県', 'チバケン', '白井市', 'シロイシ', '木', 'キ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県白井市野口', '12', '12232', '2701438', '千葉県', 'チバケン', '白井市', 'シロイシ', '野口', 'ノグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県白井市大松', '12', '12232', '2701439', '千葉県', 'チバケン', '白井市', 'シロイシ', '大松', 'ダイマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市鷲野谷新田', '12', '12217', '2701441', '千葉県', 'チバケン', '柏市', 'カシワシ', '鷲野谷新田', 'ワシノヤシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市染井入新田', '12', '12217', '2701442', '千葉県', 'チバケン', '柏市', 'カシワシ', '染井入新田', 'ソメイイリシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市鷲野谷', '12', '12217', '2701443', '千葉県', 'チバケン', '柏市', 'カシワシ', '鷲野谷', 'ワシノヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市若白毛', '12', '12217', '2701444', '千葉県', 'チバケン', '柏市', 'カシワシ', '若白毛', 'ワカシラガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市岩井', '12', '12217', '2701445', '千葉県', 'チバケン', '柏市', 'カシワシ', '岩井', 'イワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市岩井村新田', '12', '12217', '2701446', '千葉県', 'チバケン', '柏市', 'カシワシ', '岩井村新田', 'イワイムラシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市曙橋', '12', '12217', '2701451', '千葉県', 'チバケン', '柏市', 'カシワシ', '曙橋', 'アケボノバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市片山新田', '12', '12217', '2701452', '千葉県', 'チバケン', '柏市', 'カシワシ', '片山新田', 'カタヤマシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市片山', '12', '12217', '2701453', '千葉県', 'チバケン', '柏市', 'カシワシ', '片山', 'カタヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市柳戸', '12', '12217', '2701454', '千葉県', 'チバケン', '柏市', 'カシワシ', '柳戸', 'ヤナド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市金山', '12', '12217', '2701455', '千葉県', 'チバケン', '柏市', 'カシワシ', '金山', 'カネヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市泉', '12', '12217', '2701456', '千葉県', 'チバケン', '柏市', 'カシワシ', '泉', 'イズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市泉村新田', '12', '12217', '2701457', '千葉県', 'チバケン', '柏市', 'カシワシ', '泉村新田', 'イズミムラシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市水道橋', '12', '12217', '2701461', '千葉県', 'チバケン', '柏市', 'カシワシ', '水道橋', 'スイドウバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市千間橋', '12', '12217', '2701462', '千葉県', 'チバケン', '柏市', 'カシワシ', '千間橋', 'センゲンバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市布瀬新田', '12', '12217', '2701463', '千葉県', 'チバケン', '柏市', 'カシワシ', '布瀬新田', 'フゼシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市布瀬', '12', '12217', '2701464', '千葉県', 'チバケン', '柏市', 'カシワシ', '布瀬', 'フゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市手賀', '12', '12217', '2701465', '千葉県', 'チバケン', '柏市', 'カシワシ', '手賀', 'テガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市手賀新田', '12', '12217', '2701466', '千葉県', 'チバケン', '柏市', 'カシワシ', '手賀新田', 'テガシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県船橋市小室町', '12', '12204', '2701471', '千葉県', 'チバケン', '船橋市', 'フナバシシ', '小室町', 'コムロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印旛郡栄町', '12', '12329', '2701500', '千葉県', 'チバケン', '印旛郡栄町', 'インバグンサカエマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('15360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印旛郡栄町矢口神明', '12', '12329', '2701501', '千葉県', 'チバケン', '印旛郡栄町', 'インバグンサカエマチ', '矢口神明', 'ヤコウシンメイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印旛郡栄町矢口', '12', '12329', '2701502', '千葉県', 'チバケン', '印旛郡栄町', 'インバグンサカエマチ', '矢口', 'ヤコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印旛郡栄町興津', '12', '12329', '2701503', '千葉県', 'チバケン', '印旛郡栄町', 'インバグンサカエマチ', '興津', 'オキツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印旛郡栄町麻生', '12', '12329', '2701504', '千葉県', 'チバケン', '印旛郡栄町', 'インバグンサカエマチ', '麻生', 'アソウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印旛郡栄町竜角寺台', '12', '12329', '2701505', '千葉県', 'チバケン', '印旛郡栄町', 'インバグンサカエマチ', '竜角寺台', 'リュウカクジダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印旛郡栄町龍角寺', '12', '12329', '2701506', '千葉県', 'チバケン', '印旛郡栄町', 'インバグンサカエマチ', '龍角寺', 'リュウカクジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印旛郡栄町北辺田', '12', '12329', '2701511', '千葉県', 'チバケン', '印旛郡栄町', 'インバグンサカエマチ', '北辺田', 'キタベタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印旛郡栄町須賀', '12', '12329', '2701512', '千葉県', 'チバケン', '印旛郡栄町', 'インバグンサカエマチ', '須賀', 'スカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印旛郡栄町酒直', '12', '12329', '2701513', '千葉県', 'チバケン', '印旛郡栄町', 'インバグンサカエマチ', '酒直', 'サカナオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印旛郡栄町酒直台', '12', '12329', '2701514', '千葉県', 'チバケン', '印旛郡栄町', 'インバグンサカエマチ', '酒直台', 'サカナオダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印旛郡栄町安食台', '12', '12329', '2701515', '千葉県', 'チバケン', '印旛郡栄町', 'インバグンサカエマチ', '安食台', 'アジキダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印旛郡栄町安食', '12', '12329', '2701516', '千葉県', 'チバケン', '印旛郡栄町', 'インバグンサカエマチ', '安食', 'アジキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印旛郡栄町安食卜杭新田', '12', '12329', '2701517', '千葉県', 'チバケン', '印旛郡栄町', 'インバグンサカエマチ', '安食卜杭新田', 'アジキボツクイシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印旛郡栄町和田', '12', '12329', '2701521', '千葉県', 'チバケン', '印旛郡栄町', 'インバグンサカエマチ', '和田', 'ワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印旛郡栄町布鎌酒直', '12', '12329', '2701522', '千葉県', 'チバケン', '印旛郡栄町', 'インバグンサカエマチ', '布鎌酒直', 'フカマサカナオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印旛郡栄町脇川', '12', '12329', '2701523', '千葉県', 'チバケン', '印旛郡栄町', 'インバグンサカエマチ', '脇川', 'ワキカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印旛郡栄町長門谷', '12', '12329', '2701524', '千葉県', 'チバケン', '印旛郡栄町', 'インバグンサカエマチ', '長門谷', 'ナガトヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印旛郡栄町四箇', '12', '12329', '2701525', '千葉県', 'チバケン', '印旛郡栄町', 'インバグンサカエマチ', '四箇', 'シカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印旛郡栄町大森', '12', '12329', '2701526', '千葉県', 'チバケン', '印旛郡栄町', 'インバグンサカエマチ', '大森', 'オオモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印旛郡栄町押付', '12', '12329', '2701527', '千葉県', 'チバケン', '印旛郡栄町', 'インバグンサカエマチ', '押付', 'オシツケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印旛郡栄町曽根', '12', '12329', '2701531', '千葉県', 'チバケン', '印旛郡栄町', 'インバグンサカエマチ', '曽根', 'ソネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印旛郡栄町南', '12', '12329', '2701532', '千葉県', 'チバケン', '印旛郡栄町', 'インバグンサカエマチ', '南', 'ミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印旛郡栄町南ケ丘', '12', '12329', '2701533', '千葉県', 'チバケン', '印旛郡栄町', 'インバグンサカエマチ', '南ケ丘', 'ミナミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印旛郡栄町西', '12', '12329', '2701534', '千葉県', 'チバケン', '印旛郡栄町', 'インバグンサカエマチ', '西', 'ニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印旛郡栄町布太', '12', '12329', '2701535', '千葉県', 'チバケン', '印旛郡栄町', 'インバグンサカエマチ', '布太', 'フダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印旛郡栄町三和', '12', '12329', '2701536', '千葉県', 'チバケン', '印旛郡栄町', 'インバグンサカエマチ', '三和', 'ミワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印旛郡栄町龍ケ崎町歩', '12', '12329', '2701541', '千葉県', 'チバケン', '印旛郡栄町', 'インバグンサカエマチ', '龍ケ崎町歩', 'リュウガサキチョウブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印旛郡栄町四ッ谷', '12', '12329', '2701542', '千葉県', 'チバケン', '印旛郡栄町', 'インバグンサカエマチ', '四ッ谷', 'ヨツヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印旛郡栄町請方', '12', '12329', '2701543', '千葉県', 'チバケン', '印旛郡栄町', 'インバグンサカエマチ', '請方', 'ウケカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印旛郡栄町中谷', '12', '12329', '2701544', '千葉県', 'チバケン', '印旛郡栄町', 'インバグンサカエマチ', '中谷', 'ナカヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印旛郡栄町北', '12', '12329', '2701545', '千葉県', 'チバケン', '印旛郡栄町', 'インバグンサカエマチ', '北', 'キタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印旛郡栄町生板鍋子新田', '12', '12329', '2701546', '千葉県', 'チバケン', '印旛郡栄町', 'インバグンサカエマチ', '生板鍋子新田', 'マナイタナベコシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印旛郡印旛村', '12', '12325', '2701600', '千葉県', 'チバケン', '印旛郡印旛村', 'インバグンインバムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('15394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印旛郡印旛村萩原', '12', '12325', '2701601', '千葉県', 'チバケン', '印旛郡印旛村', 'インバグンインバムラ', '萩原', 'ハギワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印旛郡印旛村松虫', '12', '12325', '2701602', '千葉県', 'チバケン', '印旛郡印旛村', 'インバグンインバムラ', '松虫', 'マツムシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印旛郡印旛村吉高', '12', '12325', '2701603', '千葉県', 'チバケン', '印旛郡印旛村', 'インバグンインバムラ', '吉高', 'ヨシタカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印旛郡印旛村山田', '12', '12325', '2701604', '千葉県', 'チバケン', '印旛郡印旛村', 'インバグンインバムラ', '山田', 'ヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印旛郡印旛村平賀', '12', '12325', '2701605', '千葉県', 'チバケン', '印旛郡印旛村', 'インバグンインバムラ', '平賀', 'ヒラカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印旛郡印旛村平賀学園台', '12', '12325', '2701606', '千葉県', 'チバケン', '印旛郡印旛村', 'インバグンインバムラ', '平賀学園台', 'ヒラカガクエンダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印旛郡印旛村美瀬', '12', '12325', '2701607', '千葉県', 'チバケン', '印旛郡印旛村', 'インバグンインバムラ', '美瀬', 'ミセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印旛郡印旛村舞姫', '12', '12325', '2701608', '千葉県', 'チバケン', '印旛郡印旛村', 'インバグンインバムラ', '舞姫', 'マイヒメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印旛郡印旛村若萩', '12', '12325', '2701609', '千葉県', 'チバケン', '印旛郡印旛村', 'インバグンインバムラ', '若萩', 'ワカハギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印旛郡印旛村造谷', '12', '12325', '2701611', '千葉県', 'チバケン', '印旛郡印旛村', 'インバグンインバムラ', '造谷', 'ツクリヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印旛郡印旛村大廻', '12', '12325', '2701612', '千葉県', 'チバケン', '印旛郡印旛村', 'インバグンインバムラ', '大廻', 'オオバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印旛郡印旛村鎌苅', '12', '12325', '2701613', '千葉県', 'チバケン', '印旛郡印旛村', 'インバグンインバムラ', '鎌苅', 'カマガリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印旛郡印旛村瀬戸', '12', '12325', '2701614', '千葉県', 'チバケン', '印旛郡印旛村', 'インバグンインバムラ', '瀬戸', 'セト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印旛郡印旛村師戸', '12', '12325', '2701615', '千葉県', 'チバケン', '印旛郡印旛村', 'インバグンインバムラ', '師戸', 'モロト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印旛郡印旛村岩戸', '12', '12325', '2701616', '千葉県', 'チバケン', '印旛郡印旛村', 'インバグンインバムラ', '岩戸', 'イワト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印旛郡印旛村吉田', '12', '12325', '2701617', '千葉県', 'チバケン', '印旛郡印旛村', 'インバグンインバムラ', '吉田', 'ヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市白浜', '03', '03202', '0270201', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '白浜', 'シラハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市赤前', '03', '03202', '0270202', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '赤前', 'アカマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市津軽石', '03', '03202', '0270203', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '津軽石', 'ツガルイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市高柳新田', '12', '12207', '2702201', '千葉県', 'チバケン', '松戸市', 'マツドシ', '高柳新田', 'タカヤナギシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市高柳', '12', '12207', '2702202', '千葉県', 'チバケン', '松戸市', 'マツドシ', '高柳', 'タカヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市六高台', '12', '12207', '2702203', '千葉県', 'チバケン', '松戸市', 'マツドシ', '六高台', 'ロッコウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市六実', '12', '12207', '2702204', '千葉県', 'チバケン', '松戸市', 'マツドシ', '六実', 'ムツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市五香六実', '12', '12207', '2702211', '千葉県', 'チバケン', '松戸市', 'マツドシ', '五香六実', 'ゴコウムツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市五香南', '12', '12207', '2702212', '千葉県', 'チバケン', '松戸市', 'マツドシ', '五香南', 'ゴコウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市五香', '12', '12207', '2702213', '千葉県', 'チバケン', '松戸市', 'マツドシ', '五香', 'ゴコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市松飛台', '12', '12207', '2702214', '千葉県', 'チバケン', '松戸市', 'マツドシ', '松飛台', 'マツヒダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市串崎南町', '12', '12207', '2702215', '千葉県', 'チバケン', '松戸市', 'マツドシ', '串崎南町', 'クシザキミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市串崎新田', '12', '12207', '2702216', '千葉県', 'チバケン', '松戸市', 'マツドシ', '串崎新田', 'クシザキシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市初富飛地', '12', '12207', '2702217', '千葉県', 'チバケン', '松戸市', 'マツドシ', '初富飛地', 'ハツトミトビチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市五香西', '12', '12207', '2702218', '千葉県', 'チバケン', '松戸市', 'マツドシ', '五香西', 'ゴコウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市紙敷', '12', '12207', '2702221', '千葉県', 'チバケン', '松戸市', 'マツドシ', '紙敷', 'カミシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市高塚新田', '12', '12207', '2702222', '千葉県', 'チバケン', '松戸市', 'マツドシ', '高塚新田', 'タカツカシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市秋山', '12', '12207', '2702223', '千葉県', 'チバケン', '松戸市', 'マツドシ', '秋山', 'アキヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市大橋', '12', '12207', '2702224', '千葉県', 'チバケン', '松戸市', 'マツドシ', '大橋', 'オオハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市稔台', '12', '12207', '2702231', '千葉県', 'チバケン', '松戸市', 'マツドシ', '稔台', 'ミノリダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市和名ケ谷', '12', '12207', '2702232', '千葉県', 'チバケン', '松戸市', 'マツドシ', '和名ケ谷', 'ワナガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市松戸新田', '12', '12207', '2702241', '千葉県', 'チバケン', '松戸市', 'マツドシ', '松戸新田', 'マツドシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市仲井町', '12', '12207', '2702242', '千葉県', 'チバケン', '松戸市', 'マツドシ', '仲井町', 'ナカイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市野菊野', '12', '12207', '2702243', '千葉県', 'チバケン', '松戸市', 'マツドシ', '野菊野', 'ノギクノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市金ケ作', '12', '12207', '2702251', '千葉県', 'チバケン', '松戸市', 'マツドシ', '金ケ作', 'カネガサク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市千駄堀', '12', '12207', '2702252', '千葉県', 'チバケン', '松戸市', 'マツドシ', '千駄堀', 'センダボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市日暮', '12', '12207', '2702253', '千葉県', 'チバケン', '松戸市', 'マツドシ', '日暮', 'ヒグラシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市河原塚', '12', '12207', '2702254', '千葉県', 'チバケン', '松戸市', 'マツドシ', '河原塚', 'カワラヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市田中新田', '12', '12207', '2702255', '千葉県', 'チバケン', '松戸市', 'マツドシ', '田中新田', 'タナカシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市常盤平', '12', '12207', '2702261', '千葉県', 'チバケン', '松戸市', 'マツドシ', '常盤平', 'トキワダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市常盤平双葉町', '12', '12207', '2702262', '千葉県', 'チバケン', '松戸市', 'マツドシ', '常盤平双葉町', 'トキワダイラフタバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市常盤平柳町', '12', '12207', '2702263', '千葉県', 'チバケン', '松戸市', 'マツドシ', '常盤平柳町', 'トキワダイラヤナギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市常盤平松葉町', '12', '12207', '2702264', '千葉県', 'チバケン', '松戸市', 'マツドシ', '常盤平松葉町', 'トキワダイラマツバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市常盤平陣屋前', '12', '12207', '2702265', '千葉県', 'チバケン', '松戸市', 'マツドシ', '常盤平陣屋前', 'トキワダイラジンヤマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市常盤平西窪町', '12', '12207', '2702266', '千葉県', 'チバケン', '松戸市', 'マツドシ', '常盤平西窪町', 'トキワダイラニシクボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市牧の原', '12', '12207', '2702267', '千葉県', 'チバケン', '松戸市', 'マツドシ', '牧の原', 'マキノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印旛郡本埜村', '12', '12328', '2702300', '千葉県', 'チバケン', '印旛郡本埜村', 'インバグンモトノムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('15456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印旛郡本埜村将監', '12', '12328', '2702301', '千葉県', 'チバケン', '印旛郡本埜村', 'インバグンモトノムラ', '将監', 'ショウゲン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印旛郡本埜村安食卜杭', '12', '12328', '2702302', '千葉県', 'チバケン', '印旛郡本埜村', 'インバグンモトノムラ', '安食卜杭', 'アジキボックイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印旛郡本埜村酒直卜杭', '12', '12328', '2702303', '千葉県', 'チバケン', '印旛郡本埜村', 'インバグンモトノムラ', '酒直卜杭', 'サカナオボックイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印旛郡本埜村甚兵衛', '12', '12328', '2702304', '千葉県', 'チバケン', '印旛郡本埜村', 'インバグンモトノムラ', '甚兵衛', 'ジンベエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印旛郡本埜村佐野屋', '12', '12328', '2702305', '千葉県', 'チバケン', '印旛郡本埜村', 'インバグンモトノムラ', '佐野屋', 'サノヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印旛郡本埜村中田切', '12', '12328', '2702306', '千葉県', 'チバケン', '印旛郡本埜村', 'インバグンモトノムラ', '中田切', 'ナカタギリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印旛郡本埜村松木', '12', '12328', '2702307', '千葉県', 'チバケン', '印旛郡本埜村', 'インバグンモトノムラ', '松木', 'マツキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印旛郡本埜村小林', '12', '12328', '2702308', '千葉県', 'チバケン', '印旛郡本埜村', 'インバグンモトノムラ', '小林', 'コバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印旛郡本埜村萩原', '12', '12328', '2702311', '千葉県', 'チバケン', '印旛郡本埜村', 'インバグンモトノムラ', '萩原', 'ハギワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印旛郡本埜村長門屋', '12', '12328', '2702312', '千葉県', 'チバケン', '印旛郡本埜村', 'インバグンモトノムラ', '長門屋', 'ナガトヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印旛郡本埜村下井', '12', '12328', '2702313', '千葉県', 'チバケン', '印旛郡本埜村', 'インバグンモトノムラ', '下井', 'シモイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印旛郡本埜村松虫', '12', '12328', '2702314', '千葉県', 'チバケン', '印旛郡本埜村', 'インバグンモトノムラ', '松虫', 'マツムシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印旛郡本埜村中', '12', '12328', '2702315', '千葉県', 'チバケン', '印旛郡本埜村', 'インバグンモトノムラ', '中', 'ナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印旛郡本埜村行徳', '12', '12328', '2702316', '千葉県', 'チバケン', '印旛郡本埜村', 'インバグンモトノムラ', '行徳', 'ギョウトク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印旛郡本埜村下曽根', '12', '12328', '2702317', '千葉県', 'チバケン', '印旛郡本埜村', 'インバグンモトノムラ', '下曽根', 'シモゾネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印旛郡本埜村押付', '12', '12328', '2702318', '千葉県', 'チバケン', '印旛郡本埜村', 'インバグンモトノムラ', '押付', 'オシツケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印旛郡本埜村川向', '12', '12328', '2702319', '千葉県', 'チバケン', '印旛郡本埜村', 'インバグンモトノムラ', '川向', 'カワムカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印旛郡本埜村物木', '12', '12328', '2702321', '千葉県', 'チバケン', '印旛郡本埜村', 'インバグンモトノムラ', '物木', 'モノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印旛郡本埜村笠神', '12', '12328', '2702322', '千葉県', 'チバケン', '印旛郡本埜村', 'インバグンモトノムラ', '笠神', 'カサガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印旛郡本埜村和泉屋', '12', '12328', '2702323', '千葉県', 'チバケン', '印旛郡本埜村', 'インバグンモトノムラ', '和泉屋', 'イズミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印旛郡本埜村中根', '12', '12328', '2702324', '千葉県', 'チバケン', '印旛郡本埜村', 'インバグンモトノムラ', '中根', 'ナカネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印旛郡本埜村角田', '12', '12328', '2702325', '千葉県', 'チバケン', '印旛郡本埜村', 'インバグンモトノムラ', '角田', 'ツノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印旛郡本埜村荒野', '12', '12328', '2702326', '千葉県', 'チバケン', '印旛郡本埜村', 'インバグンモトノムラ', '荒野', 'コウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印旛郡本埜村竜腹寺', '12', '12328', '2702327', '千葉県', 'チバケン', '印旛郡本埜村', 'インバグンモトノムラ', '竜腹寺', 'リュウフクジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印旛郡本埜村滝', '12', '12328', '2702328', '千葉県', 'チバケン', '印旛郡本埜村', 'インバグンモトノムラ', '滝', 'タキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印旛郡本埜村滝野', '12', '12328', '2702329', '千葉県', 'チバケン', '印旛郡本埜村', 'インバグンモトノムラ', '滝野', 'タキノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印旛郡本埜村みどり台', '12', '12328', '2702331', '千葉県', 'チバケン', '印旛郡本埜村', 'インバグンモトノムラ', 'みどり台', 'ミドリダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市田老館が森', '03', '03202', '0270301', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '田老館が森', 'タロウタテガモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市田老田中', '03', '03202', '0270302', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '田老田中', 'タロウタナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市田老田の沢', '03', '03202', '0270303', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '田老田の沢', 'タロウタノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市田老ケラス', '03', '03202', '0270304', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '田老ケラス', 'タロウケラス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市田老荒谷', '03', '03202', '0270305', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '田老荒谷', 'タロウアリヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市田老川向', '03', '03202', '0270306', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '田老川向', 'タロウカワムカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市田老和野', '03', '03202', '0270311', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '田老和野', 'タロウワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市田老越田', '03', '03202', '0270312', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '田老越田', 'タロウコシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市田老駿達', '03', '03202', '0270313', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '田老駿達', 'タロウシュンダツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市田老乙部', '03', '03202', '0270321', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '田老乙部', 'タロウオトベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市田老青砂里', '03', '03202', '0270322', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '田老青砂里', 'タロウアオザリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市田老野原', '03', '03202', '0270323', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '田老野原', 'タロウノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市田老向山', '03', '03202', '0270324', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '田老向山', 'タロウムカイヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市田老西向山', '03', '03202', '0270331', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '田老西向山', 'タロウニシムカイヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市田老樫内', '03', '03202', '0270332', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '田老樫内', 'タロウカシナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市田老古田', '03', '03202', '0270333', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '田老古田', 'タロウフルタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市田老養呂地', '03', '03202', '0270341', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '田老養呂地', 'タロウヨウロチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市田老小田代', '03', '03202', '0270342', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '田老小田代', 'タロウコダシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市田老上小田代', '03', '03202', '0270343', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '田老上小田代', 'タロウカミコダシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市田老辰の口', '03', '03202', '0270344', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '田老辰の口', 'タロウタツノクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市田老篠倉', '03', '03202', '0270345', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '田老篠倉', 'タロウシノクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市田老七滝', '03', '03202', '0270346', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '田老七滝', 'タロウナナタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市田老笹見平', '03', '03202', '0270347', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '田老笹見平', 'タロウササミタイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市田老小林', '03', '03202', '0270351', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '田老小林', 'タロウコバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市田老八幡水神', '03', '03202', '0270352', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '田老八幡水神', 'タロウヤハタスイジン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市田老和蒔', '03', '03202', '0270353', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '田老和蒔', 'タロウワマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市田老森崎', '03', '03202', '0270354', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '田老森崎', 'タロウモリサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市田老末前', '03', '03202', '0270355', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '田老末前', 'タロウスエマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市田老和山', '03', '03202', '0270356', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '田老和山', 'タロウワヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市田老向桑畑', '03', '03202', '0270357', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '田老向桑畑', 'タロウムカイクワハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市田老立腰', '03', '03202', '0270358', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '田老立腰', 'タロウタテコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市田老青倉', '03', '03202', '0270359', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '田老青倉', 'タロウアオクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市田老小堀内', '03', '03202', '0270361', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '田老小堀内', 'タロウコボリナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市田老小堀内南', '03', '03202', '0270362', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '田老小堀内南', 'タロウコボリナイミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市田老長畑', '03', '03202', '0270363', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '田老長畑', 'タロウナガバタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市田老新田', '03', '03202', '0270364', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '田老新田', 'タロウシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市田老滝の沢', '03', '03202', '0270365', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '田老滝の沢', 'タロウタキノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市田老新田平', '03', '03202', '0270366', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '田老新田平', 'タロウニッタダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市田老鈴子沢', '03', '03202', '0270367', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '田老鈴子沢', 'タロウスズコサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市田老水沢', '03', '03202', '0270371', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '田老水沢', 'タロウミズサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市田老水沢南', '03', '03202', '0270372', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '田老水沢南', 'タロウミズサワミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市田老向新田', '03', '03202', '0270373', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '田老向新田', 'タロウムカイシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市田老青野滝北', '03', '03202', '0270374', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '田老青野滝北', 'タロウアオノタキキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市田老青野滝', '03', '03202', '0270375', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '田老青野滝', 'タロウアオノタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市田老青野滝南', '03', '03202', '0270376', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '田老青野滝南', 'タロウアオノタキミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市田老重津部北', '03', '03202', '0270377', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '田老重津部北', 'タロウオモツベキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市田老重津部', '03', '03202', '0270378', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '田老重津部', 'タロウオモツベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市田老乙部野', '03', '03202', '0270379', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '田老乙部野', 'タロウオトベノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市田老星山', '03', '03202', '0270381', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '田老星山', 'タロウホシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市田老片巻', '03', '03202', '0270382', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '田老片巻', 'タロウカタマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市田老上摂待', '03', '03202', '0270383', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '田老上摂待', 'タロウカミセッタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市田老摂待', '03', '03202', '0270384', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '田老摂待', 'タロウセッタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市田老下摂待', '03', '03202', '0270385', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '田老下摂待', 'タロウシモセッタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市田老胡桃畑', '03', '03202', '0270386', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '田老胡桃畑', 'タロウクルミハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市田老畑', '03', '03202', '0270387', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '田老畑', 'タロウハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市田老上沖', '03', '03202', '0270388', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '田老上沖', 'タロウカミオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡岩泉町小本', '03', '03483', '0270421', '岩手県', 'イワテケン', '下閉伊郡岩泉町', 'シモヘイグンイワイズミチョウ', '小本', 'オモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡岩泉町中島', '03', '03483', '0270422', '岩手県', 'イワテケン', '下閉伊郡岩泉町', 'シモヘイグンイワイズミチョウ', '中島', 'ナカシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡岩泉町中里', '03', '03483', '0270423', '岩手県', 'イワテケン', '下閉伊郡岩泉町', 'シモヘイグンイワイズミチョウ', '中里', 'ナカサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡岩泉町袰野', '03', '03483', '0270424', '岩手県', 'イワテケン', '下閉伊郡岩泉町', 'シモヘイグンイワイズミチョウ', '袰野', 'ホロノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡岩泉町', '03', '03483', '0270500', '岩手県', 'イワテケン', '下閉伊郡岩泉町', 'シモヘイグンイワイズミチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('15546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡岩泉町岩泉', '03', '03483', '0270501', '岩手県', 'イワテケン', '下閉伊郡岩泉町', 'シモヘイグンイワイズミチョウ', '岩泉', 'イワイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡岩泉町乙茂', '03', '03483', '0270502', '岩手県', 'イワテケン', '下閉伊郡岩泉町', 'シモヘイグンイワイズミチョウ', '乙茂', 'オトモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡岩泉町猿沢', '03', '03483', '0270503', '岩手県', 'イワテケン', '下閉伊郡岩泉町', 'シモヘイグンイワイズミチョウ', '猿沢', 'サルサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡岩泉町下有芸', '03', '03483', '0270504', '岩手県', 'イワテケン', '下閉伊郡岩泉町', 'シモヘイグンイワイズミチョウ', '下有芸', 'シモウゲイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡岩泉町上有芸', '03', '03483', '0270505', '岩手県', 'イワテケン', '下閉伊郡岩泉町', 'シモヘイグンイワイズミチョウ', '上有芸', 'カミウゲイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡岩泉町鼠入', '03', '03483', '0270506', '岩手県', 'イワテケン', '下閉伊郡岩泉町', 'シモヘイグンイワイズミチョウ', '鼠入', 'ソイリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡岩泉町二升石', '03', '03483', '0270507', '岩手県', 'イワテケン', '下閉伊郡岩泉町', 'シモヘイグンイワイズミチョウ', '二升石', 'ニショウイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡岩泉町尼額', '03', '03483', '0270508', '岩手県', 'イワテケン', '下閉伊郡岩泉町', 'シモヘイグンイワイズミチョウ', '尼額', 'アマヒタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡岩泉町安家', '03', '03483', '0270611', '岩手県', 'イワテケン', '下閉伊郡岩泉町', 'シモヘイグンイワイズミチョウ', '安家', 'アッカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市七右衛門新田', '12', '12207', '2710041', '千葉県', 'チバケン', '松戸市', 'マツドシ', '七右衛門新田', 'シチウエモンシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市主水新田', '12', '12207', '2710042', '千葉県', 'チバケン', '松戸市', 'マツドシ', '主水新田', 'モントシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市旭町', '12', '12207', '2710043', '千葉県', 'チバケン', '松戸市', 'マツドシ', '旭町', 'アサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市西馬橋', '12', '12207', '2710044', '千葉県', 'チバケン', '松戸市', 'マツドシ', '西馬橋', 'ニシマバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市西馬橋相川町', '12', '12207', '2710045', '千葉県', 'チバケン', '松戸市', 'マツドシ', '西馬橋相川町', 'ニシマバシアイカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市西馬橋蔵元町', '12', '12207', '2710046', '千葉県', 'チバケン', '松戸市', 'マツドシ', '西馬橋蔵元町', 'ニシマバシクラモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市西馬橋幸町', '12', '12207', '2710047', '千葉県', 'チバケン', '松戸市', 'マツドシ', '西馬橋幸町', 'ニシマバシサイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市西馬橋広手町', '12', '12207', '2710048', '千葉県', 'チバケン', '松戸市', 'マツドシ', '西馬橋広手町', 'ニシマバシヒロテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市馬橋', '12', '12207', '2710051', '千葉県', 'チバケン', '松戸市', 'マツドシ', '馬橋', 'マバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市新作', '12', '12207', '2710052', '千葉県', 'チバケン', '松戸市', 'マツドシ', '新作', 'シンザク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市中根', '12', '12207', '2710053', '千葉県', 'チバケン', '松戸市', 'マツドシ', '中根', 'ナカネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市中根長津町', '12', '12207', '2710054', '千葉県', 'チバケン', '松戸市', 'マツドシ', '中根長津町', 'ナカネナガツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市栄町西', '12', '12207', '2710061', '千葉県', 'チバケン', '松戸市', 'マツドシ', '栄町西', 'サカエチョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市栄町', '12', '12207', '2710062', '千葉県', 'チバケン', '松戸市', 'マツドシ', '栄町', 'サカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市北松戸', '12', '12207', '2710063', '千葉県', 'チバケン', '松戸市', 'マツドシ', '北松戸', 'キタマツド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市上本郷', '12', '12207', '2710064', '千葉県', 'チバケン', '松戸市', 'マツドシ', '上本郷', 'カミホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市南花島', '12', '12207', '2710065', '千葉県', 'チバケン', '松戸市', 'マツドシ', '南花島', 'ミナミハナシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市吉井町', '12', '12207', '2710066', '千葉県', 'チバケン', '松戸市', 'マツドシ', '吉井町', 'ヨシイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市樋野口', '12', '12207', '2710067', '千葉県', 'チバケン', '松戸市', 'マツドシ', '樋野口', 'ヒノクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市古ケ崎', '12', '12207', '2710068', '千葉県', 'チバケン', '松戸市', 'マツドシ', '古ケ崎', 'コガサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市竹ケ花西町', '12', '12207', '2710071', '千葉県', 'チバケン', '松戸市', 'マツドシ', '竹ケ花西町', 'タケガハナニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市竹ケ花', '12', '12207', '2710072', '千葉県', 'チバケン', '松戸市', 'マツドシ', '竹ケ花', 'タケガハナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市小根本', '12', '12207', '2710073', '千葉県', 'チバケン', '松戸市', 'マツドシ', '小根本', 'コネモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市緑ケ丘', '12', '12207', '2710074', '千葉県', 'チバケン', '松戸市', 'マツドシ', '緑ケ丘', 'ミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市胡録台', '12', '12207', '2710075', '千葉県', 'チバケン', '松戸市', 'マツドシ', '胡録台', 'コロクダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市岩瀬', '12', '12207', '2710076', '千葉県', 'チバケン', '松戸市', 'マツドシ', '岩瀬', 'イワセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市根本', '12', '12207', '2710077', '千葉県', 'チバケン', '松戸市', 'マツドシ', '根本', 'ネモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市二十世紀が丘美野里町', '12', '12207', '2710081', '千葉県', 'チバケン', '松戸市', 'マツドシ', '二十世紀が丘美野里町', 'ニジュッセイキガオカミノリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市二十世紀が丘戸山町', '12', '12207', '2710082', '千葉県', 'チバケン', '松戸市', 'マツドシ', '二十世紀が丘戸山町', 'ニジュッセイキガオカトヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市二十世紀が丘梨元町', '12', '12207', '2710083', '千葉県', 'チバケン', '松戸市', 'マツドシ', '二十世紀が丘梨元町', 'ニジュッセイキガオカナシモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市二十世紀が丘丸山町', '12', '12207', '2710084', '千葉県', 'チバケン', '松戸市', 'マツドシ', '二十世紀が丘丸山町', 'ニジュッセイキガオカマルヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市二十世紀が丘中松町', '12', '12207', '2710085', '千葉県', 'チバケン', '松戸市', 'マツドシ', '二十世紀が丘中松町', 'ニジュッセイキガオカナカマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市二十世紀が丘萩町', '12', '12207', '2710086', '千葉県', 'チバケン', '松戸市', 'マツドシ', '二十世紀が丘萩町', 'ニジュッセイキガオカハギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市三矢小台', '12', '12207', '2710087', '千葉県', 'チバケン', '松戸市', 'マツドシ', '三矢小台', 'ミヤコダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市二十世紀が丘柿の木町', '12', '12207', '2710088', '千葉県', 'チバケン', '松戸市', 'マツドシ', '二十世紀が丘柿の木町', 'ニジュッセイキガオカカキノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市本町', '12', '12207', '2710091', '千葉県', 'チバケン', '松戸市', 'マツドシ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市松戸', '12', '12207', '2710092', '千葉県', 'チバケン', '松戸市', 'マツドシ', '松戸', 'マツド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市小山', '12', '12207', '2710093', '千葉県', 'チバケン', '松戸市', 'マツドシ', '小山', 'コヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市上矢切', '12', '12207', '2710094', '千葉県', 'チバケン', '松戸市', 'マツドシ', '上矢切', 'カミヤキリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市中矢切', '12', '12207', '2710095', '千葉県', 'チバケン', '松戸市', 'マツドシ', '中矢切', 'ナカヤキリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市下矢切', '12', '12207', '2710096', '千葉県', 'チバケン', '松戸市', 'マツドシ', '下矢切', 'シモヤキリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県松戸市栗山', '12', '12207', '2710097', '千葉県', 'チバケン', '松戸市', 'マツドシ', '栗山', 'クリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市川市', '12', '12203', '2720000', '千葉県', 'チバケン', '市川市', 'イチカワシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('15626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市川市二俣', '12', '12203', '2720001', '千葉県', 'チバケン', '市川市', 'イチカワシ', '二俣', 'フタマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市川市二俣新町', '12', '12203', '2720002', '千葉県', 'チバケン', '市川市', 'イチカワシ', '二俣新町', 'フタマタシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市川市東浜', '12', '12203', '2720003', '千葉県', 'チバケン', '市川市', 'イチカワシ', '東浜', 'ヒガシハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市川市原木', '12', '12203', '2720004', '千葉県', 'チバケン', '市川市', 'イチカワシ', '原木', 'バラキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市川市高谷新町', '12', '12203', '2720011', '千葉県', 'チバケン', '市川市', 'イチカワシ', '高谷新町', 'コウヤシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市川市上妙典', '12', '12203', '2720012', '千葉県', 'チバケン', '市川市', 'イチカワシ', '上妙典', 'カミミョウデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市川市高谷', '12', '12203', '2720013', '千葉県', 'チバケン', '市川市', 'イチカワシ', '高谷', 'コウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市川市田尻', '12', '12203', '2720014', '千葉県', 'チバケン', '市川市', 'イチカワシ', '田尻', 'タジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市川市鬼高', '12', '12203', '2720015', '千葉県', 'チバケン', '市川市', 'イチカワシ', '鬼高', 'オニタカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市川市八幡', '12', '12203', '2720021', '千葉県', 'チバケン', '市川市', 'イチカワシ', '八幡', 'ヤワタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市川市鬼越', '12', '12203', '2720022', '千葉県', 'チバケン', '市川市', 'イチカワシ', '鬼越', 'オニゴエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市川市南八幡', '12', '12203', '2720023', '千葉県', 'チバケン', '市川市', 'イチカワシ', '南八幡', 'ミナミヤワタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市川市稲荷木', '12', '12203', '2720024', '千葉県', 'チバケン', '市川市', 'イチカワシ', '稲荷木', 'トウカギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市川市大和田', '12', '12203', '2720025', '千葉県', 'チバケン', '市川市', 'イチカワシ', '大和田', 'オオワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市川市東大和田', '12', '12203', '2720026', '千葉県', 'チバケン', '市川市', 'イチカワシ', '東大和田', 'ヒガシオオワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市川市平田', '12', '12203', '2720031', '千葉県', 'チバケン', '市川市', 'イチカワシ', '平田', 'ヒラタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市川市大洲', '12', '12203', '2720032', '千葉県', 'チバケン', '市川市', 'イチカワシ', '大洲', 'オオス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市川市市川南', '12', '12203', '2720033', '千葉県', 'チバケン', '市川市', 'イチカワシ', '市川南', 'イチカワミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市川市市川', '12', '12203', '2720034', '千葉県', 'チバケン', '市川市', 'イチカワシ', '市川', 'イチカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市川市新田', '12', '12203', '2720035', '千葉県', 'チバケン', '市川市', 'イチカワシ', '新田', 'シンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市川市河原', '12', '12203', '2720101', '千葉県', 'チバケン', '市川市', 'イチカワシ', '河原', 'カワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市川市下新宿', '12', '12203', '2720102', '千葉県', 'チバケン', '市川市', 'イチカワシ', '下新宿', 'シモシンシュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市川市本行徳', '12', '12203', '2720103', '千葉県', 'チバケン', '市川市', 'イチカワシ', '本行徳', 'ホンギョウトク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市川市本塩', '12', '12203', '2720104', '千葉県', 'チバケン', '市川市', 'イチカワシ', '本塩', 'ホンシオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市川市関ケ島', '12', '12203', '2720105', '千葉県', 'チバケン', '市川市', 'イチカワシ', '関ケ島', 'セキガシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市川市伊勢宿', '12', '12203', '2720106', '千葉県', 'チバケン', '市川市', 'イチカワシ', '伊勢宿', 'イセジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市川市押切', '12', '12203', '2720107', '千葉県', 'チバケン', '市川市', 'イチカワシ', '押切', 'オシキリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市川市妙典', '12', '12203', '2720111', '千葉県', 'チバケン', '市川市', 'イチカワシ', '妙典', 'ミョウデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市川市上妙典', '12', '12203', '2720112', '千葉県', 'チバケン', '市川市', 'イチカワシ', '上妙典', 'カミミョウデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市川市下妙典', '12', '12203', '2720113', '千葉県', 'チバケン', '市川市', 'イチカワシ', '下妙典', 'シモミョウデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市川市塩焼', '12', '12203', '2720114', '千葉県', 'チバケン', '市川市', 'イチカワシ', '塩焼', 'シオヤキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市川市富浜', '12', '12203', '2720115', '千葉県', 'チバケン', '市川市', 'イチカワシ', '富浜', 'トミハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市川市末広', '12', '12203', '2720121', '千葉県', 'チバケン', '市川市', 'イチカワシ', '末広', 'スエヒロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市川市宝', '12', '12203', '2720122', '千葉県', 'チバケン', '市川市', 'イチカワシ', '宝', 'タカラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市川市幸', '12', '12203', '2720123', '千葉県', 'チバケン', '市川市', 'イチカワシ', '幸', 'サイワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市川市加藤新田', '12', '12203', '2720124', '千葉県', 'チバケン', '市川市', 'イチカワシ', '加藤新田', 'カトウシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市川市高浜町', '12', '12203', '2720125', '千葉県', 'チバケン', '市川市', 'イチカワシ', '高浜町', 'タカハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市川市千鳥町', '12', '12203', '2720126', '千葉県', 'チバケン', '市川市', 'イチカワシ', '千鳥町', 'チドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市川市塩浜', '12', '12203', '2720127', '千葉県', 'チバケン', '市川市', 'イチカワシ', '塩浜', 'シオハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市川市湊', '12', '12203', '2720131', '千葉県', 'チバケン', '市川市', 'イチカワシ', '湊', 'ミナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市川市湊新田', '12', '12203', '2720132', '千葉県', 'チバケン', '市川市', 'イチカワシ', '湊新田', 'ミナトシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市川市行徳駅前', '12', '12203', '2720133', '千葉県', 'チバケン', '市川市', 'イチカワシ', '行徳駅前', 'ギョウトクエキマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市川市入船', '12', '12203', '2720134', '千葉県', 'チバケン', '市川市', 'イチカワシ', '入船', 'イリフネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市川市日之出', '12', '12203', '2720135', '千葉県', 'チバケン', '市川市', 'イチカワシ', '日之出', 'ヒノデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市川市新浜', '12', '12203', '2720136', '千葉県', 'チバケン', '市川市', 'イチカワシ', '新浜', 'ニイハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市川市福栄', '12', '12203', '2720137', '千葉県', 'チバケン', '市川市', 'イチカワシ', '福栄', 'フクエイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市川市南行徳', '12', '12203', '2720138', '千葉県', 'チバケン', '市川市', 'イチカワシ', '南行徳', 'ミナミギョウトク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市川市香取', '12', '12203', '2720141', '千葉県', 'チバケン', '市川市', 'イチカワシ', '香取', 'カンドリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市川市欠真間', '12', '12203', '2720142', '千葉県', 'チバケン', '市川市', 'イチカワシ', '欠真間', 'カケママ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市川市相之川', '12', '12203', '2720143', '千葉県', 'チバケン', '市川市', 'イチカワシ', '相之川', 'アイノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市川市新井', '12', '12203', '2720144', '千葉県', 'チバケン', '市川市', 'イチカワシ', '新井', 'アライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市川市島尻', '12', '12203', '2720145', '千葉県', 'チバケン', '市川市', 'イチカワシ', '島尻', 'シマジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市川市広尾', '12', '12203', '2720146', '千葉県', 'チバケン', '市川市', 'イチカワシ', '広尾', 'ヒロオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市川市大町', '12', '12203', '2720801', '千葉県', 'チバケン', '市川市', 'イチカワシ', '大町', 'オオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市川市柏井町', '12', '12203', '2720802', '千葉県', 'チバケン', '市川市', 'イチカワシ', '柏井町', 'カシワイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市川市奉免町', '12', '12203', '2720803', '千葉県', 'チバケン', '市川市', 'イチカワシ', '奉免町', 'ホウメマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市川市南大野', '12', '12203', '2720804', '千葉県', 'チバケン', '市川市', 'イチカワシ', '南大野', 'ミナミオオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市川市大野町', '12', '12203', '2720805', '千葉県', 'チバケン', '市川市', 'イチカワシ', '大野町', 'オオノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市川市北方町', '12', '12203', '2720811', '千葉県', 'チバケン', '市川市', 'イチカワシ', '北方町', 'ボッケマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市川市若宮', '12', '12203', '2720812', '千葉県', 'チバケン', '市川市', 'イチカワシ', '若宮', 'ワカミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市川市中山', '12', '12203', '2720813', '千葉県', 'チバケン', '市川市', 'イチカワシ', '中山', 'ナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市川市高石神', '12', '12203', '2720814', '千葉県', 'チバケン', '市川市', 'イチカワシ', '高石神', 'タカイシガミ', null, null, null, null), ('15688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市川市北方', '12', '12203', '2720815', '千葉県', 'チバケン', '市川市', 'イチカワシ', '北方', 'キタカタ', null, null, null, null), ('15689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市川市本北方', '12', '12203', '2720816', '千葉県', 'チバケン', '市川市', 'イチカワシ', '本北方', 'モトキタカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市川市下貝塚', '12', '12203', '2720821', '千葉県', 'チバケン', '市川市', 'イチカワシ', '下貝塚', 'シモカイヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市川市宮久保', '12', '12203', '2720822', '千葉県', 'チバケン', '市川市', 'イチカワシ', '宮久保', 'ミヤクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市川市東菅野', '12', '12203', '2720823', '千葉県', 'チバケン', '市川市', 'イチカワシ', '東菅野', 'ヒガシスガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市川市菅野', '12', '12203', '2720824', '千葉県', 'チバケン', '市川市', 'イチカワシ', '菅野', 'スガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市川市須和田', '12', '12203', '2720825', '千葉県', 'チバケン', '市川市', 'イチカワシ', '須和田', 'スワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市川市真間', '12', '12203', '2720826', '千葉県', 'チバケン', '市川市', 'イチカワシ', '真間', 'ママ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市川市国府台', '12', '12203', '2720827', '千葉県', 'チバケン', '市川市', 'イチカワシ', '国府台', 'コウノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市川市稲越町', '12', '12203', '2720831', '千葉県', 'チバケン', '市川市', 'イチカワシ', '稲越町', 'イナゴシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市川市曽谷', '12', '12203', '2720832', '千葉県', 'チバケン', '市川市', 'イチカワシ', '曽谷', 'ソヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市川市東国分', '12', '12203', '2720833', '千葉県', 'チバケン', '市川市', 'イチカワシ', '東国分', 'ヒガシコクブン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市川市国分', '12', '12203', '2720834', '千葉県', 'チバケン', '市川市', 'イチカワシ', '国分', 'コクブン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市川市中国分', '12', '12203', '2720835', '千葉県', 'チバケン', '市川市', 'イチカワシ', '中国分', 'ナカコクブン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市川市北国分', '12', '12203', '2720836', '千葉県', 'チバケン', '市川市', 'イチカワシ', '北国分', 'キタコクブン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市川市堀之内', '12', '12203', '2720837', '千葉県', 'チバケン', '市川市', 'イチカワシ', '堀之内', 'ホリノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県船橋市', '12', '12204', '2730000', '千葉県', 'チバケン', '船橋市', 'フナバシシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('15730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県船橋市市場', '12', '12204', '2730001', '千葉県', 'チバケン', '船橋市', 'フナバシシ', '市場', 'イチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県船橋市東船橋', '12', '12204', '2730002', '千葉県', 'チバケン', '船橋市', 'フナバシシ', '東船橋', 'ヒガシフナバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県船橋市宮本', '12', '12204', '2730003', '千葉県', 'チバケン', '船橋市', 'フナバシシ', '宮本', 'ミヤモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県船橋市南本町', '12', '12204', '2730004', '千葉県', 'チバケン', '船橋市', 'フナバシシ', '南本町', 'ミナミホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県船橋市本町', '12', '12204', '2730005', '千葉県', 'チバケン', '船橋市', 'フナバシシ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県船橋市湊町', '12', '12204', '2730011', '千葉県', 'チバケン', '船橋市', 'フナバシシ', '湊町', 'ミナトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県船橋市浜町', '12', '12204', '2730012', '千葉県', 'チバケン', '船橋市', 'フナバシシ', '浜町', 'ハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県船橋市若松', '12', '12204', '2730013', '千葉県', 'チバケン', '船橋市', 'フナバシシ', '若松', 'ワカマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県船橋市高瀬町', '12', '12204', '2730014', '千葉県', 'チバケン', '船橋市', 'フナバシシ', '高瀬町', 'タカセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県船橋市日の出', '12', '12204', '2730015', '千葉県', 'チバケン', '船橋市', 'フナバシシ', '日の出', 'ヒノデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県船橋市潮見町', '12', '12204', '2730016', '千葉県', 'チバケン', '船橋市', 'フナバシシ', '潮見町', 'シオミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県船橋市西浦', '12', '12204', '2730017', '千葉県', 'チバケン', '船橋市', 'フナバシシ', '西浦', 'ニシウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県船橋市栄町', '12', '12204', '2730018', '千葉県', 'チバケン', '船橋市', 'フナバシシ', '栄町', 'サカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県船橋市海神', '12', '12204', '2730021', '千葉県', 'チバケン', '船橋市', 'フナバシシ', '海神', 'カイジン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県船橋市海神町', '12', '12204', '2730022', '千葉県', 'チバケン', '船橋市', 'フナバシシ', '海神町', 'カイジンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県船橋市南海神', '12', '12204', '2730023', '千葉県', 'チバケン', '船橋市', 'フナバシシ', '南海神', 'ミナミカイジン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県船橋市海神町南', '12', '12204', '2730024', '千葉県', 'チバケン', '船橋市', 'フナバシシ', '海神町南', 'カイジンチョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県船橋市印内町', '12', '12204', '2730025', '千葉県', 'チバケン', '船橋市', 'フナバシシ', '印内町', 'インナイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県船橋市山野町', '12', '12204', '2730026', '千葉県', 'チバケン', '船橋市', 'フナバシシ', '山野町', 'ヤマノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県船橋市海神町西', '12', '12204', '2730027', '千葉県', 'チバケン', '船橋市', 'フナバシシ', '海神町西', 'カイジンチョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県船橋市海神町東', '12', '12204', '2730028', '千葉県', 'チバケン', '船橋市', 'フナバシシ', '海神町東', 'カイジンチョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県船橋市西船', '12', '12204', '2730031', '千葉県', 'チバケン', '船橋市', 'フナバシシ', '西船', 'ニシフナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県船橋市葛飾町', '12', '12204', '2730032', '千葉県', 'チバケン', '船橋市', 'フナバシシ', '葛飾町', 'カツシカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県船橋市本郷町', '12', '12204', '2730033', '千葉県', 'チバケン', '船橋市', 'フナバシシ', '本郷町', 'ホンゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県船橋市二子町', '12', '12204', '2730034', '千葉県', 'チバケン', '船橋市', 'フナバシシ', '二子町', 'フタゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県船橋市本中山', '12', '12204', '2730035', '千葉県', 'チバケン', '船橋市', 'フナバシシ', '本中山', 'モトナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県船橋市東中山', '12', '12204', '2730036', '千葉県', 'チバケン', '船橋市', 'フナバシシ', '東中山', 'ヒガシナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県船橋市古作', '12', '12204', '2730037', '千葉県', 'チバケン', '船橋市', 'フナバシシ', '古作', 'コサク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県船橋市古作町', '12', '12204', '2730038', '千葉県', 'チバケン', '船橋市', 'フナバシシ', '古作町', 'コサクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県船橋市印内', '12', '12204', '2730039', '千葉県', 'チバケン', '船橋市', 'フナバシシ', '印内', 'インナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県船橋市旭町', '12', '12204', '2730041', '千葉県', 'チバケン', '船橋市', 'フナバシシ', '旭町', 'アサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県船橋市前貝塚町', '12', '12204', '2730042', '千葉県', 'チバケン', '船橋市', 'フナバシシ', '前貝塚町', 'マエカイヅカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県船橋市行田町', '12', '12204', '2730043', '千葉県', 'チバケン', '船橋市', 'フナバシシ', '行田町', 'ギョウダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県船橋市行田', '12', '12204', '2730044', '千葉県', 'チバケン', '船橋市', 'フナバシシ', '行田', 'ギョウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県船橋市山手', '12', '12204', '2730045', '千葉県', 'チバケン', '船橋市', 'フナバシシ', '山手', 'ヤマテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県船橋市上山町', '12', '12204', '2730046', '千葉県', 'チバケン', '船橋市', 'フナバシシ', '上山町', 'カミヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県船橋市藤原', '12', '12204', '2730047', '千葉県', 'チバケン', '船橋市', 'フナバシシ', '藤原', 'フジワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県船橋市丸山', '12', '12204', '2730048', '千葉県', 'チバケン', '船橋市', 'フナバシシ', '丸山', 'マルヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鎌ケ谷市', '12', '12224', '2730100', '千葉県', 'チバケン', '鎌ケ谷市', 'カマガヤシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('15769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鎌ケ谷市富岡', '12', '12224', '2730101', '千葉県', 'チバケン', '鎌ケ谷市', 'カマガヤシ', '富岡', 'トミオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鎌ケ谷市右京塚', '12', '12224', '2730102', '千葉県', 'チバケン', '鎌ケ谷市', 'カマガヤシ', '右京塚', 'ウキョウヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鎌ケ谷市丸山', '12', '12224', '2730103', '千葉県', 'チバケン', '鎌ケ谷市', 'カマガヤシ', '丸山', 'マルヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鎌ケ谷市東鎌ケ谷', '12', '12224', '2730104', '千葉県', 'チバケン', '鎌ケ谷市', 'カマガヤシ', '東鎌ケ谷', 'ヒガシカマガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鎌ケ谷市鎌ケ谷', '12', '12224', '2730105', '千葉県', 'チバケン', '鎌ケ谷市', 'カマガヤシ', '鎌ケ谷', 'カマガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鎌ケ谷市南鎌ケ谷', '12', '12224', '2730106', '千葉県', 'チバケン', '鎌ケ谷市', 'カマガヤシ', '南鎌ケ谷', 'ミナミカマガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鎌ケ谷市新鎌ケ谷', '12', '12224', '2730107', '千葉県', 'チバケン', '鎌ケ谷市', 'カマガヤシ', '新鎌ケ谷', 'シンカマガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鎌ケ谷市北中沢', '12', '12224', '2730111', '千葉県', 'チバケン', '鎌ケ谷市', 'カマガヤシ', '北中沢', 'キタナカザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鎌ケ谷市東中沢', '12', '12224', '2730112', '千葉県', 'チバケン', '鎌ケ谷市', 'カマガヤシ', '東中沢', 'ヒガシナカザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鎌ケ谷市道野辺中央', '12', '12224', '2730113', '千葉県', 'チバケン', '鎌ケ谷市', 'カマガヤシ', '道野辺中央', 'ミチノベチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鎌ケ谷市道野辺', '12', '12224', '2730114', '千葉県', 'チバケン', '鎌ケ谷市', 'カマガヤシ', '道野辺', 'ミチノベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鎌ケ谷市東道野辺', '12', '12224', '2730115', '千葉県', 'チバケン', '鎌ケ谷市', 'カマガヤシ', '東道野辺', 'ヒガシミチノベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鎌ケ谷市馬込沢', '12', '12224', '2730116', '千葉県', 'チバケン', '鎌ケ谷市', 'カマガヤシ', '馬込沢', 'マゴメザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鎌ケ谷市西道野辺', '12', '12224', '2730117', '千葉県', 'チバケン', '鎌ケ谷市', 'カマガヤシ', '西道野辺', 'ニシミチノベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鎌ケ谷市中沢', '12', '12224', '2730118', '千葉県', 'チバケン', '鎌ケ谷市', 'カマガヤシ', '中沢', 'ナカザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鎌ケ谷市中沢新町', '12', '12224', '2730119', '千葉県', 'チバケン', '鎌ケ谷市', 'カマガヤシ', '中沢新町', 'ナカザワシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鎌ケ谷市初富', '12', '12224', '2730121', '千葉県', 'チバケン', '鎌ケ谷市', 'カマガヤシ', '初富', 'ハツトミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鎌ケ谷市東初富', '12', '12224', '2730122', '千葉県', 'チバケン', '鎌ケ谷市', 'カマガヤシ', '東初富', 'ヒガシハツトミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鎌ケ谷市南初富', '12', '12224', '2730123', '千葉県', 'チバケン', '鎌ケ谷市', 'カマガヤシ', '南初富', 'ミナミハツトミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鎌ケ谷市中央', '12', '12224', '2730124', '千葉県', 'チバケン', '鎌ケ谷市', 'カマガヤシ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鎌ケ谷市初富本町', '12', '12224', '2730125', '千葉県', 'チバケン', '鎌ケ谷市', 'カマガヤシ', '初富本町', 'ハツトミホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鎌ケ谷市北初富', '12', '12224', '2730126', '千葉県', 'チバケン', '鎌ケ谷市', 'カマガヤシ', '北初富', 'キタハツトミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鎌ケ谷市串崎新田', '12', '12224', '2730127', '千葉県', 'チバケン', '鎌ケ谷市', 'カマガヤシ', '串崎新田', 'クシザキシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鎌ケ谷市くぬぎ山', '12', '12224', '2730128', '千葉県', 'チバケン', '鎌ケ谷市', 'カマガヤシ', 'くぬぎ山', 'クヌギヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鎌ケ谷市軽井沢', '12', '12224', '2730131', '千葉県', 'チバケン', '鎌ケ谷市', 'カマガヤシ', '軽井沢', 'カルイザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鎌ケ谷市粟野', '12', '12224', '2730132', '千葉県', 'チバケン', '鎌ケ谷市', 'カマガヤシ', '粟野', 'アワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鎌ケ谷市南佐津間', '12', '12224', '2730133', '千葉県', 'チバケン', '鎌ケ谷市', 'カマガヤシ', '南佐津間', 'ミナミサツマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鎌ケ谷市西佐津間', '12', '12224', '2730134', '千葉県', 'チバケン', '鎌ケ谷市', 'カマガヤシ', '西佐津間', 'ニシサツマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鎌ケ谷市中佐津間', '12', '12224', '2730135', '千葉県', 'チバケン', '鎌ケ谷市', 'カマガヤシ', '中佐津間', 'ナカサツマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鎌ケ谷市佐津間', '12', '12224', '2730136', '千葉県', 'チバケン', '鎌ケ谷市', 'カマガヤシ', '佐津間', 'サツマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鎌ケ谷市道野辺本町', '12', '12224', '2730137', '千葉県', 'チバケン', '鎌ケ谷市', 'カマガヤシ', '道野辺本町', 'ミチノベホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県船橋市馬込町', '12', '12204', '2730851', '千葉県', 'チバケン', '船橋市', 'フナバシシ', '馬込町', 'マゴメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県船橋市金杉台', '12', '12204', '2730852', '千葉県', 'チバケン', '船橋市', 'フナバシシ', '金杉台', 'カナスギダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県船橋市金杉', '12', '12204', '2730853', '千葉県', 'チバケン', '船橋市', 'フナバシシ', '金杉', 'カナスギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県船橋市金杉町', '12', '12204', '2730854', '千葉県', 'チバケン', '船橋市', 'フナバシシ', '金杉町', 'カナスギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県船橋市米ケ崎町', '12', '12204', '2730861', '千葉県', 'チバケン', '船橋市', 'フナバシシ', '米ケ崎町', 'コメガサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県船橋市駿河台', '12', '12204', '2730862', '千葉県', 'チバケン', '船橋市', 'フナバシシ', '駿河台', 'スルガダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県船橋市東町', '12', '12204', '2730863', '千葉県', 'チバケン', '船橋市', 'フナバシシ', '東町', 'アズマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県船橋市北本町', '12', '12204', '2730864', '千葉県', 'チバケン', '船橋市', 'フナバシシ', '北本町', 'キタホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県船橋市夏見', '12', '12204', '2730865', '千葉県', 'チバケン', '船橋市', 'フナバシシ', '夏見', 'ナツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県船橋市夏見台', '12', '12204', '2730866', '千葉県', 'チバケン', '船橋市', 'フナバシシ', '夏見台', 'ナツミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県船橋市夏見町', '12', '12204', '2730867', '千葉県', 'チバケン', '船橋市', 'フナバシシ', '夏見町', 'ナツミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県船橋市車方町', '12', '12204', '2740051', '千葉県', 'チバケン', '船橋市', 'フナバシシ', '車方町', 'クルマガタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県船橋市鈴身町', '12', '12204', '2740052', '千葉県', 'チバケン', '船橋市', 'フナバシシ', '鈴身町', 'スズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県船橋市豊富町', '12', '12204', '2740053', '千葉県', 'チバケン', '船橋市', 'フナバシシ', '豊富町', 'トヨトミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県船橋市金堀町', '12', '12204', '2740054', '千葉県', 'チバケン', '船橋市', 'フナバシシ', '金堀町', 'カネホリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県船橋市楠が山町', '12', '12204', '2740055', '千葉県', 'チバケン', '船橋市', 'フナバシシ', '楠が山町', 'クスガヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県船橋市神保町', '12', '12204', '2740056', '千葉県', 'チバケン', '船橋市', 'フナバシシ', '神保町', 'ジンボウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県船橋市古和釜町', '12', '12204', '2740061', '千葉県', 'チバケン', '船橋市', 'フナバシシ', '古和釜町', 'コワガマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県船橋市坪井町', '12', '12204', '2740062', '千葉県', 'チバケン', '船橋市', 'フナバシシ', '坪井町', 'ツボイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県船橋市習志野台', '12', '12204', '2740063', '千葉県', 'チバケン', '船橋市', 'フナバシシ', '習志野台', 'ナラシノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県船橋市松が丘', '12', '12204', '2740064', '千葉県', 'チバケン', '船橋市', 'フナバシシ', '松が丘', 'マツガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県船橋市高根台', '12', '12204', '2740065', '千葉県', 'チバケン', '船橋市', 'フナバシシ', '高根台', 'タカネダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県船橋市大穴町', '12', '12204', '2740066', '千葉県', 'チバケン', '船橋市', 'フナバシシ', '大穴町', 'オオアナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県船橋市大穴南', '12', '12204', '2740067', '千葉県', 'チバケン', '船橋市', 'フナバシシ', '大穴南', 'オオアナミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県船橋市大穴北', '12', '12204', '2740068', '千葉県', 'チバケン', '船橋市', 'フナバシシ', '大穴北', 'オオアナキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県船橋市習志野', '12', '12204', '2740071', '千葉県', 'チバケン', '船橋市', 'フナバシシ', '習志野', 'ナラシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県船橋市三山', '12', '12204', '2740072', '千葉県', 'チバケン', '船橋市', 'フナバシシ', '三山', 'ミヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県船橋市田喜野井', '12', '12204', '2740073', '千葉県', 'チバケン', '船橋市', 'フナバシシ', '田喜野井', 'タキノイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県船橋市滝台', '12', '12204', '2740074', '千葉県', 'チバケン', '船橋市', 'フナバシシ', '滝台', 'タキダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県船橋市滝台町', '12', '12204', '2740075', '千葉県', 'チバケン', '船橋市', 'フナバシシ', '滝台町', 'タキダイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県船橋市薬園台町', '12', '12204', '2740076', '千葉県', 'チバケン', '船橋市', 'フナバシシ', '薬園台町', 'ヤクエンダイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県船橋市薬円台', '12', '12204', '2740077', '千葉県', 'チバケン', '船橋市', 'フナバシシ', '薬円台', 'ヤクエンダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県船橋市小野田町', '12', '12204', '2740081', '千葉県', 'チバケン', '船橋市', 'フナバシシ', '小野田町', 'コノダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県船橋市大神保町', '12', '12204', '2740082', '千葉県', 'チバケン', '船橋市', 'フナバシシ', '大神保町', 'オオジンボウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県船橋市高野台', '12', '12204', '2740801', '千葉県', 'チバケン', '船橋市', 'フナバシシ', '高野台', 'コウヤダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県船橋市八木が谷', '12', '12204', '2740802', '千葉県', 'チバケン', '船橋市', 'フナバシシ', '八木が谷', 'ヤキガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県船橋市八木が谷町', '12', '12204', '2740803', '千葉県', 'チバケン', '船橋市', 'フナバシシ', '八木が谷町', 'ヤキガヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県船橋市みやぎ台', '12', '12204', '2740804', '千葉県', 'チバケン', '船橋市', 'フナバシシ', 'みやぎ台', 'ミヤギダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県船橋市二和東', '12', '12204', '2740805', '千葉県', 'チバケン', '船橋市', 'フナバシシ', '二和東', 'フタワヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県船橋市二和西', '12', '12204', '2740806', '千葉県', 'チバケン', '船橋市', 'フナバシシ', '二和西', 'フタワニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県船橋市咲が丘', '12', '12204', '2740807', '千葉県', 'チバケン', '船橋市', 'フナバシシ', '咲が丘', 'サキガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県船橋市三咲町', '12', '12204', '2740811', '千葉県', 'チバケン', '船橋市', 'フナバシシ', '三咲町', 'ミサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県船橋市三咲', '12', '12204', '2740812', '千葉県', 'チバケン', '船橋市', 'フナバシシ', '三咲', 'ミサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県船橋市南三咲', '12', '12204', '2740813', '千葉県', 'チバケン', '船橋市', 'フナバシシ', '南三咲', 'ミナミミサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県船橋市新高根', '12', '12204', '2740814', '千葉県', 'チバケン', '船橋市', 'フナバシシ', '新高根', 'シンタカネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県船橋市西習志野', '12', '12204', '2740815', '千葉県', 'チバケン', '船橋市', 'フナバシシ', '西習志野', 'ニシナラシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県船橋市芝山', '12', '12204', '2740816', '千葉県', 'チバケン', '船橋市', 'フナバシシ', '芝山', 'シバヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県船橋市高根町', '12', '12204', '2740817', '千葉県', 'チバケン', '船橋市', 'フナバシシ', '高根町', 'タカネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県船橋市緑台', '12', '12204', '2740818', '千葉県', 'チバケン', '船橋市', 'フナバシシ', '緑台', 'ミドリダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県船橋市七林町', '12', '12204', '2740821', '千葉県', 'チバケン', '船橋市', 'フナバシシ', '七林町', 'ナナバヤシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県船橋市飯山満町', '12', '12204', '2740822', '千葉県', 'チバケン', '船橋市', 'フナバシシ', '飯山満町', 'ハサマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県船橋市二宮', '12', '12204', '2740823', '千葉県', 'チバケン', '船橋市', 'フナバシシ', '二宮', 'ニノミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県船橋市前原東', '12', '12204', '2740824', '千葉県', 'チバケン', '船橋市', 'フナバシシ', '前原東', 'マエバラヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県船橋市前原西', '12', '12204', '2740825', '千葉県', 'チバケン', '船橋市', 'フナバシシ', '前原西', 'マエバラニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県船橋市中野木', '12', '12204', '2740826', '千葉県', 'チバケン', '船橋市', 'フナバシシ', '中野木', 'ナカノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県習志野市', '12', '12216', '2750000', '千葉県', 'チバケン', '習志野市', 'ナラシノシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('15909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県習志野市東習志野', '12', '12216', '2750001', '千葉県', 'チバケン', '習志野市', 'ナラシノシ', '東習志野', 'ヒガシナラシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県習志野市実籾', '12', '12216', '2750002', '千葉県', 'チバケン', '習志野市', 'ナラシノシ', '実籾', 'ミモミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県習志野市実籾本郷', '12', '12216', '2750003', '千葉県', 'チバケン', '習志野市', 'ナラシノシ', '実籾本郷', 'ミモミホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県習志野市屋敷', '12', '12216', '2750004', '千葉県', 'チバケン', '習志野市', 'ナラシノシ', '屋敷', 'ヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県習志野市新栄', '12', '12216', '2750005', '千葉県', 'チバケン', '習志野市', 'ナラシノシ', '新栄', 'シンエイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県習志野市泉町', '12', '12216', '2750006', '千葉県', 'チバケン', '習志野市', 'ナラシノシ', '泉町', 'イズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県習志野市大久保', '12', '12216', '2750011', '千葉県', 'チバケン', '習志野市', 'ナラシノシ', '大久保', 'オオクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県習志野市本大久保', '12', '12216', '2750012', '千葉県', 'チバケン', '習志野市', 'ナラシノシ', '本大久保', 'モトオオクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県習志野市花咲', '12', '12216', '2750013', '千葉県', 'チバケン', '習志野市', 'ナラシノシ', '花咲', 'ハナサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県習志野市鷺沼', '12', '12216', '2750014', '千葉県', 'チバケン', '習志野市', 'ナラシノシ', '鷺沼', 'サギヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県習志野市鷺沼台', '12', '12216', '2750015', '千葉県', 'チバケン', '習志野市', 'ナラシノシ', '鷺沼台', 'サギヌマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県習志野市津田沼', '12', '12216', '2750016', '千葉県', 'チバケン', '習志野市', 'ナラシノシ', '津田沼', 'ツダヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県習志野市藤崎', '12', '12216', '2750017', '千葉県', 'チバケン', '習志野市', 'ナラシノシ', '藤崎', 'フジサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県習志野市袖ケ浦', '12', '12216', '2750021', '千葉県', 'チバケン', '習志野市', 'ナラシノシ', '袖ケ浦', 'ソデガウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県習志野市香澄', '12', '12216', '2750022', '千葉県', 'チバケン', '習志野市', 'ナラシノシ', '香澄', 'カスミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県習志野市芝園', '12', '12216', '2750023', '千葉県', 'チバケン', '習志野市', 'ナラシノシ', '芝園', 'シバゾノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県習志野市茜浜', '12', '12216', '2750024', '千葉県', 'チバケン', '習志野市', 'ナラシノシ', '茜浜', 'アカネハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県習志野市秋津', '12', '12216', '2750025', '千葉県', 'チバケン', '習志野市', 'ナラシノシ', '秋津', 'アキツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県習志野市谷津', '12', '12216', '2750026', '千葉県', 'チバケン', '習志野市', 'ナラシノシ', '谷津', 'ヤツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県習志野市谷津町', '12', '12216', '2750027', '千葉県', 'チバケン', '習志野市', 'ナラシノシ', '谷津町', 'ヤツマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県八千代市', '12', '12221', '2760000', '千葉県', 'チバケン', '八千代市', 'ヤチヨシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('15944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県八千代市小池', '12', '12221', '2760001', '千葉県', 'チバケン', '八千代市', 'ヤチヨシ', '小池', 'コイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県八千代市真木野', '12', '12221', '2760002', '千葉県', 'チバケン', '八千代市', 'ヤチヨシ', '真木野', 'マキノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県八千代市大学町', '12', '12221', '2760003', '千葉県', 'チバケン', '八千代市', 'ヤチヨシ', '大学町', 'ダイガクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県八千代市島田台', '12', '12221', '2760004', '千葉県', 'チバケン', '八千代市', 'ヤチヨシ', '島田台', 'シマダダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県八千代市島田', '12', '12221', '2760005', '千葉県', 'チバケン', '八千代市', 'ヤチヨシ', '島田', 'シマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県八千代市桑納', '12', '12221', '2760006', '千葉県', 'チバケン', '八千代市', 'ヤチヨシ', '桑納', 'カンノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県八千代市桑橋', '12', '12221', '2760007', '千葉県', 'チバケン', '八千代市', 'ヤチヨシ', '桑橋', 'ソウノハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県八千代市神久保', '12', '12221', '2760008', '千葉県', 'チバケン', '八千代市', 'ヤチヨシ', '神久保', 'イモノクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県八千代市佐山', '12', '12221', '2760011', '千葉県', 'チバケン', '八千代市', 'ヤチヨシ', '佐山', 'サヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県八千代市堀の内', '12', '12221', '2760012', '千葉県', 'チバケン', '八千代市', 'ヤチヨシ', '堀の内', 'ホリノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県八千代市保品', '12', '12221', '2760013', '千葉県', 'チバケン', '八千代市', 'ヤチヨシ', '保品', 'ホシナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県八千代市米本団地', '12', '12221', '2760014', '千葉県', 'チバケン', '八千代市', 'ヤチヨシ', '米本団地', 'ヨナモトダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県八千代市米本', '12', '12221', '2760015', '千葉県', 'チバケン', '八千代市', 'ヤチヨシ', '米本', 'ヨナモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県八千代市神野', '12', '12221', '2760016', '千葉県', 'チバケン', '八千代市', 'ヤチヨシ', '神野', 'カノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県八千代市平戸', '12', '12221', '2760017', '千葉県', 'チバケン', '八千代市', 'ヤチヨシ', '平戸', 'ヒラト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県八千代市下高野', '12', '12221', '2760021', '千葉県', 'チバケン', '八千代市', 'ヤチヨシ', '下高野', 'シモコウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県八千代市上高野', '12', '12221', '2760022', '千葉県', 'チバケン', '八千代市', 'ヤチヨシ', '上高野', 'カミコウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県八千代市勝田台', '12', '12221', '2760023', '千葉県', 'チバケン', '八千代市', 'ヤチヨシ', '勝田台', 'カツタダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県八千代市勝田', '12', '12221', '2760024', '千葉県', 'チバケン', '八千代市', 'ヤチヨシ', '勝田', 'カツタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県八千代市勝田台南', '12', '12221', '2760025', '千葉県', 'チバケン', '八千代市', 'ヤチヨシ', '勝田台南', 'カツタダイミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県八千代市下市場', '12', '12221', '2760026', '千葉県', 'チバケン', '八千代市', 'ヤチヨシ', '下市場', 'シモイチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県八千代市村上団地', '12', '12221', '2760027', '千葉県', 'チバケン', '八千代市', 'ヤチヨシ', '村上団地', 'ムラカミダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県八千代市村上', '12', '12221', '2760028', '千葉県', 'チバケン', '八千代市', 'ヤチヨシ', '村上', 'ムラカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県八千代市村上南', '12', '12221', '2760029', '千葉県', 'チバケン', '八千代市', 'ヤチヨシ', '村上南', 'ムラカミミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県八千代市八千代台北', '12', '12221', '2760031', '千葉県', 'チバケン', '八千代市', 'ヤチヨシ', '八千代台北', 'ヤチヨダイキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県八千代市八千代台東', '12', '12221', '2760032', '千葉県', 'チバケン', '八千代市', 'ヤチヨシ', '八千代台東', 'ヤチヨダイヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県八千代市八千代台南', '12', '12221', '2760033', '千葉県', 'チバケン', '八千代市', 'ヤチヨシ', '八千代台南', 'ヤチヨダイミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県八千代市八千代台西', '12', '12221', '2760034', '千葉県', 'チバケン', '八千代市', 'ヤチヨシ', '八千代台西', 'ヤチヨダイニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県八千代市高津団地', '12', '12221', '2760035', '千葉県', 'チバケン', '八千代市', 'ヤチヨシ', '高津団地', 'タカツダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県八千代市高津', '12', '12221', '2760036', '千葉県', 'チバケン', '八千代市', 'ヤチヨシ', '高津', 'タカヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県八千代市高津東', '12', '12221', '2760037', '千葉県', 'チバケン', '八千代市', 'ヤチヨシ', '高津東', 'タカツヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県八千代市麦丸', '12', '12221', '2760041', '千葉県', 'チバケン', '八千代市', 'ヤチヨシ', '麦丸', 'ムギマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県八千代市ゆりのき台', '12', '12221', '2760042', '千葉県', 'チバケン', '八千代市', 'ヤチヨシ', 'ゆりのき台', 'ユリノキダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県八千代市萱田', '12', '12221', '2760043', '千葉県', 'チバケン', '八千代市', 'ヤチヨシ', '萱田', 'カヤダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県八千代市萱田町', '12', '12221', '2760044', '千葉県', 'チバケン', '八千代市', 'ヤチヨシ', '萱田町', 'カヤダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県八千代市大和田', '12', '12221', '2760045', '千葉県', 'チバケン', '八千代市', 'ヤチヨシ', '大和田', 'オオワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県八千代市大和田新田', '12', '12221', '2760046', '千葉県', 'チバケン', '八千代市', 'ヤチヨシ', '大和田新田', 'オオワダシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県八千代市吉橋', '12', '12221', '2760047', '千葉県', 'チバケン', '八千代市', 'ヤチヨシ', '吉橋', 'ヨシハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県八千代市尾崎', '12', '12221', '2760048', '千葉県', 'チバケン', '八千代市', 'ヤチヨシ', '尾崎', 'オサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県八千代市緑が丘', '12', '12221', '2760049', '千葉県', 'チバケン', '八千代市', 'ヤチヨシ', '緑が丘', 'ミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市', '12', '12217', '2770000', '千葉県', 'チバケン', '柏市', 'カシワシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('15989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市呼塚新田', '12', '12217', '2770001', '千葉県', 'チバケン', '柏市', 'カシワシ', '呼塚新田', 'ヨバツカシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市呼塚', '12', '12217', '2770002', '千葉県', 'チバケン', '柏市', 'カシワシ', '呼塚', 'ヨバツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市柏堀之内新田', '12', '12217', '2770003', '千葉県', 'チバケン', '柏市', 'カシワシ', '柏堀之内新田', 'カシワホリノウチシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市柏下', '12', '12217', '2770004', '千葉県', 'チバケン', '柏市', 'カシワシ', '柏下', 'カシワシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市柏', '12', '12217', '2770005', '千葉県', 'チバケン', '柏市', 'カシワシ', '柏', 'カシワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市柏中村下', '12', '12217', '2770006', '千葉県', 'チバケン', '柏市', 'カシワシ', '柏中村下', 'カシワナカムラシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市戸張新田', '12', '12217', '2770007', '千葉県', 'チバケン', '柏市', 'カシワシ', '戸張新田', 'トバリシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市戸張', '12', '12217', '2770008', '千葉県', 'チバケン', '柏市', 'カシワシ', '戸張', 'トバリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市東上町', '12', '12217', '2770011', '千葉県', 'チバケン', '柏市', 'カシワシ', '東上町', 'アズマカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市桜台', '12', '12217', '2770012', '千葉県', 'チバケン', '柏市', 'カシワシ', '桜台', 'サクラダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('15999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市東台本町', '12', '12217', '2770013', '千葉県', 'チバケン', '柏市', 'カシワシ', '東台本町', 'アズマダイホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市東', '12', '12217', '2770014', '千葉県', 'チバケン', '柏市', 'カシワシ', '東', 'アズマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市弥生町', '12', '12217', '2770015', '千葉県', 'チバケン', '柏市', 'カシワシ', '弥生町', 'ヤヨイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市八幡町', '12', '12217', '2770016', '千葉県', 'チバケン', '柏市', 'カシワシ', '八幡町', 'ハチマンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市東柏', '12', '12217', '2770017', '千葉県', 'チバケン', '柏市', 'カシワシ', '東柏', 'ヒガシカシワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市中央町', '12', '12217', '2770021', '千葉県', 'チバケン', '柏市', 'カシワシ', '中央町', 'チュウオウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市泉町', '12', '12217', '2770022', '千葉県', 'チバケン', '柏市', 'カシワシ', '泉町', 'イズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市中央', '12', '12217', '2770023', '千葉県', 'チバケン', '柏市', 'カシワシ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市若葉町', '12', '12217', '2770024', '千葉県', 'チバケン', '柏市', 'カシワシ', '若葉町', 'ワカバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市千代田', '12', '12217', '2770025', '千葉県', 'チバケン', '柏市', 'カシワシ', '千代田', 'チヨダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市大塚町', '12', '12217', '2770026', '千葉県', 'チバケン', '柏市', 'カシワシ', '大塚町', 'オオツカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市あかね町', '12', '12217', '2770027', '千葉県', 'チバケン', '柏市', 'カシワシ', 'あかね町', 'アカネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市関場町', '12', '12217', '2770028', '千葉県', 'チバケン', '柏市', 'カシワシ', '関場町', 'セキバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市亀甲台町', '12', '12217', '2770031', '千葉県', 'チバケン', '柏市', 'カシワシ', '亀甲台町', 'キッコウダイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市名戸ケ谷', '12', '12217', '2770032', '千葉県', 'チバケン', '柏市', 'カシワシ', '名戸ケ谷', 'ナドガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市増尾', '12', '12217', '2770033', '千葉県', 'チバケン', '柏市', 'カシワシ', '増尾', 'マスオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市藤心', '12', '12217', '2770034', '千葉県', 'チバケン', '柏市', 'カシワシ', '藤心', 'フジゴコロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市逆井藤ノ台', '12', '12217', '2770041', '千葉県', 'チバケン', '柏市', 'カシワシ', '逆井藤ノ台', 'サカサイフジノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市逆井', '12', '12217', '2770042', '千葉県', 'チバケン', '柏市', 'カシワシ', '逆井', 'サカサイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市南逆井', '12', '12217', '2770043', '千葉県', 'チバケン', '柏市', 'カシワシ', '南逆井', 'ミナミサカサイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市新逆井', '12', '12217', '2770044', '千葉県', 'チバケン', '柏市', 'カシワシ', '新逆井', 'シンサカサイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市東逆井', '12', '12217', '2770045', '千葉県', 'チバケン', '柏市', 'カシワシ', '東逆井', 'ヒガシサカサイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市加賀', '12', '12217', '2770051', '千葉県', 'チバケン', '柏市', 'カシワシ', '加賀', 'カガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市増尾台', '12', '12217', '2770052', '千葉県', 'チバケン', '柏市', 'カシワシ', '増尾台', 'マスオダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市酒井根', '12', '12217', '2770053', '千葉県', 'チバケン', '柏市', 'カシワシ', '酒井根', 'サカイネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市南増尾', '12', '12217', '2770054', '千葉県', 'チバケン', '柏市', 'カシワシ', '南増尾', 'ミナミマスオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市青葉台', '12', '12217', '2770055', '千葉県', 'チバケン', '柏市', 'カシワシ', '青葉台', 'アオバダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市東中新宿', '12', '12217', '2770061', '千葉県', 'チバケン', '柏市', 'カシワシ', '東中新宿', 'ヒガシナカシンジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市光ケ丘団地', '12', '12217', '2770062', '千葉県', 'チバケン', '柏市', 'カシワシ', '光ケ丘団地', 'ヒカリガオカダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市西山', '12', '12217', '2770063', '千葉県', 'チバケン', '柏市', 'カシワシ', '西山', 'ニシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市東山', '12', '12217', '2770064', '千葉県', 'チバケン', '柏市', 'カシワシ', '東山', 'ヒガシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市光ケ丘', '12', '12217', '2770065', '千葉県', 'チバケン', '柏市', 'カシワシ', '光ケ丘', 'ヒカリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市中新宿', '12', '12217', '2770066', '千葉県', 'チバケン', '柏市', 'カシワシ', '中新宿', 'ナカシンジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市豊住', '12', '12217', '2770071', '千葉県', 'チバケン', '柏市', 'カシワシ', '豊住', 'トヨスミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市つくしが丘', '12', '12217', '2770072', '千葉県', 'チバケン', '柏市', 'カシワシ', 'つくしが丘', 'ツクシガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市今谷南町', '12', '12217', '2770073', '千葉県', 'チバケン', '柏市', 'カシワシ', '今谷南町', 'イマヤミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市今谷上町', '12', '12217', '2770074', '千葉県', 'チバケン', '柏市', 'カシワシ', '今谷上町', 'イマヤカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市南柏中央', '12', '12217', '2770075', '千葉県', 'チバケン', '柏市', 'カシワシ', '南柏中央', 'ミナミカシワチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市富里', '12', '12217', '2770081', '千葉県', 'チバケン', '柏市', 'カシワシ', '富里', 'トミサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市緑ケ丘', '12', '12217', '2770082', '千葉県', 'チバケン', '柏市', 'カシワシ', '緑ケ丘', 'ミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市日立台', '12', '12217', '2770083', '千葉県', 'チバケン', '柏市', 'カシワシ', '日立台', 'ヒタチダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市新柏', '12', '12217', '2770084', '千葉県', 'チバケン', '柏市', 'カシワシ', '新柏', 'シンカシワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市中原', '12', '12217', '2770085', '千葉県', 'チバケン', '柏市', 'カシワシ', '中原', 'ナカハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市永楽台', '12', '12217', '2770086', '千葉県', 'チバケン', '柏市', 'カシワシ', '永楽台', 'エイラクダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市常盤台', '12', '12217', '2770087', '千葉県', 'チバケン', '柏市', 'カシワシ', '常盤台', 'トキワダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市ひばりが丘', '12', '12217', '2770088', '千葉県', 'チバケン', '柏市', 'カシワシ', 'ひばりが丘', 'ヒバリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市船戸山高野', '12', '12217', '2770801', '千葉県', 'チバケン', '柏市', 'カシワシ', '船戸山高野', 'フナトヤマゴウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市船戸', '12', '12217', '2770802', '千葉県', 'チバケン', '柏市', 'カシワシ', '船戸', 'フナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市小青田', '12', '12217', '2770803', '千葉県', 'チバケン', '柏市', 'カシワシ', '小青田', 'コアオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市新十余二', '12', '12217', '2770804', '千葉県', 'チバケン', '柏市', 'カシワシ', '新十余二', 'シントヨフタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市大青田', '12', '12217', '2770805', '千葉県', 'チバケン', '柏市', 'カシワシ', '大青田', 'オオアオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市上利根', '12', '12217', '2770811', '千葉県', 'チバケン', '柏市', 'カシワシ', '上利根', 'カミトネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市花野井', '12', '12217', '2770812', '千葉県', 'チバケン', '柏市', 'カシワシ', '花野井', 'ハナノイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市大室', '12', '12217', '2770813', '千葉県', 'チバケン', '柏市', 'カシワシ', '大室', 'オオムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市正連寺', '12', '12217', '2770814', '千葉県', 'チバケン', '柏市', 'カシワシ', '正連寺', 'ショウレンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市弁天下', '12', '12217', '2770821', '千葉県', 'チバケン', '柏市', 'カシワシ', '弁天下', 'ベンテンシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市布施下', '12', '12217', '2770822', '千葉県', 'チバケン', '柏市', 'カシワシ', '布施下', 'フセシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市布施新町', '12', '12217', '2770823', '千葉県', 'チバケン', '柏市', 'カシワシ', '布施新町', 'フセシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市布施新田', '12', '12217', '2770824', '千葉県', 'チバケン', '柏市', 'カシワシ', '布施新田', 'フセシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市布施', '12', '12217', '2770825', '千葉県', 'チバケン', '柏市', 'カシワシ', '布施', 'フセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市宿連寺', '12', '12217', '2770826', '千葉県', 'チバケン', '柏市', 'カシワシ', '宿連寺', 'シュクレンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市松葉町', '12', '12217', '2770827', '千葉県', 'チバケン', '柏市', 'カシワシ', '松葉町', 'マツバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市根戸', '12', '12217', '2770831', '千葉県', 'チバケン', '柏市', 'カシワシ', '根戸', 'ネド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市北柏', '12', '12217', '2770832', '千葉県', 'チバケン', '柏市', 'カシワシ', '北柏', 'キタカシワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市根戸新田', '12', '12217', '2770833', '千葉県', 'チバケン', '柏市', 'カシワシ', '根戸新田', 'ネドシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市松ケ崎新田', '12', '12217', '2770834', '千葉県', 'チバケン', '柏市', 'カシワシ', '松ケ崎新田', 'マツガサキシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市松ケ崎', '12', '12217', '2770835', '千葉県', 'チバケン', '柏市', 'カシワシ', '松ケ崎', 'マツガサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市北柏台', '12', '12217', '2770836', '千葉県', 'チバケン', '柏市', 'カシワシ', '北柏台', 'キタカシワダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市大山台', '12', '12217', '2770837', '千葉県', 'チバケン', '柏市', 'カシワシ', '大山台', 'オオヤマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市あけぼの', '12', '12217', '2770841', '千葉県', 'チバケン', '柏市', 'カシワシ', 'あけぼの', 'アケボノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市末広町', '12', '12217', '2770842', '千葉県', 'チバケン', '柏市', 'カシワシ', '末広町', 'スエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市明原', '12', '12217', '2770843', '千葉県', 'チバケン', '柏市', 'カシワシ', '明原', 'アケハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市西町', '12', '12217', '2770844', '千葉県', 'チバケン', '柏市', 'カシワシ', '西町', 'ニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市豊四季台', '12', '12217', '2770845', '千葉県', 'チバケン', '柏市', 'カシワシ', '豊四季台', 'トヨシキダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市かやの町', '12', '12217', '2770846', '千葉県', 'チバケン', '柏市', 'カシワシ', 'かやの町', 'カヤノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市向原町', '12', '12217', '2770851', '千葉県', 'チバケン', '柏市', 'カシワシ', '向原町', 'ムカイハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市旭町', '12', '12217', '2770852', '千葉県', 'チバケン', '柏市', 'カシワシ', '旭町', 'アサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市吉野沢', '12', '12217', '2770853', '千葉県', 'チバケン', '柏市', 'カシワシ', '吉野沢', 'ヨシノザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市豊町', '12', '12217', '2770854', '千葉県', 'チバケン', '柏市', 'カシワシ', '豊町', 'ユタカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市南柏', '12', '12217', '2770855', '千葉県', 'チバケン', '柏市', 'カシワシ', '南柏', 'ミナミカシワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市新富町', '12', '12217', '2770856', '千葉県', 'チバケン', '柏市', 'カシワシ', '新富町', 'シントミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市豊平町', '12', '12217', '2770857', '千葉県', 'チバケン', '柏市', 'カシワシ', '豊平町', 'トヨヒラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市豊上町', '12', '12217', '2770858', '千葉県', 'チバケン', '柏市', 'カシワシ', '豊上町', 'トヨガミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市高田', '12', '12217', '2770861', '千葉県', 'チバケン', '柏市', 'カシワシ', '高田', 'タカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市篠籠田', '12', '12217', '2770862', '千葉県', 'チバケン', '柏市', 'カシワシ', '篠籠田', 'シコダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市豊四季', '12', '12217', '2770863', '千葉県', 'チバケン', '柏市', 'カシワシ', '豊四季', 'トヨシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市若柴', '12', '12217', '2770871', '千葉県', 'チバケン', '柏市', 'カシワシ', '若柴', 'ワカシバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市十余二', '12', '12217', '2770872', '千葉県', 'チバケン', '柏市', 'カシワシ', '十余二', 'トヨフタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市中十余二', '12', '12217', '2770873', '千葉県', 'チバケン', '柏市', 'カシワシ', '中十余二', 'ナカトヨフタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市青田新田飛地', '12', '12217', '2770881', '千葉県', 'チバケン', '柏市', 'カシワシ', '青田新田飛地', 'アオタシンデントビチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市柏の葉', '12', '12217', '2770882', '千葉県', 'チバケン', '柏市', 'カシワシ', '柏の葉', 'カシワノハ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市伊勢原', '12', '12217', '2770883', '千葉県', 'チバケン', '柏市', 'カシワシ', '伊勢原', 'イセハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市みどり台', '12', '12217', '2770884', '千葉県', 'チバケン', '柏市', 'カシワシ', 'みどり台', 'ミドリダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市西原', '12', '12217', '2770885', '千葉県', 'チバケン', '柏市', 'カシワシ', '西原', 'ニシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市西柏台', '12', '12217', '2770886', '千葉県', 'チバケン', '柏市', 'カシワシ', '西柏台', 'ニシカシワダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市大井新田', '12', '12217', '2770901', '千葉県', 'チバケン', '柏市', 'カシワシ', '大井新田', 'オオイシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市大井', '12', '12217', '2770902', '千葉県', 'チバケン', '柏市', 'カシワシ', '大井', 'オオイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市緑台', '12', '12217', '2770903', '千葉県', 'チバケン', '柏市', 'カシワシ', '緑台', 'ミドリダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市箕輪新田', '12', '12217', '2770911', '千葉県', 'チバケン', '柏市', 'カシワシ', '箕輪新田', 'ミノワシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市箕輪', '12', '12217', '2770912', '千葉県', 'チバケン', '柏市', 'カシワシ', '箕輪', 'ミノワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市五條谷', '12', '12217', '2770913', '千葉県', 'チバケン', '柏市', 'カシワシ', '五條谷', 'ゴジョウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市大津ケ丘', '12', '12217', '2770921', '千葉県', 'チバケン', '柏市', 'カシワシ', '大津ケ丘', 'オオツガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市大島田', '12', '12217', '2770922', '千葉県', 'チバケン', '柏市', 'カシワシ', '大島田', 'オオシマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市塚崎', '12', '12217', '2770923', '千葉県', 'チバケン', '柏市', 'カシワシ', '塚崎', 'ツカザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市風早', '12', '12217', '2770924', '千葉県', 'チバケン', '柏市', 'カシワシ', '風早', 'カザハヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市藤ケ谷', '12', '12217', '2770931', '千葉県', 'チバケン', '柏市', 'カシワシ', '藤ケ谷', 'フジガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市藤ケ谷新田', '12', '12217', '2770932', '千葉県', 'チバケン', '柏市', 'カシワシ', '藤ケ谷新田', 'フジガヤシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市高柳', '12', '12217', '2770941', '千葉県', 'チバケン', '柏市', 'カシワシ', '高柳', 'タカヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市高南台', '12', '12217', '2770942', '千葉県', 'チバケン', '柏市', 'カシワシ', '高南台', 'コウナンダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市高柳新田', '12', '12217', '2770943', '千葉県', 'チバケン', '柏市', 'カシワシ', '高柳新田', 'タカヤナギシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市南高柳', '12', '12217', '2770944', '千葉県', 'チバケン', '柏市', 'カシワシ', '南高柳', 'ミナミタカヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県柏市しいの木台', '12', '12217', '2770945', '千葉県', 'チバケン', '柏市', 'カシワシ', 'しいの木台', 'シイノキダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県野田市', '12', '12208', '2780000', '千葉県', 'チバケン', '野田市', 'ノダシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('16145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県野田市目吹', '12', '12208', '2780001', '千葉県', 'チバケン', '野田市', 'ノダシ', '目吹', 'メフキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県野田市木野崎', '12', '12208', '2780002', '千葉県', 'チバケン', '野田市', 'ノダシ', '木野崎', 'キノサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県野田市鶴奉', '12', '12208', '2780003', '千葉県', 'チバケン', '野田市', 'ノダシ', '鶴奉', 'ツルホウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県野田市横内', '12', '12208', '2780004', '千葉県', 'チバケン', '野田市', 'ノダシ', '横内', 'ヨコウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県野田市宮崎', '12', '12208', '2780005', '千葉県', 'チバケン', '野田市', 'ノダシ', '宮崎', 'ミヤザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県野田市柳沢', '12', '12208', '2780006', '千葉県', 'チバケン', '野田市', 'ノダシ', '柳沢', 'ヤナギサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県野田市金杉', '12', '12208', '2780007', '千葉県', 'チバケン', '野田市', 'ノダシ', '金杉', 'カナスギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県野田市三ツ堀', '12', '12208', '2780011', '千葉県', 'チバケン', '野田市', 'ノダシ', '三ツ堀', 'ミツボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県野田市瀬戸', '12', '12208', '2780012', '千葉県', 'チバケン', '野田市', 'ノダシ', '瀬戸', 'セト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県野田市上三ケ尾', '12', '12208', '2780013', '千葉県', 'チバケン', '野田市', 'ノダシ', '上三ケ尾', 'カミサンガオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県野田市下三ケ尾', '12', '12208', '2780014', '千葉県', 'チバケン', '野田市', 'ノダシ', '下三ケ尾', 'シモサンガオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県野田市西三ケ尾', '12', '12208', '2780015', '千葉県', 'チバケン', '野田市', 'ノダシ', '西三ケ尾', 'ニシサンガオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県野田市二ツ塚', '12', '12208', '2780016', '千葉県', 'チバケン', '野田市', 'ノダシ', '二ツ塚', 'フタツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県野田市大殿井', '12', '12208', '2780017', '千葉県', 'チバケン', '野田市', 'ノダシ', '大殿井', 'オオドノイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県野田市堤根', '12', '12208', '2780021', '千葉県', 'チバケン', '野田市', 'ノダシ', '堤根', 'ツツミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県野田市山崎', '12', '12208', '2780022', '千葉県', 'チバケン', '野田市', 'ノダシ', '山崎', 'ヤマザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県野田市山崎貝塚町', '12', '12208', '2780023', '千葉県', 'チバケン', '野田市', 'ノダシ', '山崎貝塚町', 'ヤマザキカイヅカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県野田市山崎梅の台', '12', '12208', '2780024', '千葉県', 'チバケン', '野田市', 'ノダシ', '山崎梅の台', 'ヤマザキウメノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県野田市今上', '12', '12208', '2780025', '千葉県', 'チバケン', '野田市', 'ノダシ', '今上', 'イマガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県野田市花井', '12', '12208', '2780026', '千葉県', 'チバケン', '野田市', 'ノダシ', '花井', 'ハナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県野田市みずき', '12', '12208', '2780027', '千葉県', 'チバケン', '野田市', 'ノダシ', 'みずき', 'ミズキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県野田市中根', '12', '12208', '2780031', '千葉県', 'チバケン', '野田市', 'ノダシ', '中根', 'ナカネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県野田市桜台', '12', '12208', '2780032', '千葉県', 'チバケン', '野田市', 'ノダシ', '桜台', 'サクラダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県野田市上花輪', '12', '12208', '2780033', '千葉県', 'チバケン', '野田市', 'ノダシ', '上花輪', 'カミハナワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県野田市上花輪新町', '12', '12208', '2780034', '千葉県', 'チバケン', '野田市', 'ノダシ', '上花輪新町', 'カミハナワシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県野田市中野台', '12', '12208', '2780035', '千葉県', 'チバケン', '野田市', 'ノダシ', '中野台', 'ナカノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県野田市中野台鹿島町', '12', '12208', '2780036', '千葉県', 'チバケン', '野田市', 'ノダシ', '中野台鹿島町', 'ナカノダイカシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県野田市野田', '12', '12208', '2780037', '千葉県', 'チバケン', '野田市', 'ノダシ', '野田', 'ノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県野田市蕃昌', '12', '12208', '2780041', '千葉県', 'チバケン', '野田市', 'ノダシ', '蕃昌', 'バンショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県野田市吉春', '12', '12208', '2780042', '千葉県', 'チバケン', '野田市', 'ノダシ', '吉春', 'ヨシハル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県野田市清水', '12', '12208', '2780043', '千葉県', 'チバケン', '野田市', 'ノダシ', '清水', 'シミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県野田市堤台', '12', '12208', '2780044', '千葉県', 'チバケン', '野田市', 'ノダシ', '堤台', 'ツツミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県野田市座生', '12', '12208', '2780045', '千葉県', 'チバケン', '野田市', 'ノダシ', '座生', 'ザオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県野田市谷津', '12', '12208', '2780046', '千葉県', 'チバケン', '野田市', 'ノダシ', '谷津', 'ヤツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県野田市清水公園東', '12', '12208', '2780047', '千葉県', 'チバケン', '野田市', 'ノダシ', '清水公園東', 'シミズコウエンヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県野田市桜の里', '12', '12208', '2780048', '千葉県', 'チバケン', '野田市', 'ノダシ', '桜の里', 'サクラノサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県野田市七光台', '12', '12208', '2780051', '千葉県', 'チバケン', '野田市', 'ノダシ', '七光台', 'ナナコウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県野田市春日町', '12', '12208', '2780052', '千葉県', 'チバケン', '野田市', 'ノダシ', '春日町', 'カスガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県野田市五木新町', '12', '12208', '2780053', '千葉県', 'チバケン', '野田市', 'ノダシ', '五木新町', 'ゴキシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県野田市五木', '12', '12208', '2780054', '千葉県', 'チバケン', '野田市', 'ノダシ', '五木', 'ゴキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県野田市岩名', '12', '12208', '2780055', '千葉県', 'チバケン', '野田市', 'ノダシ', '岩名', 'イワナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県野田市五木新田', '12', '12208', '2780056', '千葉県', 'チバケン', '野田市', 'ノダシ', '五木新田', 'ゴキシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県浦安市', '12', '12227', '2790000', '千葉県', 'チバケン', '浦安市', 'ウラヤスシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('16200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県浦安市当代島', '12', '12227', '2790001', '千葉県', 'チバケン', '浦安市', 'ウラヤスシ', '当代島', 'トウダイジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県浦安市北栄', '12', '12227', '2790002', '千葉県', 'チバケン', '浦安市', 'ウラヤスシ', '北栄', 'キタザカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県浦安市海楽', '12', '12227', '2790003', '千葉県', 'チバケン', '浦安市', 'ウラヤスシ', '海楽', 'カイラク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県浦安市猫実', '12', '12227', '2790004', '千葉県', 'チバケン', '浦安市', 'ウラヤスシ', '猫実', 'ネコザネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県浦安市美浜', '12', '12227', '2790011', '千葉県', 'チバケン', '浦安市', 'ウラヤスシ', '美浜', 'ミハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県浦安市入船', '12', '12227', '2790012', '千葉県', 'チバケン', '浦安市', 'ウラヤスシ', '入船', 'イリフネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県浦安市日の出', '12', '12227', '2790013', '千葉県', 'チバケン', '浦安市', 'ウラヤスシ', '日の出', 'ヒノデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県浦安市明海', '12', '12227', '2790014', '千葉県', 'チバケン', '浦安市', 'ウラヤスシ', '明海', 'アケミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県浦安市富岡', '12', '12227', '2790021', '千葉県', 'チバケン', '浦安市', 'ウラヤスシ', '富岡', 'トミオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県浦安市今川', '12', '12227', '2790022', '千葉県', 'チバケン', '浦安市', 'ウラヤスシ', '今川', 'イマガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県浦安市高洲', '12', '12227', '2790023', '千葉県', 'チバケン', '浦安市', 'ウラヤスシ', '高洲', 'タカス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県浦安市港', '12', '12227', '2790024', '千葉県', 'チバケン', '浦安市', 'ウラヤスシ', '港', 'ミナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県浦安市鉄鋼通り', '12', '12227', '2790025', '千葉県', 'チバケン', '浦安市', 'ウラヤスシ', '鉄鋼通り', 'テッコウドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県浦安市弁天', '12', '12227', '2790026', '千葉県', 'チバケン', '浦安市', 'ウラヤスシ', '弁天', 'ベンテン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県浦安市舞浜', '12', '12227', '2790031', '千葉県', 'チバケン', '浦安市', 'ウラヤスシ', '舞浜', 'マイハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県浦安市千鳥', '12', '12227', '2790032', '千葉県', 'チバケン', '浦安市', 'ウラヤスシ', '千鳥', 'チドリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県浦安市堀江', '12', '12227', '2790041', '千葉県', 'チバケン', '浦安市', 'ウラヤスシ', '堀江', 'ホリエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県浦安市東野', '12', '12227', '2790042', '千葉県', 'チバケン', '浦安市', 'ウラヤスシ', '東野', 'ヒガシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県浦安市富士見', '12', '12227', '2790043', '千葉県', 'チバケン', '浦安市', 'ウラヤスシ', '富士見', 'フジミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県久慈市', '03', '03207', '0280000', '岩手県', 'イワテケン', '久慈市', 'クジシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('16243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県久慈市夏井町', '03', '03207', '0280001', '岩手県', 'イワテケン', '久慈市', 'クジシ', '夏井町', 'ナツイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区太平1条', '01', '01102', '0028001', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '太平1条', 'タイヘイ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県久慈市湊町', '03', '03207', '0280011', '岩手県', 'イワテケン', '久慈市', 'クジシ', '湊町', 'ミナトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県久慈市新井田', '03', '03207', '0280012', '岩手県', 'イワテケン', '久慈市', 'クジシ', '新井田', 'ニイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県久慈市京の森', '03', '03207', '0280013', '岩手県', 'イワテケン', '久慈市', 'クジシ', '京の森', 'キョウノモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県久慈市旭町', '03', '03207', '0280014', '岩手県', 'イワテケン', '久慈市', 'クジシ', '旭町', 'アサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県久慈市源道', '03', '03207', '0280015', '岩手県', 'イワテケン', '久慈市', 'クジシ', '源道', 'ゲンドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区太平2条', '01', '01102', '0028002', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '太平2条', 'タイヘイ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県久慈市門前', '03', '03207', '0280021', '岩手県', 'イワテケン', '久慈市', 'クジシ', '門前', 'モンゼン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県久慈市田屋町', '03', '03207', '0280022', '岩手県', 'イワテケン', '久慈市', 'クジシ', '田屋町', 'タヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県久慈市新中の橋', '03', '03207', '0280023', '岩手県', 'イワテケン', '久慈市', 'クジシ', '新中の橋', 'シンナカノハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県久慈市栄町', '03', '03207', '0280024', '岩手県', 'イワテケン', '久慈市', 'クジシ', '栄町', 'サカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区太平3条', '01', '01102', '0028003', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '太平3条', 'タイヘイ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県久慈市天神堂', '03', '03207', '0280031', '岩手県', 'イワテケン', '久慈市', 'クジシ', '天神堂', 'テンジンドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県久慈市寺里', '03', '03207', '0280032', '岩手県', 'イワテケン', '久慈市', 'クジシ', '寺里', 'テラサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県久慈市畑田', '03', '03207', '0280033', '岩手県', 'イワテケン', '久慈市', 'クジシ', '畑田', 'ハタケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県久慈市枝成沢', '03', '03207', '0280034', '岩手県', 'イワテケン', '久慈市', 'クジシ', '枝成沢', 'エダナリサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県久慈市沢里', '03', '03207', '0280035', '岩手県', 'イワテケン', '久慈市', 'クジシ', '沢里', 'サワサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区太平4条', '01', '01102', '0028004', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '太平4条', 'タイヘイ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県久慈市長内町', '03', '03207', '0280041', '岩手県', 'イワテケン', '久慈市', 'クジシ', '長内町', 'オサナイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区太平5条', '01', '01102', '0028005', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '太平5条', 'タイヘイ05ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県久慈市川崎町', '03', '03207', '0280051', '岩手県', 'イワテケン', '久慈市', 'クジシ', '川崎町', 'カワサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県久慈市本町', '03', '03207', '0280052', '岩手県', 'イワテケン', '久慈市', 'クジシ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県久慈市田高', '03', '03207', '0280053', '岩手県', 'イワテケン', '久慈市', 'クジシ', '田高', 'タコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県久慈市柏崎', '03', '03207', '0280054', '岩手県', 'イワテケン', '久慈市', 'クジシ', '柏崎', 'カシワザキ', null, null, null, null), ('16268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県久慈市巽町', '03', '03207', '0280055', '岩手県', 'イワテケン', '久慈市', 'クジシ', '巽町', 'タツミチョウ', null, null, null, null), ('16269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県久慈市中町', '03', '03207', '0280056', '岩手県', 'イワテケン', '久慈市', 'クジシ', '中町', 'ナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区太平6条', '01', '01102', '0028006', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '太平6条', 'タイヘイ06ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県久慈市中央', '03', '03207', '0280061', '岩手県', 'イワテケン', '久慈市', 'クジシ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県久慈市二十八日町', '03', '03207', '0280062', '岩手県', 'イワテケン', '久慈市', 'クジシ', '二十八日町', 'ニジュウハチニチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県久慈市荒町', '03', '03207', '0280063', '岩手県', 'イワテケン', '久慈市', 'クジシ', '荒町', 'アラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県久慈市八日町', '03', '03207', '0280064', '岩手県', 'イワテケン', '久慈市', 'クジシ', '八日町', 'ヨウカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県久慈市十八日町', '03', '03207', '0280065', '岩手県', 'イワテケン', '久慈市', 'クジシ', '十八日町', 'ジュウハチニチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県久慈市中の橋', '03', '03207', '0280066', '岩手県', 'イワテケン', '久慈市', 'クジシ', '中の橋', 'ナカノハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区太平7条', '01', '01102', '0028007', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '太平7条', 'タイヘイ07ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県久慈市小久慈町', '03', '03207', '0280071', '岩手県', 'イワテケン', '久慈市', 'クジシ', '小久慈町', 'コクジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区太平8条', '01', '01102', '0028008', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '太平8条', 'タイヘイ08ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県久慈市西の沢', '03', '03207', '0280081', '岩手県', 'イワテケン', '久慈市', 'クジシ', '西の沢', 'ニシノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県久慈市川貫', '03', '03207', '0280082', '岩手県', 'イワテケン', '久慈市', 'クジシ', '川貫', 'カワヌキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県久慈市大沢', '03', '03207', '0280083', '岩手県', 'イワテケン', '久慈市', 'クジシ', '大沢', 'オオサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区太平9条', '01', '01102', '0028009', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '太平9条', 'タイヘイ09ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県久慈市大川目町', '03', '03207', '0280091', '岩手県', 'イワテケン', '久慈市', 'クジシ', '大川目町', 'オオカワメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区太平10条', '01', '01102', '0028010', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '太平10条', 'タイヘイ10ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市東和町北前田', '03', '03205', '0280101', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '東和町北前田', 'トウワチョウキタマエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市東和町北川目', '03', '03205', '0280102', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '東和町北川目', 'トウワチョウキタカワメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市東和町石鳩岡', '03', '03205', '0280103', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '東和町石鳩岡', 'トウワチョウイシハトオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市東和町南川目', '03', '03205', '0280104', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '東和町南川目', 'トウワチョウミナミカワメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市東和町前田', '03', '03205', '0280105', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '東和町前田', 'トウワチョウマエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市東和町外谷地', '03', '03205', '0280106', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '東和町外谷地', 'トウワチョウソトヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市東和町北小山田', '03', '03205', '0280107', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '東和町北小山田', 'トウワチョウキタオヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区太平11条', '01', '01102', '0028011', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '太平11条', 'タイヘイ11ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市東和町百ノ沢', '03', '03205', '0280111', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '東和町百ノ沢', 'トウワチョウモモノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市東和町新地', '03', '03205', '0280112', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '東和町新地', 'トウワチョウシンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市東和町東晴山', '03', '03205', '0280113', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '東和町東晴山', 'トウワチョウヒガシハルヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市東和町土沢', '03', '03205', '0280114', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '東和町土沢', 'トウワチョウツチザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市東和町安俵', '03', '03205', '0280115', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '東和町安俵', 'トウワチョウアヒョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市東和町北成島', '03', '03205', '0280116', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '東和町北成島', 'トウワチョウキタナルシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区太平12条', '01', '01102', '0028012', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '太平12条', 'タイヘイ12ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市東和町小友', '03', '03205', '0280121', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '東和町小友', 'トウワチョウオトモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市東和町谷内', '03', '03205', '0280122', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '東和町谷内', 'トウワチョウタニナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市東和町田瀬', '03', '03205', '0280123', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '東和町田瀬', 'トウワチョウタセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市東和町町井', '03', '03205', '0280131', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '東和町町井', 'トウワチョウマチイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市東和町舘迫', '03', '03205', '0280132', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '東和町舘迫', 'トウワチョウタテハサマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市東和町鷹巣堂', '03', '03205', '0280133', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '東和町鷹巣堂', 'トウワチョウタカスドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市東和町砂子', '03', '03205', '0280134', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '東和町砂子', 'トウワチョウイサゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市東和町倉沢', '03', '03205', '0280135', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '東和町倉沢', 'トウワチョウクラザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市東和町小原', '03', '03205', '0280136', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '東和町小原', 'トウワチョウオバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市東和町下浮田', '03', '03205', '0280141', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '東和町下浮田', 'トウワチョウシモウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市東和町駒籠', '03', '03205', '0280142', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '東和町駒籠', 'トウワチョウコマゴメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市東和町上浮田', '03', '03205', '0280143', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '東和町上浮田', 'トウワチョウカミウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市東和町宮田', '03', '03205', '0280144', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '東和町宮田', 'トウワチョウミヤダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市東和町落合', '03', '03205', '0280151', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '東和町落合', 'トウワチョウオチアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市東和町毒沢', '03', '03205', '0280152', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '東和町毒沢', 'トウワチョウドクサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市東和町中内', '03', '03205', '0280153', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '東和町中内', 'トウワチョウナカナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市東和町石持', '03', '03205', '0280154', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '東和町石持', 'トウワチョウイシモチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市東和町南成島', '03', '03205', '0280155', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '東和町南成島', 'トウワチョウミナミナルシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市東和町小通', '03', '03205', '0280156', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '東和町小通', 'トウワチョウコガヨウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区篠路1条', '01', '01102', '0028021', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '篠路1条', 'シノロ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区篠路2条', '01', '01102', '0028022', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '篠路2条', 'シノロ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区篠路3条', '01', '01102', '0028023', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '篠路3条', 'シノロ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区篠路4条', '01', '01102', '0028024', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '篠路4条', 'シノロ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区篠路5条', '01', '01102', '0028025', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '篠路5条', 'シノロ05ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区篠路6条', '01', '01102', '0028026', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '篠路6条', 'シノロ06ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区篠路7条', '01', '01102', '0028027', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '篠路7条', 'シノロ07ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区篠路8条', '01', '01102', '0028028', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '篠路8条', 'シノロ08ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区篠路9条', '01', '01102', '0028029', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '篠路9条', 'シノロ09ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区篠路10条', '01', '01102', '0028030', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '篠路10条', 'シノロ10ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県遠野市宮守町上宮守', '03', '03208', '0280301', '岩手県', 'イワテケン', '遠野市', 'トオノシ', '宮守町上宮守', 'ミヤモリチョウカミミヤモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県遠野市宮守町上鱒沢', '03', '03208', '0280302', '岩手県', 'イワテケン', '遠野市', 'トオノシ', '宮守町上鱒沢', 'ミヤモリチョウカミマスザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県遠野市宮守町下鱒沢', '03', '03208', '0280303', '岩手県', 'イワテケン', '遠野市', 'トオノシ', '宮守町下鱒沢', 'ミヤモリチョウシモマスザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県遠野市宮守町下宮守', '03', '03208', '0280304', '岩手県', 'イワテケン', '遠野市', 'トオノシ', '宮守町下宮守', 'ミヤモリチョウシモミヤモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県遠野市宮守町達曽部', '03', '03208', '0280305', '岩手県', 'イワテケン', '遠野市', 'トオノシ', '宮守町達曽部', 'ミヤモリチョウタッソベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区西茨戸1条', '01', '01102', '0028031', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '西茨戸1条', 'ニシバラト01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区西茨戸2条', '01', '01102', '0028032', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '西茨戸2条', 'ニシバラト02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区西茨戸3条', '01', '01102', '0028033', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '西茨戸3条', 'ニシバラト03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区西茨戸4条', '01', '01102', '0028034', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '西茨戸4条', 'ニシバラト04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区西茨戸5条', '01', '01102', '0028035', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '西茨戸5条', 'ニシバラト05ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区西茨戸6条', '01', '01102', '0028036', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '西茨戸6条', 'ニシバラト06ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区西茨戸7条', '01', '01102', '0028037', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '西茨戸7条', 'ニシバラト07ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区西茨戸', '01', '01102', '0028038', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '西茨戸', 'ニシバラト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区東茨戸1条', '01', '01102', '0028041', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '東茨戸1条', 'ヒガシバラト01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区東茨戸2条', '01', '01102', '0028042', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '東茨戸2条', 'ヒガシバラト02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区東茨戸', '01', '01102', '0028043', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '東茨戸', 'ヒガシバラト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県遠野市小友町', '03', '03208', '0280481', '岩手県', 'イワテケン', '遠野市', 'トオノシ', '小友町', 'オトモチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県遠野市', '03', '03208', '0280500', '岩手県', 'イワテケン', '遠野市', 'トオノシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('16350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県遠野市青笹町糠前', '03', '03208', '0280501', '岩手県', 'イワテケン', '遠野市', 'トオノシ', '青笹町糠前', 'アオザサチョウヌカマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県遠野市青笹町中沢', '03', '03208', '0280502', '岩手県', 'イワテケン', '遠野市', 'トオノシ', '青笹町中沢', 'アオザサチョウナカザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県遠野市青笹町青笹', '03', '03208', '0280503', '岩手県', 'イワテケン', '遠野市', 'トオノシ', '青笹町青笹', 'アオザサチョウアオザサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区篠路町太平', '01', '01102', '0028051', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '篠路町太平', 'シノロチョウタイヘイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県遠野市鶯崎町', '03', '03208', '0280511', '岩手県', 'イワテケン', '遠野市', 'トオノシ', '鶯崎町', 'ウグイスザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県遠野市東上組町', '03', '03208', '0280512', '岩手県', 'イワテケン', '遠野市', 'トオノシ', '東上組町', 'ヒガシカミクミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県遠野市東穀町', '03', '03208', '0280513', '岩手県', 'イワテケン', '遠野市', 'トオノシ', '東穀町', 'ヒガシコクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県遠野市遠野町', '03', '03208', '0280514', '岩手県', 'イワテケン', '遠野市', 'トオノシ', '遠野町', 'トオノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県遠野市東舘町', '03', '03208', '0280515', '岩手県', 'イワテケン', '遠野市', 'トオノシ', '東舘町', 'ヒガシダテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県遠野市穀町', '03', '03208', '0280516', '岩手県', 'イワテケン', '遠野市', 'トオノシ', '穀町', 'コクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県遠野市上組町', '03', '03208', '0280517', '岩手県', 'イワテケン', '遠野市', 'トオノシ', '上組町', 'カミクミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区篠路町上篠路', '01', '01102', '0028052', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '篠路町上篠路', 'シノロチョウカミシノロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県遠野市材木町', '03', '03208', '0280521', '岩手県', 'イワテケン', '遠野市', 'トオノシ', '材木町', 'ザイモクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県遠野市新穀町', '03', '03208', '0280522', '岩手県', 'イワテケン', '遠野市', 'トオノシ', '新穀町', 'シンコクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県遠野市中央通り', '03', '03208', '0280523', '岩手県', 'イワテケン', '遠野市', 'トオノシ', '中央通り', 'チュウオウドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県遠野市新町', '03', '03208', '0280524', '岩手県', 'イワテケン', '遠野市', 'トオノシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県遠野市六日町', '03', '03208', '0280525', '岩手県', 'イワテケン', '遠野市', 'トオノシ', '六日町', 'ムイカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県遠野市下組町', '03', '03208', '0280526', '岩手県', 'イワテケン', '遠野市', 'トオノシ', '下組町', 'シモクミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県遠野市大工町', '03', '03208', '0280527', '岩手県', 'イワテケン', '遠野市', 'トオノシ', '大工町', 'ダイクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区篠路町篠路', '01', '01102', '0028053', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '篠路町篠路', 'シノロチョウシノロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県遠野市綾織町新里', '03', '03208', '0280531', '岩手県', 'イワテケン', '遠野市', 'トオノシ', '綾織町新里', 'アヤオリチョウニッサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県遠野市綾織町下綾織', '03', '03208', '0280532', '岩手県', 'イワテケン', '遠野市', 'トオノシ', '綾織町下綾織', 'アヤオリチョウシモアヤオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県遠野市綾織町上綾織', '03', '03208', '0280533', '岩手県', 'イワテケン', '遠野市', 'トオノシ', '綾織町上綾織', 'アヤオリチョウカミアヤオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県遠野市綾織町みさ崎', '03', '03208', '0280534', '岩手県', 'イワテケン', '遠野市', 'トオノシ', '綾織町みさ崎', 'アヤオリチョウミサザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区篠路町拓北', '01', '01102', '0028054', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '篠路町拓北', 'シノロチョウタクホク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県遠野市松崎町白岩', '03', '03208', '0280541', '岩手県', 'イワテケン', '遠野市', 'トオノシ', '松崎町白岩', 'マツザキチョウシライワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県遠野市早瀬町', '03', '03208', '0280542', '岩手県', 'イワテケン', '遠野市', 'トオノシ', '早瀬町', 'ハヤセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県遠野市松崎町光興寺', '03', '03208', '0280543', '岩手県', 'イワテケン', '遠野市', 'トオノシ', '松崎町光興寺', 'マツザキチョウコウコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県遠野市松崎町松崎', '03', '03208', '0280544', '岩手県', 'イワテケン', '遠野市', 'トオノシ', '松崎町松崎', 'マツザキチョウマツザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県遠野市松崎町駒木', '03', '03208', '0280545', '岩手県', 'イワテケン', '遠野市', 'トオノシ', '松崎町駒木', 'マツザキチョウコマギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区篠路町福移', '01', '01102', '0028055', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '篠路町福移', 'シノロチョウフクイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県遠野市土淵町栃内', '03', '03208', '0280551', '岩手県', 'イワテケン', '遠野市', 'トオノシ', '土淵町栃内', 'ツチブチチョウトチナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県遠野市土淵町山口', '03', '03208', '0280552', '岩手県', 'イワテケン', '遠野市', 'トオノシ', '土淵町山口', 'ツチブチチョウヤマグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県遠野市土淵町柏崎', '03', '03208', '0280553', '岩手県', 'イワテケン', '遠野市', 'トオノシ', '土淵町柏崎', 'ツチブチチョウカシワザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県遠野市土淵町飯豊', '03', '03208', '0280554', '岩手県', 'イワテケン', '遠野市', 'トオノシ', '土淵町飯豊', 'ツチブチチョウイイトヨ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県遠野市土淵町土淵', '03', '03208', '0280555', '岩手県', 'イワテケン', '遠野市', 'トオノシ', '土淵町土淵', 'ツチブチチョウツチブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区拓北1条', '01', '01102', '0028061', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '拓北1条', 'タクホク01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区拓北2条', '01', '01102', '0028062', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '拓北2条', 'タクホク02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区拓北3条', '01', '01102', '0028063', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '拓北3条', 'タクホク03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区拓北4条', '01', '01102', '0028064', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '拓北4条', 'タクホク04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区拓北5条', '01', '01102', '0028065', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '拓北5条', 'タクホク05ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区拓北6条', '01', '01102', '0028066', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '拓北6条', 'タクホク06ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県遠野市附馬牛町上附馬牛', '03', '03208', '0280661', '岩手県', 'イワテケン', '遠野市', 'トオノシ', '附馬牛町上附馬牛', 'ツキモウシチョウカミツキモウシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県遠野市附馬牛町安居台', '03', '03208', '0280662', '岩手県', 'イワテケン', '遠野市', 'トオノシ', '附馬牛町安居台', 'ツキモウシチョウアオダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県遠野市附馬牛町下附馬牛', '03', '03208', '0280663', '岩手県', 'イワテケン', '遠野市', 'トオノシ', '附馬牛町下附馬牛', 'ツキモウシチョウシモツキモウシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県遠野市附馬牛町東禅寺', '03', '03208', '0280664', '岩手県', 'イワテケン', '遠野市', 'トオノシ', '附馬牛町東禅寺', 'ツキモウシチョウトウゼンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区拓北7条', '01', '01102', '0028067', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '拓北7条', 'タクホク07ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区拓北8条', '01', '01102', '0028068', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '拓北8条', 'タクホク08ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区あいの里1条', '01', '01102', '0028071', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', 'あいの里1条', 'アイノサト01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区あいの里2条', '01', '01102', '0028072', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', 'あいの里2条', 'アイノサト02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区あいの里3条', '01', '01102', '0028073', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', 'あいの里3条', 'アイノサト03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区あいの里4条', '01', '01102', '0028074', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', 'あいの里4条', 'アイノサト04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区あいの里5条', '01', '01102', '0028075', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', 'あいの里5条', 'アイノサト05ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県遠野市上郷町佐比内', '03', '03208', '0280771', '岩手県', 'イワテケン', '遠野市', 'トオノシ', '上郷町佐比内', 'カミゴウチョウサヒナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県遠野市上郷町細越', '03', '03208', '0280772', '岩手県', 'イワテケン', '遠野市', 'トオノシ', '上郷町細越', 'カミゴウチョウホソゴエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県遠野市上郷町平野原', '03', '03208', '0280773', '岩手県', 'イワテケン', '遠野市', 'トオノシ', '上郷町平野原', 'カミゴウチョウヒラノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県遠野市上郷町来内', '03', '03208', '0280774', '岩手県', 'イワテケン', '遠野市', 'トオノシ', '上郷町来内', 'カミゴウチョウライナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県遠野市上郷町平倉', '03', '03208', '0280775', '岩手県', 'イワテケン', '遠野市', 'トオノシ', '上郷町平倉', 'カミゴウチョウヒラクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県遠野市上郷町板沢', '03', '03208', '0280776', '岩手県', 'イワテケン', '遠野市', 'トオノシ', '上郷町板沢', 'カミゴウチョウイタザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区百合が原', '01', '01102', '0028081', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '百合が原', 'ユリガハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区百合が原公園', '01', '01102', '0028082', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '百合が原公園', 'ユリガハラコウエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩郡当別町ビトエ中島', '01', '01303', '0028089', '北海道', 'ホッカイドウ', '石狩郡当別町', 'イシカリグントウベツチョウ', 'ビトエ', 'ビトエ', null, null, '中島', 'ナカジマ');
INSERT INTO `ms_addresses` VALUES ('16413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区南あいの里', '01', '01102', '0028091', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '南あいの里', 'ミナミアイノサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県上閉伊郡大槌町', '03', '03461', '0281100', '岩手県', 'イワテケン', '上閉伊郡大槌町', 'カミヘイグンオオツチチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('16415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県上閉伊郡大槌町吉里吉里', '03', '03461', '0281101', '岩手県', 'イワテケン', '上閉伊郡大槌町', 'カミヘイグンオオツチチョウ', '吉里吉里', 'キリキリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県上閉伊郡大槌町赤浜', '03', '03461', '0281102', '岩手県', 'イワテケン', '上閉伊郡大槌町', 'カミヘイグンオオツチチョウ', '赤浜', 'アカハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県上閉伊郡大槌町港町', '03', '03461', '0281103', '岩手県', 'イワテケン', '上閉伊郡大槌町', 'カミヘイグンオオツチチョウ', '港町', 'ミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県上閉伊郡大槌町新港町', '03', '03461', '0281104', '岩手県', 'イワテケン', '上閉伊郡大槌町', 'カミヘイグンオオツチチョウ', '新港町', 'シンミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県上閉伊郡大槌町安渡', '03', '03461', '0281105', '岩手県', 'イワテケン', '上閉伊郡大槌町', 'カミヘイグンオオツチチョウ', '安渡', 'アンド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県上閉伊郡大槌町新町', '03', '03461', '0281111', '岩手県', 'イワテケン', '上閉伊郡大槌町', 'カミヘイグンオオツチチョウ', '新町', 'シンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県上閉伊郡大槌町大町', '03', '03461', '0281112', '岩手県', 'イワテケン', '上閉伊郡大槌町', 'カミヘイグンオオツチチョウ', '大町', 'オオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県上閉伊郡大槌町須賀町', '03', '03461', '0281113', '岩手県', 'イワテケン', '上閉伊郡大槌町', 'カミヘイグンオオツチチョウ', '須賀町', 'スカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県上閉伊郡大槌町栄町', '03', '03461', '0281114', '岩手県', 'イワテケン', '上閉伊郡大槌町', 'カミヘイグンオオツチチョウ', '栄町', 'サカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県上閉伊郡大槌町上町', '03', '03461', '0281115', '岩手県', 'イワテケン', '上閉伊郡大槌町', 'カミヘイグンオオツチチョウ', '上町', 'カミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県上閉伊郡大槌町本町', '03', '03461', '0281116', '岩手県', 'イワテケン', '上閉伊郡大槌町', 'カミヘイグンオオツチチョウ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県上閉伊郡大槌町末広町', '03', '03461', '0281117', '岩手県', 'イワテケン', '上閉伊郡大槌町', 'カミヘイグンオオツチチョウ', '末広町', 'スエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県上閉伊郡大槌町小鎚', '03', '03461', '0281121', '岩手県', 'イワテケン', '上閉伊郡大槌町', 'カミヘイグンオオツチチョウ', '小鎚', 'コヅチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県上閉伊郡大槌町桜木町', '03', '03461', '0281122', '岩手県', 'イワテケン', '上閉伊郡大槌町', 'カミヘイグンオオツチチョウ', '桜木町', 'サクラギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県上閉伊郡大槌町大槌', '03', '03461', '0281131', '岩手県', 'イワテケン', '上閉伊郡大槌町', 'カミヘイグンオオツチチョウ', '大槌', 'オオツチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県上閉伊郡大槌町大ケ口', '03', '03461', '0281132', '岩手県', 'イワテケン', '上閉伊郡大槌町', 'カミヘイグンオオツチチョウ', '大ケ口', 'オガクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県上閉伊郡大槌町金沢', '03', '03461', '0281133', '岩手県', 'イワテケン', '上閉伊郡大槌町', 'カミヘイグンオオツチチョウ', '金沢', 'カネザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡山田町', '03', '03482', '0281300', '岩手県', 'イワテケン', '下閉伊郡山田町', 'シモヘイグンヤマダマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('16434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡山田町石峠', '03', '03482', '0281301', '岩手県', 'イワテケン', '下閉伊郡山田町', 'シモヘイグンヤマダマチ', '石峠', 'イシトウゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡山田町豊間根', '03', '03482', '0281302', '岩手県', 'イワテケン', '下閉伊郡山田町', 'シモヘイグンヤマダマチ', '豊間根', 'トヨマネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡山田町荒川', '03', '03482', '0281303', '岩手県', 'イワテケン', '下閉伊郡山田町', 'シモヘイグンヤマダマチ', '荒川', 'アラカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡山田町大沢', '03', '03482', '0281311', '岩手県', 'イワテケン', '下閉伊郡山田町', 'シモヘイグンヤマダマチ', '大沢', 'オオサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡山田町山田', '03', '03482', '0281321', '岩手県', 'イワテケン', '下閉伊郡山田町', 'シモヘイグンヤマダマチ', '山田', 'ヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡山田町北浜町', '03', '03482', '0281331', '岩手県', 'イワテケン', '下閉伊郡山田町', 'シモヘイグンヤマダマチ', '北浜町', 'キタハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡山田町中央町', '03', '03482', '0281332', '岩手県', 'イワテケン', '下閉伊郡山田町', 'シモヘイグンヤマダマチ', '中央町', 'チュウオウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡山田町後楽町', '03', '03482', '0281333', '岩手県', 'イワテケン', '下閉伊郡山田町', 'シモヘイグンヤマダマチ', '後楽町', 'コウラクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡山田町八幡町', '03', '03482', '0281341', '岩手県', 'イワテケン', '下閉伊郡山田町', 'シモヘイグンヤマダマチ', '八幡町', 'ハチマンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡山田町川向町', '03', '03482', '0281342', '岩手県', 'イワテケン', '下閉伊郡山田町', 'シモヘイグンヤマダマチ', '川向町', 'カワムカイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡山田町境田町', '03', '03482', '0281343', '岩手県', 'イワテケン', '下閉伊郡山田町', 'シモヘイグンヤマダマチ', '境田町', 'サカイダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡山田町長崎', '03', '03482', '0281351', '岩手県', 'イワテケン', '下閉伊郡山田町', 'シモヘイグンヤマダマチ', '長崎', 'ナガサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡山田町飯岡', '03', '03482', '0281352', '岩手県', 'イワテケン', '下閉伊郡山田町', 'シモヘイグンヤマダマチ', '飯岡', 'イイオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡山田町織笠', '03', '03482', '0281361', '岩手県', 'イワテケン', '下閉伊郡山田町', 'シモヘイグンヤマダマチ', '織笠', 'オリカサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡山田町船越', '03', '03482', '0281371', '岩手県', 'イワテケン', '下閉伊郡山田町', 'シモヘイグンヤマダマチ', '船越', 'フナコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市天浪', '12', '12211', '2820001', '千葉県', 'チバケン', '成田市', 'ナリタシ', '天浪', 'テンナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市天神峰成田国際空港内', '12', '12211', '2820002', '千葉県', 'チバケン', '成田市', 'ナリタシ', '天神峰', 'テンジンミネ', null, null, '成田国際空港内', 'ナリタコクサイクウコウナイ');
INSERT INTO `ms_addresses` VALUES ('16452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市東峰成田国際空港内', '12', '12211', '2820003', '千葉県', 'チバケン', '成田市', 'ナリタシ', '東峰', 'トウホウ', null, null, '成田国際空港内', 'ナリタコクサイクウコウナイ');
INSERT INTO `ms_addresses` VALUES ('16453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市古込成田国際空港内', '12', '12211', '2820004', '千葉県', 'チバケン', '成田市', 'ナリタシ', '古込', 'フルゴメ', null, null, '成田国際空港内', 'ナリタコクサイクウコウナイ');
INSERT INTO `ms_addresses` VALUES ('16454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市木の根成田国際空港内', '12', '12211', '2820005', '千葉県', 'チバケン', '成田市', 'ナリタシ', '木の根', 'キノネ', null, null, '成田国際空港内', 'ナリタコクサイクウコウナイ');
INSERT INTO `ms_addresses` VALUES ('16455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市取香成田国際空港内', '12', '12211', '2820006', '千葉県', 'チバケン', '成田市', 'ナリタシ', '取香', 'トッコウ', null, null, '成田国際空港内', 'ナリタコクサイクウコウナイ');
INSERT INTO `ms_addresses` VALUES ('16456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市堀之内成田国際空港内', '12', '12211', '2820007', '千葉県', 'チバケン', '成田市', 'ナリタシ', '堀之内', 'ホリノウチ', null, null, '成田国際空港内', 'ナリタコクサイクウコウナイ');
INSERT INTO `ms_addresses` VALUES ('16457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市十余三成田国際空港内', '12', '12211', '2820009', '千葉県', 'チバケン', '成田市', 'ナリタシ', '十余三', 'トヨミ', null, null, '成田国際空港内', 'ナリタコクサイクウコウナイ');
INSERT INTO `ms_addresses` VALUES ('16458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市吉岡成田国際空港内', '12', '12211', '2820010', '千葉県', 'チバケン', '成田市', 'ナリタシ', '吉岡', 'キチオカ', null, null, '成田国際空港内', 'ナリタコクサイクウコウナイ');
INSERT INTO `ms_addresses` VALUES ('16459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市三里塚', '12', '12211', '2820011', '千葉県', 'チバケン', '成田市', 'ナリタシ', '三里塚', 'サンリヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市東三里塚成田国際空港内', '12', '12211', '2820012', '千葉県', 'チバケン', '成田市', 'ナリタシ', '東三里塚', 'ヒガシサンリヅカ', null, null, '成田国際空港内', 'ナリタコクサイクウコウナイ');
INSERT INTO `ms_addresses` VALUES ('16461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市駒井野成田国際空港内', '12', '12211', '2820021', '千葉県', 'チバケン', '成田市', 'ナリタシ', '駒井野', 'コマイノ', null, null, '成田国際空港内', 'ナリタコクサイクウコウナイ');
INSERT INTO `ms_addresses` VALUES ('16462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市小菅成田国際空港内', '12', '12211', '2820027', '千葉県', 'チバケン', '成田市', 'ナリタシ', '小菅', 'コスゲ', null, null, '成田国際空港内', 'ナリタコクサイクウコウナイ');
INSERT INTO `ms_addresses` VALUES ('16463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取郡多古町一鍬田成田国際空港内', '12', '12347', '2820031', '千葉県', 'チバケン', '香取郡多古町', 'カトリグンタコマチ', '一鍬田', 'ヒトクワダ', null, null, '成田国際空港内', 'ナリタコクサイクウコウナイ');
INSERT INTO `ms_addresses` VALUES ('16464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡芝山町香山新田成田国際空港内', '12', '12409', '2820032', '千葉県', 'チバケン', '山武郡芝山町', 'サンブグンシバヤママチ', '香山新田', 'カヤマシンデン', null, null, '成田国際空港内', 'ナリタコクサイクウコウナイ');
INSERT INTO `ms_addresses` VALUES ('16465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡芝山町菱田成田国際空港内', '12', '12409', '2820033', '千葉県', 'チバケン', '山武郡芝山町', 'サンブグンシバヤママチ', '菱田', 'ヒシダ', null, null, '成田国際空港内', 'ナリタコクサイクウコウナイ');
INSERT INTO `ms_addresses` VALUES ('16466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡芝山町大里成田国際空港内', '12', '12409', '2820034', '千葉県', 'チバケン', '山武郡芝山町', 'サンブグンシバヤママチ', '大里', 'オオサト', null, null, '成田国際空港内', 'ナリタコクサイクウコウナイ');
INSERT INTO `ms_addresses` VALUES ('16467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡芝山町岩山成田国際空港内', '12', '12409', '2820035', '千葉県', 'チバケン', '山武郡芝山町', 'サンブグンシバヤママチ', '岩山', 'イワヤマ', null, null, '成田国際空港内', 'ナリタコクサイクウコウナイ');
INSERT INTO `ms_addresses` VALUES ('16468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市茂市', '03', '03202', '0282101', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '茂市', 'モイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市蟇目', '03', '03202', '0282102', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '蟇目', 'ヒキメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市腹帯', '03', '03202', '0282103', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '腹帯', 'ハラタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市刈屋', '03', '03202', '0282104', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '刈屋', 'カリヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県宮古市和井内', '03', '03202', '0282105', '岩手県', 'イワテケン', '宮古市', 'ミヤコシ', '和井内', 'ワイナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡岩泉町浅内', '03', '03483', '0282231', '岩手県', 'イワテケン', '下閉伊郡岩泉町', 'シモヘイグンイワイズミチョウ', '浅内', 'アサナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡岩泉町大川', '03', '03483', '0282232', '岩手県', 'イワテケン', '下閉伊郡岩泉町', 'シモヘイグンイワイズミチョウ', '大川', 'オオカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡岩泉町釜津田', '03', '03483', '0282233', '岩手県', 'イワテケン', '下閉伊郡岩泉町', 'シモヘイグンイワイズミチョウ', '釜津田', 'カマツタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡川井村', '03', '03487', '0282300', '岩手県', 'イワテケン', '下閉伊郡川井村', 'シモヘイグンカワイムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('16477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡川井村古田', '03', '03487', '0282301', '岩手県', 'イワテケン', '下閉伊郡川井村', 'シモヘイグンカワイムラ', '古田', 'フッタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡川井村川井', '03', '03487', '0282302', '岩手県', 'イワテケン', '下閉伊郡川井村', 'シモヘイグンカワイムラ', '川井', 'カワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡川井村片巣', '03', '03487', '0282303', '岩手県', 'イワテケン', '下閉伊郡川井村', 'シモヘイグンカワイムラ', '片巣', 'カタス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡川井村箱石', '03', '03487', '0282304', '岩手県', 'イワテケン', '下閉伊郡川井村', 'シモヘイグンカワイムラ', '箱石', 'ハコイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡川井村川井9地割', '03', '03487', '0282402', '岩手県', 'イワテケン', '下閉伊郡川井村', 'シモヘイグンカワイムラ', '川井', 'カワイ', null, null, '9地割', '09チワリ');
INSERT INTO `ms_addresses` VALUES ('16482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡川井村川井10地割', '03', '03487', '0282402', '岩手県', 'イワテケン', '下閉伊郡川井村', 'シモヘイグンカワイムラ', '川井', 'カワイ', null, null, '10地割', '10チワリ');
INSERT INTO `ms_addresses` VALUES ('16483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡川井村川井11地割', '03', '03487', '0282402', '岩手県', 'イワテケン', '下閉伊郡川井村', 'シモヘイグンカワイムラ', '川井', 'カワイ', null, null, '11地割', '11チワリ');
INSERT INTO `ms_addresses` VALUES ('16484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡川井村江繋', '03', '03487', '0282421', '岩手県', 'イワテケン', '下閉伊郡川井村', 'シモヘイグンカワイムラ', '江繋', 'エツナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡川井村小国', '03', '03487', '0282422', '岩手県', 'イワテケン', '下閉伊郡川井村', 'シモヘイグンカワイムラ', '小国', 'オグニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡川井村箱石', '03', '03487', '0282504', '岩手県', 'イワテケン', '下閉伊郡川井村', 'シモヘイグンカワイムラ', '箱石', 'ハコイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡川井村夏屋', '03', '03487', '0282511', '岩手県', 'イワテケン', '下閉伊郡川井村', 'シモヘイグンカワイムラ', '夏屋', 'ナツヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡川井村鈴久名', '03', '03487', '0282512', '岩手県', 'イワテケン', '下閉伊郡川井村', 'シモヘイグンカワイムラ', '鈴久名', 'スズクナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡川井村川内', '03', '03487', '0282513', '岩手県', 'イワテケン', '下閉伊郡川井村', 'シモヘイグンカワイムラ', '川内', 'カワウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡川井村田代', '03', '03487', '0282631', '岩手県', 'イワテケン', '下閉伊郡川井村', 'シモヘイグンカワイムラ', '田代', 'タシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡川井村門馬', '03', '03487', '0282632', '岩手県', 'イワテケン', '下閉伊郡川井村', 'シモヘイグンカワイムラ', '門馬', 'カドマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡川井村平津戸', '03', '03487', '0282633', '岩手県', 'イワテケン', '下閉伊郡川井村', 'シモヘイグンカワイムラ', '平津戸', 'ヒラツト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市玉山区薮川', '03', '03201', '0282711', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '玉山区薮川', 'タマヤマクヤブカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県東金市', '12', '12213', '2830000', '千葉県', 'チバケン', '東金市', 'トウガネシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('16497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県東金市家之子', '12', '12213', '2830001', '千葉県', 'チバケン', '東金市', 'トウガネシ', '家之子', 'イエノコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県東金市求名', '12', '12213', '2830002', '千葉県', 'チバケン', '東金市', 'トウガネシ', '求名', 'グミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県東金市道庭', '12', '12213', '2830003', '千葉県', 'チバケン', '東金市', 'トウガネシ', '道庭', 'ドウニワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県東金市二又', '12', '12213', '2830004', '千葉県', 'チバケン', '東金市', 'トウガネシ', '二又', 'フタマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県東金市田間', '12', '12213', '2830005', '千葉県', 'チバケン', '東金市', 'トウガネシ', '田間', 'タマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県東金市東新宿', '12', '12213', '2830006', '千葉県', 'チバケン', '東金市', 'トウガネシ', '東新宿', 'ヒガシシンシュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県東金市上武射田', '12', '12213', '2830011', '千葉県', 'チバケン', '東金市', 'トウガネシ', '上武射田', 'カミムザタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県東金市下武射田', '12', '12213', '2830012', '千葉県', 'チバケン', '東金市', 'トウガネシ', '下武射田', 'シモムザタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県東金市士農田', '12', '12213', '2830013', '千葉県', 'チバケン', '東金市', 'トウガネシ', '士農田', 'シノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県東金市関内', '12', '12213', '2830014', '千葉県', 'チバケン', '東金市', 'トウガネシ', '関内', 'セキウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県東金市前之内', '12', '12213', '2830015', '千葉県', 'チバケン', '東金市', 'トウガネシ', '前之内', 'マエノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県東金市菱沼', '12', '12213', '2830016', '千葉県', 'チバケン', '東金市', 'トウガネシ', '菱沼', 'ヒシヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県東金市東中', '12', '12213', '2830021', '千葉県', 'チバケン', '東金市', 'トウガネシ', '東中', 'ヒガシナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県東金市高倉', '12', '12213', '2830022', '千葉県', 'チバケン', '東金市', 'トウガネシ', '高倉', 'タカクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県東金市宮', '12', '12213', '2830023', '千葉県', 'チバケン', '東金市', 'トウガネシ', '宮', 'ミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県東金市御門', '12', '12213', '2830024', '千葉県', 'チバケン', '東金市', 'トウガネシ', '御門', 'ミカド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県東金市殿廻', '12', '12213', '2830025', '千葉県', 'チバケン', '東金市', 'トウガネシ', '殿廻', 'トノマワリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県東金市中野', '12', '12213', '2830026', '千葉県', 'チバケン', '東金市', 'トウガネシ', '中野', 'ナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県東金市堀之内', '12', '12213', '2830027', '千葉県', 'チバケン', '東金市', 'トウガネシ', '堀之内', 'ホリノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県東金市三浦名', '12', '12213', '2830028', '千葉県', 'チバケン', '東金市', 'トウガネシ', '三浦名', 'ミウラミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県東金市薄島', '12', '12213', '2830031', '千葉県', 'チバケン', '東金市', 'トウガネシ', '薄島', 'ススキシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県東金市荒生', '12', '12213', '2830032', '千葉県', 'チバケン', '東金市', 'トウガネシ', '荒生', 'アラオイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県東金市宿', '12', '12213', '2830033', '千葉県', 'チバケン', '東金市', 'トウガネシ', '宿', 'シュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県東金市大沼', '12', '12213', '2830034', '千葉県', 'チバケン', '東金市', 'トウガネシ', '大沼', 'オオヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県東金市粟生飛地', '12', '12213', '2830035', '千葉県', 'チバケン', '東金市', 'トウガネシ', '粟生飛地', 'アオトビチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県東金市不動堂飛地', '12', '12213', '2830036', '千葉県', 'チバケン', '東金市', 'トウガネシ', '不動堂飛地', 'フドウドウトビチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県東金市細屋敷', '12', '12213', '2830037', '千葉県', 'チバケン', '東金市', 'トウガネシ', '細屋敷', 'ホソヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県東金市関下', '12', '12213', '2830038', '千葉県', 'チバケン', '東金市', 'トウガネシ', '関下', 'セキシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県東金市広瀬', '12', '12213', '2830041', '千葉県', 'チバケン', '東金市', 'トウガネシ', '広瀬', 'ヒロセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県東金市西野飛地', '12', '12213', '2830042', '千葉県', 'チバケン', '東金市', 'トウガネシ', '西野飛地', 'ニシノトビチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県東金市藤下飛地', '12', '12213', '2830043', '千葉県', 'チバケン', '東金市', 'トウガネシ', '藤下飛地', 'フジシタトビチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県東金市小沼田', '12', '12213', '2830044', '千葉県', 'チバケン', '東金市', 'トウガネシ', '小沼田', 'コヌマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県東金市西中', '12', '12213', '2830045', '千葉県', 'チバケン', '東金市', 'トウガネシ', '西中', 'ニシナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県東金市上谷', '12', '12213', '2830046', '千葉県', 'チバケン', '東金市', 'トウガネシ', '上谷', 'ウワヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県東金市北幸谷', '12', '12213', '2830047', '千葉県', 'チバケン', '東金市', 'トウガネシ', '北幸谷', 'キタゴウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県東金市幸田', '12', '12213', '2830048', '千葉県', 'チバケン', '東金市', 'トウガネシ', '幸田', 'コウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県東金市大沼田', '12', '12213', '2830051', '千葉県', 'チバケン', '東金市', 'トウガネシ', '大沼田', 'オオヌマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県東金市二之袋', '12', '12213', '2830052', '千葉県', 'チバケン', '東金市', 'トウガネシ', '二之袋', 'ニノフクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県東金市東中島', '12', '12213', '2830053', '千葉県', 'チバケン', '東金市', 'トウガネシ', '東中島', 'ヒガシナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県東金市下谷', '12', '12213', '2830054', '千葉県', 'チバケン', '東金市', 'トウガネシ', '下谷', 'シモヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県東金市依古島', '12', '12213', '2830055', '千葉県', 'チバケン', '東金市', 'トウガネシ', '依古島', 'ヨコジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県東金市砂古瀬', '12', '12213', '2830056', '千葉県', 'チバケン', '東金市', 'トウガネシ', '砂古瀬', 'イサゴゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県東金市一之袋', '12', '12213', '2830057', '千葉県', 'チバケン', '東金市', 'トウガネシ', '一之袋', 'イチノフクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県東金市北之幸谷', '12', '12213', '2830061', '千葉県', 'チバケン', '東金市', 'トウガネシ', '北之幸谷', 'キタノコウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県東金市家徳', '12', '12213', '2830062', '千葉県', 'チバケン', '東金市', 'トウガネシ', '家徳', 'カトク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県東金市堀上', '12', '12213', '2830063', '千葉県', 'チバケン', '東金市', 'トウガネシ', '堀上', 'ホリアゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県東金市川場', '12', '12213', '2830064', '千葉県', 'チバケン', '東金市', 'トウガネシ', '川場', 'カワバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県東金市押堀', '12', '12213', '2830065', '千葉県', 'チバケン', '東金市', 'トウガネシ', '押堀', 'オシホリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県東金市南上宿', '12', '12213', '2830066', '千葉県', 'チバケン', '東金市', 'トウガネシ', '南上宿', 'ミナミカミジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県東金市東上宿', '12', '12213', '2830067', '千葉県', 'チバケン', '東金市', 'トウガネシ', '東上宿', 'ヒガシカミジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県東金市東岩崎', '12', '12213', '2830068', '千葉県', 'チバケン', '東金市', 'トウガネシ', '東岩崎', 'ヒガシイワサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡九十九里町', '12', '12403', '2830100', '千葉県', 'チバケン', '山武郡九十九里町', 'サンブグンクジュウクリマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('16549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡九十九里町作田', '12', '12403', '2830101', '千葉県', 'チバケン', '山武郡九十九里町', 'サンブグンクジュウクリマチ', '作田', 'サクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡九十九里町小関', '12', '12403', '2830102', '千葉県', 'チバケン', '山武郡九十九里町', 'サンブグンクジュウクリマチ', '小関', 'コセキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡九十九里町田中荒生', '12', '12403', '2830103', '千葉県', 'チバケン', '山武郡九十九里町', 'サンブグンクジュウクリマチ', '田中荒生', 'タナカアラオイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡九十九里町片貝', '12', '12403', '2830104', '千葉県', 'チバケン', '山武郡九十九里町', 'サンブグンクジュウクリマチ', '片貝', 'カタカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡九十九里町粟生', '12', '12403', '2830105', '千葉県', 'チバケン', '山武郡九十九里町', 'サンブグンクジュウクリマチ', '粟生', 'アオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡九十九里町宿', '12', '12403', '2830106', '千葉県', 'チバケン', '山武郡九十九里町', 'サンブグンクジュウクリマチ', '宿', 'シュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡九十九里町荒生', '12', '12403', '2830107', '千葉県', 'チバケン', '山武郡九十九里町', 'サンブグンクジュウクリマチ', '荒生', 'アラオイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡九十九里町細屋敷', '12', '12403', '2830111', '千葉県', 'チバケン', '山武郡九十九里町', 'サンブグンクジュウクリマチ', '細屋敷', 'ホソヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡九十九里町藤下', '12', '12403', '2830112', '千葉県', 'チバケン', '山武郡九十九里町', 'サンブグンクジュウクリマチ', '藤下', 'フジシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡九十九里町不動堂', '12', '12403', '2830113', '千葉県', 'チバケン', '山武郡九十九里町', 'サンブグンクジュウクリマチ', '不動堂', 'フドウドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡九十九里町真亀', '12', '12403', '2830114', '千葉県', 'チバケン', '山武郡九十九里町', 'サンブグンクジュウクリマチ', '真亀', 'マガメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡九十九里町真亀新田', '12', '12403', '2830115', '千葉県', 'チバケン', '山武郡九十九里町', 'サンブグンクジュウクリマチ', '真亀新田', 'マガメシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡九十九里町西野', '12', '12403', '2830116', '千葉県', 'チバケン', '山武郡九十九里町', 'サンブグンクジュウクリマチ', '西野', 'ニシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡九十九里町下貝塚', '12', '12403', '2830117', '千葉県', 'チバケン', '山武郡九十九里町', 'サンブグンクジュウクリマチ', '下貝塚', 'シモカイヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県東金市八坂台', '12', '12213', '2830801', '千葉県', 'チバケン', '東金市', 'トウガネシ', '八坂台', 'ヤサカダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県東金市東金', '12', '12213', '2830802', '千葉県', 'チバケン', '東金市', 'トウガネシ', '東金', 'トウガネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県東金市日吉台', '12', '12213', '2830803', '千葉県', 'チバケン', '東金市', 'トウガネシ', '日吉台', 'ヒヨシダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県東金市油井', '12', '12213', '2830804', '千葉県', 'チバケン', '東金市', 'トウガネシ', '油井', 'ユイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県東金市松之郷', '12', '12213', '2830805', '千葉県', 'チバケン', '東金市', 'トウガネシ', '松之郷', 'マツノゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県東金市台方', '12', '12213', '2830811', '千葉県', 'チバケン', '東金市', 'トウガネシ', '台方', 'ダイカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県東金市福俵', '12', '12213', '2830812', '千葉県', 'チバケン', '東金市', 'トウガネシ', '福俵', 'フクタワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県東金市山口', '12', '12213', '2830813', '千葉県', 'チバケン', '東金市', 'トウガネシ', '山口', 'ヤマグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県東金市田中', '12', '12213', '2830814', '千葉県', 'チバケン', '東金市', 'トウガネシ', '田中', 'タナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県東金市大豆谷', '12', '12213', '2830815', '千葉県', 'チバケン', '東金市', 'トウガネシ', '大豆谷', 'マメザク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県東金市西福俵', '12', '12213', '2830816', '千葉県', 'チバケン', '東金市', 'トウガネシ', '西福俵', 'ニシフクタワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県東金市小野', '12', '12213', '2830821', '千葉県', 'チバケン', '東金市', 'トウガネシ', '小野', 'オノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県東金市季美の森東', '12', '12213', '2830822', '千葉県', 'チバケン', '東金市', 'トウガネシ', '季美の森東', 'キミノモリヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県東金市山田', '12', '12213', '2830823', '千葉県', 'チバケン', '東金市', 'トウガネシ', '山田', 'ヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県東金市丹尾', '12', '12213', '2830824', '千葉県', 'チバケン', '東金市', 'トウガネシ', '丹尾', 'タンノオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県東金市滝', '12', '12213', '2830825', '千葉県', 'チバケン', '東金市', 'トウガネシ', '滝', 'タキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県東金市丘山台', '12', '12213', '2830826', '千葉県', 'チバケン', '東金市', 'トウガネシ', '丘山台', 'オカヤマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県東金市酒蔵', '12', '12213', '2830831', '千葉県', 'チバケン', '東金市', 'トウガネシ', '酒蔵', 'シュゾウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県東金市三ケ尻', '12', '12213', '2830832', '千葉県', 'チバケン', '東金市', 'トウガネシ', '三ケ尻', 'ミカジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県東金市滝沢', '12', '12213', '2830833', '千葉県', 'チバケン', '東金市', 'トウガネシ', '滝沢', 'タキサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県東金市上布田', '12', '12213', '2830834', '千葉県', 'チバケン', '東金市', 'トウガネシ', '上布田', 'カミフダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県東金市極楽寺', '12', '12213', '2830835', '千葉県', 'チバケン', '東金市', 'トウガネシ', '極楽寺', 'ゴクラクジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市石鳥谷町好地', '03', '03205', '0283101', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '石鳥谷町好地', 'イシドリヤチョウコウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市石鳥谷町上口', '03', '03205', '0283102', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '石鳥谷町上口', 'イシドリヤチョウカミグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市石鳥谷町新堀', '03', '03205', '0283111', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '石鳥谷町新堀', 'イシドリヤチョウニイボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市石鳥谷町戸塚', '03', '03205', '0283121', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '石鳥谷町戸塚', 'イシドリヤチョウトヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市石鳥谷町滝田', '03', '03205', '0283122', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '石鳥谷町滝田', 'イシドリヤチョウタキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市石鳥谷町猪鼻', '03', '03205', '0283131', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '石鳥谷町猪鼻', 'イシドリヤチョウイノハナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市石鳥谷町東中島', '03', '03205', '0283132', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '石鳥谷町東中島', 'イシドリヤチョウヒガシナカシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市石鳥谷町関口', '03', '03205', '0283133', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '石鳥谷町関口', 'イシドリヤチョウセキグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市石鳥谷町五大堂', '03', '03205', '0283141', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '石鳥谷町五大堂', 'イシドリヤチョウゴダイドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市石鳥谷町八重畑', '03', '03205', '0283142', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '石鳥谷町八重畑', 'イシドリヤチョウヤエハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市石鳥谷町江曽', '03', '03205', '0283151', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '石鳥谷町江曽', 'イシドリヤチョウエソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市石鳥谷町南寺林', '03', '03205', '0283152', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '石鳥谷町南寺林', 'イシドリヤチョウミナミテラバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市石鳥谷町小森林', '03', '03205', '0283153', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '石鳥谷町小森林', 'イシドリヤチョウコモリバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市石鳥谷町黒沼', '03', '03205', '0283161', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '石鳥谷町黒沼', 'イシドリヤチョウクロヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市石鳥谷町西中島', '03', '03205', '0283162', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '石鳥谷町西中島', 'イシドリヤチョウニシナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市石鳥谷町八幡', '03', '03205', '0283163', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '石鳥谷町八幡', 'イシドリヤチョウハチマン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市石鳥谷町中寺林', '03', '03205', '0283171', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '石鳥谷町中寺林', 'イシドリヤチョウナカテラバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市石鳥谷町北寺林', '03', '03205', '0283172', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '石鳥谷町北寺林', 'イシドリヤチョウキタテラバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市石鳥谷町大興寺', '03', '03205', '0283181', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '石鳥谷町大興寺', 'イシドリヤチョウダイコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市石鳥谷町松林寺', '03', '03205', '0283182', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '石鳥谷町松林寺', 'イシドリヤチョウショウリンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市石鳥谷町長谷堂', '03', '03205', '0283183', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '石鳥谷町長谷堂', 'イシドリヤチョウハセドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市石鳥谷町富沢', '03', '03205', '0283184', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '石鳥谷町富沢', 'イシドリヤチョウトミサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市石鳥谷町大瀬川', '03', '03205', '0283185', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '石鳥谷町大瀬川', 'イシドリヤチョウオオセガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市大迫町内川目', '03', '03205', '0283201', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '大迫町内川目', 'オオハサママチウチカワメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市大迫町外川目', '03', '03205', '0283202', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '大迫町外川目', 'オオハサママチソトカワメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市大迫町大迫', '03', '03205', '0283203', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '大迫町大迫', 'オオハサママチオオハサマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県花巻市大迫町亀ケ森', '03', '03205', '0283204', '岩手県', 'イワテケン', '花巻市', 'ハナマキシ', '大迫町亀ケ森', 'オオハサママチカメガモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県紫波郡紫波町', '03', '03321', '0283300', '岩手県', 'イワテケン', '紫波郡紫波町', 'シワグンシワチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('16614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県紫波郡紫波町中島', '03', '03321', '0283301', '岩手県', 'イワテケン', '紫波郡紫波町', 'シワグンシワチョウ', '中島', 'ナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県紫波郡紫波町陣ケ岡', '03', '03321', '0283302', '岩手県', 'イワテケン', '紫波郡紫波町', 'シワグンシワチョウ', '陣ケ岡', 'ジンガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県紫波郡紫波町高水寺', '03', '03321', '0283303', '岩手県', 'イワテケン', '紫波郡紫波町', 'シワグンシワチョウ', '高水寺', 'コウスイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県紫波郡紫波町二日町', '03', '03321', '0283304', '岩手県', 'イワテケン', '紫波郡紫波町', 'シワグンシワチョウ', '二日町', 'フツカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県紫波郡紫波町日詰', '03', '03321', '0283305', '岩手県', 'イワテケン', '紫波郡紫波町', 'シワグンシワチョウ', '日詰', 'ヒヅメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県紫波郡紫波町日詰西', '03', '03321', '0283306', '岩手県', 'イワテケン', '紫波郡紫波町', 'シワグンシワチョウ', '日詰西', 'ヒヅメニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県紫波郡紫波町桜町', '03', '03321', '0283307', '岩手県', 'イワテケン', '紫波郡紫波町', 'シワグンシワチョウ', '桜町', 'サクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県紫波郡紫波町平沢', '03', '03321', '0283308', '岩手県', 'イワテケン', '紫波郡紫波町', 'シワグンシワチョウ', '平沢', 'ヒラサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県紫波郡紫波町北日詰', '03', '03321', '0283309', '岩手県', 'イワテケン', '紫波郡紫波町', 'シワグンシワチョウ', '北日詰', 'キタヒヅメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県紫波郡紫波町犬渕', '03', '03321', '0283311', '岩手県', 'イワテケン', '紫波郡紫波町', 'シワグンシワチョウ', '犬渕', 'イヌブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県紫波郡紫波町犬吠森', '03', '03321', '0283312', '岩手県', 'イワテケン', '紫波郡紫波町', 'シワグンシワチョウ', '犬吠森', 'イヌホエモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県紫波郡紫波町星山', '03', '03321', '0283313', '岩手県', 'イワテケン', '紫波郡紫波町', 'シワグンシワチョウ', '星山', 'ホシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県紫波郡紫波町大巻', '03', '03321', '0283314', '岩手県', 'イワテケン', '紫波郡紫波町', 'シワグンシワチョウ', '大巻', 'オオマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県紫波郡紫波町彦部', '03', '03321', '0283315', '岩手県', 'イワテケン', '紫波郡紫波町', 'シワグンシワチョウ', '彦部', 'ヒコベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県紫波郡紫波町佐比内', '03', '03321', '0283316', '岩手県', 'イワテケン', '紫波郡紫波町', 'シワグンシワチョウ', '佐比内', 'サヒナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県紫波郡紫波町南日詰', '03', '03321', '0283317', '岩手県', 'イワテケン', '紫波郡紫波町', 'シワグンシワチョウ', '南日詰', 'ミナミヒヅメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県紫波郡紫波町紫波中央駅前', '03', '03321', '0283318', '岩手県', 'イワテケン', '紫波郡紫波町', 'シワグンシワチョウ', '紫波中央駅前', 'シワチュウオウエキマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県紫波郡紫波町江柄', '03', '03321', '0283321', '岩手県', 'イワテケン', '紫波郡紫波町', 'シワグンシワチョウ', '江柄', 'エガラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県紫波郡紫波町栃内', '03', '03321', '0283322', '岩手県', 'イワテケン', '紫波郡紫波町', 'シワグンシワチョウ', '栃内', 'トチナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県紫波郡紫波町北沢', '03', '03321', '0283323', '岩手県', 'イワテケン', '紫波郡紫波町', 'シワグンシワチョウ', '北沢', 'キタザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県紫波郡紫波町東長岡', '03', '03321', '0283324', '岩手県', 'イワテケン', '紫波郡紫波町', 'シワグンシワチョウ', '東長岡', 'ヒガシナガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県紫波郡紫波町草刈', '03', '03321', '0283325', '岩手県', 'イワテケン', '紫波郡紫波町', 'シワグンシワチョウ', '草刈', 'クサカリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県紫波郡紫波町西長岡', '03', '03321', '0283326', '岩手県', 'イワテケン', '紫波郡紫波町', 'シワグンシワチョウ', '西長岡', 'ニシナガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県紫波郡紫波町上平沢', '03', '03321', '0283441', '岩手県', 'イワテケン', '紫波郡紫波町', 'シワグンシワチョウ', '上平沢', 'カミヒラサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県紫波郡紫波町升沢', '03', '03321', '0283442', '岩手県', 'イワテケン', '紫波郡紫波町', 'シワグンシワチョウ', '升沢', 'マスザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県紫波郡紫波町上松本', '03', '03321', '0283443', '岩手県', 'イワテケン', '紫波郡紫波町', 'シワグンシワチョウ', '上松本', 'カミマツモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県紫波郡紫波町小屋敷', '03', '03321', '0283444', '岩手県', 'イワテケン', '紫波郡紫波町', 'シワグンシワチョウ', '小屋敷', 'コヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県紫波郡紫波町南伝法寺', '03', '03321', '0283445', '岩手県', 'イワテケン', '紫波郡紫波町', 'シワグンシワチョウ', '南伝法寺', 'ミナミデンボウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県紫波郡紫波町下松本', '03', '03321', '0283446', '岩手県', 'イワテケン', '紫波郡紫波町', 'シワグンシワチョウ', '下松本', 'シモマツモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県紫波郡紫波町宮手', '03', '03321', '0283447', '岩手県', 'イワテケン', '紫波郡紫波町', 'シワグンシワチョウ', '宮手', 'ミヤデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県紫波郡紫波町吉水', '03', '03321', '0283448', '岩手県', 'イワテケン', '紫波郡紫波町', 'シワグンシワチョウ', '吉水', 'ヨシミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県紫波郡紫波町稲藤', '03', '03321', '0283451', '岩手県', 'イワテケン', '紫波郡紫波町', 'シワグンシワチョウ', '稲藤', 'イナフジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県紫波郡紫波町片寄', '03', '03321', '0283452', '岩手県', 'イワテケン', '紫波郡紫波町', 'シワグンシワチョウ', '片寄', 'カタヨセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県紫波郡紫波町土舘', '03', '03321', '0283453', '岩手県', 'イワテケン', '紫波郡紫波町', 'シワグンシワチョウ', '土舘', 'ツチダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県紫波郡紫波町山屋', '03', '03321', '0283531', '岩手県', 'イワテケン', '紫波郡紫波町', 'シワグンシワチョウ', '山屋', 'ヤマヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県紫波郡紫波町船久保', '03', '03321', '0283532', '岩手県', 'イワテケン', '紫波郡紫波町', 'シワグンシワチョウ', '船久保', 'フナクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県紫波郡紫波町赤沢', '03', '03321', '0283533', '岩手県', 'イワテケン', '紫波郡紫波町', 'シワグンシワチョウ', '赤沢', 'アカザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県紫波郡紫波町紫野', '03', '03321', '0283534', '岩手県', 'イワテケン', '紫波郡紫波町', 'シワグンシワチョウ', '紫野', 'ムラサキノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県紫波郡紫波町遠山', '03', '03321', '0283535', '岩手県', 'イワテケン', '紫波郡紫波町', 'シワグンシワチョウ', '遠山', 'トオヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県紫波郡紫波町北田', '03', '03321', '0283536', '岩手県', 'イワテケン', '紫波郡紫波町', 'シワグンシワチョウ', '北田', 'キタダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県紫波郡矢巾町', '03', '03322', '0283600', '岩手県', 'イワテケン', '紫波郡矢巾町', 'シワグンヤハバチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('16656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県紫波郡矢巾町高田', '03', '03322', '0283601', '岩手県', 'イワテケン', '紫波郡矢巾町', 'シワグンヤハバチョウ', '高田', 'タカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県紫波郡矢巾町藤沢', '03', '03322', '0283602', '岩手県', 'イワテケン', '紫波郡矢巾町', 'シワグンヤハバチョウ', '藤沢', 'フジサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県紫波郡矢巾町西徳田', '03', '03322', '0283603', '岩手県', 'イワテケン', '紫波郡矢巾町', 'シワグンヤハバチョウ', '西徳田', 'ニシトクタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県紫波郡矢巾町東徳田', '03', '03322', '0283604', '岩手県', 'イワテケン', '紫波郡矢巾町', 'シワグンヤハバチョウ', '東徳田', 'ヒガシトクタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県紫波郡矢巾町間野々', '03', '03322', '0283605', '岩手県', 'イワテケン', '紫波郡矢巾町', 'シワグンヤハバチョウ', '間野々', 'アイノノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県紫波郡矢巾町土橋', '03', '03322', '0283606', '岩手県', 'イワテケン', '紫波郡矢巾町', 'シワグンヤハバチョウ', '土橋', 'ツチハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県紫波郡矢巾町高水寺', '03', '03322', '0283607', '岩手県', 'イワテケン', '紫波郡矢巾町', 'シワグンヤハバチョウ', '高水寺', 'コウスイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県紫波郡矢巾町北郡山', '03', '03322', '0283608', '岩手県', 'イワテケン', '紫波郡矢巾町', 'シワグンヤハバチョウ', '北郡山', 'キタコオリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県紫波郡矢巾町赤林', '03', '03322', '0283611', '岩手県', 'イワテケン', '紫波郡矢巾町', 'シワグンヤハバチョウ', '赤林', 'アカバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県紫波郡矢巾町下矢次', '03', '03322', '0283612', '岩手県', 'イワテケン', '紫波郡矢巾町', 'シワグンヤハバチョウ', '下矢次', 'シモヤツギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県紫波郡矢巾町北矢幅', '03', '03322', '0283613', '岩手県', 'イワテケン', '紫波郡矢巾町', 'シワグンヤハバチョウ', '北矢幅', 'キタヤハバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県紫波郡矢巾町又兵エ新田', '03', '03322', '0283614', '岩手県', 'イワテケン', '紫波郡矢巾町', 'シワグンヤハバチョウ', '又兵エ新田', 'マタベエシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県紫波郡矢巾町南矢幅', '03', '03322', '0283615', '岩手県', 'イワテケン', '紫波郡矢巾町', 'シワグンヤハバチョウ', '南矢幅', 'ミナミヤハバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県紫波郡矢巾町白沢', '03', '03322', '0283616', '岩手県', 'イワテケン', '紫波郡矢巾町', 'シワグンヤハバチョウ', '白沢', 'シラサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県紫波郡矢巾町太田', '03', '03322', '0283617', '岩手県', 'イワテケン', '紫波郡矢巾町', 'シワグンヤハバチョウ', '太田', 'オオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県紫波郡矢巾町広宮沢', '03', '03322', '0283621', '岩手県', 'イワテケン', '紫波郡矢巾町', 'シワグンヤハバチョウ', '広宮沢', 'ヒロミヤサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県紫波郡矢巾町上矢次', '03', '03322', '0283622', '岩手県', 'イワテケン', '紫波郡矢巾町', 'シワグンヤハバチョウ', '上矢次', 'カミヤツギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県紫波郡矢巾町煙山', '03', '03322', '0283623', '岩手県', 'イワテケン', '紫波郡矢巾町', 'シワグンヤハバチョウ', '煙山', 'ケムヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県紫波郡矢巾町北伝法寺', '03', '03322', '0283624', '岩手県', 'イワテケン', '紫波郡矢巾町', 'シワグンヤハバチョウ', '北伝法寺', 'キタデンポウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県紫波郡矢巾町室岡', '03', '03322', '0283625', '岩手県', 'イワテケン', '紫波郡矢巾町', 'シワグンヤハバチョウ', '室岡', 'ムロオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県紫波郡矢巾町岩清水', '03', '03322', '0283626', '岩手県', 'イワテケン', '紫波郡矢巾町', 'シワグンヤハバチョウ', '岩清水', 'イワシミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県紫波郡矢巾町和味', '03', '03322', '0283627', '岩手県', 'イワテケン', '紫波郡矢巾町', 'シワグンヤハバチョウ', '和味', 'ワミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県四街道市', '12', '12228', '2840000', '千葉県', 'チバケン', '四街道市', 'ヨツカイドウシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('16687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県四街道市大日', '12', '12228', '2840001', '千葉県', 'チバケン', '四街道市', 'ヨツカイドウシ', '大日', 'ダイニチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県四街道市萱橋', '12', '12228', '2840002', '千葉県', 'チバケン', '四街道市', 'ヨツカイドウシ', '萱橋', 'カヤハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県四街道市鹿渡', '12', '12228', '2840003', '千葉県', 'チバケン', '四街道市', 'ヨツカイドウシ', '鹿渡', 'シカワタシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県四街道市みのり町', '12', '12228', '2840004', '千葉県', 'チバケン', '四街道市', 'ヨツカイドウシ', 'みのり町', 'ミノリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県四街道市四街道', '12', '12228', '2840005', '千葉県', 'チバケン', '四街道市', 'ヨツカイドウシ', '四街道', 'ヨツカイドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県四街道市下志津新田', '12', '12228', '2840006', '千葉県', 'チバケン', '四街道市', 'ヨツカイドウシ', '下志津新田', 'シモシヅシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県四街道市さつきケ丘', '12', '12228', '2840007', '千葉県', 'チバケン', '四街道市', 'ヨツカイドウシ', 'さつきケ丘', 'サツキガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県四街道市鹿放ケ丘', '12', '12228', '2840008', '千葉県', 'チバケン', '四街道市', 'ヨツカイドウシ', '鹿放ケ丘', 'ロッポウガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県四街道市亀崎', '12', '12228', '2840011', '千葉県', 'チバケン', '四街道市', 'ヨツカイドウシ', '亀崎', 'カメザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県四街道市物井', '12', '12228', '2840012', '千葉県', 'チバケン', '四街道市', 'ヨツカイドウシ', '物井', 'モノイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県四街道市内黒田', '12', '12228', '2840013', '千葉県', 'チバケン', '四街道市', 'ヨツカイドウシ', '内黒田', 'ウチクロダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県四街道市池花', '12', '12228', '2840014', '千葉県', 'チバケン', '四街道市', 'ヨツカイドウシ', '池花', 'イケハナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県四街道市千代田', '12', '12228', '2840015', '千葉県', 'チバケン', '四街道市', 'ヨツカイドウシ', '千代田', 'チヨダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県四街道市もねの里', '12', '12228', '2840016', '千葉県', 'チバケン', '四街道市', 'ヨツカイドウシ', 'もねの里', 'モネノサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県四街道市長岡', '12', '12228', '2840021', '千葉県', 'チバケン', '四街道市', 'ヨツカイドウシ', '長岡', 'ナガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県四街道市山梨', '12', '12228', '2840022', '千葉県', 'チバケン', '四街道市', 'ヨツカイドウシ', '山梨', 'ヤマナシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県四街道市みそら', '12', '12228', '2840023', '千葉県', 'チバケン', '四街道市', 'ヨツカイドウシ', 'みそら', 'ミソラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県四街道市旭ケ丘', '12', '12228', '2840024', '千葉県', 'チバケン', '四街道市', 'ヨツカイドウシ', '旭ケ丘', 'アサヒガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県四街道市さちが丘', '12', '12228', '2840025', '千葉県', 'チバケン', '四街道市', 'ヨツカイドウシ', 'さちが丘', 'サチガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県四街道市つくし座', '12', '12228', '2840026', '千葉県', 'チバケン', '四街道市', 'ヨツカイドウシ', 'つくし座', 'ツクシザ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県四街道市栗山', '12', '12228', '2840027', '千葉県', 'チバケン', '四街道市', 'ヨツカイドウシ', '栗山', 'クリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県四街道市成山', '12', '12228', '2840031', '千葉県', 'チバケン', '四街道市', 'ヨツカイドウシ', '成山', 'ナリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県四街道市吉岡', '12', '12228', '2840032', '千葉県', 'チバケン', '四街道市', 'ヨツカイドウシ', '吉岡', 'ヨシオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県四街道市鷹の台', '12', '12228', '2840033', '千葉県', 'チバケン', '四街道市', 'ヨツカイドウシ', '鷹の台', 'タカノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県四街道市南波佐間', '12', '12228', '2840034', '千葉県', 'チバケン', '四街道市', 'ヨツカイドウシ', '南波佐間', 'ナバサマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県四街道市和田', '12', '12228', '2840035', '千葉県', 'チバケン', '四街道市', 'ヨツカイドウシ', '和田', 'ワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県四街道市中野', '12', '12228', '2840036', '千葉県', 'チバケン', '四街道市', 'ヨツカイドウシ', '中野', 'ナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県四街道市中台', '12', '12228', '2840037', '千葉県', 'チバケン', '四街道市', 'ヨツカイドウシ', '中台', 'ナカダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県四街道市上野', '12', '12228', '2840041', '千葉県', 'チバケン', '四街道市', 'ヨツカイドウシ', '上野', 'ウエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県四街道市小名木', '12', '12228', '2840042', '千葉県', 'チバケン', '四街道市', 'ヨツカイドウシ', '小名木', 'オナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県四街道市めいわ', '12', '12228', '2840043', '千葉県', 'チバケン', '四街道市', 'ヨツカイドウシ', 'めいわ', 'メイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県四街道市和良比', '12', '12228', '2840044', '千葉県', 'チバケン', '四街道市', 'ヨツカイドウシ', '和良比', 'ワラビ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県四街道市美しが丘', '12', '12228', '2840045', '千葉県', 'チバケン', '四街道市', 'ヨツカイドウシ', '美しが丘', 'ウツクシガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市玉山区永井', '03', '03201', '0284121', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '玉山区永井', 'タマヤマクナガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市玉山区寺林', '03', '03201', '0284122', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '玉山区寺林', 'タマヤマクテラバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市玉山区巻堀', '03', '03201', '0284123', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '玉山区巻堀', 'タマヤマクマキボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市玉山区馬場', '03', '03201', '0284124', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '玉山区馬場', 'タマヤマクババ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市玉山区好摩', '03', '03201', '0284125', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '玉山区好摩', 'タマヤマクコウマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市玉山区芋田', '03', '03201', '0284131', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '玉山区芋田', 'タマヤマクイモダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市玉山区渋民', '03', '03201', '0284132', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '玉山区渋民', 'タマヤマクシブタミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市玉山区門前寺', '03', '03201', '0284133', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '玉山区門前寺', 'タマヤマクモンゼンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市玉山区下田', '03', '03201', '0284134', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '玉山区下田', 'タマヤマクシモダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市玉山区川崎', '03', '03201', '0284135', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '玉山区川崎', 'タマヤマクカワサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県盛岡市玉山区松内', '03', '03201', '0284136', '岩手県', 'イワテケン', '盛岡市', 'モリオカシ', '玉山区松内', 'タマヤマクマツナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県岩手郡岩手町川口', '03', '03303', '0284211', '岩手県', 'イワテケン', '岩手郡岩手町', 'イワテグンイワテマチ', '川口', 'カワグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県岩手郡岩手町', '03', '03303', '0284300', '岩手県', 'イワテケン', '岩手郡岩手町', 'イワテグンイワテマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('16735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県岩手郡岩手町沼宮内', '03', '03303', '0284301', '岩手県', 'イワテケン', '岩手郡岩手町', 'イワテグンイワテマチ', '沼宮内', 'ヌマクナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県岩手郡岩手町大坊', '03', '03303', '0284302', '岩手県', 'イワテケン', '岩手郡岩手町', 'イワテグンイワテマチ', '大坊', 'ダイボウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県岩手郡岩手町江刈内', '03', '03303', '0284303', '岩手県', 'イワテケン', '岩手郡岩手町', 'イワテグンイワテマチ', '江刈内', 'エカリナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県岩手郡岩手町子抱', '03', '03303', '0284304', '岩手県', 'イワテケン', '岩手郡岩手町', 'イワテグンイワテマチ', '子抱', 'コダキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県岩手郡岩手町久保', '03', '03303', '0284305', '岩手県', 'イワテケン', '岩手郡岩手町', 'イワテグンイワテマチ', '久保', 'クボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県岩手郡岩手町御堂', '03', '03303', '0284306', '岩手県', 'イワテケン', '岩手郡岩手町', 'イワテグンイワテマチ', '御堂', 'ミドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県岩手郡岩手町五日市', '03', '03303', '0284307', '岩手県', 'イワテケン', '岩手郡岩手町', 'イワテグンイワテマチ', '五日市', 'イツカイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県岩手郡岩手町一方井', '03', '03303', '0284421', '岩手県', 'イワテケン', '岩手郡岩手町', 'イワテグンイワテマチ', '一方井', 'イッカタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県岩手郡岩手町坊', '03', '03303', '0284422', '岩手県', 'イワテケン', '岩手郡岩手町', 'イワテグンイワテマチ', '坊', 'ボウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県岩手郡岩手町土川', '03', '03303', '0284423', '岩手県', 'イワテケン', '岩手郡岩手町', 'イワテグンイワテマチ', '土川', 'ツチカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県岩手郡岩手町黒石', '03', '03303', '0284424', '岩手県', 'イワテケン', '岩手郡岩手町', 'イワテグンイワテマチ', '黒石', 'クロイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県岩手郡岩手町葉木田', '03', '03303', '0284425', '岩手県', 'イワテケン', '岩手郡岩手町', 'イワテグンイワテマチ', '葉木田', 'ハキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県岩手郡岩手町黒内', '03', '03303', '0284426', '岩手県', 'イワテケン', '岩手郡岩手町', 'イワテグンイワテマチ', '黒内', 'クロナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市', '12', '12212', '2850000', '千葉県', 'チバケン', '佐倉市', 'サクラシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('16753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市土浮', '12', '12212', '2850001', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '土浮', 'ツチウキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市萩山新田', '12', '12212', '2850002', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '萩山新田', 'ハギヤマシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市飯野', '12', '12212', '2850003', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '飯野', 'イイノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市岩名', '12', '12212', '2850004', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '岩名', 'イワナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市宮前', '12', '12212', '2850005', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '宮前', 'ミヤマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市下根', '12', '12212', '2850006', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '下根', 'シモネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市下根町', '12', '12212', '2850007', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '下根町', 'シモネマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市鹿島干拓', '12', '12212', '2850008', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '鹿島干拓', 'カシマカンタク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市飯野町', '12', '12212', '2850009', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '飯野町', 'イイノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市山崎', '12', '12212', '2850011', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '山崎', 'ヤマノサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市田町', '12', '12212', '2850012', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '田町', 'タマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市海隣寺町', '12', '12212', '2850013', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '海隣寺町', 'カイリンジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市栄町', '12', '12212', '2850014', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '栄町', 'サカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市並木町', '12', '12212', '2850015', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '並木町', 'ナミキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市宮小路町', '12', '12212', '2850016', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '宮小路町', 'ミヤコウジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市城内町', '12', '12212', '2850017', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '城内町', 'ジョウナイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市最上町', '12', '12212', '2850021', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '最上町', 'モガミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市中尾余町', '12', '12212', '2850022', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '中尾余町', 'ナカビョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市新町', '12', '12212', '2850023', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市裏新町', '12', '12212', '2850024', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '裏新町', 'ウラシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市鏑木町', '12', '12212', '2850025', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '鏑木町', 'カブラギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市鏑木仲田町', '12', '12212', '2850026', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '鏑木仲田町', 'カブラギナカタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市飯田台', '12', '12212', '2850031', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '飯田台', 'イイダダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市飯田', '12', '12212', '2850032', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '飯田', 'イイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市鍋山町', '12', '12212', '2850033', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '鍋山町', 'ナベヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市千成', '12', '12212', '2850034', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '千成', 'センナリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市樹木町', '12', '12212', '2850035', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '樹木町', 'ジュモクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市藤沢町', '12', '12212', '2850036', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '藤沢町', 'フジサワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市本町', '12', '12212', '2850037', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '本町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市弥勒町', '12', '12212', '2850038', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '弥勒町', 'ミロクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市野狐台町', '12', '12212', '2850039', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '野狐台町', 'ヤッコダイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市大佐倉', '12', '12212', '2850041', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '大佐倉', 'オオザクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市将門町', '12', '12212', '2850042', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '将門町', 'マサカドマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市大蛇町', '12', '12212', '2850043', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '大蛇町', 'オオジャマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市上代', '12', '12212', '2850044', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '上代', 'カミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市白銀', '12', '12212', '2850045', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '白銀', 'シロガネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市高岡', '12', '12212', '2850046', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '高岡', 'タカオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市長熊', '12', '12212', '2850051', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '長熊', 'ナガクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市八木', '12', '12212', '2850052', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '八木', 'ヤギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市下勝田', '12', '12212', '2850053', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '下勝田', 'シモカツタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市上勝田', '12', '12212', '2850054', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '上勝田', 'カミカツタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市瓜坪新田', '12', '12212', '2850055', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '瓜坪新田', 'ウリツボシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市坪山新田', '12', '12212', '2850056', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '坪山新田', 'ツボヤマシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市米戸', '12', '12212', '2850057', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '米戸', 'コメド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市高崎', '12', '12212', '2850061', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '高崎', 'タカサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市寒風', '12', '12212', '2850062', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '寒風', 'サムカゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市宮本', '12', '12212', '2850063', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '宮本', 'ミヤモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市天辺', '12', '12212', '2850064', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '天辺', 'アマベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市直弥', '12', '12212', '2850065', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '直弥', 'ナオヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市上別所', '12', '12212', '2850066', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '上別所', 'カミベッシヨ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市岩富', '12', '12212', '2850071', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '岩富', 'イワトミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市岩富町', '12', '12212', '2850072', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '岩富町', 'イワトミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市七曲', '12', '12212', '2850073', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '七曲', 'ナナマガリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市西御門', '12', '12212', '2850074', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '西御門', 'ニシミカド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市宮内', '12', '12212', '2850075', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '宮内', 'ミヤウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市飯塚', '12', '12212', '2850076', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '飯塚', 'イイヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市内田', '12', '12212', '2850077', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '内田', 'ウチダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市坂戸', '12', '12212', '2850078', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '坂戸', 'サカド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市木野子', '12', '12212', '2850801', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '木野子', 'キノコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市大作', '12', '12212', '2850802', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '大作', 'オオサク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市神門', '12', '12212', '2850803', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '神門', 'ゴウド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市馬渡', '12', '12212', '2850804', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '馬渡', 'マワタシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市小篠塚', '12', '12212', '2850805', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '小篠塚', 'コシノヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市大篠塚', '12', '12212', '2850806', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '大篠塚', 'オオシノヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市山王', '12', '12212', '2850807', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '山王', 'サンノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市太田', '12', '12212', '2850808', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '太田', 'オオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市表町', '12', '12212', '2850811', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '表町', 'オモテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市六崎', '12', '12212', '2850812', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '六崎', 'ムツザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市石川', '12', '12212', '2850813', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '石川', 'イシカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市春路', '12', '12212', '2850814', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '春路', 'ハルジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市城', '12', '12212', '2850815', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '城', 'ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市藤治台', '12', '12212', '2850816', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '藤治台', 'トウジダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市大崎台', '12', '12212', '2850817', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '大崎台', 'オオサキダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市寺崎', '12', '12212', '2850818', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '寺崎', 'テラザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市角来', '12', '12212', '2850821', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '角来', 'カクライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市印南', '12', '12212', '2850822', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '印南', 'インナン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市江原新田', '12', '12212', '2850823', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '江原新田', 'エバラシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市江原', '12', '12212', '2850824', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '江原', 'エバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市江原台', '12', '12212', '2850825', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '江原台', 'エバラダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市染井野', '12', '12212', '2850831', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '染井野', 'ソメイノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市飯重', '12', '12212', '2850832', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '飯重', 'イイジュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市羽鳥', '12', '12212', '2850833', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '羽鳥', 'ハドリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市吉見', '12', '12212', '2850834', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '吉見', 'ヨシミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市畔田', '12', '12212', '2850835', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '畔田', 'アゼタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市生谷', '12', '12212', '2850836', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '生谷', 'オブカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市王子台', '12', '12212', '2850837', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '王子台', 'オウジダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市下志津', '12', '12212', '2850841', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '下志津', 'シモシヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市下志津原', '12', '12212', '2850842', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '下志津原', 'シモシヅハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市中志津', '12', '12212', '2850843', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '中志津', 'ナカシヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市上志津原', '12', '12212', '2850844', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '上志津原', 'カミシヅハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市西志津', '12', '12212', '2850845', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '西志津', 'ニシシヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市上志津', '12', '12212', '2850846', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '上志津', 'カミシヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市先崎', '12', '12212', '2850851', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '先崎', 'マッサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市青菅', '12', '12212', '2850852', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '青菅', 'アオスゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市小竹', '12', '12212', '2850853', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '小竹', 'オダケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市上座', '12', '12212', '2850854', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '上座', 'ジョウザ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市井野', '12', '12212', '2850855', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '井野', 'イノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市井野町', '12', '12212', '2850856', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '井野町', 'イノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市宮ノ台', '12', '12212', '2850857', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '宮ノ台', 'ミヤノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市ユーカリが丘', '12', '12212', '2850858', '千葉県', 'チバケン', '佐倉市', 'サクラシ', 'ユーカリが丘', 'ユーカリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市南ユーカリが丘', '12', '12212', '2850859', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '南ユーカリが丘', 'ミナミユーカリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市臼井田', '12', '12212', '2850861', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '臼井田', 'ウスイタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市新臼井田', '12', '12212', '2850862', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '新臼井田', 'シンウスイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市臼井', '12', '12212', '2850863', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '臼井', 'ウスイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市稲荷台', '12', '12212', '2850864', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '稲荷台', 'イナリダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市南臼井台', '12', '12212', '2850865', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '南臼井台', 'ミナミウスイダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市臼井台', '12', '12212', '2850866', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '臼井台', 'ウスイダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県佐倉市八幡台', '12', '12212', '2850867', '千葉県', 'チバケン', '佐倉市', 'サクラシ', '八幡台', 'ハチマンダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印旛郡酒々井町', '12', '12322', '2850900', '千葉県', 'チバケン', '印旛郡酒々井町', 'インバグンシスイマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('16866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印旛郡酒々井町篠山新田', '12', '12322', '2850901', '千葉県', 'チバケン', '印旛郡酒々井町', 'インバグンシスイマチ', '篠山新田', 'シノヤマシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印旛郡酒々井町伊篠', '12', '12322', '2850902', '千葉県', 'チバケン', '印旛郡酒々井町', 'インバグンシスイマチ', '伊篠', 'イジノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印旛郡酒々井町今倉新田', '12', '12322', '2850903', '千葉県', 'チバケン', '印旛郡酒々井町', 'インバグンシスイマチ', '今倉新田', 'イマクラシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印旛郡酒々井町伊篠新田', '12', '12322', '2850904', '千葉県', 'チバケン', '印旛郡酒々井町', 'インバグンシスイマチ', '伊篠新田', 'イジノシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印旛郡酒々井町上岩橋', '12', '12322', '2850905', '千葉県', 'チバケン', '印旛郡酒々井町', 'インバグンシスイマチ', '上岩橋', 'カミイワハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印旛郡酒々井町柏木', '12', '12322', '2850906', '千葉県', 'チバケン', '印旛郡酒々井町', 'インバグンシスイマチ', '柏木', 'カシワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印旛郡酒々井町下岩橋', '12', '12322', '2850907', '千葉県', 'チバケン', '印旛郡酒々井町', 'インバグンシスイマチ', '下岩橋', 'シモイワハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印旛郡酒々井町尾上', '12', '12322', '2850911', '千葉県', 'チバケン', '印旛郡酒々井町', 'インバグンシスイマチ', '尾上', 'オガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印旛郡酒々井町飯積', '12', '12322', '2850912', '千葉県', 'チバケン', '印旛郡酒々井町', 'インバグンシスイマチ', '飯積', 'イイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印旛郡酒々井町墨', '12', '12322', '2850913', '千葉県', 'チバケン', '印旛郡酒々井町', 'インバグンシスイマチ', '墨', 'スミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印旛郡酒々井町馬橋', '12', '12322', '2850914', '千葉県', 'チバケン', '印旛郡酒々井町', 'インバグンシスイマチ', '馬橋', 'マバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印旛郡酒々井町中川', '12', '12322', '2850921', '千葉県', 'チバケン', '印旛郡酒々井町', 'インバグンシスイマチ', '中川', 'ナカガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印旛郡酒々井町中央台', '12', '12322', '2850922', '千葉県', 'チバケン', '印旛郡酒々井町', 'インバグンシスイマチ', '中央台', 'チュウオウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印旛郡酒々井町東酒々井', '12', '12322', '2850923', '千葉県', 'チバケン', '印旛郡酒々井町', 'インバグンシスイマチ', '東酒々井', 'ヒガシシスイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印旛郡酒々井町下台', '12', '12322', '2850924', '千葉県', 'チバケン', '印旛郡酒々井町', 'インバグンシスイマチ', '下台', 'シモダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印旛郡酒々井町上本佐倉', '12', '12322', '2850925', '千葉県', 'チバケン', '印旛郡酒々井町', 'インバグンシスイマチ', '上本佐倉', 'カミモトサクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印旛郡酒々井町本佐倉', '12', '12322', '2850926', '千葉県', 'チバケン', '印旛郡酒々井町', 'インバグンシスイマチ', '本佐倉', 'モトサクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印旛郡酒々井町酒々井', '12', '12322', '2850927', '千葉県', 'チバケン', '印旛郡酒々井町', 'インバグンシスイマチ', '酒々井', 'シスイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県印旛郡酒々井町ふじき野', '12', '12322', '2850928', '千葉県', 'チバケン', '印旛郡酒々井町', 'インバグンシスイマチ', 'ふじき野', 'フジキノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県岩手郡葛巻町葛巻', '03', '03302', '0285102', '岩手県', 'イワテケン', '岩手郡葛巻町', 'イワテグンクズマキマチ', '葛巻', 'クズマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸郡一戸町宇別', '03', '03524', '0285131', '岩手県', 'イワテケン', '二戸郡一戸町', 'ニノヘグンイチノヘマチ', '宇別', 'ウベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸郡一戸町小繋', '03', '03524', '0285132', '岩手県', 'イワテケン', '二戸郡一戸町', 'ニノヘグンイチノヘマチ', '小繋', 'コツナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸郡一戸町中山', '03', '03524', '0285133', '岩手県', 'イワテケン', '二戸郡一戸町', 'ニノヘグンイチノヘマチ', '中山', 'ナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸郡一戸町奥中山', '03', '03524', '0285134', '岩手県', 'イワテケン', '二戸郡一戸町', 'ニノヘグンイチノヘマチ', '奥中山', 'オクナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸郡一戸町小鳥谷', '03', '03524', '0285221', '岩手県', 'イワテケン', '二戸郡一戸町', 'ニノヘグンイチノヘマチ', '小鳥谷', 'コズヤ', null, null, null, null), ('16891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸郡一戸町姉帯', '03', '03524', '0285222', '岩手県', 'イワテケン', '二戸郡一戸町', 'ニノヘグンイチノヘマチ', '姉帯', 'アネタイ', null, null, null, null), ('16892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸郡一戸町面岸', '03', '03524', '0285223', '岩手県', 'イワテケン', '二戸郡一戸町', 'ニノヘグンイチノヘマチ', '面岸', 'オモギシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸郡一戸町平糠', '03', '03524', '0285224', '岩手県', 'イワテケン', '二戸郡一戸町', 'ニノヘグンイチノヘマチ', '平糠', 'ヒラヌカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸郡一戸町中山', '03', '03524', '0285233', '岩手県', 'イワテケン', '二戸郡一戸町', 'ニノヘグンイチノヘマチ', '中山', 'ナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸郡一戸町', '03', '03524', '0285300', '岩手県', 'イワテケン', '二戸郡一戸町', 'ニノヘグンイチノヘマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('16896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸郡一戸町西法寺', '03', '03524', '0285301', '岩手県', 'イワテケン', '二戸郡一戸町', 'ニノヘグンイチノヘマチ', '西法寺', 'サイホウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸郡一戸町女鹿', '03', '03524', '0285302', '岩手県', 'イワテケン', '二戸郡一戸町', 'ニノヘグンイチノヘマチ', '女鹿', 'メガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸郡一戸町小友', '03', '03524', '0285303', '岩手県', 'イワテケン', '二戸郡一戸町', 'ニノヘグンイチノヘマチ', '小友', 'オトモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸郡一戸町出ル町', '03', '03524', '0285304', '岩手県', 'イワテケン', '二戸郡一戸町', 'ニノヘグンイチノヘマチ', '出ル町', 'イズルマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸郡一戸町月舘', '03', '03524', '0285305', '岩手県', 'イワテケン', '二戸郡一戸町', 'ニノヘグンイチノヘマチ', '月舘', 'ツキダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸郡一戸町中里', '03', '03524', '0285306', '岩手県', 'イワテケン', '二戸郡一戸町', 'ニノヘグンイチノヘマチ', '中里', 'ナカサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸郡一戸町高善寺', '03', '03524', '0285311', '岩手県', 'イワテケン', '二戸郡一戸町', 'ニノヘグンイチノヘマチ', '高善寺', 'コウゼンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸郡一戸町一戸', '03', '03524', '0285312', '岩手県', 'イワテケン', '二戸郡一戸町', 'ニノヘグンイチノヘマチ', '一戸', 'イチノヘ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸郡一戸町鳥越', '03', '03524', '0285313', '岩手県', 'イワテケン', '二戸郡一戸町', 'ニノヘグンイチノヘマチ', '鳥越', 'トリゴエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸郡一戸町楢山', '03', '03524', '0285314', '岩手県', 'イワテケン', '二戸郡一戸町', 'ニノヘグンイチノヘマチ', '楢山', 'ナラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸郡一戸町根反', '03', '03524', '0285315', '岩手県', 'イワテケン', '二戸郡一戸町', 'ニノヘグンイチノヘマチ', '根反', 'ネソリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸郡一戸町岩舘', '03', '03524', '0285316', '岩手県', 'イワテケン', '二戸郡一戸町', 'ニノヘグンイチノヘマチ', '岩舘', 'イワダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県岩手郡葛巻町', '03', '03302', '0285400', '岩手県', 'イワテケン', '岩手郡葛巻町', 'イワテグンクズマキマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('16909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県岩手郡葛巻町田部', '03', '03302', '0285401', '岩手県', 'イワテケン', '岩手郡葛巻町', 'イワテグンクズマキマチ', '田部', 'タベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県岩手郡葛巻町葛巻', '03', '03302', '0285402', '岩手県', 'イワテケン', '岩手郡葛巻町', 'イワテグンクズマキマチ', '葛巻', 'クズマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県岩手郡葛巻町江刈', '03', '03302', '0285403', '岩手県', 'イワテケン', '岩手郡葛巻町', 'イワテグンクズマキマチ', '江刈', 'エカリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡岩泉町釜津田上栗宿', '03', '03483', '0285633', '岩手県', 'イワテケン', '下閉伊郡岩泉町', 'シモヘイグンイワイズミチョウ', '釜津田', 'カマツタ', null, null, '上栗宿', 'カミクリヤド');
INSERT INTO `ms_addresses` VALUES ('16914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡岩泉町釜津田栗宿', '03', '03483', '0285633', '岩手県', 'イワテケン', '下閉伊郡岩泉町', 'シモヘイグンイワイズミチョウ', '釜津田', 'カマツタ', null, null, '栗宿', 'クリヤド');
INSERT INTO `ms_addresses` VALUES ('16915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡岩泉町釜津田権現', '03', '03483', '0285633', '岩手県', 'イワテケン', '下閉伊郡岩泉町', 'シモヘイグンイワイズミチョウ', '釜津田', 'カマツタ', null, null, '権現', 'ゴンゲン');
INSERT INTO `ms_addresses` VALUES ('16916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡岩泉町門', '03', '03483', '0285641', '岩手県', 'イワテケン', '下閉伊郡岩泉町', 'シモヘイグンイワイズミチョウ', '門', 'カド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡岩泉町穴沢', '03', '03483', '0285642', '岩手県', 'イワテケン', '下閉伊郡岩泉町', 'シモヘイグンイワイズミチョウ', '穴沢', 'アナザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡岩泉町袰綿', '03', '03483', '0285643', '岩手県', 'イワテケン', '下閉伊郡岩泉町', 'シモヘイグンイワイズミチョウ', '袰綿', 'ホロワタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市下斗米外芹沢', '03', '03213', '0285702', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '下斗米', 'シモトマイ', null, null, '外芹沢', 'ソトセリサワ');
INSERT INTO `ms_addresses` VALUES ('16920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市下斗米月折', '03', '03213', '0285702', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '下斗米', 'シモトマイ', null, null, '月折', 'ツキオリ');
INSERT INTO `ms_addresses` VALUES ('16921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市下斗米土橋', '03', '03213', '0285702', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '下斗米', 'シモトマイ', null, null, '土橋', 'ツチバシ');
INSERT INTO `ms_addresses` VALUES ('16922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市金田一', '03', '03213', '0285711', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '金田一', 'キンタイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市野々上', '03', '03213', '0285712', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '野々上', 'ノノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市釜沢', '03', '03213', '0285713', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '釜沢', 'カマザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市', '12', '12211', '2860000', '千葉県', 'チバケン', '成田市', 'ナリタシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('16942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市船形', '12', '12211', '2860001', '千葉県', 'チバケン', '成田市', 'ナリタシ', '船形', 'フナカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市八代', '12', '12211', '2860002', '千葉県', 'チバケン', '成田市', 'ナリタシ', '八代', 'ヤツシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市台方', '12', '12211', '2860003', '千葉県', 'チバケン', '成田市', 'ナリタシ', '台方', 'ダイカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市宗吾', '12', '12211', '2860004', '千葉県', 'チバケン', '成田市', 'ナリタシ', '宗吾', 'ソウゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市下方', '12', '12211', '2860005', '千葉県', 'チバケン', '成田市', 'ナリタシ', '下方', 'シタカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市北須賀', '12', '12211', '2860006', '千葉県', 'チバケン', '成田市', 'ナリタシ', '北須賀', 'キタスカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市玉造', '12', '12211', '2860011', '千葉県', 'チバケン', '成田市', 'ナリタシ', '玉造', 'タマツクリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市山口', '12', '12211', '2860012', '千葉県', 'チバケン', '成田市', 'ナリタシ', '山口', 'ヤマグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市美郷台', '12', '12211', '2860013', '千葉県', 'チバケン', '成田市', 'ナリタシ', '美郷台', 'ミサトダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市郷部', '12', '12211', '2860014', '千葉県', 'チバケン', '成田市', 'ナリタシ', '郷部', 'ゴウブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市中台', '12', '12211', '2860015', '千葉県', 'チバケン', '成田市', 'ナリタシ', '中台', 'ナカダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市米野', '12', '12211', '2860016', '千葉県', 'チバケン', '成田市', 'ナリタシ', '米野', 'ヨネノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市赤坂', '12', '12211', '2860017', '千葉県', 'チバケン', '成田市', 'ナリタシ', '赤坂', 'アカサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市吾妻', '12', '12211', '2860018', '千葉県', 'チバケン', '成田市', 'ナリタシ', '吾妻', 'アヅマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市土屋', '12', '12211', '2860021', '千葉県', 'チバケン', '成田市', 'ナリタシ', '土屋', 'ツチヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市寺台', '12', '12211', '2860022', '千葉県', 'チバケン', '成田市', 'ナリタシ', '寺台', 'テラダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市成田', '12', '12211', '2860023', '千葉県', 'チバケン', '成田市', 'ナリタシ', '成田', 'ナリタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市田町', '12', '12211', '2860024', '千葉県', 'チバケン', '成田市', 'ナリタシ', '田町', 'タマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市東町', '12', '12211', '2860025', '千葉県', 'チバケン', '成田市', 'ナリタシ', '東町', 'アズマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市本町', '12', '12211', '2860026', '千葉県', 'チバケン', '成田市', 'ナリタシ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市仲町', '12', '12211', '2860027', '千葉県', 'チバケン', '成田市', 'ナリタシ', '仲町', 'ナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市幸町', '12', '12211', '2860028', '千葉県', 'チバケン', '成田市', 'ナリタシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市ウイング土屋', '12', '12211', '2860029', '千葉県', 'チバケン', '成田市', 'ナリタシ', 'ウイング土屋', 'ウイングツチヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市新町', '12', '12211', '2860031', '千葉県', 'チバケン', '成田市', 'ナリタシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市上町', '12', '12211', '2860032', '千葉県', 'チバケン', '成田市', 'ナリタシ', '上町', 'カミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市花崎町', '12', '12211', '2860033', '千葉県', 'チバケン', '成田市', 'ナリタシ', '花崎町', 'ハナザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市馬橋', '12', '12211', '2860034', '千葉県', 'チバケン', '成田市', 'ナリタシ', '馬橋', 'マバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市囲護台', '12', '12211', '2860035', '千葉県', 'チバケン', '成田市', 'ナリタシ', '囲護台', 'イゴダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市加良部', '12', '12211', '2860036', '千葉県', 'チバケン', '成田市', 'ナリタシ', '加良部', 'カラベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市橋賀台', '12', '12211', '2860037', '千葉県', 'チバケン', '成田市', 'ナリタシ', '橋賀台', 'ハシカダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市飯田町', '12', '12211', '2860041', '千葉県', 'チバケン', '成田市', 'ナリタシ', '飯田町', 'イイダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市南平台', '12', '12211', '2860042', '千葉県', 'チバケン', '成田市', 'ナリタシ', '南平台', 'ナンペイダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市大袋', '12', '12211', '2860043', '千葉県', 'チバケン', '成田市', 'ナリタシ', '大袋', 'オオブクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市不動ケ岡', '12', '12211', '2860044', '千葉県', 'チバケン', '成田市', 'ナリタシ', '不動ケ岡', 'フドウガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市並木町', '12', '12211', '2860045', '千葉県', 'チバケン', '成田市', 'ナリタシ', '並木町', 'ナミキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市飯仲', '12', '12211', '2860046', '千葉県', 'チバケン', '成田市', 'ナリタシ', '飯仲', 'イイナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市江弁須', '12', '12211', '2860047', '千葉県', 'チバケン', '成田市', 'ナリタシ', '江弁須', 'エベス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市公津の杜', '12', '12211', '2860048', '千葉県', 'チバケン', '成田市', 'ナリタシ', '公津の杜', 'コウヅノモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市十余三', '12', '12211', '2860101', '千葉県', 'チバケン', '成田市', 'ナリタシ', '十余三', 'トヨミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市天神峰', '12', '12211', '2860102', '千葉県', 'チバケン', '成田市', 'ナリタシ', '天神峰', 'テンジンミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市東峰', '12', '12211', '2860103', '千葉県', 'チバケン', '成田市', 'ナリタシ', '東峰', 'トウホウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市古込', '12', '12211', '2860104', '千葉県', 'チバケン', '成田市', 'ナリタシ', '古込', 'フルゴメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市木の根', '12', '12211', '2860105', '千葉県', 'チバケン', '成田市', 'ナリタシ', '木の根', 'キノネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市取香', '12', '12211', '2860106', '千葉県', 'チバケン', '成田市', 'ナリタシ', '取香', 'トッコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市堀之内', '12', '12211', '2860107', '千葉県', 'チバケン', '成田市', 'ナリタシ', '堀之内', 'ホリノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市長田', '12', '12211', '2860108', '千葉県', 'チバケン', '成田市', 'ナリタシ', '長田', 'ナガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市三里塚', '12', '12211', '2860111', '千葉県', 'チバケン', '成田市', 'ナリタシ', '三里塚', 'サンリヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市東三里塚', '12', '12211', '2860112', '千葉県', 'チバケン', '成田市', 'ナリタシ', '東三里塚', 'ヒガシサンリヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市南三里塚', '12', '12211', '2860113', '千葉県', 'チバケン', '成田市', 'ナリタシ', '南三里塚', 'ミナミサンリヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市本城', '12', '12211', '2860114', '千葉県', 'チバケン', '成田市', 'ナリタシ', '本城', 'ホンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市西三里塚', '12', '12211', '2860115', '千葉県', 'チバケン', '成田市', 'ナリタシ', '西三里塚', 'ニシサンリヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市三里塚御料', '12', '12211', '2860116', '千葉県', 'チバケン', '成田市', 'ナリタシ', '三里塚御料', 'サンリヅカゴリョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市三里塚光ケ丘', '12', '12211', '2860117', '千葉県', 'チバケン', '成田市', 'ナリタシ', '三里塚光ケ丘', 'サンリヅカヒカリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市本三里塚', '12', '12211', '2860118', '千葉県', 'チバケン', '成田市', 'ナリタシ', '本三里塚', 'ホンサンリヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市駒井野', '12', '12211', '2860121', '千葉県', 'チバケン', '成田市', 'ナリタシ', '駒井野', 'コマイノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市大清水', '12', '12211', '2860122', '千葉県', 'チバケン', '成田市', 'ナリタシ', '大清水', 'オオシミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市新駒井野', '12', '12211', '2860123', '千葉県', 'チバケン', '成田市', 'ナリタシ', '新駒井野', 'シンコマイノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('16999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市畑ケ田', '12', '12211', '2860124', '千葉県', 'チバケン', '成田市', 'ナリタシ', '畑ケ田', 'ハタケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市川栗', '12', '12211', '2860125', '千葉県', 'チバケン', '成田市', 'ナリタシ', '川栗', 'カワグリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市久米野', '12', '12211', '2860126', '千葉県', 'チバケン', '成田市', 'ナリタシ', '久米野', 'クメノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市小菅', '12', '12211', '2860127', '千葉県', 'チバケン', '成田市', 'ナリタシ', '小菅', 'コスゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市大山', '12', '12211', '2860131', '千葉県', 'チバケン', '成田市', 'ナリタシ', '大山', 'オオヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市馬場', '12', '12211', '2860132', '千葉県', 'チバケン', '成田市', 'ナリタシ', '馬場', 'ババ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市吉倉', '12', '12211', '2860133', '千葉県', 'チバケン', '成田市', 'ナリタシ', '吉倉', 'ヨシクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市東和田', '12', '12211', '2860134', '千葉県', 'チバケン', '成田市', 'ナリタシ', '東和田', 'トウワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市山之作', '12', '12211', '2860135', '千葉県', 'チバケン', '成田市', 'ナリタシ', '山之作', 'ヤマノサク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市久米', '12', '12211', '2860136', '千葉県', 'チバケン', '成田市', 'ナリタシ', '久米', 'クメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市御所の内', '12', '12211', '2860137', '千葉県', 'チバケン', '成田市', 'ナリタシ', '御所の内', 'ゴショノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県富里市', '12', '12233', '2860200', '千葉県', 'チバケン', '富里市', 'トミサトシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('17011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県富里市日吉台', '12', '12233', '2860201', '千葉県', 'チバケン', '富里市', 'トミサトシ', '日吉台', 'ヒヨシダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県富里市日吉倉', '12', '12233', '2860202', '千葉県', 'チバケン', '富里市', 'トミサトシ', '日吉倉', 'ヒヨシクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県富里市久能', '12', '12233', '2860203', '千葉県', 'チバケン', '富里市', 'トミサトシ', '久能', 'クノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県富里市大和', '12', '12233', '2860204', '千葉県', 'チバケン', '富里市', 'トミサトシ', '大和', 'オオワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県富里市根木名', '12', '12233', '2860205', '千葉県', 'チバケン', '富里市', 'トミサトシ', '根木名', 'ネコナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県富里市御料', '12', '12233', '2860211', '千葉県', 'チバケン', '富里市', 'トミサトシ', '御料', 'ゴリョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県富里市十倉', '12', '12233', '2860212', '千葉県', 'チバケン', '富里市', 'トミサトシ', '十倉', 'トクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県富里市高松', '12', '12233', '2860213', '千葉県', 'チバケン', '富里市', 'トミサトシ', '高松', 'タカマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県富里市立沢', '12', '12233', '2860214', '千葉県', 'チバケン', '富里市', 'トミサトシ', '立沢', 'タツザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県富里市立沢新田', '12', '12233', '2860215', '千葉県', 'チバケン', '富里市', 'トミサトシ', '立沢新田', 'タツザワシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県富里市高野', '12', '12233', '2860216', '千葉県', 'チバケン', '富里市', 'トミサトシ', '高野', 'コウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県富里市七栄', '12', '12233', '2860221', '千葉県', 'チバケン', '富里市', 'トミサトシ', '七栄', 'ナナエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県富里市中沢', '12', '12233', '2860222', '千葉県', 'チバケン', '富里市', 'トミサトシ', '中沢', 'ナカザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県富里市新中沢', '12', '12233', '2860223', '千葉県', 'チバケン', '富里市', 'トミサトシ', '新中沢', 'シンナカザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県富里市新橋', '12', '12233', '2860224', '千葉県', 'チバケン', '富里市', 'トミサトシ', '新橋', 'ニッパシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県富里市美沢', '12', '12233', '2860225', '千葉県', 'チバケン', '富里市', 'トミサトシ', '美沢', 'ミサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市竜台', '12', '12211', '2860801', '千葉県', 'チバケン', '成田市', 'ナリタシ', '竜台', 'タツダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市北部', '12', '12211', '2860802', '千葉県', 'チバケン', '成田市', 'ナリタシ', '北部', 'ホクブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市安西', '12', '12211', '2860803', '千葉県', 'チバケン', '成田市', 'ナリタシ', '安西', 'アンサイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市長沼', '12', '12211', '2860804', '千葉県', 'チバケン', '成田市', 'ナリタシ', '長沼', 'ナガヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市南羽鳥', '12', '12211', '2860805', '千葉県', 'チバケン', '成田市', 'ナリタシ', '南羽鳥', 'ミナミハドリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市南部', '12', '12211', '2860806', '千葉県', 'チバケン', '成田市', 'ナリタシ', '南部', 'ナンブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市北羽鳥', '12', '12211', '2860807', '千葉県', 'チバケン', '成田市', 'ナリタシ', '北羽鳥', 'キタハドリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市佐野', '12', '12211', '2860808', '千葉県', 'チバケン', '成田市', 'ナリタシ', '佐野', 'サノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市磯部', '12', '12211', '2860811', '千葉県', 'チバケン', '成田市', 'ナリタシ', '磯部', 'イソベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市水掛', '12', '12211', '2860812', '千葉県', 'チバケン', '成田市', 'ナリタシ', '水掛', 'ミズカケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市飯岡', '12', '12211', '2860813', '千葉県', 'チバケン', '成田市', 'ナリタシ', '飯岡', 'イノオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市幡谷', '12', '12211', '2860814', '千葉県', 'チバケン', '成田市', 'ナリタシ', '幡谷', 'ハタヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市土室', '12', '12211', '2860815', '千葉県', 'チバケン', '成田市', 'ナリタシ', '土室', 'ツチムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市成毛', '12', '12211', '2860816', '千葉県', 'チバケン', '成田市', 'ナリタシ', '成毛', 'ナルゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市大生', '12', '12211', '2860817', '千葉県', 'チバケン', '成田市', 'ナリタシ', '大生', 'オオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市荒海', '12', '12211', '2860818', '千葉県', 'チバケン', '成田市', 'ナリタシ', '荒海', 'アラウミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市大室', '12', '12211', '2860821', '千葉県', 'チバケン', '成田市', 'ナリタシ', '大室', 'オオムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市芝', '12', '12211', '2860822', '千葉県', 'チバケン', '成田市', 'ナリタシ', '芝', 'シバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市小泉', '12', '12211', '2860823', '千葉県', 'チバケン', '成田市', 'ナリタシ', '小泉', 'コイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市野毛平', '12', '12211', '2860824', '千葉県', 'チバケン', '成田市', 'ナリタシ', '野毛平', 'ノゲダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市新泉', '12', '12211', '2860825', '千葉県', 'チバケン', '成田市', 'ナリタシ', '新泉', 'シンイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市東和泉', '12', '12211', '2860826', '千葉県', 'チバケン', '成田市', 'ナリタシ', '東和泉', 'ヒガシイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市西和泉', '12', '12211', '2860827', '千葉県', 'チバケン', '成田市', 'ナリタシ', '西和泉', 'ニシイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市芦田', '12', '12211', '2860831', '千葉県', 'チバケン', '成田市', 'ナリタシ', '芦田', 'アシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市赤荻', '12', '12211', '2860832', '千葉県', 'チバケン', '成田市', 'ナリタシ', '赤荻', 'アカオギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市東金山', '12', '12211', '2860833', '千葉県', 'チバケン', '成田市', 'ナリタシ', '東金山', 'ヒガシカナヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市和田', '12', '12211', '2860834', '千葉県', 'チバケン', '成田市', 'ナリタシ', '和田', 'ワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市関戸', '12', '12211', '2860835', '千葉県', 'チバケン', '成田市', 'ナリタシ', '関戸', 'セキド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市下金山', '12', '12211', '2860836', '千葉県', 'チバケン', '成田市', 'ナリタシ', '下金山', 'シモカナヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市新妻', '12', '12211', '2860837', '千葉県', 'チバケン', '成田市', 'ナリタシ', '新妻', 'ニッツマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市大竹', '12', '12211', '2860841', '千葉県', 'チバケン', '成田市', 'ナリタシ', '大竹', 'オオダケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市上福田', '12', '12211', '2860842', '千葉県', 'チバケン', '成田市', 'ナリタシ', '上福田', 'カミフクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市下福田', '12', '12211', '2860843', '千葉県', 'チバケン', '成田市', 'ナリタシ', '下福田', 'シモフクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市宝田', '12', '12211', '2860844', '千葉県', 'チバケン', '成田市', 'ナリタシ', '宝田', 'タカラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市押畑', '12', '12211', '2860845', '千葉県', 'チバケン', '成田市', 'ナリタシ', '押畑', 'オシハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市松崎', '12', '12211', '2860846', '千葉県', 'チバケン', '成田市', 'ナリタシ', '松崎', 'マンザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市', '03', '03213', '0286100', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('17067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市福岡', '03', '03213', '0286101', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '福岡', 'フクオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市下斗米', '03', '03213', '0286102', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '下斗米', 'シモトマイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市石切所', '03', '03213', '0286103', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '石切所', 'イシキリドコロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市米沢', '03', '03213', '0286104', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '米沢', 'マイサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市堀野', '03', '03213', '0286105', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '堀野', 'ホリノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市仁左平', '03', '03213', '0286106', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '仁左平', 'ニサタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市白鳥', '03', '03213', '0286107', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '白鳥', 'シラトリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市上斗米', '03', '03213', '0286108', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '上斗米', 'カミトマイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡軽米町晴山', '03', '03501', '0286221', '岩手県', 'イワテケン', '九戸郡軽米町', 'クノヘグンカルマイマチ', '晴山', 'ハレヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡軽米町山内', '03', '03501', '0286222', '岩手県', 'イワテケン', '九戸郡軽米町', 'クノヘグンカルマイマチ', '山内', 'サンナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡軽米町狄塚', '03', '03501', '0286223', '岩手県', 'イワテケン', '九戸郡軽米町', 'クノヘグンカルマイマチ', '狄塚', 'エヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡軽米町', '03', '03501', '0286300', '岩手県', 'イワテケン', '九戸郡軽米町', 'クノヘグンカルマイマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('17084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡軽米町上舘', '03', '03501', '0286301', '岩手県', 'イワテケン', '九戸郡軽米町', 'クノヘグンカルマイマチ', '上舘', 'カミダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡軽米町軽米', '03', '03501', '0286302', '岩手県', 'イワテケン', '九戸郡軽米町', 'クノヘグンカルマイマチ', '軽米', 'カルマイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡軽米町高家', '03', '03501', '0286303', '岩手県', 'イワテケン', '九戸郡軽米町', 'クノヘグンカルマイマチ', '高家', 'コウケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡軽米町長倉', '03', '03501', '0286304', '岩手県', 'イワテケン', '九戸郡軽米町', 'クノヘグンカルマイマチ', '長倉', 'ナガクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡軽米町小軽米', '03', '03501', '0286411', '岩手県', 'イワテケン', '九戸郡軽米町', 'クノヘグンカルマイマチ', '小軽米', 'コカルマイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡軽米町蛇口', '03', '03501', '0286412', '岩手県', 'イワテケン', '九戸郡軽米町', 'クノヘグンカルマイマチ', '蛇口', 'ヘビクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡軽米町円子', '03', '03501', '0286413', '岩手県', 'イワテケン', '九戸郡軽米町', 'クノヘグンカルマイマチ', '円子', 'マルコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡九戸村', '03', '03506', '0286500', '岩手県', 'イワテケン', '九戸郡九戸村', 'クノヘグンクノヘムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('17092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡九戸村荒谷', '03', '03506', '0286501', '岩手県', 'イワテケン', '九戸郡九戸村', 'クノヘグンクノヘムラ', '荒谷', 'アラヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡九戸村伊保内', '03', '03506', '0286502', '岩手県', 'イワテケン', '九戸郡九戸村', 'クノヘグンクノヘムラ', '伊保内', 'イボナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡九戸村小倉', '03', '03506', '0286503', '岩手県', 'イワテケン', '九戸郡九戸村', 'クノヘグンクノヘムラ', '小倉', 'コグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡九戸村長興寺', '03', '03506', '0286504', '岩手県', 'イワテケン', '九戸郡九戸村', 'クノヘグンクノヘムラ', '長興寺', 'チョウコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡九戸村江刺家', '03', '03506', '0286505', '岩手県', 'イワテケン', '九戸郡九戸村', 'クノヘグンクノヘムラ', '江刺家', 'エサシカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡九戸村山屋', '03', '03506', '0286506', '岩手県', 'イワテケン', '九戸郡九戸村', 'クノヘグンクノヘムラ', '山屋', 'ヤマヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡九戸村雪屋', '03', '03506', '0286507', '岩手県', 'イワテケン', '九戸郡九戸村', 'クノヘグンクノヘムラ', '雪屋', 'ユキヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡九戸村山根', '03', '03506', '0286611', '岩手県', 'イワテケン', '九戸郡九戸村', 'クノヘグンクノヘムラ', '山根', 'サンネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡九戸村戸田', '03', '03506', '0286612', '岩手県', 'イワテケン', '九戸郡九戸村', 'クノヘグンクノヘムラ', '戸田', 'トダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市似鳥', '03', '03213', '0286721', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '似鳥', 'ニタドリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市福田', '03', '03213', '0286722', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '福田', 'フクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市安比', '03', '03213', '0286723', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '安比', 'アッピ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市足沢', '03', '03213', '0286724', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '足沢', 'タルサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町手倉森', '03', '03213', '0286811', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町手倉森', 'ジョウボウジマチテグラモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町下沢', '03', '03213', '0286812', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町下沢', 'ジョウボウジマチシモサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町大平', '03', '03213', '0286813', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町大平', 'ジョウボウジマチオオダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町北村', '03', '03213', '0286814', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町北村', 'ジョウボウジマチキタムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町八方口', '03', '03213', '0286815', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町八方口', 'ジョウボウジマチハッポウグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町上谷地', '03', '03213', '0286816', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町上谷地', 'ジョウボウジマチカミヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町漆沢大久保', '03', '03213', '0286817', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町漆沢大久保', 'ジョウボウジマチウルシザワオオクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町鏡田', '03', '03213', '0286818', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町鏡田', 'ジョウボウジマチカガミタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町馬洗場', '03', '03213', '0286819', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町馬洗場', 'ジョウボウジマチウマアライバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町小平', '03', '03213', '0286821', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町小平', 'ジョウボウジマチコダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町漆沢舘', '03', '03213', '0286822', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町漆沢舘', 'ジョウボウジマチウルシザワタテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町宮沢', '03', '03213', '0286823', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町宮沢', 'ジョウボウジマチミヤザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町西ノ沢', '03', '03213', '0286824', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町西ノ沢', 'ジョウボウジマチニシノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町長坂', '03', '03213', '0286825', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町長坂', 'ジョウボウジマチナガサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町川又', '03', '03213', '0286826', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町川又', 'ジョウボウジマチカワマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町漆沢下平', '03', '03213', '0286831', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町漆沢下平', 'ジョウボウジマチウルシザワシモタイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町漆沢上平', '03', '03213', '0286832', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町漆沢上平', 'ジョウボウジマチウルシザワカミタイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町漆沢', '03', '03213', '0286833', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町漆沢', 'ジョウボウジマチウルシザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町細田', '03', '03213', '0286834', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町細田', 'ジョウボウジマチホソダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町漆沢下モ前田', '03', '03213', '0286835', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町漆沢下モ前田', 'ジョウボウジマチウルシザワシモマエタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町関田', '03', '03213', '0286836', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町関田', 'ジョウボウジマチセキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町荒屋敷', '03', '03213', '0286837', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町荒屋敷', 'ジョウボウジマチアラヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町向田', '03', '03213', '0286838', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町向田', 'ジョウボウジマチムカイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町松岡', '03', '03213', '0286841', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町松岡', 'ジョウボウジマチマツオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町漆沢中前田', '03', '03213', '0286842', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町漆沢中前田', 'ジョウボウジマチウルシザワナカマエタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町堤口', '03', '03213', '0286843', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町堤口', 'ジョウボウジマチツツミグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町岡本前田', '03', '03213', '0286844', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町岡本前田', 'ジョウボウジマチオカモトマエタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町漆沢上前田', '03', '03213', '0286845', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町漆沢上前田', 'ジョウボウジマチウルシザワカミマエタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町下タ前田', '03', '03213', '0286846', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町下タ前田', 'ジョウボウジマチシタマエタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町岩渕', '03', '03213', '0286847', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町岩渕', 'ジョウボウジマチイワブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町ウト坂', '03', '03213', '0286848', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町ウト坂', 'ジョウボウジマチウトザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町岡本', '03', '03213', '0286849', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町岡本', 'ジョウボウジマチオカモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町小池', '03', '03213', '0286851', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町小池', 'ジョウボウジマチコイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町樋田', '03', '03213', '0286852', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町樋田', 'ジョウボウジマチトイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町サイカツ田', '03', '03213', '0286853', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町サイカツ田', 'ジョウボウジマチサイカツタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町下前田', '03', '03213', '0286854', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町下前田', 'ジョウボウジマチシモマエタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町浄法寺', '03', '03213', '0286855', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町浄法寺', 'ジョウボウジマチジョウホウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町上外野', '03', '03213', '0286856', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町上外野', 'ジョウボウジマチカミソトノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町合名沢', '03', '03213', '0286857', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町合名沢', 'ジョウボウジマチアイナザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町上野', '03', '03213', '0286861', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町上野', 'ジョウボウジマチウワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町寺ノ上', '03', '03213', '0286862', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町寺ノ上', 'ジョウボウジマチテラノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町八幡舘', '03', '03213', '0286863', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町八幡舘', 'ジョウボウジマチハチマンダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町門前向', '03', '03213', '0286864', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町門前向', 'ジョウボウジマチモンゼンムカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町野田', '03', '03213', '0286865', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町野田', 'ジョウボウジマチノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町飯近', '03', '03213', '0286866', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町飯近', 'ジョウボウジマチイイヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町焼場', '03', '03213', '0286867', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町焼場', 'ジョウボウジマチヤキバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町長者花', '03', '03213', '0286868', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町長者花', 'ジョウボウジマチチョウジャバナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町安戸', '03', '03213', '0286871', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町安戸', 'ジョウボウジマチヤスド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町里川目', '03', '03213', '0286872', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町里川目', 'ジョウボウジマチサトカワメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町大志田', '03', '03213', '0286873', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町大志田', 'ジョウボウジマチオオシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町一反田', '03', '03213', '0286874', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町一反田', 'ジョウボウジマチイツタンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町舘', '03', '03213', '0286875', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町舘', 'ジョウボウジマチタテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町田子内沢', '03', '03213', '0286876', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町田子内沢', 'ジョウボウジマチタコナイザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町伊崎沢', '03', '03213', '0286877', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町伊崎沢', 'ジョウボウジマチイサキザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町漆原', '03', '03213', '0286878', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町漆原', 'ジョウボウジマチウルシバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町梅ノ木', '03', '03213', '0286879', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町梅ノ木', 'ジョウボウジマチウメノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町渡ノ羽', '03', '03213', '0286881', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町渡ノ羽', 'ジョウボウジマチワタノハ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町羽余内', '03', '03213', '0286882', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町羽余内', 'ジョウボウジマチハヨナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町荒谷', '03', '03213', '0286883', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町荒谷', 'ジョウボウジマチアラヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町新山', '03', '03213', '0286884', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町新山', 'ジョウボウジマチシンザン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町森越', '03', '03213', '0286885', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町森越', 'ジョウボウジマチモリコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町深堀', '03', '03213', '0286901', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町深堀', 'ジョウボウジマチフカボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町明神沢', '03', '03213', '0286902', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町明神沢', 'ジョウボウジマチミョウジンザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町坂本', '03', '03213', '0286903', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町坂本', 'ジョウボウジマチサカモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町里代', '03', '03213', '0286904', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町里代', 'ジョウボウジマチサトシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町空久保', '03', '03213', '0286905', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町空久保', 'ジョウボウジマチソラクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町上杉沢', '03', '03213', '0286906', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町上杉沢', 'ジョウボウジマチカミスギサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町季ケ平', '03', '03213', '0286907', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町季ケ平', 'ジョウボウジマチシモガタイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町野黒沢', '03', '03213', '0286908', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町野黒沢', 'ジョウボウジマチノグロサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町上前田', '03', '03213', '0286911', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町上前田', 'ジョウボウジマチカミマエタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町中前田', '03', '03213', '0286912', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町中前田', 'ジョウボウジマチナカマエタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町下ノ沢', '03', '03213', '0286913', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町下ノ沢', 'ジョウボウジマチシモノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町和泉田', '03', '03213', '0286914', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町和泉田', 'ジョウボウジマチワイズミタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町霜屋敷', '03', '03213', '0286915', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町霜屋敷', 'ジョウボウジマチシモヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町大清水下モ平', '03', '03213', '0286916', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町大清水下モ平', 'ジョウボウジマチオオシミズシモタイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町大清水前田', '03', '03213', '0286917', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町大清水前田', 'ジョウボウジマチオオシミズマエタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町サイカツ平', '03', '03213', '0286918', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町サイカツ平', 'ジョウボウジマチサイカツタイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町大清水荒屋', '03', '03213', '0286919', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町大清水荒屋', 'ジョウボウジマチオオシミズアラヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町小泉', '03', '03213', '0286921', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町小泉', 'ジョウボウジマチコイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町下谷地', '03', '03213', '0286922', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町下谷地', 'ジョウボウジマチシモヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町下村', '03', '03213', '0286923', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町下村', 'ジョウボウジマチシタムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町家ノ上', '03', '03213', '0286924', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町家ノ上', 'ジョウボウジマチイエノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町梅田', '03', '03213', '0286925', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町梅田', 'ジョウボウジマチバイタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町門崎', '03', '03213', '0286926', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町門崎', 'ジョウボウジマチカンザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町湯沢', '03', '03213', '0286927', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町湯沢', 'ジョウボウジマチユザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町山内', '03', '03213', '0286928', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町山内', 'ジョウボウジマチサンナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町大清水空久保', '03', '03213', '0286929', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町大清水空久保', 'ジョウボウジマチオオシミズソラクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町尻平', '03', '03213', '0286931', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町尻平', 'ジョウボウジマチシツペイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町松畑', '03', '03213', '0286932', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町松畑', 'ジョウボウジマチマツハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町御山上野', '03', '03213', '0286933', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町御山上野', 'ジョウボウジマチオンヤマウワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町沢田', '03', '03213', '0286934', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町沢田', 'ジョウボウジマチサワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町御山下前田', '03', '03213', '0286935', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町御山下前田', 'ジョウボウジマチオンヤマシモマエタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町長渡路', '03', '03213', '0286936', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町長渡路', 'ジョウボウジマチナガドロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町大畑', '03', '03213', '0286937', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町大畑', 'ジョウボウジマチオオハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町御山上平', '03', '03213', '0286938', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町御山上平', 'ジョウボウジマチオンヤマウワダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町長流部', '03', '03213', '0286939', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町長流部', 'ジョウボウジマチオサルベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町御山中前田', '03', '03213', '0286941', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町御山中前田', 'ジョウボウジマチオンヤマナカマエタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町御山久保', '03', '03213', '0286942', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町御山久保', 'ジョウボウジマチオヤマクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町後久保', '03', '03213', '0286943', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町後久保', 'ジョウボウジマチウシロクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町飛鳥', '03', '03213', '0286944', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町飛鳥', 'ジョウボウジマチアスカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町飛鳥谷地', '03', '03213', '0286945', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町飛鳥谷地', 'ジョウボウジマチアスカヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町安比内', '03', '03213', '0286946', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町安比内', 'ジョウボウジマチアッピナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町安比内沢', '03', '03213', '0286947', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町安比内沢', 'ジョウボウジマチアッピナイザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町御山舘', '03', '03213', '0286948', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町御山舘', 'ジョウボウジマチオンヤマタテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町御山前田', '03', '03213', '0286949', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町御山前田', 'ジョウボウジマチオンヤママエタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町清水尻', '03', '03213', '0286951', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町清水尻', 'ジョウボウジマチシミズジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町御山大久保', '03', '03213', '0286952', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町御山大久保', 'ジョウボウジマチオンヤマオオクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町木沢畑向', '03', '03213', '0286953', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町木沢畑向', 'ジョウボウジマチキサワバタムカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町早坂', '03', '03213', '0286954', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町早坂', 'ジョウボウジマチハヤサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町桂平', '03', '03213', '0286955', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町桂平', 'ジョウボウジマチカツラダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町大坊', '03', '03213', '0286956', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町大坊', 'ジョウボウジマチダイボウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町海上田', '03', '03213', '0286957', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町海上田', 'ジョウボウジマチカイショウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町大手', '03', '03213', '0286958', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町大手', 'ジョウボウジマチオオテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町滝見橋', '03', '03213', '0286961', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町滝見橋', 'ジョウボウジマチタキミバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町馬場向', '03', '03213', '0286962', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町馬場向', 'ジョウボウジマチババムカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町小又', '03', '03213', '0286963', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町小又', 'ジョウボウジマチコマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町沼久保', '03', '03213', '0286964', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町沼久保', 'ジョウボウジマチヌマクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町谷地屋敷', '03', '03213', '0286965', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町谷地屋敷', 'ジョウボウジマチヤチヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町海上', '03', '03213', '0286966', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町海上', 'ジョウボウジマチカイショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町惣川原田', '03', '03213', '0286967', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町惣川原田', 'ジョウボウジマチソウガワラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町海上前田', '03', '03213', '0286968', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町海上前田', 'ジョウボウジマチカイショウマエタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町端保口', '03', '03213', '0286969', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町端保口', 'ジョウボウジマチハホグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町向川原', '03', '03213', '0286971', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町向川原', 'ジョウボウジマチムカイガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町桜田', '03', '03213', '0286972', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町桜田', 'ジョウボウジマチサクラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町駒ケ嶺舘', '03', '03213', '0286973', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町駒ケ嶺舘', 'ジョウボウジマチコマガミネタテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町中畑', '03', '03213', '0286974', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町中畑', 'ジョウボウジマチナカハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町田余内', '03', '03213', '0286975', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町田余内', 'ジョウボウジマチタヨナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町樋口', '03', '03213', '0286976', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町樋口', 'ジョウボウジマチトイグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町駒ケ嶺', '03', '03213', '0286977', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町駒ケ嶺', 'ジョウボウジマチコマガミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町駒ケ嶺前田', '03', '03213', '0286978', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町駒ケ嶺前田', 'ジョウボウジマチコマガミネマエタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町駒ケ嶺野田', '03', '03213', '0286979', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町駒ケ嶺野田', 'ジョウボウジマチコマガミネノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町五庵', '03', '03213', '0286981', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町五庵', 'ジョウボウジマチゴアン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町焼切', '03', '03213', '0286982', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町焼切', 'ジョウボウジマチヤッキリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町下藤', '03', '03213', '0286983', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町下藤', 'ジョウボウジマチシモフジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町柿ノ木平', '03', '03213', '0286984', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町柿ノ木平', 'ジョウボウジマチカキノキタイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県二戸市浄法寺町漆畑', '03', '03213', '0286985', '岩手県', 'イワテケン', '二戸市', 'ニノヘシ', '浄法寺町漆畑', 'ジョウボウジマチウルシバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市', '12', '12236', '2870000', '千葉県', 'チバケン', '香取市', 'カトリシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('17248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市佐原ロ', '12', '12236', '2870001', '千葉県', 'チバケン', '香取市', 'カトリシ', '佐原ロ', 'サワラロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市北', '12', '12236', '2870002', '千葉県', 'チバケン', '香取市', 'カトリシ', '北', 'キタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市佐原イ', '12', '12236', '2870003', '千葉県', 'チバケン', '香取市', 'カトリシ', '佐原イ', 'サワライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市岩ケ崎台', '12', '12236', '2870004', '千葉県', 'チバケン', '香取市', 'カトリシ', '岩ケ崎台', 'イワガサキダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市佐原ホ', '12', '12236', '2870005', '千葉県', 'チバケン', '香取市', 'カトリシ', '佐原ホ', 'サワラホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市篠原イ', '12', '12236', '2870006', '千葉県', 'チバケン', '香取市', 'カトリシ', '篠原イ', 'シノハライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市津宮', '12', '12236', '2870011', '千葉県', 'チバケン', '香取市', 'カトリシ', '津宮', 'ツノミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市大倉丁子', '12', '12236', '2870012', '千葉県', 'チバケン', '香取市', 'カトリシ', '大倉丁子', 'オオクラヨウロゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市大倉', '12', '12236', '2870013', '千葉県', 'チバケン', '香取市', 'カトリシ', '大倉', 'オオクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市多田', '12', '12236', '2870014', '千葉県', 'チバケン', '香取市', 'カトリシ', '多田', 'タダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市吉原', '12', '12236', '2870015', '千葉県', 'チバケン', '香取市', 'カトリシ', '吉原', 'ヨシワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市新市場', '12', '12236', '2870016', '千葉県', 'チバケン', '香取市', 'カトリシ', '新市場', 'ニイチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市香取', '12', '12236', '2870017', '千葉県', 'チバケン', '香取市', 'カトリシ', '香取', 'カトリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市丁子', '12', '12236', '2870018', '千葉県', 'チバケン', '香取市', 'カトリシ', '丁子', 'ヨウロゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市下小野', '12', '12236', '2870021', '千葉県', 'チバケン', '香取市', 'カトリシ', '下小野', 'シモオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市九美上', '12', '12236', '2870022', '千葉県', 'チバケン', '香取市', 'カトリシ', '九美上', 'クミアゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市伊地山', '12', '12236', '2870023', '千葉県', 'チバケン', '香取市', 'カトリシ', '伊地山', 'イチヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市福田', '12', '12236', '2870024', '千葉県', 'チバケン', '香取市', 'カトリシ', '福田', 'フクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市本矢作', '12', '12236', '2870025', '千葉県', 'チバケン', '香取市', 'カトリシ', '本矢作', 'モトヤハギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市大根', '12', '12236', '2870026', '千葉県', 'チバケン', '香取市', 'カトリシ', '大根', 'オオネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市返田', '12', '12236', '2870027', '千葉県', 'チバケン', '香取市', 'カトリシ', '返田', 'カヤダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市新部', '12', '12236', '2870031', '千葉県', 'チバケン', '香取市', 'カトリシ', '新部', 'ニッペ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市釜塚', '12', '12236', '2870032', '千葉県', 'チバケン', '香取市', 'カトリシ', '釜塚', 'カマヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市牧野', '12', '12236', '2870033', '千葉県', 'チバケン', '香取市', 'カトリシ', '牧野', 'マキノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市長山', '12', '12236', '2870034', '千葉県', 'チバケン', '香取市', 'カトリシ', '長山', 'ナガヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市大崎', '12', '12236', '2870035', '千葉県', 'チバケン', '香取市', 'カトリシ', '大崎', 'オオサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市観音', '12', '12236', '2870036', '千葉県', 'チバケン', '香取市', 'カトリシ', '観音', 'カンノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市与倉', '12', '12236', '2870037', '千葉県', 'チバケン', '香取市', 'カトリシ', '与倉', 'ヨクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市鳥羽', '12', '12236', '2870038', '千葉県', 'チバケン', '香取市', 'カトリシ', '鳥羽', 'トッパ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市玉造', '12', '12236', '2870041', '千葉県', 'チバケン', '香取市', 'カトリシ', '玉造', 'タマツクリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市山之辺', '12', '12236', '2870042', '千葉県', 'チバケン', '香取市', 'カトリシ', '山之辺', 'ヤマノベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市大戸', '12', '12236', '2870043', '千葉県', 'チバケン', '香取市', 'カトリシ', '大戸', 'オオト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市片野', '12', '12236', '2870044', '千葉県', 'チバケン', '香取市', 'カトリシ', '片野', 'カタノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市関', '12', '12236', '2870045', '千葉県', 'チバケン', '香取市', 'カトリシ', '関', 'セキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市上小川', '12', '12236', '2870046', '千葉県', 'チバケン', '香取市', 'カトリシ', '上小川', 'カミオガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市鴇崎', '12', '12236', '2870047', '千葉県', 'チバケン', '香取市', 'カトリシ', '鴇崎', 'トキザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市西和田', '12', '12236', '2870048', '千葉県', 'チバケン', '香取市', 'カトリシ', '西和田', 'ニシワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市新寺', '12', '12236', '2870051', '千葉県', 'チバケン', '香取市', 'カトリシ', '新寺', 'ニイデラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市森戸', '12', '12236', '2870052', '千葉県', 'チバケン', '香取市', 'カトリシ', '森戸', 'モリド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市大戸新田', '12', '12236', '2870053', '千葉県', 'チバケン', '香取市', 'カトリシ', '大戸新田', 'オオトシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市大戸川', '12', '12236', '2870054', '千葉県', 'チバケン', '香取市', 'カトリシ', '大戸川', 'オオトガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市昭和町', '12', '12236', '2870055', '千葉県', 'チバケン', '香取市', 'カトリシ', '昭和町', 'ショウワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市飯島', '12', '12236', '2870056', '千葉県', 'チバケン', '香取市', 'カトリシ', '飯島', 'イイジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市谷中', '12', '12236', '2870061', '千葉県', 'チバケン', '香取市', 'カトリシ', '谷中', 'ヤナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市寺内', '12', '12236', '2870062', '千葉県', 'チバケン', '香取市', 'カトリシ', '寺内', 'テラウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市西坂', '12', '12236', '2870063', '千葉県', 'チバケン', '香取市', 'カトリシ', '西坂', 'ニシザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市みずほ台', '12', '12236', '2870064', '千葉県', 'チバケン', '香取市', 'カトリシ', 'みずほ台', 'ミズホダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市西部田', '12', '12236', '2870065', '千葉県', 'チバケン', '香取市', 'カトリシ', '西部田', 'ニシベタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市堀之内', '12', '12236', '2870066', '千葉県', 'チバケン', '香取市', 'カトリシ', '堀之内', 'ホリノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市川尻', '12', '12236', '2870067', '千葉県', 'チバケン', '香取市', 'カトリシ', '川尻', 'カワジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市高萩', '12', '12236', '2870101', '千葉県', 'チバケン', '香取市', 'カトリシ', '高萩', 'タカハギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市岩部', '12', '12236', '2870102', '千葉県', 'チバケン', '香取市', 'カトリシ', '岩部', 'イワベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市西田部', '12', '12236', '2870103', '千葉県', 'チバケン', '香取市', 'カトリシ', '西田部', 'ニシタベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市苅毛', '12', '12236', '2870104', '千葉県', 'チバケン', '香取市', 'カトリシ', '苅毛', 'カリケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市沢', '12', '12236', '2870105', '千葉県', 'チバケン', '香取市', 'カトリシ', '沢', 'サワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市荒北', '12', '12236', '2870106', '千葉県', 'チバケン', '香取市', 'カトリシ', '荒北', 'アラキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市助沢', '12', '12236', '2870107', '千葉県', 'チバケン', '香取市', 'カトリシ', '助沢', 'スケザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市柴田', '12', '12211', '2870201', '千葉県', 'チバケン', '成田市', 'ナリタシ', '柴田', 'シバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市堀籠', '12', '12211', '2870202', '千葉県', 'チバケン', '成田市', 'ナリタシ', '堀籠', 'ホウメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市村田', '12', '12211', '2870203', '千葉県', 'チバケン', '成田市', 'ナリタシ', '村田', 'ムラタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市伊能', '12', '12211', '2870204', '千葉県', 'チバケン', '成田市', 'ナリタシ', '伊能', 'イノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市奈土', '12', '12211', '2870205', '千葉県', 'チバケン', '成田市', 'ナリタシ', '奈土', 'ナド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市所', '12', '12211', '2870211', '千葉県', 'チバケン', '成田市', 'ナリタシ', '所', 'トコロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市東ノ台', '12', '12211', '2870212', '千葉県', 'チバケン', '成田市', 'ナリタシ', '東ノ台', 'ヒガシノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市大沼', '12', '12211', '2870213', '千葉県', 'チバケン', '成田市', 'ナリタシ', '大沼', 'オオヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市横山', '12', '12211', '2870214', '千葉県', 'チバケン', '成田市', 'ナリタシ', '横山', 'ヨコヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市馬乗里', '12', '12211', '2870215', '千葉県', 'チバケン', '成田市', 'ナリタシ', '馬乗里', 'マジョウリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市南敷', '12', '12211', '2870216', '千葉県', 'チバケン', '成田市', 'ナリタシ', '南敷', 'ナジキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市桜田', '12', '12211', '2870217', '千葉県', 'チバケン', '成田市', 'ナリタシ', '桜田', 'サクラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市官林', '12', '12211', '2870221', '千葉県', 'チバケン', '成田市', 'ナリタシ', '官林', 'カンリン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市前林', '12', '12211', '2870222', '千葉県', 'チバケン', '成田市', 'ナリタシ', '前林', 'マエバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市新田', '12', '12211', '2870224', '千葉県', 'チバケン', '成田市', 'ナリタシ', '新田', 'シンデン', null, null, null, null), ('17320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市吉岡', '12', '12211', '2870225', '千葉県', 'チバケン', '成田市', 'ナリタシ', '吉岡', 'キチオカ', null, null, null, null), ('17321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市一坪田', '12', '12211', '2870227', '千葉県', 'チバケン', '成田市', 'ナリタシ', '一坪田', 'ヒトツボタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市久井崎', '12', '12211', '2870232', '千葉県', 'チバケン', '成田市', 'ナリタシ', '久井崎', 'クイザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市稲荷山', '12', '12211', '2870233', '千葉県', 'チバケン', '成田市', 'ナリタシ', '稲荷山', 'トウカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市松子', '12', '12211', '2870234', '千葉県', 'チバケン', '成田市', 'ナリタシ', '松子', 'マツコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市臼作', '12', '12211', '2870235', '千葉県', 'チバケン', '成田市', 'ナリタシ', '臼作', 'ウスクリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市津富浦', '12', '12211', '2870236', '千葉県', 'チバケン', '成田市', 'ナリタシ', '津富浦', 'ツブウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市中野', '12', '12211', '2870237', '千葉県', 'チバケン', '成田市', 'ナリタシ', '中野', 'ナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市水の上', '12', '12211', '2870241', '千葉県', 'チバケン', '成田市', 'ナリタシ', '水の上', 'ミズノカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市多良貝', '12', '12211', '2870242', '千葉県', 'チバケン', '成田市', 'ナリタシ', '多良貝', 'タラガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市大栄十余三', '12', '12211', '2870243', '千葉県', 'チバケン', '成田市', 'ナリタシ', '大栄十余三', 'タイエイトヨミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市川上', '12', '12211', '2870244', '千葉県', 'チバケン', '成田市', 'ナリタシ', '川上', 'カワカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市扇島', '12', '12236', '2870801', '千葉県', 'チバケン', '香取市', 'カトリシ', '扇島', 'オウギシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市加藤洲', '12', '12236', '2870802', '千葉県', 'チバケン', '香取市', 'カトリシ', '加藤洲', 'カドウズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市磯山', '12', '12236', '2870803', '千葉県', 'チバケン', '香取市', 'カトリシ', '磯山', 'イソヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市市和田', '12', '12236', '2870804', '千葉県', 'チバケン', '香取市', 'カトリシ', '市和田', 'イチワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市公官洲', '12', '12236', '2870805', '千葉県', 'チバケン', '香取市', 'カトリシ', '公官洲', 'コウカンズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市附洲新田', '12', '12236', '2870806', '千葉県', 'チバケン', '香取市', 'カトリシ', '附洲新田', 'ツキスシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市大島', '12', '12236', '2870811', '千葉県', 'チバケン', '香取市', 'カトリシ', '大島', 'オオシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市三島', '12', '12236', '2870812', '千葉県', 'チバケン', '香取市', 'カトリシ', '三島', 'ミシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市境島', '12', '12236', '2870813', '千葉県', 'チバケン', '香取市', 'カトリシ', '境島', 'サカイジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市中洲', '12', '12236', '2870814', '千葉県', 'チバケン', '香取市', 'カトリシ', '中洲', 'ナカズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市八筋川', '12', '12236', '2870815', '千葉県', 'チバケン', '香取市', 'カトリシ', '八筋川', 'ヤスジカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市佐原ハ', '12', '12236', '2870816', '千葉県', 'チバケン', '香取市', 'カトリシ', '佐原ハ', 'サワラハ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市篠原ロ', '12', '12236', '2870821', '千葉県', 'チバケン', '香取市', 'カトリシ', '篠原ロ', 'シノハラロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市佐原ニ', '12', '12236', '2870822', '千葉県', 'チバケン', '香取市', 'カトリシ', '佐原ニ', 'サワラニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市笄島', '12', '12236', '2870823', '千葉県', 'チバケン', '香取市', 'カトリシ', '笄島', 'コウガイジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市長島', '12', '12236', '2870824', '千葉県', 'チバケン', '香取市', 'カトリシ', '長島', 'ナガシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市野間谷原', '12', '12236', '2870825', '千葉県', 'チバケン', '香取市', 'カトリシ', '野間谷原', 'ノマヤワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市石納', '12', '12236', '2870826', '千葉県', 'チバケン', '香取市', 'カトリシ', '石納', 'コクノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市', '03', '03214', '0287100', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('17352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市大更', '03', '03214', '0287111', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '大更', 'オオブケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市田頭', '03', '03214', '0287112', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '田頭', 'デンドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市平笠', '03', '03214', '0287113', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '平笠', 'ヒラカサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市野駄', '03', '03214', '0287301', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '野駄', 'ノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市八幡平温泉郷', '03', '03214', '0287302', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '八幡平温泉郷', 'ハチマンタイオンセンキョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市松尾寄木', '03', '03214', '0287302', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '松尾寄木', 'マツオヨリキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市松川温泉', '03', '03214', '0287302', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '松川温泉', 'マツカワオンセン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市柏台', '03', '03214', '0287303', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '柏台', 'カシワダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市藤七温泉', '03', '03214', '0287303', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '藤七温泉', 'トウシチオンセン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市緑ガ丘', '03', '03214', '0287304', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '緑ガ丘', 'ミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市松尾', '03', '03214', '0287305', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '松尾', 'マツオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市安比高原', '03', '03214', '0287306', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '安比高原', 'アッピコウゲン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市西根寺田', '03', '03214', '0287401', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '西根寺田', 'ニシネテラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市帷子', '03', '03214', '0287402', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '帷子', 'カタビラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市上関', '03', '03214', '0287403', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '上関', 'ウワセキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市堀切', '03', '03214', '0287404', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '堀切', 'ホリキリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市平舘', '03', '03214', '0287405', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '平舘', 'タイラダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市荒木田', '03', '03214', '0287406', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '荒木田', 'アラキダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市岩木向', '03', '03214', '0287501', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '岩木向', 'イワキムカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市上岩木', '03', '03214', '0287502', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '上岩木', 'カミイワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市中田', '03', '03214', '0287503', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '中田', 'ナカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市前田', '03', '03214', '0287504', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '前田', 'マエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市岩屋', '03', '03214', '0287505', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '岩屋', 'イワヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市安代寺田', '03', '03214', '0287506', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '安代寺田', 'アシロテラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市下の田', '03', '03214', '0287511', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '下の田', 'シモノタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市山岸', '03', '03214', '0287512', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '山岸', 'ヤマギシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市土沢', '03', '03214', '0287513', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '土沢', 'ツチザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市中佐井', '03', '03214', '0287514', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '中佐井', 'ナカサイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市古屋敷', '03', '03214', '0287515', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '古屋敷', 'フルヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市関沢口', '03', '03214', '0287516', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '関沢口', 'セキサワグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市石神', '03', '03214', '0287521', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '石神', 'イシガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市山口', '03', '03214', '0287522', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '山口', 'ヤマグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市繋沢', '03', '03214', '0287523', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '繋沢', 'ツナギサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市湯の沢', '03', '03214', '0287524', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '湯の沢', 'ユノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市日影', '03', '03214', '0287525', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '日影', 'ヒカゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市赤子平', '03', '03214', '0287526', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '赤子平', 'アカコタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市川原', '03', '03214', '0287527', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '川原', 'カワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市上の山', '03', '03214', '0287531', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '上の山', 'ウエノヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市小柳田', '03', '03214', '0287532', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '小柳田', 'コヤナギダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市叺田', '03', '03214', '0287533', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '叺田', 'カマスダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市荒屋新町', '03', '03214', '0287534', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '荒屋新町', 'アラヤシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市清水', '03', '03214', '0287535', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '清水', 'シミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市打田内', '03', '03214', '0287536', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '打田内', 'ウツタナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市曲田', '03', '03214', '0287537', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '曲田', 'マガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市寺志田', '03', '03214', '0287541', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '寺志田', 'テラシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市高畑', '03', '03214', '0287542', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '高畑', 'タカハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市小屋畑', '03', '03214', '0287543', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '小屋畑', 'コヤノハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市保戸坂', '03', '03214', '0287544', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '保戸坂', 'ホトザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市松木田', '03', '03214', '0287545', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '松木田', 'マツキダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市新田', '03', '03214', '0287551', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '新田', 'シンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市安代寄木', '03', '03214', '0287552', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '安代寄木', 'アシロヨリキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市扇畑', '03', '03214', '0287553', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '扇畑', 'オウギハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市赤坂田', '03', '03214', '0287554', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '赤坂田', 'アカサカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市黒沢', '03', '03214', '0287555', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '黒沢', 'クロサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市星沢', '03', '03214', '0287556', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '星沢', 'ホシザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市細野', '03', '03214', '0287557', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '細野', 'ホソノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市下町', '03', '03214', '0287561', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '下町', 'シタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市五日市', '03', '03214', '0287562', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '五日市', 'イツカイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市田の沢', '03', '03214', '0287563', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '田の沢', 'タノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市谷地田', '03', '03214', '0287564', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '谷地田', 'ヤチタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市目名市', '03', '03214', '0287565', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '目名市', 'メナイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市滝沢', '03', '03214', '0287566', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '滝沢', 'タキザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市戸沢', '03', '03214', '0287567', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '戸沢', 'トザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市田沢', '03', '03214', '0287601', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '田沢', 'タザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市丑山', '03', '03214', '0287602', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '丑山', 'ウシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市矢神', '03', '03214', '0287603', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '矢神', 'ヤガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市丑山口', '03', '03214', '0287604', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '丑山口', 'ウシヤマグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市鵜谷地', '03', '03214', '0287605', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '鵜谷地', 'ウノドリヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市姥子石', '03', '03214', '0287606', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '姥子石', 'ウバコイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市大面平', '03', '03214', '0287607', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '大面平', 'オオツラタイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市谷地中', '03', '03214', '0287608', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '谷地中', 'ヤチナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市沖田表', '03', '03214', '0287611', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '沖田表', 'オキタオモテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市欠田', '03', '03214', '0287612', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '欠田', 'カケタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市亦戸川原', '03', '03214', '0287613', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '亦戸川原', 'マタトカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市石名坂下タ', '03', '03214', '0287614', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '石名坂下タ', 'イシナザカシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市石名坂', '03', '03214', '0287615', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '石名坂', 'イシナザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市二タ子', '03', '03214', '0287616', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '二タ子', 'フタゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市折壁', '03', '03214', '0287617', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '折壁', 'オリカベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市蛇石', '03', '03214', '0287618', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '蛇石', 'ジャイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市相沢', '03', '03214', '0287619', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '相沢', 'アイザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市兄川', '03', '03214', '0287621', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '兄川', 'アニカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市作平', '03', '03214', '0287621', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '作平', 'サクヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市兄畑中川原', '03', '03214', '0287622', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '兄畑中川原', 'アニハタナカカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市舘市', '03', '03214', '0287623', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '舘市', 'タテイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市大又沢口', '03', '03214', '0287624', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '大又沢口', 'オオマタサワグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市沖ノ平', '03', '03214', '0287625', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '沖ノ平', 'オキノタイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市戸鎖', '03', '03214', '0287626', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '戸鎖', 'トクサリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市佐比内', '03', '03214', '0287627', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '佐比内', 'サヒナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市小岩井', '03', '03214', '0287628', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '小岩井', 'コイワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市白沢口', '03', '03214', '0287629', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '白沢口', 'シラサワグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市瀬ノ沢', '03', '03214', '0287631', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '瀬ノ沢', 'セノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市小原道ノ上', '03', '03214', '0287632', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '小原道ノ上', 'コハラミチノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市日泥道ノ上', '03', '03214', '0287633', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '日泥道ノ上', 'ヒドロミチノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市和屋敷道ノ上', '03', '03214', '0287634', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '和屋敷道ノ上', 'ワヤシキミチノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市愛の山', '03', '03214', '0287635', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '愛の山', 'アイノヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市和屋敷道ノ下', '03', '03214', '0287636', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '和屋敷道ノ下', 'ワヤシキミチノシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市日泥道ノ下', '03', '03214', '0287637', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '日泥道ノ下', 'ヒドロミチノシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市小原道ノ下', '03', '03214', '0287638', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '小原道ノ下', 'コハラミチノシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市比路平', '03', '03214', '0287641', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '比路平', 'ヒロビラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市勝善川原', '03', '03214', '0287642', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '勝善川原', 'ショウゼンカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市切通', '03', '03214', '0287643', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '切通', 'キリトオシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市雀長根', '03', '03214', '0287644', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '雀長根', 'スズメナガネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市下タ川原', '03', '03214', '0287645', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '下タ川原', 'シタカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市長者前', '03', '03214', '0287651', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '長者前', 'チョウジャマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市根石', '03', '03214', '0287652', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '根石', 'ネイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市平又', '03', '03214', '0287653', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '平又', 'ヒラマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市小峠', '03', '03214', '0287654', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '小峠', 'コトウゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市馬揚沢', '03', '03214', '0287655', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '馬揚沢', 'ウマアゲサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市左妻', '03', '03214', '0287656', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '左妻', 'サヅマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市栗木田', '03', '03214', '0287657', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '栗木田', 'クリキダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市大沢', '03', '03214', '0287661', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '大沢', 'オオサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市杉沢', '03', '03214', '0287662', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '杉沢', 'スギサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市石森', '03', '03214', '0287663', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '石森', 'イシモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市大沢田', '03', '03214', '0287664', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '大沢田', 'オオサワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市馬場下', '03', '03214', '0287671', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '馬場下', 'ババシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市田中下タ', '03', '03214', '0287672', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '田中下タ', 'タナカシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市殿坂下タ', '03', '03214', '0287673', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '殿坂下タ', 'トノサカシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市家ノ裏', '03', '03214', '0287674', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '家ノ裏', 'イエノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市下モ川原', '03', '03214', '0287675', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '下モ川原', 'シモカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市沢口', '03', '03214', '0287676', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '沢口', 'サワグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市田山', '03', '03214', '0287677', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '田山', 'タヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市小森', '03', '03214', '0287678', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '小森', 'コモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県八幡平市足深', '03', '03214', '0287679', '岩手県', 'イワテケン', '八幡平市', 'ハチマンタイシ', '足深', 'アシブカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県久慈市侍浜町', '03', '03207', '0287801', '岩手県', 'イワテケン', '久慈市', 'クジシ', '侍浜町', 'サムライハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡洋野町', '03', '03507', '0287900', '岩手県', 'イワテケン', '九戸郡洋野町', 'クノヘグンヒロノチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('17491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡洋野町種市第8地割', '03', '03507', '0287901', '岩手県', 'イワテケン', '九戸郡洋野町', 'クノヘグンヒロノチョウ', '種市', 'タネイチ', null, null, '第8地割', 'ダイ08チワリ');
INSERT INTO `ms_addresses` VALUES ('17492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡洋野町種市第9地割', '03', '03507', '0287901', '岩手県', 'イワテケン', '九戸郡洋野町', 'クノヘグンヒロノチョウ', '種市', 'タネイチ', null, null, '第9地割', 'ダイ09チワリ');
INSERT INTO `ms_addresses` VALUES ('17493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡洋野町種市第10地割', '03', '03507', '0287901', '岩手県', 'イワテケン', '九戸郡洋野町', 'クノヘグンヒロノチョウ', '種市', 'タネイチ', null, null, '第10地割', 'ダイ10チワリ');
INSERT INTO `ms_addresses` VALUES ('17494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡洋野町種市第11地割', '03', '03507', '0287901', '岩手県', 'イワテケン', '九戸郡洋野町', 'クノヘグンヒロノチョウ', '種市', 'タネイチ', null, null, '第11地割', 'ダイ11チワリ');
INSERT INTO `ms_addresses` VALUES ('17495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡洋野町種市第12地割', '03', '03507', '0287901', '岩手県', 'イワテケン', '九戸郡洋野町', 'クノヘグンヒロノチョウ', '種市', 'タネイチ', null, null, '第12地割', 'ダイ12チワリ');
INSERT INTO `ms_addresses` VALUES ('17496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡洋野町種市第13地割', '03', '03507', '0287901', '岩手県', 'イワテケン', '九戸郡洋野町', 'クノヘグンヒロノチョウ', '種市', 'タネイチ', null, null, '第13地割', 'ダイ13チワリ');
INSERT INTO `ms_addresses` VALUES ('17497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡洋野町種市第14地割', '03', '03507', '0287901', '岩手県', 'イワテケン', '九戸郡洋野町', 'クノヘグンヒロノチョウ', '種市', 'タネイチ', null, null, '第14地割', 'ダイ14チワリ');
INSERT INTO `ms_addresses` VALUES ('17498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡洋野町種市第4地割', '03', '03507', '0287902', '岩手県', 'イワテケン', '九戸郡洋野町', 'クノヘグンヒロノチョウ', '種市', 'タネイチ', null, null, '第4地割', 'ダイ04チワリ');
INSERT INTO `ms_addresses` VALUES ('17499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡洋野町種市第5地割', '03', '03507', '0287902', '岩手県', 'イワテケン', '九戸郡洋野町', 'クノヘグンヒロノチョウ', '種市', 'タネイチ', null, null, '第5地割', 'ダイ05チワリ');
INSERT INTO `ms_addresses` VALUES ('17500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡洋野町種市第6地割', '03', '03507', '0287902', '岩手県', 'イワテケン', '九戸郡洋野町', 'クノヘグンヒロノチョウ', '種市', 'タネイチ', null, null, '第6地割', 'ダイ06チワリ');
INSERT INTO `ms_addresses` VALUES ('17501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡洋野町種市第7地割', '03', '03507', '0287902', '岩手県', 'イワテケン', '九戸郡洋野町', 'クノヘグンヒロノチョウ', '種市', 'タネイチ', null, null, '第7地割', 'ダイ07チワリ');
INSERT INTO `ms_addresses` VALUES ('17502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡洋野町種市第1地割', '03', '03507', '0287903', '岩手県', 'イワテケン', '九戸郡洋野町', 'クノヘグンヒロノチョウ', '種市', 'タネイチ', null, null, '第1地割', 'ダイ01チワリ');
INSERT INTO `ms_addresses` VALUES ('17503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡洋野町種市第2地割', '03', '03507', '0287903', '岩手県', 'イワテケン', '九戸郡洋野町', 'クノヘグンヒロノチョウ', '種市', 'タネイチ', null, null, '第2地割', 'ダイ02チワリ');
INSERT INTO `ms_addresses` VALUES ('17504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡洋野町種市第3地割', '03', '03507', '0287903', '岩手県', 'イワテケン', '九戸郡洋野町', 'クノヘグンヒロノチョウ', '種市', 'タネイチ', null, null, '第3地割', 'ダイ03チワリ');
INSERT INTO `ms_addresses` VALUES ('17505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡洋野町小子内', '03', '03507', '0287904', '岩手県', 'イワテケン', '九戸郡洋野町', 'クノヘグンヒロノチョウ', '小子内', 'オコナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡洋野町有家', '03', '03507', '0287905', '岩手県', 'イワテケン', '九戸郡洋野町', 'クノヘグンヒロノチョウ', '有家', 'ウゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡洋野町中野', '03', '03507', '0287906', '岩手県', 'イワテケン', '九戸郡洋野町', 'クノヘグンヒロノチョウ', '中野', 'ナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡洋野町種市第39地割', '03', '03507', '0287911', '岩手県', 'イワテケン', '九戸郡洋野町', 'クノヘグンヒロノチョウ', '種市', 'タネイチ', null, null, '第39地割', 'ダイ39チワリ');
INSERT INTO `ms_addresses` VALUES ('17509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡洋野町種市第40地割', '03', '03507', '0287911', '岩手県', 'イワテケン', '九戸郡洋野町', 'クノヘグンヒロノチョウ', '種市', 'タネイチ', null, null, '第40地割', 'ダイ40チワリ');
INSERT INTO `ms_addresses` VALUES ('17510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡洋野町種市第41地割', '03', '03507', '0287911', '岩手県', 'イワテケン', '九戸郡洋野町', 'クノヘグンヒロノチョウ', '種市', 'タネイチ', null, null, '第41地割', 'ダイ41チワリ');
INSERT INTO `ms_addresses` VALUES ('17511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡洋野町種市第42地割', '03', '03507', '0287911', '岩手県', 'イワテケン', '九戸郡洋野町', 'クノヘグンヒロノチョウ', '種市', 'タネイチ', null, null, '第42地割', 'ダイ42チワリ');
INSERT INTO `ms_addresses` VALUES ('17512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡洋野町種市第43地割', '03', '03507', '0287911', '岩手県', 'イワテケン', '九戸郡洋野町', 'クノヘグンヒロノチョウ', '種市', 'タネイチ', null, null, '第43地割', 'ダイ43チワリ');
INSERT INTO `ms_addresses` VALUES ('17513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡洋野町種市第44地割', '03', '03507', '0287911', '岩手県', 'イワテケン', '九戸郡洋野町', 'クノヘグンヒロノチョウ', '種市', 'タネイチ', null, null, '第44地割', 'ダイ44チワリ');
INSERT INTO `ms_addresses` VALUES ('17514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡洋野町種市第45地割', '03', '03507', '0287911', '岩手県', 'イワテケン', '九戸郡洋野町', 'クノヘグンヒロノチョウ', '種市', 'タネイチ', null, null, '第45地割', 'ダイ45チワリ');
INSERT INTO `ms_addresses` VALUES ('17515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡洋野町種市第26地割', '03', '03507', '0287912', '岩手県', 'イワテケン', '九戸郡洋野町', 'クノヘグンヒロノチョウ', '種市', 'タネイチ', null, null, '第26地割', 'ダイ26チワリ');
INSERT INTO `ms_addresses` VALUES ('17516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡洋野町種市第27地割', '03', '03507', '0287912', '岩手県', 'イワテケン', '九戸郡洋野町', 'クノヘグンヒロノチョウ', '種市', 'タネイチ', null, null, '第27地割', 'ダイ27チワリ');
INSERT INTO `ms_addresses` VALUES ('17517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡洋野町種市第28地割', '03', '03507', '0287912', '岩手県', 'イワテケン', '九戸郡洋野町', 'クノヘグンヒロノチョウ', '種市', 'タネイチ', null, null, '第28地割', 'ダイ28チワリ');
INSERT INTO `ms_addresses` VALUES ('17518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡洋野町種市第29地割', '03', '03507', '0287912', '岩手県', 'イワテケン', '九戸郡洋野町', 'クノヘグンヒロノチョウ', '種市', 'タネイチ', null, null, '第29地割', 'ダイ29チワリ');
INSERT INTO `ms_addresses` VALUES ('17519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡洋野町種市第30地割', '03', '03507', '0287912', '岩手県', 'イワテケン', '九戸郡洋野町', 'クノヘグンヒロノチョウ', '種市', 'タネイチ', null, null, '第30地割', 'ダイ30チワリ');
INSERT INTO `ms_addresses` VALUES ('17520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡洋野町種市第31地割', '03', '03507', '0287912', '岩手県', 'イワテケン', '九戸郡洋野町', 'クノヘグンヒロノチョウ', '種市', 'タネイチ', null, null, '第31地割', 'ダイ31チワリ');
INSERT INTO `ms_addresses` VALUES ('17521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡洋野町種市第32地割', '03', '03507', '0287912', '岩手県', 'イワテケン', '九戸郡洋野町', 'クノヘグンヒロノチョウ', '種市', 'タネイチ', null, null, '第32地割', 'ダイ32チワリ');
INSERT INTO `ms_addresses` VALUES ('17522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡洋野町種市第33地割', '03', '03507', '0287912', '岩手県', 'イワテケン', '九戸郡洋野町', 'クノヘグンヒロノチョウ', '種市', 'タネイチ', null, null, '第33地割', 'ダイ33チワリ');
INSERT INTO `ms_addresses` VALUES ('17523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡洋野町種市第34地割', '03', '03507', '0287912', '岩手県', 'イワテケン', '九戸郡洋野町', 'クノヘグンヒロノチョウ', '種市', 'タネイチ', null, null, '第34地割', 'ダイ34チワリ');
INSERT INTO `ms_addresses` VALUES ('17524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡洋野町種市第35地割', '03', '03507', '0287912', '岩手県', 'イワテケン', '九戸郡洋野町', 'クノヘグンヒロノチョウ', '種市', 'タネイチ', null, null, '第35地割', 'ダイ35チワリ');
INSERT INTO `ms_addresses` VALUES ('17525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡洋野町種市第36地割', '03', '03507', '0287912', '岩手県', 'イワテケン', '九戸郡洋野町', 'クノヘグンヒロノチョウ', '種市', 'タネイチ', null, null, '第36地割', 'ダイ36チワリ');
INSERT INTO `ms_addresses` VALUES ('17526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡洋野町種市第37地割', '03', '03507', '0287912', '岩手県', 'イワテケン', '九戸郡洋野町', 'クノヘグンヒロノチョウ', '種市', 'タネイチ', null, null, '第37地割', 'ダイ37チワリ');
INSERT INTO `ms_addresses` VALUES ('17527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡洋野町種市第38地割', '03', '03507', '0287912', '岩手県', 'イワテケン', '九戸郡洋野町', 'クノヘグンヒロノチョウ', '種市', 'タネイチ', null, null, '第38地割', 'ダイ38チワリ');
INSERT INTO `ms_addresses` VALUES ('17528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡洋野町種市第24地割', '03', '03507', '0287913', '岩手県', 'イワテケン', '九戸郡洋野町', 'クノヘグンヒロノチョウ', '種市', 'タネイチ', null, null, '第24地割', 'ダイ24チワリ');
INSERT INTO `ms_addresses` VALUES ('17529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡洋野町種市第25地割', '03', '03507', '0287913', '岩手県', 'イワテケン', '九戸郡洋野町', 'クノヘグンヒロノチョウ', '種市', 'タネイチ', null, null, '第25地割', 'ダイ25チワリ');
INSERT INTO `ms_addresses` VALUES ('17530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡洋野町種市第22地割', '03', '03507', '0287914', '岩手県', 'イワテケン', '九戸郡洋野町', 'クノヘグンヒロノチョウ', '種市', 'タネイチ', null, null, '第22地割', 'ダイ22チワリ');
INSERT INTO `ms_addresses` VALUES ('17531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡洋野町種市第23地割', '03', '03507', '0287914', '岩手県', 'イワテケン', '九戸郡洋野町', 'クノヘグンヒロノチョウ', '種市', 'タネイチ', null, null, '第23地割', 'ダイ23チワリ');
INSERT INTO `ms_addresses` VALUES ('17532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡洋野町種市第15地割', '03', '03507', '0287915', '岩手県', 'イワテケン', '九戸郡洋野町', 'クノヘグンヒロノチョウ', '種市', 'タネイチ', null, null, '第15地割', 'ダイ15チワリ');
INSERT INTO `ms_addresses` VALUES ('17533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡洋野町種市第16地割', '03', '03507', '0287915', '岩手県', 'イワテケン', '九戸郡洋野町', 'クノヘグンヒロノチョウ', '種市', 'タネイチ', null, null, '第16地割', 'ダイ16チワリ');
INSERT INTO `ms_addresses` VALUES ('17534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡洋野町種市第17地割', '03', '03507', '0287915', '岩手県', 'イワテケン', '九戸郡洋野町', 'クノヘグンヒロノチョウ', '種市', 'タネイチ', null, null, '第17地割', 'ダイ17チワリ');
INSERT INTO `ms_addresses` VALUES ('17535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡洋野町種市第18地割', '03', '03507', '0287915', '岩手県', 'イワテケン', '九戸郡洋野町', 'クノヘグンヒロノチョウ', '種市', 'タネイチ', null, null, '第18地割', 'ダイ18チワリ');
INSERT INTO `ms_addresses` VALUES ('17536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡洋野町種市第19地割', '03', '03507', '0287915', '岩手県', 'イワテケン', '九戸郡洋野町', 'クノヘグンヒロノチョウ', '種市', 'タネイチ', null, null, '第19地割', 'ダイ19チワリ');
INSERT INTO `ms_addresses` VALUES ('17537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡洋野町種市第20地割', '03', '03507', '0287915', '岩手県', 'イワテケン', '九戸郡洋野町', 'クノヘグンヒロノチョウ', '種市', 'タネイチ', null, null, '第20地割', 'ダイ20チワリ');
INSERT INTO `ms_addresses` VALUES ('17538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡洋野町種市第21地割', '03', '03507', '0287915', '岩手県', 'イワテケン', '九戸郡洋野町', 'クノヘグンヒロノチョウ', '種市', 'タネイチ', null, null, '第21地割', 'ダイ21チワリ');
INSERT INTO `ms_addresses` VALUES ('17539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡洋野町種市第71地割', '03', '03507', '0287916', '岩手県', 'イワテケン', '九戸郡洋野町', 'クノヘグンヒロノチョウ', '種市', 'タネイチ', null, null, '第71地割', 'ダイ71チワリ');
INSERT INTO `ms_addresses` VALUES ('17540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡洋野町種市第72地割', '03', '03507', '0287916', '岩手県', 'イワテケン', '九戸郡洋野町', 'クノヘグンヒロノチョウ', '種市', 'タネイチ', null, null, '第72地割', 'ダイ72チワリ');
INSERT INTO `ms_addresses` VALUES ('17541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡洋野町種市第73地割', '03', '03507', '0287916', '岩手県', 'イワテケン', '九戸郡洋野町', 'クノヘグンヒロノチョウ', '種市', 'タネイチ', null, null, '第73地割', 'ダイ73チワリ');
INSERT INTO `ms_addresses` VALUES ('17542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡洋野町種市第74地割', '03', '03507', '0287916', '岩手県', 'イワテケン', '九戸郡洋野町', 'クノヘグンヒロノチョウ', '種市', 'タネイチ', null, null, '第74地割', 'ダイ74チワリ');
INSERT INTO `ms_addresses` VALUES ('17543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡洋野町種市第50地割', '03', '03507', '0287917', '岩手県', 'イワテケン', '九戸郡洋野町', 'クノヘグンヒロノチョウ', '種市', 'タネイチ', null, null, '第50地割', 'ダイ50チワリ');
INSERT INTO `ms_addresses` VALUES ('17544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡洋野町種市第51地割', '03', '03507', '0287917', '岩手県', 'イワテケン', '九戸郡洋野町', 'クノヘグンヒロノチョウ', '種市', 'タネイチ', null, null, '第51地割', 'ダイ51チワリ');
INSERT INTO `ms_addresses` VALUES ('17545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡洋野町種市第52地割', '03', '03507', '0287917', '岩手県', 'イワテケン', '九戸郡洋野町', 'クノヘグンヒロノチョウ', '種市', 'タネイチ', null, null, '第52地割', 'ダイ52チワリ');
INSERT INTO `ms_addresses` VALUES ('17546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡洋野町種市第53地割', '03', '03507', '0287917', '岩手県', 'イワテケン', '九戸郡洋野町', 'クノヘグンヒロノチョウ', '種市', 'タネイチ', null, null, '第53地割', 'ダイ53チワリ');
INSERT INTO `ms_addresses` VALUES ('17547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡洋野町種市第54地割', '03', '03507', '0287917', '岩手県', 'イワテケン', '九戸郡洋野町', 'クノヘグンヒロノチョウ', '種市', 'タネイチ', null, null, '第54地割', 'ダイ54チワリ');
INSERT INTO `ms_addresses` VALUES ('17548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡洋野町種市第55地割', '03', '03507', '0287917', '岩手県', 'イワテケン', '九戸郡洋野町', 'クノヘグンヒロノチョウ', '種市', 'タネイチ', null, null, '第55地割', 'ダイ55チワリ');
INSERT INTO `ms_addresses` VALUES ('17549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡洋野町種市第56地割', '03', '03507', '0287917', '岩手県', 'イワテケン', '九戸郡洋野町', 'クノヘグンヒロノチョウ', '種市', 'タネイチ', null, null, '第56地割', 'ダイ56チワリ');
INSERT INTO `ms_addresses` VALUES ('17550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡洋野町種市第57地割', '03', '03507', '0287917', '岩手県', 'イワテケン', '九戸郡洋野町', 'クノヘグンヒロノチョウ', '種市', 'タネイチ', null, null, '第57地割', 'ダイ57チワリ');
INSERT INTO `ms_addresses` VALUES ('17551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡洋野町種市第58地割', '03', '03507', '0287917', '岩手県', 'イワテケン', '九戸郡洋野町', 'クノヘグンヒロノチョウ', '種市', 'タネイチ', null, null, '第58地割', 'ダイ58チワリ');
INSERT INTO `ms_addresses` VALUES ('17552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡洋野町種市第59地割', '03', '03507', '0287917', '岩手県', 'イワテケン', '九戸郡洋野町', 'クノヘグンヒロノチョウ', '種市', 'タネイチ', null, null, '第59地割', 'ダイ59チワリ');
INSERT INTO `ms_addresses` VALUES ('17553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡洋野町種市第60地割', '03', '03507', '0287917', '岩手県', 'イワテケン', '九戸郡洋野町', 'クノヘグンヒロノチョウ', '種市', 'タネイチ', null, null, '第60地割', 'ダイ60チワリ');
INSERT INTO `ms_addresses` VALUES ('17554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡洋野町種市第61地割', '03', '03507', '0287917', '岩手県', 'イワテケン', '九戸郡洋野町', 'クノヘグンヒロノチョウ', '種市', 'タネイチ', null, null, '第61地割', 'ダイ61チワリ');
INSERT INTO `ms_addresses` VALUES ('17555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡洋野町種市第62地割', '03', '03507', '0287917', '岩手県', 'イワテケン', '九戸郡洋野町', 'クノヘグンヒロノチョウ', '種市', 'タネイチ', null, null, '第62地割', 'ダイ62チワリ');
INSERT INTO `ms_addresses` VALUES ('17556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡洋野町種市第63地割', '03', '03507', '0287917', '岩手県', 'イワテケン', '九戸郡洋野町', 'クノヘグンヒロノチョウ', '種市', 'タネイチ', null, null, '第63地割', 'ダイ63チワリ');
INSERT INTO `ms_addresses` VALUES ('17557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡洋野町種市第64地割', '03', '03507', '0287917', '岩手県', 'イワテケン', '九戸郡洋野町', 'クノヘグンヒロノチョウ', '種市', 'タネイチ', null, null, '第64地割', 'ダイ64チワリ');
INSERT INTO `ms_addresses` VALUES ('17558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡洋野町種市第65地割', '03', '03507', '0287917', '岩手県', 'イワテケン', '九戸郡洋野町', 'クノヘグンヒロノチョウ', '種市', 'タネイチ', null, null, '第65地割', 'ダイ65チワリ');
INSERT INTO `ms_addresses` VALUES ('17559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡洋野町種市第66地割', '03', '03507', '0287917', '岩手県', 'イワテケン', '九戸郡洋野町', 'クノヘグンヒロノチョウ', '種市', 'タネイチ', null, null, '第66地割', 'ダイ66チワリ');
INSERT INTO `ms_addresses` VALUES ('17560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡洋野町種市第67地割', '03', '03507', '0287917', '岩手県', 'イワテケン', '九戸郡洋野町', 'クノヘグンヒロノチョウ', '種市', 'タネイチ', null, null, '第67地割', 'ダイ67チワリ');
INSERT INTO `ms_addresses` VALUES ('17561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡洋野町種市第68地割', '03', '03507', '0287917', '岩手県', 'イワテケン', '九戸郡洋野町', 'クノヘグンヒロノチョウ', '種市', 'タネイチ', null, null, '第68地割', 'ダイ68チワリ');
INSERT INTO `ms_addresses` VALUES ('17562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡洋野町種市第69地割', '03', '03507', '0287917', '岩手県', 'イワテケン', '九戸郡洋野町', 'クノヘグンヒロノチョウ', '種市', 'タネイチ', null, null, '第69地割', 'ダイ69チワリ');
INSERT INTO `ms_addresses` VALUES ('17563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡洋野町種市第70地割', '03', '03507', '0287917', '岩手県', 'イワテケン', '九戸郡洋野町', 'クノヘグンヒロノチョウ', '種市', 'タネイチ', null, null, '第70地割', 'ダイ70チワリ');
INSERT INTO `ms_addresses` VALUES ('17564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡洋野町種市第46地割', '03', '03507', '0287918', '岩手県', 'イワテケン', '九戸郡洋野町', 'クノヘグンヒロノチョウ', '種市', 'タネイチ', null, null, '第46地割', 'ダイ46チワリ');
INSERT INTO `ms_addresses` VALUES ('17565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡洋野町種市第47地割', '03', '03507', '0287918', '岩手県', 'イワテケン', '九戸郡洋野町', 'クノヘグンヒロノチョウ', '種市', 'タネイチ', null, null, '第47地割', 'ダイ47チワリ');
INSERT INTO `ms_addresses` VALUES ('17566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡洋野町種市第48地割', '03', '03507', '0287918', '岩手県', 'イワテケン', '九戸郡洋野町', 'クノヘグンヒロノチョウ', '種市', 'タネイチ', null, null, '第48地割', 'ダイ48チワリ');
INSERT INTO `ms_addresses` VALUES ('17567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡洋野町種市第49地割', '03', '03507', '0287918', '岩手県', 'イワテケン', '九戸郡洋野町', 'クノヘグンヒロノチョウ', '種市', 'タネイチ', null, null, '第49地割', 'ダイ49チワリ');
INSERT INTO `ms_addresses` VALUES ('17569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市', '12', '12202', '2880000', '千葉県', 'チバケン', '銚子市', 'チョウシシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('17570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市川口町', '12', '12202', '2880001', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '川口町', 'カワグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市明神町', '12', '12202', '2880002', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '明神町', 'ミョウジンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市黒生町', '12', '12202', '2880003', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '黒生町', 'クロハイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市笠上町', '12', '12202', '2880004', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '笠上町', 'カサガミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市海鹿島町', '12', '12202', '2880005', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '海鹿島町', 'アシカジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市榊町', '12', '12202', '2880006', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '榊町', 'サカキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市愛宕町', '12', '12202', '2880007', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '愛宕町', 'アタゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市君ケ浜', '12', '12202', '2880011', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '君ケ浜', 'キミガハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市犬吠埼', '12', '12202', '2880012', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '犬吠埼', 'イヌボウザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市長崎町', '12', '12202', '2880013', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '長崎町', 'ナガサキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市外川町', '12', '12202', '2880014', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '外川町', 'トカワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市犬若', '12', '12202', '2880015', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '犬若', 'イヌワカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市外川台町', '12', '12202', '2880016', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '外川台町', 'トカワダイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市小畑新町', '12', '12202', '2880021', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '小畑新町', 'コバタケシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市小畑町', '12', '12202', '2880022', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '小畑町', 'コバタケマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市高神東町', '12', '12202', '2880023', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '高神東町', 'タカガミヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市天王台', '12', '12202', '2880024', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '天王台', 'テンノウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市潮見町', '12', '12202', '2880025', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '潮見町', 'シオミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市高神西町', '12', '12202', '2880026', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '高神西町', 'タカガミニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市高神原町', '12', '12202', '2880027', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '高神原町', 'タカガミハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市前宿町', '12', '12202', '2880031', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '前宿町', 'マエジュクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市東小川町', '12', '12202', '2880032', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '東小川町', 'ヒガシオガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市南小川町', '12', '12202', '2880033', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '南小川町', 'ミナミオガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市粟島町', '12', '12202', '2880034', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '粟島町', 'アワシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市名洗町', '12', '12202', '2880035', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '名洗町', 'ナアライマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市西小川町', '12', '12202', '2880036', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '西小川町', 'ニシオガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市北小川町', '12', '12202', '2880037', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '北小川町', 'キタオガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市南町', '12', '12202', '2880038', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '南町', 'ミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市中央町', '12', '12202', '2880041', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '中央町', 'チュウオウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市末広町', '12', '12202', '2880042', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '末広町', 'スエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市東芝町', '12', '12202', '2880043', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '東芝町', 'ヒガシシバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市西芝町', '12', '12202', '2880044', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '西芝町', 'ニシシバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市三軒町', '12', '12202', '2880045', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '三軒町', 'サンゲンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市大橋町', '12', '12202', '2880046', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '大橋町', 'オオハシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市若宮町', '12', '12202', '2880047', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '若宮町', 'ワカミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市双葉町', '12', '12202', '2880048', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '双葉町', 'フタバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市飯沼町', '12', '12202', '2880051', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '飯沼町', 'イイヌマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市浜町', '12', '12202', '2880052', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '浜町', 'ハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市東町', '12', '12202', '2880053', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '東町', 'ヒガシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市馬場町', '12', '12202', '2880054', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '馬場町', 'ババチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市陣屋町', '12', '12202', '2880055', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '陣屋町', 'ジンヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市新生町', '12', '12202', '2880056', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '新生町', 'アラオイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市港町', '12', '12202', '2880061', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '港町', 'ミナトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市竹町', '12', '12202', '2880062', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '竹町', 'タケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市清水町', '12', '12202', '2880063', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '清水町', 'シミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市後飯町', '12', '12202', '2880064', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '後飯町', 'ゴハンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市田中町', '12', '12202', '2880065', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '田中町', 'タナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市和田町', '12', '12202', '2880066', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '和田町', 'ワダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市新地町', '12', '12202', '2880067', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '新地町', 'シンチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市内浜町', '12', '12202', '2880068', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '内浜町', 'ウチバマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市植松町', '12', '12202', '2880071', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '植松町', 'ウエマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市弥生町', '12', '12202', '2880072', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '弥生町', 'ヤヨイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市幸町', '12', '12202', '2880073', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市橋本町', '12', '12202', '2880074', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '橋本町', 'ハシモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市通町', '12', '12202', '2880075', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '通町', 'トオリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市本町', '12', '12202', '2880076', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市仲町', '12', '12202', '2880077', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '仲町', 'ナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市唐子町', '12', '12202', '2880801', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '唐子町', 'カラコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市松本町', '12', '12202', '2880802', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '松本町', 'マツモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市八幡町', '12', '12202', '2880803', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '八幡町', 'ヤハタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市今宮町', '12', '12202', '2880804', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '今宮町', 'イマミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市上野町', '12', '12202', '2880805', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '上野町', 'ウエノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市妙見町', '12', '12202', '2880811', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '妙見町', 'ミョウケンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市栄町', '12', '12202', '2880812', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '栄町', 'サカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市台町', '12', '12202', '2880813', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '台町', 'ダイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市春日町', '12', '12202', '2880814', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '春日町', 'カスガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市三崎町', '12', '12202', '2880815', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '三崎町', 'ミサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市春日台町', '12', '12202', '2880816', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '春日台町', 'カスガダイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市清川町', '12', '12202', '2880817', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '清川町', 'キヨカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市小浜町', '12', '12202', '2880821', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '小浜町', 'オバマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市八木町', '12', '12202', '2880822', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '八木町', 'ヤギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市親田町', '12', '12202', '2880823', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '親田町', 'オヤダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市常世田町', '12', '12202', '2880824', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '常世田町', 'トコヨダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市新町', '12', '12202', '2880825', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '新町', 'シンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市本城町', '12', '12202', '2880831', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '本城町', 'ホンジョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市松岸見晴台', '12', '12202', '2880832', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '松岸見晴台', 'マツギシミハラシダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市垣根見晴台', '12', '12202', '2880833', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '垣根見晴台', 'カキネミハラシダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市高野町', '12', '12202', '2880834', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '高野町', 'タカノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市垣根町', '12', '12202', '2880835', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '垣根町', 'カキネマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市松岸町', '12', '12202', '2880836', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '松岸町', 'マツギシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市長塚町', '12', '12202', '2880837', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '長塚町', 'ナガツカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市四日市場町', '12', '12202', '2880841', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '四日市場町', 'ヨッカイチバマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市柴崎町', '12', '12202', '2880842', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '柴崎町', 'シバサキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市四日市場台', '12', '12202', '2880843', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '四日市場台', 'ヨッカイチバダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市赤塚町', '12', '12202', '2880844', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '赤塚町', 'アカヅカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市三宅町', '12', '12202', '2880845', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '三宅町', 'ミヤケマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市余山町', '12', '12202', '2880846', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '余山町', 'ヨヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市三門町', '12', '12202', '2880851', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '三門町', 'ミカドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市岡野台町', '12', '12202', '2880852', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '岡野台町', 'オカノダイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市白石町', '12', '12202', '2880853', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '白石町', 'シライシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市茶畑町', '12', '12202', '2880854', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '茶畑町', 'チャバタケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市猿田町', '12', '12202', '2880855', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '猿田町', 'サルダチョウ', null, null, null, null), ('17666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市正明寺町', '12', '12202', '2880856', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '正明寺町', 'ショウミョウジチョウ', null, null, null, null), ('17667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市船木町', '12', '12202', '2880857', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '船木町', 'フナキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市中島町', '12', '12202', '2880858', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '中島町', 'ナカジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市芦崎町', '12', '12202', '2880861', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '芦崎町', 'アシサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市高田町', '12', '12202', '2880862', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '高田町', 'タカダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市野尻町', '12', '12202', '2880863', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '野尻町', 'ノジリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市小船木町', '12', '12202', '2880864', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '小船木町', 'コブナキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市長山町', '12', '12202', '2880865', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '長山町', 'ナガヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市小長町', '12', '12202', '2880866', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '小長町', 'コナガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市忍町', '12', '12202', '2880867', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '忍町', 'シノビチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市塚本町', '12', '12202', '2880868', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '塚本町', 'ツカモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市富川町', '12', '12202', '2880871', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '富川町', 'トミガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市森戸町', '12', '12202', '2880872', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '森戸町', 'モリトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市笹本町', '12', '12202', '2880873', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '笹本町', 'ササモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市豊里台', '12', '12202', '2880874', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '豊里台', 'トヨサトダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市諸持町', '12', '12202', '2880875', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '諸持町', 'モロモチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市桜井町', '12', '12202', '2880876', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '桜井町', 'サクライチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県銚子市宮原町', '12', '12202', '2880877', '千葉県', 'チバケン', '銚子市', 'チョウシシ', '宮原町', 'ミヤバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県久慈市宇部町', '03', '03207', '0288111', '岩手県', 'イワテケン', '久慈市', 'クジシ', '宇部町', 'ウベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡野田村', '03', '03503', '0288200', '岩手県', 'イワテケン', '九戸郡野田村', 'クノヘグンノダムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('17686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡野田村野田', '03', '03503', '0288201', '岩手県', 'イワテケン', '九戸郡野田村', 'クノヘグンノダムラ', '野田', 'ノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡野田村玉川', '03', '03503', '0288202', '岩手県', 'イワテケン', '九戸郡野田村', 'クノヘグンノダムラ', '玉川', 'タマガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡普代村', '03', '03485', '0288300', '岩手県', 'イワテケン', '下閉伊郡普代村', 'シモヘイグンフダイムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('17689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡普代村馬場野', '03', '03485', '0288301', '岩手県', 'イワテケン', '下閉伊郡普代村', 'シモヘイグンフダイムラ', '馬場野', 'ババノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡普代村堀内', '03', '03485', '0288302', '岩手県', 'イワテケン', '下閉伊郡普代村', 'シモヘイグンフダイムラ', '堀内', 'ホリナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡普代村沢向', '03', '03485', '0288303', '岩手県', 'イワテケン', '下閉伊郡普代村', 'シモヘイグンフダイムラ', '沢向', 'サワムカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡普代村白井', '03', '03485', '0288311', '岩手県', 'イワテケン', '下閉伊郡普代村', 'シモヘイグンフダイムラ', '白井', 'シライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡普代村小谷地', '03', '03485', '0288312', '岩手県', 'イワテケン', '下閉伊郡普代村', 'シモヘイグンフダイムラ', '小谷地', 'コヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡普代村土取場', '03', '03485', '0288313', '岩手県', 'イワテケン', '下閉伊郡普代村', 'シモヘイグンフダイムラ', '土取場', 'ツチトリバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡普代村野胡桃', '03', '03485', '0288321', '岩手県', 'イワテケン', '下閉伊郡普代村', 'シモヘイグンフダイムラ', '野胡桃', 'ノグルミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡普代村天拝坂', '03', '03485', '0288322', '岩手県', 'イワテケン', '下閉伊郡普代村', 'シモヘイグンフダイムラ', '天拝坂', 'テンバイザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡普代村鳥居', '03', '03485', '0288323', '岩手県', 'イワテケン', '下閉伊郡普代村', 'シモヘイグンフダイムラ', '鳥居', 'トリイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡普代村宇留部', '03', '03485', '0288331', '岩手県', 'イワテケン', '下閉伊郡普代村', 'シモヘイグンフダイムラ', '宇留部', 'ウルベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡普代村銅屋', '03', '03485', '0288332', '岩手県', 'イワテケン', '下閉伊郡普代村', 'シモヘイグンフダイムラ', '銅屋', 'ドウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡普代村羅賀', '03', '03485', '0288333', '岩手県', 'イワテケン', '下閉伊郡普代村', 'シモヘイグンフダイムラ', '羅賀', 'ラガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡普代村中村', '03', '03485', '0288334', '岩手県', 'イワテケン', '下閉伊郡普代村', 'シモヘイグンフダイムラ', '中村', 'ナカムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡普代村普代', '03', '03485', '0288335', '岩手県', 'イワテケン', '下閉伊郡普代村', 'シモヘイグンフダイムラ', '普代', 'フダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡普代村堤', '03', '03485', '0288336', '岩手県', 'イワテケン', '下閉伊郡普代村', 'シモヘイグンフダイムラ', '堤', 'ツツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡普代村明神', '03', '03485', '0288341', '岩手県', 'イワテケン', '下閉伊郡普代村', 'シモヘイグンフダイムラ', '明神', 'ミョウジン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡普代村和野山', '03', '03485', '0288342', '岩手県', 'イワテケン', '下閉伊郡普代村', 'シモヘイグンフダイムラ', '和野山', 'ワノヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡普代村上の山', '03', '03485', '0288343', '岩手県', 'イワテケン', '下閉伊郡普代村', 'シモヘイグンフダイムラ', '上の山', 'ウエノヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡普代村中山', '03', '03485', '0288344', '岩手県', 'イワテケン', '下閉伊郡普代村', 'シモヘイグンフダイムラ', '中山', 'ナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡普代村太田名部', '03', '03485', '0288345', '岩手県', 'イワテケン', '下閉伊郡普代村', 'シモヘイグンフダイムラ', '太田名部', 'オオタナベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡普代村下村', '03', '03485', '0288351', '岩手県', 'イワテケン', '下閉伊郡普代村', 'シモヘイグンフダイムラ', '下村', 'シモムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡普代村上村', '03', '03485', '0288352', '岩手県', 'イワテケン', '下閉伊郡普代村', 'シモヘイグンフダイムラ', '上村', 'カミムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡普代村黒崎', '03', '03485', '0288353', '岩手県', 'イワテケン', '下閉伊郡普代村', 'シモヘイグンフダイムラ', '黒崎', 'クロサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡普代村北ノ股', '03', '03485', '0288361', '岩手県', 'イワテケン', '下閉伊郡普代村', 'シモヘイグンフダイムラ', '北ノ股', 'キタノマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡普代村卯子酉', '03', '03485', '0288362', '岩手県', 'イワテケン', '下閉伊郡普代村', 'シモヘイグンフダイムラ', '卯子酉', 'ウネドリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡普代村茂市', '03', '03485', '0288363', '岩手県', 'イワテケン', '下閉伊郡普代村', 'シモヘイグンフダイムラ', '茂市', 'モイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡普代村南股', '03', '03485', '0288364', '岩手県', 'イワテケン', '下閉伊郡普代村', 'シモヘイグンフダイムラ', '南股', 'ミナミノマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡普代村芦渡', '03', '03485', '0288365', '岩手県', 'イワテケン', '下閉伊郡普代村', 'シモヘイグンフダイムラ', '芦渡', 'アシワタリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡普代村芦生', '03', '03485', '0288366', '岩手県', 'イワテケン', '下閉伊郡普代村', 'シモヘイグンフダイムラ', '芦生', 'アシオイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡普代村萩牛', '03', '03485', '0288367', '岩手県', 'イワテケン', '下閉伊郡普代村', 'シモヘイグンフダイムラ', '萩牛', 'ハギュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡普代村柏木平', '03', '03485', '0288368', '岩手県', 'イワテケン', '下閉伊郡普代村', 'シモヘイグンフダイムラ', '柏木平', 'カシワギダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡田野畑村', '03', '03484', '0288400', '岩手県', 'イワテケン', '下閉伊郡田野畑村', 'シモヘイグンタノハタムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('17722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡田野畑村一の渡', '03', '03484', '0288401', '岩手県', 'イワテケン', '下閉伊郡田野畑村', 'シモヘイグンタノハタムラ', '一の渡', 'イチノワタリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡田野畑村蝦夷森', '03', '03484', '0288401', '岩手県', 'イワテケン', '下閉伊郡田野畑村', 'シモヘイグンタノハタムラ', '蝦夷森', 'エゾモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡田野畑村大森', '03', '03484', '0288401', '岩手県', 'イワテケン', '下閉伊郡田野畑村', 'シモヘイグンタノハタムラ', '大森', 'オオモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡田野畑村尾肝要', '03', '03484', '0288401', '岩手県', 'イワテケン', '下閉伊郡田野畑村', 'シモヘイグンタノハタムラ', '尾肝要', 'オカンヨウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡田野畑村奥地', '03', '03484', '0288401', '岩手県', 'イワテケン', '下閉伊郡田野畑村', 'シモヘイグンタノハタムラ', '奥地', 'オクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡田野畑村奥地向', '03', '03484', '0288401', '岩手県', 'イワテケン', '下閉伊郡田野畑村', 'シモヘイグンタノハタムラ', '奥地向', 'オクチムカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡田野畑村茅刈沢', '03', '03484', '0288401', '岩手県', 'イワテケン', '下閉伊郡田野畑村', 'シモヘイグンタノハタムラ', '茅刈沢', 'カヤカリサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡田野畑村巣合', '03', '03484', '0288401', '岩手県', 'イワテケン', '下閉伊郡田野畑村', 'シモヘイグンタノハタムラ', '巣合', 'スゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡田野畑村千丈', '03', '03484', '0288401', '岩手県', 'イワテケン', '下閉伊郡田野畑村', 'シモヘイグンタノハタムラ', '千丈', 'センジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡田野畑村千足', '03', '03484', '0288401', '岩手県', 'イワテケン', '下閉伊郡田野畑村', 'シモヘイグンタノハタムラ', '千足', 'センゾク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡田野畑村滝ノ沢', '03', '03484', '0288401', '岩手県', 'イワテケン', '下閉伊郡田野畑村', 'シモヘイグンタノハタムラ', '滝ノ沢', 'タキノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡田野畑村田代', '03', '03484', '0288401', '岩手県', 'イワテケン', '下閉伊郡田野畑村', 'シモヘイグンタノハタムラ', '田代', 'タシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡田野畑村長根', '03', '03484', '0288401', '岩手県', 'イワテケン', '下閉伊郡田野畑村', 'シモヘイグンタノハタムラ', '長根', 'ナガネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡田野畑村沼袋', '03', '03484', '0288401', '岩手県', 'イワテケン', '下閉伊郡田野畑村', 'シモヘイグンタノハタムラ', '沼袋', 'ヌマブクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡田野畑村子木地', '03', '03484', '0288401', '岩手県', 'イワテケン', '下閉伊郡田野畑村', 'シモヘイグンタノハタムラ', '子木地', 'ネギチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡田野畑村子木屋敷', '03', '03484', '0288401', '岩手県', 'イワテケン', '下閉伊郡田野畑村', 'シモヘイグンタノハタムラ', '子木屋敷', 'ネギヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡田野畑村萩牛', '03', '03484', '0288401', '岩手県', 'イワテケン', '下閉伊郡田野畑村', 'シモヘイグンタノハタムラ', '萩牛', 'ハギュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡田野畑村日蔭', '03', '03484', '0288401', '岩手県', 'イワテケン', '下閉伊郡田野畑村', 'シモヘイグンタノハタムラ', '日蔭', 'ヒカゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡田野畑村姫松', '03', '03484', '0288401', '岩手県', 'イワテケン', '下閉伊郡田野畑村', 'シモヘイグンタノハタムラ', '姫松', 'ヒメマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡田野畑村三沢', '03', '03484', '0288401', '岩手県', 'イワテケン', '下閉伊郡田野畑村', 'シモヘイグンタノハタムラ', '三沢', 'ミサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡田野畑村明戸', '03', '03484', '0288402', '岩手県', 'イワテケン', '下閉伊郡田野畑村', 'シモヘイグンタノハタムラ', '明戸', 'アケト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡田野畑村北山', '03', '03484', '0288402', '岩手県', 'イワテケン', '下閉伊郡田野畑村', 'シモヘイグンタノハタムラ', '北山', 'キタヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡田野畑村机', '03', '03484', '0288402', '岩手県', 'イワテケン', '下閉伊郡田野畑村', 'シモヘイグンタノハタムラ', '机', 'ツクエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡田野畑村羅賀', '03', '03484', '0288403', '岩手県', 'イワテケン', '下閉伊郡田野畑村', 'シモヘイグンタノハタムラ', '羅賀', 'ラガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡田野畑村島越', '03', '03484', '0288404', '岩手県', 'イワテケン', '下閉伊郡田野畑村', 'シモヘイグンタノハタムラ', '島越', 'シマノコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡田野畑村松前沢', '03', '03484', '0288404', '岩手県', 'イワテケン', '下閉伊郡田野畑村', 'シモヘイグンタノハタムラ', '松前沢', 'マツマエサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡田野畑村大芦', '03', '03484', '0288405', '岩手県', 'イワテケン', '下閉伊郡田野畑村', 'シモヘイグンタノハタムラ', '大芦', 'オオアシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡田野畑村切牛', '03', '03484', '0288405', '岩手県', 'イワテケン', '下閉伊郡田野畑村', 'シモヘイグンタノハタムラ', '切牛', 'キリウシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡田野畑村浜岩泉', '03', '03484', '0288405', '岩手県', 'イワテケン', '下閉伊郡田野畑村', 'シモヘイグンタノハタムラ', '浜岩泉', 'ハマイワイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡田野畑村真木沢', '03', '03484', '0288405', '岩手県', 'イワテケン', '下閉伊郡田野畑村', 'シモヘイグンタノハタムラ', '真木沢', 'マギサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡田野畑村南大芦', '03', '03484', '0288405', '岩手県', 'イワテケン', '下閉伊郡田野畑村', 'シモヘイグンタノハタムラ', '南大芦', 'ミナミオオアシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡田野畑村猿山', '03', '03484', '0288406', '岩手県', 'イワテケン', '下閉伊郡田野畑村', 'シモヘイグンタノハタムラ', '猿山', 'サルヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡田野畑村年呂部', '03', '03484', '0288406', '岩手県', 'イワテケン', '下閉伊郡田野畑村', 'シモヘイグンタノハタムラ', '年呂部', 'トシロベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡田野畑村七滝', '03', '03484', '0288406', '岩手県', 'イワテケン', '下閉伊郡田野畑村', 'シモヘイグンタノハタムラ', '七滝', 'ナナタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡田野畑村室場', '03', '03484', '0288406', '岩手県', 'イワテケン', '下閉伊郡田野畑村', 'シモヘイグンタノハタムラ', '室場', 'ムロバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡田野畑村目名', '03', '03484', '0288406', '岩手県', 'イワテケン', '下閉伊郡田野畑村', 'シモヘイグンタノハタムラ', '目名', 'メナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡田野畑村川平', '03', '03484', '0288407', '岩手県', 'イワテケン', '下閉伊郡田野畑村', 'シモヘイグンタノハタムラ', '川平', 'カワダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡田野畑村菅窪', '03', '03484', '0288407', '岩手県', 'イワテケン', '下閉伊郡田野畑村', 'シモヘイグンタノハタムラ', '菅窪', 'スゲノクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡田野畑村田野畑', '03', '03484', '0288407', '岩手県', 'イワテケン', '下閉伊郡田野畑村', 'シモヘイグンタノハタムラ', '田野畑', 'タノハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県下閉伊郡田野畑村和野', '03', '03484', '0288407', '岩手県', 'イワテケン', '下閉伊郡田野畑村', 'シモヘイグンタノハタムラ', '和野', 'ワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県久慈市山根町', '03', '03207', '0288521', '岩手県', 'イワテケン', '久慈市', 'クジシ', '山根町', 'ヤマネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県久慈市山形町戸呂町', '03', '03207', '0288601', '岩手県', 'イワテケン', '久慈市', 'クジシ', '山形町戸呂町', 'ヤマガタチョウヘロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県久慈市山形町川井', '03', '03207', '0288602', '岩手県', 'イワテケン', '久慈市', 'クジシ', '山形町川井', 'ヤマガタチョウカワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県久慈市山形町荷軽部', '03', '03207', '0288603', '岩手県', 'イワテケン', '久慈市', 'クジシ', '山形町荷軽部', 'ヤマガタチョウニカルベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県久慈市山形町日野沢', '03', '03207', '0288604', '岩手県', 'イワテケン', '久慈市', 'クジシ', '山形町日野沢', 'ヤマガタチョウヒノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県久慈市山形町来内', '03', '03207', '0288605', '岩手県', 'イワテケン', '久慈市', 'クジシ', '山形町来内', 'ヤマガタチョウライナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県久慈市山形町繋', '03', '03207', '0288711', '岩手県', 'イワテケン', '久慈市', 'クジシ', '山形町繋', 'ヤマガタチョウツナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県久慈市山形町小国', '03', '03207', '0288712', '岩手県', 'イワテケン', '久慈市', 'クジシ', '山形町小国', 'ヤマガタチョウオグニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県久慈市山形町霜畑', '03', '03207', '0288713', '岩手県', 'イワテケン', '久慈市', 'クジシ', '山形町霜畑', 'ヤマガタチョウシモハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡洋野町上館', '03', '03507', '0288801', '岩手県', 'イワテケン', '九戸郡洋野町', 'クノヘグンヒロノチョウ', '上館', 'カミダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡洋野町大野', '03', '03507', '0288802', '岩手県', 'イワテケン', '九戸郡洋野町', 'クノヘグンヒロノチョウ', '大野', 'オオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡洋野町阿子木', '03', '03507', '0288803', '岩手県', 'イワテケン', '九戸郡洋野町', 'クノヘグンヒロノチョウ', '阿子木', 'アコギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡洋野町帯島', '03', '03507', '0288804', '岩手県', 'イワテケン', '九戸郡洋野町', 'クノヘグンヒロノチョウ', '帯島', 'タイシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県九戸郡洋野町水沢', '03', '03507', '0288805', '岩手県', 'イワテケン', '九戸郡洋野町', 'クノヘグンヒロノチョウ', '水沢', 'ミズサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取郡神崎町', '12', '12342', '2890100', '千葉県', 'チバケン', '香取郡神崎町', 'カトリグンコウザキマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('17779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市小浮', '12', '12211', '2890101', '千葉県', 'チバケン', '成田市', 'ナリタシ', '小浮', 'コブケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市野馬込', '12', '12211', '2890102', '千葉県', 'チバケン', '成田市', 'ナリタシ', '野馬込', 'ノマゴメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市高', '12', '12211', '2890103', '千葉県', 'チバケン', '成田市', 'ナリタシ', '高', 'タカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市冬父', '12', '12211', '2890104', '千葉県', 'チバケン', '成田市', 'ナリタシ', '冬父', 'トブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市中里', '12', '12211', '2890105', '千葉県', 'チバケン', '成田市', 'ナリタシ', '中里', 'ナカザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市小野', '12', '12211', '2890106', '千葉県', 'チバケン', '成田市', 'ナリタシ', '小野', 'オノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市猿山', '12', '12211', '2890107', '千葉県', 'チバケン', '成田市', 'ナリタシ', '猿山', 'サルヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市高岡', '12', '12211', '2890108', '千葉県', 'チバケン', '成田市', 'ナリタシ', '高岡', 'タカオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市大和田', '12', '12211', '2890109', '千葉県', 'チバケン', '成田市', 'ナリタシ', '大和田', 'オオワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市名木', '12', '12211', '2890111', '千葉県', 'チバケン', '成田市', 'ナリタシ', '名木', 'ナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市青山', '12', '12211', '2890112', '千葉県', 'チバケン', '成田市', 'ナリタシ', '青山', 'アオヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市倉水', '12', '12211', '2890113', '千葉県', 'チバケン', '成田市', 'ナリタシ', '倉水', 'クラミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市成井', '12', '12211', '2890114', '千葉県', 'チバケン', '成田市', 'ナリタシ', '成井', 'ナルイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市地蔵原新田', '12', '12211', '2890115', '千葉県', 'チバケン', '成田市', 'ナリタシ', '地蔵原新田', 'ジゾウハラシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市名古屋', '12', '12211', '2890116', '千葉県', 'チバケン', '成田市', 'ナリタシ', '名古屋', 'ナゴヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市七沢', '12', '12211', '2890117', '千葉県', 'チバケン', '成田市', 'ナリタシ', '七沢', 'ナナサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市大菅', '12', '12211', '2890121', '千葉県', 'チバケン', '成田市', 'ナリタシ', '大菅', 'オオスゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市高倉', '12', '12211', '2890122', '千葉県', 'チバケン', '成田市', 'ナリタシ', '高倉', 'タカクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市四ツ谷', '12', '12211', '2890123', '千葉県', 'チバケン', '成田市', 'ナリタシ', '四ツ谷', 'ヨツヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市西大須賀', '12', '12211', '2890124', '千葉県', 'チバケン', '成田市', 'ナリタシ', '西大須賀', 'ニシオオスカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県成田市滑川', '12', '12211', '2890125', '千葉県', 'チバケン', '成田市', 'ナリタシ', '滑川', 'ナメガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取郡神崎町高谷', '12', '12342', '2890201', '千葉県', 'チバケン', '香取郡神崎町', 'カトリグンコウザキマチ', '高谷', 'コウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取郡神崎町郡', '12', '12342', '2890202', '千葉県', 'チバケン', '香取郡神崎町', 'カトリグンコウザキマチ', '郡', 'コオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取郡神崎町大貫', '12', '12342', '2890203', '千葉県', 'チバケン', '香取郡神崎町', 'カトリグンコウザキマチ', '大貫', 'オオヌキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取郡神崎町四季の丘', '12', '12342', '2890204', '千葉県', 'チバケン', '香取郡神崎町', 'カトリグンコウザキマチ', '四季の丘', 'シキノオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取郡神崎町今', '12', '12342', '2890205', '千葉県', 'チバケン', '香取郡神崎町', 'カトリグンコウザキマチ', '今', 'イマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取郡神崎町立野', '12', '12342', '2890211', '千葉県', 'チバケン', '香取郡神崎町', 'カトリグンコウザキマチ', '立野', 'タチノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取郡神崎町武田', '12', '12342', '2890212', '千葉県', 'チバケン', '香取郡神崎町', 'カトリグンコウザキマチ', '武田', 'タケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取郡神崎町新', '12', '12342', '2890213', '千葉県', 'チバケン', '香取郡神崎町', 'カトリグンコウザキマチ', '新', 'シン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取郡神崎町毛成', '12', '12342', '2890214', '千葉県', 'チバケン', '香取郡神崎町', 'カトリグンコウザキマチ', '毛成', 'ケナリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取郡神崎町古原', '12', '12342', '2890215', '千葉県', 'チバケン', '香取郡神崎町', 'カトリグンコウザキマチ', '古原', 'コハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取郡神崎町植房', '12', '12342', '2890216', '千葉県', 'チバケン', '香取郡神崎町', 'カトリグンコウザキマチ', '植房', 'ウエボウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取郡神崎町藤の台', '12', '12342', '2890217', '千葉県', 'チバケン', '香取郡神崎町', 'カトリグンコウザキマチ', '藤の台', 'フジノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取郡神崎町神崎本宿', '12', '12342', '2890221', '千葉県', 'チバケン', '香取郡神崎町', 'カトリグンコウザキマチ', '神崎本宿', 'コウザキホンシュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取郡神崎町並木', '12', '12342', '2890222', '千葉県', 'チバケン', '香取郡神崎町', 'カトリグンコウザキマチ', '並木', 'ナミキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取郡神崎町小松', '12', '12342', '2890223', '千葉県', 'チバケン', '香取郡神崎町', 'カトリグンコウザキマチ', '小松', 'コマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取郡神崎町松崎', '12', '12342', '2890224', '千葉県', 'チバケン', '香取郡神崎町', 'カトリグンコウザキマチ', '松崎', 'マツザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取郡神崎町十三間戸', '12', '12342', '2890225', '千葉県', 'チバケン', '香取郡神崎町', 'カトリグンコウザキマチ', '十三間戸', 'ジュウサンマド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取郡神崎町神崎神宿', '12', '12342', '2890226', '千葉県', 'チバケン', '香取郡神崎町', 'カトリグンコウザキマチ', '神崎神宿', 'コウザキシンシュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市一ノ分目', '12', '12236', '2890301', '千葉県', 'チバケン', '香取市', 'カトリシ', '一ノ分目', 'イチノワケメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市三ノ分目', '12', '12236', '2890302', '千葉県', 'チバケン', '香取市', 'カトリシ', '三ノ分目', 'サンノワケメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市富田', '12', '12236', '2890303', '千葉県', 'チバケン', '香取市', 'カトリシ', '富田', 'トミタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市下小堀', '12', '12236', '2890304', '千葉県', 'チバケン', '香取市', 'カトリシ', '下小堀', 'シモコボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市分郷', '12', '12236', '2890305', '千葉県', 'チバケン', '香取市', 'カトリシ', '分郷', 'ワカレゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市上小堀', '12', '12236', '2890306', '千葉県', 'チバケン', '香取市', 'カトリシ', '上小堀', 'カミコボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市増田', '12', '12236', '2890307', '千葉県', 'チバケン', '香取市', 'カトリシ', '増田', 'マシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市木内虫幡上小堀入会地大平', '12', '12236', '2890308', '千葉県', 'チバケン', '香取市', 'カトリシ', '木内虫幡上小堀入会地大平', 'キノウチムシハタカミコボリイリアイチオオダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市八日市場', '12', '12236', '2890311', '千葉県', 'チバケン', '香取市', 'カトリシ', '八日市場', 'ヨウカイチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市本郷', '12', '12236', '2890312', '千葉県', 'チバケン', '香取市', 'カトリシ', '本郷', 'ホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市小見川', '12', '12236', '2890313', '千葉県', 'チバケン', '香取市', 'カトリシ', '小見川', 'オミガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市野田', '12', '12236', '2890314', '千葉県', 'チバケン', '香取市', 'カトリシ', '野田', 'ノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市阿玉川', '12', '12236', '2890321', '千葉県', 'チバケン', '香取市', 'カトリシ', '阿玉川', 'アタマガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市下飯田', '12', '12236', '2890322', '千葉県', 'チバケン', '香取市', 'カトリシ', '下飯田', 'シモイイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市岡飯田', '12', '12236', '2890323', '千葉県', 'チバケン', '香取市', 'カトリシ', '岡飯田', 'オカイイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市和泉', '12', '12236', '2890324', '千葉県', 'チバケン', '香取市', 'カトリシ', '和泉', 'イズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市貝塚', '12', '12236', '2890325', '千葉県', 'チバケン', '香取市', 'カトリシ', '貝塚', 'カイヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市阿玉台', '12', '12236', '2890326', '千葉県', 'チバケン', '香取市', 'カトリシ', '阿玉台', 'アタマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市久保', '12', '12236', '2890327', '千葉県', 'チバケン', '香取市', 'カトリシ', '久保', 'クボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市五郷内', '12', '12236', '2890328', '千葉県', 'チバケン', '香取市', 'カトリシ', '五郷内', 'ゴゴウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市布野', '12', '12236', '2890329', '千葉県', 'チバケン', '香取市', 'カトリシ', '布野', 'フノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市羽根川', '12', '12236', '2890331', '千葉県', 'チバケン', '香取市', 'カトリシ', '羽根川', 'ハネガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市南原地新田', '12', '12236', '2890332', '千葉県', 'チバケン', '香取市', 'カトリシ', '南原地新田', 'ミナミハラチシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市入会地', '12', '12236', '2890333', '千葉県', 'チバケン', '香取市', 'カトリシ', '入会地', 'イリアイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市川頭', '12', '12236', '2890334', '千葉県', 'チバケン', '香取市', 'カトリシ', '川頭', 'カワガシラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市北原地新田', '12', '12236', '2890335', '千葉県', 'チバケン', '香取市', 'カトリシ', '北原地新田', 'キタハラチシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市新々田', '12', '12236', '2890336', '千葉県', 'チバケン', '香取市', 'カトリシ', '新々田', 'シンシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市木内', '12', '12236', '2890337', '千葉県', 'チバケン', '香取市', 'カトリシ', '木内', 'キノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市下小川', '12', '12236', '2890338', '千葉県', 'チバケン', '香取市', 'カトリシ', '下小川', 'シモオガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市虫幡', '12', '12236', '2890341', '千葉県', 'チバケン', '香取市', 'カトリシ', '虫幡', 'ムシハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市竜谷', '12', '12236', '2890342', '千葉県', 'チバケン', '香取市', 'カトリシ', '竜谷', 'リュウザク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市山川', '12', '12236', '2890343', '千葉県', 'チバケン', '香取市', 'カトリシ', '山川', 'ヤマガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市白井', '12', '12236', '2890344', '千葉県', 'チバケン', '香取市', 'カトリシ', '白井', 'シライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市八本', '12', '12236', '2890345', '千葉県', 'チバケン', '香取市', 'カトリシ', '八本', 'ハチホン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市油田', '12', '12236', '2890346', '千葉県', 'チバケン', '香取市', 'カトリシ', '油田', 'アブラタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市旗鉾', '12', '12236', '2890347', '千葉県', 'チバケン', '香取市', 'カトリシ', '旗鉾', 'ハタホコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市織幡', '12', '12236', '2890348', '千葉県', 'チバケン', '香取市', 'カトリシ', '織幡', 'オリハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市内野', '12', '12236', '2890349', '千葉県', 'チバケン', '香取市', 'カトリシ', '内野', 'ウチノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市米野井', '12', '12236', '2890401', '千葉県', 'チバケン', '香取市', 'カトリシ', '米野井', 'コメノイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市小見', '12', '12236', '2890402', '千葉県', 'チバケン', '香取市', 'カトリシ', '小見', 'オミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市川上', '12', '12236', '2890403', '千葉県', 'チバケン', '香取市', 'カトリシ', '川上', 'カワカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市高野', '12', '12236', '2890404', '千葉県', 'チバケン', '香取市', 'カトリシ', '高野', 'コウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市竹之内', '12', '12236', '2890405', '千葉県', 'チバケン', '香取市', 'カトリシ', '竹之内', 'タケノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市田部', '12', '12236', '2890406', '千葉県', 'チバケン', '香取市', 'カトリシ', '田部', 'タベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市仁良', '12', '12236', '2890407', '千葉県', 'チバケン', '香取市', 'カトリシ', '仁良', 'ニラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市神生', '12', '12236', '2890408', '千葉県', 'チバケン', '香取市', 'カトリシ', '神生', 'カンノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市府馬', '12', '12236', '2890411', '千葉県', 'チバケン', '香取市', 'カトリシ', '府馬', 'フマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市古内', '12', '12236', '2890412', '千葉県', 'チバケン', '香取市', 'カトリシ', '古内', 'フルウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市志高', '12', '12236', '2890413', '千葉県', 'チバケン', '香取市', 'カトリシ', '志高', 'シダカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市長岡', '12', '12236', '2890414', '千葉県', 'チバケン', '香取市', 'カトリシ', '長岡', 'ナガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市鳩山', '12', '12236', '2890421', '千葉県', 'チバケン', '香取市', 'カトリシ', '鳩山', 'ハトヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市桐谷', '12', '12236', '2890422', '千葉県', 'チバケン', '香取市', 'カトリシ', '桐谷', 'キリザク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市小川', '12', '12236', '2890423', '千葉県', 'チバケン', '香取市', 'カトリシ', '小川', 'オガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市新里', '12', '12236', '2890424', '千葉県', 'チバケン', '香取市', 'カトリシ', '新里', 'ニッサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市大角', '12', '12236', '2890425', '千葉県', 'チバケン', '香取市', 'カトリシ', '大角', 'オオトガリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取市山倉', '12', '12236', '2890426', '千葉県', 'チバケン', '香取市', 'カトリシ', '山倉', 'ヤマクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県旭市清和乙', '12', '12215', '2890501', '千葉県', 'チバケン', '旭市', 'アサヒシ', '清和乙', 'セイワオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県旭市長部', '12', '12215', '2890502', '千葉県', 'チバケン', '旭市', 'アサヒシ', '長部', 'ナガベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県旭市溝原', '12', '12215', '2890503', '千葉県', 'チバケン', '旭市', 'アサヒシ', '溝原', 'ミゾワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県旭市櫻井', '12', '12215', '2890504', '千葉県', 'チバケン', '旭市', 'アサヒシ', '櫻井', 'サクライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県旭市萬歳', '12', '12215', '2890505', '千葉県', 'チバケン', '旭市', 'アサヒシ', '萬歳', 'マンザイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県旭市さくら台', '12', '12215', '2890506', '千葉県', 'チバケン', '旭市', 'アサヒシ', 'さくら台', 'サクラダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県旭市清和甲', '12', '12215', '2890507', '千葉県', 'チバケン', '旭市', 'アサヒシ', '清和甲', 'セイワコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県旭市鏑木', '12', '12215', '2890511', '千葉県', 'チバケン', '旭市', 'アサヒシ', '鏑木', 'カブラキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県旭市南堀之内', '12', '12215', '2890512', '千葉県', 'チバケン', '旭市', 'アサヒシ', '南堀之内', 'ミナミホリノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県旭市舟戸', '12', '12215', '2890513', '千葉県', 'チバケン', '旭市', 'アサヒシ', '舟戸', 'フナド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県旭市関戸', '12', '12215', '2890514', '千葉県', 'チバケン', '旭市', 'アサヒシ', '関戸', 'セキド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県旭市入野', '12', '12215', '2890515', '千葉県', 'チバケン', '旭市', 'アサヒシ', '入野', 'イリノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県旭市米込', '12', '12215', '2890516', '千葉県', 'チバケン', '旭市', 'アサヒシ', '米込', 'ヨネゴメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県旭市萬力', '12', '12215', '2890517', '千葉県', 'チバケン', '旭市', 'アサヒシ', '萬力', 'マンリキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県旭市秋田', '12', '12215', '2890518', '千葉県', 'チバケン', '旭市', 'アサヒシ', '秋田', 'アキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取郡東庄町', '12', '12349', '2890600', '千葉県', 'チバケン', '香取郡東庄町', 'カトリグントウノショウマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('17897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取郡東庄町笹川い', '12', '12349', '2890601', '千葉県', 'チバケン', '香取郡東庄町', 'カトリグントウノショウマチ', '笹川い', 'ササガワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取郡東庄町笹川ろ', '12', '12349', '2890602', '千葉県', 'チバケン', '香取郡東庄町', 'カトリグントウノショウマチ', '笹川ろ', 'ササガワロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取郡東庄町新宿', '12', '12349', '2890611', '千葉県', 'チバケン', '香取郡東庄町', 'カトリグントウノショウマチ', '新宿', 'ニイジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取郡東庄町石出', '12', '12349', '2890612', '千葉県', 'チバケン', '香取郡東庄町', 'カトリグントウノショウマチ', '石出', 'イシデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取郡東庄町東今泉', '12', '12349', '2890613', '千葉県', 'チバケン', '香取郡東庄町', 'カトリグントウノショウマチ', '東今泉', 'ヒガシイマイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取郡東庄町宮本', '12', '12349', '2890614', '千葉県', 'チバケン', '香取郡東庄町', 'カトリグントウノショウマチ', '宮本', 'ミヤモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取郡東庄町青馬', '12', '12349', '2890615', '千葉県', 'チバケン', '香取郡東庄町', 'カトリグントウノショウマチ', '青馬', 'オオマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取郡東庄町高部', '12', '12349', '2890616', '千葉県', 'チバケン', '香取郡東庄町', 'カトリグントウノショウマチ', '高部', 'タカベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取郡東庄町羽計', '12', '12349', '2890617', '千葉県', 'チバケン', '香取郡東庄町', 'カトリグントウノショウマチ', '羽計', 'ハバカリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取郡東庄町谷津', '12', '12349', '2890618', '千葉県', 'チバケン', '香取郡東庄町', 'カトリグントウノショウマチ', '谷津', 'ヤヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取郡東庄町今郡', '12', '12349', '2890619', '千葉県', 'チバケン', '香取郡東庄町', 'カトリグントウノショウマチ', '今郡', 'イマゴオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取郡東庄町大友', '12', '12349', '2890621', '千葉県', 'チバケン', '香取郡東庄町', 'カトリグントウノショウマチ', '大友', 'オオトモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取郡東庄町小座', '12', '12349', '2890622', '千葉県', 'チバケン', '香取郡東庄町', 'カトリグントウノショウマチ', '小座', 'オザ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取郡東庄町宮野台', '12', '12349', '2890623', '千葉県', 'チバケン', '香取郡東庄町', 'カトリグントウノショウマチ', '宮野台', 'ミヤノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取郡東庄町小南', '12', '12349', '2890624', '千葉県', 'チバケン', '香取郡東庄町', 'カトリグントウノショウマチ', '小南', 'コミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取郡東庄町夏目', '12', '12349', '2890625', '千葉県', 'チバケン', '香取郡東庄町', 'カトリグントウノショウマチ', '夏目', 'ナツメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取郡東庄町八重穂', '12', '12349', '2890626', '千葉県', 'チバケン', '香取郡東庄町', 'カトリグントウノショウマチ', '八重穂', 'ヤエボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取郡東庄町粟野', '12', '12349', '2890627', '千葉県', 'チバケン', '香取郡東庄町', 'カトリグントウノショウマチ', '粟野', 'アワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取郡東庄町平山', '12', '12349', '2890631', '千葉県', 'チバケン', '香取郡東庄町', 'カトリグントウノショウマチ', '平山', 'ヒラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取郡東庄町窪野谷', '12', '12349', '2890632', '千葉県', 'チバケン', '香取郡東庄町', 'カトリグントウノショウマチ', '窪野谷', 'クボノヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取郡東庄町大久保', '12', '12349', '2890633', '千葉県', 'チバケン', '香取郡東庄町', 'カトリグントウノショウマチ', '大久保', 'オオクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取郡東庄町舟戸', '12', '12349', '2890634', '千葉県', 'チバケン', '香取郡東庄町', 'カトリグントウノショウマチ', '舟戸', 'フナド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取郡東庄町神田', '12', '12349', '2890635', '千葉県', 'チバケン', '香取郡東庄町', 'カトリグントウノショウマチ', '神田', 'カンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取郡東庄町東和田', '12', '12349', '2890636', '千葉県', 'チバケン', '香取郡東庄町', 'カトリグントウノショウマチ', '東和田', 'トウワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取郡東庄町小貝野', '12', '12349', '2890637', '千葉県', 'チバケン', '香取郡東庄町', 'カトリグントウノショウマチ', '小貝野', 'コガイノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県八街市', '12', '12230', '2891100', '千葉県', 'チバケン', '八街市', 'ヤチマタシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('17924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県八街市朝日', '12', '12230', '2891101', '千葉県', 'チバケン', '八街市', 'ヤチマタシ', '朝日', 'アサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県八街市沖渡', '12', '12230', '2891102', '千葉県', 'チバケン', '八街市', 'ヤチマタシ', '沖渡', 'オキワタシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県八街市八街に', '12', '12230', '2891103', '千葉県', 'チバケン', '八街市', 'ヤチマタシ', '八街に', 'ヤチマタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県八街市文違', '12', '12230', '2891104', '千葉県', 'チバケン', '八街市', 'ヤチマタシ', '文違', 'ヒジカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県八街市泉台', '12', '12230', '2891105', '千葉県', 'チバケン', '八街市', 'ヤチマタシ', '泉台', 'イズミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県八街市榎戸', '12', '12230', '2891106', '千葉県', 'チバケン', '八街市', 'ヤチマタシ', '榎戸', 'エノキド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県八街市八街は', '12', '12230', '2891107', '千葉県', 'チバケン', '八街市', 'ヤチマタシ', '八街は', 'ヤチマタハ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県八街市雁丸', '12', '12230', '2891108', '千葉県', 'チバケン', '八街市', 'ヤチマタシ', '雁丸', 'ガンマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県八街市大木', '12', '12230', '2891111', '千葉県', 'チバケン', '八街市', 'ヤチマタシ', '大木', 'オオギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県八街市木原', '12', '12230', '2891112', '千葉県', 'チバケン', '八街市', 'ヤチマタシ', '木原', 'キバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県八街市八街へ', '12', '12230', '2891113', '千葉県', 'チバケン', '八街市', 'ヤチマタシ', '八街へ', 'ヤチマタヘ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県八街市東吉田', '12', '12230', '2891114', '千葉県', 'チバケン', '八街市', 'ヤチマタシ', '東吉田', 'ヒガシヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県八街市八街ほ', '12', '12230', '2891115', '千葉県', 'チバケン', '八街市', 'ヤチマタシ', '八街ほ', 'ヤチマタホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県八街市砂', '12', '12230', '2891121', '千葉県', 'チバケン', '八街市', 'ヤチマタシ', '砂', 'イサゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県八街市四木', '12', '12230', '2891122', '千葉県', 'チバケン', '八街市', 'ヤチマタシ', '四木', 'シモク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県八街市滝台', '12', '12230', '2891123', '千葉県', 'チバケン', '八街市', 'ヤチマタシ', '滝台', 'タキダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県八街市山田台', '12', '12230', '2891124', '千葉県', 'チバケン', '八街市', 'ヤチマタシ', '山田台', 'ヤマダダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県八街市上砂', '12', '12230', '2891125', '千葉県', 'チバケン', '八街市', 'ヤチマタシ', '上砂', 'カミイサゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県八街市沖', '12', '12230', '2891126', '千葉県', 'チバケン', '八街市', 'ヤチマタシ', '沖', 'オキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県八街市希望ケ丘', '12', '12230', '2891131', '千葉県', 'チバケン', '八街市', 'ヤチマタシ', '希望ケ丘', 'キボウガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県八街市勢田', '12', '12230', '2891132', '千葉県', 'チバケン', '八街市', 'ヤチマタシ', '勢田', 'セタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県八街市吉倉', '12', '12230', '2891133', '千葉県', 'チバケン', '八街市', 'ヤチマタシ', '吉倉', 'ヨシクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県八街市大谷流', '12', '12230', '2891134', '千葉県', 'チバケン', '八街市', 'ヤチマタシ', '大谷流', 'オオヤル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県八街市小谷流', '12', '12230', '2891135', '千葉県', 'チバケン', '八街市', 'ヤチマタシ', '小谷流', 'コヤル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県八街市根古谷', '12', '12230', '2891136', '千葉県', 'チバケン', '八街市', 'ヤチマタシ', '根古谷', 'ネゴヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県八街市岡田', '12', '12230', '2891137', '千葉県', 'チバケン', '八街市', 'ヤチマタシ', '岡田', 'オカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県八街市用草', '12', '12230', '2891138', '千葉県', 'チバケン', '八街市', 'ヤチマタシ', '用草', 'モチクサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県八街市富山', '12', '12230', '2891141', '千葉県', 'チバケン', '八街市', 'ヤチマタシ', '富山', 'トヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県八街市大関', '12', '12230', '2891142', '千葉県', 'チバケン', '八街市', 'ヤチマタシ', '大関', 'オオセキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県八街市八街い', '12', '12230', '2891143', '千葉県', 'チバケン', '八街市', 'ヤチマタシ', '八街い', 'ヤチマタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県八街市八街ろ', '12', '12230', '2891144', '千葉県', 'チバケン', '八街市', 'ヤチマタシ', '八街ろ', 'ヤチマタロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県八街市みどり台', '12', '12230', '2891145', '千葉県', 'チバケン', '八街市', 'ヤチマタシ', 'みどり台', 'ミドリダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武市板川', '12', '12237', '2891201', '千葉県', 'チバケン', '山武市', 'サンムシ', '板川', 'イタガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武市中津田', '12', '12237', '2891202', '千葉県', 'チバケン', '山武市', 'サンムシ', '中津田', 'ナカツタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武市麻生新田', '12', '12237', '2891203', '千葉県', 'チバケン', '山武市', 'サンムシ', '麻生新田', 'アソウシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武市戸田', '12', '12237', '2891204', '千葉県', 'チバケン', '山武市', 'サンムシ', '戸田', 'トダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武市椎崎', '12', '12237', '2891205', '千葉県', 'チバケン', '山武市', 'サンムシ', '椎崎', 'シイザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武市日向台', '12', '12237', '2891206', '千葉県', 'チバケン', '山武市', 'サンムシ', '日向台', 'ヒュウガダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武市大木', '12', '12237', '2891211', '千葉県', 'チバケン', '山武市', 'サンムシ', '大木', 'オオギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武市木原', '12', '12237', '2891212', '千葉県', 'チバケン', '山武市', 'サンムシ', '木原', 'キバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武市雨坪', '12', '12237', '2891213', '千葉県', 'チバケン', '山武市', 'サンムシ', '雨坪', 'アメツボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武市森', '12', '12237', '2891214', '千葉県', 'チバケン', '山武市', 'サンムシ', '森', 'モリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武市矢部', '12', '12237', '2891215', '千葉県', 'チバケン', '山武市', 'サンムシ', '矢部', 'ヤベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武市植草', '12', '12237', '2891216', '千葉県', 'チバケン', '山武市', 'サンムシ', '植草', 'ウエクサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武市下布田', '12', '12237', '2891217', '千葉県', 'チバケン', '山武市', 'サンムシ', '下布田', 'シモフダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武市武勝', '12', '12237', '2891218', '千葉県', 'チバケン', '山武市', 'サンムシ', '武勝', 'ムショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武市実門', '12', '12237', '2891221', '千葉県', 'チバケン', '山武市', 'サンムシ', '実門', 'サネカド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武市板中新田', '12', '12237', '2891222', '千葉県', 'チバケン', '山武市', 'サンムシ', '板中新田', 'イタナカシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武市埴谷', '12', '12237', '2891223', '千葉県', 'チバケン', '山武市', 'サンムシ', '埴谷', 'ハニヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武市美杉野', '12', '12237', '2891224', '千葉県', 'チバケン', '山武市', 'サンムシ', '美杉野', 'ミスギノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武市沖渡', '12', '12237', '2891225', '千葉県', 'チバケン', '山武市', 'サンムシ', '沖渡', 'オキワタシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武市横田', '12', '12237', '2891226', '千葉県', 'チバケン', '山武市', 'サンムシ', '横田', 'ヨコタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武市', '12', '12237', '2891300', '千葉県', 'チバケン', '山武市', 'サンムシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('17980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武市木戸', '12', '12237', '2891301', '千葉県', 'チバケン', '山武市', 'サンムシ', '木戸', 'キド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武市小松', '12', '12237', '2891302', '千葉県', 'チバケン', '山武市', 'サンムシ', '小松', 'コマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武市松ケ谷', '12', '12237', '2891303', '千葉県', 'チバケン', '山武市', 'サンムシ', '松ケ谷', 'マツガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武市井之内', '12', '12237', '2891304', '千葉県', 'チバケン', '山武市', 'サンムシ', '井之内', 'イノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武市本須賀', '12', '12237', '2891305', '千葉県', 'チバケン', '山武市', 'サンムシ', '本須賀', 'モトスカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武市白幡', '12', '12237', '2891306', '千葉県', 'チバケン', '山武市', 'サンムシ', '白幡', 'シラハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武市早船', '12', '12237', '2891311', '千葉県', 'チバケン', '山武市', 'サンムシ', '早船', 'ハヤフネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武市柴原', '12', '12237', '2891312', '千葉県', 'チバケン', '山武市', 'サンムシ', '柴原', 'シバハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武市上横地', '12', '12237', '2891313', '千葉県', 'チバケン', '山武市', 'サンムシ', '上横地', 'カミヨコジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武市下横地', '12', '12237', '2891314', '千葉県', 'チバケン', '山武市', 'サンムシ', '下横地', 'シモヨコヂ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武市草深', '12', '12237', '2891315', '千葉県', 'チバケン', '山武市', 'サンムシ', '草深', 'クサブカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武市五木田', '12', '12237', '2891316', '千葉県', 'チバケン', '山武市', 'サンムシ', '五木田', 'ゴキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武市小泉', '12', '12237', '2891317', '千葉県', 'チバケン', '山武市', 'サンムシ', '小泉', 'コイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武市寺崎', '12', '12237', '2891318', '千葉県', 'チバケン', '山武市', 'サンムシ', '寺崎', 'テラザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武市富田', '12', '12237', '2891321', '千葉県', 'チバケン', '山武市', 'サンムシ', '富田', 'トミダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武市富田幸谷', '12', '12237', '2891322', '千葉県', 'チバケン', '山武市', 'サンムシ', '富田幸谷', 'トミダゴウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武市富口', '12', '12237', '2891323', '千葉県', 'チバケン', '山武市', 'サンムシ', '富口', 'トミグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武市殿台', '12', '12237', '2891324', '千葉県', 'チバケン', '山武市', 'サンムシ', '殿台', 'トノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武市島', '12', '12237', '2891325', '千葉県', 'チバケン', '山武市', 'サンムシ', '島', 'シマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('17999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武市成東', '12', '12237', '2891326', '千葉県', 'チバケン', '山武市', 'サンムシ', '成東', 'ナルトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武市姫島', '12', '12237', '2891327', '千葉県', 'チバケン', '山武市', 'サンムシ', '姫島', 'ヒメシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武市湯坂', '12', '12237', '2891328', '千葉県', 'チバケン', '山武市', 'サンムシ', '湯坂', 'ユサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武市川崎', '12', '12237', '2891331', '千葉県', 'チバケン', '山武市', 'サンムシ', '川崎', 'カワサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武市親田', '12', '12237', '2891332', '千葉県', 'チバケン', '山武市', 'サンムシ', '親田', 'オヤダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武市市場', '12', '12237', '2891333', '千葉県', 'チバケン', '山武市', 'サンムシ', '市場', 'イチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武市和田', '12', '12237', '2891334', '千葉県', 'チバケン', '山武市', 'サンムシ', '和田', 'ワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武市板附', '12', '12237', '2891335', '千葉県', 'チバケン', '山武市', 'サンムシ', '板附', 'イタツキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武市野堀', '12', '12237', '2891341', '千葉県', 'チバケン', '山武市', 'サンムシ', '野堀', 'ノボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武市島戸', '12', '12237', '2891342', '千葉県', 'チバケン', '山武市', 'サンムシ', '島戸', 'シマド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武市真行寺', '12', '12237', '2891343', '千葉県', 'チバケン', '山武市', 'サンムシ', '真行寺', 'シンギョウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武市新泉', '12', '12237', '2891344', '千葉県', 'チバケン', '山武市', 'サンムシ', '新泉', 'ニイノミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武市津辺', '12', '12237', '2891345', '千葉県', 'チバケン', '山武市', 'サンムシ', '津辺', 'ツベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武市松尾町山室', '12', '12237', '2891501', '千葉県', 'チバケン', '山武市', 'サンムシ', '松尾町山室', 'マツオマチヤマムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武市松尾町引越', '12', '12237', '2891502', '千葉県', 'チバケン', '山武市', 'サンムシ', '松尾町引越', 'マツオマチヒッコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武市松尾町谷津', '12', '12237', '2891503', '千葉県', 'チバケン', '山武市', 'サンムシ', '松尾町谷津', 'マツオマチヤツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武市松尾町古和', '12', '12237', '2891504', '千葉県', 'チバケン', '山武市', 'サンムシ', '松尾町古和', 'マツオマチコワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武市松尾町金尾', '12', '12237', '2891505', '千葉県', 'チバケン', '山武市', 'サンムシ', '松尾町金尾', 'マツオマチカンノオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武市松尾町上大蔵', '12', '12237', '2891506', '千葉県', 'チバケン', '山武市', 'サンムシ', '松尾町上大蔵', 'マツオマチカミオオクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武市松尾町小川', '12', '12237', '2891507', '千葉県', 'チバケン', '山武市', 'サンムシ', '松尾町小川', 'マツオマチオガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武市松尾町蕪木', '12', '12237', '2891511', '千葉県', 'チバケン', '山武市', 'サンムシ', '松尾町蕪木', 'マツオマチカブラキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武市松尾町八田', '12', '12237', '2891512', '千葉県', 'チバケン', '山武市', 'サンムシ', '松尾町八田', 'マツオマチハッタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武市松尾町猿尾', '12', '12237', '2891513', '千葉県', 'チバケン', '山武市', 'サンムシ', '松尾町猿尾', 'マツオマチサルオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武市松尾町松尾', '12', '12237', '2891514', '千葉県', 'チバケン', '山武市', 'サンムシ', '松尾町松尾', 'マツオマチマツオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武市松尾町富士見台', '12', '12237', '2891515', '千葉県', 'チバケン', '山武市', 'サンムシ', '松尾町富士見台', 'マツオマチフジミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武市松尾町田越', '12', '12237', '2891516', '千葉県', 'チバケン', '山武市', 'サンムシ', '松尾町田越', 'マツオマチタコエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武市松尾町下大蔵', '12', '12237', '2891517', '千葉県', 'チバケン', '山武市', 'サンムシ', '松尾町下大蔵', 'マツオマチシモオオクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武市松尾町本柏', '12', '12237', '2891521', '千葉県', 'チバケン', '山武市', 'サンムシ', '松尾町本柏', 'マツオマチモトガシワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武市松尾町高富', '12', '12237', '2891522', '千葉県', 'チバケン', '山武市', 'サンムシ', '松尾町高富', 'マツオマチタカトミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武市松尾町五反田', '12', '12237', '2891523', '千葉県', 'チバケン', '山武市', 'サンムシ', '松尾町五反田', 'マツオマチゴタンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武市松尾町祝田', '12', '12237', '2891524', '千葉県', 'チバケン', '山武市', 'サンムシ', '松尾町祝田', 'マツオマチイワイタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武市松尾町本水深', '12', '12237', '2891525', '千葉県', 'チバケン', '山武市', 'サンムシ', '松尾町本水深', 'マツオマチモトミズフカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武市松尾町水深', '12', '12237', '2891526', '千葉県', 'チバケン', '山武市', 'サンムシ', '松尾町水深', 'マツオマチミズフカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武市松尾町大堤', '12', '12237', '2891527', '千葉県', 'チバケン', '山武市', 'サンムシ', '松尾町大堤', 'マツオマチオオツツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武市松尾町木刀', '12', '12237', '2891531', '千葉県', 'チバケン', '山武市', 'サンムシ', '松尾町木刀', 'マツオマチキガタナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武市松尾町武野里', '12', '12237', '2891532', '千葉県', 'チバケン', '山武市', 'サンムシ', '松尾町武野里', 'マツオマチタケノサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武市松尾町広根', '12', '12237', '2891533', '千葉県', 'チバケン', '山武市', 'サンムシ', '松尾町広根', 'マツオマチヒロネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武市松尾町下野', '12', '12237', '2891534', '千葉県', 'チバケン', '山武市', 'サンムシ', '松尾町下野', 'マツオマチシモノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武市松尾町折戸', '12', '12237', '2891535', '千葉県', 'チバケン', '山武市', 'サンムシ', '松尾町折戸', 'マツオマチオリト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武市松尾町下之郷', '12', '12237', '2891536', '千葉県', 'チバケン', '山武市', 'サンムシ', '松尾町下之郷', 'マツオマチシモノゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武市松尾町借毛本郷', '12', '12237', '2891537', '千葉県', 'チバケン', '山武市', 'サンムシ', '松尾町借毛本郷', 'マツオマチカシケホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡芝山町', '12', '12409', '2891600', '千葉県', 'チバケン', '山武郡芝山町', 'サンブグンシバヤママチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('18045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡芝山町香山新田', '12', '12409', '2891601', '千葉県', 'チバケン', '山武郡芝山町', 'サンブグンシバヤママチ', '香山新田', 'カヤマシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡芝山町菱田', '12', '12409', '2891602', '千葉県', 'チバケン', '山武郡芝山町', 'サンブグンシバヤママチ', '菱田', 'ヒシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡芝山町大里', '12', '12409', '2891603', '千葉県', 'チバケン', '山武郡芝山町', 'サンブグンシバヤママチ', '大里', 'オオサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡芝山町飯櫃', '12', '12409', '2891604', '千葉県', 'チバケン', '山武郡芝山町', 'サンブグンシバヤママチ', '飯櫃', 'イビツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡芝山町大台', '12', '12409', '2891605', '千葉県', 'チバケン', '山武郡芝山町', 'サンブグンシバヤママチ', '大台', 'オオダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡芝山町山田', '12', '12409', '2891606', '千葉県', 'チバケン', '山武郡芝山町', 'サンブグンシバヤママチ', '山田', 'ヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡芝山町朝倉', '12', '12409', '2891607', '千葉県', 'チバケン', '山武郡芝山町', 'サンブグンシバヤママチ', '朝倉', 'アサクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡芝山町岩山', '12', '12409', '2891608', '千葉県', 'チバケン', '山武郡芝山町', 'サンブグンシバヤママチ', '岩山', 'イワヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡芝山町小原子', '12', '12409', '2891611', '千葉県', 'チバケン', '山武郡芝山町', 'サンブグンシバヤママチ', '小原子', 'オバラク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡芝山町上吹入', '12', '12409', '2891612', '千葉県', 'チバケン', '山武郡芝山町', 'サンブグンシバヤママチ', '上吹入', 'カミフキイレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡芝山町下吹入', '12', '12409', '2891613', '千葉県', 'チバケン', '山武郡芝山町', 'サンブグンシバヤママチ', '下吹入', 'シモフキイレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡芝山町宮崎', '12', '12409', '2891614', '千葉県', 'チバケン', '山武郡芝山町', 'サンブグンシバヤママチ', '宮崎', 'ミヤザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡芝山町境', '12', '12409', '2891615', '千葉県', 'チバケン', '山武郡芝山町', 'サンブグンシバヤママチ', '境', 'サカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡芝山町高谷', '12', '12409', '2891616', '千葉県', 'チバケン', '山武郡芝山町', 'サンブグンシバヤママチ', '高谷', 'タカヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡芝山町殿部田', '12', '12409', '2891617', '千葉県', 'チバケン', '山武郡芝山町', 'サンブグンシバヤママチ', '殿部田', 'トノベタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡芝山町山中', '12', '12409', '2891618', '千葉県', 'チバケン', '山武郡芝山町', 'サンブグンシバヤママチ', '山中', 'ヤマナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡芝山町芝山', '12', '12409', '2891619', '千葉県', 'チバケン', '山武郡芝山町', 'サンブグンシバヤママチ', '芝山', 'シバヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡芝山町牧野', '12', '12409', '2891621', '千葉県', 'チバケン', '山武郡芝山町', 'サンブグンシバヤママチ', '牧野', 'マキノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡芝山町宝馬', '12', '12409', '2891622', '千葉県', 'チバケン', '山武郡芝山町', 'サンブグンシバヤママチ', '宝馬', 'ホウマ', null, null, null, null), ('18064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡芝山町高田', '12', '12409', '2891623', '千葉県', 'チバケン', '山武郡芝山町', 'サンブグンシバヤママチ', '高田', 'タカダ', null, null, null, null), ('18065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡芝山町小池', '12', '12409', '2891624', '千葉県', 'チバケン', '山武郡芝山町', 'サンブグンシバヤママチ', '小池', 'コイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡芝山町新井田', '12', '12409', '2891625', '千葉県', 'チバケン', '山武郡芝山町', 'サンブグンシバヤママチ', '新井田', 'ニイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡芝山町新井田新田', '12', '12409', '2891626', '千葉県', 'チバケン', '山武郡芝山町', 'サンブグンシバヤママチ', '新井田新田', 'ニイダシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡横芝光町', '12', '12410', '2891700', '千葉県', 'チバケン', '山武郡横芝光町', 'サンブグンヨコシバヒカリマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('18071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡横芝光町篠本', '12', '12410', '2891701', '千葉県', 'チバケン', '山武郡横芝光町', 'サンブグンヨコシバヒカリマチ', '篠本', 'ササモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡横芝光町二又', '12', '12410', '2891702', '千葉県', 'チバケン', '山武郡横芝光町', 'サンブグンヨコシバヒカリマチ', '二又', 'フタマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡横芝光町傍示戸', '12', '12410', '2891703', '千葉県', 'チバケン', '山武郡横芝光町', 'サンブグンヨコシバヒカリマチ', '傍示戸', 'ホウジド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡横芝光町富下', '12', '12410', '2891704', '千葉県', 'チバケン', '山武郡横芝光町', 'サンブグンヨコシバヒカリマチ', '富下', 'トミシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡横芝光町宝米', '12', '12410', '2891705', '千葉県', 'チバケン', '山武郡横芝光町', 'サンブグンヨコシバヒカリマチ', '宝米', 'ホウメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡横芝光町市野原', '12', '12410', '2891706', '千葉県', 'チバケン', '山武郡横芝光町', 'サンブグンヨコシバヒカリマチ', '市野原', 'イチノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡横芝光町新井', '12', '12410', '2891707', '千葉県', 'チバケン', '山武郡横芝光町', 'サンブグンヨコシバヒカリマチ', '新井', 'アライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡横芝光町篠本根切', '12', '12410', '2891708', '千葉県', 'チバケン', '山武郡横芝光町', 'サンブグンヨコシバヒカリマチ', '篠本根切', 'ササモトネギリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡横芝光町小川台', '12', '12410', '2891711', '千葉県', 'チバケン', '山武郡横芝光町', 'サンブグンヨコシバヒカリマチ', '小川台', 'オガワダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡横芝光町台', '12', '12410', '2891712', '千葉県', 'チバケン', '山武郡横芝光町', 'サンブグンヨコシバヒカリマチ', '台', 'ダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡横芝光町小田部', '12', '12410', '2891713', '千葉県', 'チバケン', '山武郡横芝光町', 'サンブグンヨコシバヒカリマチ', '小田部', 'コタベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡横芝光町母子', '12', '12410', '2891714', '千葉県', 'チバケン', '山武郡横芝光町', 'サンブグンヨコシバヒカリマチ', '母子', 'ハハコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡横芝光町芝崎', '12', '12410', '2891715', '千葉県', 'チバケン', '山武郡横芝光町', 'サンブグンヨコシバヒカリマチ', '芝崎', 'シバサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡横芝光町芝崎南', '12', '12410', '2891716', '千葉県', 'チバケン', '山武郡横芝光町', 'サンブグンヨコシバヒカリマチ', '芝崎南', 'シバサキミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡横芝光町虫生', '12', '12410', '2891717', '千葉県', 'チバケン', '山武郡横芝光町', 'サンブグンヨコシバヒカリマチ', '虫生', 'ムショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡横芝光町谷中', '12', '12410', '2891721', '千葉県', 'チバケン', '山武郡横芝光町', 'サンブグンヨコシバヒカリマチ', '谷中', 'ヤナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡横芝光町目篠', '12', '12410', '2891722', '千葉県', 'チバケン', '山武郡横芝光町', 'サンブグンヨコシバヒカリマチ', '目篠', 'メジノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡横芝光町上原', '12', '12410', '2891723', '千葉県', 'チバケン', '山武郡横芝光町', 'サンブグンヨコシバヒカリマチ', '上原', 'カンバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡横芝光町原方', '12', '12410', '2891724', '千葉県', 'チバケン', '山武郡横芝光町', 'サンブグンヨコシバヒカリマチ', '原方', 'ハラカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡横芝光町尾垂', '12', '12410', '2891725', '千葉県', 'チバケン', '山武郡横芝光町', 'サンブグンヨコシバヒカリマチ', '尾垂', 'オダレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡横芝光町木戸', '12', '12410', '2891726', '千葉県', 'チバケン', '山武郡横芝光町', 'サンブグンヨコシバヒカリマチ', '木戸', 'キド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡横芝光町宮川', '12', '12410', '2891727', '千葉県', 'チバケン', '山武郡横芝光町', 'サンブグンヨコシバヒカリマチ', '宮川', 'ミヤガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡横芝光町古川', '12', '12410', '2891731', '千葉県', 'チバケン', '山武郡横芝光町', 'サンブグンヨコシバヒカリマチ', '古川', 'コカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡横芝光町横芝', '12', '12410', '2891732', '千葉県', 'チバケン', '山武郡横芝光町', 'サンブグンヨコシバヒカリマチ', '横芝', 'ヨコシバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡横芝光町栗山', '12', '12410', '2891733', '千葉県', 'チバケン', '山武郡横芝光町', 'サンブグンヨコシバヒカリマチ', '栗山', 'クリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡横芝光町北清水', '12', '12410', '2891734', '千葉県', 'チバケン', '山武郡横芝光町', 'サンブグンヨコシバヒカリマチ', '北清水', 'キタシミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡横芝光町屋形', '12', '12410', '2891735', '千葉県', 'チバケン', '山武郡横芝光町', 'サンブグンヨコシバヒカリマチ', '屋形', 'ヤカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡横芝光町新島', '12', '12410', '2891736', '千葉県', 'チバケン', '山武郡横芝光町', 'サンブグンヨコシバヒカリマチ', '新島', 'ニイジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡横芝光町鳥喰下', '12', '12410', '2891737', '千葉県', 'チバケン', '山武郡横芝光町', 'サンブグンヨコシバヒカリマチ', '鳥喰下', 'トリハミシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡横芝光町鳥喰上', '12', '12410', '2891738', '千葉県', 'チバケン', '山武郡横芝光町', 'サンブグンヨコシバヒカリマチ', '鳥喰上', 'トリハミカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡横芝光町鳥喰新田', '12', '12410', '2891739', '千葉県', 'チバケン', '山武郡横芝光町', 'サンブグンヨコシバヒカリマチ', '鳥喰新田', 'トリハミシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡横芝光町中台', '12', '12410', '2891741', '千葉県', 'チバケン', '山武郡横芝光町', 'サンブグンヨコシバヒカリマチ', '中台', 'ナカダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡横芝光町牛熊', '12', '12410', '2891742', '千葉県', 'チバケン', '山武郡横芝光町', 'サンブグンヨコシバヒカリマチ', '牛熊', 'ウシクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡横芝光町谷台', '12', '12410', '2891743', '千葉県', 'チバケン', '山武郡横芝光町', 'サンブグンヨコシバヒカリマチ', '谷台', 'ヤツダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡横芝光町木戸台', '12', '12410', '2891744', '千葉県', 'チバケン', '山武郡横芝光町', 'サンブグンヨコシバヒカリマチ', '木戸台', 'キドダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡横芝光町小堤', '12', '12410', '2891745', '千葉県', 'チバケン', '山武郡横芝光町', 'サンブグンヨコシバヒカリマチ', '小堤', 'オンヅミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡横芝光町寺方', '12', '12410', '2891746', '千葉県', 'チバケン', '山武郡横芝光町', 'サンブグンヨコシバヒカリマチ', '寺方', 'テラカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡横芝光町曽根合', '12', '12410', '2891747', '千葉県', 'チバケン', '山武郡横芝光町', 'サンブグンヨコシバヒカリマチ', '曽根合', 'ソネアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡横芝光町於幾', '12', '12410', '2891748', '千葉県', 'チバケン', '山武郡横芝光町', 'サンブグンヨコシバヒカリマチ', '於幾', 'オキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡横芝光町両国新田', '12', '12410', '2891749', '千葉県', 'チバケン', '山武郡横芝光町', 'サンブグンヨコシバヒカリマチ', '両国新田', 'リョウゴクシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡横芝光町長山台', '12', '12410', '2891751', '千葉県', 'チバケン', '山武郡横芝光町', 'サンブグンヨコシバヒカリマチ', '長山台', 'ナガヤマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡横芝光町姥山', '12', '12410', '2891752', '千葉県', 'チバケン', '山武郡横芝光町', 'サンブグンヨコシバヒカリマチ', '姥山', 'ウバヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡横芝光町取立', '12', '12410', '2891753', '千葉県', 'チバケン', '山武郡横芝光町', 'サンブグンヨコシバヒカリマチ', '取立', 'トリタテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡横芝光町坂田', '12', '12410', '2891754', '千葉県', 'チバケン', '山武郡横芝光町', 'サンブグンヨコシバヒカリマチ', '坂田', 'サカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡横芝光町坂田池', '12', '12410', '2891755', '千葉県', 'チバケン', '山武郡横芝光町', 'サンブグンヨコシバヒカリマチ', '坂田池', 'サカタイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡横芝光町長倉', '12', '12410', '2891756', '千葉県', 'チバケン', '山武郡横芝光町', 'サンブグンヨコシバヒカリマチ', '長倉', 'ナガクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡横芝光町遠山', '12', '12410', '2891757', '千葉県', 'チバケン', '山武郡横芝光町', 'サンブグンヨコシバヒカリマチ', '遠山', 'トオヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武市蓮沼イ', '12', '12237', '2891801', '千葉県', 'チバケン', '山武市', 'サンムシ', '蓮沼イ', 'ハスヌマイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武市蓮沼ロ', '12', '12237', '2891802', '千葉県', 'チバケン', '山武市', 'サンムシ', '蓮沼ロ', 'ハスヌマロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武市蓮沼ホ', '12', '12237', '2891803', '千葉県', 'チバケン', '山武市', 'サンムシ', '蓮沼ホ', 'ハスヌマホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武市蓮沼平', '12', '12237', '2891804', '千葉県', 'チバケン', '山武市', 'サンムシ', '蓮沼平', 'ハスヌマヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武市蓮沼ニ', '12', '12237', '2891805', '千葉県', 'チバケン', '山武市', 'サンムシ', '蓮沼ニ', 'ハスヌマニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武市蓮沼ハ', '12', '12237', '2891806', '千葉県', 'チバケン', '山武市', 'サンムシ', '蓮沼ハ', 'ハスヌマハ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県匝瑳市', '12', '12235', '2892100', '千葉県', 'チバケン', '匝瑳市', 'ソウサシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('18127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県匝瑳市春海', '12', '12235', '2892101', '千葉県', 'チバケン', '匝瑳市', 'ソウサシ', '春海', 'ハルミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県匝瑳市椿', '12', '12235', '2892102', '千葉県', 'チバケン', '匝瑳市', 'ソウサシ', '椿', 'ツバキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県匝瑳市宮本', '12', '12235', '2892103', '千葉県', 'チバケン', '匝瑳市', 'ソウサシ', '宮本', 'ミヤモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県匝瑳市生尾', '12', '12235', '2892104', '千葉県', 'チバケン', '匝瑳市', 'ソウサシ', '生尾', 'オイオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県匝瑳市山桑', '12', '12235', '2892105', '千葉県', 'チバケン', '匝瑳市', 'ソウサシ', '山桑', 'ヤマクワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県匝瑳市飯塚', '12', '12235', '2892106', '千葉県', 'チバケン', '匝瑳市', 'ソウサシ', '飯塚', 'イイヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県匝瑳市米持', '12', '12235', '2892107', '千葉県', 'チバケン', '匝瑳市', 'ソウサシ', '米持', 'ヨネモチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県匝瑳市大寺', '12', '12235', '2892108', '千葉県', 'チバケン', '匝瑳市', 'ソウサシ', '大寺', 'オオデラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県匝瑳市川向', '12', '12235', '2892111', '千葉県', 'チバケン', '匝瑳市', 'ソウサシ', '川向', 'カワムカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県匝瑳市荻野', '12', '12235', '2892112', '千葉県', 'チバケン', '匝瑳市', 'ソウサシ', '荻野', 'オギノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県匝瑳市平木', '12', '12235', '2892113', '千葉県', 'チバケン', '匝瑳市', 'ソウサシ', '平木', 'ヒラギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県匝瑳市上谷中', '12', '12235', '2892114', '千葉県', 'チバケン', '匝瑳市', 'ソウサシ', '上谷中', 'ジョウヤナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県匝瑳市東谷', '12', '12235', '2892115', '千葉県', 'チバケン', '匝瑳市', 'ソウサシ', '東谷', 'ヒガシヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県匝瑳市東小笹', '12', '12235', '2892121', '千葉県', 'チバケン', '匝瑳市', 'ソウサシ', '東小笹', 'ヒガシコザサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県匝瑳市吉崎', '12', '12235', '2892122', '千葉県', 'チバケン', '匝瑳市', 'ソウサシ', '吉崎', 'ヨシザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県匝瑳市長谷', '12', '12235', '2892123', '千葉県', 'チバケン', '匝瑳市', 'ソウサシ', '長谷', 'ナガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県匝瑳市登戸', '12', '12235', '2892124', '千葉県', 'チバケン', '匝瑳市', 'ソウサシ', '登戸', 'ノブト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県匝瑳市西小笹', '12', '12235', '2892125', '千葉県', 'チバケン', '匝瑳市', 'ソウサシ', '西小笹', 'ニシコザサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県匝瑳市みどり平', '12', '12235', '2892131', '千葉県', 'チバケン', '匝瑳市', 'ソウサシ', 'みどり平', 'ミドリダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県匝瑳市高', '12', '12235', '2892132', '千葉県', 'チバケン', '匝瑳市', 'ソウサシ', '高', 'タカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県匝瑳市蕪里', '12', '12235', '2892133', '千葉県', 'チバケン', '匝瑳市', 'ソウサシ', '蕪里', 'カブザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県匝瑳市横須賀', '12', '12235', '2892134', '千葉県', 'チバケン', '匝瑳市', 'ソウサシ', '横須賀', 'ヨコスカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県匝瑳市高野', '12', '12235', '2892135', '千葉県', 'チバケン', '匝瑳市', 'ソウサシ', '高野', 'コウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県匝瑳市時曽根', '12', '12235', '2892136', '千葉県', 'チバケン', '匝瑳市', 'ソウサシ', '時曽根', 'トキゾネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県匝瑳市八日市場ハ', '12', '12235', '2892141', '千葉県', 'チバケン', '匝瑳市', 'ソウサシ', '八日市場ハ', 'ヨウカイチバハ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県匝瑳市八日市場ニ', '12', '12235', '2892142', '千葉県', 'チバケン', '匝瑳市', 'ソウサシ', '八日市場ニ', 'ヨウカイチバニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県匝瑳市八日市場ロ', '12', '12235', '2892143', '千葉県', 'チバケン', '匝瑳市', 'ソウサシ', '八日市場ロ', 'ヨウカイチバロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県匝瑳市八日市場イ', '12', '12235', '2892144', '千葉県', 'チバケン', '匝瑳市', 'ソウサシ', '八日市場イ', 'ヨウカイチバイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県匝瑳市若潮町', '12', '12235', '2892145', '千葉県', 'チバケン', '匝瑳市', 'ソウサシ', '若潮町', 'ワカシオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県匝瑳市八日市場ホ', '12', '12235', '2892146', '千葉県', 'チバケン', '匝瑳市', 'ソウサシ', '八日市場ホ', 'ヨウカイチバホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県匝瑳市飯倉', '12', '12235', '2892147', '千葉県', 'チバケン', '匝瑳市', 'ソウサシ', '飯倉', 'イイグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県匝瑳市飯倉台', '12', '12235', '2892148', '千葉県', 'チバケン', '匝瑳市', 'ソウサシ', '飯倉台', 'イイグラダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県匝瑳市貝塚', '12', '12235', '2892149', '千葉県', 'チバケン', '匝瑳市', 'ソウサシ', '貝塚', 'カイヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県匝瑳市大浦', '12', '12235', '2892151', '千葉県', 'チバケン', '匝瑳市', 'ソウサシ', '大浦', 'オオウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県匝瑳市松山', '12', '12235', '2892152', '千葉県', 'チバケン', '匝瑳市', 'ソウサシ', '松山', 'マツヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県匝瑳市中台', '12', '12235', '2892153', '千葉県', 'チバケン', '匝瑳市', 'ソウサシ', '中台', 'ナカダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県匝瑳市富岡', '12', '12235', '2892154', '千葉県', 'チバケン', '匝瑳市', 'ソウサシ', '富岡', 'トミオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県匝瑳市八辺', '12', '12235', '2892155', '千葉県', 'チバケン', '匝瑳市', 'ソウサシ', '八辺', 'ヤッペ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県匝瑳市長岡', '12', '12235', '2892156', '千葉県', 'チバケン', '匝瑳市', 'ソウサシ', '長岡', 'ナガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県匝瑳市堀之内', '12', '12235', '2892157', '千葉県', 'チバケン', '匝瑳市', 'ソウサシ', '堀之内', 'ホリノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県匝瑳市入山崎', '12', '12235', '2892161', '千葉県', 'チバケン', '匝瑳市', 'ソウサシ', '入山崎', 'イリヤマザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県匝瑳市南山崎', '12', '12235', '2892162', '千葉県', 'チバケン', '匝瑳市', 'ソウサシ', '南山崎', 'ミナミヤマザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県匝瑳市南神崎', '12', '12235', '2892163', '千葉県', 'チバケン', '匝瑳市', 'ソウサシ', '南神崎', 'ミナミカンザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県匝瑳市木積', '12', '12235', '2892164', '千葉県', 'チバケン', '匝瑳市', 'ソウサシ', '木積', 'キズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県匝瑳市田久保', '12', '12235', '2892165', '千葉県', 'チバケン', '匝瑳市', 'ソウサシ', '田久保', 'タクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県匝瑳市新', '12', '12235', '2892166', '千葉県', 'チバケン', '匝瑳市', 'ソウサシ', '新', 'シムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県匝瑳市亀崎', '12', '12235', '2892167', '千葉県', 'チバケン', '匝瑳市', 'ソウサシ', '亀崎', 'カメザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県匝瑳市久方', '12', '12235', '2892168', '千葉県', 'チバケン', '匝瑳市', 'ソウサシ', '久方', 'ヒサカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県匝瑳市吉田', '12', '12235', '2892169', '千葉県', 'チバケン', '匝瑳市', 'ソウサシ', '吉田', 'ヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県匝瑳市内山', '12', '12235', '2892171', '千葉県', 'チバケン', '匝瑳市', 'ソウサシ', '内山', 'ウチヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県匝瑳市城下', '12', '12235', '2892172', '千葉県', 'チバケン', '匝瑳市', 'ソウサシ', '城下', 'ネゴヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県匝瑳市飯高', '12', '12235', '2892173', '千葉県', 'チバケン', '匝瑳市', 'ソウサシ', '飯高', 'イイダカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県匝瑳市公崎', '12', '12235', '2892174', '千葉県', 'チバケン', '匝瑳市', 'ソウサシ', '公崎', 'コウザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県匝瑳市片子', '12', '12235', '2892175', '千葉県', 'チバケン', '匝瑳市', 'ソウサシ', '片子', 'カタコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県匝瑳市大堀', '12', '12235', '2892176', '千葉県', 'チバケン', '匝瑳市', 'ソウサシ', '大堀', 'オオホリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県匝瑳市金原', '12', '12235', '2892177', '千葉県', 'チバケン', '匝瑳市', 'ソウサシ', '金原', 'カナバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県匝瑳市安久山', '12', '12235', '2892178', '千葉県', 'チバケン', '匝瑳市', 'ソウサシ', '安久山', 'アグヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県匝瑳市小高', '12', '12235', '2892179', '千葉県', 'チバケン', '匝瑳市', 'ソウサシ', '小高', 'オダカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取郡多古町', '12', '12347', '2892200', '千葉県', 'チバケン', '香取郡多古町', 'カトリグンタコマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('18189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取郡多古町飯笹', '12', '12347', '2892231', '千葉県', 'チバケン', '香取郡多古町', 'カトリグンタコマチ', '飯笹', 'イイザサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取郡多古町喜多', '12', '12347', '2892232', '千葉県', 'チバケン', '香取郡多古町', 'カトリグンタコマチ', '喜多', 'キタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取郡多古町林', '12', '12347', '2892233', '千葉県', 'チバケン', '香取郡多古町', 'カトリグンタコマチ', '林', 'ハヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取郡多古町五反田', '12', '12347', '2892234', '千葉県', 'チバケン', '香取郡多古町', 'カトリグンタコマチ', '五反田', 'ゴタンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取郡多古町間倉', '12', '12347', '2892235', '千葉県', 'チバケン', '香取郡多古町', 'カトリグンタコマチ', '間倉', 'マグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取郡多古町一鍬田', '12', '12347', '2892236', '千葉県', 'チバケン', '香取郡多古町', 'カトリグンタコマチ', '一鍬田', 'ヒトクワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取郡多古町多古', '12', '12347', '2892241', '千葉県', 'チバケン', '香取郡多古町', 'カトリグンタコマチ', '多古', 'タコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取郡多古町染井', '12', '12347', '2892242', '千葉県', 'チバケン', '香取郡多古町', 'カトリグンタコマチ', '染井', 'ソメイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取郡多古町島', '12', '12347', '2892243', '千葉県', 'チバケン', '香取郡多古町', 'カトリグンタコマチ', '島', 'シマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取郡多古町船越', '12', '12347', '2892244', '千葉県', 'チバケン', '香取郡多古町', 'カトリグンタコマチ', '船越', 'フナコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取郡多古町牛尾', '12', '12347', '2892245', '千葉県', 'チバケン', '香取郡多古町', 'カトリグンタコマチ', '牛尾', 'ウシノオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取郡多古町千田', '12', '12347', '2892246', '千葉県', 'チバケン', '香取郡多古町', 'カトリグンタコマチ', '千田', 'チダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取郡多古町水戸', '12', '12347', '2892247', '千葉県', 'チバケン', '香取郡多古町', 'カトリグンタコマチ', '水戸', 'ミト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取郡多古町北中', '12', '12347', '2892251', '千葉県', 'チバケン', '香取郡多古町', 'カトリグンタコマチ', '北中', 'キタナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取郡多古町南和田', '12', '12347', '2892252', '千葉県', 'チバケン', '香取郡多古町', 'カトリグンタコマチ', '南和田', 'ミナミワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取郡多古町南借当', '12', '12347', '2892253', '千葉県', 'チバケン', '香取郡多古町', 'カトリグンタコマチ', '南借当', 'ミナミカリアテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取郡多古町東輝', '12', '12347', '2892254', '千葉県', 'チバケン', '香取郡多古町', 'カトリグンタコマチ', '東輝', 'トウキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取郡多古町南並木', '12', '12347', '2892255', '千葉県', 'チバケン', '香取郡多古町', 'カトリグンタコマチ', '南並木', 'ミナミナミキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取郡多古町中村新田', '12', '12347', '2892256', '千葉県', 'チバケン', '香取郡多古町', 'カトリグンタコマチ', '中村新田', 'ナカムラシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取郡多古町南中', '12', '12347', '2892257', '千葉県', 'チバケン', '香取郡多古町', 'カトリグンタコマチ', '南中', 'ミナミナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取郡多古町出沼', '12', '12347', '2892301', '千葉県', 'チバケン', '香取郡多古町', 'カトリグンタコマチ', '出沼', 'イデヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取郡多古町桧木', '12', '12347', '2892302', '千葉県', 'チバケン', '香取郡多古町', 'カトリグンタコマチ', '桧木', 'ヒノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取郡多古町大門', '12', '12347', '2892303', '千葉県', 'チバケン', '香取郡多古町', 'カトリグンタコマチ', '大門', 'オオカド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取郡多古町高津原', '12', '12347', '2892304', '千葉県', 'チバケン', '香取郡多古町', 'カトリグンタコマチ', '高津原', 'タカツハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取郡多古町大高', '12', '12347', '2892305', '千葉県', 'チバケン', '香取郡多古町', 'カトリグンタコマチ', '大高', 'オオタカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取郡多古町十余三', '12', '12347', '2892306', '千葉県', 'チバケン', '香取郡多古町', 'カトリグンタコマチ', '十余三', 'トヨミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取郡多古町本三倉', '12', '12347', '2892311', '千葉県', 'チバケン', '香取郡多古町', 'カトリグンタコマチ', '本三倉', 'モトミクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取郡多古町谷三倉', '12', '12347', '2892312', '千葉県', 'チバケン', '香取郡多古町', 'カトリグンタコマチ', '谷三倉', 'サクミクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取郡多古町次浦', '12', '12347', '2892313', '千葉県', 'チバケン', '香取郡多古町', 'カトリグンタコマチ', '次浦', 'ツギウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取郡多古町西古内', '12', '12347', '2892314', '千葉県', 'チバケン', '香取郡多古町', 'カトリグンタコマチ', '西古内', 'ニシフルウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取郡多古町御所台', '12', '12347', '2892315', '千葉県', 'チバケン', '香取郡多古町', 'カトリグンタコマチ', '御所台', 'ゴショダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取郡多古町寺作', '12', '12347', '2892316', '千葉県', 'チバケン', '香取郡多古町', 'カトリグンタコマチ', '寺作', 'テラサク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取郡多古町井戸山', '12', '12347', '2892317', '千葉県', 'チバケン', '香取郡多古町', 'カトリグンタコマチ', '井戸山', 'イドヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取郡多古町東松崎', '12', '12347', '2892321', '千葉県', 'チバケン', '香取郡多古町', 'カトリグンタコマチ', '東松崎', 'ヒガシマツサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取郡多古町坂', '12', '12347', '2892322', '千葉県', 'チバケン', '香取郡多古町', 'カトリグンタコマチ', '坂', 'サカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取郡多古町方田', '12', '12347', '2892323', '千葉県', 'チバケン', '香取郡多古町', 'カトリグンタコマチ', '方田', 'ホウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取郡多古町川島', '12', '12347', '2892324', '千葉県', 'チバケン', '香取郡多古町', 'カトリグンタコマチ', '川島', 'カワシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県香取郡多古町南玉造', '12', '12347', '2892325', '千葉県', 'チバケン', '香取郡多古町', 'カトリグンタコマチ', '南玉造', 'ミナミタマツクリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県旭市', '12', '12215', '2892500', '千葉県', 'チバケン', '旭市', 'アサヒシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('18229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県旭市新町', '12', '12215', '2892501', '千葉県', 'チバケン', '旭市', 'アサヒシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県旭市琴田', '12', '12215', '2892502', '千葉県', 'チバケン', '旭市', 'アサヒシ', '琴田', 'コトダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県旭市江ケ崎', '12', '12215', '2892503', '千葉県', 'チバケン', '旭市', 'アサヒシ', '江ケ崎', 'エガサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県旭市ニ', '12', '12215', '2892504', '千葉県', 'チバケン', '旭市', 'アサヒシ', 'ニ', 'ニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県旭市鎌数', '12', '12215', '2892505', '千葉県', 'チバケン', '旭市', 'アサヒシ', '鎌数', 'カマカズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県旭市イ', '12', '12215', '2892511', '千葉県', 'チバケン', '旭市', 'アサヒシ', 'イ', 'イ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県旭市東足洗', '12', '12215', '2892512', '千葉県', 'チバケン', '旭市', 'アサヒシ', '東足洗', 'ヒガシアシアライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県旭市野中', '12', '12215', '2892513', '千葉県', 'チバケン', '旭市', 'アサヒシ', '野中', 'ノナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県旭市椎名内', '12', '12215', '2892514', '千葉県', 'チバケン', '旭市', 'アサヒシ', '椎名内', 'シイナウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県旭市西足洗', '12', '12215', '2892515', '千葉県', 'チバケン', '旭市', 'アサヒシ', '西足洗', 'ニシアシアライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県旭市ロ', '12', '12215', '2892516', '千葉県', 'チバケン', '旭市', 'アサヒシ', 'ロ', 'ロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県旭市ハ', '12', '12215', '2892521', '千葉県', 'チバケン', '旭市', 'アサヒシ', 'ハ', 'ハ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県旭市足川', '12', '12215', '2892522', '千葉県', 'チバケン', '旭市', 'アサヒシ', '足川', 'アシカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県旭市中谷里', '12', '12215', '2892523', '千葉県', 'チバケン', '旭市', 'アサヒシ', '中谷里', 'ナカヤリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県旭市神宮寺', '12', '12215', '2892524', '千葉県', 'チバケン', '旭市', 'アサヒシ', '神宮寺', 'ジングウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県旭市仁玉', '12', '12215', '2892525', '千葉県', 'チバケン', '旭市', 'アサヒシ', '仁玉', 'ニッタマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県旭市井戸野', '12', '12215', '2892531', '千葉県', 'チバケン', '旭市', 'アサヒシ', '井戸野', 'イドノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県旭市駒込', '12', '12215', '2892532', '千葉県', 'チバケン', '旭市', 'アサヒシ', '駒込', 'コマゴメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県旭市大塚原', '12', '12215', '2892533', '千葉県', 'チバケン', '旭市', 'アサヒシ', '大塚原', 'オオツカハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県旭市泉川', '12', '12215', '2892534', '千葉県', 'チバケン', '旭市', 'アサヒシ', '泉川', 'イズミカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県旭市川口', '12', '12215', '2892535', '千葉県', 'チバケン', '旭市', 'アサヒシ', '川口', 'カワグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県旭市松ケ谷', '12', '12215', '2892601', '千葉県', 'チバケン', '旭市', 'アサヒシ', '松ケ谷', 'マツガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県旭市岩井', '12', '12215', '2892602', '千葉県', 'チバケン', '旭市', 'アサヒシ', '岩井', 'イワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県旭市大間手', '12', '12215', '2892603', '千葉県', 'チバケン', '旭市', 'アサヒシ', '大間手', 'オオマデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県旭市高生', '12', '12215', '2892604', '千葉県', 'チバケン', '旭市', 'アサヒシ', '高生', 'タカオイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県旭市琴田', '12', '12215', '2892605', '千葉県', 'チバケン', '旭市', 'アサヒシ', '琴田', 'コトダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県旭市清滝', '12', '12215', '2892606', '千葉県', 'チバケン', '旭市', 'アサヒシ', '清滝', 'キヨタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県旭市幾世', '12', '12215', '2892607', '千葉県', 'チバケン', '旭市', 'アサヒシ', '幾世', 'イクヨ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県旭市倉橋', '12', '12215', '2892611', '千葉県', 'チバケン', '旭市', 'アサヒシ', '倉橋', 'クラハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県旭市蛇園', '12', '12215', '2892612', '千葉県', 'チバケン', '旭市', 'アサヒシ', '蛇園', 'ヘビソノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県旭市後草', '12', '12215', '2892613', '千葉県', 'チバケン', '旭市', 'アサヒシ', '後草', 'ウシログサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県旭市江ケ崎', '12', '12215', '2892614', '千葉県', 'チバケン', '旭市', 'アサヒシ', '江ケ崎', 'エガサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県旭市長尾', '12', '12215', '2892615', '千葉県', 'チバケン', '旭市', 'アサヒシ', '長尾', 'ナガオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県旭市見広', '12', '12215', '2892616', '千葉県', 'チバケン', '旭市', 'アサヒシ', '見広', 'ミヒロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県旭市狢野', '12', '12215', '2892701', '千葉県', 'チバケン', '旭市', 'アサヒシ', '狢野', 'ムジナノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県旭市塙', '12', '12215', '2892702', '千葉県', 'チバケン', '旭市', 'アサヒシ', '塙', 'ハナワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県旭市八木', '12', '12215', '2892703', '千葉県', 'チバケン', '旭市', 'アサヒシ', '八木', 'ヤギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県旭市上永井', '12', '12215', '2892704', '千葉県', 'チバケン', '旭市', 'アサヒシ', '上永井', 'カミナガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県旭市飯岡', '12', '12215', '2892705', '千葉県', 'チバケン', '旭市', 'アサヒシ', '飯岡', 'イイオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県旭市下永井', '12', '12215', '2892706', '千葉県', 'チバケン', '旭市', 'アサヒシ', '下永井', 'シモナガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県旭市行内', '12', '12215', '2892707', '千葉県', 'チバケン', '旭市', 'アサヒシ', '行内', 'ギョウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県旭市平松', '12', '12215', '2892708', '千葉県', 'チバケン', '旭市', 'アサヒシ', '平松', 'ヒラマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県旭市岩崎', '12', '12215', '2892711', '千葉県', 'チバケン', '旭市', 'アサヒシ', '岩崎', 'イワサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県旭市横根', '12', '12215', '2892712', '千葉県', 'チバケン', '旭市', 'アサヒシ', '横根', 'ヨコネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県旭市萩園', '12', '12215', '2892713', '千葉県', 'チバケン', '旭市', 'アサヒシ', '萩園', 'ハギゾノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県旭市三川', '12', '12215', '2892714', '千葉県', 'チバケン', '旭市', 'アサヒシ', '三川', 'サンガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県旭市権田沼新田', '12', '12215', '2892715', '千葉県', 'チバケン', '旭市', 'アサヒシ', '権田沼新田', 'ゴンダヌマシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県匝瑳市野手', '12', '12235', '2893181', '千葉県', 'チバケン', '匝瑳市', 'ソウサシ', '野手', 'ノデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県匝瑳市今泉', '12', '12235', '2893182', '千葉県', 'チバケン', '匝瑳市', 'ソウサシ', '今泉', 'イマイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県匝瑳市新堀', '12', '12235', '2893183', '千葉県', 'チバケン', '匝瑳市', 'ソウサシ', '新堀', 'ニイボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県匝瑳市栢田', '12', '12235', '2893184', '千葉県', 'チバケン', '匝瑳市', 'ソウサシ', '栢田', 'カヤダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県匝瑳市堀川', '12', '12235', '2893185', '千葉県', 'チバケン', '匝瑳市', 'ソウサシ', '堀川', 'ホリカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県匝瑳市川辺', '12', '12235', '2893186', '千葉県', 'チバケン', '匝瑳市', 'ソウサシ', '川辺', 'カワベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市', '12', '12219', '2900000', '千葉県', 'チバケン', '市原市', 'イチハラシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('18284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市草刈', '12', '12219', '2900001', '千葉県', 'チバケン', '市原市', 'イチハラシ', '草刈', 'クサカリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市大厩', '12', '12219', '2900002', '千葉県', 'チバケン', '市原市', 'イチハラシ', '大厩', 'オオマヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市辰巳台東', '12', '12219', '2900003', '千葉県', 'チバケン', '市原市', 'イチハラシ', '辰巳台東', 'タツミダイヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市辰巳台西', '12', '12219', '2900004', '千葉県', 'チバケン', '市原市', 'イチハラシ', '辰巳台西', 'タツミダイニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市山木', '12', '12219', '2900005', '千葉県', 'チバケン', '市原市', 'イチハラシ', '山木', 'ヤマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市若宮', '12', '12219', '2900006', '千葉県', 'チバケン', '市原市', 'イチハラシ', '若宮', 'ワカミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市菊間', '12', '12219', '2900007', '千葉県', 'チバケン', '市原市', 'イチハラシ', '菊間', 'キクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市古市場', '12', '12219', '2900008', '千葉県', 'チバケン', '市原市', 'イチハラシ', '古市場', 'フルイチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市能満', '12', '12219', '2900011', '千葉県', 'チバケン', '市原市', 'イチハラシ', '能満', 'ノウマン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市藤井', '12', '12219', '2900012', '千葉県', 'チバケン', '市原市', 'イチハラシ', '藤井', 'フジイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市郡本', '12', '12219', '2900013', '千葉県', 'チバケン', '市原市', 'イチハラシ', '郡本', 'コオリモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市西野谷', '12', '12219', '2900014', '千葉県', 'チバケン', '市原市', 'イチハラシ', '西野谷', 'ニシノヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市市原', '12', '12219', '2900015', '千葉県', 'チバケン', '市原市', 'イチハラシ', '市原', 'イチハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市門前', '12', '12219', '2900016', '千葉県', 'チバケン', '市原市', 'イチハラシ', '門前', 'モンゼン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市山田橋', '12', '12219', '2900021', '千葉県', 'チバケン', '市原市', 'イチハラシ', '山田橋', 'ヤマダバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市西広', '12', '12219', '2900022', '千葉県', 'チバケン', '市原市', 'イチハラシ', '西広', 'サイヒロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市惣社', '12', '12219', '2900023', '千葉県', 'チバケン', '市原市', 'イチハラシ', '惣社', 'ソウジャ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市根田', '12', '12219', '2900024', '千葉県', 'チバケン', '市原市', 'イチハラシ', '根田', 'ネダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市加茂', '12', '12219', '2900025', '千葉県', 'チバケン', '市原市', 'イチハラシ', '加茂', 'カモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市諏訪', '12', '12219', '2900026', '千葉県', 'チバケン', '市原市', 'イチハラシ', '諏訪', 'スワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市村上', '12', '12219', '2900031', '千葉県', 'チバケン', '市原市', 'イチハラシ', '村上', 'ムラカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市廿五里', '12', '12219', '2900032', '千葉県', 'チバケン', '市原市', 'イチハラシ', '廿五里', 'ツイヘイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市野毛', '12', '12219', '2900033', '千葉県', 'チバケン', '市原市', 'イチハラシ', '野毛', 'ノゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市島野', '12', '12219', '2900034', '千葉県', 'チバケン', '市原市', 'イチハラシ', '島野', 'シマノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市松ケ島', '12', '12219', '2900035', '千葉県', 'チバケン', '市原市', 'イチハラシ', '松ケ島', 'マツガシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市松ケ島西', '12', '12219', '2900036', '千葉県', 'チバケン', '市原市', 'イチハラシ', '松ケ島西', 'マツガシマニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市飯沼', '12', '12219', '2900037', '千葉県', 'チバケン', '市原市', 'イチハラシ', '飯沼', 'イイヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市五井西', '12', '12219', '2900038', '千葉県', 'チバケン', '市原市', 'イチハラシ', '五井西', 'ゴイニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市玉前', '12', '12219', '2900041', '千葉県', 'チバケン', '市原市', 'イチハラシ', '玉前', 'タマサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市出津', '12', '12219', '2900042', '千葉県', 'チバケン', '市原市', 'イチハラシ', '出津', 'デヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市出津西', '12', '12219', '2900043', '千葉県', 'チバケン', '市原市', 'イチハラシ', '出津西', 'デヅニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市玉前西', '12', '12219', '2900044', '千葉県', 'チバケン', '市原市', 'イチハラシ', '玉前西', 'タマサキニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市五井南海岸', '12', '12219', '2900045', '千葉県', 'チバケン', '市原市', 'イチハラシ', '五井南海岸', 'ゴイミナミカイガン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市岩崎西', '12', '12219', '2900046', '千葉県', 'チバケン', '市原市', 'イチハラシ', '岩崎西', 'イワサキニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市岩崎', '12', '12219', '2900047', '千葉県', 'チバケン', '市原市', 'イチハラシ', '岩崎', 'イワサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市君塚', '12', '12219', '2900051', '千葉県', 'チバケン', '市原市', 'イチハラシ', '君塚', 'キミヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市岩野見', '12', '12219', '2900052', '千葉県', 'チバケン', '市原市', 'イチハラシ', '岩野見', 'イワノミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市平田', '12', '12219', '2900053', '千葉県', 'チバケン', '市原市', 'イチハラシ', '平田', 'ヒラタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市五井中央東', '12', '12219', '2900054', '千葉県', 'チバケン', '市原市', 'イチハラシ', '五井中央東', 'ゴイチュウオウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市五井東', '12', '12219', '2900055', '千葉県', 'チバケン', '市原市', 'イチハラシ', '五井東', 'ゴイヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市五井', '12', '12219', '2900056', '千葉県', 'チバケン', '市原市', 'イチハラシ', '五井', 'ゴイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市五井金杉', '12', '12219', '2900057', '千葉県', 'チバケン', '市原市', 'イチハラシ', '五井金杉', 'ゴイカナスギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市五井海岸', '12', '12219', '2900058', '千葉県', 'チバケン', '市原市', 'イチハラシ', '五井海岸', 'ゴイカイガン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市白金町', '12', '12219', '2900059', '千葉県', 'チバケン', '市原市', 'イチハラシ', '白金町', 'シロガネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市八幡石塚', '12', '12219', '2900061', '千葉県', 'チバケン', '市原市', 'イチハラシ', '八幡石塚', 'ヤワタイシヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市八幡', '12', '12219', '2900062', '千葉県', 'チバケン', '市原市', 'イチハラシ', '八幡', 'ヤワタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市旭五所', '12', '12219', '2900063', '千葉県', 'チバケン', '市原市', 'イチハラシ', '旭五所', 'アサヒゴショ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市東五所', '12', '12219', '2900064', '千葉県', 'チバケン', '市原市', 'イチハラシ', '東五所', 'ヒガシゴショ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市西五所', '12', '12219', '2900065', '千葉県', 'チバケン', '市原市', 'イチハラシ', '西五所', 'ニシゴショ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市五所', '12', '12219', '2900066', '千葉県', 'チバケン', '市原市', 'イチハラシ', '五所', 'ゴショ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市八幡海岸通', '12', '12219', '2900067', '千葉県', 'チバケン', '市原市', 'イチハラシ', '八幡海岸通', 'ヤワタカイガンドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市八幡浦', '12', '12219', '2900068', '千葉県', 'チバケン', '市原市', 'イチハラシ', '八幡浦', 'ヤワタウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市八幡北町', '12', '12219', '2900069', '千葉県', 'チバケン', '市原市', 'イチハラシ', '八幡北町', 'ヤワタキタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市北国分寺台', '12', '12219', '2900071', '千葉県', 'チバケン', '市原市', 'イチハラシ', '北国分寺台', 'キタコクブンジダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市西国分寺台', '12', '12219', '2900072', '千葉県', 'チバケン', '市原市', 'イチハラシ', '西国分寺台', 'ニシコクブンジダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市国分寺台中央', '12', '12219', '2900073', '千葉県', 'チバケン', '市原市', 'イチハラシ', '国分寺台中央', 'コクブンジダイチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市東国分寺台', '12', '12219', '2900074', '千葉県', 'チバケン', '市原市', 'イチハラシ', '東国分寺台', 'ヒガシコクブンジダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市南国分寺台', '12', '12219', '2900075', '千葉県', 'チバケン', '市原市', 'イチハラシ', '南国分寺台', 'ミナミコクブンジダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市五井中央西', '12', '12219', '2900081', '千葉県', 'チバケン', '市原市', 'イチハラシ', '五井中央西', 'ゴイチュウオウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市ちはら台東', '12', '12219', '2900141', '千葉県', 'チバケン', '市原市', 'イチハラシ', 'ちはら台東', 'チハラダイヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市ちはら台南', '12', '12219', '2900142', '千葉県', 'チバケン', '市原市', 'イチハラシ', 'ちはら台南', 'チハラダイミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市ちはら台西', '12', '12219', '2900143', '千葉県', 'チバケン', '市原市', 'イチハラシ', 'ちはら台西', 'チハラダイニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市瀬又', '12', '12219', '2900151', '千葉県', 'チバケン', '市原市', 'イチハラシ', '瀬又', 'セマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市高田', '12', '12219', '2900152', '千葉県', 'チバケン', '市原市', 'イチハラシ', '高田', 'タカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市中野', '12', '12219', '2900153', '千葉県', 'チバケン', '市原市', 'イチハラシ', '中野', 'ナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市下野', '12', '12219', '2900154', '千葉県', 'チバケン', '市原市', 'イチハラシ', '下野', 'シモノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市番場', '12', '12219', '2900155', '千葉県', 'チバケン', '市原市', 'イチハラシ', '番場', 'バンバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市草刈', '12', '12219', '2900156', '千葉県', 'チバケン', '市原市', 'イチハラシ', '草刈', 'クサカリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市押沼', '12', '12219', '2900157', '千葉県', 'チバケン', '市原市', 'イチハラシ', '押沼', 'オシヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市高倉', '12', '12219', '2900161', '千葉県', 'チバケン', '市原市', 'イチハラシ', '高倉', 'タカクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市金剛地', '12', '12219', '2900162', '千葉県', 'チバケン', '市原市', 'イチハラシ', '金剛地', 'コンゴウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市東国吉', '12', '12219', '2900163', '千葉県', 'チバケン', '市原市', 'イチハラシ', '東国吉', 'ヒガシクニヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市奈良', '12', '12219', '2900164', '千葉県', 'チバケン', '市原市', 'イチハラシ', '奈良', 'ナラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市古都辺', '12', '12219', '2900165', '千葉県', 'チバケン', '市原市', 'イチハラシ', '古都辺', 'コツベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市犬成', '12', '12219', '2900166', '千葉県', 'チバケン', '市原市', 'イチハラシ', '犬成', 'イヌナリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市喜多', '12', '12219', '2900167', '千葉県', 'チバケン', '市原市', 'イチハラシ', '喜多', 'キタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市永吉', '12', '12219', '2900168', '千葉県', 'チバケン', '市原市', 'イチハラシ', '永吉', 'ナガヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市潤井戸', '12', '12219', '2900171', '千葉県', 'チバケン', '市原市', 'イチハラシ', '潤井戸', 'ウルイド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市大作', '12', '12219', '2900172', '千葉県', 'チバケン', '市原市', 'イチハラシ', '大作', 'オオサク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市滝口', '12', '12219', '2900173', '千葉県', 'チバケン', '市原市', 'イチハラシ', '滝口', 'タキグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市勝間', '12', '12219', '2900174', '千葉県', 'チバケン', '市原市', 'イチハラシ', '勝間', 'カツマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市葉木', '12', '12219', '2900175', '千葉県', 'チバケン', '市原市', 'イチハラシ', '葉木', 'ハギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市小田部', '12', '12219', '2900176', '千葉県', 'チバケン', '市原市', 'イチハラシ', '小田部', 'オダツペ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市荻作', '12', '12219', '2900177', '千葉県', 'チバケン', '市原市', 'イチハラシ', '荻作', 'オギサク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市神崎', '12', '12219', '2900178', '千葉県', 'チバケン', '市原市', 'イチハラシ', '神崎', 'カンザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市久々津', '12', '12219', '2900179', '千葉県', 'チバケン', '市原市', 'イチハラシ', '久々津', 'クグツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市山倉', '12', '12219', '2900201', '千葉県', 'チバケン', '市原市', 'イチハラシ', '山倉', 'ヤマクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市福増', '12', '12219', '2900202', '千葉県', 'チバケン', '市原市', 'イチハラシ', '福増', 'フクマス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市武士', '12', '12219', '2900203', '千葉県', 'チバケン', '市原市', 'イチハラシ', '武士', 'タケシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市磯ケ谷', '12', '12219', '2900204', '千葉県', 'チバケン', '市原市', 'イチハラシ', '磯ケ谷', 'イソガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市山田', '12', '12219', '2900205', '千葉県', 'チバケン', '市原市', 'イチハラシ', '山田', 'ヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市新堀', '12', '12219', '2900206', '千葉県', 'チバケン', '市原市', 'イチハラシ', '新堀', 'ニイホリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市海士有木', '12', '12219', '2900207', '千葉県', 'チバケン', '市原市', 'イチハラシ', '海士有木', 'アマアリキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市大坪', '12', '12219', '2900208', '千葉県', 'チバケン', '市原市', 'イチハラシ', '大坪', 'オオツボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市権現堂', '12', '12219', '2900209', '千葉県', 'チバケン', '市原市', 'イチハラシ', '権現堂', 'ゴンゲンドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市大桶', '12', '12219', '2900211', '千葉県', 'チバケン', '市原市', 'イチハラシ', '大桶', 'オオオケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市新巻', '12', '12219', '2900212', '千葉県', 'チバケン', '市原市', 'イチハラシ', '新巻', 'アラマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市川在', '12', '12219', '2900213', '千葉県', 'チバケン', '市原市', 'イチハラシ', '川在', 'カワザイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市櫃挾', '12', '12219', '2900214', '千葉県', 'チバケン', '市原市', 'イチハラシ', '櫃挾', 'ヒツバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市土宇', '12', '12219', '2900215', '千葉県', 'チバケン', '市原市', 'イチハラシ', '土宇', 'ツチウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市二日市場', '12', '12219', '2900216', '千葉県', 'チバケン', '市原市', 'イチハラシ', '二日市場', 'フツカイチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市松崎', '12', '12219', '2900217', '千葉県', 'チバケン', '市原市', 'イチハラシ', '松崎', 'マツザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市馬立', '12', '12219', '2900221', '千葉県', 'チバケン', '市原市', 'イチハラシ', '馬立', 'ウマタテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市上原', '12', '12219', '2900222', '千葉県', 'チバケン', '市原市', 'イチハラシ', '上原', 'ウエハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市妙香', '12', '12219', '2900223', '千葉県', 'チバケン', '市原市', 'イチハラシ', '妙香', 'ミョウコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市奉免', '12', '12219', '2900224', '千葉県', 'チバケン', '市原市', 'イチハラシ', '奉免', 'ホウメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市牛久', '12', '12219', '2900225', '千葉県', 'チバケン', '市原市', 'イチハラシ', '牛久', 'ウシク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市中', '12', '12219', '2900226', '千葉県', 'チバケン', '市原市', 'イチハラシ', '中', 'ナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市藪', '12', '12219', '2900227', '千葉県', 'チバケン', '市原市', 'イチハラシ', '藪', 'ヤブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市岩', '12', '12219', '2900228', '千葉県', 'チバケン', '市原市', 'イチハラシ', '岩', 'イワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市佐是', '12', '12219', '2900229', '千葉県', 'チバケン', '市原市', 'イチハラシ', '佐是', 'サゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市西国吉', '12', '12219', '2900231', '千葉県', 'チバケン', '市原市', 'イチハラシ', '西国吉', 'ニシクニヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市皆吉', '12', '12219', '2900232', '千葉県', 'チバケン', '市原市', 'イチハラシ', '皆吉', 'ミナヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市金沢', '12', '12219', '2900233', '千葉県', 'チバケン', '市原市', 'イチハラシ', '金沢', 'カネサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市大蔵', '12', '12219', '2900234', '千葉県', 'チバケン', '市原市', 'イチハラシ', '大蔵', 'オオクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市栢橋', '12', '12219', '2900235', '千葉県', 'チバケン', '市原市', 'イチハラシ', '栢橋', 'カヤハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市寺谷', '12', '12219', '2900236', '千葉県', 'チバケン', '市原市', 'イチハラシ', '寺谷', 'テラヤツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市風戸', '12', '12219', '2900241', '千葉県', 'チバケン', '市原市', 'イチハラシ', '風戸', 'カザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市中高根', '12', '12219', '2900242', '千葉県', 'チバケン', '市原市', 'イチハラシ', '中高根', 'ナカタカネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市上高根', '12', '12219', '2900243', '千葉県', 'チバケン', '市原市', 'イチハラシ', '上高根', 'カミタカネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市南岩崎', '12', '12219', '2900244', '千葉県', 'チバケン', '市原市', 'イチハラシ', '南岩崎', 'ミナミイワサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市浅井小向', '12', '12219', '2900251', '千葉県', 'チバケン', '市原市', 'イチハラシ', '浅井小向', 'アサイコムカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市相川', '12', '12219', '2900252', '千葉県', 'チバケン', '市原市', 'イチハラシ', '相川', 'アイカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市安須', '12', '12219', '2900253', '千葉県', 'チバケン', '市原市', 'イチハラシ', '安須', 'アズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市高坂', '12', '12219', '2900254', '千葉県', 'チバケン', '市原市', 'イチハラシ', '高坂', 'コウザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市光風台', '12', '12219', '2900255', '千葉県', 'チバケン', '市原市', 'イチハラシ', '光風台', 'コウフウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市引田', '12', '12219', '2900256', '千葉県', 'チバケン', '市原市', 'イチハラシ', '引田', 'ヒキダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市新生', '12', '12219', '2900257', '千葉県', 'チバケン', '市原市', 'イチハラシ', '新生', 'アラオイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市神代', '12', '12219', '2900258', '千葉県', 'チバケン', '市原市', 'イチハラシ', '神代', 'カジロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市分目', '12', '12219', '2900259', '千葉県', 'チバケン', '市原市', 'イチハラシ', '分目', 'ワンメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市西野', '12', '12219', '2900261', '千葉県', 'チバケン', '市原市', 'イチハラシ', '西野', 'ニシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市糸久', '12', '12219', '2900262', '千葉県', 'チバケン', '市原市', 'イチハラシ', '糸久', 'イトヒサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市十五沢', '12', '12219', '2900263', '千葉県', 'チバケン', '市原市', 'イチハラシ', '十五沢', 'ジュウゴザワ', null, null, null, null), ('18420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市宮原', '12', '12219', '2900264', '千葉県', 'チバケン', '市原市', 'イチハラシ', '宮原', 'ミヤバラ', null, null, null, null), ('18421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市今富', '12', '12219', '2900265', '千葉県', 'チバケン', '市原市', 'イチハラシ', '今富', 'イマドミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市海保', '12', '12219', '2900266', '千葉県', 'チバケン', '市原市', 'イチハラシ', '海保', 'カイホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市町田', '12', '12219', '2900267', '千葉県', 'チバケン', '市原市', 'イチハラシ', '町田', 'マチダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市柳原', '12', '12219', '2900268', '千葉県', 'チバケン', '市原市', 'イチハラシ', '柳原', 'ヤナギハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市小折', '12', '12219', '2900269', '千葉県', 'チバケン', '市原市', 'イチハラシ', '小折', 'コオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市米沢', '12', '12219', '2900501', '千葉県', 'チバケン', '市原市', 'イチハラシ', '米沢', 'ヨネザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市真ケ谷', '12', '12219', '2900502', '千葉県', 'チバケン', '市原市', 'イチハラシ', '真ケ谷', 'シンガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市宿', '12', '12219', '2900503', '千葉県', 'チバケン', '市原市', 'イチハラシ', '宿', 'シュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市堀越', '12', '12219', '2900504', '千葉県', 'チバケン', '市原市', 'イチハラシ', '堀越', 'ホリコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市市場', '12', '12219', '2900505', '千葉県', 'チバケン', '市原市', 'イチハラシ', '市場', 'イチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市島田', '12', '12219', '2900506', '千葉県', 'チバケン', '市原市', 'イチハラシ', '島田', 'シマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市原田', '12', '12219', '2900507', '千葉県', 'チバケン', '市原市', 'イチハラシ', '原田', 'ハラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市江子田', '12', '12219', '2900508', '千葉県', 'チバケン', '市原市', 'イチハラシ', '江子田', 'エゴダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市安久谷', '12', '12219', '2900509', '千葉県', 'チバケン', '市原市', 'イチハラシ', '安久谷', 'アクヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市石川', '12', '12219', '2900511', '千葉県', 'チバケン', '市原市', 'イチハラシ', '石川', 'イシカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市鶴舞', '12', '12219', '2900512', '千葉県', 'チバケン', '市原市', 'イチハラシ', '鶴舞', 'ツルマイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市奥野', '12', '12219', '2900513', '千葉県', 'チバケン', '市原市', 'イチハラシ', '奥野', 'オクノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市水沢', '12', '12219', '2900514', '千葉県', 'チバケン', '市原市', 'イチハラシ', '水沢', 'ミズサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市田尾', '12', '12219', '2900515', '千葉県', 'チバケン', '市原市', 'イチハラシ', '田尾', 'タビ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市池和田', '12', '12219', '2900516', '千葉県', 'チバケン', '市原市', 'イチハラシ', '池和田', 'イケワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市矢田', '12', '12219', '2900517', '千葉県', 'チバケン', '市原市', 'イチハラシ', '矢田', 'ヤタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市下矢田', '12', '12219', '2900518', '千葉県', 'チバケン', '市原市', 'イチハラシ', '下矢田', 'シモヤタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市山小川', '12', '12219', '2900521', '千葉県', 'チバケン', '市原市', 'イチハラシ', '山小川', 'ヤマコガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市新井', '12', '12219', '2900522', '千葉県', 'チバケン', '市原市', 'イチハラシ', '新井', 'アライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市吉沢', '12', '12219', '2900523', '千葉県', 'チバケン', '市原市', 'イチハラシ', '吉沢', 'キチサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市平蔵', '12', '12219', '2900524', '千葉県', 'チバケン', '市原市', 'イチハラシ', '平蔵', 'ヘイゾウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市米原', '12', '12219', '2900525', '千葉県', 'チバケン', '市原市', 'イチハラシ', '米原', 'ヨネワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市小草畑', '12', '12219', '2900526', '千葉県', 'チバケン', '市原市', 'イチハラシ', '小草畑', 'コクサバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市月出', '12', '12219', '2900527', '千葉県', 'チバケン', '市原市', 'イチハラシ', '月出', 'ツキデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市古敷谷', '12', '12219', '2900528', '千葉県', 'チバケン', '市原市', 'イチハラシ', '古敷谷', 'コシキヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市小谷田', '12', '12219', '2900529', '千葉県', 'チバケン', '市原市', 'イチハラシ', '小谷田', 'コヤダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市国本', '12', '12219', '2900531', '千葉県', 'チバケン', '市原市', 'イチハラシ', '国本', 'コクモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市大久保', '12', '12219', '2900532', '千葉県', 'チバケン', '市原市', 'イチハラシ', '大久保', 'オオクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市折津', '12', '12219', '2900533', '千葉県', 'チバケン', '市原市', 'イチハラシ', '折津', 'オリヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市石神', '12', '12219', '2900534', '千葉県', 'チバケン', '市原市', 'イチハラシ', '石神', 'イシガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市朝生原', '12', '12219', '2900535', '千葉県', 'チバケン', '市原市', 'イチハラシ', '朝生原', 'アソウバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市戸面', '12', '12219', '2900536', '千葉県', 'チバケン', '市原市', 'イチハラシ', '戸面', 'トヅラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市石塚', '12', '12219', '2900537', '千葉県', 'チバケン', '市原市', 'イチハラシ', '石塚', 'イシヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市柳川', '12', '12219', '2900538', '千葉県', 'チバケン', '市原市', 'イチハラシ', '柳川', 'ヤナガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市菅野', '12', '12219', '2900539', '千葉県', 'チバケン', '市原市', 'イチハラシ', '菅野', 'スゲノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市平野', '12', '12219', '2900541', '千葉県', 'チバケン', '市原市', 'イチハラシ', '平野', 'ヒラノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市大戸', '12', '12219', '2900542', '千葉県', 'チバケン', '市原市', 'イチハラシ', '大戸', 'オオト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市飯給', '12', '12219', '2900543', '千葉県', 'チバケン', '市原市', 'イチハラシ', '飯給', 'イタブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市徳氏', '12', '12219', '2900544', '千葉県', 'チバケン', '市原市', 'イチハラシ', '徳氏', 'トクウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市田淵旧日竹', '12', '12219', '2900545', '千葉県', 'チバケン', '市原市', 'イチハラシ', '田淵旧日竹', 'タブチキュウヒタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市田淵', '12', '12219', '2900546', '千葉県', 'チバケン', '市原市', 'イチハラシ', '田淵', 'タブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市月崎', '12', '12219', '2900547', '千葉県', 'チバケン', '市原市', 'イチハラシ', '月崎', 'ツキザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市柿木台', '12', '12219', '2900548', '千葉県', 'チバケン', '市原市', 'イチハラシ', '柿木台', 'カキノキダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市万田野', '12', '12219', '2900549', '千葉県', 'チバケン', '市原市', 'イチハラシ', '万田野', 'マンダノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市外部田', '12', '12219', '2900551', '千葉県', 'チバケン', '市原市', 'イチハラシ', '外部田', 'トノベタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市久保', '12', '12219', '2900552', '千葉県', 'チバケン', '市原市', 'イチハラシ', '久保', 'クボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市大和田', '12', '12219', '2900553', '千葉県', 'チバケン', '市原市', 'イチハラシ', '大和田', 'オオワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市不入', '12', '12219', '2900554', '千葉県', 'チバケン', '市原市', 'イチハラシ', '不入', 'フニュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市高滝', '12', '12219', '2900555', '千葉県', 'チバケン', '市原市', 'イチハラシ', '高滝', 'タカタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市本郷', '12', '12219', '2900556', '千葉県', 'チバケン', '市原市', 'イチハラシ', '本郷', 'ホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市養老', '12', '12219', '2900557', '千葉県', 'チバケン', '市原市', 'イチハラシ', '養老', 'ヨウロウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市山口', '12', '12219', '2900558', '千葉県', 'チバケン', '市原市', 'イチハラシ', '山口', 'ヤマグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市駒込', '12', '12219', '2900559', '千葉県', 'チバケン', '市原市', 'イチハラシ', '駒込', 'コマゴメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市狐禅寺', '03', '03209', '0290131', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '狐禅寺', 'コゼンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市滝沢', '03', '03209', '0290132', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '滝沢', 'タキザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市川崎町門崎', '03', '03209', '0290201', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '川崎町門崎', 'カワサキチョウカンザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市川崎町薄衣', '03', '03209', '0290202', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '川崎町薄衣', 'カワサキチョウウスギヌ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市弥栄', '03', '03209', '0290211', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '弥栄', 'ヤサカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市東山町田河津', '03', '03209', '0290301', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '東山町田河津', 'ヒガシヤマチョウタコウヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市東山町長坂', '03', '03209', '0290302', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '東山町長坂', 'ヒガシヤマチョウナガサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市東山町松川', '03', '03209', '0290303', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '東山町松川', 'ヒガシヤマチョウマツカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市大東町猿沢', '03', '03209', '0290431', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '大東町猿沢', 'ダイトウチョウサルサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市大東町渋民', '03', '03209', '0290521', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '大東町渋民', 'ダイトウチョウシブタミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市大東町曽慶', '03', '03209', '0290522', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '大東町曽慶', 'ダイトウチョウソゲイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市大東町摺沢', '03', '03209', '0290523', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '大東町摺沢', 'ダイトウチョウスリサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市大東町中川', '03', '03209', '0290601', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '大東町中川', 'ダイトウチョウナカガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市大東町鳥海', '03', '03209', '0290602', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '大東町鳥海', 'ダイトウチョウトリウミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市大東町沖田', '03', '03209', '0290603', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '大東町沖田', 'ダイトウチョウオキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市大東町大原', '03', '03209', '0290711', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '大東町大原', 'ダイトウチョウオオハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市千厩町清田', '03', '03209', '0290801', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '千厩町清田', 'センマヤチョウキヨタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市千厩町小梨', '03', '03209', '0290802', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '千厩町小梨', 'センマヤチョウコナシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市千厩町千厩', '03', '03209', '0290803', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '千厩町千厩', 'センマヤチョウセンマヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市千厩町磐清水', '03', '03209', '0290804', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '千厩町磐清水', 'センマヤチョウイワシミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市千厩町奥玉', '03', '03209', '0291111', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '千厩町奥玉', 'センマヤチョウオクタマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市室根町折壁', '03', '03209', '0291201', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '室根町折壁', 'ムロネチョウオリカベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市室根町矢越', '03', '03209', '0291202', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '室根町矢越', 'ムロネチョウヤゴシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市室根町津谷川', '03', '03209', '0291211', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '室根町津谷川', 'ムロネチョウツヤガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県木更津市', '12', '12206', '2920000', '千葉県', 'チバケン', '木更津市', 'キサラヅシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('18521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県木更津市牛込', '12', '12206', '2920001', '千葉県', 'チバケン', '木更津市', 'キサラヅシ', '牛込', 'ウシゴメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県木更津市中野', '12', '12206', '2920002', '千葉県', 'チバケン', '木更津市', 'キサラヅシ', '中野', 'ナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県木更津市万石', '12', '12206', '2920003', '千葉県', 'チバケン', '木更津市', 'キサラヅシ', '万石', 'マンゴク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県木更津市久津間', '12', '12206', '2920004', '千葉県', 'チバケン', '木更津市', 'キサラヅシ', '久津間', 'クヅマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県木更津市畔戸', '12', '12206', '2920005', '千葉県', 'チバケン', '木更津市', 'キサラヅシ', '畔戸', 'クロト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県木更津市北浜町', '12', '12206', '2920006', '千葉県', 'チバケン', '木更津市', 'キサラヅシ', '北浜町', 'キタハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県木更津市瓜倉', '12', '12206', '2920007', '千葉県', 'チバケン', '木更津市', 'キサラヅシ', '瓜倉', 'ウリクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県木更津市中島', '12', '12206', '2920008', '千葉県', 'チバケン', '木更津市', 'キサラヅシ', '中島', 'ナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県木更津市牛袋野', '12', '12206', '2920011', '千葉県', 'チバケン', '木更津市', 'キサラヅシ', '牛袋野', 'ウシブクロノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県木更津市牛袋', '12', '12206', '2920012', '千葉県', 'チバケン', '木更津市', 'キサラヅシ', '牛袋', 'ウシブクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県木更津市若葉町', '12', '12206', '2920013', '千葉県', 'チバケン', '木更津市', 'キサラヅシ', '若葉町', 'ワカバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県木更津市高柳', '12', '12206', '2920014', '千葉県', 'チバケン', '木更津市', 'キサラヅシ', '高柳', 'タカヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県木更津市本郷', '12', '12206', '2920015', '千葉県', 'チバケン', '木更津市', 'キサラヅシ', '本郷', 'ホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県木更津市高砂', '12', '12206', '2920016', '千葉県', 'チバケン', '木更津市', 'キサラヅシ', '高砂', 'タカサゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県木更津市有吉', '12', '12206', '2920021', '千葉県', 'チバケン', '木更津市', 'キサラヅシ', '有吉', 'アリヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県木更津市上望陀', '12', '12206', '2920022', '千葉県', 'チバケン', '木更津市', 'キサラヅシ', '上望陀', 'カミモウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県木更津市下望陀', '12', '12206', '2920023', '千葉県', 'チバケン', '木更津市', 'キサラヅシ', '下望陀', 'シモモウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県木更津市大寺', '12', '12206', '2920024', '千葉県', 'チバケン', '木更津市', 'キサラヅシ', '大寺', 'オオテラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県木更津市十日市場', '12', '12206', '2920025', '千葉県', 'チバケン', '木更津市', 'キサラヅシ', '十日市場', 'トオカイチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県木更津市井尻', '12', '12206', '2920026', '千葉県', 'チバケン', '木更津市', 'キサラヅシ', '井尻', 'イジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県木更津市曽根', '12', '12206', '2920027', '千葉県', 'チバケン', '木更津市', 'キサラヅシ', '曽根', 'ソネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県木更津市椿', '12', '12206', '2920031', '千葉県', 'チバケン', '木更津市', 'キサラヅシ', '椿', 'ツバキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県木更津市笹子', '12', '12206', '2920032', '千葉県', 'チバケン', '木更津市', 'キサラヅシ', '笹子', 'ササゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県木更津市犬成', '12', '12206', '2920033', '千葉県', 'チバケン', '木更津市', 'キサラヅシ', '犬成', 'インナリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県木更津市伊豆島', '12', '12206', '2920034', '千葉県', 'チバケン', '木更津市', 'キサラヅシ', '伊豆島', 'イズシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県木更津市中尾', '12', '12206', '2920035', '千葉県', 'チバケン', '木更津市', 'キサラヅシ', '中尾', 'ナカオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県木更津市菅生', '12', '12206', '2920036', '千葉県', 'チバケン', '木更津市', 'キサラヅシ', '菅生', 'スゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県木更津市日の出町', '12', '12206', '2920037', '千葉県', 'チバケン', '木更津市', 'キサラヅシ', '日の出町', 'ヒノデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県木更津市ほたる野', '12', '12206', '2920038', '千葉県', 'チバケン', '木更津市', 'キサラヅシ', 'ほたる野', 'ホタルノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県木更津市清見台東', '12', '12206', '2920041', '千葉県', 'チバケン', '木更津市', 'キサラヅシ', '清見台東', 'キヨミダイヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県木更津市清見台南', '12', '12206', '2920042', '千葉県', 'チバケン', '木更津市', 'キサラヅシ', '清見台南', 'キヨミダイミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県木更津市東太田', '12', '12206', '2920043', '千葉県', 'チバケン', '木更津市', 'キサラヅシ', '東太田', 'ヒガシオオダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県木更津市太田', '12', '12206', '2920044', '千葉県', 'チバケン', '木更津市', 'キサラヅシ', '太田', 'オオダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県木更津市清見台', '12', '12206', '2920045', '千葉県', 'チバケン', '木更津市', 'キサラヅシ', '清見台', 'キヨミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県木更津市清川', '12', '12206', '2920051', '千葉県', 'チバケン', '木更津市', 'キサラヅシ', '清川', 'キヨカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県木更津市祇園', '12', '12206', '2920052', '千葉県', 'チバケン', '木更津市', 'キサラヅシ', '祇園', 'ギオン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県木更津市永井作', '12', '12206', '2920053', '千葉県', 'チバケン', '木更津市', 'キサラヅシ', '永井作', 'ナガイサク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県木更津市長須賀', '12', '12206', '2920054', '千葉県', 'チバケン', '木更津市', 'キサラヅシ', '長須賀', 'ナガスカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県木更津市朝日', '12', '12206', '2920055', '千葉県', 'チバケン', '木更津市', 'キサラヅシ', '朝日', 'アサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県木更津市木更津', '12', '12206', '2920056', '千葉県', 'チバケン', '木更津市', 'キサラヅシ', '木更津', 'キサラヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県木更津市東中央', '12', '12206', '2920057', '千葉県', 'チバケン', '木更津市', 'キサラヅシ', '東中央', 'ヒガシチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県木更津市岩根', '12', '12206', '2920061', '千葉県', 'チバケン', '木更津市', 'キサラヅシ', '岩根', 'イワネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県木更津市西岩根', '12', '12206', '2920062', '千葉県', 'チバケン', '木更津市', 'キサラヅシ', '西岩根', 'ニシイワネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県木更津市江川', '12', '12206', '2920063', '千葉県', 'チバケン', '木更津市', 'キサラヅシ', '江川', 'エガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県木更津市中里', '12', '12206', '2920064', '千葉県', 'チバケン', '木更津市', 'キサラヅシ', '中里', 'ナカザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県木更津市吾妻', '12', '12206', '2920065', '千葉県', 'チバケン', '木更津市', 'キサラヅシ', '吾妻', 'アヅマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県木更津市新宿', '12', '12206', '2920066', '千葉県', 'チバケン', '木更津市', 'キサラヅシ', '新宿', 'シンジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県木更津市中央', '12', '12206', '2920067', '千葉県', 'チバケン', '木更津市', 'キサラヅシ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県木更津市中島地先海ほたる', '12', '12206', '2920071', '千葉県', 'チバケン', '木更津市', 'キサラヅシ', '中島地先海ほたる', 'ナカジマチサキウミホタル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県木更津市真里谷', '12', '12206', '2920201', '千葉県', 'チバケン', '木更津市', 'キサラヅシ', '真里谷', 'マリヤツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県木更津市茅野七曲', '12', '12206', '2920202', '千葉県', 'チバケン', '木更津市', 'キサラヅシ', '茅野七曲', 'カヤノナナマガリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県木更津市山本七曲', '12', '12206', '2920203', '千葉県', 'チバケン', '木更津市', 'キサラヅシ', '山本七曲', 'ヤマモトナナマガリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県木更津市茅野', '12', '12206', '2920204', '千葉県', 'チバケン', '木更津市', 'キサラヅシ', '茅野', 'カヤノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県木更津市下郡', '12', '12206', '2920205', '千葉県', 'チバケン', '木更津市', 'キサラヅシ', '下郡', 'シモゴオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県木更津市佐野', '12', '12206', '2920206', '千葉県', 'チバケン', '木更津市', 'キサラヅシ', '佐野', 'サノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県木更津市田川', '12', '12206', '2920207', '千葉県', 'チバケン', '木更津市', 'キサラヅシ', '田川', 'タガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県木更津市大稲', '12', '12206', '2920211', '千葉県', 'チバケン', '木更津市', 'キサラヅシ', '大稲', 'オオイネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県木更津市真里', '12', '12206', '2920212', '千葉県', 'チバケン', '木更津市', 'キサラヅシ', '真里', 'マリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県木更津市下内橋', '12', '12206', '2920213', '千葉県', 'チバケン', '木更津市', 'キサラヅシ', '下内橋', 'ゲナイバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県木更津市戸国', '12', '12206', '2920214', '千葉県', 'チバケン', '木更津市', 'キサラヅシ', '戸国', 'トクニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県木更津市上根岸', '12', '12206', '2920215', '千葉県', 'チバケン', '木更津市', 'キサラヅシ', '上根岸', 'カミネギシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県木更津市根岸', '12', '12206', '2920216', '千葉県', 'チバケン', '木更津市', 'キサラヅシ', '根岸', 'ネギシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県木更津市下宮田', '12', '12206', '2920217', '千葉県', 'チバケン', '木更津市', 'キサラヅシ', '下宮田', 'シモミヤダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市山本', '12', '12225', '2920401', '千葉県', 'チバケン', '君津市', 'キミツシ', '山本', 'ヤマモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市西原', '12', '12225', '2920402', '千葉県', 'チバケン', '君津市', 'キミツシ', '西原', 'ニシバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市三田', '12', '12225', '2920403', '千葉県', 'チバケン', '君津市', 'キミツシ', '三田', 'サンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市賀恵渕', '12', '12225', '2920404', '千葉県', 'チバケン', '君津市', 'キミツシ', '賀恵渕', 'カエフチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市長谷川', '12', '12225', '2920411', '千葉県', 'チバケン', '君津市', 'キミツシ', '長谷川', 'ハセガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市小櫃台', '12', '12225', '2920412', '千葉県', 'チバケン', '君津市', 'キミツシ', '小櫃台', 'オビツダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市吉野', '12', '12225', '2920413', '千葉県', 'チバケン', '君津市', 'キミツシ', '吉野', 'ヨシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市久留里大谷', '12', '12225', '2920414', '千葉県', 'チバケン', '君津市', 'キミツシ', '久留里大谷', 'クルリオオヤツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市川谷', '12', '12225', '2920415', '千葉県', 'チバケン', '君津市', 'キミツシ', '川谷', 'カワヤツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市小市部', '12', '12225', '2920416', '千葉県', 'チバケン', '君津市', 'キミツシ', '小市部', 'コイチブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市久留里市場', '12', '12225', '2920421', '千葉県', 'チバケン', '君津市', 'キミツシ', '久留里市場', 'クルリイチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市久留里', '12', '12225', '2920422', '千葉県', 'チバケン', '君津市', 'キミツシ', '久留里', 'クルリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市久留里大和田', '12', '12225', '2920423', '千葉県', 'チバケン', '君津市', 'キミツシ', '久留里大和田', 'クルリオオワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市怒田', '12', '12225', '2920431', '千葉県', 'チバケン', '君津市', 'キミツシ', '怒田', 'ヌダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市浦田', '12', '12225', '2920432', '千葉県', 'チバケン', '君津市', 'キミツシ', '浦田', 'ウラタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市芋窪', '12', '12225', '2920433', '千葉県', 'チバケン', '君津市', 'キミツシ', '芋窪', 'イモクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市向郷', '12', '12225', '2920434', '千葉県', 'チバケン', '君津市', 'キミツシ', '向郷', 'ムカイゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市栗坪', '12', '12225', '2920435', '千葉県', 'チバケン', '君津市', 'キミツシ', '栗坪', 'クリツボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市戸崎', '12', '12225', '2920441', '千葉県', 'チバケン', '君津市', 'キミツシ', '戸崎', 'トザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市岩出', '12', '12225', '2920442', '千葉県', 'チバケン', '君津市', 'キミツシ', '岩出', 'イワデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市寺沢', '12', '12225', '2920443', '千葉県', 'チバケン', '君津市', 'キミツシ', '寺沢', 'テラザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市富田', '12', '12225', '2920444', '千葉県', 'チバケン', '君津市', 'キミツシ', '富田', 'トミダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市愛宕', '12', '12225', '2920445', '千葉県', 'チバケン', '君津市', 'キミツシ', '愛宕', 'アタゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市末吉', '12', '12225', '2920451', '千葉県', 'チバケン', '君津市', 'キミツシ', '末吉', 'スエヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市上新田', '12', '12225', '2920452', '千葉県', 'チバケン', '君津市', 'キミツシ', '上新田', 'カミニッタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市箕輪', '12', '12225', '2920453', '千葉県', 'チバケン', '君津市', 'キミツシ', '箕輪', 'ミノワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市青柳', '12', '12225', '2920454', '千葉県', 'チバケン', '君津市', 'キミツシ', '青柳', 'アオヤギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市俵田', '12', '12225', '2920455', '千葉県', 'チバケン', '君津市', 'キミツシ', '俵田', 'タワラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市山滝野', '12', '12225', '2920501', '千葉県', 'チバケン', '君津市', 'キミツシ', '山滝野', 'ヤマタキノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市平山', '12', '12225', '2920502', '千葉県', 'チバケン', '君津市', 'キミツシ', '平山', 'ヒラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市広岡', '12', '12225', '2920503', '千葉県', 'チバケン', '君津市', 'キミツシ', '広岡', 'ヒロオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市大坂', '12', '12225', '2920511', '千葉県', 'チバケン', '君津市', 'キミツシ', '大坂', 'オサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市大戸見', '12', '12225', '2920512', '千葉県', 'チバケン', '君津市', 'キミツシ', '大戸見', 'オオトミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市加名盛', '12', '12225', '2920513', '千葉県', 'チバケン', '君津市', 'キミツシ', '加名盛', 'カナモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市大戸見旧名殿', '12', '12225', '2920514', '千葉県', 'チバケン', '君津市', 'キミツシ', '大戸見旧名殿', 'オオトミキュウナドノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市柳城', '12', '12225', '2920515', '千葉県', 'チバケン', '君津市', 'キミツシ', '柳城', 'ヤナシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市高水', '12', '12225', '2920516', '千葉県', 'チバケン', '君津市', 'キミツシ', '高水', 'タカミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市利根', '12', '12225', '2920521', '千葉県', 'チバケン', '君津市', 'キミツシ', '利根', 'トネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市大中', '12', '12225', '2920522', '千葉県', 'チバケン', '君津市', 'キミツシ', '大中', 'ダイナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市豊田', '12', '12225', '2920523', '千葉県', 'チバケン', '君津市', 'キミツシ', '豊田', 'トヨダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市川俣', '12', '12225', '2920524', '千葉県', 'チバケン', '君津市', 'キミツシ', '川俣', 'カワマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市草川原', '12', '12225', '2920525', '千葉県', 'チバケン', '君津市', 'キミツシ', '草川原', 'クサガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市笹', '12', '12225', '2920526', '千葉県', 'チバケン', '君津市', 'キミツシ', '笹', 'ササ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市香木原', '12', '12225', '2920527', '千葉県', 'チバケン', '君津市', 'キミツシ', '香木原', 'カギハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市藤林', '12', '12225', '2920531', '千葉県', 'チバケン', '君津市', 'キミツシ', '藤林', 'フジバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市坂畑', '12', '12225', '2920532', '千葉県', 'チバケン', '君津市', 'キミツシ', '坂畑', 'サカハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市折木沢', '12', '12225', '2920533', '千葉県', 'チバケン', '君津市', 'キミツシ', '折木沢', 'オリキサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市滝原', '12', '12225', '2920534', '千葉県', 'チバケン', '君津市', 'キミツシ', '滝原', 'タキハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市釜生', '12', '12225', '2920535', '千葉県', 'チバケン', '君津市', 'キミツシ', '釜生', 'カモウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市蔵玉', '12', '12225', '2920536', '千葉県', 'チバケン', '君津市', 'キミツシ', '蔵玉', 'クラダマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市黄和田畑', '12', '12225', '2920537', '千葉県', 'チバケン', '君津市', 'キミツシ', '黄和田畑', 'キワダハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県木更津市請西', '12', '12206', '2920801', '千葉県', 'チバケン', '木更津市', 'キサラヅシ', '請西', 'ジョウザイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県木更津市真舟', '12', '12206', '2920802', '千葉県', 'チバケン', '木更津市', 'キサラヅシ', '真舟', 'マフネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県木更津市幸町', '12', '12206', '2920803', '千葉県', 'チバケン', '木更津市', 'キサラヅシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県木更津市文京', '12', '12206', '2920804', '千葉県', 'チバケン', '木更津市', 'キサラヅシ', '文京', 'ブンキョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県木更津市大和', '12', '12206', '2920805', '千葉県', 'チバケン', '木更津市', 'キサラヅシ', '大和', 'ヤマト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県木更津市請西東', '12', '12206', '2920806', '千葉県', 'チバケン', '木更津市', 'キサラヅシ', '請西東', 'ジョウザイヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県木更津市請西南', '12', '12206', '2920807', '千葉県', 'チバケン', '木更津市', 'キサラヅシ', '請西南', 'ジョウザイミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県木更津市草敷', '12', '12206', '2920811', '千葉県', 'チバケン', '木更津市', 'キサラヅシ', '草敷', 'クサジキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県木更津市矢那', '12', '12206', '2920812', '千葉県', 'チバケン', '木更津市', 'キサラヅシ', '矢那', 'ヤナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県木更津市上烏田', '12', '12206', '2920813', '千葉県', 'チバケン', '木更津市', 'キサラヅシ', '上烏田', 'カミカラスダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県木更津市八幡台', '12', '12206', '2920814', '千葉県', 'チバケン', '木更津市', 'キサラヅシ', '八幡台', 'ハチマンダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県木更津市大久保', '12', '12206', '2920815', '千葉県', 'チバケン', '木更津市', 'キサラヅシ', '大久保', 'オオクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県木更津市下烏田', '12', '12206', '2920816', '千葉県', 'チバケン', '木更津市', 'キサラヅシ', '下烏田', 'シモカラスダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県木更津市中烏田', '12', '12206', '2920817', '千葉県', 'チバケン', '木更津市', 'キサラヅシ', '中烏田', 'ナカカラスダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県木更津市かずさ鎌足', '12', '12206', '2920818', '千葉県', 'チバケン', '木更津市', 'キサラヅシ', 'かずさ鎌足', 'カズサカマタリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県木更津市羽鳥野', '12', '12206', '2920819', '千葉県', 'チバケン', '木更津市', 'キサラヅシ', '羽鳥野', 'ハトリノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県木更津市桜町', '12', '12206', '2920821', '千葉県', 'チバケン', '木更津市', 'キサラヅシ', '桜町', 'サクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県木更津市桜井', '12', '12206', '2920822', '千葉県', 'チバケン', '木更津市', 'キサラヅシ', '桜井', 'サクライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県木更津市桜井新町', '12', '12206', '2920823', '千葉県', 'チバケン', '木更津市', 'キサラヅシ', '桜井新町', 'サクライシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県木更津市小浜', '12', '12206', '2920824', '千葉県', 'チバケン', '木更津市', 'キサラヅシ', '小浜', 'コバマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県木更津市畑沢', '12', '12206', '2920825', '千葉県', 'チバケン', '木更津市', 'キサラヅシ', '畑沢', 'ハタザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県木更津市畑沢南', '12', '12206', '2920826', '千葉県', 'チバケン', '木更津市', 'キサラヅシ', '畑沢南', 'ハタザワミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県木更津市港南台', '12', '12206', '2920827', '千葉県', 'チバケン', '木更津市', 'キサラヅシ', '港南台', 'コウナンダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県木更津市富士見', '12', '12206', '2920831', '千葉県', 'チバケン', '木更津市', 'キサラヅシ', '富士見', 'フジミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県木更津市新田', '12', '12206', '2920832', '千葉県', 'チバケン', '木更津市', 'キサラヅシ', '新田', 'シンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県木更津市貝渕', '12', '12206', '2920833', '千葉県', 'チバケン', '木更津市', 'キサラヅシ', '貝渕', 'カイフチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県木更津市潮見', '12', '12206', '2920834', '千葉県', 'チバケン', '木更津市', 'キサラヅシ', '潮見', 'シオミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県木更津市築地', '12', '12206', '2920835', '千葉県', 'チバケン', '木更津市', 'キサラヅシ', '築地', 'ツキジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県木更津市新港', '12', '12206', '2920836', '千葉県', 'チバケン', '木更津市', 'キサラヅシ', '新港', 'シンミナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県木更津市木材港', '12', '12206', '2920837', '千葉県', 'チバケン', '木更津市', 'キサラヅシ', '木材港', 'モクザイミナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県木更津市潮浜', '12', '12206', '2920838', '千葉県', 'チバケン', '木更津市', 'キサラヅシ', '潮浜', 'シオハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県木更津市中の島', '12', '12206', '2920839', '千葉県', 'チバケン', '木更津市', 'キサラヅシ', '中の島', 'ナカノシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市糠田飛地', '12', '12225', '2921140', '千葉県', 'チバケン', '君津市', 'キミツシ', '糠田飛地', 'ヌカタトビチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市根本', '12', '12225', '2921141', '千葉県', 'チバケン', '君津市', 'キミツシ', '根本', 'ネモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市小糸大谷', '12', '12225', '2921142', '千葉県', 'チバケン', '君津市', 'キミツシ', '小糸大谷', 'コイトオオヤツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市長石', '12', '12225', '2921143', '千葉県', 'チバケン', '君津市', 'キミツシ', '長石', 'ナガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市法木', '12', '12225', '2921144', '千葉県', 'チバケン', '君津市', 'キミツシ', '法木', 'ホウギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市糸川', '12', '12225', '2921145', '千葉県', 'チバケン', '君津市', 'キミツシ', '糸川', 'イトガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市大井戸', '12', '12225', '2921146', '千葉県', 'チバケン', '君津市', 'キミツシ', '大井戸', 'オオイド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市塚原', '12', '12225', '2921147', '千葉県', 'チバケン', '君津市', 'キミツシ', '塚原', 'ツカハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市行馬', '12', '12225', '2921148', '千葉県', 'チバケン', '君津市', 'キミツシ', '行馬', 'ギョウマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市かずさ小糸', '12', '12225', '2921149', '千葉県', 'チバケン', '君津市', 'キミツシ', 'かずさ小糸', 'カズサコイト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市大野台', '12', '12225', '2921151', '千葉県', 'チバケン', '君津市', 'キミツシ', '大野台', 'オオノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市日渡根', '12', '12225', '2921152', '千葉県', 'チバケン', '君津市', 'キミツシ', '日渡根', 'ニットネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市市宿', '12', '12225', '2921153', '千葉県', 'チバケン', '君津市', 'キミツシ', '市宿', 'イチジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市清和市場', '12', '12225', '2921154', '千葉県', 'チバケン', '君津市', 'キミツシ', '清和市場', 'セイワイチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市鹿野山', '12', '12225', '2921155', '千葉県', 'チバケン', '君津市', 'キミツシ', '鹿野山', 'カノウザン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市荻作', '12', '12225', '2921156', '千葉県', 'チバケン', '君津市', 'キミツシ', '荻作', 'オギサク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市福岡', '12', '12225', '2921157', '千葉県', 'チバケン', '君津市', 'キミツシ', '福岡', 'フクオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市鎌滝', '12', '12225', '2921158', '千葉県', 'チバケン', '君津市', 'キミツシ', '鎌滝', 'カマダキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市東猪原', '12', '12225', '2921161', '千葉県', 'チバケン', '君津市', 'キミツシ', '東猪原', 'ヒガシイノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市西猪原', '12', '12225', '2921162', '千葉県', 'チバケン', '君津市', 'キミツシ', '西猪原', 'ニシイノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市東粟倉', '12', '12225', '2921163', '千葉県', 'チバケン', '君津市', 'キミツシ', '東粟倉', 'ヒガシアワグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市東日笠', '12', '12225', '2921164', '千葉県', 'チバケン', '君津市', 'キミツシ', '東日笠', 'ヒガシヒカサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市西日笠', '12', '12225', '2921165', '千葉県', 'チバケン', '君津市', 'キミツシ', '西日笠', 'ニシヒカサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市植畑', '12', '12225', '2921166', '千葉県', 'チバケン', '君津市', 'キミツシ', '植畑', 'ウエハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市平田', '12', '12225', '2921167', '千葉県', 'チバケン', '君津市', 'キミツシ', '平田', 'ヒラッタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市西粟倉', '12', '12225', '2921168', '千葉県', 'チバケン', '君津市', 'キミツシ', '西粟倉', 'ニシアワグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市二入', '12', '12225', '2921171', '千葉県', 'チバケン', '君津市', 'キミツシ', '二入', 'フタイリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市辻森', '12', '12225', '2921172', '千葉県', 'チバケン', '君津市', 'キミツシ', '辻森', 'ツジモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市大岩', '12', '12225', '2921173', '千葉県', 'チバケン', '君津市', 'キミツシ', '大岩', 'オオイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市正木', '12', '12225', '2921174', '千葉県', 'チバケン', '君津市', 'キミツシ', '正木', 'マサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市奥米', '12', '12225', '2921175', '千葉県', 'チバケン', '君津市', 'キミツシ', '奥米', 'オクゴメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市宿原', '12', '12225', '2921176', '千葉県', 'チバケン', '君津市', 'キミツシ', '宿原', 'シュクバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市怒田沢', '12', '12225', '2921177', '千葉県', 'チバケン', '君津市', 'キミツシ', '怒田沢', 'ヌタザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市旅名', '12', '12225', '2921178', '千葉県', 'チバケン', '君津市', 'キミツシ', '旅名', 'タビナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市豊英', '12', '12225', '2921179', '千葉県', 'チバケン', '君津市', 'キミツシ', '豊英', 'トヨフサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県陸前高田市', '03', '03210', '0292200', '岩手県', 'イワテケン', '陸前高田市', 'リクゼンタカタシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('18703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県陸前高田市矢作町', '03', '03210', '0292201', '岩手県', 'イワテケン', '陸前高田市', 'リクゼンタカタシ', '矢作町', 'ヤハギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県陸前高田市横田町', '03', '03210', '0292202', '岩手県', 'イワテケン', '陸前高田市', 'リクゼンタカタシ', '横田町', 'ヨコタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県陸前高田市竹駒町', '03', '03210', '0292203', '岩手県', 'イワテケン', '陸前高田市', 'リクゼンタカタシ', '竹駒町', 'タケコマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県陸前高田市気仙町', '03', '03210', '0292204', '岩手県', 'イワテケン', '陸前高田市', 'リクゼンタカタシ', '気仙町', 'ケセンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県陸前高田市高田町', '03', '03210', '0292205', '岩手県', 'イワテケン', '陸前高田市', 'リクゼンタカタシ', '高田町', 'タカタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県陸前高田市米崎町', '03', '03210', '0292206', '岩手県', 'イワテケン', '陸前高田市', 'リクゼンタカタシ', '米崎町', 'ヨネサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県陸前高田市小友町', '03', '03210', '0292207', '岩手県', 'イワテケン', '陸前高田市', 'リクゼンタカタシ', '小友町', 'オトモチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県陸前高田市広田町', '03', '03210', '0292208', '岩手県', 'イワテケン', '陸前高田市', 'リクゼンタカタシ', '広田町', 'ヒロタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県気仙郡住田町', '03', '03441', '0292300', '岩手県', 'イワテケン', '気仙郡住田町', 'ケセングンスミタチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('18714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県気仙郡住田町世田米', '03', '03441', '0292311', '岩手県', 'イワテケン', '気仙郡住田町', 'ケセングンスミタチョウ', '世田米', 'セタマイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県気仙郡住田町上有住', '03', '03441', '0292501', '岩手県', 'イワテケン', '気仙郡住田町', 'ケセングンスミタチョウ', '上有住', 'カミアリス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県気仙郡住田町下有住', '03', '03441', '0292502', '岩手県', 'イワテケン', '気仙郡住田町', 'ケセングンスミタチョウ', '下有住', 'シモアリス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県富津市', '12', '12226', '2930000', '千葉県', 'チバケン', '富津市', 'フッツシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('18734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県富津市大堀', '12', '12226', '2930001', '千葉県', 'チバケン', '富津市', 'フッツシ', '大堀', 'オオホリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県富津市二間塚', '12', '12226', '2930002', '千葉県', 'チバケン', '富津市', 'フッツシ', '二間塚', 'フタマヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県富津市本郷', '12', '12226', '2930003', '千葉県', 'チバケン', '富津市', 'フッツシ', '本郷', 'ホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県富津市前久保', '12', '12226', '2930004', '千葉県', 'チバケン', '富津市', 'フッツシ', '前久保', 'マエクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県富津市上飯野', '12', '12226', '2930005', '千葉県', 'チバケン', '富津市', 'フッツシ', '上飯野', 'カミイイノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県富津市下飯野', '12', '12226', '2930006', '千葉県', 'チバケン', '富津市', 'フッツシ', '下飯野', 'シモイイノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県富津市新富', '12', '12226', '2930011', '千葉県', 'チバケン', '富津市', 'フッツシ', '新富', 'シントミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県富津市青木', '12', '12226', '2930012', '千葉県', 'チバケン', '富津市', 'フッツシ', '青木', 'アオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県富津市西川', '12', '12226', '2930013', '千葉県', 'チバケン', '富津市', 'フッツシ', '西川', 'ニシカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県富津市富津', '12', '12226', '2930021', '千葉県', 'チバケン', '富津市', 'フッツシ', '富津', 'フッツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県富津市新井', '12', '12226', '2930022', '千葉県', 'チバケン', '富津市', 'フッツシ', '新井', 'アライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県富津市川名', '12', '12226', '2930023', '千葉県', 'チバケン', '富津市', 'フッツシ', '川名', 'カワナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県富津市篠部', '12', '12226', '2930024', '千葉県', 'チバケン', '富津市', 'フッツシ', '篠部', 'シノベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県富津市相野谷', '12', '12226', '2930031', '千葉県', 'チバケン', '富津市', 'フッツシ', '相野谷', 'アイノヤツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県富津市障子谷', '12', '12226', '2930032', '千葉県', 'チバケン', '富津市', 'フッツシ', '障子谷', 'ショウジヤツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県富津市一色', '12', '12226', '2930033', '千葉県', 'チバケン', '富津市', 'フッツシ', '一色', 'イッシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県富津市絹', '12', '12226', '2930034', '千葉県', 'チバケン', '富津市', 'フッツシ', '絹', 'キヌ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県富津市西大和田', '12', '12226', '2930035', '千葉県', 'チバケン', '富津市', 'フッツシ', '西大和田', 'ニシオオワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県富津市千種新田', '12', '12226', '2930036', '千葉県', 'チバケン', '富津市', 'フッツシ', '千種新田', 'チグサシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県富津市上', '12', '12226', '2930041', '千葉県', 'チバケン', '富津市', 'フッツシ', '上', 'カミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県富津市小久保', '12', '12226', '2930042', '千葉県', 'チバケン', '富津市', 'フッツシ', '小久保', 'コクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県富津市岩瀬', '12', '12226', '2930043', '千葉県', 'チバケン', '富津市', 'フッツシ', '岩瀬', 'イワセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県富津市中', '12', '12226', '2930044', '千葉県', 'チバケン', '富津市', 'フッツシ', '中', 'ナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県富津市八田沼', '12', '12226', '2930045', '千葉県', 'チバケン', '富津市', 'フッツシ', '八田沼', 'ヤタヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県富津市近藤', '12', '12226', '2930046', '千葉県', 'チバケン', '富津市', 'フッツシ', '近藤', 'コンドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県富津市亀沢', '12', '12226', '2930051', '千葉県', 'チバケン', '富津市', 'フッツシ', '亀沢', 'カメザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県富津市宝竜寺', '12', '12226', '2930052', '千葉県', 'チバケン', '富津市', 'フッツシ', '宝竜寺', 'ホウリュウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県富津市花香谷', '12', '12226', '2930053', '千葉県', 'チバケン', '富津市', 'フッツシ', '花香谷', 'ハナガヤツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県富津市鶴岡', '12', '12226', '2930054', '千葉県', 'チバケン', '富津市', 'フッツシ', '鶴岡', 'ツルオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県富津市笹毛', '12', '12226', '2930055', '千葉県', 'チバケン', '富津市', 'フッツシ', '笹毛', 'ササゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県富津市八幡', '12', '12226', '2930056', '千葉県', 'チバケン', '富津市', 'フッツシ', '八幡', 'ヤワタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県富津市亀田', '12', '12226', '2930057', '千葉県', 'チバケン', '富津市', 'フッツシ', '亀田', 'カメダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県富津市佐貫', '12', '12226', '2930058', '千葉県', 'チバケン', '富津市', 'フッツシ', '佐貫', 'サヌキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市花泉町花泉', '03', '03209', '0293101', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '花泉町花泉', 'ハナイズミチョウハナイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市花泉町金沢', '03', '03209', '0293102', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '花泉町金沢', 'ハナイズミチョウカザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市花泉町老松', '03', '03209', '0293103', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '花泉町老松', 'ハナイズミチョウオイマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市花泉町日形', '03', '03209', '0293104', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '花泉町日形', 'ハナイズミチョウヒカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市花泉町涌津一ノ町', '03', '03209', '0293105', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '花泉町涌津', 'ハナイズミチョウワクツ', null, null, '一ノ町', 'イチノマチ');
INSERT INTO `ms_addresses` VALUES ('18772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市花泉町涌津上原', '03', '03209', '0293105', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '花泉町涌津', 'ハナイズミチョウワクツ', null, null, '上原', 'カミハラ');
INSERT INTO `ms_addresses` VALUES ('18773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市花泉町涌津境', '03', '03209', '0293105', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '花泉町涌津', 'ハナイズミチョウワクツ', null, null, '境', 'サカイ');
INSERT INTO `ms_addresses` VALUES ('18774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市花泉町涌津二ノ町', '03', '03209', '0293105', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '花泉町涌津', 'ハナイズミチョウワクツ', null, null, '二ノ町', 'ニノマチ');
INSERT INTO `ms_addresses` VALUES ('18775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市花泉町涌津古川', '03', '03209', '0293105', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '花泉町涌津', 'ハナイズミチョウワクツ', null, null, '古川', 'フルカワ');
INSERT INTO `ms_addresses` VALUES ('18776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市花泉町涌津道下', '03', '03209', '0293105', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '花泉町涌津', 'ハナイズミチョウワクツ', null, null, '道下', 'ミチシタ');
INSERT INTO `ms_addresses` VALUES ('18777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市花泉町涌津', '03', '03209', '0293205', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '花泉町涌津', 'ハナイズミチョウワクツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市花泉町永井', '03', '03209', '0293206', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '花泉町永井', 'ハナイズミチョウナガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県一関市花泉町油島', '03', '03209', '0293207', '岩手県', 'イワテケン', '一関市', 'イチノセキシ', '花泉町油島', 'ハナイズミチョウユシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県東磐井郡藤沢町黄海', '03', '03422', '0293311', '岩手県', 'イワテケン', '東磐井郡藤沢町', 'ヒガシイワイグンフジサワチョウ', '黄海', 'キノミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県東磐井郡藤沢町', '03', '03422', '0293400', '岩手県', 'イワテケン', '東磐井郡藤沢町', 'ヒガシイワイグンフジサワチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('18782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県東磐井郡藤沢町増沢', '03', '03422', '0293401', '岩手県', 'イワテケン', '東磐井郡藤沢町', 'ヒガシイワイグンフジサワチョウ', '増沢', 'マスザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県東磐井郡藤沢町新沼', '03', '03422', '0293402', '岩手県', 'イワテケン', '東磐井郡藤沢町', 'ヒガシイワイグンフジサワチョウ', '新沼', 'ニイヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県東磐井郡藤沢町砂子田', '03', '03422', '0293403', '岩手県', 'イワテケン', '東磐井郡藤沢町', 'ヒガシイワイグンフジサワチョウ', '砂子田', 'スナゴタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県東磐井郡藤沢町徳田', '03', '03422', '0293404', '岩手県', 'イワテケン', '東磐井郡藤沢町', 'ヒガシイワイグンフジサワチョウ', '徳田', 'トクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県東磐井郡藤沢町藤沢', '03', '03422', '0293405', '岩手県', 'イワテケン', '東磐井郡藤沢町', 'ヒガシイワイグンフジサワチョウ', '藤沢', 'フジサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県東磐井郡藤沢町西口', '03', '03422', '0293406', '岩手県', 'イワテケン', '東磐井郡藤沢町', 'ヒガシイワイグンフジサワチョウ', '西口', 'ニシグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県東磐井郡藤沢町保呂羽', '03', '03422', '0293521', '岩手県', 'イワテケン', '東磐井郡藤沢町', 'ヒガシイワイグンフジサワチョウ', '保呂羽', 'ホロワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県東磐井郡藤沢町大籠', '03', '03422', '0293522', '岩手県', 'イワテケン', '東磐井郡藤沢町', 'ヒガシイワイグンフジサワチョウ', '大籠', 'オオカゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県館山市', '12', '12205', '2940000', '千葉県', 'チバケン', '館山市', 'タテヤマシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('18793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県館山市竹原', '12', '12205', '2940001', '千葉県', 'チバケン', '館山市', 'タテヤマシ', '竹原', 'タケワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県館山市大井', '12', '12205', '2940002', '千葉県', 'チバケン', '館山市', 'タテヤマシ', '大井', 'オオイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県館山市水玉', '12', '12205', '2940003', '千葉県', 'チバケン', '館山市', 'タテヤマシ', '水玉', 'ミズタマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県館山市水岡', '12', '12205', '2940004', '千葉県', 'チバケン', '館山市', 'タテヤマシ', '水岡', 'ミズオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県館山市安東', '12', '12205', '2940005', '千葉県', 'チバケン', '館山市', 'タテヤマシ', '安東', 'アンドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県館山市薗', '12', '12205', '2940006', '千葉県', 'チバケン', '館山市', 'タテヤマシ', '薗', 'ソノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県館山市腰越', '12', '12205', '2940007', '千葉県', 'チバケン', '館山市', 'タテヤマシ', '腰越', 'コシゴエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県館山市広瀬', '12', '12205', '2940008', '千葉県', 'チバケン', '館山市', 'タテヤマシ', '広瀬', 'ヒロセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県館山市江田', '12', '12205', '2940009', '千葉県', 'チバケン', '館山市', 'タテヤマシ', '江田', 'エダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県館山市二子', '12', '12205', '2940011', '千葉県', 'チバケン', '館山市', 'タテヤマシ', '二子', 'フタゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県館山市稲', '12', '12205', '2940012', '千葉県', 'チバケン', '館山市', 'タテヤマシ', '稲', 'イナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県館山市宝貝', '12', '12205', '2940013', '千葉県', 'チバケン', '館山市', 'タテヤマシ', '宝貝', 'ホウガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県館山市山本', '12', '12205', '2940014', '千葉県', 'チバケン', '館山市', 'タテヤマシ', '山本', 'ヤマモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県館山市古茂口', '12', '12205', '2940015', '千葉県', 'チバケン', '館山市', 'タテヤマシ', '古茂口', 'コモグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県館山市飯沼', '12', '12205', '2940016', '千葉県', 'チバケン', '館山市', 'タテヤマシ', '飯沼', 'イイヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県館山市南条', '12', '12205', '2940017', '千葉県', 'チバケン', '館山市', 'タテヤマシ', '南条', 'ナンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県館山市国分', '12', '12205', '2940018', '千葉県', 'チバケン', '館山市', 'タテヤマシ', '国分', 'コクブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県館山市山荻', '12', '12205', '2940021', '千葉県', 'チバケン', '館山市', 'タテヤマシ', '山荻', 'ヤモオギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県館山市畑', '12', '12205', '2940022', '千葉県', 'チバケン', '館山市', 'タテヤマシ', '畑', 'ハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県館山市神余', '12', '12205', '2940023', '千葉県', 'チバケン', '館山市', 'タテヤマシ', '神余', 'カナマリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県館山市岡田', '12', '12205', '2940024', '千葉県', 'チバケン', '館山市', 'タテヤマシ', '岡田', 'オカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県館山市大戸', '12', '12205', '2940025', '千葉県', 'チバケン', '館山市', 'タテヤマシ', '大戸', 'オオト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県館山市出野尾', '12', '12205', '2940026', '千葉県', 'チバケン', '館山市', 'タテヤマシ', '出野尾', 'イデノオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県館山市西長田', '12', '12205', '2940027', '千葉県', 'チバケン', '館山市', 'タテヤマシ', '西長田', 'ニシナガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県館山市東長田', '12', '12205', '2940028', '千葉県', 'チバケン', '館山市', 'タテヤマシ', '東長田', 'ヒガシナガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県館山市作名', '12', '12205', '2940029', '千葉県', 'チバケン', '館山市', 'タテヤマシ', '作名', 'サクナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県館山市大賀', '12', '12205', '2940031', '千葉県', 'チバケン', '館山市', 'タテヤマシ', '大賀', 'オオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県館山市笠名', '12', '12205', '2940032', '千葉県', 'チバケン', '館山市', 'タテヤマシ', '笠名', 'カサナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県館山市宮城', '12', '12205', '2940033', '千葉県', 'チバケン', '館山市', 'タテヤマシ', '宮城', 'ミヤギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県館山市沼', '12', '12205', '2940034', '千葉県', 'チバケン', '館山市', 'タテヤマシ', '沼', 'ヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県館山市富士見', '12', '12205', '2940035', '千葉県', 'チバケン', '館山市', 'タテヤマシ', '富士見', 'フジミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県館山市館山', '12', '12205', '2940036', '千葉県', 'チバケン', '館山市', 'タテヤマシ', '館山', 'タテヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県館山市長須賀', '12', '12205', '2940037', '千葉県', 'チバケン', '館山市', 'タテヤマシ', '長須賀', 'ナガスカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県館山市上真倉', '12', '12205', '2940038', '千葉県', 'チバケン', '館山市', 'タテヤマシ', '上真倉', 'カミサナグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県館山市高井', '12', '12205', '2940041', '千葉県', 'チバケン', '館山市', 'タテヤマシ', '高井', 'タカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県館山市上野原', '12', '12205', '2940042', '千葉県', 'チバケン', '館山市', 'タテヤマシ', '上野原', 'ウエノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県館山市安布里', '12', '12205', '2940043', '千葉県', 'チバケン', '館山市', 'タテヤマシ', '安布里', 'アブリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県館山市大網', '12', '12205', '2940044', '千葉県', 'チバケン', '館山市', 'タテヤマシ', '大網', 'オオアミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県館山市北条', '12', '12205', '2940045', '千葉県', 'チバケン', '館山市', 'タテヤマシ', '北条', 'ホウジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県館山市新宿', '12', '12205', '2940046', '千葉県', 'チバケン', '館山市', 'タテヤマシ', '新宿', 'シンジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県館山市八幡', '12', '12205', '2940047', '千葉県', 'チバケン', '館山市', 'タテヤマシ', '八幡', 'ヤワタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県館山市下真倉', '12', '12205', '2940048', '千葉県', 'チバケン', '館山市', 'タテヤマシ', '下真倉', 'シモサナグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県館山市正木', '12', '12205', '2940051', '千葉県', 'チバケン', '館山市', 'タテヤマシ', '正木', 'マサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県館山市亀ケ原', '12', '12205', '2940052', '千葉県', 'チバケン', '館山市', 'タテヤマシ', '亀ケ原', 'カメガハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県館山市北条正木', '12', '12205', '2940053', '千葉県', 'チバケン', '館山市', 'タテヤマシ', '北条正木', 'ホウジョウマサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県館山市湊', '12', '12205', '2940054', '千葉県', 'チバケン', '館山市', 'タテヤマシ', '湊', 'ミナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県館山市那古', '12', '12205', '2940055', '千葉県', 'チバケン', '館山市', 'タテヤマシ', '那古', 'ナゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県館山市船形', '12', '12205', '2940056', '千葉県', 'チバケン', '館山市', 'タテヤマシ', '船形', 'フナカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県館山市川名', '12', '12205', '2940057', '千葉県', 'チバケン', '館山市', 'タテヤマシ', '川名', 'カワナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県館山市小原', '12', '12205', '2940058', '千葉県', 'チバケン', '館山市', 'タテヤマシ', '小原', 'コバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県館山市布沼', '12', '12205', '2940221', '千葉県', 'チバケン', '館山市', 'タテヤマシ', '布沼', 'メヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県館山市茂名', '12', '12205', '2940222', '千葉県', 'チバケン', '館山市', 'タテヤマシ', '茂名', 'モナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県館山市洲宮', '12', '12205', '2940223', '千葉県', 'チバケン', '館山市', 'タテヤマシ', '洲宮', 'スノミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県館山市藤原', '12', '12205', '2940224', '千葉県', 'チバケン', '館山市', 'タテヤマシ', '藤原', 'フジワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県館山市佐野', '12', '12205', '2940225', '千葉県', 'チバケン', '館山市', 'タテヤマシ', '佐野', 'サノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県館山市犬石', '12', '12205', '2940226', '千葉県', 'チバケン', '館山市', 'タテヤマシ', '犬石', 'イヌイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県館山市中里', '12', '12205', '2940231', '千葉県', 'チバケン', '館山市', 'タテヤマシ', '中里', 'ナカザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県館山市竜岡', '12', '12205', '2940232', '千葉県', 'チバケン', '館山市', 'タテヤマシ', '竜岡', 'リュウオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県館山市大神宮', '12', '12205', '2940233', '千葉県', 'チバケン', '館山市', 'タテヤマシ', '大神宮', 'ダイジングウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県館山市布良', '12', '12205', '2940234', '千葉県', 'チバケン', '館山市', 'タテヤマシ', '布良', 'メラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県館山市相浜', '12', '12205', '2940235', '千葉県', 'チバケン', '館山市', 'タテヤマシ', '相浜', 'アイハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県館山市香', '12', '12205', '2940301', '千葉県', 'チバケン', '館山市', 'タテヤマシ', '香', 'コウヤツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県館山市塩見', '12', '12205', '2940302', '千葉県', 'チバケン', '館山市', 'タテヤマシ', '塩見', 'シオミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県館山市浜田', '12', '12205', '2940303', '千葉県', 'チバケン', '館山市', 'タテヤマシ', '浜田', 'ハマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県館山市早物', '12', '12205', '2940304', '千葉県', 'チバケン', '館山市', 'タテヤマシ', '早物', 'ハヤブツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県館山市見物', '12', '12205', '2940305', '千葉県', 'チバケン', '館山市', 'タテヤマシ', '見物', 'ケンブツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県館山市加賀名', '12', '12205', '2940306', '千葉県', 'チバケン', '館山市', 'タテヤマシ', '加賀名', 'カガナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県館山市波左間', '12', '12205', '2940307', '千葉県', 'チバケン', '館山市', 'タテヤマシ', '波左間', 'ハサマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県館山市坂田', '12', '12205', '2940308', '千葉県', 'チバケン', '館山市', 'タテヤマシ', '坂田', 'バンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県館山市坂井', '12', '12205', '2940311', '千葉県', 'チバケン', '館山市', 'タテヤマシ', '坂井', 'サカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県館山市小沼', '12', '12205', '2940312', '千葉県', 'チバケン', '館山市', 'タテヤマシ', '小沼', 'コヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県館山市坂足', '12', '12205', '2940313', '千葉県', 'チバケン', '館山市', 'タテヤマシ', '坂足', 'サカダル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県館山市伊戸', '12', '12205', '2940314', '千葉県', 'チバケン', '館山市', 'タテヤマシ', '伊戸', 'イト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県館山市西川名', '12', '12205', '2940315', '千葉県', 'チバケン', '館山市', 'タテヤマシ', '西川名', 'ニシカワナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県館山市洲崎', '12', '12205', '2940316', '千葉県', 'チバケン', '館山市', 'タテヤマシ', '洲崎', 'スノサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市増間', '12', '12234', '2940801', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '増間', 'マスマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市山名', '12', '12234', '2940802', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '山名', 'ヤマナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市御庄', '12', '12234', '2940803', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '御庄', 'ミショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市海老敷', '12', '12234', '2940804', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '海老敷', 'エビシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市下滝田', '12', '12234', '2940805', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '下滝田', 'シモタキダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市上滝田', '12', '12234', '2940806', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '上滝田', 'カミタキダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市中', '12', '12234', '2940811', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '中', 'ナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市池之内', '12', '12234', '2940812', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '池之内', 'イケノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市谷向', '12', '12234', '2940813', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '谷向', 'ヤムカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市川田', '12', '12234', '2940814', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '川田', 'カワタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市千代', '12', '12234', '2940815', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '千代', 'センダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市山下', '12', '12234', '2940816', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '山下', 'ヤマシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市大学口', '12', '12234', '2940817', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '大学口', 'オオガクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市明石', '12', '12234', '2940821', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '明石', 'アカシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市本織', '12', '12234', '2940822', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '本織', 'モトオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市府中', '12', '12234', '2940823', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '府中', 'フチュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市下堀', '12', '12234', '2940824', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '下堀', 'シモホリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市上堀', '12', '12234', '2940825', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '上堀', 'カミホリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市三坂', '12', '12234', '2940826', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '三坂', 'ミサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県西磐井郡平泉町', '03', '03402', '0294100', '岩手県', 'イワテケン', '西磐井郡平泉町', 'ニシイワイグンヒライズミチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('18888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県西磐井郡平泉町長島', '03', '03402', '0294101', '岩手県', 'イワテケン', '西磐井郡平泉町', 'ニシイワイグンヒライズミチョウ', '長島', 'ナガシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県西磐井郡平泉町平泉', '03', '03402', '0294102', '岩手県', 'イワテケン', '西磐井郡平泉町', 'ニシイワイグンヒライズミチョウ', '平泉', 'ヒライズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区阿部舘', '03', '03215', '0294201', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区阿部舘', 'マエサワクアベタテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区久田', '03', '03215', '0294201', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区久田', 'マエサワクキュウデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区源氏ケ崎', '03', '03215', '0294201', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区源氏ケ崎', 'マエサワクゲンジガサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区古城', '03', '03215', '0294201', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区古城', 'マエサワクコジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区白山', '03', '03215', '0294202', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区白山', 'マエサワクシラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区北久保', '03', '03215', '0294203', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区北久保', 'マエサワクキタクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区狐堂', '03', '03215', '0294203', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区狐堂', 'マエサワクキツネドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区生母', '03', '03215', '0294203', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区生母', 'マエサワクセイボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区下谷起', '03', '03215', '0294204', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区下谷起', 'マエサワクシタヤギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区島', '03', '03215', '0294204', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区島', 'マエサワクシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区宿', '03', '03215', '0294204', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区宿', 'マエサワクシュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区高畑', '03', '03215', '0294204', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区高畑', 'マエサワクタカハタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区田中', '03', '03215', '0294204', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区田中', 'マエサワクタナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区道場', '03', '03215', '0294204', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区道場', 'マエサワクドウバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区鳥待小屋', '03', '03215', '0294204', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区鳥待小屋', 'マエサワクトリマチゴヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区中久保', '03', '03215', '0294204', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区中久保', 'マエサワクナカクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区長檀', '03', '03215', '0294204', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区長檀', 'マエサワクナガダン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区中村', '03', '03215', '0294204', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区中村', 'マエサワクナカムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区古川', '03', '03215', '0294204', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区古川', 'マエサワクフルカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区南前沢', '03', '03215', '0294204', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区南前沢', 'マエサワクミナミマエサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区向田', '03', '03215', '0294204', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区向田', 'マエサワクムカイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区本杉', '03', '03215', '0294204', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区本杉', 'マエサワクモトスギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区谷地', '03', '03215', '0294204', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区谷地', 'マエサワクヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区八幡', '03', '03215', '0294204', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区八幡', 'マエサワクヤワタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区八幡前', '03', '03215', '0294204', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区八幡前', 'マエサワクヤワタマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区合ノ沢', '03', '03215', '0294205', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区合ノ沢', 'マエサワクアイノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区安寺沢', '03', '03215', '0294205', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区安寺沢', 'マエサワクアテラサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区石田', '03', '03215', '0294205', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区石田', 'マエサワクイシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区一ノ沢', '03', '03215', '0294205', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区一ノ沢', 'マエサワクイチノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区鵜ノ木', '03', '03215', '0294205', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区鵜ノ木', 'マエサワクウノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区鵜ノ木田', '03', '03215', '0294205', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区鵜ノ木田', 'マエサワクウノキダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区うるし野', '03', '03215', '0294205', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区うるし野', 'マエサワクウルシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区大袋', '03', '03215', '0294205', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区大袋', 'マエサワクオオブクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区沖田', '03', '03215', '0294205', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区沖田', 'マエサワクオキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区小沢口', '03', '03215', '0294205', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区小沢口', 'マエサワクオサワグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区川内', '03', '03215', '0294205', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区川内', 'マエサワクカワウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区衣関', '03', '03215', '0294205', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区衣関', 'マエサワクキヌトメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区里', '03', '03215', '0294205', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区里', 'マエサワクサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区清水', '03', '03215', '0294205', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区清水', 'マエサワクシミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区蛇ノ鼻', '03', '03215', '0294205', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区蛇ノ鼻', 'マエサワクジャノハナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区白鳥舘', '03', '03215', '0294205', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区白鳥舘', 'マエサワクシロトリダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区新城', '03', '03215', '0294205', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区新城', 'マエサワクシンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区堤田', '03', '03215', '0294205', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区堤田', 'マエサワクツツミダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区照井舘', '03', '03215', '0294205', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区照井舘', 'マエサワクテルイダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区徳沢', '03', '03215', '0294205', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区徳沢', 'マエサワクトクサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区永沢', '03', '03215', '0294205', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区永沢', 'マエサワクナガサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区長根', '03', '03215', '0294205', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区長根', 'マエサワクナガネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区中屋敷', '03', '03215', '0294205', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区中屋敷', 'マエサワクナカヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区浪洗', '03', '03215', '0294205', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区浪洗', 'マエサワクナミアライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区二ノ沢', '03', '03215', '0294205', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区二ノ沢', 'マエサワクニノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区沼尻', '03', '03215', '0294205', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区沼尻', 'マエサワクヌマジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区沼ノ沢', '03', '03215', '0294205', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区沼ノ沢', 'マエサワクヌマノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区日向', '03', '03215', '0294205', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区日向', 'マエサワクヒナタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区福養', '03', '03215', '0294205', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区福養', 'マエサワクフクヨウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区干場', '03', '03215', '0294205', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区干場', 'マエサワクホシバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区前野', '03', '03215', '0294205', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区前野', 'マエサワクマエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区南陣場', '03', '03215', '0294205', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区南陣場', 'マエサワクミナミジンバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区南塔ヶ崎', '03', '03215', '0294205', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区南塔ヶ崎', 'マエサワクミナミトウガサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区南中島', '03', '03215', '0294205', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区南中島', 'マエサワクミナミナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区箕輪', '03', '03215', '0294205', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区箕輪', 'マエサワクミノワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区両手沢', '03', '03215', '0294205', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区両手沢', 'マエサワクモロテザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区谷記', '03', '03215', '0294205', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区谷記', 'マエサワクヤギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区谷起', '03', '03215', '0294205', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区谷起', 'マエサワクヤギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区谷記田', '03', '03215', '0294205', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区谷記田', 'マエサワクヤギタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区谷起田', '03', '03215', '0294205', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区谷起田', 'マエサワクヤギタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区櫓前', '03', '03215', '0294205', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区櫓前', 'マエサワクヤグラマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区六本松', '03', '03215', '0294205', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区六本松', 'マエサワクロッポンマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区赤坂', '03', '03215', '0294206', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区赤坂', 'マエサワクアカサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区裏新田', '03', '03215', '0294206', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区裏新田', 'マエサワクウラシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区狐石', '03', '03215', '0294206', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区狐石', 'マエサワクキツネイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区駒水', '03', '03215', '0294206', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区駒水', 'マエサワクコマスイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区陣場', '03', '03215', '0294206', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区陣場', 'マエサワクジンバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区太郎ケ沢', '03', '03215', '0294206', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区太郎ケ沢', 'マエサワクタロウガサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区日除松', '03', '03215', '0294206', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区日除松', 'マエサワクヒヨケマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区簾森', '03', '03215', '0294206', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区簾森', 'マエサワクミスモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区養ケ森', '03', '03215', '0294206', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区養ケ森', 'マエサワクヨウガモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区赤面', '03', '03215', '0294207', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区赤面', 'マエサワクアカツラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区一本杉', '03', '03215', '0294207', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区一本杉', 'マエサワクイッポンスギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区大桜', '03', '03215', '0294207', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区大桜', 'マエサワクオオザクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区五十人町', '03', '03215', '0294207', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区五十人町', 'マエサワクゴジュウニンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区下小路', '03', '03215', '0294207', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区下小路', 'マエサワクシモコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区平小路', '03', '03215', '0294207', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区平小路', 'マエサワクタイラコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区平前', '03', '03215', '0294207', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区平前', 'マエサワクタイラマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区塔ケ崎', '03', '03215', '0294207', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区塔ケ崎', 'マエサワクトウガサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区泊ケ崎', '03', '03215', '0294207', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区泊ケ崎', 'マエサワクトマリガサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区三日町', '03', '03215', '0294207', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区三日町', 'マエサワクミッカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区三日町浦', '03', '03215', '0294207', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区三日町浦', 'マエサワクミッカマチウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区三日町新裏', '03', '03215', '0294207', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区三日町新裏', 'マエサワクミッカマチシンウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区屋敷', '03', '03215', '0294207', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区屋敷', 'マエサワクヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区粟ケ島', '03', '03215', '0294208', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区粟ケ島', 'マエサワクアワガシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区河ノ畑', '03', '03215', '0294208', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区河ノ畑', 'マエサワクカノハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区株樹', '03', '03215', '0294208', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区株樹', 'マエサワクカブキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区五合田', '03', '03215', '0294208', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区五合田', 'マエサワクゴゴウタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区新町', '03', '03215', '0294208', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区新町', 'マエサワクシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区新町裏', '03', '03215', '0294208', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区新町裏', 'マエサワクシンマチウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区大林寺下', '03', '03215', '0294208', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区大林寺下', 'マエサワクダイリンジシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区竹沢', '03', '03215', '0294208', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区竹沢', 'マエサワクタケザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区立石', '03', '03215', '0294208', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区立石', 'マエサワクタテイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区田畠', '03', '03215', '0294208', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区田畠', 'マエサワクタバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区中田', '03', '03215', '0294208', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区中田', 'マエサワクナカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区七日町', '03', '03215', '0294208', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区七日町', 'マエサワクナノカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区七日町裏', '03', '03215', '0294208', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区七日町裏', 'マエサワクナノカマチウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区二十人町', '03', '03215', '0294208', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区二十人町', 'マエサワクニジュウニンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区二十人町裏', '03', '03215', '0294208', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区二十人町裏', 'マエサワクニジュウニンマチウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区山下', '03', '03215', '0294208', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区山下', 'マエサワクヤマシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('18998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市前沢区駅東', '03', '03215', '0294211', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '前沢区駅東', 'マエサワクエキヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区衣原', '03', '03215', '0294303', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区衣原', 'コロモガワクキヌハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区外の沢', '03', '03215', '0294304', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区外の沢', 'コロモガワクソトノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区長袋', '03', '03215', '0294305', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区長袋', 'コロモガワクナガフクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区小田', '03', '03215', '0294306', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区小田', 'コロモガワクコダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区有浦', '03', '03215', '0294307', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区有浦', 'コロモガワクアリウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区大平', '03', '03215', '0294308', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区大平', 'コロモガワクオオダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区古館', '03', '03215', '0294311', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区古館', 'コロモガワクフルダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区西窪', '03', '03215', '0294312', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区西窪', 'コロモガワクニシクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区石生', '03', '03215', '0294313', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区石生', 'コロモガワクイシュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区中屋敷', '03', '03215', '0294314', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区中屋敷', 'コロモガワクナカヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区天田', '03', '03215', '0294315', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区天田', 'コロモガワクアマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区苗代沢', '03', '03215', '0294316', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区苗代沢', 'コロモガワクナワシロサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区桑畑', '03', '03215', '0294317', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区桑畑', 'コロモガワククワハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区雲南田', '03', '03215', '0294321', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区雲南田', 'コロモガワクウンナンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区板倉', '03', '03215', '0294322', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区板倉', 'コロモガワクイタクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区小安代', '03', '03215', '0294323', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区小安代', 'コロモガワクコアンシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区正板', '03', '03215', '0294324', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区正板', 'コロモガワクマサイタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区小正板', '03', '03215', '0294325', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区小正板', 'コロモガワクコマサイタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区懸田', '03', '03215', '0294326', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区懸田', 'コロモガワクカケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区馬懸', '03', '03215', '0294327', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区馬懸', 'コロモガワクマガケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区下寺田', '03', '03215', '0294328', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区下寺田', 'コロモガワクシモテラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区上寺田', '03', '03215', '0294329', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区上寺田', 'コロモガワクカミテラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区深沢', '03', '03215', '0294331', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区深沢', 'コロモガワクフカサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区古戸', '03', '03215', '0294332', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区古戸', 'コロモガワクフルド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区駒場', '03', '03215', '0294333', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区駒場', 'コロモガワクコマバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区百ケ袋', '03', '03215', '0294334', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区百ケ袋', 'コロモガワクモガフクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区六道', '03', '03215', '0294341', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区六道', 'コロモガワクロクドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区高保呂', '03', '03215', '0294342', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区高保呂', 'コロモガワクタカホロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区能登屋敷', '03', '03215', '0294343', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区能登屋敷', 'コロモガワクノトヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区沢田', '03', '03215', '0294344', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区沢田', 'コロモガワクサワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区館城', '03', '03215', '0294345', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区館城', 'コロモガワクタテシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区豊巻', '03', '03215', '0294346', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区豊巻', 'コロモガワクトヨマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区大西', '03', '03215', '0294347', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区大西', 'コロモガワクオオニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区杉野', '03', '03215', '0294348', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区杉野', 'コロモガワクスギノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区夏秋', '03', '03215', '0294351', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区夏秋', 'コロモガワクナツアキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区岩の上', '03', '03215', '0294352', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区岩の上', 'コロモガワクイワノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区旧殿', '03', '03215', '0294353', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区旧殿', 'コロモガワクキュウデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区除', '03', '03215', '0294354', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区除', 'コロモガワクノゾキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区山岸', '03', '03215', '0294355', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区山岸', 'コロモガワクヤマギシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区長嚢', '03', '03215', '0294361', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区長嚢', 'コロモガワクナガフクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区小林山', '03', '03215', '0294362', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区小林山', 'コロモガワクコバヤシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区夏梨', '03', '03215', '0294363', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区夏梨', 'コロモガワクナツナシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区西風山', '03', '03215', '0294364', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区西風山', 'コロモガワクナレヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区天土', '03', '03215', '0294365', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区天土', 'コロモガワクアマツチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区桧山沢', '03', '03215', '0294371', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区桧山沢', 'コロモガワクヒヤマサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区松林', '03', '03215', '0294372', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区松林', 'コロモガワクマツバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区山田', '03', '03215', '0294373', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区山田', 'コロモガワクヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区桧山沢山', '03', '03215', '0294374', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区桧山沢山', 'コロモガワクヒヤマサワヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区鞍掛', '03', '03215', '0294375', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区鞍掛', 'コロモガワククラカケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区本巻', '03', '03215', '0294376', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区本巻', 'コロモガワクモトマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区後山', '03', '03215', '0294377', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区後山', 'コロモガワクウシロヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区菖蒲平', '03', '03215', '0294378', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区菖蒲平', 'コロモガワクショウブダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区石ケ沢', '03', '03215', '0294381', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区石ケ沢', 'コロモガワクイシガサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区関袋', '03', '03215', '0294382', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区関袋', 'コロモガワクセキブクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区沖の野', '03', '03215', '0294383', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区沖の野', 'コロモガワクオキノノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区石神', '03', '03215', '0294384', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区石神', 'コロモガワクイシガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区富沢', '03', '03215', '0294385', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区富沢', 'コロモガワクトミサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区女石', '03', '03215', '0294386', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区女石', 'コロモガワクオンナイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区下大森', '03', '03215', '0294387', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区下大森', 'コロモガワクシモオオモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区上大森', '03', '03215', '0294388', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区上大森', 'コロモガワクカミオオモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区長板沢', '03', '03215', '0294389', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区長板沢', 'コロモガワクナガイタサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区張山', '03', '03215', '0294401', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区張山', 'コロモガワクハリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区星屋', '03', '03215', '0294402', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区星屋', 'コロモガワクホシヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区本田原', '03', '03215', '0294403', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区本田原', 'コロモガワクホンダワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区寺袋', '03', '03215', '0294404', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区寺袋', 'コロモガワクテラブクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区桑木谷地', '03', '03215', '0294405', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区桑木谷地', 'コロモガワククワノキヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区大坂', '03', '03215', '0294406', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区大坂', 'コロモガワクオオザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区金成', '03', '03215', '0294407', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区金成', 'コロモガワクカンナリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区土屋', '03', '03215', '0294408', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区土屋', 'コロモガワクツチヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区上小路', '03', '03215', '0294411', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区上小路', 'コロモガワクカミコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区富田', '03', '03215', '0294412', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区富田', 'コロモガワクトミタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区堰下', '03', '03215', '0294413', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区堰下', 'コロモガワクセキシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区野田', '03', '03215', '0294414', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区野田', 'コロモガワクノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区向館谷起', '03', '03215', '0294415', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区向館谷起', 'コロモガワクムカイダテヤギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区向館', '03', '03215', '0294416', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区向館', 'コロモガワクムカイダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区富田前', '03', '03215', '0294417', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区富田前', 'コロモガワクトミタマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区杉林', '03', '03215', '0294418', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区杉林', 'コロモガワクスギバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区大面', '03', '03215', '0294419', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区大面', 'コロモガワクオオツラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区日向', '03', '03215', '0294421', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区日向', 'コロモガワクヒナタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区瀬原', '03', '03215', '0294422', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区瀬原', 'コロモガワクセワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区瀬原西浦', '03', '03215', '0294423', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区瀬原西浦', 'コロモガワクセワラニシウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区九輪堂', '03', '03215', '0294424', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区九輪堂', 'コロモガワククリンドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区采女沢', '03', '03215', '0294425', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区采女沢', 'コロモガワクウネメザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区愛宕下', '03', '03215', '0294426', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区愛宕下', 'コロモガワクアタゴシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区陣場下', '03', '03215', '0294427', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区陣場下', 'コロモガワクジンバシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区田中', '03', '03215', '0294431', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区田中', 'コロモガワクタナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区小林', '03', '03215', '0294432', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区小林', 'コロモガワクコバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区池田西', '03', '03215', '0294433', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区池田西', 'コロモガワクイケダニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区池田', '03', '03215', '0294434', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区池田', 'コロモガワクイケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区押切', '03', '03215', '0294435', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区押切', 'コロモガワクオシキリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区大石ケ沢', '03', '03215', '0294436', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区大石ケ沢', 'コロモガワクオオイシガサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区唐金', '03', '03215', '0294437', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区唐金', 'コロモガワクカラカネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区室の木', '03', '03215', '0294438', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区室の木', 'コロモガワクムロノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区田中西', '03', '03215', '0294439', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区田中西', 'コロモガワクタナカニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区並木前', '03', '03215', '0294441', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区並木前', 'コロモガワクナミキマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区上野', '03', '03215', '0294442', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区上野', 'コロモガワクウワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区六日市場', '03', '03215', '0294443', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区六日市場', 'コロモガワクムイカイチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区清水の上', '03', '03215', '0294444', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区清水の上', 'コロモガワクシミズノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区七日市場', '03', '03215', '0294445', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区七日市場', 'コロモガワクナノカイチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区川端', '03', '03215', '0294446', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区川端', 'コロモガワクカワハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区東裏', '03', '03215', '0294451', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区東裏', 'コロモガワクヒガシウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区月山', '03', '03215', '0294452', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区月山', 'コロモガワクガッサン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区山口', '03', '03215', '0294453', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区山口', 'コロモガワクヤマグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区表', '03', '03215', '0294454', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区表', 'コロモガワクオモテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区横道下', '03', '03215', '0294455', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区横道下', 'コロモガワクヨコミチシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区西裏', '03', '03215', '0294456', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区西裏', 'コロモガワクニシウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区平', '03', '03215', '0294461', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区平', 'コロモガワクヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区八千', '03', '03215', '0294462', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区八千', 'コロモガワクハッセン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区葭ケ沢', '03', '03215', '0294463', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区葭ケ沢', 'コロモガワクヨシガサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区前滝の沢', '03', '03215', '0294464', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区前滝の沢', 'コロモガワクマエタキノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区後滝の沢', '03', '03215', '0294465', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区後滝の沢', 'コロモガワクウシロタキノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区下河内', '03', '03215', '0294471', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区下河内', 'コロモガワクシモカワウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区中河内', '03', '03215', '0294472', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区中河内', 'コロモガワクナカカワウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区向', '03', '03215', '0294473', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区向', 'コロモガワクムカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区上河内', '03', '03215', '0294474', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区上河内', 'コロモガワクカミカワウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区中山', '03', '03215', '0294475', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区中山', 'コロモガワクナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区畦畑山', '03', '03215', '0294481', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区畦畑山', 'コロモガワクウネハタヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区畦畑', '03', '03215', '0294482', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区畦畑', 'コロモガワクウネハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区沼野', '03', '03215', '0294483', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区沼野', 'コロモガワクヌマノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区噌味', '03', '03215', '0294484', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区噌味', 'コロモガワクソウミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区宝塔谷地', '03', '03215', '0294485', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区宝塔谷地', 'コロモガワクホウトウヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区鷹の巣', '03', '03215', '0294486', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区鷹の巣', 'コロモガワクタカノス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区大原山', '03', '03215', '0294487', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区大原山', 'コロモガワクオオハラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区大原', '03', '03215', '0294488', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区大原', 'コロモガワクオオハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区上立沢', '03', '03215', '0294491', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区上立沢', 'コロモガワクカミタチサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区下立沢', '03', '03215', '0294492', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区下立沢', 'コロモガワクシモタチサワ', null, null, null, null), ('19127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区野崎', '03', '03215', '0294493', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区野崎', 'コロモガワクノザキ', null, null, null, null), ('19128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区楢原山', '03', '03215', '0294494', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区楢原山', 'コロモガワクナラハラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区楢原', '03', '03215', '0294495', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区楢原', 'コロモガワクナラハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区真打', '03', '03215', '0294496', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区真打', 'コロモガワクマウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県奥州市衣川区餅転', '03', '03215', '0294497', '岩手県', 'イワテケン', '奥州市', 'オウシュウシ', '衣川区餅転', 'コロモガワクモチコロバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県胆沢郡金ケ崎町', '03', '03381', '0294500', '岩手県', 'イワテケン', '胆沢郡金ケ崎町', 'イサワグンカネガサキチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('19133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県胆沢郡金ケ崎町六原', '03', '03381', '0294501', '岩手県', 'イワテケン', '胆沢郡金ケ崎町', 'イサワグンカネガサキチョウ', '六原', 'ロクハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県胆沢郡金ケ崎町三ケ尻', '03', '03381', '0294502', '岩手県', 'イワテケン', '胆沢郡金ケ崎町', 'イサワグンカネガサキチョウ', '三ケ尻', 'ミカジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県胆沢郡金ケ崎町西根', '03', '03381', '0294503', '岩手県', 'イワテケン', '胆沢郡金ケ崎町', 'イサワグンカネガサキチョウ', '西根', 'ニシネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県胆沢郡金ケ崎町永沢', '03', '03381', '0294504', '岩手県', 'イワテケン', '胆沢郡金ケ崎町', 'イサワグンカネガサキチョウ', '永沢', 'ナガサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県胆沢郡金ケ崎町永栄', '03', '03381', '0294505', '岩手県', 'イワテケン', '胆沢郡金ケ崎町', 'イサワグンカネガサキチョウ', '永栄', 'ナガサカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市千倉町久保', '12', '12234', '2950001', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '千倉町久保', 'チクラチョウクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市千倉町川合', '12', '12234', '2950002', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '千倉町川合', 'チクラチョウカワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市千倉町白子', '12', '12234', '2950003', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '千倉町白子', 'チクラチョウシラコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市千倉町瀬戸', '12', '12234', '2950004', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '千倉町瀬戸', 'チクラチョウセト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市千倉町牧田', '12', '12234', '2950005', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '千倉町牧田', 'チクラチョウマキダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市千倉町宇田', '12', '12234', '2950006', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '千倉町宇田', 'チクラチョウウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市千倉町北朝夷', '12', '12234', '2950011', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '千倉町北朝夷', 'チクラチョウキタアサイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市千倉町南朝夷', '12', '12234', '2950012', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '千倉町南朝夷', 'チクラチョウミナミアサイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市千倉町大貫', '12', '12234', '2950013', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '千倉町大貫', 'チクラチョウオオヌキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市千倉町川戸', '12', '12234', '2950014', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '千倉町川戸', 'チクラチョウカワト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市千倉町平舘', '12', '12234', '2950021', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '千倉町平舘', 'チクラチョウヘダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市千倉町忽戸', '12', '12234', '2950022', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '千倉町忽戸', 'チクラチョウコット', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市千倉町川口', '12', '12234', '2950023', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '千倉町川口', 'チクラチョウカワグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市千倉町平磯', '12', '12234', '2950024', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '千倉町平磯', 'チクラチョウヒライソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市千倉町千田', '12', '12234', '2950025', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '千倉町千田', 'チクラチョウセンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市千倉町大川', '12', '12234', '2950026', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '千倉町大川', 'チクラチョウオオカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市千倉町白間津', '12', '12234', '2950027', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '千倉町白間津', 'チクラチョウシラマヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市白浜町乙浜', '12', '12234', '2950101', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '白浜町乙浜', 'シラハマチョウオトハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市白浜町白浜', '12', '12234', '2950102', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '白浜町白浜', 'シラハマチョウシラハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市白浜町滝口', '12', '12234', '2950103', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '白浜町滝口', 'シラハマチョウタキグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市白浜町根本', '12', '12234', '2950104', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '白浜町根本', 'シラハマチョウネモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県和賀郡西和賀町', '03', '03366', '0295500', '岩手県', 'イワテケン', '和賀郡西和賀町', 'ワガグンニシワガマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('19168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県和賀郡西和賀町左草1地割', '03', '03366', '0295501', '岩手県', 'イワテケン', '和賀郡西和賀町', 'ワガグンニシワガマチ', '左草', 'サソウ', null, null, '1地割', '01チワリ');
INSERT INTO `ms_addresses` VALUES ('19169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県和賀郡西和賀町左草2地割', '03', '03366', '0295501', '岩手県', 'イワテケン', '和賀郡西和賀町', 'ワガグンニシワガマチ', '左草', 'サソウ', null, null, '2地割', '02チワリ');
INSERT INTO `ms_addresses` VALUES ('19170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県和賀郡西和賀町左草3地割', '03', '03366', '0295501', '岩手県', 'イワテケン', '和賀郡西和賀町', 'ワガグンニシワガマチ', '左草', 'サソウ', null, null, '3地割', '03チワリ');
INSERT INTO `ms_addresses` VALUES ('19171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県和賀郡西和賀町左草4地割', '03', '03366', '0295501', '岩手県', 'イワテケン', '和賀郡西和賀町', 'ワガグンニシワガマチ', '左草', 'サソウ', null, null, '4地割', '04チワリ');
INSERT INTO `ms_addresses` VALUES ('19172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県和賀郡西和賀町左草5地割', '03', '03366', '0295501', '岩手県', 'イワテケン', '和賀郡西和賀町', 'ワガグンニシワガマチ', '左草', 'サソウ', null, null, '5地割', '05チワリ');
INSERT INTO `ms_addresses` VALUES ('19173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県和賀郡西和賀町左草6地割', '03', '03366', '0295501', '岩手県', 'イワテケン', '和賀郡西和賀町', 'ワガグンニシワガマチ', '左草', 'サソウ', null, null, '6地割', '06チワリ');
INSERT INTO `ms_addresses` VALUES ('19174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県和賀郡西和賀町下左草77地割', '03', '03366', '0295501', '岩手県', 'イワテケン', '和賀郡西和賀町', 'ワガグンニシワガマチ', '下左草', 'シモサソウ', null, null, '77地割', '77チワリ');
INSERT INTO `ms_addresses` VALUES ('19175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県和賀郡西和賀町下左草78地割', '03', '03366', '0295501', '岩手県', 'イワテケン', '和賀郡西和賀町', 'ワガグンニシワガマチ', '下左草', 'シモサソウ', null, null, '78地割', '78チワリ');
INSERT INTO `ms_addresses` VALUES ('19176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県和賀郡西和賀町下左草79地割', '03', '03366', '0295501', '岩手県', 'イワテケン', '和賀郡西和賀町', 'ワガグンニシワガマチ', '下左草', 'シモサソウ', null, null, '79地割', '79チワリ');
INSERT INTO `ms_addresses` VALUES ('19177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県和賀郡西和賀町下左草80地割', '03', '03366', '0295501', '岩手県', 'イワテケン', '和賀郡西和賀町', 'ワガグンニシワガマチ', '下左草', 'シモサソウ', null, null, '80地割', '80チワリ');
INSERT INTO `ms_addresses` VALUES ('19178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県和賀郡西和賀町樺沢16地割', '03', '03366', '0295502', '岩手県', 'イワテケン', '和賀郡西和賀町', 'ワガグンニシワガマチ', '樺沢', 'カバサワ', null, null, '16地割', '16チワリ');
INSERT INTO `ms_addresses` VALUES ('19179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県和賀郡西和賀町樺沢17地割', '03', '03366', '0295502', '岩手県', 'イワテケン', '和賀郡西和賀町', 'ワガグンニシワガマチ', '樺沢', 'カバサワ', null, null, '17地割', '17チワリ');
INSERT INTO `ms_addresses` VALUES ('19180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県和賀郡西和賀町下前7地割', '03', '03366', '0295502', '岩手県', 'イワテケン', '和賀郡西和賀町', 'ワガグンニシワガマチ', '下前', 'シタマエ', null, null, '7地割', '07チワリ');
INSERT INTO `ms_addresses` VALUES ('19181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県和賀郡西和賀町下前8地割', '03', '03366', '0295502', '岩手県', 'イワテケン', '和賀郡西和賀町', 'ワガグンニシワガマチ', '下前', 'シタマエ', null, null, '8地割', '08チワリ');
INSERT INTO `ms_addresses` VALUES ('19182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県和賀郡西和賀町下前9地割', '03', '03366', '0295502', '岩手県', 'イワテケン', '和賀郡西和賀町', 'ワガグンニシワガマチ', '下前', 'シタマエ', null, null, '9地割', '09チワリ');
INSERT INTO `ms_addresses` VALUES ('19183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県和賀郡西和賀町下前10地割', '03', '03366', '0295502', '岩手県', 'イワテケン', '和賀郡西和賀町', 'ワガグンニシワガマチ', '下前', 'シタマエ', null, null, '10地割', '10チワリ');
INSERT INTO `ms_addresses` VALUES ('19184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県和賀郡西和賀町下前11地割', '03', '03366', '0295502', '岩手県', 'イワテケン', '和賀郡西和賀町', 'ワガグンニシワガマチ', '下前', 'シタマエ', null, null, '11地割', '11チワリ');
INSERT INTO `ms_addresses` VALUES ('19185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県和賀郡西和賀町下前12地割', '03', '03366', '0295502', '岩手県', 'イワテケン', '和賀郡西和賀町', 'ワガグンニシワガマチ', '下前', 'シタマエ', null, null, '12地割', '12チワリ');
INSERT INTO `ms_addresses` VALUES ('19186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県和賀郡西和賀町下前13地割', '03', '03366', '0295502', '岩手県', 'イワテケン', '和賀郡西和賀町', 'ワガグンニシワガマチ', '下前', 'シタマエ', null, null, '13地割', '13チワリ');
INSERT INTO `ms_addresses` VALUES ('19187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県和賀郡西和賀町下前14地割', '03', '03366', '0295502', '岩手県', 'イワテケン', '和賀郡西和賀町', 'ワガグンニシワガマチ', '下前', 'シタマエ', null, null, '14地割', '14チワリ');
INSERT INTO `ms_addresses` VALUES ('19188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県和賀郡西和賀町寅沢15地割', '03', '03366', '0295502', '岩手県', 'イワテケン', '和賀郡西和賀町', 'ワガグンニシワガマチ', '寅沢', 'トラサワ', null, null, '15地割', '15チワリ');
INSERT INTO `ms_addresses` VALUES ('19189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県和賀郡西和賀町穴明22地割', '03', '03366', '0295503', '岩手県', 'イワテケン', '和賀郡西和賀町', 'ワガグンニシワガマチ', '穴明', 'アナアケ', null, null, '22地割', '22チワリ');
INSERT INTO `ms_addresses` VALUES ('19190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県和賀郡西和賀町穴明23地割', '03', '03366', '0295503', '岩手県', 'イワテケン', '和賀郡西和賀町', 'ワガグンニシワガマチ', '穴明', 'アナアケ', null, null, '23地割', '23チワリ');
INSERT INTO `ms_addresses` VALUES ('19191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県和賀郡西和賀町清水ケ野18地割', '03', '03366', '0295503', '岩手県', 'イワテケン', '和賀郡西和賀町', 'ワガグンニシワガマチ', '清水ケ野', 'シミズガノ', null, null, '18地割', '18チワリ');
INSERT INTO `ms_addresses` VALUES ('19192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県和賀郡西和賀町間木野24地割', '03', '03366', '0295503', '岩手県', 'イワテケン', '和賀郡西和賀町', 'ワガグンニシワガマチ', '間木野', 'マギノ', null, null, '24地割', '24チワリ');
INSERT INTO `ms_addresses` VALUES ('19193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県和賀郡西和賀町湯田19地割', '03', '03366', '0295503', '岩手県', 'イワテケン', '和賀郡西和賀町', 'ワガグンニシワガマチ', '湯田', 'ユダ', null, null, '19地割', '19チワリ');
INSERT INTO `ms_addresses` VALUES ('19194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県和賀郡西和賀町湯田20地割', '03', '03366', '0295503', '岩手県', 'イワテケン', '和賀郡西和賀町', 'ワガグンニシワガマチ', '湯田', 'ユダ', null, null, '20地割', '20チワリ');
INSERT INTO `ms_addresses` VALUES ('19195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県和賀郡西和賀町湯田21地割', '03', '03366', '0295503', '岩手県', 'イワテケン', '和賀郡西和賀町', 'ワガグンニシワガマチ', '湯田', 'ユダ', null, null, '21地割', '21チワリ');
INSERT INTO `ms_addresses` VALUES ('19196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県和賀郡西和賀町槻沢25地割', '03', '03366', '0295504', '岩手県', 'イワテケン', '和賀郡西和賀町', 'ワガグンニシワガマチ', '槻沢', 'ツキザワ', null, null, '25地割', '25チワリ');
INSERT INTO `ms_addresses` VALUES ('19197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県和賀郡西和賀町槻沢26地割', '03', '03366', '0295504', '岩手県', 'イワテケン', '和賀郡西和賀町', 'ワガグンニシワガマチ', '槻沢', 'ツキザワ', null, null, '26地割', '26チワリ');
INSERT INTO `ms_addresses` VALUES ('19198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県和賀郡西和賀町槻沢27地割', '03', '03366', '0295504', '岩手県', 'イワテケン', '和賀郡西和賀町', 'ワガグンニシワガマチ', '槻沢', 'ツキザワ', null, null, '27地割', '27チワリ');
INSERT INTO `ms_addresses` VALUES ('19199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県和賀郡西和賀町槻沢28地割', '03', '03366', '0295504', '岩手県', 'イワテケン', '和賀郡西和賀町', 'ワガグンニシワガマチ', '槻沢', 'ツキザワ', null, null, '28地割', '28チワリ');
INSERT INTO `ms_addresses` VALUES ('19200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県和賀郡西和賀町湯本29地割', '03', '03366', '0295505', '岩手県', 'イワテケン', '和賀郡西和賀町', 'ワガグンニシワガマチ', '湯本', 'ユモト', null, null, '29地割', '29チワリ');
INSERT INTO `ms_addresses` VALUES ('19201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県和賀郡西和賀町湯本30地割', '03', '03366', '0295505', '岩手県', 'イワテケン', '和賀郡西和賀町', 'ワガグンニシワガマチ', '湯本', 'ユモト', null, null, '30地割', '30チワリ');
INSERT INTO `ms_addresses` VALUES ('19202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県和賀郡西和賀町湯之沢31地割', '03', '03366', '0295506', '岩手県', 'イワテケン', '和賀郡西和賀町', 'ワガグンニシワガマチ', '湯之沢', 'ユノサワ', null, null, '31地割', '31チワリ');
INSERT INTO `ms_addresses` VALUES ('19203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県和賀郡西和賀町湯之沢32地割', '03', '03366', '0295506', '岩手県', 'イワテケン', '和賀郡西和賀町', 'ワガグンニシワガマチ', '湯之沢', 'ユノサワ', null, null, '32地割', '32チワリ');
INSERT INTO `ms_addresses` VALUES ('19204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県和賀郡西和賀町湯之沢33地割', '03', '03366', '0295506', '岩手県', 'イワテケン', '和賀郡西和賀町', 'ワガグンニシワガマチ', '湯之沢', 'ユノサワ', null, null, '33地割', '33チワリ');
INSERT INTO `ms_addresses` VALUES ('19205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県和賀郡西和賀町湯之沢34地割', '03', '03366', '0295506', '岩手県', 'イワテケン', '和賀郡西和賀町', 'ワガグンニシワガマチ', '湯之沢', 'ユノサワ', null, null, '34地割', '34チワリ');
INSERT INTO `ms_addresses` VALUES ('19206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県和賀郡西和賀町湯之沢35地割', '03', '03366', '0295506', '岩手県', 'イワテケン', '和賀郡西和賀町', 'ワガグンニシワガマチ', '湯之沢', 'ユノサワ', null, null, '35地割', '35チワリ');
INSERT INTO `ms_addresses` VALUES ('19207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県和賀郡西和賀町大沓36地割', '03', '03366', '0295507', '岩手県', 'イワテケン', '和賀郡西和賀町', 'ワガグンニシワガマチ', '大沓', 'オオクツ', null, null, '36地割', '36チワリ');
INSERT INTO `ms_addresses` VALUES ('19208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県和賀郡西和賀町上野々39地割', '03', '03366', '0295511', '岩手県', 'イワテケン', '和賀郡西和賀町', 'ワガグンニシワガマチ', '上野々', 'ウエノノ', null, null, '39地割', '39チワリ');
INSERT INTO `ms_addresses` VALUES ('19209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県和賀郡西和賀町川尻40地割', '03', '03366', '0295512', '岩手県', 'イワテケン', '和賀郡西和賀町', 'ワガグンニシワガマチ', '川尻', 'カワシリ', null, null, '40地割', '40チワリ');
INSERT INTO `ms_addresses` VALUES ('19210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県和賀郡西和賀町川尻41地割', '03', '03366', '0295512', '岩手県', 'イワテケン', '和賀郡西和賀町', 'ワガグンニシワガマチ', '川尻', 'カワシリ', null, null, '41地割', '41チワリ');
INSERT INTO `ms_addresses` VALUES ('19211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県和賀郡西和賀町甲子51地割', '03', '03366', '0295513', '岩手県', 'イワテケン', '和賀郡西和賀町', 'ワガグンニシワガマチ', '甲子', 'カッチ', null, null, '51地割', '51チワリ');
INSERT INTO `ms_addresses` VALUES ('19212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県和賀郡西和賀町草井沢47地割', '03', '03366', '0295513', '岩手県', 'イワテケン', '和賀郡西和賀町', 'ワガグンニシワガマチ', '草井沢', 'クサイザワ', null, null, '47地割', '47チワリ');
INSERT INTO `ms_addresses` VALUES ('19213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県和賀郡西和賀町杉名畑44地割', '03', '03366', '0295513', '岩手県', 'イワテケン', '和賀郡西和賀町', 'ワガグンニシワガマチ', '杉名畑', 'スギナハタ', null, null, '44地割', '44チワリ');
INSERT INTO `ms_addresses` VALUES ('19214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県和賀郡西和賀町本内46地割', '03', '03366', '0295513', '岩手県', 'イワテケン', '和賀郡西和賀町', 'ワガグンニシワガマチ', '本内', 'ホンナイ', null, null, '46地割', '46チワリ');
INSERT INTO `ms_addresses` VALUES ('19215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県和賀郡西和賀町耳取49地割', '03', '03366', '0295513', '岩手県', 'イワテケン', '和賀郡西和賀町', 'ワガグンニシワガマチ', '耳取', 'ミミドリ', null, null, '49地割', '49チワリ');
INSERT INTO `ms_addresses` VALUES ('19216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県和賀郡西和賀町本屋敷48地割', '03', '03366', '0295513', '岩手県', 'イワテケン', '和賀郡西和賀町', 'ワガグンニシワガマチ', '本屋敷', 'モトヤシキ', null, null, '48地割', '48チワリ');
INSERT INTO `ms_addresses` VALUES ('19217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県和賀郡西和賀町鷲之巣50地割', '03', '03366', '0295513', '岩手県', 'イワテケン', '和賀郡西和賀町', 'ワガグンニシワガマチ', '鷲之巣', 'ワシノス', null, null, '50地割', '50チワリ');
INSERT INTO `ms_addresses` VALUES ('19218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県和賀郡西和賀町湯川52地割', '03', '03366', '0295514', '岩手県', 'イワテケン', '和賀郡西和賀町', 'ワガグンニシワガマチ', '湯川', 'ユガワ', null, null, '52地割', '52チワリ');
INSERT INTO `ms_addresses` VALUES ('19219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県和賀郡西和賀町湯川53地割', '03', '03366', '0295514', '岩手県', 'イワテケン', '和賀郡西和賀町', 'ワガグンニシワガマチ', '湯川', 'ユガワ', null, null, '53地割', '53チワリ');
INSERT INTO `ms_addresses` VALUES ('19220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県和賀郡西和賀町大渡57地割', '03', '03366', '0295521', '岩手県', 'イワテケン', '和賀郡西和賀町', 'ワガグンニシワガマチ', '大渡', 'オオワタリ', null, null, '57地割', '57チワリ');
INSERT INTO `ms_addresses` VALUES ('19221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県和賀郡西和賀町小繋沢54地割', '03', '03366', '0295521', '岩手県', 'イワテケン', '和賀郡西和賀町', 'ワガグンニシワガマチ', '小繋沢', 'コツナギザワ', null, null, '54地割', '54チワリ');
INSERT INTO `ms_addresses` VALUES ('19222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県和賀郡西和賀町小繋沢55地割', '03', '03366', '0295521', '岩手県', 'イワテケン', '和賀郡西和賀町', 'ワガグンニシワガマチ', '小繋沢', 'コツナギザワ', null, null, '55地割', '55チワリ');
INSERT INTO `ms_addresses` VALUES ('19223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県和賀郡西和賀町小繋沢56地割', '03', '03366', '0295521', '岩手県', 'イワテケン', '和賀郡西和賀町', 'ワガグンニシワガマチ', '小繋沢', 'コツナギザワ', null, null, '56地割', '56チワリ');
INSERT INTO `ms_addresses` VALUES ('19224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県和賀郡西和賀町巣郷63地割', '03', '03366', '0295522', '岩手県', 'イワテケン', '和賀郡西和賀町', 'ワガグンニシワガマチ', '巣郷', 'スゴウ', null, null, '63地割', '63チワリ');
INSERT INTO `ms_addresses` VALUES ('19225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県和賀郡西和賀町中村58地割', '03', '03366', '0295522', '岩手県', 'イワテケン', '和賀郡西和賀町', 'ワガグンニシワガマチ', '中村', 'ナカムラ', null, null, '58地割', '58チワリ');
INSERT INTO `ms_addresses` VALUES ('19226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県和賀郡西和賀町中村59地割', '03', '03366', '0295522', '岩手県', 'イワテケン', '和賀郡西和賀町', 'ワガグンニシワガマチ', '中村', 'ナカムラ', null, null, '59地割', '59チワリ');
INSERT INTO `ms_addresses` VALUES ('19227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県和賀郡西和賀町野々宿60地割', '03', '03366', '0295522', '岩手県', 'イワテケン', '和賀郡西和賀町', 'ワガグンニシワガマチ', '野々宿', 'ノノシュク', null, null, '60地割', '60チワリ');
INSERT INTO `ms_addresses` VALUES ('19228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県和賀郡西和賀町野々宿61地割', '03', '03366', '0295522', '岩手県', 'イワテケン', '和賀郡西和賀町', 'ワガグンニシワガマチ', '野々宿', 'ノノシュク', null, null, '61地割', '61チワリ');
INSERT INTO `ms_addresses` VALUES ('19229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県和賀郡西和賀町野々宿62地割', '03', '03366', '0295522', '岩手県', 'イワテケン', '和賀郡西和賀町', 'ワガグンニシワガマチ', '野々宿', 'ノノシュク', null, null, '62地割', '62チワリ');
INSERT INTO `ms_addresses` VALUES ('19230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県和賀郡西和賀町越中畑64地割', '03', '03366', '0295523', '岩手県', 'イワテケン', '和賀郡西和賀町', 'ワガグンニシワガマチ', '越中畑', 'エッチュウハタ', null, null, '64地割', '64チワリ');
INSERT INTO `ms_addresses` VALUES ('19231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県和賀郡西和賀町越中畑65地割', '03', '03366', '0295523', '岩手県', 'イワテケン', '和賀郡西和賀町', 'ワガグンニシワガマチ', '越中畑', 'エッチュウハタ', null, null, '65地割', '65チワリ');
INSERT INTO `ms_addresses` VALUES ('19232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県和賀郡西和賀町越中畑66地割', '03', '03366', '0295523', '岩手県', 'イワテケン', '和賀郡西和賀町', 'ワガグンニシワガマチ', '越中畑', 'エッチュウハタ', null, null, '66地割', '66チワリ');
INSERT INTO `ms_addresses` VALUES ('19233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県和賀郡西和賀町桂子沢75地割', '03', '03366', '0295523', '岩手県', 'イワテケン', '和賀郡西和賀町', 'ワガグンニシワガマチ', '桂子沢', 'カツラゴザワ', null, null, '75地割', '75チワリ');
INSERT INTO `ms_addresses` VALUES ('19234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県和賀郡西和賀町桂子沢76地割', '03', '03366', '0295523', '岩手県', 'イワテケン', '和賀郡西和賀町', 'ワガグンニシワガマチ', '桂子沢', 'カツラゴザワ', null, null, '76地割', '76チワリ');
INSERT INTO `ms_addresses` VALUES ('19235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県和賀郡西和賀町沢中73地割', '03', '03366', '0295523', '岩手県', 'イワテケン', '和賀郡西和賀町', 'ワガグンニシワガマチ', '沢中', 'サワナカ', null, null, '73地割', '73チワリ');
INSERT INTO `ms_addresses` VALUES ('19236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県和賀郡西和賀町沢中74地割', '03', '03366', '0295523', '岩手県', 'イワテケン', '和賀郡西和賀町', 'ワガグンニシワガマチ', '沢中', 'サワナカ', null, null, '74地割', '74チワリ');
INSERT INTO `ms_addresses` VALUES ('19237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県和賀郡西和賀町白木野67地割', '03', '03366', '0295523', '岩手県', 'イワテケン', '和賀郡西和賀町', 'ワガグンニシワガマチ', '白木野', 'シロキノ', null, null, '67地割', '67チワリ');
INSERT INTO `ms_addresses` VALUES ('19238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県和賀郡西和賀町細内68地割', '03', '03366', '0295523', '岩手県', 'イワテケン', '和賀郡西和賀町', 'ワガグンニシワガマチ', '細内', 'ホソナイ', null, null, '68地割', '68チワリ');
INSERT INTO `ms_addresses` VALUES ('19239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県和賀郡西和賀町細内69地割', '03', '03366', '0295523', '岩手県', 'イワテケン', '和賀郡西和賀町', 'ワガグンニシワガマチ', '細内', 'ホソナイ', null, null, '69地割', '69チワリ');
INSERT INTO `ms_addresses` VALUES ('19240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県和賀郡西和賀町柳沢70地割', '03', '03366', '0295523', '岩手県', 'イワテケン', '和賀郡西和賀町', 'ワガグンニシワガマチ', '柳沢', 'ヤナギザワ', null, null, '70地割', '70チワリ');
INSERT INTO `ms_addresses` VALUES ('19241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県和賀郡西和賀町柳沢71地割', '03', '03366', '0295523', '岩手県', 'イワテケン', '和賀郡西和賀町', 'ワガグンニシワガマチ', '柳沢', 'ヤナギザワ', null, null, '71地割', '71チワリ');
INSERT INTO `ms_addresses` VALUES ('19242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県和賀郡西和賀町芦ケ沢72地割', '03', '03366', '0295523', '岩手県', 'イワテケン', '和賀郡西和賀町', 'ワガグンニシワガマチ', '芦ケ沢', 'ヨシガサワ', null, null, '72地割', '72チワリ');
INSERT INTO `ms_addresses` VALUES ('19243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県和賀郡西和賀町沢内新町', '03', '03366', '0295611', '岩手県', 'イワテケン', '和賀郡西和賀町', 'ワガグンニシワガマチ', '沢内新町', 'サワウチシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県和賀郡西和賀町沢内大野', '03', '03366', '0295612', '岩手県', 'イワテケン', '和賀郡西和賀町', 'ワガグンニシワガマチ', '沢内大野', 'サワウチオオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県和賀郡西和賀町沢内前郷', '03', '03366', '0295613', '岩手県', 'イワテケン', '和賀郡西和賀町', 'ワガグンニシワガマチ', '沢内前郷', 'サワウチマエゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県和賀郡西和賀町沢内太田', '03', '03366', '0295614', '岩手県', 'イワテケン', '和賀郡西和賀町', 'ワガグンニシワガマチ', '沢内太田', 'サワウチオオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県和賀郡西和賀町沢内猿橋', '03', '03366', '0295615', '岩手県', 'イワテケン', '和賀郡西和賀町', 'ワガグンニシワガマチ', '沢内猿橋', 'サワウチサルハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県和賀郡西和賀町沢内泉沢', '03', '03366', '0295616', '岩手県', 'イワテケン', '和賀郡西和賀町', 'ワガグンニシワガマチ', '沢内泉沢', 'サワウチイズミザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県和賀郡西和賀町沢内長瀬野', '03', '03366', '0295617', '岩手県', 'イワテケン', '和賀郡西和賀町', 'ワガグンニシワガマチ', '沢内長瀬野', 'サワウチナガセノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県和賀郡西和賀町沢内両沢', '03', '03366', '0295618', '岩手県', 'イワテケン', '和賀郡西和賀町', 'ワガグンニシワガマチ', '沢内両沢', 'サワウチリョウザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県和賀郡西和賀町沢内弁天', '03', '03366', '0295619', '岩手県', 'イワテケン', '和賀郡西和賀町', 'ワガグンニシワガマチ', '沢内弁天', 'サワウチベンテン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県和賀郡西和賀町沢内鍵飯', '03', '03366', '0295621', '岩手県', 'イワテケン', '和賀郡西和賀町', 'ワガグンニシワガマチ', '沢内鍵飯', 'サワウチケンパン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県和賀郡西和賀町沢内川舟', '03', '03366', '0295701', '岩手県', 'イワテケン', '和賀郡西和賀町', 'ワガグンニシワガマチ', '沢内川舟', 'サワウチカワフネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県和賀郡西和賀町沢内若畑', '03', '03366', '0295702', '岩手県', 'イワテケン', '和賀郡西和賀町', 'ワガグンニシワガマチ', '沢内若畑', 'サワウチワカハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岩手県和賀郡西和賀町沢内貝沢', '03', '03366', '0295703', '岩手県', 'イワテケン', '和賀郡西和賀町', 'ワガグンニシワガマチ', '沢内貝沢', 'サワウチカイザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鴨川市', '12', '12223', '2960000', '千葉県', 'チバケン', '鴨川市', 'カモガワシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('19259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鴨川市横渚', '12', '12223', '2960001', '千葉県', 'チバケン', '鴨川市', 'カモガワシ', '横渚', 'ヨコスカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鴨川市前原', '12', '12223', '2960002', '千葉県', 'チバケン', '鴨川市', 'カモガワシ', '前原', 'マエバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鴨川市磯村', '12', '12223', '2960003', '千葉県', 'チバケン', '鴨川市', 'カモガワシ', '磯村', 'イソムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鴨川市貝渚', '12', '12223', '2960004', '千葉県', 'チバケン', '鴨川市', 'カモガワシ', '貝渚', 'カイスカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鴨川市大里', '12', '12223', '2960011', '千葉県', 'チバケン', '鴨川市', 'カモガワシ', '大里', 'ダイリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鴨川市来秀', '12', '12223', '2960012', '千葉県', 'チバケン', '鴨川市', 'カモガワシ', '来秀', 'ライシュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鴨川市田原西', '12', '12223', '2960013', '千葉県', 'チバケン', '鴨川市', 'カモガワシ', '田原西', 'タバラニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鴨川市太尾', '12', '12223', '2960014', '千葉県', 'チバケン', '鴨川市', 'カモガワシ', '太尾', 'フトオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鴨川市川代', '12', '12223', '2960015', '千葉県', 'チバケン', '鴨川市', 'カモガワシ', '川代', 'カワシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鴨川市坂東', '12', '12223', '2960016', '千葉県', 'チバケン', '鴨川市', 'カモガワシ', '坂東', 'バンドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鴨川市竹平', '12', '12223', '2960021', '千葉県', 'チバケン', '鴨川市', 'カモガワシ', '竹平', 'タケヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鴨川市京田', '12', '12223', '2960022', '千葉県', 'チバケン', '鴨川市', 'カモガワシ', '京田', 'キョウデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鴨川市押切', '12', '12223', '2960023', '千葉県', 'チバケン', '鴨川市', 'カモガワシ', '押切', 'オシキリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鴨川市池田', '12', '12223', '2960024', '千葉県', 'チバケン', '鴨川市', 'カモガワシ', '池田', 'イケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鴨川市太田学', '12', '12223', '2960025', '千葉県', 'チバケン', '鴨川市', 'カモガワシ', '太田学', 'オダガク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鴨川市粟斗', '12', '12223', '2960031', '千葉県', 'チバケン', '鴨川市', 'カモガワシ', '粟斗', 'アワト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鴨川市花房', '12', '12223', '2960032', '千葉県', 'チバケン', '鴨川市', 'カモガワシ', '花房', 'ハナブサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鴨川市八色', '12', '12223', '2960033', '千葉県', 'チバケン', '鴨川市', 'カモガワシ', '八色', 'ヤイロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鴨川市滑谷', '12', '12223', '2960034', '千葉県', 'チバケン', '鴨川市', 'カモガワシ', '滑谷', 'ヌカリヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鴨川市打墨', '12', '12223', '2960035', '千葉県', 'チバケン', '鴨川市', 'カモガワシ', '打墨', 'ウツツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鴨川市東町', '12', '12223', '2960041', '千葉県', 'チバケン', '鴨川市', 'カモガワシ', '東町', 'ヒガシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鴨川市東元浜荻飛地', '12', '12223', '2960042', '千葉県', 'チバケン', '鴨川市', 'カモガワシ', '東元浜荻飛地', 'ヒガシモトハマオギトビチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鴨川市西町', '12', '12223', '2960043', '千葉県', 'チバケン', '鴨川市', 'カモガワシ', '西町', 'ニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鴨川市広場', '12', '12223', '2960044', '千葉県', 'チバケン', '鴨川市', 'カモガワシ', '広場', 'ヒロバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鴨川市和泉', '12', '12223', '2960045', '千葉県', 'チバケン', '鴨川市', 'カモガワシ', '和泉', 'イズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鴨川市北小町', '12', '12223', '2960101', '千葉県', 'チバケン', '鴨川市', 'カモガワシ', '北小町', 'キタコマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鴨川市下小原', '12', '12223', '2960102', '千葉県', 'チバケン', '鴨川市', 'カモガワシ', '下小原', 'シモコバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鴨川市上小原', '12', '12223', '2960103', '千葉県', 'チバケン', '鴨川市', 'カモガワシ', '上小原', 'カミコバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鴨川市南小町', '12', '12223', '2960104', '千葉県', 'チバケン', '鴨川市', 'カモガワシ', '南小町', 'ミナミコマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鴨川市成川', '12', '12223', '2960105', '千葉県', 'チバケン', '鴨川市', 'カモガワシ', '成川', 'ナリガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鴨川市主基西', '12', '12223', '2960106', '千葉県', 'チバケン', '鴨川市', 'カモガワシ', '主基西', 'スキニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鴨川市仲', '12', '12223', '2960111', '千葉県', 'チバケン', '鴨川市', 'カモガワシ', '仲', 'ナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鴨川市宮山', '12', '12223', '2960112', '千葉県', 'チバケン', '鴨川市', 'カモガワシ', '宮山', 'ミヤヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鴨川市吉尾平塚', '12', '12223', '2960113', '千葉県', 'チバケン', '鴨川市', 'カモガワシ', '吉尾平塚', 'ヨシオヒラツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鴨川市細野', '12', '12223', '2960114', '千葉県', 'チバケン', '鴨川市', 'カモガワシ', '細野', 'ホソノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鴨川市松尾寺', '12', '12223', '2960115', '千葉県', 'チバケン', '鴨川市', 'カモガワシ', '松尾寺', 'マツオジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鴨川市大川面', '12', '12223', '2960121', '千葉県', 'チバケン', '鴨川市', 'カモガワシ', '大川面', 'オオカワヅラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鴨川市寺門', '12', '12223', '2960122', '千葉県', 'チバケン', '鴨川市', 'カモガワシ', '寺門', 'テラカド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鴨川市北風原', '12', '12223', '2960123', '千葉県', 'チバケン', '鴨川市', 'カモガワシ', '北風原', 'ナライハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鴨川市大幡', '12', '12223', '2960124', '千葉県', 'チバケン', '鴨川市', 'カモガワシ', '大幡', 'オオハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鴨川市横尾', '12', '12223', '2960125', '千葉県', 'チバケン', '鴨川市', 'カモガワシ', '横尾', 'ヨコオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鴨川市吉尾西', '12', '12223', '2960126', '千葉県', 'チバケン', '鴨川市', 'カモガワシ', '吉尾西', 'ヨシオニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鴨川市釜沼', '12', '12223', '2960231', '千葉県', 'チバケン', '鴨川市', 'カモガワシ', '釜沼', 'カマヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鴨川市平塚', '12', '12223', '2960232', '千葉県', 'チバケン', '鴨川市', 'カモガワシ', '平塚', 'ヒラツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鴨川市金束', '12', '12223', '2960233', '千葉県', 'チバケン', '鴨川市', 'カモガワシ', '金束', 'コヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鴨川市古畑', '12', '12223', '2960234', '千葉県', 'チバケン', '鴨川市', 'カモガワシ', '古畑', 'コバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鴨川市奈良林', '12', '12223', '2960235', '千葉県', 'チバケン', '鴨川市', 'カモガワシ', '奈良林', 'ナラバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鴨川市佐野', '12', '12223', '2960236', '千葉県', 'チバケン', '鴨川市', 'カモガワシ', '佐野', 'サノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鴨川市大山平塚', '12', '12223', '2960237', '千葉県', 'チバケン', '鴨川市', 'カモガワシ', '大山平塚', 'オオヤマヒラツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県茂原市', '12', '12210', '2970000', '千葉県', 'チバケン', '茂原市', 'モバラシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('19312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県茂原市七渡', '12', '12210', '2970001', '千葉県', 'チバケン', '茂原市', 'モバラシ', '七渡', 'ナナワタリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県茂原市千町', '12', '12210', '2970002', '千葉県', 'チバケン', '茂原市', 'モバラシ', '千町', 'センチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県茂原市北高根飛地', '12', '12210', '2970003', '千葉県', 'チバケン', '茂原市', 'モバラシ', '北高根飛地', 'キタタカネトビチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県茂原市小轡', '12', '12210', '2970004', '千葉県', 'チバケン', '茂原市', 'モバラシ', '小轡', 'コグツワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県茂原市本小轡', '12', '12210', '2970005', '千葉県', 'チバケン', '茂原市', 'モバラシ', '本小轡', 'ホンコグツワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県茂原市新小轡', '12', '12210', '2970006', '千葉県', 'チバケン', '茂原市', 'モバラシ', '新小轡', 'シンコグツワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県茂原市腰当', '12', '12210', '2970007', '千葉県', 'チバケン', '茂原市', 'モバラシ', '腰当', 'コシアテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県茂原市渋谷', '12', '12210', '2970008', '千葉県', 'チバケン', '茂原市', 'モバラシ', '渋谷', 'シブヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県茂原市北塚', '12', '12210', '2970009', '千葉県', 'チバケン', '茂原市', 'モバラシ', '北塚', 'キタヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県茂原市谷本', '12', '12210', '2970011', '千葉県', 'チバケン', '茂原市', 'モバラシ', '谷本', 'ヤモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県茂原市六ツ野', '12', '12210', '2970012', '千葉県', 'チバケン', '茂原市', 'モバラシ', '六ツ野', 'ムツノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県茂原市中之郷飛地', '12', '12210', '2970013', '千葉県', 'チバケン', '茂原市', 'モバラシ', '中之郷飛地', 'ナカノゴウトビチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県茂原市川島飛地', '12', '12210', '2970014', '千葉県', 'チバケン', '茂原市', 'モバラシ', '川島飛地', 'カワシマトビチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県茂原市東部台', '12', '12210', '2970015', '千葉県', 'チバケン', '茂原市', 'モバラシ', '東部台', 'トウブダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県茂原市木崎', '12', '12210', '2970016', '千葉県', 'チバケン', '茂原市', 'モバラシ', '木崎', 'キサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県茂原市東郷', '12', '12210', '2970017', '千葉県', 'チバケン', '茂原市', 'モバラシ', '東郷', 'トウゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県茂原市萩原町', '12', '12210', '2970018', '千葉県', 'チバケン', '茂原市', 'モバラシ', '萩原町', 'ハギワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県茂原市上林', '12', '12210', '2970019', '千葉県', 'チバケン', '茂原市', 'モバラシ', '上林', 'カンバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県茂原市高師町', '12', '12210', '2970021', '千葉県', 'チバケン', '茂原市', 'モバラシ', '高師町', 'タカシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県茂原市町保', '12', '12210', '2970022', '千葉県', 'チバケン', '茂原市', 'モバラシ', '町保', 'マチボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県茂原市千代田町', '12', '12210', '2970023', '千葉県', 'チバケン', '茂原市', 'モバラシ', '千代田町', 'チヨダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県茂原市八千代', '12', '12210', '2970024', '千葉県', 'チバケン', '茂原市', 'モバラシ', '八千代', 'ヤチヨ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県茂原市緑町', '12', '12210', '2970025', '千葉県', 'チバケン', '茂原市', 'モバラシ', '緑町', 'ミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県茂原市茂原', '12', '12210', '2970026', '千葉県', 'チバケン', '茂原市', 'モバラシ', '茂原', 'モバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県茂原市中部', '12', '12210', '2970027', '千葉県', 'チバケン', '茂原市', 'モバラシ', '中部', 'チュウブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県茂原市道表', '12', '12210', '2970028', '千葉県', 'チバケン', '茂原市', 'モバラシ', '道表', 'ドウビョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県茂原市高師', '12', '12210', '2970029', '千葉県', 'チバケン', '茂原市', 'モバラシ', '高師', 'タカシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県茂原市早野新田', '12', '12210', '2970031', '千葉県', 'チバケン', '茂原市', 'モバラシ', '早野新田', 'ハヤノシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県茂原市東茂原', '12', '12210', '2970032', '千葉県', 'チバケン', '茂原市', 'モバラシ', '東茂原', 'ヒガシモバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県茂原市大芝', '12', '12210', '2970033', '千葉県', 'チバケン', '茂原市', 'モバラシ', '大芝', 'オオシバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県茂原市中の島町', '12', '12210', '2970034', '千葉県', 'チバケン', '茂原市', 'モバラシ', '中の島町', 'ナカノシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県茂原市下永吉', '12', '12210', '2970035', '千葉県', 'チバケン', '茂原市', 'モバラシ', '下永吉', 'シモナガヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県茂原市上永吉', '12', '12210', '2970036', '千葉県', 'チバケン', '茂原市', 'モバラシ', '上永吉', 'カミナガヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県茂原市早野', '12', '12210', '2970037', '千葉県', 'チバケン', '茂原市', 'モバラシ', '早野', 'ハヤノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県茂原市長清水', '12', '12210', '2970038', '千葉県', 'チバケン', '茂原市', 'モバラシ', '長清水', 'ナガシミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県茂原市茂原西', '12', '12210', '2970039', '千葉県', 'チバケン', '茂原市', 'モバラシ', '茂原西', 'モバラニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県茂原市猿袋', '12', '12210', '2970041', '千葉県', 'チバケン', '茂原市', 'モバラシ', '猿袋', 'サルブクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県茂原市三ケ谷', '12', '12210', '2970042', '千葉県', 'チバケン', '茂原市', 'モバラシ', '三ケ谷', 'サンガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県茂原市立木', '12', '12210', '2970043', '千葉県', 'チバケン', '茂原市', 'モバラシ', '立木', 'タチキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県茂原市台田', '12', '12210', '2970044', '千葉県', 'チバケン', '茂原市', 'モバラシ', '台田', 'ダイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県茂原市野牛', '12', '12210', '2970045', '千葉県', 'チバケン', '茂原市', 'モバラシ', '野牛', 'ヤギュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県茂原市鷲巣', '12', '12210', '2970051', '千葉県', 'チバケン', '茂原市', 'モバラシ', '鷲巣', 'ワシノス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県茂原市上茂原', '12', '12210', '2970052', '千葉県', 'チバケン', '茂原市', 'モバラシ', '上茂原', 'カミモバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県茂原市墨田', '12', '12210', '2970053', '千葉県', 'チバケン', '茂原市', 'モバラシ', '墨田', 'スミダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県茂原市八幡原', '12', '12210', '2970054', '千葉県', 'チバケン', '茂原市', 'モバラシ', '八幡原', 'ヤワタバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県茂原市綱島', '12', '12210', '2970055', '千葉県', 'チバケン', '茂原市', 'モバラシ', '綱島', 'ツナシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県茂原市六田台', '12', '12210', '2970056', '千葉県', 'チバケン', '茂原市', 'モバラシ', '六田台', 'ロクタダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県茂原市中善寺', '12', '12210', '2970057', '千葉県', 'チバケン', '茂原市', 'モバラシ', '中善寺', 'チュウゼンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県茂原市石神', '12', '12210', '2970058', '千葉県', 'チバケン', '茂原市', 'モバラシ', '石神', 'イシガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県茂原市山崎', '12', '12210', '2970061', '千葉県', 'チバケン', '茂原市', 'モバラシ', '山崎', 'ヤマサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県茂原市内長谷', '12', '12210', '2970062', '千葉県', 'チバケン', '茂原市', 'モバラシ', '内長谷', 'ウチナガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県茂原市長谷', '12', '12210', '2970063', '千葉県', 'チバケン', '茂原市', 'モバラシ', '長谷', 'ナガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県茂原市箕輪', '12', '12210', '2970064', '千葉県', 'チバケン', '茂原市', 'モバラシ', '箕輪', 'ミノワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県茂原市緑ケ丘', '12', '12210', '2970065', '千葉県', 'チバケン', '茂原市', 'モバラシ', '緑ケ丘', 'ミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県茂原市芦網', '12', '12210', '2970066', '千葉県', 'チバケン', '茂原市', 'モバラシ', '芦網', 'アシアミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県茂原市国府関', '12', '12210', '2970067', '千葉県', 'チバケン', '茂原市', 'モバラシ', '国府関', 'コウセキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県茂原市黒戸', '12', '12210', '2970071', '千葉県', 'チバケン', '茂原市', 'モバラシ', '黒戸', 'クロド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県茂原市大登', '12', '12210', '2970072', '千葉県', 'チバケン', '茂原市', 'モバラシ', '大登', 'オオノボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県茂原市長尾', '12', '12210', '2970073', '千葉県', 'チバケン', '茂原市', 'モバラシ', '長尾', 'ナガオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県茂原市小林', '12', '12210', '2970074', '千葉県', 'チバケン', '茂原市', 'モバラシ', '小林', 'コバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県茂原市押日', '12', '12210', '2970075', '千葉県', 'チバケン', '茂原市', 'モバラシ', '押日', 'オシビ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県茂原市庄吉', '12', '12210', '2970076', '千葉県', 'チバケン', '茂原市', 'モバラシ', '庄吉', 'ショウヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県茂原市真名', '12', '12210', '2970077', '千葉県', 'チバケン', '茂原市', 'モバラシ', '真名', 'マンナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県茂原市高師台', '12', '12210', '2970078', '千葉県', 'チバケン', '茂原市', 'モバラシ', '高師台', 'タカシダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡長南町', '12', '12427', '2970100', '千葉県', 'チバケン', '長生郡長南町', 'チョウセイグンチョウナンマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('19377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡長南町岩川', '12', '12427', '2970101', '千葉県', 'チバケン', '長生郡長南町', 'チョウセイグンチョウナンマチ', '岩川', 'イワカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡長南町本台', '12', '12427', '2970102', '千葉県', 'チバケン', '長生郡長南町', 'チョウセイグンチョウナンマチ', '本台', 'モトダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡長南町今泉', '12', '12427', '2970103', '千葉県', 'チバケン', '長生郡長南町', 'チョウセイグンチョウナンマチ', '今泉', 'イマイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡長南町又富', '12', '12427', '2970104', '千葉県', 'チバケン', '長生郡長南町', 'チョウセイグンチョウナンマチ', '又富', 'マタドミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡長南町棚毛', '12', '12427', '2970105', '千葉県', 'チバケン', '長生郡長南町', 'チョウセイグンチョウナンマチ', '棚毛', 'タナゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡長南町須田', '12', '12427', '2970111', '千葉県', 'チバケン', '長生郡長南町', 'チョウセイグンチョウナンマチ', '須田', 'スダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡長南町米満', '12', '12427', '2970112', '千葉県', 'チバケン', '長生郡長南町', 'チョウセイグンチョウナンマチ', '米満', 'ヨネミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡長南町関原', '12', '12427', '2970113', '千葉県', 'チバケン', '長生郡長南町', 'チョウセイグンチョウナンマチ', '関原', 'セキバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡長南町千手堂', '12', '12427', '2970114', '千葉県', 'チバケン', '長生郡長南町', 'チョウセイグンチョウナンマチ', '千手堂', 'センジュドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡長南町千田', '12', '12427', '2970115', '千葉県', 'チバケン', '長生郡長南町', 'チョウセイグンチョウナンマチ', '千田', 'センダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡長南町長南', '12', '12427', '2970121', '千葉県', 'チバケン', '長生郡長南町', 'チョウセイグンチョウナンマチ', '長南', 'チョウナン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡長南町坂本', '12', '12427', '2970122', '千葉県', 'チバケン', '長生郡長南町', 'チョウセイグンチョウナンマチ', '坂本', 'サカモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡長南町蔵持', '12', '12427', '2970123', '千葉県', 'チバケン', '長生郡長南町', 'チョウセイグンチョウナンマチ', '蔵持', 'クラモチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡長南町深沢', '12', '12427', '2970124', '千葉県', 'チバケン', '長生郡長南町', 'チョウセイグンチョウナンマチ', '深沢', 'フカサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡長南町笠森', '12', '12427', '2970125', '千葉県', 'チバケン', '長生郡長南町', 'チョウセイグンチョウナンマチ', '笠森', 'カサモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡長南町中原', '12', '12427', '2970131', '千葉県', 'チバケン', '長生郡長南町', 'チョウセイグンチョウナンマチ', '中原', 'ナカハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡長南町給田', '12', '12427', '2970132', '千葉県', 'チバケン', '長生郡長南町', 'チョウセイグンチョウナンマチ', '給田', 'キュウデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡長南町豊原', '12', '12427', '2970133', '千葉県', 'チバケン', '長生郡長南町', 'チョウセイグンチョウナンマチ', '豊原', 'トヨハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡長南町芝原', '12', '12427', '2970134', '千葉県', 'チバケン', '長生郡長南町', 'チョウセイグンチョウナンマチ', '芝原', 'シバハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡長南町地引', '12', '12427', '2970135', '千葉県', 'チバケン', '長生郡長南町', 'チョウセイグンチョウナンマチ', '地引', 'ジヒキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡長南町小生田', '12', '12427', '2970136', '千葉県', 'チバケン', '長生郡長南町', 'チョウセイグンチョウナンマチ', '小生田', 'オブタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡長南町上小野田', '12', '12427', '2970137', '千葉県', 'チバケン', '長生郡長南町', 'チョウセイグンチョウナンマチ', '上小野田', 'カミオノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡長南町下小野田', '12', '12427', '2970138', '千葉県', 'チバケン', '長生郡長南町', 'チョウセイグンチョウナンマチ', '下小野田', 'シモオノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡長南町報恩寺', '12', '12427', '2970141', '千葉県', 'チバケン', '長生郡長南町', 'チョウセイグンチョウナンマチ', '報恩寺', 'ホウオンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡長南町小沢', '12', '12427', '2970142', '千葉県', 'チバケン', '長生郡長南町', 'チョウセイグンチョウナンマチ', '小沢', 'オザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡長南町美原台', '12', '12427', '2970143', '千葉県', 'チバケン', '長生郡長南町', 'チョウセイグンチョウナンマチ', '美原台', 'ミハラダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡長南町市野々', '12', '12427', '2970144', '千葉県', 'チバケン', '長生郡長南町', 'チョウセイグンチョウナンマチ', '市野々', 'イチノノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡長南町佐坪', '12', '12427', '2970145', '千葉県', 'チバケン', '長生郡長南町', 'チョウセイグンチョウナンマチ', '佐坪', 'サツボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡長南町茗荷沢', '12', '12427', '2970151', '千葉県', 'チバケン', '長生郡長南町', 'チョウセイグンチョウナンマチ', '茗荷沢', 'ミョウガザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡長南町水沼', '12', '12427', '2970152', '千葉県', 'チバケン', '長生郡長南町', 'チョウセイグンチョウナンマチ', '水沼', 'ミズヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡長南町山内', '12', '12427', '2970153', '千葉県', 'チバケン', '長生郡長南町', 'チョウセイグンチョウナンマチ', '山内', 'ヤマウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡長南町岩撫', '12', '12427', '2970154', '千葉県', 'チバケン', '長生郡長南町', 'チョウセイグンチョウナンマチ', '岩撫', 'イワナデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡長南町竹林', '12', '12427', '2970155', '千葉県', 'チバケン', '長生郡長南町', 'チョウセイグンチョウナンマチ', '竹林', 'タケバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡長柄町', '12', '12426', '2970200', '千葉県', 'チバケン', '長生郡長柄町', 'チョウセイグンナガラマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('19418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡長柄町上野', '12', '12426', '2970201', '千葉県', 'チバケン', '長生郡長柄町', 'チョウセイグンナガラマチ', '上野', 'ウエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡長柄町味庄', '12', '12426', '2970202', '千葉県', 'チバケン', '長生郡長柄町', 'チョウセイグンナガラマチ', '味庄', 'ミショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡長柄町国府里', '12', '12426', '2970203', '千葉県', 'チバケン', '長生郡長柄町', 'チョウセイグンナガラマチ', '国府里', 'コウリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡長柄町力丸', '12', '12426', '2970204', '千葉県', 'チバケン', '長生郡長柄町', 'チョウセイグンナガラマチ', '力丸', 'リキマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡長柄町千代丸', '12', '12426', '2970205', '千葉県', 'チバケン', '長生郡長柄町', 'チョウセイグンナガラマチ', '千代丸', 'チヨマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡長柄町山根', '12', '12426', '2970206', '千葉県', 'チバケン', '長生郡長柄町', 'チョウセイグンナガラマチ', '山根', 'ヤマンネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡長柄町船木', '12', '12426', '2970207', '千葉県', 'チバケン', '長生郡長柄町', 'チョウセイグンナガラマチ', '船木', 'フナキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡長柄町榎本', '12', '12426', '2970211', '千葉県', 'チバケン', '長生郡長柄町', 'チョウセイグンナガラマチ', '榎本', 'エモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡長柄町小榎本', '12', '12426', '2970212', '千葉県', 'チバケン', '長生郡長柄町', 'チョウセイグンナガラマチ', '小榎本', 'コエモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡長柄町徳増', '12', '12426', '2970213', '千葉県', 'チバケン', '長生郡長柄町', 'チョウセイグンナガラマチ', '徳増', 'トクマス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡長柄町長富', '12', '12426', '2970214', '千葉県', 'チバケン', '長生郡長柄町', 'チョウセイグンナガラマチ', '長富', 'ナガドミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡長柄町鴇谷', '12', '12426', '2970215', '千葉県', 'チバケン', '長生郡長柄町', 'チョウセイグンナガラマチ', '鴇谷', 'トウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡長柄町立鳥', '12', '12426', '2970216', '千葉県', 'チバケン', '長生郡長柄町', 'チョウセイグンナガラマチ', '立鳥', 'タツトリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡長柄町針ケ谷', '12', '12426', '2970217', '千葉県', 'チバケン', '長生郡長柄町', 'チョウセイグンナガラマチ', '針ケ谷', 'ハリガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡長柄町桜谷', '12', '12426', '2970218', '千葉県', 'チバケン', '長生郡長柄町', 'チョウセイグンナガラマチ', '桜谷', 'サクラヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡長柄町高山', '12', '12426', '2970221', '千葉県', 'チバケン', '長生郡長柄町', 'チョウセイグンナガラマチ', '高山', 'タカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡長柄町大庭', '12', '12426', '2970222', '千葉県', 'チバケン', '長生郡長柄町', 'チョウセイグンナガラマチ', '大庭', 'オオニワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡長柄町大津倉', '12', '12426', '2970223', '千葉県', 'チバケン', '長生郡長柄町', 'チョウセイグンナガラマチ', '大津倉', 'オオヅクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡長柄町田代', '12', '12426', '2970224', '千葉県', 'チバケン', '長生郡長柄町', 'チョウセイグンナガラマチ', '田代', 'タシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡長柄町刑部', '12', '12426', '2970225', '千葉県', 'チバケン', '長生郡長柄町', 'チョウセイグンナガラマチ', '刑部', 'オサカベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡長柄町金谷', '12', '12426', '2970226', '千葉県', 'チバケン', '長生郡長柄町', 'チョウセイグンナガラマチ', '金谷', 'カナヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡長柄町山之郷', '12', '12426', '2970231', '千葉県', 'チバケン', '長生郡長柄町', 'チョウセイグンナガラマチ', '山之郷', 'ヤマノゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡長柄町中野台', '12', '12426', '2970232', '千葉県', 'チバケン', '長生郡長柄町', 'チョウセイグンナガラマチ', '中野台', 'ナカノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡長柄町六地蔵', '12', '12426', '2970233', '千葉県', 'チバケン', '長生郡長柄町', 'チョウセイグンナガラマチ', '六地蔵', 'ロクジゾウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡長柄町長柄山', '12', '12426', '2970234', '千葉県', 'チバケン', '長生郡長柄町', 'チョウセイグンナガラマチ', '長柄山', 'ナガラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡長柄町皿木', '12', '12426', '2970235', '千葉県', 'チバケン', '長生郡長柄町', 'チョウセイグンナガラマチ', '皿木', 'サラギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県いすみ市', '12', '12238', '2980000', '千葉県', 'チバケン', 'いすみ市', 'イスミシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('19459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県いすみ市若山', '12', '12238', '2980001', '千葉県', 'チバケン', 'いすみ市', 'イスミシ', '若山', 'ワカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県いすみ市日在', '12', '12238', '2980002', '千葉県', 'チバケン', 'いすみ市', 'イスミシ', '日在', 'ヒアリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県いすみ市深堀', '12', '12238', '2980003', '千葉県', 'チバケン', 'いすみ市', 'イスミシ', '深堀', 'フカホリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県いすみ市大原', '12', '12238', '2980004', '千葉県', 'チバケン', 'いすみ市', 'イスミシ', '大原', 'オオハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県いすみ市新田', '12', '12238', '2980005', '千葉県', 'チバケン', 'いすみ市', 'イスミシ', '新田', 'ニッタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県いすみ市岩船', '12', '12238', '2980011', '千葉県', 'チバケン', 'いすみ市', 'イスミシ', '岩船', 'イワフネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県いすみ市小沢', '12', '12238', '2980012', '千葉県', 'チバケン', 'いすみ市', 'イスミシ', '小沢', 'オザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県いすみ市小池', '12', '12238', '2980013', '千葉県', 'チバケン', 'いすみ市', 'イスミシ', '小池', 'オイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県いすみ市大原台', '12', '12238', '2980014', '千葉県', 'チバケン', 'いすみ市', 'イスミシ', '大原台', 'オオハラダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県いすみ市釈迦谷', '12', '12238', '2980015', '千葉県', 'チバケン', 'いすみ市', 'イスミシ', '釈迦谷', 'シャカヤツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県いすみ市新田若山深堀入会地', '12', '12238', '2980016', '千葉県', 'チバケン', 'いすみ市', 'イスミシ', '新田若山深堀入会地', 'ニッタワカヤマフカホリイリアイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県いすみ市下布施', '12', '12238', '2980017', '千葉県', 'チバケン', 'いすみ市', 'イスミシ', '下布施', 'シモブセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県いすみ市上布施', '12', '12238', '2980018', '千葉県', 'チバケン', 'いすみ市', 'イスミシ', '上布施', 'カミブセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県いすみ市高谷', '12', '12238', '2980021', '千葉県', 'チバケン', 'いすみ市', 'イスミシ', '高谷', 'タカダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県いすみ市佐室', '12', '12238', '2980022', '千葉県', 'チバケン', 'いすみ市', 'イスミシ', '佐室', 'サムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県いすみ市沢部', '12', '12238', '2980023', '千葉県', 'チバケン', 'いすみ市', 'イスミシ', '沢部', 'サワベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県いすみ市長志', '12', '12238', '2980024', '千葉県', 'チバケン', 'いすみ市', 'イスミシ', '長志', 'ナガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県いすみ市山田', '12', '12238', '2980025', '千葉県', 'チバケン', 'いすみ市', 'イスミシ', '山田', 'ヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県いすみ市新田野', '12', '12238', '2980026', '千葉県', 'チバケン', 'いすみ市', 'イスミシ', '新田野', 'ニッタノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県いすみ市下原', '12', '12238', '2980027', '千葉県', 'チバケン', 'いすみ市', 'イスミシ', '下原', 'シモハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県いすみ市細尾', '12', '12238', '2980028', '千葉県', 'チバケン', 'いすみ市', 'イスミシ', '細尾', 'ホソオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県いすみ市大和田', '12', '12238', '2980029', '千葉県', 'チバケン', 'いすみ市', 'イスミシ', '大和田', 'オオワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県いすみ市小又井', '12', '12238', '2980101', '千葉県', 'チバケン', 'いすみ市', 'イスミシ', '小又井', 'コマタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県いすみ市小高', '12', '12238', '2980102', '千葉県', 'チバケン', 'いすみ市', 'イスミシ', '小高', 'オダカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県いすみ市神置', '12', '12238', '2980103', '千葉県', 'チバケン', 'いすみ市', 'イスミシ', '神置', 'カミオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県いすみ市松丸', '12', '12238', '2980104', '千葉県', 'チバケン', 'いすみ市', 'イスミシ', '松丸', 'マツマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県いすみ市能実', '12', '12238', '2980105', '千葉県', 'チバケン', 'いすみ市', 'イスミシ', '能実', 'ノウジツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県いすみ市須賀谷', '12', '12238', '2980106', '千葉県', 'チバケン', 'いすみ市', 'イスミシ', '須賀谷', 'スガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県いすみ市万木', '12', '12238', '2980111', '千葉県', 'チバケン', 'いすみ市', 'イスミシ', '万木', 'マンギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県いすみ市国府台', '12', '12238', '2980112', '千葉県', 'チバケン', 'いすみ市', 'イスミシ', '国府台', 'コウノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県いすみ市大野', '12', '12238', '2980113', '千葉県', 'チバケン', 'いすみ市', 'イスミシ', '大野', 'オオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県いすみ市札森', '12', '12238', '2980114', '千葉県', 'チバケン', 'いすみ市', 'イスミシ', '札森', 'サツモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県いすみ市柿和田', '12', '12238', '2980115', '千葉県', 'チバケン', 'いすみ市', 'イスミシ', '柿和田', 'カキワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県いすみ市正立寺', '12', '12238', '2980116', '千葉県', 'チバケン', 'いすみ市', 'イスミシ', '正立寺', 'ショウリュウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県いすみ市増田', '12', '12238', '2980117', '千葉県', 'チバケン', 'いすみ市', 'イスミシ', '増田', 'マスダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県いすみ市島', '12', '12238', '2980121', '千葉県', 'チバケン', 'いすみ市', 'イスミシ', '島', 'シマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県いすみ市楽町', '12', '12238', '2980122', '千葉県', 'チバケン', 'いすみ市', 'イスミシ', '楽町', 'ラクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県いすみ市苅谷', '12', '12238', '2980123', '千葉県', 'チバケン', 'いすみ市', 'イスミシ', '苅谷', 'カリヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県いすみ市弥正', '12', '12238', '2980124', '千葉県', 'チバケン', 'いすみ市', 'イスミシ', '弥正', 'ヤマサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県いすみ市深谷', '12', '12238', '2980125', '千葉県', 'チバケン', 'いすみ市', 'イスミシ', '深谷', 'フカヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県いすみ市今関', '12', '12238', '2980126', '千葉県', 'チバケン', 'いすみ市', 'イスミシ', '今関', 'イマゼキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県いすみ市荻原', '12', '12238', '2980131', '千葉県', 'チバケン', 'いすみ市', 'イスミシ', '荻原', 'オギワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県いすみ市八乙女', '12', '12238', '2980132', '千葉県', 'チバケン', 'いすみ市', 'イスミシ', '八乙女', 'ヤオトメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県いすみ市引田', '12', '12238', '2980133', '千葉県', 'チバケン', 'いすみ市', 'イスミシ', '引田', 'ヒキダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県いすみ市行川', '12', '12238', '2980134', '千葉県', 'チバケン', 'いすみ市', 'イスミシ', '行川', 'ナメガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県いすみ市作田', '12', '12238', '2980135', '千葉県', 'チバケン', 'いすみ市', 'イスミシ', '作田', 'サクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県夷隅郡大多喜町', '12', '12441', '2980200', '千葉県', 'チバケン', '夷隅郡大多喜町', 'イスミグンオオタキマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('19506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県夷隅郡大多喜町小土呂', '12', '12441', '2980201', '千葉県', 'チバケン', '夷隅郡大多喜町', 'イスミグンオオタキマチ', '小土呂', 'オドロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県夷隅郡大多喜町下大多喜', '12', '12441', '2980202', '千葉県', 'チバケン', '夷隅郡大多喜町', 'イスミグンオオタキマチ', '下大多喜', 'シモオオタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県夷隅郡大多喜町森宮', '12', '12441', '2980203', '千葉県', 'チバケン', '夷隅郡大多喜町', 'イスミグンオオタキマチ', '森宮', 'モリミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県夷隅郡大多喜町船子', '12', '12441', '2980204', '千葉県', 'チバケン', '夷隅郡大多喜町', 'イスミグンオオタキマチ', '船子', 'フナコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県夷隅郡大多喜町上原西部田柳原入会', '12', '12441', '2980205', '千葉県', 'チバケン', '夷隅郡大多喜町', 'イスミグンオオタキマチ', '上原西部田柳原入会', 'ウエバラニシベタヤナバライリアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県夷隅郡大多喜町横山', '12', '12441', '2980206', '千葉県', 'チバケン', '夷隅郡大多喜町', 'イスミグンオオタキマチ', '横山', 'ヨコヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県夷隅郡大多喜町泉水', '12', '12441', '2980207', '千葉県', 'チバケン', '夷隅郡大多喜町', 'イスミグンオオタキマチ', '泉水', 'センズイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県夷隅郡大多喜町紺屋', '12', '12441', '2980211', '千葉県', 'チバケン', '夷隅郡大多喜町', 'イスミグンオオタキマチ', '紺屋', 'コウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県夷隅郡大多喜町猿稲', '12', '12441', '2980212', '千葉県', 'チバケン', '夷隅郡大多喜町', 'イスミグンオオタキマチ', '猿稲', 'サルイネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県夷隅郡大多喜町桜台', '12', '12441', '2980213', '千葉県', 'チバケン', '夷隅郡大多喜町', 'イスミグンオオタキマチ', '桜台', 'サクラダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県夷隅郡大多喜町新丁', '12', '12441', '2980214', '千葉県', 'チバケン', '夷隅郡大多喜町', 'イスミグンオオタキマチ', '新丁', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県夷隅郡大多喜町久保', '12', '12441', '2980215', '千葉県', 'チバケン', '夷隅郡大多喜町', 'イスミグンオオタキマチ', '久保', 'クボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県夷隅郡大多喜町大多喜', '12', '12441', '2980216', '千葉県', 'チバケン', '夷隅郡大多喜町', 'イスミグンオオタキマチ', '大多喜', 'オオタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県夷隅郡大多喜町田丁', '12', '12441', '2980217', '千葉県', 'チバケン', '夷隅郡大多喜町', 'イスミグンオオタキマチ', '田丁', 'タマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県夷隅郡大多喜町柳原', '12', '12441', '2980221', '千葉県', 'チバケン', '夷隅郡大多喜町', 'イスミグンオオタキマチ', '柳原', 'ヤナバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県夷隅郡大多喜町八声', '12', '12441', '2980222', '千葉県', 'チバケン', '夷隅郡大多喜町', 'イスミグンオオタキマチ', '八声', 'ヤコエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県夷隅郡大多喜町上原', '12', '12441', '2980223', '千葉県', 'チバケン', '夷隅郡大多喜町', 'イスミグンオオタキマチ', '上原', 'ウエバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県夷隅郡大多喜町堀之内', '12', '12441', '2980224', '千葉県', 'チバケン', '夷隅郡大多喜町', 'イスミグンオオタキマチ', '堀之内', 'ホリノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県夷隅郡大多喜町大戸', '12', '12441', '2980225', '千葉県', 'チバケン', '夷隅郡大多喜町', 'イスミグンオオタキマチ', '大戸', 'オオト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県夷隅郡大多喜町部田', '12', '12441', '2980226', '千葉県', 'チバケン', '夷隅郡大多喜町', 'イスミグンオオタキマチ', '部田', 'ヘタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県夷隅郡大多喜町西部田', '12', '12441', '2980227', '千葉県', 'チバケン', '夷隅郡大多喜町', 'イスミグンオオタキマチ', '西部田', 'ニシベタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県夷隅郡大多喜町小谷松', '12', '12441', '2980228', '千葉県', 'チバケン', '夷隅郡大多喜町', 'イスミグンオオタキマチ', '小谷松', 'コヤマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県夷隅郡大多喜町馬場内', '12', '12441', '2980231', '千葉県', 'チバケン', '夷隅郡大多喜町', 'イスミグンオオタキマチ', '馬場内', 'ババウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県夷隅郡大多喜町小内', '12', '12441', '2980232', '千葉県', 'チバケン', '夷隅郡大多喜町', 'イスミグンオオタキマチ', '小内', 'コウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県夷隅郡大多喜町笛倉', '12', '12441', '2980233', '千葉県', 'チバケン', '夷隅郡大多喜町', 'イスミグンオオタキマチ', '笛倉', 'フエグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県夷隅郡大多喜町押沼', '12', '12441', '2980234', '千葉県', 'チバケン', '夷隅郡大多喜町', 'イスミグンオオタキマチ', '押沼', 'オシヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県夷隅郡大多喜町宇筒原', '12', '12441', '2980235', '千葉県', 'チバケン', '夷隅郡大多喜町', 'イスミグンオオタキマチ', '宇筒原', 'ウトウバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県夷隅郡大多喜町百鉾', '12', '12441', '2980236', '千葉県', 'チバケン', '夷隅郡大多喜町', 'イスミグンオオタキマチ', '百鉾', 'モフク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県夷隅郡大多喜町原内', '12', '12441', '2980237', '千葉県', 'チバケン', '夷隅郡大多喜町', 'イスミグンオオタキマチ', '原内', 'ハラウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県夷隅郡大多喜町小内笛倉入会', '12', '12441', '2980238', '千葉県', 'チバケン', '夷隅郡大多喜町', 'イスミグンオオタキマチ', '小内笛倉入会', 'コウチフエグライリアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県夷隅郡大多喜町紙敷', '12', '12441', '2980241', '千葉県', 'チバケン', '夷隅郡大多喜町', 'イスミグンオオタキマチ', '紙敷', 'カミシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県夷隅郡大多喜町小苗', '12', '12441', '2980242', '千葉県', 'チバケン', '夷隅郡大多喜町', 'イスミグンオオタキマチ', '小苗', 'コミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県夷隅郡大多喜町湯倉', '12', '12441', '2980243', '千葉県', 'チバケン', '夷隅郡大多喜町', 'イスミグンオオタキマチ', '湯倉', 'ユグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県夷隅郡大多喜町松尾', '12', '12441', '2980244', '千葉県', 'チバケン', '夷隅郡大多喜町', 'イスミグンオオタキマチ', '松尾', 'マツオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県夷隅郡大多喜町弥喜用', '12', '12441', '2980245', '千葉県', 'チバケン', '夷隅郡大多喜町', 'イスミグンオオタキマチ', '弥喜用', 'ヤキヨウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県夷隅郡大多喜町庄司', '12', '12441', '2980246', '千葉県', 'チバケン', '夷隅郡大多喜町', 'イスミグンオオタキマチ', '庄司', 'ショウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県夷隅郡大多喜町久我原', '12', '12441', '2980251', '千葉県', 'チバケン', '夷隅郡大多喜町', 'イスミグンオオタキマチ', '久我原', 'クガハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県夷隅郡大多喜町三又', '12', '12441', '2980252', '千葉県', 'チバケン', '夷隅郡大多喜町', 'イスミグンオオタキマチ', '三又', 'ミマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県夷隅郡大多喜町川畑', '12', '12441', '2980253', '千葉県', 'チバケン', '夷隅郡大多喜町', 'イスミグンオオタキマチ', '川畑', 'カワハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県夷隅郡大多喜町平沢', '12', '12441', '2980254', '千葉県', 'チバケン', '夷隅郡大多喜町', 'イスミグンオオタキマチ', '平沢', 'ヒラサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県夷隅郡大多喜町黒原', '12', '12441', '2980255', '千葉県', 'チバケン', '夷隅郡大多喜町', 'イスミグンオオタキマチ', '黒原', 'クロハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県夷隅郡大多喜町石神', '12', '12441', '2980256', '千葉県', 'チバケン', '夷隅郡大多喜町', 'イスミグンオオタキマチ', '石神', 'イシガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県夷隅郡大多喜町板谷', '12', '12441', '2980261', '千葉県', 'チバケン', '夷隅郡大多喜町', 'イスミグンオオタキマチ', '板谷', 'イタヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県夷隅郡大多喜町堀切', '12', '12441', '2980262', '千葉県', 'チバケン', '夷隅郡大多喜町', 'イスミグンオオタキマチ', '堀切', 'ホリキリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県夷隅郡大多喜町伊保田', '12', '12441', '2980263', '千葉県', 'チバケン', '夷隅郡大多喜町', 'イスミグンオオタキマチ', '伊保田', 'イホタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県夷隅郡大多喜町大田代', '12', '12441', '2980264', '千葉県', 'チバケン', '夷隅郡大多喜町', 'イスミグンオオタキマチ', '大田代', 'オオタダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県夷隅郡大多喜町小田代', '12', '12441', '2980265', '千葉県', 'チバケン', '夷隅郡大多喜町', 'イスミグンオオタキマチ', '小田代', 'コタダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県夷隅郡大多喜町筒森', '12', '12441', '2980266', '千葉県', 'チバケン', '夷隅郡大多喜町', 'イスミグンオオタキマチ', '筒森', 'ツツモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県夷隅郡大多喜町葛藤', '12', '12441', '2980267', '千葉県', 'チバケン', '夷隅郡大多喜町', 'イスミグンオオタキマチ', '葛藤', 'クズフジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県夷隅郡大多喜町中野', '12', '12441', '2980271', '千葉県', 'チバケン', '夷隅郡大多喜町', 'イスミグンオオタキマチ', '中野', 'ナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県夷隅郡大多喜町市川', '12', '12441', '2980272', '千葉県', 'チバケン', '夷隅郡大多喜町', 'イスミグンオオタキマチ', '市川', 'イチカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県夷隅郡大多喜町三条', '12', '12441', '2980273', '千葉県', 'チバケン', '夷隅郡大多喜町', 'イスミグンオオタキマチ', '三条', 'サンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県夷隅郡大多喜町田代', '12', '12441', '2980274', '千葉県', 'チバケン', '夷隅郡大多喜町', 'イスミグンオオタキマチ', '田代', 'タシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県夷隅郡大多喜町弓木', '12', '12441', '2980275', '千葉県', 'チバケン', '夷隅郡大多喜町', 'イスミグンオオタキマチ', '弓木', 'ユミギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県夷隅郡大多喜町会所', '12', '12441', '2980276', '千葉県', 'チバケン', '夷隅郡大多喜町', 'イスミグンオオタキマチ', '会所', 'カイショ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県夷隅郡大多喜町粟又', '12', '12441', '2980277', '千葉県', 'チバケン', '夷隅郡大多喜町', 'イスミグンオオタキマチ', '粟又', 'アワマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県夷隅郡大多喜町小沢又', '12', '12441', '2980278', '千葉県', 'チバケン', '夷隅郡大多喜町', 'イスミグンオオタキマチ', '小沢又', 'コザワマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県夷隅郡大多喜町面白', '12', '12441', '2980279', '千葉県', 'チバケン', '夷隅郡大多喜町', 'イスミグンオオタキマチ', '面白', 'オモジロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市青柳北', '12', '12219', '2990101', '千葉県', 'チバケン', '市原市', 'イチハラシ', '青柳北', 'アオヤギキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市青柳', '12', '12219', '2990102', '千葉県', 'チバケン', '市原市', 'イチハラシ', '青柳', 'アオヤギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市青柳海岸', '12', '12219', '2990103', '千葉県', 'チバケン', '市原市', 'イチハラシ', '青柳海岸', 'アオヤギカイガン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市白塚', '12', '12219', '2990104', '千葉県', 'チバケン', '市原市', 'イチハラシ', '白塚', 'シラツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市柏原', '12', '12219', '2990105', '千葉県', 'チバケン', '市原市', 'イチハラシ', '柏原', 'カシワバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市今津朝山', '12', '12219', '2990106', '千葉県', 'チバケン', '市原市', 'イチハラシ', '今津朝山', 'イマヅアサヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市姉崎海岸', '12', '12219', '2990107', '千葉県', 'チバケン', '市原市', 'イチハラシ', '姉崎海岸', 'アネサキカイガン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市千種海岸', '12', '12219', '2990108', '千葉県', 'チバケン', '市原市', 'イチハラシ', '千種海岸', 'チグサカイガン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市千種', '12', '12219', '2990109', '千葉県', 'チバケン', '市原市', 'イチハラシ', '千種', 'チグサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市姉崎', '12', '12219', '2990111', '千葉県', 'チバケン', '市原市', 'イチハラシ', '姉崎', 'アネサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市畑木', '12', '12219', '2990112', '千葉県', 'チバケン', '市原市', 'イチハラシ', '畑木', 'ハタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市片又木', '12', '12219', '2990113', '千葉県', 'チバケン', '市原市', 'イチハラシ', '片又木', 'カタマタギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市泉台', '12', '12219', '2990114', '千葉県', 'チバケン', '市原市', 'イチハラシ', '泉台', 'イズミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市不入斗', '12', '12219', '2990115', '千葉県', 'チバケン', '市原市', 'イチハラシ', '不入斗', 'イリヤマズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市迎田', '12', '12219', '2990116', '千葉県', 'チバケン', '市原市', 'イチハラシ', '迎田', 'ムカエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市青葉台', '12', '12219', '2990117', '千葉県', 'チバケン', '市原市', 'イチハラシ', '青葉台', 'アオバダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市椎津', '12', '12219', '2990118', '千葉県', 'チバケン', '市原市', 'イチハラシ', '椎津', 'シイヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市立野', '12', '12219', '2990121', '千葉県', 'チバケン', '市原市', 'イチハラシ', '立野', 'タテノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市豊成', '12', '12219', '2990122', '千葉県', 'チバケン', '市原市', 'イチハラシ', '豊成', 'トヨナリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市深城', '12', '12219', '2990123', '千葉県', 'チバケン', '市原市', 'イチハラシ', '深城', 'フカシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市有秋台東', '12', '12219', '2990124', '千葉県', 'チバケン', '市原市', 'イチハラシ', '有秋台東', 'ユウシュウダイヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市有秋台西', '12', '12219', '2990125', '千葉県', 'チバケン', '市原市', 'イチハラシ', '有秋台西', 'ユウシュウダイニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市天羽田', '12', '12219', '2990126', '千葉県', 'チバケン', '市原市', 'イチハラシ', '天羽田', 'アモウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市桜台', '12', '12219', '2990127', '千葉県', 'チバケン', '市原市', 'イチハラシ', '桜台', 'サクラダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県市原市椎の木台', '12', '12219', '2990128', '千葉県', 'チバケン', '市原市', 'イチハラシ', '椎の木台', 'シイノキダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県袖ケ浦市', '12', '12229', '2990200', '千葉県', 'チバケン', '袖ケ浦市', 'ソデガウラシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('19600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県袖ケ浦市川原井', '12', '12229', '2990201', '千葉県', 'チバケン', '袖ケ浦市', 'ソデガウラシ', '川原井', 'カワハライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県袖ケ浦市林', '12', '12229', '2990202', '千葉県', 'チバケン', '袖ケ浦市', 'ソデガウラシ', '林', 'ハヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県袖ケ浦市高谷', '12', '12229', '2990203', '千葉県', 'チバケン', '袖ケ浦市', 'ソデガウラシ', '高谷', 'タカヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県袖ケ浦市永吉', '12', '12229', '2990204', '千葉県', 'チバケン', '袖ケ浦市', 'ソデガウラシ', '永吉', 'ナガヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県袖ケ浦市上泉', '12', '12229', '2990205', '千葉県', 'チバケン', '袖ケ浦市', 'ソデガウラシ', '上泉', 'カミイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県袖ケ浦市野里', '12', '12229', '2990211', '千葉県', 'チバケン', '袖ケ浦市', 'ソデガウラシ', '野里', 'ノザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県袖ケ浦市三箇', '12', '12229', '2990212', '千葉県', 'チバケン', '袖ケ浦市', 'ソデガウラシ', '三箇', 'サンガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県袖ケ浦市百目木', '12', '12229', '2990213', '千葉県', 'チバケン', '袖ケ浦市', 'ソデガウラシ', '百目木', 'ドウメキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県袖ケ浦市下根岸', '12', '12229', '2990214', '千葉県', 'チバケン', '袖ケ浦市', 'ソデガウラシ', '下根岸', 'シモネギシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県袖ケ浦市堂谷', '12', '12229', '2990215', '千葉県', 'チバケン', '袖ケ浦市', 'ソデガウラシ', '堂谷', 'ドウヤツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県袖ケ浦市阿部', '12', '12229', '2990216', '千葉県', 'チバケン', '袖ケ浦市', 'ソデガウラシ', '阿部', 'アベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県袖ケ浦市打越', '12', '12229', '2990217', '千葉県', 'チバケン', '袖ケ浦市', 'ソデガウラシ', '打越', 'ウチコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県袖ケ浦市大竹', '12', '12229', '2990221', '千葉県', 'チバケン', '袖ケ浦市', 'ソデガウラシ', '大竹', 'オオダケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県袖ケ浦市上宮田', '12', '12229', '2990222', '千葉県', 'チバケン', '袖ケ浦市', 'ソデガウラシ', '上宮田', 'カミミヤダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県袖ケ浦市下宮田', '12', '12229', '2990223', '千葉県', 'チバケン', '袖ケ浦市', 'ソデガウラシ', '下宮田', 'シモミヤダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県袖ケ浦市吉野田', '12', '12229', '2990224', '千葉県', 'チバケン', '袖ケ浦市', 'ソデガウラシ', '吉野田', 'ヨシノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県袖ケ浦市玉野', '12', '12229', '2990225', '千葉県', 'チバケン', '袖ケ浦市', 'ソデガウラシ', '玉野', 'タマノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県袖ケ浦市滝の口', '12', '12229', '2990226', '千葉県', 'チバケン', '袖ケ浦市', 'ソデガウラシ', '滝の口', 'タキノクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県袖ケ浦市下泉', '12', '12229', '2990231', '千葉県', 'チバケン', '袖ケ浦市', 'ソデガウラシ', '下泉', 'シモイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県袖ケ浦市永地', '12', '12229', '2990232', '千葉県', 'チバケン', '袖ケ浦市', 'ソデガウラシ', '永地', 'エイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県袖ケ浦市岩井', '12', '12229', '2990233', '千葉県', 'チバケン', '袖ケ浦市', 'ソデガウラシ', '岩井', 'イワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県袖ケ浦市谷中', '12', '12229', '2990234', '千葉県', 'チバケン', '袖ケ浦市', 'ソデガウラシ', '谷中', 'ヤナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県袖ケ浦市三黒', '12', '12229', '2990235', '千葉県', 'チバケン', '袖ケ浦市', 'ソデガウラシ', '三黒', 'ミクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県袖ケ浦市横田', '12', '12229', '2990236', '千葉県', 'チバケン', '袖ケ浦市', 'ソデガウラシ', '横田', 'ヨコタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県袖ケ浦市大鳥居', '12', '12229', '2990237', '千葉県', 'チバケン', '袖ケ浦市', 'ソデガウラシ', '大鳥居', 'オオドリイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県袖ケ浦市代宿', '12', '12229', '2990241', '千葉県', 'チバケン', '袖ケ浦市', 'ソデガウラシ', '代宿', 'ダイジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県袖ケ浦市久保田', '12', '12229', '2990242', '千葉県', 'チバケン', '袖ケ浦市', 'ソデガウラシ', '久保田', 'クボタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県袖ケ浦市蔵波', '12', '12229', '2990243', '千葉県', 'チバケン', '袖ケ浦市', 'ソデガウラシ', '蔵波', 'クラナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県袖ケ浦市野田', '12', '12229', '2990244', '千葉県', 'チバケン', '袖ケ浦市', 'ソデガウラシ', '野田', 'ノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県袖ケ浦市蔵波台', '12', '12229', '2990245', '千葉県', 'チバケン', '袖ケ浦市', 'ソデガウラシ', '蔵波台', 'クラナミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県袖ケ浦市長浦駅前', '12', '12229', '2990246', '千葉県', 'チバケン', '袖ケ浦市', 'ソデガウラシ', '長浦駅前', 'ナガウラエキマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県袖ケ浦市椎の森', '12', '12229', '2990247', '千葉県', 'チバケン', '袖ケ浦市', 'ソデガウラシ', '椎の森', 'シイノモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県袖ケ浦市のぞみ野', '12', '12229', '2990251', '千葉県', 'チバケン', '袖ケ浦市', 'ソデガウラシ', 'のぞみ野', 'ノゾミノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県袖ケ浦市勝', '12', '12229', '2990252', '千葉県', 'チバケン', '袖ケ浦市', 'ソデガウラシ', '勝', 'カツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県袖ケ浦市大曽根', '12', '12229', '2990253', '千葉県', 'チバケン', '袖ケ浦市', 'ソデガウラシ', '大曽根', 'オゾネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県袖ケ浦市三ツ作', '12', '12229', '2990254', '千葉県', 'チバケン', '袖ケ浦市', 'ソデガウラシ', '三ツ作', 'ミツザク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県袖ケ浦市下新田', '12', '12229', '2990255', '千葉県', 'チバケン', '袖ケ浦市', 'ソデガウラシ', '下新田', 'シモニッタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県袖ケ浦市飯富', '12', '12229', '2990256', '千葉県', 'チバケン', '袖ケ浦市', 'ソデガウラシ', '飯富', 'イイトミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県袖ケ浦市神納', '12', '12229', '2990257', '千葉県', 'チバケン', '袖ケ浦市', 'ソデガウラシ', '神納', 'カンノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県袖ケ浦市福王台', '12', '12229', '2990261', '千葉県', 'チバケン', '袖ケ浦市', 'ソデガウラシ', '福王台', 'フクオウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県袖ケ浦市坂戸市場', '12', '12229', '2990262', '千葉県', 'チバケン', '袖ケ浦市', 'ソデガウラシ', '坂戸市場', 'サカドイチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県袖ケ浦市奈良輪', '12', '12229', '2990263', '千葉県', 'チバケン', '袖ケ浦市', 'ソデガウラシ', '奈良輪', 'ナラワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県袖ケ浦市今井', '12', '12229', '2990264', '千葉県', 'チバケン', '袖ケ浦市', 'ソデガウラシ', '今井', 'イマイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県袖ケ浦市長浦', '12', '12229', '2990265', '千葉県', 'チバケン', '袖ケ浦市', 'ソデガウラシ', '長浦', 'ナガウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県袖ケ浦市北袖', '12', '12229', '2990266', '千葉県', 'チバケン', '袖ケ浦市', 'ソデガウラシ', '北袖', 'キタソデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県袖ケ浦市中袖', '12', '12229', '2990267', '千葉県', 'チバケン', '袖ケ浦市', 'ソデガウラシ', '中袖', 'ナカソデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県袖ケ浦市南袖', '12', '12229', '2990268', '千葉県', 'チバケン', '袖ケ浦市', 'ソデガウラシ', '南袖', 'ミナミソデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県木更津市坂戸市場', '12', '12206', '2990271', '千葉県', 'チバケン', '木更津市', 'キサラヅシ', '坂戸市場', 'サカドイチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市', '12', '12225', '2991100', '千葉県', 'チバケン', '君津市', 'キミツシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('19655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市大鷲新田', '12', '12225', '2991101', '千葉県', 'チバケン', '君津市', 'キミツシ', '大鷲新田', 'オオワシシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市大鷲', '12', '12225', '2991102', '千葉県', 'チバケン', '君津市', 'キミツシ', '大鷲', 'オオワシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市大井', '12', '12225', '2991103', '千葉県', 'チバケン', '君津市', 'キミツシ', '大井', 'オオイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市糠田', '12', '12225', '2991104', '千葉県', 'チバケン', '君津市', 'キミツシ', '糠田', 'ヌカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市白駒', '12', '12225', '2991105', '千葉県', 'チバケン', '君津市', 'キミツシ', '白駒', 'シロコマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市中島', '12', '12225', '2991106', '千葉県', 'チバケン', '君津市', 'キミツシ', '中島', 'ナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市上', '12', '12225', '2991107', '千葉県', 'チバケン', '君津市', 'キミツシ', '上', 'カミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市練木', '12', '12225', '2991108', '千葉県', 'チバケン', '君津市', 'キミツシ', '練木', 'ネリキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市六手', '12', '12225', '2991111', '千葉県', 'チバケン', '君津市', 'キミツシ', '六手', 'ムテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市泉', '12', '12225', '2991112', '千葉県', 'チバケン', '君津市', 'キミツシ', '泉', 'イズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市尾車', '12', '12225', '2991113', '千葉県', 'チバケン', '君津市', 'キミツシ', '尾車', 'ビシャ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市草牛', '12', '12225', '2991114', '千葉県', 'チバケン', '君津市', 'キミツシ', '草牛', 'ソウギュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市馬登', '12', '12225', '2991115', '千葉県', 'チバケン', '君津市', 'キミツシ', '馬登', 'マノボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市皿引', '12', '12225', '2991116', '千葉県', 'チバケン', '君津市', 'キミツシ', '皿引', 'サラヒキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市宮下', '12', '12225', '2991117', '千葉県', 'チバケン', '君津市', 'キミツシ', '宮下', 'ミヤノシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市常代', '12', '12225', '2991121', '千葉県', 'チバケン', '君津市', 'キミツシ', '常代', 'トコシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市浜子', '12', '12225', '2991122', '千葉県', 'チバケン', '君津市', 'キミツシ', '浜子', 'ハマゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市大山野', '12', '12225', '2991123', '千葉県', 'チバケン', '君津市', 'キミツシ', '大山野', 'オオヤマノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市作木', '12', '12225', '2991124', '千葉県', 'チバケン', '君津市', 'キミツシ', '作木', 'ツクリキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市山高原', '12', '12225', '2991125', '千葉県', 'チバケン', '君津市', 'キミツシ', '山高原', 'ヤマタカハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市小山野', '12', '12225', '2991126', '千葉県', 'チバケン', '君津市', 'キミツシ', '小山野', 'コヤマノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市郡', '12', '12225', '2991127', '千葉県', 'チバケン', '君津市', 'キミツシ', '郡', 'コオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市下湯江', '12', '12225', '2991131', '千葉県', 'チバケン', '君津市', 'キミツシ', '下湯江', 'シモユエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市中富', '12', '12225', '2991132', '千葉県', 'チバケン', '君津市', 'キミツシ', '中富', 'ナカトミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市貞元', '12', '12225', '2991133', '千葉県', 'チバケン', '君津市', 'キミツシ', '貞元', 'サダモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市八幡', '12', '12225', '2991134', '千葉県', 'チバケン', '君津市', 'キミツシ', '八幡', 'ヤワタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市杉谷', '12', '12225', '2991135', '千葉県', 'チバケン', '君津市', 'キミツシ', '杉谷', 'スギヤツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市新御堂', '12', '12225', '2991136', '千葉県', 'チバケン', '君津市', 'キミツシ', '新御堂', 'シミドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市小香', '12', '12225', '2991137', '千葉県', 'チバケン', '君津市', 'キミツシ', '小香', 'ショウコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市上湯江', '12', '12225', '2991138', '千葉県', 'チバケン', '君津市', 'キミツシ', '上湯江', 'カミユエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市君津', '12', '12225', '2991141', '千葉県', 'チバケン', '君津市', 'キミツシ', '君津', 'キミツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市坂田', '12', '12225', '2991142', '千葉県', 'チバケン', '君津市', 'キミツシ', '坂田', 'サカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市君津台', '12', '12225', '2991143', '千葉県', 'チバケン', '君津市', 'キミツシ', '君津台', 'キミツダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市東坂田', '12', '12225', '2991144', '千葉県', 'チバケン', '君津市', 'キミツシ', '東坂田', 'ヒガシサカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市西坂田', '12', '12225', '2991145', '千葉県', 'チバケン', '君津市', 'キミツシ', '西坂田', 'ニシサカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市大和田', '12', '12225', '2991146', '千葉県', 'チバケン', '君津市', 'キミツシ', '大和田', 'オオワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市人見', '12', '12225', '2991147', '千葉県', 'チバケン', '君津市', 'キミツシ', '人見', 'ヒトミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市中野', '12', '12225', '2991151', '千葉県', 'チバケン', '君津市', 'キミツシ', '中野', 'ナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市久保', '12', '12225', '2991152', '千葉県', 'チバケン', '君津市', 'キミツシ', '久保', 'クボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市台', '12', '12225', '2991153', '千葉県', 'チバケン', '君津市', 'キミツシ', '台', 'ダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市南久保', '12', '12225', '2991154', '千葉県', 'チバケン', '君津市', 'キミツシ', '南久保', 'ミナミクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市北子安', '12', '12225', '2991161', '千葉県', 'チバケン', '君津市', 'キミツシ', '北子安', 'キタコヤス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市南子安', '12', '12225', '2991162', '千葉県', 'チバケン', '君津市', 'キミツシ', '南子安', 'ミナミコヤス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市杢師', '12', '12225', '2991163', '千葉県', 'チバケン', '君津市', 'キミツシ', '杢師', 'モクシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市北久保', '12', '12225', '2991164', '千葉県', 'チバケン', '君津市', 'キミツシ', '北久保', 'キタクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市高坂', '12', '12225', '2991165', '千葉県', 'チバケン', '君津市', 'キミツシ', '高坂', 'コウサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市陽光台', '12', '12225', '2991166', '千葉県', 'チバケン', '君津市', 'キミツシ', '陽光台', 'ヨウコウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市八重原', '12', '12225', '2991171', '千葉県', 'チバケン', '君津市', 'キミツシ', '八重原', 'ヤエハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市三直', '12', '12225', '2991172', '千葉県', 'チバケン', '君津市', 'キミツシ', '三直', 'ミノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市外箕輪', '12', '12225', '2991173', '千葉県', 'チバケン', '君津市', 'キミツシ', '外箕輪', 'ソトミノワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市法木作', '12', '12225', '2991174', '千葉県', 'チバケン', '君津市', 'キミツシ', '法木作', 'ホウギサク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市内箕輪', '12', '12225', '2991175', '千葉県', 'チバケン', '君津市', 'キミツシ', '内箕輪', 'ウチミノワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県君津市内蓑輪', '12', '12225', '2991176', '千葉県', 'チバケン', '君津市', 'キミツシ', '内蓑輪', 'ウチミノワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県富津市桜井総稱鬼泪山', '12', '12226', '2991601', '千葉県', 'チバケン', '富津市', 'フッツシ', '桜井総稱鬼泪山', 'サクライソウショウキナダヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県富津市桜井', '12', '12226', '2991602', '千葉県', 'チバケン', '富津市', 'フッツシ', '桜井', 'サクライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県富津市更和', '12', '12226', '2991603', '千葉県', 'チバケン', '富津市', 'フッツシ', '更和', 'サラワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県富津市台原', '12', '12226', '2991604', '千葉県', 'チバケン', '富津市', 'フッツシ', '台原', 'ダイバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県富津市望井', '12', '12226', '2991605', '千葉県', 'チバケン', '富津市', 'フッツシ', '望井', 'モチイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県富津市数馬', '12', '12226', '2991606', '千葉県', 'チバケン', '富津市', 'フッツシ', '数馬', 'カズマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県富津市湊', '12', '12226', '2991607', '千葉県', 'チバケン', '富津市', 'フッツシ', '湊', 'ミナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県富津市岩坂', '12', '12226', '2991608', '千葉県', 'チバケン', '富津市', 'フッツシ', '岩坂', 'イワサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県富津市加藤', '12', '12226', '2991609', '千葉県', 'チバケン', '富津市', 'フッツシ', '加藤', 'カトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県富津市長崎', '12', '12226', '2991611', '千葉県', 'チバケン', '富津市', 'フッツシ', '長崎', 'ナガサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県富津市横山', '12', '12226', '2991612', '千葉県', 'チバケン', '富津市', 'フッツシ', '横山', 'ヨコヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県富津市不入斗', '12', '12226', '2991613', '千葉県', 'チバケン', '富津市', 'フッツシ', '不入斗', 'イリヤマズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県富津市梨沢', '12', '12226', '2991614', '千葉県', 'チバケン', '富津市', 'フッツシ', '梨沢', 'ナシザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県富津市相川', '12', '12226', '2991615', '千葉県', 'チバケン', '富津市', 'フッツシ', '相川', 'アイカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県富津市海良', '12', '12226', '2991616', '千葉県', 'チバケン', '富津市', 'フッツシ', '海良', 'カイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県富津市売津', '12', '12226', '2991617', '千葉県', 'チバケン', '富津市', 'フッツシ', '売津', 'ウルヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県富津市花輪', '12', '12226', '2991618', '千葉県', 'チバケン', '富津市', 'フッツシ', '花輪', 'ハナワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県富津市竹岡', '12', '12226', '2991621', '千葉県', 'チバケン', '富津市', 'フッツシ', '竹岡', 'タケオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県富津市萩生', '12', '12226', '2991622', '千葉県', 'チバケン', '富津市', 'フッツシ', '萩生', 'ハギウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県富津市田倉', '12', '12226', '2991731', '千葉県', 'チバケン', '富津市', 'フッツシ', '田倉', 'タグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県富津市宇藤原', '12', '12226', '2991732', '千葉県', 'チバケン', '富津市', 'フッツシ', '宇藤原', 'ウトウバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県富津市高溝', '12', '12226', '2991733', '千葉県', 'チバケン', '富津市', 'フッツシ', '高溝', 'タカミゾ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県富津市関', '12', '12226', '2991734', '千葉県', 'チバケン', '富津市', 'フッツシ', '関', 'セキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県富津市大田和', '12', '12226', '2991735', '千葉県', 'チバケン', '富津市', 'フッツシ', '大田和', 'オオタワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県富津市大川崎', '12', '12226', '2991736', '千葉県', 'チバケン', '富津市', 'フッツシ', '大川崎', 'オオガワサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県富津市東大和田', '12', '12226', '2991737', '千葉県', 'チバケン', '富津市', 'フッツシ', '東大和田', 'ヒガシオオワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県富津市御代原', '12', '12226', '2991741', '千葉県', 'チバケン', '富津市', 'フッツシ', '御代原', 'ミヨバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県富津市豊岡', '12', '12226', '2991742', '千葉県', 'チバケン', '富津市', 'フッツシ', '豊岡', 'トヨオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県富津市山中', '12', '12226', '2991743', '千葉県', 'チバケン', '富津市', 'フッツシ', '山中', 'ヤマナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県富津市梨沢東井戸堀', '12', '12226', '2991744', '千葉県', 'チバケン', '富津市', 'フッツシ', '梨沢', 'ナシザワ', null, null, '東井戸堀', 'ヒガシイドボリ');
INSERT INTO `ms_addresses` VALUES ('19742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県富津市志駒', '12', '12226', '2991745', '千葉県', 'チバケン', '富津市', 'フッツシ', '志駒', 'シコマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県富津市岩本', '12', '12226', '2991746', '千葉県', 'チバケン', '富津市', 'フッツシ', '岩本', 'イワモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県富津市小志駒', '12', '12226', '2991747', '千葉県', 'チバケン', '富津市', 'フッツシ', '小志駒', 'コジコマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県富津市恩田', '12', '12226', '2991751', '千葉県', 'チバケン', '富津市', 'フッツシ', '恩田', 'オンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県富津市関尻', '12', '12226', '2991752', '千葉県', 'チバケン', '富津市', 'フッツシ', '関尻', 'セキジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県富津市上後', '12', '12226', '2991753', '千葉県', 'チバケン', '富津市', 'フッツシ', '上後', 'ウエゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県富津市山脇', '12', '12226', '2991754', '千葉県', 'チバケン', '富津市', 'フッツシ', '山脇', 'ヤマワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県富津市田原', '12', '12226', '2991755', '千葉県', 'チバケン', '富津市', 'フッツシ', '田原', 'タバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県富津市六野', '12', '12226', '2991756', '千葉県', 'チバケン', '富津市', 'フッツシ', '六野', 'ムツノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県富津市押切', '12', '12226', '2991757', '千葉県', 'チバケン', '富津市', 'フッツシ', '押切', 'オシキリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県富津市大森', '12', '12226', '2991758', '千葉県', 'チバケン', '富津市', 'フッツシ', '大森', 'オオモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県富津市寺尾', '12', '12226', '2991759', '千葉県', 'チバケン', '富津市', 'フッツシ', '寺尾', 'テラオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県富津市金谷', '12', '12226', '2991861', '千葉県', 'チバケン', '富津市', 'フッツシ', '金谷', 'カナヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県安房郡鋸南町元名', '12', '12463', '2991901', '千葉県', 'チバケン', '安房郡鋸南町', 'アワグンキョナンマチ', '元名', 'モトナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県安房郡鋸南町保田', '12', '12463', '2991902', '千葉県', 'チバケン', '安房郡鋸南町', 'アワグンキョナンマチ', '保田', 'ホタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県安房郡鋸南町大帷子', '12', '12463', '2991903', '千葉県', 'チバケン', '安房郡鋸南町', 'アワグンキョナンマチ', '大帷子', 'オオカタビラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県安房郡鋸南町小保田', '12', '12463', '2991904', '千葉県', 'チバケン', '安房郡鋸南町', 'アワグンキョナンマチ', '小保田', 'コボタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県安房郡鋸南町市井原', '12', '12463', '2991905', '千葉県', 'チバケン', '安房郡鋸南町', 'アワグンキョナンマチ', '市井原', 'イチイバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県安房郡鋸南町横根', '12', '12463', '2991906', '千葉県', 'チバケン', '安房郡鋸南町', 'アワグンキョナンマチ', '横根', 'ヨコネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県安房郡鋸南町江月', '12', '12463', '2991907', '千葉県', 'チバケン', '安房郡鋸南町', 'アワグンキョナンマチ', '江月', 'エヅキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県安房郡鋸南町吉浜', '12', '12463', '2991908', '千葉県', 'チバケン', '安房郡鋸南町', 'アワグンキョナンマチ', '吉浜', 'ヨシハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県安房郡鋸南町大六', '12', '12463', '2991909', '千葉県', 'チバケン', '安房郡鋸南町', 'アワグンキョナンマチ', '大六', 'ダイロク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県安房郡鋸南町', '12', '12463', '2992100', '千葉県', 'チバケン', '安房郡鋸南町', 'アワグンキョナンマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('19765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県安房郡鋸南町大崩', '12', '12463', '2992111', '千葉県', 'チバケン', '安房郡鋸南町', 'アワグンキョナンマチ', '大崩', 'オクズレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県安房郡鋸南町奥山', '12', '12463', '2992112', '千葉県', 'チバケン', '安房郡鋸南町', 'アワグンキョナンマチ', '奥山', 'オクヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県安房郡鋸南町上佐久間', '12', '12463', '2992113', '千葉県', 'チバケン', '安房郡鋸南町', 'アワグンキョナンマチ', '上佐久間', 'カミサクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県安房郡鋸南町中佐久間', '12', '12463', '2992114', '千葉県', 'チバケン', '安房郡鋸南町', 'アワグンキョナンマチ', '中佐久間', 'ナカサクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県安房郡鋸南町下佐久間', '12', '12463', '2992115', '千葉県', 'チバケン', '安房郡鋸南町', 'アワグンキョナンマチ', '下佐久間', 'シモサクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県安房郡鋸南町岩井袋', '12', '12463', '2992116', '千葉県', 'チバケン', '安房郡鋸南町', 'アワグンキョナンマチ', '岩井袋', 'イワイフクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県安房郡鋸南町勝山', '12', '12463', '2992117', '千葉県', 'チバケン', '安房郡鋸南町', 'アワグンキョナンマチ', '勝山', 'カツヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県安房郡鋸南町竜島', '12', '12463', '2992118', '千葉県', 'チバケン', '安房郡鋸南町', 'アワグンキョナンマチ', '竜島', 'リュウシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市荒川', '12', '12234', '2992201', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '荒川', 'アラカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市平塚', '12', '12234', '2992202', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '平塚', 'ヒラツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市山田', '12', '12234', '2992203', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '山田', 'ヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市平久里中', '12', '12234', '2992204', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '平久里中', 'ヘグリナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市犬掛', '12', '12234', '2992205', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '犬掛', 'イヌカケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市平久里下', '12', '12234', '2992206', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '平久里下', 'ヘグリシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市川上', '12', '12234', '2992211', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '川上', 'カワカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市井野', '12', '12234', '2992212', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '井野', 'イノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市吉沢', '12', '12234', '2992213', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '吉沢', 'ヨシザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市二部', '12', '12234', '2992214', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '二部', 'ニブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市検儀谷', '12', '12234', '2992215', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '検儀谷', 'ケギヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市久枝', '12', '12234', '2992216', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '久枝', 'クシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市合戸', '12', '12234', '2992221', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '合戸', 'ゴウド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市宮谷', '12', '12234', '2992222', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '宮谷', 'ミヤノヤツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市高崎', '12', '12234', '2992223', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '高崎', 'タカサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市小浦', '12', '12234', '2992224', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '小浦', 'コウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市竹内', '12', '12234', '2992225', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '竹内', 'タケノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市市部', '12', '12234', '2992226', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '市部', 'イチブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市', '12', '12234', '2992400', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('19794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市富浦町南無谷', '12', '12234', '2992401', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '富浦町南無谷', 'トミウラチョウナムヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市富浦町豊岡', '12', '12234', '2992402', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '富浦町豊岡', 'トミウラチョウトヨオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市富浦町原岡', '12', '12234', '2992403', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '富浦町原岡', 'トミウラチョウハラオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市富浦町多田良', '12', '12234', '2992404', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '富浦町多田良', 'トミウラチョウタダラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市富浦町居倉', '12', '12234', '2992411', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '富浦町居倉', 'トミウラチョウイグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市富浦町大津', '12', '12234', '2992412', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '富浦町大津', 'トミウラチョウオオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市富浦町宮本', '12', '12234', '2992413', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '富浦町宮本', 'トミウラチョウミヤモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市富浦町福澤', '12', '12234', '2992414', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '富浦町福澤', 'トミウラチョウフクザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市富浦町深名', '12', '12234', '2992415', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '富浦町深名', 'トミウラチョウフカナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市富浦町青木', '12', '12234', '2992416', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '富浦町青木', 'トミウラチョウアオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市富浦町丹生', '12', '12234', '2992417', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '富浦町丹生', 'トミウラチョウニュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市富浦町手取', '12', '12234', '2992418', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '富浦町手取', 'トミウラチョウテドリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市珠師ケ谷', '12', '12234', '2992501', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '珠師ケ谷', 'シュシガヤツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市石堂原', '12', '12234', '2992502', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '石堂原', 'イシドウハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市石堂', '12', '12234', '2992503', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '石堂', 'イシドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市川谷', '12', '12234', '2992504', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '川谷', 'カワヤツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市宮下', '12', '12234', '2992505', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '宮下', 'ミヤシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市御子神', '12', '12234', '2992506', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '御子神', 'ミコガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市大井', '12', '12234', '2992507', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '大井', 'オオイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市丸山平塚', '12', '12234', '2992508', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '丸山平塚', 'マルヤマヒラツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市小戸', '12', '12234', '2992511', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '小戸', 'オド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市岩糸', '12', '12234', '2992512', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '岩糸', 'イワイト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市古川', '12', '12234', '2992513', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '古川', 'フルカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市西原', '12', '12234', '2992514', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '西原', 'ニシバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市石神', '12', '12234', '2992515', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '石神', 'イシガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市前田', '12', '12234', '2992516', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '前田', 'マエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市丸本郷', '12', '12234', '2992517', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '丸本郷', 'マルホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市白子', '12', '12234', '2992521', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '白子', 'シラコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市安馬谷', '12', '12234', '2992522', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '安馬谷', 'アンバヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市峰', '12', '12234', '2992523', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '峰', 'ミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市久保', '12', '12234', '2992524', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '久保', 'クボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市加茂', '12', '12234', '2992525', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '加茂', 'カモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市沓見', '12', '12234', '2992526', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '沓見', 'クツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市和田町花園', '12', '12234', '2992701', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '和田町花園', 'ワダチョウハナソノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市和田町柴', '12', '12234', '2992702', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '和田町柴', 'ワダチョウシバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市和田町仁我浦', '12', '12234', '2992703', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '和田町仁我浦', 'ワダチョウニガウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市和田町和田', '12', '12234', '2992704', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '和田町和田', 'ワダチョウワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市和田町真浦', '12', '12234', '2992705', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '和田町真浦', 'ワダチョウモウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市和田町白渚', '12', '12234', '2992711', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '和田町白渚', 'ワダチョウシラスカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市和田町海発', '12', '12234', '2992712', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '和田町海発', 'ワダチョウカイホツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市和田町松田', '12', '12234', '2992713', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '和田町松田', 'ワダチョウマツダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市和田町沼', '12', '12234', '2992714', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '和田町沼', 'ワダチョウヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市和田町下三原', '12', '12234', '2992715', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '和田町下三原', 'ワダチョウシモミハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市和田町中三原', '12', '12234', '2992716', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '和田町中三原', 'ワダチョウナカミハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市和田町五十蔵', '12', '12234', '2992721', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '和田町五十蔵', 'ワダチョウゴジュウクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市和田町磑森', '12', '12234', '2992722', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '和田町磑森', 'ワダチョウスルスモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市和田町布野', '12', '12234', '2992723', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '和田町布野', 'ワダチョウフノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市和田町小向', '12', '12234', '2992724', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '和田町小向', 'ワダチョウコムカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市和田町黒岩', '12', '12234', '2992725', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '和田町黒岩', 'ワダチョウクロイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市和田町小川', '12', '12234', '2992726', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '和田町小川', 'ワダチョウオガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市和田町上三原', '12', '12234', '2992727', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '和田町上三原', 'ワダチョウカミミハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県南房総市和田町石堂', '12', '12234', '2992728', '千葉県', 'チバケン', '南房総市', 'ミナミボウソウシ', '和田町石堂', 'ワダチョウイシドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鴨川市西江見', '12', '12223', '2992841', '千葉県', 'チバケン', '鴨川市', 'カモガワシ', '西江見', 'ニシエミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鴨川市江見青木', '12', '12223', '2992842', '千葉県', 'チバケン', '鴨川市', 'カモガワシ', '江見青木', 'エミアオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鴨川市東江見', '12', '12223', '2992843', '千葉県', 'チバケン', '鴨川市', 'カモガワシ', '東江見', 'ヒガシエミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鴨川市江見東真門', '12', '12223', '2992844', '千葉県', 'チバケン', '鴨川市', 'カモガワシ', '江見東真門', 'エミヒガシマカド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鴨川市江見西真門', '12', '12223', '2992845', '千葉県', 'チバケン', '鴨川市', 'カモガワシ', '江見西真門', 'エミニシマカド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鴨川市江見外堀', '12', '12223', '2992846', '千葉県', 'チバケン', '鴨川市', 'カモガワシ', '江見外堀', 'エミソトボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鴨川市江見内遠野', '12', '12223', '2992847', '千葉県', 'チバケン', '鴨川市', 'カモガワシ', '江見内遠野', 'エミウトノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鴨川市仲町', '12', '12223', '2992851', '千葉県', 'チバケン', '鴨川市', 'カモガワシ', '仲町', 'ナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鴨川市二子', '12', '12223', '2992852', '千葉県', 'チバケン', '鴨川市', 'カモガワシ', '二子', 'フタゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鴨川市宮', '12', '12223', '2992853', '千葉県', 'チバケン', '鴨川市', 'カモガワシ', '宮', 'ミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鴨川市代', '12', '12223', '2992854', '千葉県', 'チバケン', '鴨川市', 'カモガワシ', '代', 'ダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鴨川市畑', '12', '12223', '2992855', '千葉県', 'チバケン', '鴨川市', 'カモガワシ', '畑', 'ハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鴨川市西', '12', '12223', '2992856', '千葉県', 'チバケン', '鴨川市', 'カモガワシ', '西', 'ニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鴨川市東', '12', '12223', '2992857', '千葉県', 'チバケン', '鴨川市', 'カモガワシ', '東', 'ヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鴨川市上', '12', '12223', '2992858', '千葉県', 'チバケン', '鴨川市', 'カモガワシ', '上', 'カミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鴨川市太海西', '12', '12223', '2992861', '千葉県', 'チバケン', '鴨川市', 'カモガワシ', '太海西', 'フトミニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鴨川市太海', '12', '12223', '2992862', '千葉県', 'チバケン', '鴨川市', 'カモガワシ', '太海', 'フトミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鴨川市太海浜', '12', '12223', '2992863', '千葉県', 'チバケン', '鴨川市', 'カモガワシ', '太海浜', 'フトミハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鴨川市天面', '12', '12223', '2992864', '千葉県', 'チバケン', '鴨川市', 'カモガワシ', '天面', 'アマツラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鴨川市江見太夫崎', '12', '12223', '2992865', '千葉県', 'チバケン', '鴨川市', 'カモガワシ', '江見太夫崎', 'エミタユウザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鴨川市江見吉浦', '12', '12223', '2992866', '千葉県', 'チバケン', '鴨川市', 'カモガワシ', '江見吉浦', 'エミヨシウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鴨川市西山', '12', '12223', '2992867', '千葉県', 'チバケン', '鴨川市', 'カモガワシ', '西山', 'ニシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡大網白里町', '12', '12402', '2993200', '千葉県', 'チバケン', '山武郡大網白里町', 'サンブグンオオアミシラサトマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('19873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡大網白里町北今泉', '12', '12402', '2993201', '千葉県', 'チバケン', '山武郡大網白里町', 'サンブグンオオアミシラサトマチ', '北今泉', 'キタイマイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡大網白里町南今泉', '12', '12402', '2993202', '千葉県', 'チバケン', '山武郡大網白里町', 'サンブグンオオアミシラサトマチ', '南今泉', 'ミナミイマイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡大網白里町四天木', '12', '12402', '2993203', '千葉県', 'チバケン', '山武郡大網白里町', 'サンブグンオオアミシラサトマチ', '四天木', 'シテンギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡大網白里町細草', '12', '12402', '2993211', '千葉県', 'チバケン', '山武郡大網白里町', 'サンブグンオオアミシラサトマチ', '細草', 'ホソクサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡大網白里町清水', '12', '12402', '2993212', '千葉県', 'チバケン', '山武郡大網白里町', 'サンブグンオオアミシラサトマチ', '清水', 'シミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡大網白里町二之袋', '12', '12402', '2993213', '千葉県', 'チバケン', '山武郡大網白里町', 'サンブグンオオアミシラサトマチ', '二之袋', 'ニノフクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡大網白里町下ケ傍示', '12', '12402', '2993214', '千葉県', 'チバケン', '山武郡大網白里町', 'サンブグンオオアミシラサトマチ', '下ケ傍示', 'サゲホウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡大網白里町長国', '12', '12402', '2993215', '千葉県', 'チバケン', '山武郡大網白里町', 'サンブグンオオアミシラサトマチ', '長国', 'ナガクニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡大網白里町北吉田', '12', '12402', '2993216', '千葉県', 'チバケン', '山武郡大網白里町', 'サンブグンオオアミシラサトマチ', '北吉田', 'キタヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡大網白里町木崎', '12', '12402', '2993217', '千葉県', 'チバケン', '山武郡大網白里町', 'サンブグンオオアミシラサトマチ', '木崎', 'キサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡大網白里町北飯塚', '12', '12402', '2993218', '千葉県', 'チバケン', '山武郡大網白里町', 'サンブグンオオアミシラサトマチ', '北飯塚', 'キタイイヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡大網白里町南飯塚', '12', '12402', '2993219', '千葉県', 'チバケン', '山武郡大網白里町', 'サンブグンオオアミシラサトマチ', '南飯塚', 'ミナミイイヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡大網白里町富田', '12', '12402', '2993221', '千葉県', 'チバケン', '山武郡大網白里町', 'サンブグンオオアミシラサトマチ', '富田', 'トミダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡大網白里町星谷', '12', '12402', '2993222', '千葉県', 'チバケン', '山武郡大網白里町', 'サンブグンオオアミシラサトマチ', '星谷', 'ホシヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡大網白里町南横川', '12', '12402', '2993223', '千葉県', 'チバケン', '山武郡大網白里町', 'サンブグンオオアミシラサトマチ', '南横川', 'ミナミヨコカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡大網白里町経田', '12', '12402', '2993231', '千葉県', 'チバケン', '山武郡大網白里町', 'サンブグンオオアミシラサトマチ', '経田', 'キョウデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡大網白里町ながた野', '12', '12402', '2993232', '千葉県', 'チバケン', '山武郡大網白里町', 'サンブグンオオアミシラサトマチ', 'ながた野', 'ナガタノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡大網白里町永田', '12', '12402', '2993233', '千葉県', 'チバケン', '山武郡大網白里町', 'サンブグンオオアミシラサトマチ', '永田', 'ナガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡大網白里町みずほ台', '12', '12402', '2993234', '千葉県', 'チバケン', '山武郡大網白里町', 'サンブグンオオアミシラサトマチ', 'みずほ台', 'ミズホダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡大網白里町駒込', '12', '12402', '2993235', '千葉県', 'チバケン', '山武郡大網白里町', 'サンブグンオオアミシラサトマチ', '駒込', 'コマゴメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡大網白里町みやこ野', '12', '12402', '2993236', '千葉県', 'チバケン', '山武郡大網白里町', 'サンブグンオオアミシラサトマチ', 'みやこ野', 'ミヤコノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡大網白里町仏島', '12', '12402', '2993237', '千葉県', 'チバケン', '山武郡大網白里町', 'サンブグンオオアミシラサトマチ', '仏島', 'ホトケシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡大網白里町季美の森南', '12', '12402', '2993241', '千葉県', 'チバケン', '山武郡大網白里町', 'サンブグンオオアミシラサトマチ', '季美の森南', 'キミノモリミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡大網白里町金谷郷', '12', '12402', '2993242', '千葉県', 'チバケン', '山武郡大網白里町', 'サンブグンオオアミシラサトマチ', '金谷郷', 'カナヤゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡大網白里町大竹', '12', '12402', '2993243', '千葉県', 'チバケン', '山武郡大網白里町', 'サンブグンオオアミシラサトマチ', '大竹', 'オオタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡大網白里町南玉', '12', '12402', '2993244', '千葉県', 'チバケン', '山武郡大網白里町', 'サンブグンオオアミシラサトマチ', '南玉', 'ミナミダマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡大網白里町池田', '12', '12402', '2993245', '千葉県', 'チバケン', '山武郡大網白里町', 'サンブグンオオアミシラサトマチ', '池田', 'イケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡大網白里町小中', '12', '12402', '2993246', '千葉県', 'チバケン', '山武郡大網白里町', 'サンブグンオオアミシラサトマチ', '小中', 'コナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡大網白里町神房', '12', '12402', '2993247', '千葉県', 'チバケン', '山武郡大網白里町', 'サンブグンオオアミシラサトマチ', '神房', 'カンボウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡大網白里町萱野', '12', '12402', '2993248', '千葉県', 'チバケン', '山武郡大網白里町', 'サンブグンオオアミシラサトマチ', '萱野', 'カヤノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡大網白里町砂田', '12', '12402', '2993249', '千葉県', 'チバケン', '山武郡大網白里町', 'サンブグンオオアミシラサトマチ', '砂田', 'イサゴダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡大網白里町大網', '12', '12402', '2993251', '千葉県', 'チバケン', '山武郡大網白里町', 'サンブグンオオアミシラサトマチ', '大網', 'オオアミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡大網白里町餅木', '12', '12402', '2993252', '千葉県', 'チバケン', '山武郡大網白里町', 'サンブグンオオアミシラサトマチ', '餅木', 'モチノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡大網白里町小西', '12', '12402', '2993253', '千葉県', 'チバケン', '山武郡大網白里町', 'サンブグンオオアミシラサトマチ', '小西', 'コニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡大網白里町養安寺', '12', '12402', '2993254', '千葉県', 'チバケン', '山武郡大網白里町', 'サンブグンオオアミシラサトマチ', '養安寺', 'ヨウアンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡大網白里町みどりが丘', '12', '12402', '2993255', '千葉県', 'チバケン', '山武郡大網白里町', 'サンブグンオオアミシラサトマチ', 'みどりが丘', 'ミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡大網白里町山口', '12', '12402', '2993256', '千葉県', 'チバケン', '山武郡大網白里町', 'サンブグンオオアミシラサトマチ', '山口', 'ヤマグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡大網白里町九十根', '12', '12402', '2993261', '千葉県', 'チバケン', '山武郡大網白里町', 'サンブグンオオアミシラサトマチ', '九十根', 'クジュウネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡大網白里町桂山', '12', '12402', '2993262', '千葉県', 'チバケン', '山武郡大網白里町', 'サンブグンオオアミシラサトマチ', '桂山', 'カツラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡大網白里町柳橋', '12', '12402', '2993263', '千葉県', 'チバケン', '山武郡大網白里町', 'サンブグンオオアミシラサトマチ', '柳橋', 'ヤナギバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡大網白里町柿餅', '12', '12402', '2993264', '千葉県', 'チバケン', '山武郡大網白里町', 'サンブグンオオアミシラサトマチ', '柿餅', 'カキモチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡大網白里町上貝塚', '12', '12402', '2993265', '千葉県', 'チバケン', '山武郡大網白里町', 'サンブグンオオアミシラサトマチ', '上貝塚', 'カミカイヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡大網白里町北横川', '12', '12402', '2993266', '千葉県', 'チバケン', '山武郡大網白里町', 'サンブグンオオアミシラサトマチ', '北横川', 'キタヨコカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡大網白里町清名幸谷', '12', '12402', '2993267', '千葉県', 'チバケン', '山武郡大網白里町', 'サンブグンオオアミシラサトマチ', '清名幸谷', 'セイナゴヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県山武郡大網白里町上谷新田', '12', '12402', '2993268', '千葉県', 'チバケン', '山武郡大網白里町', 'サンブグンオオアミシラサトマチ', '上谷新田', 'ウワヤシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県茂原市清水', '12', '12210', '2994101', '千葉県', 'チバケン', '茂原市', 'モバラシ', '清水', 'シミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県茂原市御蔵芝', '12', '12210', '2994102', '千葉県', 'チバケン', '茂原市', 'モバラシ', '御蔵芝', 'ミクラシバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県茂原市千沢', '12', '12210', '2994103', '千葉県', 'チバケン', '茂原市', 'モバラシ', '千沢', 'センザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県茂原市南吉田', '12', '12210', '2994104', '千葉県', 'チバケン', '茂原市', 'モバラシ', '南吉田', 'ミナミヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県茂原市弓渡', '12', '12210', '2994105', '千葉県', 'チバケン', '茂原市', 'モバラシ', '弓渡', 'ユミワタシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県茂原市粟生野', '12', '12210', '2994106', '千葉県', 'チバケン', '茂原市', 'モバラシ', '粟生野', 'アオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県茂原市萱場', '12', '12210', '2994111', '千葉県', 'チバケン', '茂原市', 'モバラシ', '萱場', 'カヤバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県茂原市西野', '12', '12210', '2994112', '千葉県', 'チバケン', '茂原市', 'モバラシ', '西野', 'ニシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県茂原市法目', '12', '12210', '2994113', '千葉県', 'チバケン', '茂原市', 'モバラシ', '法目', 'ホウメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県茂原市本納', '12', '12210', '2994114', '千葉県', 'チバケン', '茂原市', 'モバラシ', '本納', 'ホンノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県茂原市榎神房', '12', '12210', '2994115', '千葉県', 'チバケン', '茂原市', 'モバラシ', '榎神房', 'エノキカンボウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県茂原市高田', '12', '12210', '2994116', '千葉県', 'チバケン', '茂原市', 'モバラシ', '高田', 'タカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県茂原市小萱場', '12', '12210', '2994117', '千葉県', 'チバケン', '茂原市', 'モバラシ', '小萱場', 'コカヤバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県茂原市榎神房飛地', '12', '12210', '2994118', '千葉県', 'チバケン', '茂原市', 'モバラシ', '榎神房飛地', 'エノキカンボウトビチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県茂原市吉井下', '12', '12210', '2994121', '千葉県', 'チバケン', '茂原市', 'モバラシ', '吉井下', 'ヨシイシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県茂原市吉井上', '12', '12210', '2994122', '千葉県', 'チバケン', '茂原市', 'モバラシ', '吉井上', 'ヨシイカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県茂原市下太田', '12', '12210', '2994123', '千葉県', 'チバケン', '茂原市', 'モバラシ', '下太田', 'シモオオダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県茂原市上太田', '12', '12210', '2994124', '千葉県', 'チバケン', '茂原市', 'モバラシ', '上太田', 'カミオオダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県茂原市大沢', '12', '12210', '2994125', '千葉県', 'チバケン', '茂原市', 'モバラシ', '大沢', 'オオサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県茂原市柴名', '12', '12210', '2994126', '千葉県', 'チバケン', '茂原市', 'モバラシ', '柴名', 'シバナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県茂原市桂', '12', '12210', '2994127', '千葉県', 'チバケン', '茂原市', 'モバラシ', '桂', 'カツラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県茂原市桂飛地', '12', '12210', '2994128', '千葉県', 'チバケン', '茂原市', 'モバラシ', '桂飛地', 'カツラトビチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡白子町', '12', '12424', '2994200', '千葉県', 'チバケン', '長生郡白子町', 'チョウセイグンシラコマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('19943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡白子町浜宿', '12', '12424', '2994201', '千葉県', 'チバケン', '長生郡白子町', 'チョウセイグンシラコマチ', '浜宿', 'ハマシュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡白子町牛込', '12', '12424', '2994202', '千葉県', 'チバケン', '長生郡白子町', 'チョウセイグンシラコマチ', '牛込', 'ウシゴメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡白子町剃金', '12', '12424', '2994203', '千葉県', 'チバケン', '長生郡白子町', 'チョウセイグンシラコマチ', '剃金', 'ソリガネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡白子町福島', '12', '12424', '2994204', '千葉県', 'チバケン', '長生郡白子町', 'チョウセイグンシラコマチ', '福島', 'フクシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡白子町南日当', '12', '12424', '2994205', '千葉県', 'チバケン', '長生郡白子町', 'チョウセイグンシラコマチ', '南日当', 'ミナミヒナタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡白子町北日当', '12', '12424', '2994206', '千葉県', 'チバケン', '長生郡白子町', 'チョウセイグンシラコマチ', '北日当', 'キタヒナタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡白子町五井', '12', '12424', '2994211', '千葉県', 'チバケン', '長生郡白子町', 'チョウセイグンシラコマチ', '五井', 'ゴイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡白子町古所', '12', '12424', '2994212', '千葉県', 'チバケン', '長生郡白子町', 'チョウセイグンシラコマチ', '古所', 'フルトコロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡白子町八斗', '12', '12424', '2994213', '千葉県', 'チバケン', '長生郡白子町', 'チョウセイグンシラコマチ', '八斗', 'ハツト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡白子町驚', '12', '12424', '2994214', '千葉県', 'チバケン', '長生郡白子町', 'チョウセイグンシラコマチ', '驚', 'オドロキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡白子町中里', '12', '12424', '2994215', '千葉県', 'チバケン', '長生郡白子町', 'チョウセイグンシラコマチ', '中里', 'ナカザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡白子町幸治', '12', '12424', '2994216', '千葉県', 'チバケン', '長生郡白子町', 'チョウセイグンシラコマチ', '幸治', 'コウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡白子町北高根', '12', '12424', '2994217', '千葉県', 'チバケン', '長生郡白子町', 'チョウセイグンシラコマチ', '北高根', 'キタダカネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡白子町関', '12', '12424', '2994218', '千葉県', 'チバケン', '長生郡白子町', 'チョウセイグンシラコマチ', '関', 'セキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡一宮町', '12', '12421', '2994300', '千葉県', 'チバケン', '長生郡一宮町', 'チョウセイグンイチノミヤマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('19959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡長生村', '12', '12423', '2994300', '千葉県', 'チバケン', '長生郡長生村', 'チョウセイグンチョウセイムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('19960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡一宮町一宮', '12', '12421', '2994301', '千葉県', 'チバケン', '長生郡一宮町', 'チョウセイグンイチノミヤマチ', '一宮', 'イチノミヤ', null, null, null, null), ('19961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡一宮町田町', '12', '12421', '2994302', '千葉県', 'チバケン', '長生郡一宮町', 'チョウセイグンイチノミヤマチ', '田町', 'タマチ', null, null, null, null), ('19962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡一宮町東浪見', '12', '12421', '2994303', '千葉県', 'チバケン', '長生郡一宮町', 'チョウセイグンイチノミヤマチ', '東浪見', 'トラミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡一宮町綱田', '12', '12421', '2994304', '千葉県', 'チバケン', '長生郡一宮町', 'チョウセイグンイチノミヤマチ', '綱田', 'ツナダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡一宮町本給', '12', '12421', '2994305', '千葉県', 'チバケン', '長生郡一宮町', 'チョウセイグンイチノミヤマチ', '本給', 'ホンキュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡一宮町白山', '12', '12421', '2994311', '千葉県', 'チバケン', '長生郡一宮町', 'チョウセイグンイチノミヤマチ', '白山', 'ハクサン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡一宮町宮原', '12', '12421', '2994312', '千葉県', 'チバケン', '長生郡一宮町', 'チョウセイグンイチノミヤマチ', '宮原', 'ミヤバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡一宮町船頭給', '12', '12421', '2994313', '千葉県', 'チバケン', '長生郡一宮町', 'チョウセイグンイチノミヤマチ', '船頭給', 'センドウキュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡一宮町新地', '12', '12421', '2994314', '千葉県', 'チバケン', '長生郡一宮町', 'チョウセイグンイチノミヤマチ', '新地', 'アラチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡一宮町新地甲', '12', '12421', '2994315', '千葉県', 'チバケン', '長生郡一宮町', 'チョウセイグンイチノミヤマチ', '新地甲', 'アラチコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡一宮町新地丙', '12', '12421', '2994316', '千葉県', 'チバケン', '長生郡一宮町', 'チョウセイグンイチノミヤマチ', '新地丙', 'アラチヘイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡長生村入山津', '12', '12423', '2994321', '千葉県', 'チバケン', '長生郡長生村', 'チョウセイグンチョウセイムラ', '入山津', 'イリヤマヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡長生村驚', '12', '12423', '2994322', '千葉県', 'チバケン', '長生郡長生村', 'チョウセイグンチョウセイムラ', '驚', 'オドロキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡長生村一松戊', '12', '12423', '2994323', '千葉県', 'チバケン', '長生郡長生村', 'チョウセイグンチョウセイムラ', '一松戊', 'ヒトツマツボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡長生村一松丁', '12', '12423', '2994324', '千葉県', 'チバケン', '長生郡長生村', 'チョウセイグンチョウセイムラ', '一松丁', 'ヒトツマツテイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡長生村一松丙', '12', '12423', '2994325', '千葉県', 'チバケン', '長生郡長生村', 'チョウセイグンチョウセイムラ', '一松丙', 'ヒトツマツヘイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡長生村一松乙', '12', '12423', '2994326', '千葉県', 'チバケン', '長生郡長生村', 'チョウセイグンチョウセイムラ', '一松乙', 'ヒトツマツオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡長生村一松', '12', '12423', '2994327', '千葉県', 'チバケン', '長生郡長生村', 'チョウセイグンチョウセイムラ', '一松', 'ヒトツマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡長生村一松甲', '12', '12423', '2994328', '千葉県', 'チバケン', '長生郡長生村', 'チョウセイグンチョウセイムラ', '一松甲', 'ヒトツマツコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡長生村信友', '12', '12423', '2994331', '千葉県', 'チバケン', '長生郡長生村', 'チョウセイグンチョウセイムラ', '信友', 'ノブトモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡長生村金田', '12', '12423', '2994332', '千葉県', 'チバケン', '長生郡長生村', 'チョウセイグンチョウセイムラ', '金田', 'カネダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡長生村七井土', '12', '12423', '2994333', '千葉県', 'チバケン', '長生郡長生村', 'チョウセイグンチョウセイムラ', '七井土', 'ナナイド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡長生村薮塚', '12', '12423', '2994334', '千葉県', 'チバケン', '長生郡長生村', 'チョウセイグンチョウセイムラ', '薮塚', 'ヤブツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡長生村水口', '12', '12423', '2994335', '千葉県', 'チバケン', '長生郡長生村', 'チョウセイグンチョウセイムラ', '水口', 'ミヨグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡長生村岩沼', '12', '12423', '2994336', '千葉県', 'チバケン', '長生郡長生村', 'チョウセイグンチョウセイムラ', '岩沼', 'イワヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡長生村北水口', '12', '12423', '2994337', '千葉県', 'チバケン', '長生郡長生村', 'チョウセイグンチョウセイムラ', '北水口', 'キタミヨグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡長生村六ツ野飛地', '12', '12423', '2994338', '千葉県', 'チバケン', '長生郡長生村', 'チョウセイグンチョウセイムラ', '六ツ野飛地', 'ムツノトビチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡長生村宮成', '12', '12423', '2994341', '千葉県', 'チバケン', '長生郡長生村', 'チョウセイグンチョウセイムラ', '宮成', 'ミヤナリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡長生村一松飛地甲', '12', '12423', '2994342', '千葉県', 'チバケン', '長生郡長生村', 'チョウセイグンチョウセイムラ', '一松飛地甲', 'ヒトツマツトビチコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡長生村岩沼飛地', '12', '12423', '2994343', '千葉県', 'チバケン', '長生郡長生村', 'チョウセイグンチョウセイムラ', '岩沼飛地', 'イワヌマトビチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡長生村曽根', '12', '12423', '2994344', '千葉県', 'チバケン', '長生郡長生村', 'チョウセイグンチョウセイムラ', '曽根', 'ソネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡長生村本郷', '12', '12423', '2994345', '千葉県', 'チバケン', '長生郡長生村', 'チョウセイグンチョウセイムラ', '本郷', 'ホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡長生村中之郷', '12', '12423', '2994346', '千葉県', 'チバケン', '長生郡長生村', 'チョウセイグンチョウセイムラ', '中之郷', 'ナカノゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡長生村小泉', '12', '12423', '2994347', '千葉県', 'チバケン', '長生郡長生村', 'チョウセイグンチョウセイムラ', '小泉', 'コイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡睦沢町', '12', '12422', '2994400', '千葉県', 'チバケン', '長生郡睦沢町', 'チョウセイグンムツザワマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('19998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡睦沢町寺崎', '12', '12422', '2994401', '千葉県', 'チバケン', '長生郡睦沢町', 'チョウセイグンムツザワマチ', '寺崎', 'テラサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('19999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡睦沢町川島', '12', '12422', '2994402', '千葉県', 'チバケン', '長生郡睦沢町', 'チョウセイグンムツザワマチ', '川島', 'カワシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡睦沢町上市場', '12', '12422', '2994403', '千葉県', 'チバケン', '長生郡睦沢町', 'チョウセイグンムツザワマチ', '上市場', 'カミイチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡睦沢町北山田', '12', '12422', '2994404', '千葉県', 'チバケン', '長生郡睦沢町', 'チョウセイグンムツザワマチ', '北山田', 'キタヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡睦沢町大谷木', '12', '12422', '2994405', '千葉県', 'チバケン', '長生郡睦沢町', 'チョウセイグンムツザワマチ', '大谷木', 'オオヤギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡睦沢町北山田寺崎両村新田', '12', '12422', '2994406', '千葉県', 'チバケン', '長生郡睦沢町', 'チョウセイグンムツザワマチ', '北山田寺崎両村新田', 'キタヤマダテラサキリョウソンシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡睦沢町河須ケ谷', '12', '12422', '2994411', '千葉県', 'チバケン', '長生郡睦沢町', 'チョウセイグンムツザワマチ', '河須ケ谷', 'カワスガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡睦沢町岩井', '12', '12422', '2994412', '千葉県', 'チバケン', '長生郡睦沢町', 'チョウセイグンムツザワマチ', '岩井', 'イワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡睦沢町上之郷', '12', '12422', '2994413', '千葉県', 'チバケン', '長生郡睦沢町', 'チョウセイグンムツザワマチ', '上之郷', 'カミノゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡睦沢町下之郷', '12', '12422', '2994414', '千葉県', 'チバケン', '長生郡睦沢町', 'チョウセイグンムツザワマチ', '下之郷', 'シモノゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡睦沢町小滝', '12', '12422', '2994415', '千葉県', 'チバケン', '長生郡睦沢町', 'チョウセイグンムツザワマチ', '小滝', 'コダキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡睦沢町長楽寺', '12', '12422', '2994421', '千葉県', 'チバケン', '長生郡睦沢町', 'チョウセイグンムツザワマチ', '長楽寺', 'チョウラクジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡睦沢町森', '12', '12422', '2994422', '千葉県', 'チバケン', '長生郡睦沢町', 'チョウセイグンムツザワマチ', '森', 'モリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡睦沢町大上', '12', '12422', '2994423', '千葉県', 'チバケン', '長生郡睦沢町', 'チョウセイグンムツザワマチ', '大上', 'オオガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡睦沢町妙楽寺', '12', '12422', '2994424', '千葉県', 'チバケン', '長生郡睦沢町', 'チョウセイグンムツザワマチ', '妙楽寺', 'ミョウラクジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県長生郡睦沢町佐貫', '12', '12422', '2994425', '千葉県', 'チバケン', '長生郡睦沢町', 'チョウセイグンムツザワマチ', '佐貫', 'サヌキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県いすみ市岬町椎木', '12', '12238', '2994501', '千葉県', 'チバケン', 'いすみ市', 'イスミシ', '岬町椎木', 'ミサキチョウシイギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県いすみ市岬町中原', '12', '12238', '2994502', '千葉県', 'チバケン', 'いすみ市', 'イスミシ', '岬町中原', 'ミサキチョウナカハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県いすみ市岬町和泉', '12', '12238', '2994503', '千葉県', 'チバケン', 'いすみ市', 'イスミシ', '岬町和泉', 'ミサキチョウイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県いすみ市岬町桑田', '12', '12238', '2994504', '千葉県', 'チバケン', 'いすみ市', 'イスミシ', '岬町桑田', 'ミサキチョウクワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県いすみ市岬町岩熊', '12', '12238', '2994505', '千葉県', 'チバケン', 'いすみ市', 'イスミシ', '岬町岩熊', 'ミサキチョウイワクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県いすみ市岬町市野々', '12', '12238', '2994506', '千葉県', 'チバケン', 'いすみ市', 'イスミシ', '岬町市野々', 'ミサキチョウイチノノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県いすみ市岬町谷上', '12', '12238', '2994507', '千葉県', 'チバケン', 'いすみ市', 'イスミシ', '岬町谷上', 'ミサキチョウヤガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県いすみ市岬町榎沢', '12', '12238', '2994508', '千葉県', 'チバケン', 'いすみ市', 'イスミシ', '岬町榎沢', 'ミサキチョウエノキサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県いすみ市岬町和泉', '12', '12238', '2994611', '千葉県', 'チバケン', 'いすみ市', 'イスミシ', '岬町和泉', 'ミサキチョウイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県いすみ市岬町江場土', '12', '12238', '2994612', '千葉県', 'チバケン', 'いすみ市', 'イスミシ', '岬町江場土', 'ミサキチョウエバド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県いすみ市岬町三門', '12', '12238', '2994613', '千葉県', 'チバケン', 'いすみ市', 'イスミシ', '岬町三門', 'ミサキチョウミカド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県いすみ市岬町東小高', '12', '12238', '2994614', '千葉県', 'チバケン', 'いすみ市', 'イスミシ', '岬町東小高', 'ミサキチョウヒガシオダカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県いすみ市岬町井沢', '12', '12238', '2994615', '千葉県', 'チバケン', 'いすみ市', 'イスミシ', '岬町井沢', 'ミサキチョウイザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県いすみ市岬町長者', '12', '12238', '2994616', '千葉県', 'チバケン', 'いすみ市', 'イスミシ', '岬町長者', 'ミサキチョウチョウジャ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県いすみ市岬町東中滝', '12', '12238', '2994621', '千葉県', 'チバケン', 'いすみ市', 'イスミシ', '岬町東中滝', 'ミサキチョウヒガシナカタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県いすみ市岬町押日', '12', '12238', '2994622', '千葉県', 'チバケン', 'いすみ市', 'イスミシ', '岬町押日', 'ミサキチョウオシビ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県いすみ市岬町中滝', '12', '12238', '2994623', '千葉県', 'チバケン', 'いすみ市', 'イスミシ', '岬町中滝', 'ミサキチョウナカダキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県いすみ市岬町鴨根', '12', '12238', '2994624', '千葉県', 'チバケン', 'いすみ市', 'イスミシ', '岬町鴨根', 'ミサキチョウカモネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県いすみ市岬町嘉谷', '12', '12238', '2994625', '千葉県', 'チバケン', 'いすみ市', 'イスミシ', '岬町嘉谷', 'ミサキチョウカヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県夷隅郡御宿町', '12', '12443', '2995100', '千葉県', 'チバケン', '夷隅郡御宿町', 'イスミグンオンジュクマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('20037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県夷隅郡御宿町高山田', '12', '12443', '2995101', '千葉県', 'チバケン', '夷隅郡御宿町', 'イスミグンオンジュクマチ', '高山田', 'タカヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県夷隅郡御宿町久保', '12', '12443', '2995102', '千葉県', 'チバケン', '夷隅郡御宿町', 'イスミグンオンジュクマチ', '久保', 'クボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県夷隅郡御宿町新町', '12', '12443', '2995103', '千葉県', 'チバケン', '夷隅郡御宿町', 'イスミグンオンジュクマチ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県夷隅郡御宿町六軒町', '12', '12443', '2995104', '千葉県', 'チバケン', '夷隅郡御宿町', 'イスミグンオンジュクマチ', '六軒町', 'ロッケンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県夷隅郡御宿町岩和田', '12', '12443', '2995105', '千葉県', 'チバケン', '夷隅郡御宿町', 'イスミグンオンジュクマチ', '岩和田', 'イワワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県夷隅郡御宿町須賀', '12', '12443', '2995106', '千葉県', 'チバケン', '夷隅郡御宿町', 'イスミグンオンジュクマチ', '須賀', 'スカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県夷隅郡御宿町浜', '12', '12443', '2995107', '千葉県', 'チバケン', '夷隅郡御宿町', 'イスミグンオンジュクマチ', '浜', 'ハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県夷隅郡御宿町上布施', '12', '12443', '2995111', '千葉県', 'チバケン', '夷隅郡御宿町', 'イスミグンオンジュクマチ', '上布施', 'カミフセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県夷隅郡御宿町御宿台', '12', '12443', '2995112', '千葉県', 'チバケン', '夷隅郡御宿町', 'イスミグンオンジュクマチ', '御宿台', 'オンジュクダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県夷隅郡御宿町七本', '12', '12443', '2995113', '千葉県', 'チバケン', '夷隅郡御宿町', 'イスミグンオンジュクマチ', '七本', 'ナナモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県夷隅郡御宿町実谷', '12', '12443', '2995114', '千葉県', 'チバケン', '夷隅郡御宿町', 'イスミグンオンジュクマチ', '実谷', 'ジッコク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県勝浦市', '12', '12218', '2995200', '千葉県', 'チバケン', '勝浦市', 'カツウラシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('20050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県勝浦市市野郷', '12', '12218', '2995201', '千葉県', 'チバケン', '勝浦市', 'カツウラシ', '市野郷', 'イチノゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県勝浦市市野川', '12', '12218', '2995202', '千葉県', 'チバケン', '勝浦市', 'カツウラシ', '市野川', 'イチノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県勝浦市花里', '12', '12218', '2995203', '千葉県', 'チバケン', '勝浦市', 'カツウラシ', '花里', 'ハナザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県勝浦市中倉', '12', '12218', '2995204', '千葉県', 'チバケン', '勝浦市', 'カツウラシ', '中倉', 'ナカグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県勝浦市杉戸', '12', '12218', '2995205', '千葉県', 'チバケン', '勝浦市', 'カツウラシ', '杉戸', 'スギド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県勝浦市佐野', '12', '12218', '2995206', '千葉県', 'チバケン', '勝浦市', 'カツウラシ', '佐野', 'サノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県勝浦市松野', '12', '12218', '2995211', '千葉県', 'チバケン', '勝浦市', 'カツウラシ', '松野', 'マツノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県勝浦市蟹田', '12', '12218', '2995212', '千葉県', 'チバケン', '勝浦市', 'カツウラシ', '蟹田', 'カニタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県勝浦市芳賀', '12', '12218', '2995213', '千葉県', 'チバケン', '勝浦市', 'カツウラシ', '芳賀', 'ハガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県勝浦市白木', '12', '12218', '2995214', '千葉県', 'チバケン', '勝浦市', 'カツウラシ', '白木', 'シラキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県勝浦市白井久保', '12', '12218', '2995215', '千葉県', 'チバケン', '勝浦市', 'カツウラシ', '白井久保', 'シライクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県勝浦市宿戸', '12', '12218', '2995216', '千葉県', 'チバケン', '勝浦市', 'カツウラシ', '宿戸', 'シュクド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県勝浦市大楠', '12', '12218', '2995217', '千葉県', 'チバケン', '勝浦市', 'カツウラシ', '大楠', 'オオクス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県勝浦市小羽戸', '12', '12218', '2995218', '千葉県', 'チバケン', '勝浦市', 'カツウラシ', '小羽戸', 'コバド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県勝浦市小松野', '12', '12218', '2995219', '千葉県', 'チバケン', '勝浦市', 'カツウラシ', '小松野', 'コマツノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県勝浦市平田', '12', '12218', '2995221', '千葉県', 'チバケン', '勝浦市', 'カツウラシ', '平田', 'ヒラタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県勝浦市関谷', '12', '12218', '2995222', '千葉県', 'チバケン', '勝浦市', 'カツウラシ', '関谷', 'セキヤツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県勝浦市部原', '12', '12218', '2995223', '千葉県', 'チバケン', '勝浦市', 'カツウラシ', '部原', 'ヘバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県勝浦市新官', '12', '12218', '2995224', '千葉県', 'チバケン', '勝浦市', 'カツウラシ', '新官', 'シンカン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県勝浦市墨名', '12', '12218', '2995225', '千葉県', 'チバケン', '勝浦市', 'カツウラシ', '墨名', 'トナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県勝浦市串浜', '12', '12218', '2995226', '千葉県', 'チバケン', '勝浦市', 'カツウラシ', '串浜', 'クシハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県勝浦市中谷', '12', '12218', '2995227', '千葉県', 'チバケン', '勝浦市', 'カツウラシ', '中谷', 'ナカヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県勝浦市新戸', '12', '12218', '2995228', '千葉県', 'チバケン', '勝浦市', 'カツウラシ', '新戸', 'シンド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県勝浦市沢倉', '12', '12218', '2995231', '千葉県', 'チバケン', '勝浦市', 'カツウラシ', '沢倉', 'サワクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県勝浦市川津', '12', '12218', '2995232', '千葉県', 'チバケン', '勝浦市', 'カツウラシ', '川津', 'カワヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県勝浦市浜勝浦', '12', '12218', '2995233', '千葉県', 'チバケン', '勝浦市', 'カツウラシ', '浜勝浦', 'ハマカツウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県勝浦市勝浦', '12', '12218', '2995234', '千葉県', 'チバケン', '勝浦市', 'カツウラシ', '勝浦', 'カツウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県勝浦市出水', '12', '12218', '2995235', '千葉県', 'チバケン', '勝浦市', 'カツウラシ', '出水', 'イデミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県勝浦市松部', '12', '12218', '2995241', '千葉県', 'チバケン', '勝浦市', 'カツウラシ', '松部', 'マツベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県勝浦市吉尾', '12', '12218', '2995242', '千葉県', 'チバケン', '勝浦市', 'カツウラシ', '吉尾', 'ヨシオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県勝浦市鵜原', '12', '12218', '2995243', '千葉県', 'チバケン', '勝浦市', 'カツウラシ', '鵜原', 'ウバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県勝浦市守谷', '12', '12218', '2995244', '千葉県', 'チバケン', '勝浦市', 'カツウラシ', '守谷', 'モリヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県勝浦市興津', '12', '12218', '2995245', '千葉県', 'チバケン', '勝浦市', 'カツウラシ', '興津', 'オキツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県勝浦市興津久保山台', '12', '12218', '2995246', '千葉県', 'チバケン', '勝浦市', 'カツウラシ', '興津久保山台', 'オキツクボヤマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県勝浦市大森上植野入会地', '12', '12218', '2995251', '千葉県', 'チバケン', '勝浦市', 'カツウラシ', '大森上植野入会地', 'オオモリカミウエノイリアイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県勝浦市上植野', '12', '12218', '2995252', '千葉県', 'チバケン', '勝浦市', 'カツウラシ', '上植野', 'カミウエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県勝浦市名木', '12', '12218', '2995253', '千葉県', 'チバケン', '勝浦市', 'カツウラシ', '名木', 'ナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県勝浦市台宿', '12', '12218', '2995254', '千葉県', 'チバケン', '勝浦市', 'カツウラシ', '台宿', 'ダイジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県勝浦市浜行川', '12', '12218', '2995255', '千葉県', 'チバケン', '勝浦市', 'カツウラシ', '浜行川', 'ハマナメガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県勝浦市大沢', '12', '12218', '2995256', '千葉県', 'チバケン', '勝浦市', 'カツウラシ', '大沢', 'オオサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県勝浦市大森', '12', '12218', '2995261', '千葉県', 'チバケン', '勝浦市', 'カツウラシ', '大森', 'オオモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県勝浦市中里', '12', '12218', '2995262', '千葉県', 'チバケン', '勝浦市', 'カツウラシ', '中里', 'ナカザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県勝浦市赤羽根', '12', '12218', '2995263', '千葉県', 'チバケン', '勝浦市', 'カツウラシ', '赤羽根', 'アカバネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県勝浦市中島', '12', '12218', '2995264', '千葉県', 'チバケン', '勝浦市', 'カツウラシ', '中島', 'ナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県勝浦市植野', '12', '12218', '2995265', '千葉県', 'チバケン', '勝浦市', 'カツウラシ', '植野', 'ウエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県勝浦市上野', '12', '12218', '2995266', '千葉県', 'チバケン', '勝浦市', 'カツウラシ', '上野', 'ウエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県勝浦市法花', '12', '12218', '2995271', '千葉県', 'チバケン', '勝浦市', 'カツウラシ', '法花', 'ホウゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県勝浦市貝掛', '12', '12218', '2995272', '千葉県', 'チバケン', '勝浦市', 'カツウラシ', '貝掛', 'カイガケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県勝浦市荒川', '12', '12218', '2995273', '千葉県', 'チバケン', '勝浦市', 'カツウラシ', '荒川', 'アラカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県勝浦市南山田', '12', '12218', '2995274', '千葉県', 'チバケン', '勝浦市', 'カツウラシ', '南山田', 'ミナミヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鴨川市小湊', '12', '12223', '2995501', '千葉県', 'チバケン', '鴨川市', 'カモガワシ', '小湊', 'コミナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鴨川市内浦', '12', '12223', '2995502', '千葉県', 'チバケン', '鴨川市', 'カモガワシ', '内浦', 'ウチウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鴨川市天津', '12', '12223', '2995503', '千葉県', 'チバケン', '鴨川市', 'カモガワシ', '天津', 'アマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鴨川市浜荻', '12', '12223', '2995504', '千葉県', 'チバケン', '鴨川市', 'カモガワシ', '浜荻', 'ハマオギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鴨川市清澄', '12', '12223', '2995505', '千葉県', 'チバケン', '鴨川市', 'カモガワシ', '清澄', 'キヨスミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '千葉県鴨川市四方木', '12', '12223', '2995506', '千葉県', 'チバケン', '鴨川市', 'カモガワシ', '四方木', 'ヨモギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市白石区', '01', '01104', '0030000', '北海道', 'ホッカイドウ', '札幌市白石区', 'サッポロシシロイシク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('20109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市', '08', '08203', '3000000', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('20110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市今泉', '08', '08203', '3000001', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '今泉', 'イマイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市粟野町', '08', '08203', '3000002', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '粟野町', 'アワノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市紫ケ丘', '08', '08203', '3000003', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '紫ケ丘', 'ムラサキガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市小山崎', '08', '08203', '3000004', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '小山崎', 'コヤマザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市中貫', '08', '08203', '3000005', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '中貫', 'ナカヌキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市東中貫町', '08', '08203', '3000006', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '東中貫町', 'ヒガシナカヌキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市板谷', '08', '08203', '3000007', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '板谷', 'イタヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市笠師町', '08', '08203', '3000008', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '笠師町', 'カサシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市中都町', '08', '08203', '3000009', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '中都町', 'ナカツマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市神立中央', '08', '08203', '3000011', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '神立中央', 'カンダツチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市神立東', '08', '08203', '3000012', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '神立東', 'カンダツヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市神立町', '08', '08203', '3000013', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '神立町', 'カンダツマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市西神立', '08', '08203', '3000014', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '西神立', 'ニシカンダツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市北神立町', '08', '08203', '3000015', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '北神立町', 'キタカンダツマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市中神立町', '08', '08203', '3000016', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '中神立町', 'ナカカンダツマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市菅谷町', '08', '08203', '3000021', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '菅谷町', 'スゲノヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市白鳥町', '08', '08203', '3000022', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '白鳥町', 'シラトリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市沖宿町', '08', '08203', '3000023', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '沖宿町', 'オキジュクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市田村町', '08', '08203', '3000024', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '田村町', 'タムラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市手野町', '08', '08203', '3000025', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '手野町', 'テノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市木田余', '08', '08203', '3000026', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '木田余', 'キダマリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市木田余東台', '08', '08203', '3000027', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '木田余東台', 'キダマリヒガシダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市おおつ野', '08', '08203', '3000028', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', 'おおつ野', 'オオツノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市東崎町', '08', '08203', '3000031', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '東崎町', 'トウザキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市湖北', '08', '08203', '3000032', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '湖北', 'コホク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市川口', '08', '08203', '3000033', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '川口', 'カワグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市港町', '08', '08203', '3000034', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '港町', 'ミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市有明町', '08', '08203', '3000035', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '有明町', 'アリアケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市大和町', '08', '08203', '3000036', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '大和町', 'ヤマトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市桜町', '08', '08203', '3000037', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '桜町', 'サクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市大町', '08', '08203', '3000038', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '大町', 'オオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市立田町', '08', '08203', '3000041', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '立田町', 'タツタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市城北町', '08', '08203', '3000042', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '城北町', 'ジョウホクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市中央', '08', '08203', '3000043', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市大手町', '08', '08203', '3000044', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '大手町', 'オオテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市文京町', '08', '08203', '3000045', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '文京町', 'ブンキョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市千束町', '08', '08203', '3000046', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '千束町', 'センゾクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市生田町', '08', '08203', '3000047', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '生田町', 'イクタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市田中', '08', '08203', '3000048', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '田中', 'タナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市田中町', '08', '08203', '3000049', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '田中町', 'タナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市真鍋', '08', '08203', '3000051', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '真鍋', 'マナベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市東真鍋町', '08', '08203', '3000052', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '東真鍋町', 'ヒガシマナベマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市真鍋新町', '08', '08203', '3000053', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '真鍋新町', 'マナベシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市西真鍋町', '08', '08203', '3000054', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '西真鍋町', 'ニシマナベマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市殿里', '08', '08203', '3000055', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '殿里', 'トノサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市木田余西台', '08', '08203', '3000056', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '木田余西台', 'キダマリニシダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市並木', '08', '08203', '3000061', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '並木', 'ナミキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市都和', '08', '08203', '3000062', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '都和', 'ツワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市若松町', '08', '08203', '3000063', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '若松町', 'ワカマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市東若松町', '08', '08203', '3000064', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '東若松町', 'ヒガシワカマツマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市常名', '08', '08203', '3000065', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '常名', 'ヒタナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市虫掛', '08', '08203', '3000066', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '虫掛', 'ムシカケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市東都和', '08', '08203', '3000067', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '東都和', 'ヒガシツワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市西並木町', '08', '08203', '3000068', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '西並木町', 'ニシナミキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市東並木町', '08', '08203', '3000069', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '東並木町', 'ヒガシナミキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市白石区東札幌1条', '01', '01104', '0030001', '北海道', 'ホッカイドウ', '札幌市白石区', 'サッポロシシロイシク', '東札幌1条', 'ヒガシサッポロ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県かすみがうら市宍倉', '08', '08230', '3000121', '茨城県', 'イバラキケン', 'かすみがうら市', 'カスミガウラシ', '宍倉', 'シシクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県かすみがうら市西成井', '08', '08230', '3000122', '茨城県', 'イバラキケン', 'かすみがうら市', 'カスミガウラシ', '西成井', 'ニシナルイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県かすみがうら市上軽部', '08', '08230', '3000123', '茨城県', 'イバラキケン', 'かすみがうら市', 'カスミガウラシ', '上軽部', 'カミカルベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県かすみがうら市大和田', '08', '08230', '3000124', '茨城県', 'イバラキケン', 'かすみがうら市', 'カスミガウラシ', '大和田', 'オオワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県かすみがうら市三ツ木', '08', '08230', '3000125', '茨城県', 'イバラキケン', 'かすみがうら市', 'カスミガウラシ', '三ツ木', 'ミツギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県かすみがうら市南根本', '08', '08230', '3000126', '茨城県', 'イバラキケン', 'かすみがうら市', 'カスミガウラシ', '南根本', 'ミナミネモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県かすみがうら市上大堤', '08', '08230', '3000127', '茨城県', 'イバラキケン', 'かすみがうら市', 'カスミガウラシ', '上大堤', 'カミオオヅツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県かすみがうら市下大堤', '08', '08230', '3000131', '茨城県', 'イバラキケン', 'かすみがうら市', 'カスミガウラシ', '下大堤', 'シモオオヅツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県かすみがうら市男神', '08', '08230', '3000132', '茨城県', 'イバラキケン', 'かすみがうら市', 'カスミガウラシ', '男神', 'オガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県かすみがうら市中台', '08', '08230', '3000133', '茨城県', 'イバラキケン', 'かすみがうら市', 'カスミガウラシ', '中台', 'ナカダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県かすみがうら市深谷', '08', '08230', '3000134', '茨城県', 'イバラキケン', 'かすみがうら市', 'カスミガウラシ', '深谷', 'フカヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県かすみがうら市加茂', '08', '08230', '3000135', '茨城県', 'イバラキケン', 'かすみがうら市', 'カスミガウラシ', '加茂', 'カモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県かすみがうら市戸崎', '08', '08230', '3000136', '茨城県', 'イバラキケン', 'かすみがうら市', 'カスミガウラシ', '戸崎', 'トザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市白石区東札幌2条', '01', '01104', '0030002', '北海道', 'ホッカイドウ', '札幌市白石区', 'サッポロシシロイシク', '東札幌2条', 'ヒガシサッポロ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県かすみがうら市柏崎', '08', '08230', '3000201', '茨城県', 'イバラキケン', 'かすみがうら市', 'カスミガウラシ', '柏崎', 'カシワザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県かすみがうら市田伏', '08', '08230', '3000202', '茨城県', 'イバラキケン', 'かすみがうら市', 'カスミガウラシ', '田伏', 'タブセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県かすみがうら市岩坪', '08', '08230', '3000203', '茨城県', 'イバラキケン', 'かすみがうら市', 'カスミガウラシ', '岩坪', 'イワツボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県かすみがうら市下軽部', '08', '08230', '3000204', '茨城県', 'イバラキケン', 'かすみがうら市', 'カスミガウラシ', '下軽部', 'シモカルベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県かすみがうら市安食', '08', '08230', '3000205', '茨城県', 'イバラキケン', 'かすみがうら市', 'カスミガウラシ', '安食', 'アンジキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県かすみがうら市志戸崎', '08', '08230', '3000211', '茨城県', 'イバラキケン', 'かすみがうら市', 'カスミガウラシ', '志戸崎', 'シトザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県かすみがうら市有河', '08', '08230', '3000212', '茨城県', 'イバラキケン', 'かすみがうら市', 'カスミガウラシ', '有河', 'アルガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県かすみがうら市牛渡', '08', '08230', '3000213', '茨城県', 'イバラキケン', 'かすみがうら市', 'カスミガウラシ', '牛渡', 'ウシワタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県かすみがうら市坂', '08', '08230', '3000214', '茨城県', 'イバラキケン', 'かすみがうら市', 'カスミガウラシ', '坂', 'サカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市白石区東札幌3条', '01', '01104', '0030003', '北海道', 'ホッカイドウ', '札幌市白石区', 'サッポロシシロイシク', '東札幌3条', 'ヒガシサッポロ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷郡阿見町', '08', '08443', '3000300', '茨城県', 'イバラキケン', '稲敷郡阿見町', 'イナシキグンアミマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('20193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷郡阿見町青宿', '08', '08443', '3000301', '茨城県', 'イバラキケン', '稲敷郡阿見町', 'イナシキグンアミマチ', '青宿', 'アオヤド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷郡阿見町廻戸', '08', '08443', '3000302', '茨城県', 'イバラキケン', '稲敷郡阿見町', 'イナシキグンアミマチ', '廻戸', 'ハサマド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷郡阿見町大室', '08', '08443', '3000303', '茨城県', 'イバラキケン', '稲敷郡阿見町', 'イナシキグンアミマチ', '大室', 'オオムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷郡阿見町掛馬', '08', '08443', '3000304', '茨城県', 'イバラキケン', '稲敷郡阿見町', 'イナシキグンアミマチ', '掛馬', 'カケウマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷郡阿見町竹来', '08', '08443', '3000305', '茨城県', 'イバラキケン', '稲敷郡阿見町', 'イナシキグンアミマチ', '竹来', 'タカク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷郡阿見町曙', '08', '08443', '3000306', '茨城県', 'イバラキケン', '稲敷郡阿見町', 'イナシキグンアミマチ', '曙', 'アケボノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷郡阿見町島津', '08', '08443', '3000311', '茨城県', 'イバラキケン', '稲敷郡阿見町', 'イナシキグンアミマチ', '島津', 'シマヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷郡阿見町南平台', '08', '08443', '3000312', '茨城県', 'イバラキケン', '稲敷郡阿見町', 'イナシキグンアミマチ', '南平台', 'ナンペイダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷郡阿見町石川', '08', '08443', '3000313', '茨城県', 'イバラキケン', '稲敷郡阿見町', 'イナシキグンアミマチ', '石川', 'イシカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷郡阿見町追原', '08', '08443', '3000314', '茨城県', 'イバラキケン', '稲敷郡阿見町', 'イナシキグンアミマチ', '追原', 'オッパラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷郡阿見町香澄の里', '08', '08443', '3000315', '茨城県', 'イバラキケン', '稲敷郡阿見町', 'イナシキグンアミマチ', '香澄の里', 'カスミノサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷郡阿見町塙', '08', '08443', '3000321', '茨城県', 'イバラキケン', '稲敷郡阿見町', 'イナシキグンアミマチ', '塙', 'ハナワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷郡阿見町君島', '08', '08443', '3000322', '茨城県', 'イバラキケン', '稲敷郡阿見町', 'イナシキグンアミマチ', '君島', 'キミジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷郡阿見町大形', '08', '08443', '3000323', '茨城県', 'イバラキケン', '稲敷郡阿見町', 'イナシキグンアミマチ', '大形', 'オオガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷郡阿見町飯倉', '08', '08443', '3000324', '茨城県', 'イバラキケン', '稲敷郡阿見町', 'イナシキグンアミマチ', '飯倉', 'イイグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷郡阿見町上条', '08', '08443', '3000325', '茨城県', 'イバラキケン', '稲敷郡阿見町', 'イナシキグンアミマチ', '上条', 'ジョウジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷郡阿見町星の里', '08', '08443', '3000326', '茨城県', 'イバラキケン', '稲敷郡阿見町', 'イナシキグンアミマチ', '星の里', 'ホシノサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷郡阿見町阿見', '08', '08443', '3000331', '茨城県', 'イバラキケン', '稲敷郡阿見町', 'イナシキグンアミマチ', '阿見', 'アミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷郡阿見町中央', '08', '08443', '3000332', '茨城県', 'イバラキケン', '稲敷郡阿見町', 'イナシキグンアミマチ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷郡阿見町若栗', '08', '08443', '3000333', '茨城県', 'イバラキケン', '稲敷郡阿見町', 'イナシキグンアミマチ', '若栗', 'ワカグリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷郡阿見町鈴木', '08', '08443', '3000334', '茨城県', 'イバラキケン', '稲敷郡阿見町', 'イナシキグンアミマチ', '鈴木', 'スズキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷郡阿見町岡崎', '08', '08443', '3000335', '茨城県', 'イバラキケン', '稲敷郡阿見町', 'イナシキグンアミマチ', '岡崎', 'オカザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷郡阿見町うずら野', '08', '08443', '3000341', '茨城県', 'イバラキケン', '稲敷郡阿見町', 'イナシキグンアミマチ', 'うずら野', 'ウズラノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市白石区東札幌4条', '01', '01104', '0030004', '北海道', 'ホッカイドウ', '札幌市白石区', 'サッポロシシロイシク', '東札幌4条', 'ヒガシサッポロ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷郡美浦村', '08', '08442', '3000400', '茨城県', 'イバラキケン', '稲敷郡美浦村', 'イナシキグンミホムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('20225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷郡美浦村馬掛', '08', '08442', '3000401', '茨城県', 'イバラキケン', '稲敷郡美浦村', 'イナシキグンミホムラ', '馬掛', 'マガキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷郡美浦村大山', '08', '08442', '3000402', '茨城県', 'イバラキケン', '稲敷郡美浦村', 'イナシキグンミホムラ', '大山', 'オオヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷郡美浦村馬見山', '08', '08442', '3000403', '茨城県', 'イバラキケン', '稲敷郡美浦村', 'イナシキグンミホムラ', '馬見山', 'マミヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷郡美浦村土浦', '08', '08442', '3000404', '茨城県', 'イバラキケン', '稲敷郡美浦村', 'イナシキグンミホムラ', '土浦', 'ツチウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷郡美浦村間野', '08', '08442', '3000405', '茨城県', 'イバラキケン', '稲敷郡美浦村', 'イナシキグンミホムラ', '間野', 'マノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷郡美浦村山内', '08', '08442', '3000406', '茨城県', 'イバラキケン', '稲敷郡美浦村', 'イナシキグンミホムラ', '山内', 'ヤマウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷郡美浦村八井田', '08', '08442', '3000407', '茨城県', 'イバラキケン', '稲敷郡美浦村', 'イナシキグンミホムラ', '八井田', 'ヤイタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷郡美浦村根火', '08', '08442', '3000408', '茨城県', 'イバラキケン', '稲敷郡美浦村', 'イナシキグンミホムラ', '根火', 'ネビ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷郡美浦村牛込', '08', '08442', '3000409', '茨城県', 'イバラキケン', '稲敷郡美浦村', 'イナシキグンミホムラ', '牛込', 'ウシゴメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷郡美浦村みどり台', '08', '08442', '3000410', '茨城県', 'イバラキケン', '稲敷郡美浦村', 'イナシキグンミホムラ', 'みどり台', 'ミドリダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷郡美浦村太田', '08', '08442', '3000411', '茨城県', 'イバラキケン', '稲敷郡美浦村', 'イナシキグンミホムラ', '太田', 'オオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷郡美浦村宮地', '08', '08442', '3000412', '茨城県', 'イバラキケン', '稲敷郡美浦村', 'イナシキグンミホムラ', '宮地', 'ミヤジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷郡美浦村大谷', '08', '08442', '3000413', '茨城県', 'イバラキケン', '稲敷郡美浦村', 'イナシキグンミホムラ', '大谷', 'オオヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷郡美浦村信太', '08', '08442', '3000414', '茨城県', 'イバラキケン', '稲敷郡美浦村', 'イナシキグンミホムラ', '信太', 'シダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷郡美浦村美駒', '08', '08442', '3000415', '茨城県', 'イバラキケン', '稲敷郡美浦村', 'イナシキグンミホムラ', '美駒', 'ミコマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷郡美浦村大塚', '08', '08442', '3000416', '茨城県', 'イバラキケン', '稲敷郡美浦村', 'イナシキグンミホムラ', '大塚', 'オオツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷郡美浦村谷中', '08', '08442', '3000417', '茨城県', 'イバラキケン', '稲敷郡美浦村', 'イナシキグンミホムラ', '谷中', 'ヤナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷郡美浦村花見塚', '08', '08442', '3000418', '茨城県', 'イバラキケン', '稲敷郡美浦村', 'イナシキグンミホムラ', '花見塚', 'ハナミヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷郡美浦村山王', '08', '08442', '3000419', '茨城県', 'イバラキケン', '稲敷郡美浦村', 'イナシキグンミホムラ', '山王', 'サンノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷郡美浦村郷中', '08', '08442', '3000420', '茨城県', 'イバラキケン', '稲敷郡美浦村', 'イナシキグンミホムラ', '郷中', 'ゴウナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷郡美浦村木原', '08', '08442', '3000421', '茨城県', 'イバラキケン', '稲敷郡美浦村', 'イナシキグンミホムラ', '木原', 'キハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷郡美浦村大須賀津', '08', '08442', '3000422', '茨城県', 'イバラキケン', '稲敷郡美浦村', 'イナシキグンミホムラ', '大須賀津', 'オオスカヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷郡美浦村茂呂', '08', '08442', '3000423', '茨城県', 'イバラキケン', '稲敷郡美浦村', 'イナシキグンミホムラ', '茂呂', 'モロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷郡美浦村受領', '08', '08442', '3000424', '茨城県', 'イバラキケン', '稲敷郡美浦村', 'イナシキグンミホムラ', '受領', 'ウケリョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷郡美浦村興津', '08', '08442', '3000425', '茨城県', 'イバラキケン', '稲敷郡美浦村', 'イナシキグンミホムラ', '興津', 'オキツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷郡美浦村土屋', '08', '08442', '3000426', '茨城県', 'イバラキケン', '稲敷郡美浦村', 'イナシキグンミホムラ', '土屋', 'ツチヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷郡美浦村布佐', '08', '08442', '3000427', '茨城県', 'イバラキケン', '稲敷郡美浦村', 'イナシキグンミホムラ', '布佐', 'フサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷郡美浦村舟子', '08', '08442', '3000428', '茨城県', 'イバラキケン', '稲敷郡美浦村', 'イナシキグンミホムラ', '舟子', 'フナコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷郡美浦村本橋', '08', '08442', '3000431', '茨城県', 'イバラキケン', '稲敷郡美浦村', 'イナシキグンミホムラ', '本橋', 'モトハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷郡美浦村定光', '08', '08442', '3000432', '茨城県', 'イバラキケン', '稲敷郡美浦村', 'イナシキグンミホムラ', '定光', 'ジョウコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷郡美浦村木', '08', '08442', '3000433', '茨城県', 'イバラキケン', '稲敷郡美浦村', 'イナシキグンミホムラ', '木', 'キ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷郡美浦村堀田', '08', '08442', '3000434', '茨城県', 'イバラキケン', '稲敷郡美浦村', 'イナシキグンミホムラ', '堀田', 'ホッタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷郡美浦村中野内', '08', '08442', '3000435', '茨城県', 'イバラキケン', '稲敷郡美浦村', 'イナシキグンミホムラ', '中野内', 'ナカノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷郡美浦村根本', '08', '08442', '3000436', '茨城県', 'イバラキケン', '稲敷郡美浦村', 'イナシキグンミホムラ', '根本', 'ネモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷郡美浦村見晴', '08', '08442', '3000437', '茨城県', 'イバラキケン', '稲敷郡美浦村', 'イナシキグンミホムラ', '見晴', 'ミハル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市白石区東札幌5条', '01', '01104', '0030005', '北海道', 'ホッカイドウ', '札幌市白石区', 'サッポロシシロイシク', '東札幌5条', 'ヒガシサッポロ05ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷市', '08', '08229', '3000500', '茨城県', 'イバラキケン', '稲敷市', 'イナシキシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('20264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷市鳩崎', '08', '08229', '3000501', '茨城県', 'イバラキケン', '稲敷市', 'イナシキシ', '鳩崎', 'ハトザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷市信太古渡', '08', '08229', '3000502', '茨城県', 'イバラキケン', '稲敷市', 'イナシキシ', '信太古渡', 'シダフット', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷市稲波', '08', '08229', '3000503', '茨城県', 'イバラキケン', '稲敷市', 'イナシキシ', '稲波', 'イナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷市江戸崎甲', '08', '08229', '3000504', '茨城県', 'イバラキケン', '稲敷市', 'イナシキシ', '江戸崎甲', 'エドサキコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷市村田', '08', '08229', '3000505', '茨城県', 'イバラキケン', '稲敷市', 'イナシキシ', '村田', 'ムラタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷市沼田', '08', '08229', '3000506', '茨城県', 'イバラキケン', '稲敷市', 'イナシキシ', '沼田', 'ヌマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷市犬塚', '08', '08229', '3000507', '茨城県', 'イバラキケン', '稲敷市', 'イナシキシ', '犬塚', 'イヌヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷市佐倉', '08', '08229', '3000508', '茨城県', 'イバラキケン', '稲敷市', 'イナシキシ', '佐倉', 'サクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷市江戸崎乙', '08', '08229', '3000509', '茨城県', 'イバラキケン', '稲敷市', 'イナシキシ', '江戸崎乙', 'エドサキオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷市高田', '08', '08229', '3000511', '茨城県', 'イバラキケン', '稲敷市', 'イナシキシ', '高田', 'タカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷市椎塚', '08', '08229', '3000512', '茨城県', 'イバラキケン', '稲敷市', 'イナシキシ', '椎塚', 'シイヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷市桑山', '08', '08229', '3000513', '茨城県', 'イバラキケン', '稲敷市', 'イナシキシ', '桑山', 'クワヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷市駒塚', '08', '08229', '3000514', '茨城県', 'イバラキケン', '稲敷市', 'イナシキシ', '駒塚', 'コマツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷市南ケ丘', '08', '08229', '3000515', '茨城県', 'イバラキケン', '稲敷市', 'イナシキシ', '南ケ丘', 'ミナミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷市月出里', '08', '08229', '3000521', '茨城県', 'イバラキケン', '稲敷市', 'イナシキシ', '月出里', 'スダチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷市蒲ケ山', '08', '08229', '3000522', '茨城県', 'イバラキケン', '稲敷市', 'イナシキシ', '蒲ケ山', 'カマガヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷市時崎', '08', '08229', '3000523', '茨城県', 'イバラキケン', '稲敷市', 'イナシキシ', '時崎', 'トキザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷市小羽賀', '08', '08229', '3000524', '茨城県', 'イバラキケン', '稲敷市', 'イナシキシ', '小羽賀', 'コハガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷市羽賀', '08', '08229', '3000525', '茨城県', 'イバラキケン', '稲敷市', 'イナシキシ', '羽賀', 'ハガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷市松山', '08', '08229', '3000526', '茨城県', 'イバラキケン', '稲敷市', 'イナシキシ', '松山', 'マツヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷市下君山', '08', '08229', '3000527', '茨城県', 'イバラキケン', '稲敷市', 'イナシキシ', '下君山', 'シモキミヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷市上君山', '08', '08229', '3000528', '茨城県', 'イバラキケン', '稲敷市', 'イナシキシ', '上君山', 'カミキミヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市白石区東札幌6条', '01', '01104', '0030006', '北海道', 'ホッカイドウ', '札幌市白石区', 'サッポロシシロイシク', '東札幌6条', 'ヒガシサッポロ06ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷市下須田', '08', '08229', '3000601', '茨城県', 'イバラキケン', '稲敷市', 'イナシキシ', '下須田', 'シモスダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷市阿波崎', '08', '08229', '3000602', '茨城県', 'イバラキケン', '稲敷市', 'イナシキシ', '阿波崎', 'アバサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷市伊佐部', '08', '08229', '3000603', '茨城県', 'イバラキケン', '稲敷市', 'イナシキシ', '伊佐部', 'イサブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷市釜井', '08', '08229', '3000604', '茨城県', 'イバラキケン', '稲敷市', 'イナシキシ', '釜井', 'カマイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷市幸田', '08', '08229', '3000605', '茨城県', 'イバラキケン', '稲敷市', 'イナシキシ', '幸田', 'コウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷市脇川', '08', '08229', '3000606', '茨城県', 'イバラキケン', '稲敷市', 'イナシキシ', '脇川', 'ワキガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷市光葉', '08', '08229', '3000607', '茨城県', 'イバラキケン', '稲敷市', 'イナシキシ', '光葉', 'ミツバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷市中島', '08', '08229', '3000611', '茨城県', 'イバラキケン', '稲敷市', 'イナシキシ', '中島', 'ナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷市市崎', '08', '08229', '3000612', '茨城県', 'イバラキケン', '稲敷市', 'イナシキシ', '市崎', 'イチザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷市新橋', '08', '08229', '3000613', '茨城県', 'イバラキケン', '稲敷市', 'イナシキシ', '新橋', 'シンバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷市清水', '08', '08229', '3000614', '茨城県', 'イバラキケン', '稲敷市', 'イナシキシ', '清水', 'シミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷市町田', '08', '08229', '3000615', '茨城県', 'イバラキケン', '稲敷市', 'イナシキシ', '町田', 'マチダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷市東大沼', '08', '08229', '3000616', '茨城県', 'イバラキケン', '稲敷市', 'イナシキシ', '東大沼', 'ヒガシオオヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷市福田', '08', '08229', '3000617', '茨城県', 'イバラキケン', '稲敷市', 'イナシキシ', '福田', 'フクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷市阿波', '08', '08229', '3000621', '茨城県', 'イバラキケン', '稲敷市', 'イナシキシ', '阿波', 'アバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷市神宮寺', '08', '08229', '3000622', '茨城県', 'イバラキケン', '稲敷市', 'イナシキシ', '神宮寺', 'ジングウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷市四箇', '08', '08229', '3000623', '茨城県', 'イバラキケン', '稲敷市', 'イナシキシ', '四箇', 'シカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷市南山来', '08', '08229', '3000624', '茨城県', 'イバラキケン', '稲敷市', 'イナシキシ', '南山来', 'ミナミヤマク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷市須賀津', '08', '08229', '3000625', '茨城県', 'イバラキケン', '稲敷市', 'イナシキシ', '須賀津', 'スカヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷市甘田', '08', '08229', '3000626', '茨城県', 'イバラキケン', '稲敷市', 'イナシキシ', '甘田', 'アマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷市三次', '08', '08229', '3000631', '茨城県', 'イバラキケン', '稲敷市', 'イナシキシ', '三次', 'ミツギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷市飯出', '08', '08229', '3000632', '茨城県', 'イバラキケン', '稲敷市', 'イナシキシ', '飯出', 'イイデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷市岡飯出', '08', '08229', '3000633', '茨城県', 'イバラキケン', '稲敷市', 'イナシキシ', '岡飯出', 'オカイイデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷市柏木', '08', '08229', '3000634', '茨城県', 'イバラキケン', '稲敷市', 'イナシキシ', '柏木', 'カシワギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷市堀之内', '08', '08229', '3000635', '茨城県', 'イバラキケン', '稲敷市', 'イナシキシ', '堀之内', 'ホリノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷市羽生', '08', '08229', '3000636', '茨城県', 'イバラキケン', '稲敷市', 'イナシキシ', '羽生', 'ハニュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷市柏木古渡', '08', '08229', '3000637', '茨城県', 'イバラキケン', '稲敷市', 'イナシキシ', '柏木古渡', 'カシワギフット', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷市古渡', '08', '08229', '3000638', '茨城県', 'イバラキケン', '稲敷市', 'イナシキシ', '古渡', 'フット', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷市浮島', '08', '08229', '3000641', '茨城県', 'イバラキケン', '稲敷市', 'イナシキシ', '浮島', 'ウキシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷市下馬渡', '08', '08229', '3000642', '茨城県', 'イバラキケン', '稲敷市', 'イナシキシ', '下馬渡', 'シモマワタシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷市上馬渡', '08', '08229', '3000643', '茨城県', 'イバラキケン', '稲敷市', 'イナシキシ', '上馬渡', 'カミマワタシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷市大島', '08', '08229', '3000721', '茨城県', 'イバラキケン', '稲敷市', 'イナシキシ', '大島', 'オオシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷市三島', '08', '08229', '3000722', '茨城県', 'イバラキケン', '稲敷市', 'イナシキシ', '三島', 'ミシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷市境島', '08', '08229', '3000723', '茨城県', 'イバラキケン', '稲敷市', 'イナシキシ', '境島', 'サカイジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷市八筋川', '08', '08229', '3000724', '茨城県', 'イバラキケン', '稲敷市', 'イナシキシ', '八筋川', 'ヤスジカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷市佐原下手', '08', '08229', '3000725', '茨城県', 'イバラキケン', '稲敷市', 'イナシキシ', '佐原下手', 'サワラシタテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷市西代', '08', '08229', '3000726', '茨城県', 'イバラキケン', '稲敷市', 'イナシキシ', '西代', 'ニシシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷市飯島', '08', '08229', '3000727', '茨城県', 'イバラキケン', '稲敷市', 'イナシキシ', '飯島', 'イイジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷市本新', '08', '08229', '3000731', '茨城県', 'イバラキケン', '稲敷市', 'イナシキシ', '本新', 'モトシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷市上之島', '08', '08229', '3000732', '茨城県', 'イバラキケン', '稲敷市', 'イナシキシ', '上之島', 'カミノシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷市石納', '08', '08229', '3000733', '茨城県', 'イバラキケン', '稲敷市', 'イナシキシ', '石納', 'コクノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷市結佐', '08', '08229', '3000734', '茨城県', 'イバラキケン', '稲敷市', 'イナシキシ', '結佐', 'ケッサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷市六角', '08', '08229', '3000735', '茨城県', 'イバラキケン', '稲敷市', 'イナシキシ', '六角', 'ロッカク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷市八千石', '08', '08229', '3000736', '茨城県', 'イバラキケン', '稲敷市', 'イナシキシ', '八千石', 'ハッセンゴク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷市上須田', '08', '08229', '3000737', '茨城県', 'イバラキケン', '稲敷市', 'イナシキシ', '上須田', 'カミスダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷市手賀組新田', '08', '08229', '3000741', '茨城県', 'イバラキケン', '稲敷市', 'イナシキシ', '手賀組新田', 'テガクミシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷市四ッ谷', '08', '08229', '3000742', '茨城県', 'イバラキケン', '稲敷市', 'イナシキシ', '四ッ谷', 'ヨツヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷市曲渕', '08', '08229', '3000743', '茨城県', 'イバラキケン', '稲敷市', 'イナシキシ', '曲渕', 'マガブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷市押砂', '08', '08229', '3000744', '茨城県', 'イバラキケン', '稲敷市', 'イナシキシ', '押砂', 'オシズナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷市橋向', '08', '08229', '3000745', '茨城県', 'イバラキケン', '稲敷市', 'イナシキシ', '橋向', 'ハシムコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷市神崎本宿', '08', '08229', '3000746', '茨城県', 'イバラキケン', '稲敷市', 'イナシキシ', '神崎本宿', 'コウザキホンジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷市余津谷', '08', '08229', '3000747', '茨城県', 'イバラキケン', '稲敷市', 'イナシキシ', '余津谷', 'ヨツヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷市清久島', '08', '08229', '3000748', '茨城県', 'イバラキケン', '稲敷市', 'イナシキシ', '清久島', 'セイキュウジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷市佐原組新田', '08', '08229', '3000749', '茨城県', 'イバラキケン', '稲敷市', 'イナシキシ', '佐原組新田', 'サワラグミシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市矢作', '08', '08203', '3000801', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '矢作', 'ヤハギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市飯田', '08', '08203', '3000802', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '飯田', 'イイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市佐野子', '08', '08203', '3000803', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '佐野子', 'サノコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市粕毛', '08', '08203', '3000804', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '粕毛', 'カスゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市宍塚', '08', '08203', '3000805', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '宍塚', 'シシツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市永国台', '08', '08203', '3000810', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '永国台', 'ナガクニダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市上高津', '08', '08203', '3000811', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '上高津', 'カミタカツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市下高津', '08', '08203', '3000812', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '下高津', 'シモタカツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市富士崎', '08', '08203', '3000813', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '富士崎', 'フジサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市国分町', '08', '08203', '3000814', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '国分町', 'コクブチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市中高津', '08', '08203', '3000815', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '中高津', 'ナカタカツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市永国東町', '08', '08203', '3000816', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '永国東町', 'ナガクニヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市永国', '08', '08203', '3000817', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '永国', 'ナガクニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市天川', '08', '08203', '3000818', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '天川', 'アマカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市上高津新町', '08', '08203', '3000819', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '上高津新町', 'カミタカツシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市蓮河原新町', '08', '08203', '3000821', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '蓮河原新町', 'ハスカワラシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市蓮河原町', '08', '08203', '3000822', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '蓮河原町', 'ハスカワラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市小松', '08', '08203', '3000823', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '小松', 'コマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市千鳥ケ丘町', '08', '08203', '3000824', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '千鳥ケ丘町', 'チドリガオカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市霞ケ岡町', '08', '08203', '3000825', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '霞ケ岡町', 'カスミガオカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市小松ケ丘町', '08', '08203', '3000826', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '小松ケ丘町', 'コマツガオカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市小岩田', '08', '08203', '3000831', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '小岩田', 'コイワタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市桜ケ丘町', '08', '08203', '3000832', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '桜ケ丘町', 'サクラガオカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市小岩田西', '08', '08203', '3000833', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '小岩田西', 'コイワダニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市小岩田東', '08', '08203', '3000834', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '小岩田東', 'コイワダヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市大岩田', '08', '08203', '3000835', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '大岩田', 'オオイワタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市烏山', '08', '08203', '3000836', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '烏山', 'カラスヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市右籾', '08', '08203', '3000837', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '右籾', 'ミギモミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市摩利山新田', '08', '08203', '3000838', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '摩利山新田', 'マリヤマシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市滝田', '08', '08203', '3000839', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '滝田', 'タキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市中', '08', '08203', '3000841', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '中', 'ナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市西根南', '08', '08203', '3000842', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '西根南', 'ニシネミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市中村南', '08', '08203', '3000843', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '中村南', 'ナカムラミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市乙戸', '08', '08203', '3000844', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '乙戸', 'オット', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市乙戸南', '08', '08203', '3000845', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '乙戸南', 'オットミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市小山田', '08', '08203', '3000846', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '小山田', 'オヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市卸町', '08', '08203', '3000847', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '卸町', 'オロシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市西根西', '08', '08203', '3000848', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '西根西', 'ニシネニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市中村西根', '08', '08203', '3000849', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '中村西根', 'ナカムラニシネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市中村東', '08', '08203', '3000850', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '中村東', 'ナカムラヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市荒川沖東', '08', '08203', '3000871', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '荒川沖東', 'アラカワオキヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市沖新田', '08', '08203', '3000872', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '沖新田', 'オキシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市荒川沖', '08', '08203', '3000873', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '荒川沖', 'アラカワオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市荒川沖西', '08', '08203', '3000874', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '荒川沖西', 'アラカワオキニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市中荒川沖町', '08', '08203', '3000875', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '中荒川沖町', 'ナカアラカワオキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市北荒川沖町', '08', '08203', '3000876', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '北荒川沖町', 'キタアラカワオキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市荒川本郷', '08', '08203', '3000877', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '荒川本郷', 'アラカワホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市白石区中央1条', '01', '01104', '0030011', '北海道', 'ホッカイドウ', '札幌市白石区', 'サッポロシシロイシク', '中央1条', 'チュウオウ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市荒川', '02', '02201', '0300111', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '荒川', 'アラカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市八ツ役', '02', '02201', '0300112', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '八ツ役', 'ヤツヤク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市第二問屋町', '02', '02201', '0300113', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '第二問屋町', 'ダイニトンヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷郡阿見町荒川沖', '08', '08443', '3001151', '茨城県', 'イバラキケン', '稲敷郡阿見町', 'イナシキグンアミマチ', '荒川沖', 'アラカワオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷郡阿見町荒川本郷', '08', '08443', '3001152', '茨城県', 'イバラキケン', '稲敷郡阿見町', 'イナシキグンアミマチ', '荒川本郷', 'アラカワホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷郡阿見町実穀', '08', '08443', '3001153', '茨城県', 'イバラキケン', '稲敷郡阿見町', 'イナシキグンアミマチ', '実穀', 'ジツコク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷郡阿見町上長', '08', '08443', '3001154', '茨城県', 'イバラキケン', '稲敷郡阿見町', 'イナシキグンアミマチ', '上長', 'カミナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷郡阿見町吉原', '08', '08443', '3001155', '茨城県', 'イバラキケン', '稲敷郡阿見町', 'イナシキグンアミマチ', '吉原', 'ヨシワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷郡阿見町福田', '08', '08443', '3001156', '茨城県', 'イバラキケン', '稲敷郡阿見町', 'イナシキグンアミマチ', '福田', 'フクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷郡阿見町小池', '08', '08443', '3001157', '茨城県', 'イバラキケン', '稲敷郡阿見町', 'イナシキグンアミマチ', '小池', 'コイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷郡阿見町住吉', '08', '08443', '3001158', '茨城県', 'イバラキケン', '稲敷郡阿見町', 'イナシキグンアミマチ', '住吉', 'スミヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市白石区中央2条', '01', '01104', '0030012', '北海道', 'ホッカイドウ', '札幌市白石区', 'サッポロシシロイシク', '中央2条', 'チュウオウ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県牛久市', '08', '08219', '3001200', '茨城県', 'イバラキケン', '牛久市', 'ウシクシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('20409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県牛久市東猯穴町', '08', '08219', '3001201', '茨城県', 'イバラキケン', '牛久市', 'ウシクシ', '東猯穴町', 'ヒガシマミアナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県牛久市中根町', '08', '08219', '3001202', '茨城県', 'イバラキケン', '牛久市', 'ウシクシ', '中根町', 'ナカネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県牛久市下根町', '08', '08219', '3001203', '茨城県', 'イバラキケン', '牛久市', 'ウシクシ', '下根町', 'シモネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県牛久市岡見町', '08', '08219', '3001204', '茨城県', 'イバラキケン', '牛久市', 'ウシクシ', '岡見町', 'オカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県牛久市東大和田町', '08', '08219', '3001205', '茨城県', 'イバラキケン', '牛久市', 'ウシクシ', '東大和田町', 'ヒガシオオワダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県牛久市ひたち野西', '08', '08219', '3001206', '茨城県', 'イバラキケン', '牛久市', 'ウシクシ', 'ひたち野西', 'ヒタチノニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県牛久市ひたち野東', '08', '08219', '3001207', '茨城県', 'イバラキケン', '牛久市', 'ウシクシ', 'ひたち野東', 'ヒタチノヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市妙見', '02', '02201', '0300121', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '妙見', 'ミョウケン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県牛久市柏田町', '08', '08219', '3001211', '茨城県', 'イバラキケン', '牛久市', 'ウシクシ', '柏田町', 'カシワダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県牛久市結束町', '08', '08219', '3001212', '茨城県', 'イバラキケン', '牛久市', 'ウシクシ', '結束町', 'ケッソクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県牛久市上太田町', '08', '08219', '3001213', '茨城県', 'イバラキケン', '牛久市', 'ウシクシ', '上太田町', 'カミオオタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県牛久市女化町', '08', '08219', '3001214', '茨城県', 'イバラキケン', '牛久市', 'ウシクシ', '女化町', 'オナバケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県牛久市遠山町', '08', '08219', '3001215', '茨城県', 'イバラキケン', '牛久市', 'ウシクシ', '遠山町', 'トオヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県牛久市神谷', '08', '08219', '3001216', '茨城県', 'イバラキケン', '牛久市', 'ウシクシ', '神谷', 'カミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県牛久市さくら台', '08', '08219', '3001217', '茨城県', 'イバラキケン', '牛久市', 'ウシクシ', 'さくら台', 'サクラダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市野尻', '02', '02201', '0300122', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '野尻', 'ノジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県牛久市牛久町', '08', '08219', '3001221', '茨城県', 'イバラキケン', '牛久市', 'ウシクシ', '牛久町', 'ウシクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県牛久市南', '08', '08219', '3001222', '茨城県', 'イバラキケン', '牛久市', 'ウシクシ', '南', 'ミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県牛久市城中町', '08', '08219', '3001223', '茨城県', 'イバラキケン', '牛久市', 'ウシクシ', '城中町', 'ジョウチュウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県牛久市庄兵衛新田町', '08', '08219', '3001224', '茨城県', 'イバラキケン', '牛久市', 'ウシクシ', '庄兵衛新田町', 'ショウベエシンデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県牛久市新地町', '08', '08219', '3001225', '茨城県', 'イバラキケン', '牛久市', 'ウシクシ', '新地町', 'シンチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市大矢沢', '02', '02201', '0300123', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '大矢沢', 'オオヤサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県牛久市猪子町', '08', '08219', '3001231', '茨城県', 'イバラキケン', '牛久市', 'ウシクシ', '猪子町', 'シシコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県牛久市上柏田', '08', '08219', '3001232', '茨城県', 'イバラキケン', '牛久市', 'ウシクシ', '上柏田', 'カミカシワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県牛久市栄町', '08', '08219', '3001233', '茨城県', 'イバラキケン', '牛久市', 'ウシクシ', '栄町', 'サカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県牛久市中央', '08', '08219', '3001234', '茨城県', 'イバラキケン', '牛久市', 'ウシクシ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県牛久市刈谷町', '08', '08219', '3001235', '茨城県', 'イバラキケン', '牛久市', 'ウシクシ', '刈谷町', 'カリヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県牛久市田宮町', '08', '08219', '3001236', '茨城県', 'イバラキケン', '牛久市', 'ウシクシ', '田宮町', 'タグウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県牛久市田宮', '08', '08219', '3001237', '茨城県', 'イバラキケン', '牛久市', 'ウシクシ', '田宮', 'タグウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市田茂木野', '02', '02201', '0300124', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '田茂木野', 'タモギノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市池の台', '08', '08220', '3001240', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '池の台', 'イケノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市牧園', '08', '08220', '3001241', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '牧園', 'マキゾノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市樋の沢', '08', '08220', '3001242', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '樋の沢', 'ヒノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市大井', '08', '08220', '3001243', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '大井', 'オオイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市松の里', '08', '08220', '3001244', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '松の里', 'マツノサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市高崎', '08', '08220', '3001245', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '高崎', 'タカサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市菅間', '08', '08220', '3001246', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '菅間', 'スガマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市西の沢', '08', '08220', '3001247', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '西の沢', 'ニシノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市若栗', '08', '08220', '3001248', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '若栗', 'ワカグリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市若葉', '08', '08220', '3001249', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '若葉', 'ワカバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市四ツ石', '02', '02201', '0300125', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '四ツ石', 'ヨツイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市城山', '08', '08220', '3001251', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '城山', 'シロヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市高見原', '08', '08220', '3001252', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '高見原', 'タカミハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市天宝喜', '08', '08220', '3001253', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '天宝喜', 'アマボウキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市宝陽台', '08', '08220', '3001254', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '宝陽台', 'ホウヨウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市小茎', '08', '08220', '3001255', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '小茎', 'オグキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市森の里', '08', '08220', '3001256', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '森の里', 'モリノサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市明神', '08', '08220', '3001257', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '明神', 'ミョウジン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市六斗', '08', '08220', '3001258', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '六斗', 'ロクト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市稲荷原', '08', '08220', '3001259', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '稲荷原', 'イナリハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市西大井', '08', '08220', '3001260', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '西大井', 'ニシオオイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市あしび野', '08', '08220', '3001261', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', 'あしび野', 'アシビノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市九万坪', '08', '08220', '3001262', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '九万坪', 'クマンツボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市富士見台', '08', '08220', '3001263', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '富士見台', 'フジミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市泊崎', '08', '08220', '3001264', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '泊崎', 'ハッサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市細見', '08', '08220', '3001265', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '細見', 'ホソミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市自由ケ丘', '08', '08220', '3001266', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '自由ケ丘', 'ジユウガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市大舟戸', '08', '08220', '3001267', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '大舟戸', 'オオフナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市中山', '08', '08220', '3001268', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '中山', 'ナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市池向', '08', '08220', '3001269', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '池向', 'イケムカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市桜が丘', '08', '08220', '3001271', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '桜が丘', 'サクラガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市茎崎', '08', '08220', '3001272', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '茎崎', 'クキザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市下岩崎', '08', '08220', '3001273', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '下岩崎', 'シモイワサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市上岩崎', '08', '08220', '3001274', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '上岩崎', 'カミイワサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市梅ケ丘', '08', '08220', '3001275', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '梅ケ丘', 'ウメガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市小山', '08', '08220', '3001276', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '小山', 'コヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市駒込', '08', '08220', '3001277', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '駒込', 'コマゴメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市房内', '08', '08220', '3001278', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '房内', 'ボウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県牛久市桂町', '08', '08219', '3001281', '茨城県', 'イバラキケン', '牛久市', 'ウシクシ', '桂町', 'カツラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県牛久市井ノ岡町', '08', '08219', '3001282', '茨城県', 'イバラキケン', '牛久市', 'ウシクシ', '井ノ岡町', 'イノオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県牛久市奥原町', '08', '08219', '3001283', '茨城県', 'イバラキケン', '牛久市', 'ウシクシ', '奥原町', 'オクバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県牛久市島田町', '08', '08219', '3001284', '茨城県', 'イバラキケン', '牛久市', 'ウシクシ', '島田町', 'シマダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県牛久市正直町', '08', '08219', '3001285', '茨城県', 'イバラキケン', '牛久市', 'ウシクシ', '正直町', 'ショウジキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県牛久市小坂町', '08', '08219', '3001286', '茨城県', 'イバラキケン', '牛久市', 'ウシクシ', '小坂町', 'オサカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県牛久市福田町', '08', '08219', '3001287', '茨城県', 'イバラキケン', '牛久市', 'ウシクシ', '福田町', 'フクダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県牛久市久野町', '08', '08219', '3001288', '茨城県', 'イバラキケン', '牛久市', 'ウシクシ', '久野町', 'クノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市白石区中央3条', '01', '01104', '0030013', '北海道', 'ホッカイドウ', '札幌市白石区', 'サッポロシシロイシク', '中央3条', 'チュウオウ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷郡河内町', '08', '08447', '3001300', '茨城県', 'イバラキケン', '稲敷郡河内町', 'イナシキグンカワチマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('20492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市問屋町', '02', '02201', '0300131', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '問屋町', 'トンヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷郡河内町庄布川', '08', '08447', '3001311', '茨城県', 'イバラキケン', '稲敷郡河内町', 'イナシキグンカワチマチ', '庄布川', 'ショウブカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷郡河内町長竿', '08', '08447', '3001312', '茨城県', 'イバラキケン', '稲敷郡河内町', 'イナシキグンカワチマチ', '長竿', 'ナガサオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷郡河内町田川', '08', '08447', '3001313', '茨城県', 'イバラキケン', '稲敷郡河内町', 'イナシキグンカワチマチ', '田川', 'タガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷郡河内町下町歩', '08', '08447', '3001314', '茨城県', 'イバラキケン', '稲敷郡河内町', 'イナシキグンカワチマチ', '下町歩', 'シモチョウブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷郡河内町十里', '08', '08447', '3001315', '茨城県', 'イバラキケン', '稲敷郡河内町', 'イナシキグンカワチマチ', '十里', 'ジュウリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷郡河内町布鎌', '08', '08447', '3001316', '茨城県', 'イバラキケン', '稲敷郡河内町', 'イナシキグンカワチマチ', '布鎌', 'フカマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市横内', '02', '02201', '0300132', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '横内', 'ヨコウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷郡河内町羽子騎', '08', '08447', '3001321', '茨城県', 'イバラキケン', '稲敷郡河内町', 'イナシキグンカワチマチ', '羽子騎', 'ハネキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷郡河内町古河林', '08', '08447', '3001322', '茨城県', 'イバラキケン', '稲敷郡河内町', 'イナシキグンカワチマチ', '古河林', 'コガバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷郡河内町手栗', '08', '08447', '3001323', '茨城県', 'イバラキケン', '稲敷郡河内町', 'イナシキグンカワチマチ', '手栗', 'テグリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷郡河内町源清田', '08', '08447', '3001324', '茨城県', 'イバラキケン', '稲敷郡河内町', 'イナシキグンカワチマチ', '源清田', 'ゲンセイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷郡河内町平三郎', '08', '08447', '3001325', '茨城県', 'イバラキケン', '稲敷郡河内町', 'イナシキグンカワチマチ', '平三郎', 'ヘイザブロウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷郡河内町宮淵', '08', '08447', '3001326', '茨城県', 'イバラキケン', '稲敷郡河内町', 'イナシキグンカワチマチ', '宮淵', 'ミヤブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷郡河内町猿島', '08', '08447', '3001327', '茨城県', 'イバラキケン', '稲敷郡河内町', 'イナシキグンカワチマチ', '猿島', 'サシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市雲谷', '02', '02201', '0300133', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '雲谷', 'モヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷郡河内町生板', '08', '08447', '3001331', '茨城県', 'イバラキケン', '稲敷郡河内町', 'イナシキグンカワチマチ', '生板', 'マナイタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷郡河内町幸谷', '08', '08447', '3001332', '茨城県', 'イバラキケン', '稲敷郡河内町', 'イナシキグンカワチマチ', '幸谷', 'コウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷郡河内町角崎町歩', '08', '08447', '3001333', '茨城県', 'イバラキケン', '稲敷郡河内町', 'イナシキグンカワチマチ', '角崎町歩', 'スミザキチョウブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷郡河内町小林町歩', '08', '08447', '3001334', '茨城県', 'イバラキケン', '稲敷郡河内町', 'イナシキグンカワチマチ', '小林町歩', 'コバヤシチョウブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷郡河内町生板鍋子新田', '08', '08447', '3001335', '茨城県', 'イバラキケン', '稲敷郡河内町', 'イナシキグンカワチマチ', '生板鍋子新田', 'マナイタナベコシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷郡河内町大徳鍋子新田', '08', '08447', '3001336', '茨城県', 'イバラキケン', '稲敷郡河内町', 'イナシキグンカワチマチ', '大徳鍋子新田', 'ダイトクナベコシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷郡河内町竜ケ崎町歩', '08', '08447', '3001337', '茨城県', 'イバラキケン', '稲敷郡河内町', 'イナシキグンカワチマチ', '竜ケ崎町歩', 'リュウガサキチョウブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市合子沢', '02', '02201', '0300134', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '合子沢', 'ゴウシザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市新町野', '02', '02201', '0300135', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '新町野', 'シンマチノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市牛館', '02', '02201', '0300136', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '牛館', 'ウシタテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市卸町', '02', '02201', '0300137', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '卸町', 'オロシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷郡河内町十三間戸', '08', '08447', '3001401', '茨城県', 'イバラキケン', '稲敷郡河内町', 'イナシキグンカワチマチ', '十三間戸', 'ジュウサンマド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷郡河内町平川', '08', '08447', '3001402', '茨城県', 'イバラキケン', '稲敷郡河内町', 'イナシキグンカワチマチ', '平川', 'ヒラカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷郡河内町金江津', '08', '08447', '3001403', '茨城県', 'イバラキケン', '稲敷郡河内町', 'イナシキグンカワチマチ', '金江津', 'カナエツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷郡河内町片巻', '08', '08447', '3001404', '茨城県', 'イバラキケン', '稲敷郡河内町', 'イナシキグンカワチマチ', '片巻', 'カタマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷郡河内町田川', '08', '08447', '3001405', '茨城県', 'イバラキケン', '稲敷郡河内町', 'イナシキグンカワチマチ', '田川', 'タガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷郡河内町下加納', '08', '08447', '3001406', '茨城県', 'イバラキケン', '稲敷郡河内町', 'イナシキグンカワチマチ', '下加納', 'シモカノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市上野', '02', '02201', '0300141', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '上野', 'ウワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷市伊佐津', '08', '08229', '3001411', '茨城県', 'イバラキケン', '稲敷市', 'イナシキシ', '伊佐津', 'イサツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷市柴崎', '08', '08229', '3001412', '茨城県', 'イバラキケン', '稲敷市', 'イナシキシ', '柴崎', 'シバサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷市伊崎', '08', '08229', '3001413', '茨城県', 'イバラキケン', '稲敷市', 'イナシキシ', '伊崎', 'イサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷市戌渡', '08', '08229', '3001414', '茨城県', 'イバラキケン', '稲敷市', 'イナシキシ', '戌渡', 'イヌワタリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷市中山', '08', '08229', '3001415', '茨城県', 'イバラキケン', '稲敷市', 'イナシキシ', '中山', 'ナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷市角崎', '08', '08229', '3001416', '茨城県', 'イバラキケン', '稲敷市', 'イナシキシ', '角崎', 'スミザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷市狸穴', '08', '08229', '3001417', '茨城県', 'イバラキケン', '稲敷市', 'イナシキシ', '狸穴', 'マミアナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市野木', '02', '02201', '0300142', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '野木', 'ノギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷市堀川', '08', '08229', '3001421', '茨城県', 'イバラキケン', '稲敷市', 'イナシキシ', '堀川', 'ホリカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷市南太田', '08', '08229', '3001422', '茨城県', 'イバラキケン', '稲敷市', 'イナシキシ', '南太田', 'ミナミオオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷市太田', '08', '08229', '3001423', '茨城県', 'イバラキケン', '稲敷市', 'イナシキシ', '太田', 'オオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷市下太田', '08', '08229', '3001424', '茨城県', 'イバラキケン', '稲敷市', 'イナシキシ', '下太田', 'シモオオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷市小野', '08', '08229', '3001425', '茨城県', 'イバラキケン', '稲敷市', 'イナシキシ', '小野', 'オノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷市寺内', '08', '08229', '3001426', '茨城県', 'イバラキケン', '稲敷市', 'イナシキシ', '寺内', 'テラウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷市羽賀浦', '08', '08229', '3001427', '茨城県', 'イバラキケン', '稲敷市', 'イナシキシ', '羽賀浦', 'ハガウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市小畑沢', '02', '02201', '0300143', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '小畑沢', 'オバタケザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市大別内', '02', '02201', '0300144', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '大別内', 'オオベツナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市金浜', '02', '02201', '0300145', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '金浜', 'カネハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県取手市双葉', '08', '08217', '3001501', '茨城県', 'イバラキケン', '取手市', 'トリデシ', '双葉', 'フタバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県取手市新川', '08', '08217', '3001502', '茨城県', 'イバラキケン', '取手市', 'トリデシ', '新川', 'シンカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県取手市大曲', '08', '08217', '3001503', '茨城県', 'イバラキケン', '取手市', 'トリデシ', '大曲', 'オオマガリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県取手市萱場', '08', '08217', '3001504', '茨城県', 'イバラキケン', '取手市', 'トリデシ', '萱場', 'カヤバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県取手市下萱場', '08', '08217', '3001505', '茨城県', 'イバラキケン', '取手市', 'トリデシ', '下萱場', 'シモカヤバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県取手市上萱場', '08', '08217', '3001506', '茨城県', 'イバラキケン', '取手市', 'トリデシ', '上萱場', 'カミカヤバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県取手市浜田', '08', '08217', '3001507', '茨城県', 'イバラキケン', '取手市', 'トリデシ', '浜田', 'ハマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県取手市紫水', '08', '08217', '3001508', '茨城県', 'イバラキケン', '取手市', 'トリデシ', '紫水', 'シスイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市高田', '02', '02201', '0300151', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '高田', 'タカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県取手市椚木', '08', '08217', '3001511', '茨城県', 'イバラキケン', '取手市', 'トリデシ', '椚木', 'クヌギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県取手市藤代', '08', '08217', '3001512', '茨城県', 'イバラキケン', '取手市', 'トリデシ', '藤代', 'フジシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県取手市片町', '08', '08217', '3001513', '茨城県', 'イバラキケン', '取手市', 'トリデシ', '片町', 'カタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県取手市宮和田', '08', '08217', '3001514', '茨城県', 'イバラキケン', '取手市', 'トリデシ', '宮和田', 'ミヤワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県取手市平野', '08', '08217', '3001515', '茨城県', 'イバラキケン', '取手市', 'トリデシ', '平野', 'ヒラノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県取手市藤代南', '08', '08217', '3001516', '茨城県', 'イバラキケン', '取手市', 'トリデシ', '藤代南', 'フジシロミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市野沢', '02', '02201', '0300152', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '野沢', 'ノザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県取手市押切', '08', '08217', '3001521', '茨城県', 'イバラキケン', '取手市', 'トリデシ', '押切', 'オシキリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県取手市高須', '08', '08217', '3001522', '茨城県', 'イバラキケン', '取手市', 'トリデシ', '高須', 'タカス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県取手市大留', '08', '08217', '3001523', '茨城県', 'イバラキケン', '取手市', 'トリデシ', '大留', 'オオドメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県取手市神浦', '08', '08217', '3001524', '茨城県', 'イバラキケン', '取手市', 'トリデシ', '神浦', 'カンノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県取手市桜が丘', '08', '08217', '3001525', '茨城県', 'イバラキケン', '取手市', 'トリデシ', '桜が丘', 'サクラガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市小館', '02', '02201', '0300153', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '小館', 'コダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県取手市小浮気', '08', '08217', '3001531', '茨城県', 'イバラキケン', '取手市', 'トリデシ', '小浮気', 'コブケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県取手市谷中', '08', '08217', '3001532', '茨城県', 'イバラキケン', '取手市', 'トリデシ', '谷中', 'ヤナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県取手市中田', '08', '08217', '3001533', '茨城県', 'イバラキケン', '取手市', 'トリデシ', '中田', 'ナカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県取手市渋沼', '08', '08217', '3001534', '茨城県', 'イバラキケン', '取手市', 'トリデシ', '渋沼', 'シブヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県取手市清水', '08', '08217', '3001535', '茨城県', 'イバラキケン', '取手市', 'トリデシ', '清水', 'シミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県取手市光風台', '08', '08217', '3001536', '茨城県', 'イバラキケン', '取手市', 'トリデシ', '光風台', 'コウフウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県取手市毛有', '08', '08217', '3001537', '茨城県', 'イバラキケン', '取手市', 'トリデシ', '毛有', 'ケアリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県取手市米田', '08', '08217', '3001538', '茨城県', 'イバラキケン', '取手市', 'トリデシ', '米田', 'ヨネダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県取手市小泉', '08', '08217', '3001539', '茨城県', 'イバラキケン', '取手市', 'トリデシ', '小泉', 'コイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市入内', '02', '02201', '0300154', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '入内', 'ニュウナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県取手市配松', '08', '08217', '3001541', '茨城県', 'イバラキケン', '取手市', 'トリデシ', '配松', 'ハイマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県取手市神住', '08', '08217', '3001542', '茨城県', 'イバラキケン', '取手市', 'トリデシ', '神住', 'カスミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県取手市中内', '08', '08217', '3001543', '茨城県', 'イバラキケン', '取手市', 'トリデシ', '中内', 'ナカウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県取手市山王', '08', '08217', '3001544', '茨城県', 'イバラキケン', '取手市', 'トリデシ', '山王', 'サンノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県取手市和田', '08', '08217', '3001545', '茨城県', 'イバラキケン', '取手市', 'トリデシ', '和田', 'ワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県取手市岡', '08', '08217', '3001546', '茨城県', 'イバラキケン', '取手市', 'トリデシ', '岡', 'オカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市大谷', '02', '02201', '0300155', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '大谷', 'オオタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県北相馬郡利根町', '08', '08564', '3001600', '茨城県', 'イバラキケン', '北相馬郡利根町', 'キタソウマグントネマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('20586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県北相馬郡利根町大房', '08', '08564', '3001601', '茨城県', 'イバラキケン', '北相馬郡利根町', 'キタソウマグントネマチ', '大房', 'ダイボウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県北相馬郡利根町押戸', '08', '08564', '3001602', '茨城県', 'イバラキケン', '北相馬郡利根町', 'キタソウマグントネマチ', '押戸', 'オシド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県北相馬郡利根町奥山', '08', '08564', '3001603', '茨城県', 'イバラキケン', '北相馬郡利根町', 'キタソウマグントネマチ', '奥山', 'オクヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県北相馬郡利根町横須賀', '08', '08564', '3001604', '茨城県', 'イバラキケン', '北相馬郡利根町', 'キタソウマグントネマチ', '横須賀', 'ヨコスカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県北相馬郡利根町大平', '08', '08564', '3001605', '茨城県', 'イバラキケン', '北相馬郡利根町', 'キタソウマグントネマチ', '大平', 'ダイヘイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県北相馬郡利根町もえぎ野台', '08', '08564', '3001606', '茨城県', 'イバラキケン', '北相馬郡利根町', 'キタソウマグントネマチ', 'もえぎ野台', 'モエギノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県北相馬郡利根町惣新田', '08', '08564', '3001611', '茨城県', 'イバラキケン', '北相馬郡利根町', 'キタソウマグントネマチ', '惣新田', 'ソウシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県北相馬郡利根町加納新田', '08', '08564', '3001612', '茨城県', 'イバラキケン', '北相馬郡利根町', 'キタソウマグントネマチ', '加納新田', 'カノウシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県北相馬郡利根町東奥山新田', '08', '08564', '3001613', '茨城県', 'イバラキケン', '北相馬郡利根町', 'キタソウマグントネマチ', '東奥山新田', 'ヒガシオクヤマシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県北相馬郡利根町立崎', '08', '08564', '3001614', '茨城県', 'イバラキケン', '北相馬郡利根町', 'キタソウマグントネマチ', '立崎', 'タツザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県北相馬郡利根町中谷', '08', '08564', '3001615', '茨城県', 'イバラキケン', '北相馬郡利根町', 'キタソウマグントネマチ', '中谷', 'ナカヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県北相馬郡利根町立木', '08', '08564', '3001616', '茨城県', 'イバラキケン', '北相馬郡利根町', 'キタソウマグントネマチ', '立木', 'タツギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県北相馬郡利根町福木', '08', '08564', '3001621', '茨城県', 'イバラキケン', '北相馬郡利根町', 'キタソウマグントネマチ', '福木', 'フクノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県北相馬郡利根町布川', '08', '08564', '3001622', '茨城県', 'イバラキケン', '北相馬郡利根町', 'キタソウマグントネマチ', '布川', 'フカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県北相馬郡利根町八幡台', '08', '08564', '3001623', '茨城県', 'イバラキケン', '北相馬郡利根町', 'キタソウマグントネマチ', '八幡台', 'ハチマンダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県北相馬郡利根町中田切', '08', '08564', '3001624', '茨城県', 'イバラキケン', '北相馬郡利根町', 'キタソウマグントネマチ', '中田切', 'ナカタギリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県北相馬郡利根町羽中', '08', '08564', '3001625', '茨城県', 'イバラキケン', '北相馬郡利根町', 'キタソウマグントネマチ', '羽中', 'ハナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県北相馬郡利根町四季の丘', '08', '08564', '3001626', '茨城県', 'イバラキケン', '北相馬郡利根町', 'キタソウマグントネマチ', '四季の丘', 'シキノオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県北相馬郡利根町早尾', '08', '08564', '3001631', '茨城県', 'イバラキケン', '北相馬郡利根町', 'キタソウマグントネマチ', '早尾', 'ハヤオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県北相馬郡利根町下曽根', '08', '08564', '3001632', '茨城県', 'イバラキケン', '北相馬郡利根町', 'キタソウマグントネマチ', '下曽根', 'シモゾネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県北相馬郡利根町下井', '08', '08564', '3001633', '茨城県', 'イバラキケン', '北相馬郡利根町', 'キタソウマグントネマチ', '下井', 'シモイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県北相馬郡利根町押付新田', '08', '08564', '3001634', '茨城県', 'イバラキケン', '北相馬郡利根町', 'キタソウマグントネマチ', '押付新田', 'オシツケシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県北相馬郡利根町上曽根', '08', '08564', '3001635', '茨城県', 'イバラキケン', '北相馬郡利根町', 'キタソウマグントネマチ', '上曽根', 'カミゾネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県北相馬郡利根町羽根野', '08', '08564', '3001636', '茨城県', 'イバラキケン', '北相馬郡利根町', 'キタソウマグントネマチ', '羽根野', 'ハネノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市白石区栄通', '01', '01104', '0030021', '北海道', 'ホッカイドウ', '札幌市白石区', 'サッポロシシロイシク', '栄通', 'サカエドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市白石区南郷通南', '01', '01104', '0030022', '北海道', 'ホッカイドウ', '札幌市白石区', 'サッポロシシロイシク', '南郷通', 'ナンゴウドオリ', null, null, '南', 'ミナミ');
INSERT INTO `ms_addresses` VALUES ('20622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市白石区南郷通北', '01', '01104', '0030023', '北海道', 'ホッカイドウ', '札幌市白石区', 'サッポロシシロイシク', '南郷通', 'ナンゴウドオリ', null, null, '北', 'キタ');
INSERT INTO `ms_addresses` VALUES ('20623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくばみらい市', '08', '08235', '3002300', '茨城県', 'イバラキケン', 'つくばみらい市', 'ツクバミライシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('20624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくばみらい市高岡', '08', '08235', '3002301', '茨城県', 'イバラキケン', 'つくばみらい市', 'ツクバミライシ', '高岡', 'タカオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくばみらい市狸穴', '08', '08235', '3002302', '茨城県', 'イバラキケン', 'つくばみらい市', 'ツクバミライシ', '狸穴', 'マミアナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくばみらい市大和田', '08', '08235', '3002303', '茨城県', 'イバラキケン', 'つくばみらい市', 'ツクバミライシ', '大和田', 'オオワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくばみらい市武兵衛新田', '08', '08235', '3002304', '茨城県', 'イバラキケン', 'つくばみらい市', 'ツクバミライシ', '武兵衛新田', 'ブヘエシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくばみらい市重右衛門新田', '08', '08235', '3002305', '茨城県', 'イバラキケン', 'つくばみらい市', 'ツクバミライシ', '重右衛門新田', 'ジュウエモンシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくばみらい市南太田', '08', '08235', '3002306', '茨城県', 'イバラキケン', 'つくばみらい市', 'ツクバミライシ', '南太田', 'ミナミオオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくばみらい市板橋', '08', '08235', '3002307', '茨城県', 'イバラキケン', 'つくばみらい市', 'ツクバミライシ', '板橋', 'イタバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくばみらい市伊奈東', '08', '08235', '3002308', '茨城県', 'イバラキケン', 'つくばみらい市', 'ツクバミライシ', '伊奈東', 'イナヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくばみらい市野堀', '08', '08235', '3002311', '茨城県', 'イバラキケン', 'つくばみらい市', 'ツクバミライシ', '野堀', 'ノボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくばみらい市神生', '08', '08235', '3002312', '茨城県', 'イバラキケン', 'つくばみらい市', 'ツクバミライシ', '神生', 'カンノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくばみらい市東栗山', '08', '08235', '3002313', '茨城県', 'イバラキケン', 'つくばみらい市', 'ツクバミライシ', '東栗山', 'ヒガシクリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくばみらい市城中', '08', '08235', '3002314', '茨城県', 'イバラキケン', 'つくばみらい市', 'ツクバミライシ', '城中', 'ジョウチュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくばみらい市足高', '08', '08235', '3002315', '茨城県', 'イバラキケン', 'つくばみらい市', 'ツクバミライシ', '足高', 'アダカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくばみらい市戸茂', '08', '08235', '3002321', '茨城県', 'イバラキケン', 'つくばみらい市', 'ツクバミライシ', '戸茂', 'トモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくばみらい市戸崎', '08', '08235', '3002322', '茨城県', 'イバラキケン', 'つくばみらい市', 'ツクバミライシ', '戸崎', 'トサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくばみらい市伊丹', '08', '08235', '3002323', '茨城県', 'イバラキケン', 'つくばみらい市', 'ツクバミライシ', '伊丹', 'イタミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくばみらい市下島', '08', '08235', '3002324', '茨城県', 'イバラキケン', 'つくばみらい市', 'ツクバミライシ', '下島', 'シモジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくばみらい市中島', '08', '08235', '3002325', '茨城県', 'イバラキケン', 'つくばみらい市', 'ツクバミライシ', '中島', 'ナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくばみらい市上島', '08', '08235', '3002326', '茨城県', 'イバラキケン', 'つくばみらい市', 'ツクバミライシ', '上島', 'カミジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくばみらい市福原', '08', '08235', '3002327', '茨城県', 'イバラキケン', 'つくばみらい市', 'ツクバミライシ', '福原', 'フクワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくばみらい市神住新田', '08', '08235', '3002331', '茨城県', 'イバラキケン', 'つくばみらい市', 'ツクバミライシ', '神住新田', 'カスミシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくばみらい市山王新田', '08', '08235', '3002332', '茨城県', 'イバラキケン', 'つくばみらい市', 'ツクバミライシ', '山王新田', 'サンノウシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくばみらい市下平柳', '08', '08235', '3002333', '茨城県', 'イバラキケン', 'つくばみらい市', 'ツクバミライシ', '下平柳', 'シモヒラヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくばみらい市中平柳', '08', '08235', '3002334', '茨城県', 'イバラキケン', 'つくばみらい市', 'ツクバミライシ', '中平柳', 'ナカヒラヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくばみらい市上平柳', '08', '08235', '3002335', '茨城県', 'イバラキケン', 'つくばみらい市', 'ツクバミライシ', '上平柳', 'カミヒラヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくばみらい市山谷', '08', '08235', '3002336', '茨城県', 'イバラキケン', 'つくばみらい市', 'ツクバミライシ', '山谷', 'サンヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくばみらい市谷井田', '08', '08235', '3002337', '茨城県', 'イバラキケン', 'つくばみらい市', 'ツクバミライシ', '谷井田', 'ヤイタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくばみらい市福田', '08', '08235', '3002341', '茨城県', 'イバラキケン', 'つくばみらい市', 'ツクバミライシ', '福田', 'フクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくばみらい市弥柳', '08', '08235', '3002342', '茨城県', 'イバラキケン', 'つくばみらい市', 'ツクバミライシ', '弥柳', 'イヨヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくばみらい市狸渕', '08', '08235', '3002343', '茨城県', 'イバラキケン', 'つくばみらい市', 'ツクバミライシ', '狸渕', 'ムジナブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくばみらい市長渡呂新田', '08', '08235', '3002344', '茨城県', 'イバラキケン', 'つくばみらい市', 'ツクバミライシ', '長渡呂新田', 'ナガトロシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくばみらい市長渡呂', '08', '08235', '3002345', '茨城県', 'イバラキケン', 'つくばみらい市', 'ツクバミライシ', '長渡呂', 'ナガトロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくばみらい市青木', '08', '08235', '3002346', '茨城県', 'イバラキケン', 'つくばみらい市', 'ツクバミライシ', '青木', 'アオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくばみらい市豊体', '08', '08235', '3002347', '茨城県', 'イバラキケン', 'つくばみらい市', 'ツクバミライシ', '豊体', 'ブタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくばみらい市青古新田', '08', '08235', '3002348', '茨城県', 'イバラキケン', 'つくばみらい市', 'ツクバミライシ', '青古新田', 'アオコシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくばみらい市善助新田', '08', '08235', '3002351', '茨城県', 'イバラキケン', 'つくばみらい市', 'ツクバミライシ', '善助新田', 'ゼンスケシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくばみらい市小島新田', '08', '08235', '3002352', '茨城県', 'イバラキケン', 'つくばみらい市', 'ツクバミライシ', '小島新田', 'オジマシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくばみらい市小張', '08', '08235', '3002353', '茨城県', 'イバラキケン', 'つくばみらい市', 'ツクバミライシ', '小張', 'オバリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくばみらい市新戸', '08', '08235', '3002354', '茨城県', 'イバラキケン', 'つくばみらい市', 'ツクバミライシ', '新戸', 'アラト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくばみらい市市野深', '08', '08235', '3002355', '茨城県', 'イバラキケン', 'つくばみらい市', 'ツクバミライシ', '市野深', 'イチノフカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくばみらい市奉社', '08', '08235', '3002356', '茨城県', 'イバラキケン', 'つくばみらい市', 'ツクバミライシ', '奉社', 'ビシャ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくばみらい市谷口', '08', '08235', '3002357', '茨城県', 'イバラキケン', 'つくばみらい市', 'ツクバミライシ', '谷口', 'ヤグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくばみらい市小張陽光台', '08', '08235', '3002358', '茨城県', 'イバラキケン', 'つくばみらい市', 'ツクバミライシ', '小張', 'オバリ', null, null, '陽光台', 'ヨウコウダイ');
INSERT INTO `ms_addresses` VALUES ('20667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくばみらい市東楢戸陽光台', '08', '08235', '3002358', '茨城県', 'イバラキケン', 'つくばみらい市', 'ツクバミライシ', '東楢戸', 'ヒガシナラド', null, null, '陽光台', 'ヨウコウダイ');
INSERT INTO `ms_addresses` VALUES ('20668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくばみらい市小島新田紫峰ヶ丘', '08', '08235', '3002359', '茨城県', 'イバラキケン', 'つくばみらい市', 'ツクバミライシ', '小島新田', 'オジマシンデン', null, null, '紫峰ヶ丘', 'シホウガオカ');
INSERT INTO `ms_addresses` VALUES ('20669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくばみらい市小張紫峰ヶ丘', '08', '08235', '3002359', '茨城県', 'イバラキケン', 'つくばみらい市', 'ツクバミライシ', '小張', 'オバリ', null, null, '紫峰ヶ丘', 'シホウガオカ');
INSERT INTO `ms_addresses` VALUES ('20670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくばみらい市田村紫峰ヶ丘', '08', '08235', '3002359', '茨城県', 'イバラキケン', 'つくばみらい市', 'ツクバミライシ', '田村', 'タムラ', null, null, '紫峰ヶ丘', 'シホウガオカ');
INSERT INTO `ms_addresses` VALUES ('20671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくばみらい市西楢戸紫峰ヶ丘', '08', '08235', '3002359', '茨城県', 'イバラキケン', 'つくばみらい市', 'ツクバミライシ', '西楢戸', 'ニシナラド', null, null, '紫峰ヶ丘', 'シホウガオカ');
INSERT INTO `ms_addresses` VALUES ('20672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくばみらい市東楢戸紫峰ヶ丘', '08', '08235', '3002359', '茨城県', 'イバラキケン', 'つくばみらい市', 'ツクバミライシ', '東楢戸', 'ヒガシナラド', null, null, '紫峰ヶ丘', 'シホウガオカ');
INSERT INTO `ms_addresses` VALUES ('20674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市白石区本郷通南', '01', '01104', '0030024', '北海道', 'ホッカイドウ', '札幌市白石区', 'サッポロシシロイシク', '本郷通', 'ホンゴウドオリ', null, null, '南', 'ミナミ');
INSERT INTO `ms_addresses` VALUES ('20675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくばみらい市台', '08', '08235', '3002401', '茨城県', 'イバラキケン', 'つくばみらい市', 'ツクバミライシ', '台', 'ダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくばみらい市坂野新田', '08', '08235', '3002402', '茨城県', 'イバラキケン', 'つくばみらい市', 'ツクバミライシ', '坂野新田', 'サカノシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくばみらい市中原', '08', '08235', '3002403', '茨城県', 'イバラキケン', 'つくばみらい市', 'ツクバミライシ', '中原', 'ナカハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくばみらい市南', '08', '08235', '3002404', '茨城県', 'イバラキケン', 'つくばみらい市', 'ツクバミライシ', '南', 'ミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくばみらい市仁左衛門新田', '08', '08235', '3002405', '茨城県', 'イバラキケン', 'つくばみらい市', 'ツクバミライシ', '仁左衛門新田', 'ニザエモンシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくばみらい市福岡', '08', '08235', '3002406', '茨城県', 'イバラキケン', 'つくばみらい市', 'ツクバミライシ', '福岡', 'フクオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくばみらい市北山', '08', '08235', '3002407', '茨城県', 'イバラキケン', 'つくばみらい市', 'ツクバミライシ', '北山', 'キタヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくばみらい市押砂', '08', '08235', '3002411', '茨城県', 'イバラキケン', 'つくばみらい市', 'ツクバミライシ', '押砂', 'オシズナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくばみらい市日川', '08', '08235', '3002412', '茨城県', 'イバラキケン', 'つくばみらい市', 'ツクバミライシ', '日川', 'ニッカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくばみらい市田村', '08', '08235', '3002413', '茨城県', 'イバラキケン', 'つくばみらい市', 'ツクバミライシ', '田村', 'タムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくばみらい市真木', '08', '08235', '3002414', '茨城県', 'イバラキケン', 'つくばみらい市', 'ツクバミライシ', '真木', 'マギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくばみらい市西楢戸', '08', '08235', '3002415', '茨城県', 'イバラキケン', 'つくばみらい市', 'ツクバミライシ', '西楢戸', 'ニシナラド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくばみらい市東楢戸', '08', '08235', '3002416', '茨城県', 'イバラキケン', 'つくばみらい市', 'ツクバミライシ', '東楢戸', 'ヒガシナラド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくばみらい市田村富士見ヶ丘', '08', '08235', '3002417', '茨城県', 'イバラキケン', 'つくばみらい市', 'ツクバミライシ', '田村', 'タムラ', null, null, '富士見ヶ丘', 'フジミガオカ');
INSERT INTO `ms_addresses` VALUES ('20689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくばみらい市西楢戸富士見ヶ丘', '08', '08235', '3002417', '茨城県', 'イバラキケン', 'つくばみらい市', 'ツクバミライシ', '西楢戸', 'ニシナラド', null, null, '富士見ヶ丘', 'フジミガオカ');
INSERT INTO `ms_addresses` VALUES ('20690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくばみらい市東楢戸富士見ヶ丘', '08', '08235', '3002417', '茨城県', 'イバラキケン', 'つくばみらい市', 'ツクバミライシ', '東楢戸', 'ヒガシナラド', null, null, '富士見ヶ丘', 'フジミガオカ');
INSERT INTO `ms_addresses` VALUES ('20691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくばみらい市真木富士見ヶ丘', '08', '08235', '3002417', '茨城県', 'イバラキケン', 'つくばみらい市', 'ツクバミライシ', '真木', 'マギ', null, null, '富士見ヶ丘', 'フジミガオカ');
INSERT INTO `ms_addresses` VALUES ('20692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくばみらい市西丸山', '08', '08235', '3002421', '茨城県', 'イバラキケン', 'つくばみらい市', 'ツクバミライシ', '西丸山', 'ニシマルヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくばみらい市古川', '08', '08235', '3002422', '茨城県', 'イバラキケン', 'つくばみらい市', 'ツクバミライシ', '古川', 'フルカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくばみらい市成瀬', '08', '08235', '3002423', '茨城県', 'イバラキケン', 'つくばみらい市', 'ツクバミライシ', '成瀬', 'ナルセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくばみらい市加藤', '08', '08235', '3002424', '茨城県', 'イバラキケン', 'つくばみらい市', 'ツクバミライシ', '加藤', 'カトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくばみらい市川崎', '08', '08235', '3002425', '茨城県', 'イバラキケン', 'つくばみらい市', 'ツクバミライシ', '川崎', 'カワサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくばみらい市宮戸', '08', '08235', '3002426', '茨城県', 'イバラキケン', 'つくばみらい市', 'ツクバミライシ', '宮戸', 'ミヤド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくばみらい市上小目', '08', '08235', '3002431', '茨城県', 'イバラキケン', 'つくばみらい市', 'ツクバミライシ', '上小目', 'カミオメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくばみらい市鬼長', '08', '08235', '3002432', '茨城県', 'イバラキケン', 'つくばみらい市', 'ツクバミライシ', '鬼長', 'オニオサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくばみらい市下小目', '08', '08235', '3002433', '茨城県', 'イバラキケン', 'つくばみらい市', 'ツクバミライシ', '下小目', 'シモオメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくばみらい市平沼', '08', '08235', '3002434', '茨城県', 'イバラキケン', 'つくばみらい市', 'ツクバミライシ', '平沼', 'ヒラヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくばみらい市筒戸', '08', '08235', '3002435', '茨城県', 'イバラキケン', 'つくばみらい市', 'ツクバミライシ', '筒戸', 'ツツド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくばみらい市絹の台', '08', '08235', '3002436', '茨城県', 'イバラキケン', 'つくばみらい市', 'ツクバミライシ', '絹の台', 'キヌノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくばみらい市寺畑', '08', '08235', '3002441', '茨城県', 'イバラキケン', 'つくばみらい市', 'ツクバミライシ', '寺畑', 'テラハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくばみらい市西ノ台', '08', '08235', '3002442', '茨城県', 'イバラキケン', 'つくばみらい市', 'ツクバミライシ', '西ノ台', 'ニシノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくばみらい市西ノ台南', '08', '08235', '3002443', '茨城県', 'イバラキケン', 'つくばみらい市', 'ツクバミライシ', '西ノ台南', 'ニシノダイミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくばみらい市杉下', '08', '08235', '3002444', '茨城県', 'イバラキケン', 'つくばみらい市', 'ツクバミライシ', '杉下', 'スギシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくばみらい市小絹', '08', '08235', '3002445', '茨城県', 'イバラキケン', 'つくばみらい市', 'ツクバミライシ', '小絹', 'コキヌ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくばみらい市細代', '08', '08235', '3002446', '茨城県', 'イバラキケン', 'つくばみらい市', 'ツクバミライシ', '細代', 'ホソシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくばみらい市箕輪', '08', '08235', '3002451', '茨城県', 'イバラキケン', 'つくばみらい市', 'ツクバミライシ', '箕輪', 'ミノワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくばみらい市樛木', '08', '08235', '3002452', '茨城県', 'イバラキケン', 'つくばみらい市', 'ツクバミライシ', '樛木', 'ツキヌキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくばみらい市上長沼', '08', '08235', '3002453', '茨城県', 'イバラキケン', 'つくばみらい市', 'ツクバミライシ', '上長沼', 'カミナガヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくばみらい市下長沼', '08', '08235', '3002454', '茨城県', 'イバラキケン', 'つくばみらい市', 'ツクバミライシ', '下長沼', 'シモナガヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくばみらい市十和', '08', '08235', '3002455', '茨城県', 'イバラキケン', 'つくばみらい市', 'ツクバミライシ', '十和', 'ジュウワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくばみらい市北袋', '08', '08235', '3002456', '茨城県', 'イバラキケン', 'つくばみらい市', 'ツクバミライシ', '北袋', 'キタブクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市白石区本郷通北', '01', '01104', '0030025', '北海道', 'ホッカイドウ', '札幌市白石区', 'サッポロシシロイシク', '本郷通', 'ホンゴウドオリ', null, null, '北', 'キタ');
INSERT INTO `ms_addresses` VALUES ('20724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常総市福二町', '08', '08211', '3002501', '茨城県', 'イバラキケン', '常総市', 'ジョウソウシ', '福二町', 'フクジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常総市上蛇町', '08', '08211', '3002502', '茨城県', 'イバラキケン', '常総市', 'ジョウソウシ', '上蛇町', 'ジョウジャマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常総市川崎町', '08', '08211', '3002503', '茨城県', 'イバラキケン', '常総市', 'ジョウソウシ', '川崎町', 'カワサキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常総市沖新田町', '08', '08211', '3002504', '茨城県', 'イバラキケン', '常総市', 'ジョウソウシ', '沖新田町', 'オキシンデンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常総市中妻町', '08', '08211', '3002505', '茨城県', 'イバラキケン', '常総市', 'ジョウソウシ', '中妻町', 'ナカツママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常総市三坂町', '08', '08211', '3002506', '茨城県', 'イバラキケン', '常総市', 'ジョウソウシ', '三坂町', 'ミサカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常総市三坂新田町', '08', '08211', '3002507', '茨城県', 'イバラキケン', '常総市', 'ジョウソウシ', '三坂新田町', 'ミサカシンデンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常総市花島町', '08', '08211', '3002511', '茨城県', 'イバラキケン', '常総市', 'ジョウソウシ', '花島町', 'ハナシママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常総市大輪町', '08', '08211', '3002512', '茨城県', 'イバラキケン', '常総市', 'ジョウソウシ', '大輪町', 'オオワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常総市羽生町', '08', '08211', '3002513', '茨城県', 'イバラキケン', '常総市', 'ジョウソウシ', '羽生町', 'ハニュウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常総市大生郷町', '08', '08211', '3002521', '茨城県', 'イバラキケン', '常総市', 'ジョウソウシ', '大生郷町', 'オオノゴウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常総市横曽根新田町', '08', '08211', '3002522', '茨城県', 'イバラキケン', '常総市', 'ジョウソウシ', '横曽根新田町', 'ヨコゾネシンデンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常総市笹塚新田町', '08', '08211', '3002523', '茨城県', 'イバラキケン', '常総市', 'ジョウソウシ', '笹塚新田町', 'ササツカシンデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常総市五郎兵衛新田町', '08', '08211', '3002524', '茨城県', 'イバラキケン', '常総市', 'ジョウソウシ', '五郎兵衛新田町', 'ゴロベエシンデンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常総市伊左衛門新田町', '08', '08211', '3002525', '茨城県', 'イバラキケン', '常総市', 'ジョウソウシ', '伊左衛門新田町', 'イザエモンシンデンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常総市大生郷新田町', '08', '08211', '3002526', '茨城県', 'イバラキケン', '常総市', 'ジョウソウシ', '大生郷新田町', 'オオノゴウシンデンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市白石区本通南', '01', '01104', '0030026', '北海道', 'ホッカイドウ', '札幌市白石区', 'サッポロシシロイシク', '本通', 'ホンドオリ', null, null, '南', 'ミナミ');
INSERT INTO `ms_addresses` VALUES ('20743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市大久保', '08', '08220', '3002611', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '大久保', 'オオクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市大砂', '08', '08220', '3002612', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '大砂', 'オオスナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市西高野', '08', '08220', '3002613', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '西高野', 'ニシゴウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市上里', '08', '08220', '3002614', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '上里', 'カミサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市田倉', '08', '08220', '3002615', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '田倉', 'タクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市五人受', '08', '08220', '3002616', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '五人受', 'ゴニンウケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市吉沼', '08', '08220', '3002617', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '吉沼', 'ヨシヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市南原', '08', '08220', '3002621', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '南原', 'ミナミハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市要', '08', '08220', '3002622', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '要', 'カナメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市本沢', '08', '08220', '3002623', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '本沢', 'ホンザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市西沢', '08', '08220', '3002624', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '西沢', 'ニシザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市沼崎', '08', '08220', '3002631', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '沼崎', 'ヌマザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市旭', '08', '08220', '3002632', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '旭', 'アサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市遠東', '08', '08220', '3002633', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '遠東', 'トオヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市中東原新田', '08', '08220', '3002634', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '中東原新田', 'ナカヒガシハラシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市東光台', '08', '08220', '3002635', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '東光台', 'トウコウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市土田', '08', '08220', '3002636', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '土田', 'ツチダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市酒丸', '08', '08220', '3002637', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '酒丸', 'サケマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市百家', '08', '08220', '3002638', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '百家', 'ハッケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市今鹿島', '08', '08220', '3002641', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '今鹿島', 'イマカシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市高野', '08', '08220', '3002642', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '高野', 'コウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市野畑', '08', '08220', '3002643', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '野畑', 'ノバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市木俣', '08', '08220', '3002644', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '木俣', 'コノマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市上郷', '08', '08220', '3002645', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '上郷', 'カミゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市緑ケ原', '08', '08220', '3002646', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '緑ケ原', 'ミドリガハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市手子生', '08', '08220', '3002647', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '手子生', 'テゴマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市豊里の杜', '08', '08220', '3002648', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '豊里の杜', 'トヨサトノモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市鬼ケ窪', '08', '08220', '3002651', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '鬼ケ窪', 'オニガクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市高田', '08', '08220', '3002652', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '高田', 'タカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市面野井', '08', '08220', '3002653', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '面野井', 'オモノイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市水堀', '08', '08220', '3002654', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '水堀', 'ミズボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市島名', '08', '08220', '3002655', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '島名', 'シマナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市真瀬', '08', '08220', '3002656', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '真瀬', 'マセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市香取台', '08', '08220', '3002657', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '香取台', 'カトリダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市諏訪', '08', '08220', '3002658', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '諏訪', 'スワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市上河原崎', '08', '08220', '3002661', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '上河原崎', 'カミカワラザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市下河原崎', '08', '08220', '3002662', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '下河原崎', 'シモカワラザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市鍋沼新田', '08', '08220', '3002663', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '鍋沼新田', 'ナベヌマシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市高良田', '08', '08220', '3002664', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '高良田', 'タカラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市高須賀', '08', '08220', '3002665', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '高須賀', 'タカスカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市下別府', '08', '08220', '3002666', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '下別府', 'シモベップ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市中別府', '08', '08220', '3002667', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '中別府', 'ナカベップ', null, null, null, null), ('20786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市白石区本通北', '01', '01104', '0030027', '北海道', 'ホッカイドウ', '札幌市白石区', 'サッポロシシロイシク', '本通', 'ホンドオリ', null, null, '北', 'キタ'), ('20787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常総市若宮戸', '08', '08211', '3002701', '茨城県', 'イバラキケン', '常総市', 'ジョウソウシ', '若宮戸', 'ワカミヤド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常総市原宿', '08', '08211', '3002702', '茨城県', 'イバラキケン', '常総市', 'ジョウソウシ', '原宿', 'ハラジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常総市小保川', '08', '08211', '3002703', '茨城県', 'イバラキケン', '常総市', 'ジョウソウシ', '小保川', 'オボカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常総市舘方', '08', '08211', '3002704', '茨城県', 'イバラキケン', '常総市', 'ジョウソウシ', '舘方', 'タテガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常総市豊田', '08', '08211', '3002705', '茨城県', 'イバラキケン', '常総市', 'ジョウソウシ', '豊田', 'トヨダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常総市新石下', '08', '08211', '3002706', '茨城県', 'イバラキケン', '常総市', 'ジョウソウシ', '新石下', 'シンイシゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常総市本石下', '08', '08211', '3002707', '茨城県', 'イバラキケン', '常総市', 'ジョウソウシ', '本石下', 'モトイシゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常総市本豊田', '08', '08211', '3002711', '茨城県', 'イバラキケン', '常総市', 'ジョウソウシ', '本豊田', 'モトトヨダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常総市曲田', '08', '08211', '3002712', '茨城県', 'イバラキケン', '常総市', 'ジョウソウシ', '曲田', 'マガッタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常総市収納谷', '08', '08211', '3002713', '茨城県', 'イバラキケン', '常総市', 'ジョウソウシ', '収納谷', 'スノウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常総市平内', '08', '08211', '3002714', '茨城県', 'イバラキケン', '常総市', 'ジョウソウシ', '平内', 'ヘイナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常総市山口', '08', '08211', '3002715', '茨城県', 'イバラキケン', '常総市', 'ジョウソウシ', '山口', 'ヤマグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常総市大房', '08', '08211', '3002716', '茨城県', 'イバラキケン', '常総市', 'ジョウソウシ', '大房', 'ダイボウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常総市東野原', '08', '08211', '3002717', '茨城県', 'イバラキケン', '常総市', 'ジョウソウシ', '東野原', 'トウノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常総市篠山', '08', '08211', '3002721', '茨城県', 'イバラキケン', '常総市', 'ジョウソウシ', '篠山', 'シノヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常総市蔵持', '08', '08211', '3002722', '茨城県', 'イバラキケン', '常総市', 'ジョウソウシ', '蔵持', 'クラモチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常総市蔵持新田', '08', '08211', '3002723', '茨城県', 'イバラキケン', '常総市', 'ジョウソウシ', '蔵持新田', 'クラモチシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常総市古間木', '08', '08211', '3002724', '茨城県', 'イバラキケン', '常総市', 'ジョウソウシ', '古間木', 'フルマギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常総市古間木沼新田', '08', '08211', '3002725', '茨城県', 'イバラキケン', '常総市', 'ジョウソウシ', '古間木沼新田', 'フルマギヌマシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常総市中沼', '08', '08211', '3002726', '茨城県', 'イバラキケン', '常総市', 'ジョウソウシ', '中沼', 'ナカヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常総市大沢', '08', '08211', '3002727', '茨城県', 'イバラキケン', '常総市', 'ジョウソウシ', '大沢', 'オオサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常総市古間木新田', '08', '08211', '3002731', '茨城県', 'イバラキケン', '常総市', 'ジョウソウシ', '古間木新田', 'フルマギシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常総市鴻野山新田', '08', '08211', '3002732', '茨城県', 'イバラキケン', '常総市', 'ジョウソウシ', '鴻野山新田', 'コウノヤマシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常総市馬場新田', '08', '08211', '3002733', '茨城県', 'イバラキケン', '常総市', 'ジョウソウシ', '馬場新田', 'ババシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常総市栗山新田', '08', '08211', '3002734', '茨城県', 'イバラキケン', '常総市', 'ジョウソウシ', '栗山新田', 'クリヤマシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常総市左平太新田', '08', '08211', '3002735', '茨城県', 'イバラキケン', '常総市', 'ジョウソウシ', '左平太新田', 'サヘイタシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常総市孫兵ヱ新田', '08', '08211', '3002736', '茨城県', 'イバラキケン', '常総市', 'ジョウソウシ', '孫兵ヱ新田', 'マゴベエシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常総市国生', '08', '08211', '3002741', '茨城県', 'イバラキケン', '常総市', 'ジョウソウシ', '国生', 'コッショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常総市向石下', '08', '08211', '3002742', '茨城県', 'イバラキケン', '常総市', 'ジョウソウシ', '向石下', 'ムコウイシゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常総市岡田', '08', '08211', '3002743', '茨城県', 'イバラキケン', '常総市', 'ジョウソウシ', '岡田', 'オカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常総市杉山', '08', '08211', '3002744', '茨城県', 'イバラキケン', '常総市', 'ジョウソウシ', '杉山', 'スギヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常総市大沢新田', '08', '08211', '3002745', '茨城県', 'イバラキケン', '常総市', 'ジョウソウシ', '大沢新田', 'オオサワシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常総市鴻野山', '08', '08211', '3002746', '茨城県', 'イバラキケン', '常総市', 'ジョウソウシ', '鴻野山', 'コウノヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常総市崎房', '08', '08211', '3002747', '茨城県', 'イバラキケン', '常総市', 'ジョウソウシ', '崎房', 'サキブサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常総市馬場', '08', '08211', '3002748', '茨城県', 'イバラキケン', '常総市', 'ジョウソウシ', '馬場', 'ババ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市白石区平和通南', '01', '01104', '0030028', '北海道', 'ホッカイドウ', '札幌市白石区', 'サッポロシシロイシク', '平和通', 'ヘイワドオリ', null, null, '南', 'ミナミ');
INSERT INTO `ms_addresses` VALUES ('20828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市白石区平和通北', '01', '01104', '0030029', '北海道', 'ホッカイドウ', '札幌市白石区', 'サッポロシシロイシク', '平和通', 'ヘイワドオリ', null, null, '北', 'キタ');
INSERT INTO `ms_addresses` VALUES ('20829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市白石区流通センター', '01', '01104', '0030030', '北海道', 'ホッカイドウ', '札幌市白石区', 'サッポロシシロイシク', '流通センター', 'リュウツウセンター', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市佐', '08', '08220', '3003251', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '佐', 'サ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市若森', '08', '08220', '3003252', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '若森', 'ワカモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市大曽根', '08', '08220', '3003253', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '大曽根', 'オオゾネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市鹿島台', '08', '08220', '3003254', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '鹿島台', 'カシマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市玉取', '08', '08220', '3003255', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '玉取', 'タマトリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市大穂', '08', '08220', '3003256', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '大穂', 'オオホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市筑穂', '08', '08220', '3003257', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '筑穂', 'ツクホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市花畑', '08', '08220', '3003261', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '花畑', 'ハナバタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市蓮沼', '08', '08220', '3003262', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '蓮沼', 'ハスヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市立原', '08', '08220', '3003263', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '立原', 'タチハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市篠崎', '08', '08220', '3003264', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '篠崎', 'シノザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市長高野', '08', '08220', '3003265', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '長高野', 'オサゴウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市北原', '08', '08220', '3003266', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '北原', 'キタハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市前野', '08', '08220', '3003267', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '前野', 'マエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県結城郡八千代町', '08', '08521', '3003500', '茨城県', 'イバラキケン', '結城郡八千代町', 'ユウキグンヤチヨマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('20848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県結城郡八千代町塩本', '08', '08521', '3003501', '茨城県', 'イバラキケン', '結城郡八千代町', 'ユウキグンヤチヨマチ', '塩本', 'シオモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県結城郡八千代町下山川', '08', '08521', '3003502', '茨城県', 'イバラキケン', '結城郡八千代町', 'ユウキグンヤチヨマチ', '下山川', 'シモヤマカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県結城郡八千代町粕礼', '08', '08521', '3003503', '茨城県', 'イバラキケン', '結城郡八千代町', 'ユウキグンヤチヨマチ', '粕礼', 'カスレイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県結城郡八千代町西大山', '08', '08521', '3003504', '茨城県', 'イバラキケン', '結城郡八千代町', 'ユウキグンヤチヨマチ', '西大山', 'ニシオオヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県結城郡八千代町佐野', '08', '08521', '3003505', '茨城県', 'イバラキケン', '結城郡八千代町', 'ユウキグンヤチヨマチ', '佐野', 'サノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県結城郡八千代町成田', '08', '08521', '3003506', '茨城県', 'イバラキケン', '結城郡八千代町', 'ユウキグンヤチヨマチ', '成田', 'ナリタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県結城郡八千代町瀬戸井', '08', '08521', '3003511', '茨城県', 'イバラキケン', '結城郡八千代町', 'ユウキグンヤチヨマチ', '瀬戸井', 'セトイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県結城郡八千代町小屋', '08', '08521', '3003512', '茨城県', 'イバラキケン', '結城郡八千代町', 'ユウキグンヤチヨマチ', '小屋', 'コヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県結城郡八千代町久下田', '08', '08521', '3003513', '茨城県', 'イバラキケン', '結城郡八千代町', 'ユウキグンヤチヨマチ', '久下田', 'クゲタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県結城郡八千代町大里', '08', '08521', '3003514', '茨城県', 'イバラキケン', '結城郡八千代町', 'ユウキグンヤチヨマチ', '大里', 'オオサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県結城郡八千代町大渡戸', '08', '08521', '3003515', '茨城県', 'イバラキケン', '結城郡八千代町', 'ユウキグンヤチヨマチ', '大渡戸', 'オオワダド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県結城郡八千代町高崎', '08', '08521', '3003516', '茨城県', 'イバラキケン', '結城郡八千代町', 'ユウキグンヤチヨマチ', '高崎', 'タカサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県結城郡八千代町坪井', '08', '08521', '3003517', '茨城県', 'イバラキケン', '結城郡八千代町', 'ユウキグンヤチヨマチ', '坪井', 'ツボイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県結城郡八千代町野爪', '08', '08521', '3003518', '茨城県', 'イバラキケン', '結城郡八千代町', 'ユウキグンヤチヨマチ', '野爪', 'ノツメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県結城郡八千代町新井', '08', '08521', '3003519', '茨城県', 'イバラキケン', '結城郡八千代町', 'ユウキグンヤチヨマチ', '新井', 'アライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県結城郡八千代町川尻', '08', '08521', '3003521', '茨城県', 'イバラキケン', '結城郡八千代町', 'ユウキグンヤチヨマチ', '川尻', 'カワジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県結城郡八千代町袋', '08', '08521', '3003522', '茨城県', 'イバラキケン', '結城郡八千代町', 'ユウキグンヤチヨマチ', '袋', 'フクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県結城郡八千代町八町', '08', '08521', '3003523', '茨城県', 'イバラキケン', '結城郡八千代町', 'ユウキグンヤチヨマチ', '八町', 'ハッチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県結城郡八千代町兵庫', '08', '08521', '3003524', '茨城県', 'イバラキケン', '結城郡八千代町', 'ユウキグンヤチヨマチ', '兵庫', 'ヒョウゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県結城郡八千代町沼森', '08', '08521', '3003525', '茨城県', 'イバラキケン', '結城郡八千代町', 'ユウキグンヤチヨマチ', '沼森', 'ヌマモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県結城郡八千代町貝谷', '08', '08521', '3003526', '茨城県', 'イバラキケン', '結城郡八千代町', 'ユウキグンヤチヨマチ', '貝谷', 'カイヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県結城郡八千代町東原', '08', '08521', '3003527', '茨城県', 'イバラキケン', '結城郡八千代町', 'ユウキグンヤチヨマチ', '東原', 'ヒガシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県結城郡八千代町今里', '08', '08521', '3003531', '茨城県', 'イバラキケン', '結城郡八千代町', 'ユウキグンヤチヨマチ', '今里', 'イマザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県結城郡八千代町本郷', '08', '08521', '3003532', '茨城県', 'イバラキケン', '結城郡八千代町', 'ユウキグンヤチヨマチ', '本郷', 'ホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県結城郡八千代町片角', '08', '08521', '3003533', '茨城県', 'イバラキケン', '結城郡八千代町', 'ユウキグンヤチヨマチ', '片角', 'カタカク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県結城郡八千代町太田', '08', '08521', '3003534', '茨城県', 'イバラキケン', '結城郡八千代町', 'ユウキグンヤチヨマチ', '太田', 'オオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県結城郡八千代町粟野', '08', '08521', '3003535', '茨城県', 'イバラキケン', '結城郡八千代町', 'ユウキグンヤチヨマチ', '粟野', 'アワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県結城郡八千代町中野', '08', '08521', '3003536', '茨城県', 'イバラキケン', '結城郡八千代町', 'ユウキグンヤチヨマチ', '中野', 'ナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県結城郡八千代町苅橋', '08', '08521', '3003537', '茨城県', 'イバラキケン', '結城郡八千代町', 'ユウキグンヤチヨマチ', '苅橋', 'カリハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県結城郡八千代町東大山', '08', '08521', '3003538', '茨城県', 'イバラキケン', '結城郡八千代町', 'ユウキグンヤチヨマチ', '東大山', 'ヒガシオオヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県結城郡八千代町仁江戸', '08', '08521', '3003539', '茨城県', 'イバラキケン', '結城郡八千代町', 'ユウキグンヤチヨマチ', '仁江戸', 'ニエド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県結城郡八千代町新地', '08', '08521', '3003541', '茨城県', 'イバラキケン', '結城郡八千代町', 'ユウキグンヤチヨマチ', '新地', 'シンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県結城郡八千代町福岡', '08', '08521', '3003542', '茨城県', 'イバラキケン', '結城郡八千代町', 'ユウキグンヤチヨマチ', '福岡', 'フクオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県結城郡八千代町新地新田', '08', '08521', '3003543', '茨城県', 'イバラキケン', '結城郡八千代町', 'ユウキグンヤチヨマチ', '新地新田', 'シンチシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県結城郡八千代町若', '08', '08521', '3003544', '茨城県', 'イバラキケン', '結城郡八千代町', 'ユウキグンヤチヨマチ', '若', 'ワカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県結城郡八千代町東蕗田', '08', '08521', '3003545', '茨城県', 'イバラキケン', '結城郡八千代町', 'ユウキグンヤチヨマチ', '東蕗田', 'ヒガシフキダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県結城郡八千代町栗山', '08', '08521', '3003551', '茨城県', 'イバラキケン', '結城郡八千代町', 'ユウキグンヤチヨマチ', '栗山', 'クリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県結城郡八千代町大間木', '08', '08521', '3003552', '茨城県', 'イバラキケン', '結城郡八千代町', 'ユウキグンヤチヨマチ', '大間木', 'オオマギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県結城郡八千代町蕗田', '08', '08521', '3003553', '茨城県', 'イバラキケン', '結城郡八千代町', 'ユウキグンヤチヨマチ', '蕗田', 'フキダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県結城郡八千代町尾崎', '08', '08521', '3003554', '茨城県', 'イバラキケン', '結城郡八千代町', 'ユウキグンヤチヨマチ', '尾崎', 'オサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県結城郡八千代町芦ケ谷', '08', '08521', '3003555', '茨城県', 'イバラキケン', '結城郡八千代町', 'ユウキグンヤチヨマチ', '芦ケ谷', 'アシガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県結城郡八千代町芦ケ谷新田', '08', '08521', '3003556', '茨城県', 'イバラキケン', '結城郡八千代町', 'ユウキグンヤチヨマチ', '芦ケ谷新田', 'アシガヤシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県結城郡八千代町平塚', '08', '08521', '3003561', '茨城県', 'イバラキケン', '結城郡八千代町', 'ユウキグンヤチヨマチ', '平塚', 'ヒラツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県結城郡八千代町磯', '08', '08521', '3003562', '茨城県', 'イバラキケン', '結城郡八千代町', 'ユウキグンヤチヨマチ', '磯', 'イソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県結城郡八千代町村貫', '08', '08521', '3003563', '茨城県', 'イバラキケン', '結城郡八千代町', 'ユウキグンヤチヨマチ', '村貫', 'ムラヌキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県結城郡八千代町水口', '08', '08521', '3003564', '茨城県', 'イバラキケン', '結城郡八千代町', 'ユウキグンヤチヨマチ', '水口', 'ミノクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県結城郡八千代町松本', '08', '08521', '3003565', '茨城県', 'イバラキケン', '結城郡八千代町', 'ユウキグンヤチヨマチ', '松本', 'マツモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県結城郡八千代町大戸新田', '08', '08521', '3003571', '茨城県', 'イバラキケン', '結城郡八千代町', 'ユウキグンヤチヨマチ', '大戸新田', 'オオドシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県結城郡八千代町菅谷', '08', '08521', '3003572', '茨城県', 'イバラキケン', '結城郡八千代町', 'ユウキグンヤチヨマチ', '菅谷', 'スゲノヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市永井', '08', '08203', '3004101', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '永井', 'ナガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市本郷', '08', '08203', '3004102', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '本郷', 'ホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市大志戸', '08', '08203', '3004103', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '大志戸', 'オオシト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市沢辺', '08', '08203', '3004104', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '沢辺', 'サワベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市田宮', '08', '08203', '3004105', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '田宮', 'タミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市小高', '08', '08203', '3004106', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '小高', 'オダカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市東城寺', '08', '08203', '3004107', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '東城寺', 'トウジョウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市小野', '08', '08203', '3004108', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '小野', 'オノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市大畑', '08', '08203', '3004111', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '大畑', 'オオバタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市桃園', '08', '08203', '3004112', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '桃園', 'モモゾノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市下坂田', '08', '08203', '3004113', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '下坂田', 'シモサカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市上坂田', '08', '08203', '3004114', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '上坂田', 'カミサカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市藤沢', '08', '08203', '3004115', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '藤沢', 'フジサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市藤沢新田', '08', '08203', '3004116', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '藤沢新田', 'フジサワシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市高岡', '08', '08203', '3004117', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '高岡', 'タカオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県土浦市田土部', '08', '08203', '3004118', '茨城県', 'イバラキケン', '土浦市', 'ツチウラシ', '田土部', 'タドベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市寺具', '08', '08220', '3004201', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '寺具', 'テラグ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市高野原新田', '08', '08220', '3004202', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '高野原新田', 'コウヤハラシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市明石', '08', '08220', '3004203', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '明石', 'アケシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市作谷', '08', '08220', '3004204', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '作谷', 'ツクリヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市安食', '08', '08220', '3004205', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '安食', 'アジキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市臼井', '08', '08220', '3004211', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '臼井', 'ウスイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市神郡', '08', '08220', '3004212', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '神郡', 'カンゴオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市平沢', '08', '08220', '3004213', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '平沢', 'ヒラサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市山口', '08', '08220', '3004214', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '山口', 'ヤマグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市小沢', '08', '08220', '3004215', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '小沢', 'オザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市漆所', '08', '08220', '3004216', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '漆所', 'ウルシジョ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市杉木', '08', '08220', '3004217', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '杉木', 'スギノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市大貫', '08', '08220', '3004218', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '大貫', 'オオヌキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市大形', '08', '08220', '3004221', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '大形', 'オオガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市下大島', '08', '08220', '3004222', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '下大島', 'シモオオシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市小田', '08', '08220', '3004223', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '小田', 'オダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市小和田', '08', '08220', '3004224', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '小和田', 'コワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市北条', '08', '08220', '3004231', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '北条', 'ホウジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市北太田', '08', '08220', '3004232', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '北太田', 'キタオオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市君島', '08', '08220', '3004233', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '君島', 'キミジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市山木', '08', '08220', '3004234', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '山木', 'ヤマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市泉', '08', '08220', '3004235', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '泉', 'イズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市小泉', '08', '08220', '3004236', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '小泉', 'コイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市上菅間', '08', '08220', '3004241', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '上菅間', 'カミスガマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市中菅間', '08', '08220', '3004242', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '中菅間', 'ナカスガマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市池田', '08', '08220', '3004243', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '池田', 'イケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市田中', '08', '08220', '3004244', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '田中', 'タナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市水守', '08', '08220', '3004245', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '水守', 'ミモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市上沢', '08', '08220', '3004246', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '上沢', 'カミサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市和台', '08', '08220', '3004247', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '和台', 'ワダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市磯部', '08', '08220', '3004248', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '磯部', 'イソベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市洞下', '08', '08220', '3004249', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '洞下', 'ホラゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市田水山', '08', '08220', '3004251', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '田水山', 'タミヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市上大島', '08', '08220', '3004351', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '上大島', 'カミオオシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市筑波', '08', '08220', '3004352', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '筑波', 'ツクバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市沼田', '08', '08220', '3004353', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '沼田', 'ヌマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市国松', '08', '08220', '3004354', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '国松', 'クニマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県桜川市真壁町上小幡', '08', '08231', '3004401', '茨城県', 'イバラキケン', '桜川市', 'サクラガワシ', '真壁町上小幡', 'マカベチョウカミコバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県桜川市真壁町下小幡', '08', '08231', '3004402', '茨城県', 'イバラキケン', '桜川市', 'サクラガワシ', '真壁町下小幡', 'マカベチョウシモコバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県桜川市真壁町長岡', '08', '08231', '3004403', '茨城県', 'イバラキケン', '桜川市', 'サクラガワシ', '真壁町長岡', 'マカベチョウナガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県桜川市真壁町白井', '08', '08231', '3004404', '茨城県', 'イバラキケン', '桜川市', 'サクラガワシ', '真壁町白井', 'マカベチョウシライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県桜川市真壁町桜井', '08', '08231', '3004405', '茨城県', 'イバラキケン', '桜川市', 'サクラガワシ', '真壁町桜井', 'マカベチョウサクライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県桜川市真壁町山尾', '08', '08231', '3004406', '茨城県', 'イバラキケン', '桜川市', 'サクラガワシ', '真壁町山尾', 'マカベチョウヤマオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県桜川市真壁町古城', '08', '08231', '3004407', '茨城県', 'イバラキケン', '桜川市', 'サクラガワシ', '真壁町古城', 'マカベチョウフルシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県桜川市真壁町真壁', '08', '08231', '3004408', '茨城県', 'イバラキケン', '桜川市', 'サクラガワシ', '真壁町真壁', 'マカベチョウマカベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県桜川市真壁町田', '08', '08231', '3004411', '茨城県', 'イバラキケン', '桜川市', 'サクラガワシ', '真壁町田', 'マカベチョウタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県桜川市真壁町羽鳥', '08', '08231', '3004412', '茨城県', 'イバラキケン', '桜川市', 'サクラガワシ', '真壁町羽鳥', 'マカベチョウハドリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県桜川市真壁町酒寄', '08', '08231', '3004413', '茨城県', 'イバラキケン', '桜川市', 'サクラガワシ', '真壁町酒寄', 'マカベチョウサカヨリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県桜川市真壁町椎尾', '08', '08231', '3004414', '茨城県', 'イバラキケン', '桜川市', 'サクラガワシ', '真壁町椎尾', 'マカベチョウシイオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県桜川市真壁町東山田', '08', '08231', '3004415', '茨城県', 'イバラキケン', '桜川市', 'サクラガワシ', '真壁町東山田', 'マカベチョウヒガシヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県桜川市真壁町伊佐々', '08', '08231', '3004416', '茨城県', 'イバラキケン', '桜川市', 'サクラガワシ', '真壁町伊佐々', 'マカベチョウイサザ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県桜川市真壁町飯塚', '08', '08231', '3004417', '茨城県', 'イバラキケン', '桜川市', 'サクラガワシ', '真壁町飯塚', 'マカベチョウイイツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県桜川市真壁町原方', '08', '08231', '3004421', '茨城県', 'イバラキケン', '桜川市', 'サクラガワシ', '真壁町原方', 'マカベチョウハラガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県桜川市真壁町亀熊', '08', '08231', '3004422', '茨城県', 'イバラキケン', '桜川市', 'サクラガワシ', '真壁町亀熊', 'マカベチョウカメクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県桜川市真壁町塙世', '08', '08231', '3004423', '茨城県', 'イバラキケン', '桜川市', 'サクラガワシ', '真壁町塙世', 'マカベチョウハナワゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県桜川市真壁町源法寺', '08', '08231', '3004424', '茨城県', 'イバラキケン', '桜川市', 'サクラガワシ', '真壁町源法寺', 'マカベチョウゲンボウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県桜川市真壁町細芝', '08', '08231', '3004425', '茨城県', 'イバラキケン', '桜川市', 'サクラガワシ', '真壁町細芝', 'マカベチョウホソシバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県桜川市真壁町下谷貝', '08', '08231', '3004426', '茨城県', 'イバラキケン', '桜川市', 'サクラガワシ', '真壁町下谷貝', 'マカベチョウシモヤガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県桜川市真壁町上谷貝', '08', '08231', '3004427', '茨城県', 'イバラキケン', '桜川市', 'サクラガワシ', '真壁町上谷貝', 'マカベチョウカミヤガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県桜川市真壁町大塚新田', '08', '08231', '3004428', '茨城県', 'イバラキケン', '桜川市', 'サクラガワシ', '真壁町大塚新田', 'マカベチョウオオツカシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県桜川市真壁町東矢貝', '08', '08231', '3004429', '茨城県', 'イバラキケン', '桜川市', 'サクラガワシ', '真壁町東矢貝', 'マカベチョウヒガシヤガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市猫島', '08', '08227', '3004501', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '猫島', 'ネコシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市上西郷谷', '08', '08227', '3004502', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '上西郷谷', 'カミニシゴヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市宮後', '08', '08227', '3004503', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '宮後', 'ミヤゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市宮山', '08', '08227', '3004504', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '宮山', 'ミヤヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市田宿', '08', '08227', '3004505', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '田宿', 'タジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市鍋山', '08', '08227', '3004506', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '鍋山', 'ナベヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市内淀', '08', '08227', '3004507', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '内淀', 'ウチヨド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市押尾', '08', '08227', '3004511', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '押尾', 'オシビ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市有田', '08', '08227', '3004512', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '有田', 'アリタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市中根', '08', '08227', '3004513', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '中根', 'ナカネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市山王堂', '08', '08227', '3004514', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '山王堂', 'サンオウドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市倉持', '08', '08227', '3004515', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '倉持', 'クラモチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市新井新田', '08', '08227', '3004516', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '新井新田', 'アライシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市海老ケ島', '08', '08227', '3004517', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '海老ケ島', 'エビガシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市東石田', '08', '08227', '3004521', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '東石田', 'ヒガシイシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市向上野', '08', '08227', '3004522', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '向上野', 'ムコウウエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('20999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市赤浜', '08', '08227', '3004523', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '赤浜', 'アカハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市中上野', '08', '08227', '3004524', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '中上野', 'ナカウエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市寺上野', '08', '08227', '3004525', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '寺上野', 'テラウエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市築地', '08', '08227', '3004531', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '築地', 'ツイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市鷺島', '08', '08227', '3004532', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '鷺島', 'サギシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市成井', '08', '08227', '3004533', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '成井', 'ナルイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市高津', '08', '08227', '3004534', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '高津', 'タカツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市谷原', '08', '08227', '3004535', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '谷原', 'ヤワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市東保末', '08', '08227', '3004536', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '東保末', 'ヒガシホズエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市大林', '08', '08227', '3004537', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '大林', 'オオバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市海老江', '08', '08227', '3004538', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '海老江', 'エビエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市松原', '08', '08227', '3004541', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '松原', 'マツバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市吉田', '08', '08227', '3004542', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '吉田', 'ヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市竹垣', '08', '08227', '3004543', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '竹垣', 'タケガキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市古内', '08', '08227', '3004544', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '古内', 'フルウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市下川中子', '08', '08227', '3004545', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '下川中子', 'シモカワナゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市村田', '08', '08227', '3004546', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '村田', 'ムラタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市新町', '02', '02201', '0300801', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市本町', '02', '02201', '0300802', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市安方', '02', '02201', '0300803', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '安方', 'ヤスカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市青柳', '02', '02201', '0300811', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '青柳', 'アオヤギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市堤町', '02', '02201', '0300812', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '堤町', 'ツツミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市松原', '02', '02201', '0300813', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '松原', 'マツバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市勝田', '02', '02201', '0300821', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '勝田', 'カッタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市中央', '02', '02201', '0300822', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市橋本', '02', '02201', '0300823', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '橋本', 'ハシモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市奥野', '02', '02201', '0300841', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '奥野', 'オクノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市浦町', '02', '02201', '0300842', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '浦町', 'ウラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市浜田', '02', '02201', '0300843', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '浜田', 'ハマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市桂木', '02', '02201', '0300844', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '桂木', 'カツラギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市緑', '02', '02201', '0300845', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '緑', 'ミドリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市青葉', '02', '02201', '0300846', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '青葉', 'アオバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市東大野', '02', '02201', '0300847', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '東大野', 'ヒガシオオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市旭町', '02', '02201', '0300851', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '旭町', 'アサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市大野', '02', '02201', '0300852', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '大野', 'オオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市金沢', '02', '02201', '0300853', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '金沢', 'カナザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市千富町', '02', '02201', '0300854', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '千富町', 'セントミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市北金沢', '02', '02201', '0300855', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '北金沢', 'キタカナザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市長島', '02', '02201', '0300861', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '長島', 'ナガシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市古川', '02', '02201', '0300862', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '古川', 'フルカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市港町', '02', '02201', '0300901', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '港町', 'ミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市合浦', '02', '02201', '0300902', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '合浦', 'ガッポ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市栄町', '02', '02201', '0300903', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市茶屋町', '02', '02201', '0300904', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '茶屋町', 'チャヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市造道', '02', '02201', '0300911', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '造道', 'ツクリミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市八重田', '02', '02201', '0300912', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '八重田', 'ヤエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市東造道', '02', '02201', '0300913', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '東造道', 'ヒガシツクリミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市岡造道', '02', '02201', '0300914', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '岡造道', 'オカツクリミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市小柳', '02', '02201', '0300915', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '小柳', 'コヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市田屋敷', '02', '02201', '0300916', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '田屋敷', 'タヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市矢作', '02', '02201', '0300917', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '矢作', 'ヤサク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市けやき', '02', '02201', '0300918', '青森県', 'アオモリケン', '青森市', 'アオモリシ', 'けやき', 'ケヤキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市はまなす', '02', '02201', '0300919', '青森県', 'アオモリケン', '青森市', 'アオモリシ', 'はまなす', 'ハマナス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市原別', '02', '02201', '0300921', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '原別', 'ハラベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市泉野', '02', '02201', '0300922', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '泉野', 'イズミノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市八幡林', '02', '02201', '0300923', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '八幡林', 'ヤハタバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市滝沢', '02', '02201', '0300924', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '滝沢', 'タキサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市築木館', '02', '02201', '0300925', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '築木館', 'ツキノキダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市平新田', '02', '02201', '0300931', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '平新田', 'タイラシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市後萢', '02', '02201', '0300932', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '後萢', 'ウシロヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市諏訪沢', '02', '02201', '0300933', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '諏訪沢', 'スワノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市戸崎', '02', '02201', '0300934', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '戸崎', 'トザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市桑原', '02', '02201', '0300935', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '桑原', 'クワバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市矢田前', '02', '02201', '0300936', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '矢田前', 'ヤダマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市本泉', '02', '02201', '0300937', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '本泉', 'モトイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市自由ケ丘', '02', '02201', '0300941', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '自由ケ丘', 'ジユウガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市沢山', '02', '02201', '0300942', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '沢山', 'サワヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市幸畑', '02', '02201', '0300943', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '幸畑', 'コウバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市筒井', '02', '02201', '0300944', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '筒井', 'ツツイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市桜川', '02', '02201', '0300945', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '桜川', 'サクラガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市古館', '02', '02201', '0300946', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '古館', 'フルダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市浜館', '02', '02201', '0300947', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '浜館', 'ハマダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市虹ケ丘', '02', '02201', '0300948', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '虹ケ丘', 'ニジガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市戸山', '02', '02201', '0300951', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '戸山', 'トヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市戸山赤坂', '02', '02201', '0300952', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '戸山', 'トヤマ', null, null, '赤坂', 'アカサカ');
INSERT INTO `ms_addresses` VALUES ('21079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市駒込螢沢', '02', '02201', '0300953', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '駒込', 'コマゴメ', null, null, '螢沢', 'ホタルサワ');
INSERT INTO `ms_addresses` VALUES ('21080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市駒込月見野', '02', '02201', '0300954', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '駒込', 'コマゴメ', null, null, '月見野', 'ツキミノ');
INSERT INTO `ms_addresses` VALUES ('21081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市駒込', '02', '02201', '0300955', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '駒込', 'コマゴメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市浪打', '02', '02201', '0300961', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '浪打', 'ナミウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市佃', '02', '02201', '0300962', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '佃', 'ツクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市中佃', '02', '02201', '0300963', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '中佃', 'ナカツクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市南佃', '02', '02201', '0300964', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '南佃', 'ミナミツクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市松森', '02', '02201', '0300965', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '松森', 'マツモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市花園', '02', '02201', '0300966', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '花園', 'ハナゾノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県龍ケ崎市', '08', '08208', '3010000', '茨城県', 'イバラキケン', '龍ケ崎市', 'リュウガサキシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('21089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県龍ケ崎市久保台', '08', '08208', '3010001', '茨城県', 'イバラキケン', '龍ケ崎市', 'リュウガサキシ', '久保台', 'クボダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県龍ケ崎市中根台', '08', '08208', '3010002', '茨城県', 'イバラキケン', '龍ケ崎市', 'リュウガサキシ', '中根台', 'ナカネダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県龍ケ崎市平台', '08', '08208', '3010003', '茨城県', 'イバラキケン', '龍ケ崎市', 'リュウガサキシ', '平台', 'ヒラダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県龍ケ崎市馴馬町', '08', '08208', '3010004', '茨城県', 'イバラキケン', '龍ケ崎市', 'リュウガサキシ', '馴馬町', 'ナレウママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県龍ケ崎市川原代町', '08', '08208', '3010005', '茨城県', 'イバラキケン', '龍ケ崎市', 'リュウガサキシ', '川原代町', 'カワラシロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県龍ケ崎市門倉新田町', '08', '08208', '3010006', '茨城県', 'イバラキケン', '龍ケ崎市', 'リュウガサキシ', '門倉新田町', 'カドクラシンデンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県龍ケ崎市馴柴町', '08', '08208', '3010007', '茨城県', 'イバラキケン', '龍ケ崎市', 'リュウガサキシ', '馴柴町', 'ナレシバマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県龍ケ崎市横町', '08', '08208', '3010011', '茨城県', 'イバラキケン', '龍ケ崎市', 'リュウガサキシ', '横町', 'ヨコマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県龍ケ崎市上町', '08', '08208', '3010012', '茨城県', 'イバラキケン', '龍ケ崎市', 'リュウガサキシ', '上町', 'カミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県龍ケ崎市水門', '08', '08208', '3010013', '茨城県', 'イバラキケン', '龍ケ崎市', 'リュウガサキシ', '水門', 'ミズモン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県龍ケ崎市須藤堀町', '08', '08208', '3010014', '茨城県', 'イバラキケン', '龍ケ崎市', 'リュウガサキシ', '須藤堀町', 'スドウボリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県龍ケ崎市長沖町', '08', '08208', '3010015', '茨城県', 'イバラキケン', '龍ケ崎市', 'リュウガサキシ', '長沖町', 'ナガオキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県龍ケ崎市長沖新田町', '08', '08208', '3010016', '茨城県', 'イバラキケン', '龍ケ崎市', 'リュウガサキシ', '長沖新田町', 'ナガオキシンデンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県龍ケ崎市姫宮町', '08', '08208', '3010017', '茨城県', 'イバラキケン', '龍ケ崎市', 'リュウガサキシ', '姫宮町', 'ヒメミヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県龍ケ崎市米町', '08', '08208', '3010018', '茨城県', 'イバラキケン', '龍ケ崎市', 'リュウガサキシ', '米町', 'コメマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県龍ケ崎市北方町', '08', '08208', '3010021', '茨城県', 'イバラキケン', '龍ケ崎市', 'リュウガサキシ', '北方町', 'キタカタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県龍ケ崎市南が丘', '08', '08208', '3010022', '茨城県', 'イバラキケン', '龍ケ崎市', 'リュウガサキシ', '南が丘', 'ミナミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県龍ケ崎市羽黒町', '08', '08208', '3010023', '茨城県', 'イバラキケン', '龍ケ崎市', 'リュウガサキシ', '羽黒町', 'ハグロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県龍ケ崎市豊田町', '08', '08208', '3010024', '茨城県', 'イバラキケン', '龍ケ崎市', 'リュウガサキシ', '豊田町', 'トヨダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県龍ケ崎市大留町', '08', '08208', '3010025', '茨城県', 'イバラキケン', '龍ケ崎市', 'リュウガサキシ', '大留町', 'オオドメマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県龍ケ崎市高須町', '08', '08208', '3010026', '茨城県', 'イバラキケン', '龍ケ崎市', 'リュウガサキシ', '高須町', 'タカスマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県龍ケ崎市庄兵衛新田町', '08', '08208', '3010031', '茨城県', 'イバラキケン', '龍ケ崎市', 'リュウガサキシ', '庄兵衛新田町', 'ショウベエシンデンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県龍ケ崎市佐貫', '08', '08208', '3010032', '茨城県', 'イバラキケン', '龍ケ崎市', 'リュウガサキシ', '佐貫', 'サヌキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県龍ケ崎市佐貫町', '08', '08208', '3010033', '茨城県', 'イバラキケン', '龍ケ崎市', 'リュウガサキシ', '佐貫町', 'サヌキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県龍ケ崎市小通幸谷町', '08', '08208', '3010034', '茨城県', 'イバラキケン', '龍ケ崎市', 'リュウガサキシ', '小通幸谷町', 'コトオリコウヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県龍ケ崎市稗柄町', '08', '08208', '3010035', '茨城県', 'イバラキケン', '龍ケ崎市', 'リュウガサキシ', '稗柄町', 'ヒエガラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県龍ケ崎市若柴町', '08', '08208', '3010041', '茨城県', 'イバラキケン', '龍ケ崎市', 'リュウガサキシ', '若柴町', 'ワカシバマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県龍ケ崎市長山', '08', '08208', '3010042', '茨城県', 'イバラキケン', '龍ケ崎市', 'リュウガサキシ', '長山', 'ナガヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県龍ケ崎市松葉', '08', '08208', '3010043', '茨城県', 'イバラキケン', '龍ケ崎市', 'リュウガサキシ', '松葉', 'マツバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県龍ケ崎市小柴', '08', '08208', '3010044', '茨城県', 'イバラキケン', '龍ケ崎市', 'リュウガサキシ', '小柴', 'コシバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県龍ケ崎市稲荷新田町', '08', '08208', '3010045', '茨城県', 'イバラキケン', '龍ケ崎市', 'リュウガサキシ', '稲荷新田町', 'イナリシンデンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県龍ケ崎市入地町', '08', '08208', '3010046', '茨城県', 'イバラキケン', '龍ケ崎市', 'リュウガサキシ', '入地町', 'イレジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県龍ケ崎市南中島町', '08', '08208', '3010047', '茨城県', 'イバラキケン', '龍ケ崎市', 'リュウガサキシ', '南中島町', 'ミナミナカジママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県龍ケ崎市川崎町', '08', '08208', '3010048', '茨城県', 'イバラキケン', '龍ケ崎市', 'リュウガサキシ', '川崎町', 'カワサキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県龍ケ崎市板橋町', '08', '08208', '3010801', '茨城県', 'イバラキケン', '龍ケ崎市', 'リュウガサキシ', '板橋町', 'イタバシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県龍ケ崎市高作町', '08', '08208', '3010802', '茨城県', 'イバラキケン', '龍ケ崎市', 'リュウガサキシ', '高作町', 'コウサマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県龍ケ崎市塗戸町', '08', '08208', '3010803', '茨城県', 'イバラキケン', '龍ケ崎市', 'リュウガサキシ', '塗戸町', 'ヌルトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県龍ケ崎市長峰町', '08', '08208', '3010804', '茨城県', 'イバラキケン', '龍ケ崎市', 'リュウガサキシ', '長峰町', 'ナガミネマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県龍ケ崎市薄倉町', '08', '08208', '3010805', '茨城県', 'イバラキケン', '龍ケ崎市', 'リュウガサキシ', '薄倉町', 'ウスクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県龍ケ崎市半田町', '08', '08208', '3010806', '茨城県', 'イバラキケン', '龍ケ崎市', 'リュウガサキシ', '半田町', 'ハンダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県龍ケ崎市宮渕町', '08', '08208', '3010811', '茨城県', 'イバラキケン', '龍ケ崎市', 'リュウガサキシ', '宮渕町', 'ミヤブチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県龍ケ崎市佐沼町', '08', '08208', '3010812', '茨城県', 'イバラキケン', '龍ケ崎市', 'リュウガサキシ', '佐沼町', 'サヌママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県龍ケ崎市新町', '08', '08208', '3010813', '茨城県', 'イバラキケン', '龍ケ崎市', 'リュウガサキシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県龍ケ崎市高砂', '08', '08208', '3010814', '茨城県', 'イバラキケン', '龍ケ崎市', 'リュウガサキシ', '高砂', 'タカスナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県龍ケ崎市直鮒', '08', '08208', '3010815', '茨城県', 'イバラキケン', '龍ケ崎市', 'リュウガサキシ', '直鮒', 'スウブナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県龍ケ崎市大徳町', '08', '08208', '3010816', '茨城県', 'イバラキケン', '龍ケ崎市', 'リュウガサキシ', '大徳町', 'ダイトクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県龍ケ崎市上大徳新町', '08', '08208', '3010817', '茨城県', 'イバラキケン', '龍ケ崎市', 'リュウガサキシ', '上大徳新町', 'カミダイトクシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県龍ケ崎市東町', '08', '08208', '3010821', '茨城県', 'イバラキケン', '龍ケ崎市', 'リュウガサキシ', '東町', 'アズママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県龍ケ崎市光順田', '08', '08208', '3010822', '茨城県', 'イバラキケン', '龍ケ崎市', 'リュウガサキシ', '光順田', 'コウジュンタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県龍ケ崎市砂町', '08', '08208', '3010823', '茨城県', 'イバラキケン', '龍ケ崎市', 'リュウガサキシ', '砂町', 'スナマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県龍ケ崎市下町', '08', '08208', '3010824', '茨城県', 'イバラキケン', '龍ケ崎市', 'リュウガサキシ', '下町', 'シモマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県龍ケ崎市川余郷', '08', '08208', '3010825', '茨城県', 'イバラキケン', '龍ケ崎市', 'リュウガサキシ', '川余郷', 'カワヨゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県龍ケ崎市栄町', '08', '08208', '3010826', '茨城県', 'イバラキケン', '龍ケ崎市', 'リュウガサキシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県龍ケ崎市野原町', '08', '08208', '3010831', '茨城県', 'イバラキケン', '龍ケ崎市', 'リュウガサキシ', '野原町', 'ヤハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県龍ケ崎市緑町', '08', '08208', '3010832', '茨城県', 'イバラキケン', '龍ケ崎市', 'リュウガサキシ', '緑町', 'ミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県龍ケ崎市城下', '08', '08208', '3010833', '茨城県', 'イバラキケン', '龍ケ崎市', 'リュウガサキシ', '城下', 'シロシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県龍ケ崎市古城', '08', '08208', '3010834', '茨城県', 'イバラキケン', '龍ケ崎市', 'リュウガサキシ', '古城', 'コジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県龍ケ崎市田町', '08', '08208', '3010835', '茨城県', 'イバラキケン', '龍ケ崎市', 'リュウガサキシ', '田町', 'タマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県龍ケ崎市寺後', '08', '08208', '3010836', '茨城県', 'イバラキケン', '龍ケ崎市', 'リュウガサキシ', '寺後', 'テラゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県龍ケ崎市根町', '08', '08208', '3010837', '茨城県', 'イバラキケン', '龍ケ崎市', 'リュウガサキシ', '根町', 'ネマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県龍ケ崎市愛戸町', '08', '08208', '3010838', '茨城県', 'イバラキケン', '龍ケ崎市', 'リュウガサキシ', '愛戸町', 'アタドマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県龍ケ崎市出し山町', '08', '08208', '3010839', '茨城県', 'イバラキケン', '龍ケ崎市', 'リュウガサキシ', '出し山町', 'ダシヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県龍ケ崎市白羽', '08', '08208', '3010841', '茨城県', 'イバラキケン', '龍ケ崎市', 'リュウガサキシ', '白羽', 'シラハネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県龍ケ崎市八代町', '08', '08208', '3010842', '茨城県', 'イバラキケン', '龍ケ崎市', 'リュウガサキシ', '八代町', 'ヤシロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県龍ケ崎市羽原町', '08', '08208', '3010843', '茨城県', 'イバラキケン', '龍ケ崎市', 'リュウガサキシ', '羽原町', 'ハバラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県龍ケ崎市平畑', '08', '08208', '3010844', '茨城県', 'イバラキケン', '龍ケ崎市', 'リュウガサキシ', '平畑', 'ヒラハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県龍ケ崎市奈戸岡', '08', '08208', '3010845', '茨城県', 'イバラキケン', '龍ケ崎市', 'リュウガサキシ', '奈戸岡', 'ナドオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県龍ケ崎市別所町', '08', '08208', '3010846', '茨城県', 'イバラキケン', '龍ケ崎市', 'リュウガサキシ', '別所町', 'ベッショマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県龍ケ崎市城ノ内', '08', '08208', '3010847', '茨城県', 'イバラキケン', '龍ケ崎市', 'リュウガサキシ', '城ノ内', 'ジョウノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県龍ケ崎市大塚町', '08', '08208', '3010851', '茨城県', 'イバラキケン', '龍ケ崎市', 'リュウガサキシ', '大塚町', 'オオツカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県龍ケ崎市向陽台', '08', '08208', '3010852', '茨城県', 'イバラキケン', '龍ケ崎市', 'リュウガサキシ', '向陽台', 'コウヨウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県龍ケ崎市松ケ丘', '08', '08208', '3010853', '茨城県', 'イバラキケン', '龍ケ崎市', 'リュウガサキシ', '松ケ丘', 'マツガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県龍ケ崎市中里', '08', '08208', '3010854', '茨城県', 'イバラキケン', '龍ケ崎市', 'リュウガサキシ', '中里', 'ナカザトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県龍ケ崎市藤ケ丘', '08', '08208', '3010855', '茨城県', 'イバラキケン', '龍ケ崎市', 'リュウガサキシ', '藤ケ丘', 'フジガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県龍ケ崎市貝原塚町', '08', '08208', '3010856', '茨城県', 'イバラキケン', '龍ケ崎市', 'リュウガサキシ', '貝原塚町', 'カイハラツカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県龍ケ崎市泉町', '08', '08208', '3010857', '茨城県', 'イバラキケン', '龍ケ崎市', 'リュウガサキシ', '泉町', 'イズミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷市下根本', '08', '08229', '3010901', '茨城県', 'イバラキケン', '稲敷市', 'イナシキシ', '下根本', 'シモネモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県稲敷市上根本', '08', '08229', '3010902', '茨城県', 'イバラキケン', '稲敷市', 'イナシキシ', '上根本', 'カミネモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県東津軽郡蓬田村', '02', '02304', '0301200', '青森県', 'アオモリケン', '東津軽郡蓬田村', 'ヒガシツガルグンヨモギタムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('21168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県東津軽郡蓬田村広瀬', '02', '02304', '0301201', '青森県', 'アオモリケン', '東津軽郡蓬田村', 'ヒガシツガルグンヨモギタムラ', '広瀬', 'ヒロセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県東津軽郡蓬田村瀬辺地', '02', '02304', '0301202', '青森県', 'アオモリケン', '東津軽郡蓬田村', 'ヒガシツガルグンヨモギタムラ', '瀬辺地', 'セヘジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県東津軽郡蓬田村郷沢', '02', '02304', '0301203', '青森県', 'アオモリケン', '東津軽郡蓬田村', 'ヒガシツガルグンヨモギタムラ', '郷沢', 'ゴウサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県東津軽郡蓬田村蓬田', '02', '02304', '0301211', '青森県', 'アオモリケン', '東津軽郡蓬田村', 'ヒガシツガルグンヨモギタムラ', '蓬田', 'ヨモギダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県東津軽郡蓬田村阿弥陀川', '02', '02304', '0301212', '青森県', 'アオモリケン', '東津軽郡蓬田村', 'ヒガシツガルグンヨモギタムラ', '阿弥陀川', 'アミダガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県東津軽郡蓬田村長科', '02', '02304', '0301213', '青森県', 'アオモリケン', '東津軽郡蓬田村', 'ヒガシツガルグンヨモギタムラ', '長科', 'ナガシナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県東津軽郡蓬田村中沢', '02', '02304', '0301214', '青森県', 'アオモリケン', '東津軽郡蓬田村', 'ヒガシツガルグンヨモギタムラ', '中沢', 'ナカザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市四戸橋', '02', '02201', '0301261', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '四戸橋', 'シトバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市後潟', '02', '02201', '0301262', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '後潟', 'ウシロガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市六枚橋', '02', '02201', '0301271', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '六枚橋', 'ロクマエバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市小橋', '02', '02201', '0301272', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '小橋', 'コバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市左堰', '02', '02201', '0301273', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '左堰', 'ヒダリゼキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県東津軽郡外ヶ浜町蟹田石浜', '02', '02307', '0301301', '青森県', 'アオモリケン', '東津軽郡外ヶ浜町', 'ヒガシツガルグンソトガハママチ', '蟹田石浜', 'カニタイシハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県東津軽郡外ヶ浜町蟹田中師', '02', '02307', '0301302', '青森県', 'アオモリケン', '東津軽郡外ヶ浜町', 'ヒガシツガルグンソトガハママチ', '蟹田中師', 'カニタチュウシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県東津軽郡外ヶ浜町蟹田', '02', '02307', '0301303', '青森県', 'アオモリケン', '東津軽郡外ヶ浜町', 'ヒガシツガルグンソトガハママチ', '蟹田', 'カニタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県東津軽郡外ヶ浜町蟹田南沢', '02', '02307', '0301304', '青森県', 'アオモリケン', '東津軽郡外ヶ浜町', 'ヒガシツガルグンソトガハママチ', '蟹田南沢', 'カニタミナミザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県東津軽郡外ヶ浜町蟹田小国', '02', '02307', '0301305', '青森県', 'アオモリケン', '東津軽郡外ヶ浜町', 'ヒガシツガルグンソトガハママチ', '蟹田小国', 'カニタオグニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県東津軽郡外ヶ浜町蟹田山本', '02', '02307', '0301306', '青森県', 'アオモリケン', '東津軽郡外ヶ浜町', 'ヒガシツガルグンソトガハママチ', '蟹田山本', 'カニタヤマモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県東津軽郡外ヶ浜町蟹田大平', '02', '02307', '0301307', '青森県', 'アオモリケン', '東津軽郡外ヶ浜町', 'ヒガシツガルグンソトガハママチ', '蟹田大平', 'カニタオオダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県東津軽郡外ヶ浜町下蟹田', '02', '02307', '0301308', '青森県', 'アオモリケン', '東津軽郡外ヶ浜町', 'ヒガシツガルグンソトガハママチ', '下蟹田', 'シタカニタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県東津軽郡外ヶ浜町上蟹田', '02', '02307', '0301309', '青森県', 'アオモリケン', '東津軽郡外ヶ浜町', 'ヒガシツガルグンソトガハママチ', '上蟹田', 'ウエカニタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県東津軽郡外ヶ浜町蟹田塩越', '02', '02307', '0301311', '青森県', 'アオモリケン', '東津軽郡外ヶ浜町', 'ヒガシツガルグンソトガハママチ', '蟹田塩越', 'カニタシオコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県東津軽郡外ヶ浜町', '02', '02307', '0301400', '青森県', 'アオモリケン', '東津軽郡外ヶ浜町', 'ヒガシツガルグンソトガハママチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('21192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県東津軽郡外ヶ浜町平舘', '02', '02307', '0301402', '青森県', 'アオモリケン', '東津軽郡外ヶ浜町', 'ヒガシツガルグンソトガハママチ', '平舘', 'タイラダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県東津軽郡外ヶ浜町平舘元宇田', '02', '02307', '0301403', '青森県', 'アオモリケン', '東津軽郡外ヶ浜町', 'ヒガシツガルグンソトガハママチ', '平舘元宇田', 'タイラダテモトウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県東津軽郡外ヶ浜町平舘弥蔵釜', '02', '02307', '0301404', '青森県', 'アオモリケン', '東津軽郡外ヶ浜町', 'ヒガシツガルグンソトガハママチ', '平舘弥蔵釜', 'タイラダテヤゾウガマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県東津軽郡外ヶ浜町平舘石崎沢', '02', '02307', '0301405', '青森県', 'アオモリケン', '東津軽郡外ヶ浜町', 'ヒガシツガルグンソトガハママチ', '平舘石崎沢', 'タイラダテイシザキサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県東津軽郡外ヶ浜町平舘根岸', '02', '02307', '0301411', '青森県', 'アオモリケン', '東津軽郡外ヶ浜町', 'ヒガシツガルグンソトガハママチ', '平舘根岸', 'タイラダテネギシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県東津軽郡外ヶ浜町平舘野田', '02', '02307', '0301412', '青森県', 'アオモリケン', '東津軽郡外ヶ浜町', 'ヒガシツガルグンソトガハママチ', '平舘野田', 'タイラダテノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県東津軽郡外ヶ浜町平舘今津', '02', '02307', '0301413', '青森県', 'アオモリケン', '東津軽郡外ヶ浜町', 'ヒガシツガルグンソトガハママチ', '平舘今津', 'タイラダテイマヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県東津軽郡外ヶ浜町平舘舟岡', '02', '02307', '0301415', '青森県', 'アオモリケン', '東津軽郡外ヶ浜町', 'ヒガシツガルグンソトガハママチ', '平舘舟岡', 'タイラダテフナオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県東津軽郡外ヶ浜町平舘磯山', '02', '02307', '0301416', '青森県', 'アオモリケン', '東津軽郡外ヶ浜町', 'ヒガシツガルグンソトガハママチ', '平舘磯山', 'タイラダテイソヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県東津軽郡今別町', '02', '02303', '0301500', '青森県', 'アオモリケン', '東津軽郡今別町', 'ヒガシツガルグンイマベツマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('21204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県東津軽郡今別町浜名', '02', '02303', '0301501', '青森県', 'アオモリケン', '東津軽郡今別町', 'ヒガシツガルグンイマベツマチ', '浜名', 'ハマナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県東津軽郡今別町今別', '02', '02303', '0301502', '青森県', 'アオモリケン', '東津軽郡今別町', 'ヒガシツガルグンイマベツマチ', '今別', 'イマベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県東津軽郡今別町村元', '02', '02303', '0301503', '青森県', 'アオモリケン', '東津軽郡今別町', 'ヒガシツガルグンイマベツマチ', '村元', 'ムラモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県東津軽郡今別町鍋田', '02', '02303', '0301504', '青森県', 'アオモリケン', '東津軽郡今別町', 'ヒガシツガルグンイマベツマチ', '鍋田', 'ナベタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県東津軽郡今別町大川平', '02', '02303', '0301505', '青森県', 'アオモリケン', '東津軽郡今別町', 'ヒガシツガルグンイマベツマチ', '大川平', 'オオカワダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県東津軽郡今別町山崎', '02', '02303', '0301511', '青森県', 'アオモリケン', '東津軽郡今別町', 'ヒガシツガルグンイマベツマチ', '山崎', 'ヤマザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県東津軽郡今別町大泊', '02', '02303', '0301512', '青森県', 'アオモリケン', '東津軽郡今別町', 'ヒガシツガルグンイマベツマチ', '大泊', 'オオドマリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県東津軽郡今別町袰月', '02', '02303', '0301513', '青森県', 'アオモリケン', '東津軽郡今別町', 'ヒガシツガルグンイマベツマチ', '袰月', 'ホロヅキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県東津軽郡今別町砂ケ森', '02', '02303', '0301514', '青森県', 'アオモリケン', '東津軽郡今別町', 'ヒガシツガルグンイマベツマチ', '砂ケ森', 'スナガモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県東津軽郡今別町奥平部', '02', '02303', '0301515', '青森県', 'アオモリケン', '東津軽郡今別町', 'ヒガシツガルグンイマベツマチ', '奥平部', 'オクタイラヘ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県北津軽郡中泊町小泊袰内', '02', '02387', '0301701', '青森県', 'アオモリケン', '北津軽郡中泊町', 'キタツガルグンナカドマリマチ', '小泊袰内', 'コドマリホロナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県東津軽郡外ヶ浜町三厩源兵衛間', '02', '02307', '0301711', '青森県', 'アオモリケン', '東津軽郡外ヶ浜町', 'ヒガシツガルグンソトガハママチ', '三厩源兵衛間', 'ミンマヤゲンベイマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県東津軽郡外ヶ浜町三厩龍浜', '02', '02307', '0301711', '青森県', 'アオモリケン', '東津軽郡外ヶ浜町', 'ヒガシツガルグンソトガハママチ', '三厩龍浜', 'ミンマヤタツハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県東津軽郡外ヶ浜町三厩木落', '02', '02307', '0301712', '青森県', 'アオモリケン', '東津軽郡外ヶ浜町', 'ヒガシツガルグンソトガハママチ', '三厩木落', 'ミンマヤキオトシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県東津軽郡外ヶ浜町三厩鎧嶋', '02', '02307', '0301713', '青森県', 'アオモリケン', '東津軽郡外ヶ浜町', 'ヒガシツガルグンソトガハママチ', '三厩鎧嶋', 'ミンマヤヨロイジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県東津軽郡外ヶ浜町三厩梹榔', '02', '02307', '0301714', '青森県', 'アオモリケン', '東津軽郡外ヶ浜町', 'ヒガシツガルグンソトガハママチ', '三厩梹榔', 'ミンマヤヒョウロウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県東津軽郡外ヶ浜町三厩鳴神', '02', '02307', '0301715', '青森県', 'アオモリケン', '東津軽郡外ヶ浜町', 'ヒガシツガルグンソトガハママチ', '三厩鳴神', 'ミンマヤナルカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県東津軽郡外ヶ浜町三厩尻神', '02', '02307', '0301716', '青森県', 'アオモリケン', '東津軽郡外ヶ浜町', 'ヒガシツガルグンソトガハママチ', '三厩尻神', 'ミンマヤシリカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県東津軽郡外ヶ浜町三厩川柱', '02', '02307', '0301717', '青森県', 'アオモリケン', '東津軽郡外ヶ浜町', 'ヒガシツガルグンソトガハママチ', '三厩川柱', 'ミンマヤカワシラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県東津軽郡外ヶ浜町三厩梨ノ木間', '02', '02307', '0301718', '青森県', 'アオモリケン', '東津軽郡外ヶ浜町', 'ヒガシツガルグンソトガハママチ', '三厩梨ノ木間', 'ミンマヤナシノキマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県東津軽郡外ヶ浜町三厩鐇泊', '02', '02307', '0301721', '青森県', 'アオモリケン', '東津軽郡外ヶ浜町', 'ヒガシツガルグンソトガハママチ', '三厩鐇泊', 'ミンマヤマサカリドマリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県東津軽郡外ヶ浜町三厩上宇鉄', '02', '02307', '0301722', '青森県', 'アオモリケン', '東津軽郡外ヶ浜町', 'ヒガシツガルグンソトガハママチ', '三厩上宇鉄', 'ミンマヤカミウテツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県東津軽郡外ヶ浜町三厩元宇鉄', '02', '02307', '0301723', '青森県', 'アオモリケン', '東津軽郡外ヶ浜町', 'ヒガシツガルグンソトガハママチ', '三厩元宇鉄', 'ミンマヤモトウテツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県東津軽郡外ヶ浜町三厩釜野澤', '02', '02307', '0301724', '青森県', 'アオモリケン', '東津軽郡外ヶ浜町', 'ヒガシツガルグンソトガハママチ', '三厩釜野澤', 'ミンマヤカマノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県東津軽郡外ヶ浜町三厩藤嶋', '02', '02307', '0301725', '青森県', 'アオモリケン', '東津軽郡外ヶ浜町', 'ヒガシツガルグンソトガハママチ', '三厩藤嶋', 'ミンマヤフジシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県東津軽郡外ヶ浜町三厩六條間', '02', '02307', '0301726', '青森県', 'アオモリケン', '東津軽郡外ヶ浜町', 'ヒガシツガルグンソトガハママチ', '三厩六條間', 'ミンマヤロクジョウマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県東津軽郡外ヶ浜町三厩算用師', '02', '02307', '0301727', '青森県', 'アオモリケン', '東津軽郡外ヶ浜町', 'ヒガシツガルグンソトガハママチ', '三厩算用師', 'ミンマヤサンヨウシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県東津軽郡外ヶ浜町三厩中浜', '02', '02307', '0301728', '青森県', 'アオモリケン', '東津軽郡外ヶ浜町', 'ヒガシツガルグンソトガハママチ', '三厩中浜', 'ミンマヤナカハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県東津軽郡外ヶ浜町三厩下平', '02', '02307', '0301729', '青森県', 'アオモリケン', '東津軽郡外ヶ浜町', 'ヒガシツガルグンソトガハママチ', '三厩下平', 'ミンマヤシモタイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県東津軽郡外ヶ浜町三厩本町', '02', '02307', '0301731', '青森県', 'アオモリケン', '東津軽郡外ヶ浜町', 'ヒガシツガルグンソトガハママチ', '三厩本町', 'ミンマヤホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県東津軽郡外ヶ浜町三厩家ノ上', '02', '02307', '0301732', '青森県', 'アオモリケン', '東津軽郡外ヶ浜町', 'ヒガシツガルグンソトガハママチ', '三厩家ノ上', 'ミンマヤイエノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県東津軽郡外ヶ浜町三厩新町', '02', '02307', '0301733', '青森県', 'アオモリケン', '東津軽郡外ヶ浜町', 'ヒガシツガルグンソトガハママチ', '三厩新町', 'ミンマヤシンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県東津軽郡外ヶ浜町三厩増川', '02', '02307', '0301734', '青森県', 'アオモリケン', '東津軽郡外ヶ浜町', 'ヒガシツガルグンソトガハママチ', '三厩増川', 'ミンマヤマスカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県東津軽郡外ヶ浜町三厩緑ケ丘', '02', '02307', '0301735', '青森県', 'アオモリケン', '東津軽郡外ヶ浜町', 'ヒガシツガルグンソトガハママチ', '三厩緑ケ丘', 'ミンマヤミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県東津軽郡外ヶ浜町三厩桃ケ丘', '02', '02307', '0301736', '青森県', 'アオモリケン', '東津軽郡外ヶ浜町', 'ヒガシツガルグンソトガハママチ', '三厩桃ケ丘', 'ミンマヤモモガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県東津軽郡外ヶ浜町三厩東町', '02', '02307', '0301737', '青森県', 'アオモリケン', '東津軽郡外ヶ浜町', 'ヒガシツガルグンソトガハママチ', '三厩東町', 'ミンマヤヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県取手市', '08', '08217', '3020000', '茨城県', 'イバラキケン', '取手市', 'トリデシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('21249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県取手市小文間', '08', '08217', '3020001', '茨城県', 'イバラキケン', '取手市', 'トリデシ', '小文間', 'オモンマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県取手市長兵衛新田', '08', '08217', '3020002', '茨城県', 'イバラキケン', '取手市', 'トリデシ', '長兵衛新田', 'チョウベエシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県取手市小堀', '08', '08217', '3020003', '茨城県', 'イバラキケン', '取手市', 'トリデシ', '小堀', 'オオホリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県取手市取手', '08', '08217', '3020004', '茨城県', 'イバラキケン', '取手市', 'トリデシ', '取手', 'トリデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県取手市東', '08', '08217', '3020005', '茨城県', 'イバラキケン', '取手市', 'トリデシ', '東', 'ヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県取手市青柳', '08', '08217', '3020006', '茨城県', 'イバラキケン', '取手市', 'トリデシ', '青柳', 'アオヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県取手市吉田', '08', '08217', '3020007', '茨城県', 'イバラキケン', '取手市', 'トリデシ', '吉田', 'ヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県取手市井野', '08', '08217', '3020011', '茨城県', 'イバラキケン', '取手市', 'トリデシ', '井野', 'イノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県取手市井野団地', '08', '08217', '3020012', '茨城県', 'イバラキケン', '取手市', 'トリデシ', '井野団地', 'イノダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県取手市台宿', '08', '08217', '3020013', '茨城県', 'イバラキケン', '取手市', 'トリデシ', '台宿', 'ダイシュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県取手市中央町', '08', '08217', '3020014', '茨城県', 'イバラキケン', '取手市', 'トリデシ', '中央町', 'チュウオウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県取手市井野台', '08', '08217', '3020015', '茨城県', 'イバラキケン', '取手市', 'トリデシ', '井野台', 'イノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県取手市中原町', '08', '08217', '3020016', '茨城県', 'イバラキケン', '取手市', 'トリデシ', '中原町', 'ナカハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県取手市桑原', '08', '08217', '3020017', '茨城県', 'イバラキケン', '取手市', 'トリデシ', '桑原', 'クワバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県取手市寺田', '08', '08217', '3020021', '茨城県', 'イバラキケン', '取手市', 'トリデシ', '寺田', 'テラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県取手市本郷', '08', '08217', '3020022', '茨城県', 'イバラキケン', '取手市', 'トリデシ', '本郷', 'ホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県取手市白山', '08', '08217', '3020023', '茨城県', 'イバラキケン', '取手市', 'トリデシ', '白山', 'ハクサン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県取手市新町', '08', '08217', '3020024', '茨城県', 'イバラキケン', '取手市', 'トリデシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県取手市西', '08', '08217', '3020025', '茨城県', 'イバラキケン', '取手市', 'トリデシ', '西', 'ニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県取手市稲', '08', '08217', '3020026', '茨城県', 'イバラキケン', '取手市', 'トリデシ', '稲', 'イナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県取手市駒場', '08', '08217', '3020027', '茨城県', 'イバラキケン', '取手市', 'トリデシ', '駒場', 'コマバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県取手市新取手', '08', '08217', '3020031', '茨城県', 'イバラキケン', '取手市', 'トリデシ', '新取手', 'シントリデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県取手市野々井', '08', '08217', '3020032', '茨城県', 'イバラキケン', '取手市', 'トリデシ', '野々井', 'ノノイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県取手市米ノ井', '08', '08217', '3020033', '茨城県', 'イバラキケン', '取手市', 'トリデシ', '米ノ井', 'コメノイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県取手市戸頭', '08', '08217', '3020034', '茨城県', 'イバラキケン', '取手市', 'トリデシ', '戸頭', 'トガシラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県取手市上高井', '08', '08217', '3020035', '茨城県', 'イバラキケン', '取手市', 'トリデシ', '上高井', 'カミタカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県取手市貝塚', '08', '08217', '3020036', '茨城県', 'イバラキケン', '取手市', 'トリデシ', '貝塚', 'カイヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県取手市市之代', '08', '08217', '3020037', '茨城県', 'イバラキケン', '取手市', 'トリデシ', '市之代', 'イチノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県取手市下高井', '08', '08217', '3020038', '茨城県', 'イバラキケン', '取手市', 'トリデシ', '下高井', 'シモタカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県守谷市', '08', '08224', '3020100', '茨城県', 'イバラキケン', '守谷市', 'モリヤシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('21279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県守谷市板戸井', '08', '08224', '3020101', '茨城県', 'イバラキケン', '守谷市', 'モリヤシ', '板戸井', 'イタトイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県守谷市松前台', '08', '08224', '3020102', '茨城県', 'イバラキケン', '守谷市', 'モリヤシ', '松前台', 'マツマエダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県守谷市大山新田', '08', '08224', '3020103', '茨城県', 'イバラキケン', '守谷市', 'モリヤシ', '大山新田', 'オオヤマシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県守谷市久保ケ丘', '08', '08224', '3020104', '茨城県', 'イバラキケン', '守谷市', 'モリヤシ', '久保ケ丘', 'クボガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県守谷市薬師台', '08', '08224', '3020105', '茨城県', 'イバラキケン', '守谷市', 'モリヤシ', '薬師台', 'ヤクシダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県守谷市緑', '08', '08224', '3020106', '茨城県', 'イバラキケン', '守谷市', 'モリヤシ', '緑', 'ミドリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県守谷市大木', '08', '08224', '3020107', '茨城県', 'イバラキケン', '守谷市', 'モリヤシ', '大木', 'オオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県守谷市松並', '08', '08224', '3020108', '茨城県', 'イバラキケン', '守谷市', 'モリヤシ', '松並', 'マツナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県守谷市本町', '08', '08224', '3020109', '茨城県', 'イバラキケン', '守谷市', 'モリヤシ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県守谷市百合ケ丘', '08', '08224', '3020110', '茨城県', 'イバラキケン', '守谷市', 'モリヤシ', '百合ケ丘', 'ユリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県守谷市赤法花', '08', '08224', '3020111', '茨城県', 'イバラキケン', '守谷市', 'モリヤシ', '赤法花', 'アカボツケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県守谷市同地', '08', '08224', '3020112', '茨城県', 'イバラキケン', '守谷市', 'モリヤシ', '同地', 'ドウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県守谷市守谷甲', '08', '08224', '3020115', '茨城県', 'イバラキケン', '守谷市', 'モリヤシ', '守谷', 'モリヤ', null, null, '甲', 'コウ');
INSERT INTO `ms_addresses` VALUES ('21292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県守谷市大柏', '08', '08224', '3020116', '茨城県', 'イバラキケン', '守谷市', 'モリヤシ', '大柏', 'オオガシワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県守谷市野木崎', '08', '08224', '3020117', '茨城県', 'イバラキケン', '守谷市', 'モリヤシ', '野木崎', 'ノギサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県守谷市立沢', '08', '08224', '3020118', '茨城県', 'イバラキケン', '守谷市', 'モリヤシ', '立沢', 'タツザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県守谷市御所ケ丘', '08', '08224', '3020119', '茨城県', 'イバラキケン', '守谷市', 'モリヤシ', '御所ケ丘', 'ゴショガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県守谷市みずき野', '08', '08224', '3020121', '茨城県', 'イバラキケン', '守谷市', 'モリヤシ', 'みずき野', 'ミズキノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県守谷市小山', '08', '08224', '3020122', '茨城県', 'イバラキケン', '守谷市', 'モリヤシ', '小山', 'コヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県守谷市乙子', '08', '08224', '3020123', '茨城県', 'イバラキケン', '守谷市', 'モリヤシ', '乙子', 'オトゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県守谷市美園', '08', '08224', '3020124', '茨城県', 'イバラキケン', '守谷市', 'モリヤシ', '美園', 'ミソノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県守谷市高野', '08', '08224', '3020125', '茨城県', 'イバラキケン', '守谷市', 'モリヤシ', '高野', 'コウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県守谷市鈴塚', '08', '08224', '3020126', '茨城県', 'イバラキケン', '守谷市', 'モリヤシ', '鈴塚', 'スヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県守谷市松ケ丘', '08', '08224', '3020127', '茨城県', 'イバラキケン', '守谷市', 'モリヤシ', '松ケ丘', 'マツガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県守谷市けやき台', '08', '08224', '3020128', '茨城県', 'イバラキケン', '守谷市', 'モリヤシ', 'けやき台', 'ケヤキダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県守谷市ひがし野', '08', '08224', '3020131', '茨城県', 'イバラキケン', '守谷市', 'モリヤシ', 'ひがし野', 'ヒガシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常総市', '08', '08211', '3030000', '茨城県', 'イバラキケン', '常総市', 'ジョウソウシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('21311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常総市中山町', '08', '08211', '3030001', '茨城県', 'イバラキケン', '常総市', 'ジョウソウシ', '中山町', 'ナカヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常総市相野谷町', '08', '08211', '3030002', '茨城県', 'イバラキケン', '常総市', 'ジョウソウシ', '相野谷町', 'アイノヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常総市水海道橋本町', '08', '08211', '3030003', '茨城県', 'イバラキケン', '常総市', 'ジョウソウシ', '水海道橋本町', 'ミツカイドウハシモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常総市水海道元町', '08', '08211', '3030004', '茨城県', 'イバラキケン', '常総市', 'ジョウソウシ', '水海道元町', 'ミツカイドウモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常総市水海道森下町', '08', '08211', '3030005', '茨城県', 'イバラキケン', '常総市', 'ジョウソウシ', '水海道森下町', 'ミツカイドウモリシタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常総市小山戸町', '08', '08211', '3030006', '茨城県', 'イバラキケン', '常総市', 'ジョウソウシ', '小山戸町', 'コヤマドマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常総市東町', '08', '08211', '3030011', '茨城県', 'イバラキケン', '常総市', 'ジョウソウシ', '東町', 'アズマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常総市大崎町', '08', '08211', '3030012', '茨城県', 'イバラキケン', '常総市', 'ジョウソウシ', '大崎町', 'オオサキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常総市箕輪町', '08', '08211', '3030013', '茨城県', 'イバラキケン', '常総市', 'ジョウソウシ', '箕輪町', 'ミノワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常総市兵町', '08', '08211', '3030014', '茨城県', 'イバラキケン', '常総市', 'ジョウソウシ', '兵町', 'ヒョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常総市長助町', '08', '08211', '3030015', '茨城県', 'イバラキケン', '常総市', 'ジョウソウシ', '長助町', 'チョウスケマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常総市新井木町', '08', '08211', '3030016', '茨城県', 'イバラキケン', '常総市', 'ジョウソウシ', '新井木町', 'アライギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常総市平町', '08', '08211', '3030017', '茨城県', 'イバラキケン', '常総市', 'ジョウソウシ', '平町', 'ヘイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常総市十花町', '08', '08211', '3030018', '茨城県', 'イバラキケン', '常総市', 'ジョウソウシ', '十花町', 'ジュッカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常総市水海道諏訪町', '08', '08211', '3030021', '茨城県', 'イバラキケン', '常総市', 'ジョウソウシ', '水海道諏訪町', 'ミツカイドウスワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常総市水海道淵頭町', '08', '08211', '3030022', '茨城県', 'イバラキケン', '常総市', 'ジョウソウシ', '水海道淵頭町', 'ミツカイドウフチガシラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常総市水海道宝町', '08', '08211', '3030023', '茨城県', 'イバラキケン', '常総市', 'ジョウソウシ', '水海道宝町', 'ミツカイドウタカラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常総市水海道栄町', '08', '08211', '3030024', '茨城県', 'イバラキケン', '常総市', 'ジョウソウシ', '水海道栄町', 'ミツカイドウサカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常総市水海道亀岡町', '08', '08211', '3030025', '茨城県', 'イバラキケン', '常総市', 'ジョウソウシ', '水海道亀岡町', 'ミツカイドウカメオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常総市水海道本町', '08', '08211', '3030026', '茨城県', 'イバラキケン', '常総市', 'ジョウソウシ', '水海道本町', 'ミツカイドウホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常総市水海道山田町', '08', '08211', '3030031', '茨城県', 'イバラキケン', '常総市', 'ジョウソウシ', '水海道山田町', 'ミツカイドウヤマダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常総市水海道川又町', '08', '08211', '3030032', '茨城県', 'イバラキケン', '常総市', 'ジョウソウシ', '水海道川又町', 'ミツカイドウカワマタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常総市水海道高野町', '08', '08211', '3030033', '茨城県', 'イバラキケン', '常総市', 'ジョウソウシ', '水海道高野町', 'ミツカイドウコウヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常総市水海道天満町', '08', '08211', '3030034', '茨城県', 'イバラキケン', '常総市', 'ジョウソウシ', '水海道天満町', 'ミツカイドウテンマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常総市豊岡町', '08', '08211', '3030041', '茨城県', 'イバラキケン', '常総市', 'ジョウソウシ', '豊岡町', 'トヨオカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常総市坂手町', '08', '08211', '3030042', '茨城県', 'イバラキケン', '常総市', 'ジョウソウシ', '坂手町', 'サカテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常総市内守谷町', '08', '08211', '3030043', '茨城県', 'イバラキケン', '常総市', 'ジョウソウシ', '内守谷町', 'ウチモリヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常総市菅生町', '08', '08211', '3030044', '茨城県', 'イバラキケン', '常総市', 'ジョウソウシ', '菅生町', 'スガオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常総市大塚戸町', '08', '08211', '3030045', '茨城県', 'イバラキケン', '常総市', 'ジョウソウシ', '大塚戸町', 'オオツカドマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常総市内守谷町きぬの里', '08', '08211', '3030046', '茨城県', 'イバラキケン', '常総市', 'ジョウソウシ', '内守谷町きぬの里', 'ウチモリヤマチキヌノサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県下妻市', '08', '08210', '3040000', '茨城県', 'イバラキケン', '下妻市', 'シモツマシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('21344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県下妻市平方', '08', '08210', '3040001', '茨城県', 'イバラキケン', '下妻市', 'シモツマシ', '平方', 'ヒラカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県下妻市江', '08', '08210', '3040002', '茨城県', 'イバラキケン', '下妻市', 'シモツマシ', '江', 'エ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県下妻市関本下', '08', '08210', '3040003', '茨城県', 'イバラキケン', '下妻市', 'シモツマシ', '関本下', 'セキモトシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県下妻市大木', '08', '08210', '3040004', '茨城県', 'イバラキケン', '下妻市', 'シモツマシ', '大木', 'オオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県下妻市半谷', '08', '08210', '3040005', '茨城県', 'イバラキケン', '下妻市', 'シモツマシ', '半谷', 'ハンヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県下妻市柴', '08', '08210', '3040006', '茨城県', 'イバラキケン', '下妻市', 'シモツマシ', '柴', 'シバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県下妻市黒駒', '08', '08210', '3040007', '茨城県', 'イバラキケン', '下妻市', 'シモツマシ', '黒駒', 'クロコマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県下妻市神明', '08', '08210', '3040011', '茨城県', 'イバラキケン', '下妻市', 'シモツマシ', '神明', 'シンメイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県下妻市若柳', '08', '08210', '3040012', '茨城県', 'イバラキケン', '下妻市', 'シモツマシ', '若柳', 'ワカヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県下妻市下宮', '08', '08210', '3040013', '茨城県', 'イバラキケン', '下妻市', 'シモツマシ', '下宮', 'シタミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県下妻市中郷', '08', '08210', '3040014', '茨城県', 'イバラキケン', '下妻市', 'シモツマシ', '中郷', 'ナカゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県下妻市下田', '08', '08210', '3040015', '茨城県', 'イバラキケン', '下妻市', 'シモツマシ', '下田', 'シモダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県下妻市数須', '08', '08210', '3040016', '茨城県', 'イバラキケン', '下妻市', 'シモツマシ', '数須', 'カズス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県下妻市筑波島', '08', '08210', '3040017', '茨城県', 'イバラキケン', '下妻市', 'シモツマシ', '筑波島', 'チクワジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県下妻市平川戸', '08', '08210', '3040018', '茨城県', 'イバラキケン', '下妻市', 'シモツマシ', '平川戸', 'ヒラカワド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県下妻市北大宝', '08', '08210', '3040021', '茨城県', 'イバラキケン', '下妻市', 'シモツマシ', '北大宝', 'キタダイホウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県下妻市大宝', '08', '08210', '3040022', '茨城県', 'イバラキケン', '下妻市', 'シモツマシ', '大宝', 'ダイホウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県下妻市大串', '08', '08210', '3040023', '茨城県', 'イバラキケン', '下妻市', 'シモツマシ', '大串', 'オオクシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県下妻市坂本新田', '08', '08210', '3040024', '茨城県', 'イバラキケン', '下妻市', 'シモツマシ', '坂本新田', 'サカモトシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県下妻市大木新田', '08', '08210', '3040025', '茨城県', 'イバラキケン', '下妻市', 'シモツマシ', '大木新田', 'オオキシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県下妻市平沼', '08', '08210', '3040026', '茨城県', 'イバラキケン', '下妻市', 'シモツマシ', '平沼', 'ヒラヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県下妻市福田', '08', '08210', '3040027', '茨城県', 'イバラキケン', '下妻市', 'シモツマシ', '福田', 'フクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県下妻市下木戸', '08', '08210', '3040028', '茨城県', 'イバラキケン', '下妻市', 'シモツマシ', '下木戸', 'シモキド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県下妻市高道祖', '08', '08210', '3040031', '茨城県', 'イバラキケン', '下妻市', 'シモツマシ', '高道祖', 'タカサイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県下妻市比毛', '08', '08210', '3040032', '茨城県', 'イバラキケン', '下妻市', 'シモツマシ', '比毛', 'ヒケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県下妻市堀篭', '08', '08210', '3040033', '茨城県', 'イバラキケン', '下妻市', 'シモツマシ', '堀篭', 'ホリゴメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県下妻市坂井', '08', '08210', '3040034', '茨城県', 'イバラキケン', '下妻市', 'シモツマシ', '坂井', 'サカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県下妻市横根', '08', '08210', '3040035', '茨城県', 'イバラキケン', '下妻市', 'シモツマシ', '横根', 'ヨコネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県下妻市古沢', '08', '08210', '3040041', '茨城県', 'イバラキケン', '下妻市', 'シモツマシ', '古沢', 'フルサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県下妻市袋畑', '08', '08210', '3040042', '茨城県', 'イバラキケン', '下妻市', 'シモツマシ', '袋畑', 'フクロハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県下妻市谷田部', '08', '08210', '3040043', '茨城県', 'イバラキケン', '下妻市', 'シモツマシ', '谷田部', 'ヤタベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県下妻市柳原', '08', '08210', '3040044', '茨城県', 'イバラキケン', '下妻市', 'シモツマシ', '柳原', 'ヤギワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県下妻市山尻', '08', '08210', '3040045', '茨城県', 'イバラキケン', '下妻市', 'シモツマシ', '山尻', 'ヤマジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県下妻市樋橋', '08', '08210', '3040046', '茨城県', 'イバラキケン', '下妻市', 'シモツマシ', '樋橋', 'ヒバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県下妻市肘谷', '08', '08210', '3040047', '茨城県', 'イバラキケン', '下妻市', 'シモツマシ', '肘谷', 'ヒジヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県下妻市加養', '08', '08210', '3040048', '茨城県', 'イバラキケン', '下妻市', 'シモツマシ', '加養', 'カヨウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県下妻市新堀', '08', '08210', '3040049', '茨城県', 'イバラキケン', '下妻市', 'シモツマシ', '新堀', 'ニイボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県下妻市亀崎', '08', '08210', '3040050', '茨城県', 'イバラキケン', '下妻市', 'シモツマシ', '亀崎', 'カメザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県下妻市小島', '08', '08210', '3040051', '茨城県', 'イバラキケン', '下妻市', 'シモツマシ', '小島', 'オジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県下妻市二本紀', '08', '08210', '3040052', '茨城県', 'イバラキケン', '下妻市', 'シモツマシ', '二本紀', 'ニホンギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県下妻市今泉', '08', '08210', '3040053', '茨城県', 'イバラキケン', '下妻市', 'シモツマシ', '今泉', 'イマイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県下妻市中居指', '08', '08210', '3040054', '茨城県', 'イバラキケン', '下妻市', 'シモツマシ', '中居指', 'ナカイザシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県下妻市砂沼新田', '08', '08210', '3040055', '茨城県', 'イバラキケン', '下妻市', 'シモツマシ', '砂沼新田', 'サヌマシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県下妻市長塚', '08', '08210', '3040056', '茨城県', 'イバラキケン', '下妻市', 'シモツマシ', '長塚', 'ナガツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県下妻市石の宮', '08', '08210', '3040057', '茨城県', 'イバラキケン', '下妻市', 'シモツマシ', '石の宮', 'イシノミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県下妻市下妻丙', '08', '08210', '3040061', '茨城県', 'イバラキケン', '下妻市', 'シモツマシ', '下妻丙', 'シモツマヘイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県下妻市下妻戊', '08', '08210', '3040062', '茨城県', 'イバラキケン', '下妻市', 'シモツマシ', '下妻戊', 'シモツマボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県下妻市小野子町', '08', '08210', '3040063', '茨城県', 'イバラキケン', '下妻市', 'シモツマシ', '小野子町', 'オノコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県下妻市本城町', '08', '08210', '3040064', '茨城県', 'イバラキケン', '下妻市', 'シモツマシ', '本城町', 'モトシロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県下妻市本宿町', '08', '08210', '3040065', '茨城県', 'イバラキケン', '下妻市', 'シモツマシ', '本宿町', 'ホンジュクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県下妻市下妻甲', '08', '08210', '3040066', '茨城県', 'イバラキケン', '下妻市', 'シモツマシ', '下妻甲', 'シモツマコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県下妻市下妻乙', '08', '08210', '3040067', '茨城県', 'イバラキケン', '下妻市', 'シモツマシ', '下妻乙', 'シモツマオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県下妻市下妻丁', '08', '08210', '3040068', '茨城県', 'イバラキケン', '下妻市', 'シモツマシ', '下妻丁', 'シモツマテイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県下妻市田町', '08', '08210', '3040069', '茨城県', 'イバラキケン', '下妻市', 'シモツマシ', '田町', 'タマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県下妻市尻手', '08', '08210', '3040071', '茨城県', 'イバラキケン', '下妻市', 'シモツマシ', '尻手', 'シッテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県下妻市渋井', '08', '08210', '3040072', '茨城県', 'イバラキケン', '下妻市', 'シモツマシ', '渋井', 'シブイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県下妻市桐ケ瀬', '08', '08210', '3040073', '茨城県', 'イバラキケン', '下妻市', 'シモツマシ', '桐ケ瀬', 'キリガセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県下妻市赤須', '08', '08210', '3040074', '茨城県', 'イバラキケン', '下妻市', 'シモツマシ', '赤須', 'アカス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県下妻市南原', '08', '08210', '3040075', '茨城県', 'イバラキケン', '下妻市', 'シモツマシ', '南原', 'ミナミハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県下妻市前河原', '08', '08210', '3040076', '茨城県', 'イバラキケン', '下妻市', 'シモツマシ', '前河原', 'マエガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県下妻市大園木', '08', '08210', '3040801', '茨城県', 'イバラキケン', '下妻市', 'シモツマシ', '大園木', 'オオゾノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県下妻市鯨', '08', '08210', '3040802', '茨城県', 'イバラキケン', '下妻市', 'シモツマシ', '鯨', 'クジラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県下妻市伊古立', '08', '08210', '3040803', '茨城県', 'イバラキケン', '下妻市', 'シモツマシ', '伊古立', 'イゴダツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県下妻市長萱', '08', '08210', '3040804', '茨城県', 'イバラキケン', '下妻市', 'シモツマシ', '長萱', 'オサガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県下妻市唐崎', '08', '08210', '3040805', '茨城県', 'イバラキケン', '下妻市', 'シモツマシ', '唐崎', 'カラサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県下妻市見田', '08', '08210', '3040806', '茨城県', 'イバラキケン', '下妻市', 'シモツマシ', '見田', 'ミタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県下妻市下栗', '08', '08210', '3040811', '茨城県', 'イバラキケン', '下妻市', 'シモツマシ', '下栗', 'シモグリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県下妻市田下', '08', '08210', '3040812', '茨城県', 'イバラキケン', '下妻市', 'シモツマシ', '田下', 'タゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県下妻市本宗道', '08', '08210', '3040813', '茨城県', 'イバラキケン', '下妻市', 'シモツマシ', '本宗道', 'ホンソウドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県下妻市宗道', '08', '08210', '3040814', '茨城県', 'イバラキケン', '下妻市', 'シモツマシ', '宗道', 'ソウドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県下妻市渋田', '08', '08210', '3040815', '茨城県', 'イバラキケン', '下妻市', 'シモツマシ', '渋田', 'シブタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県下妻市原', '08', '08210', '3040816', '茨城県', 'イバラキケン', '下妻市', 'シモツマシ', '原', 'ハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県下妻市羽子', '08', '08210', '3040817', '茨城県', 'イバラキケン', '下妻市', 'シモツマシ', '羽子', 'ハネゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県下妻市鬼怒', '08', '08210', '3040818', '茨城県', 'イバラキケン', '下妻市', 'シモツマシ', '鬼怒', 'キヌ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県下妻市鎌庭', '08', '08210', '3040819', '茨城県', 'イバラキケン', '下妻市', 'シモツマシ', '鎌庭', 'カマニワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県下妻市別府', '08', '08210', '3040821', '茨城県', 'イバラキケン', '下妻市', 'シモツマシ', '別府', 'ベップ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県下妻市皆葉', '08', '08210', '3040822', '茨城県', 'イバラキケン', '下妻市', 'シモツマシ', '皆葉', 'ミナバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県下妻市五箇', '08', '08210', '3040823', '茨城県', 'イバラキケン', '下妻市', 'シモツマシ', '五箇', 'ゴカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県下妻市村岡', '08', '08210', '3040824', '茨城県', 'イバラキケン', '下妻市', 'シモツマシ', '村岡', 'ムラオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市', '08', '08220', '3050000', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('21426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市栗原', '08', '08220', '3050001', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '栗原', 'クリハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市上野', '08', '08220', '3050002', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '上野', 'ウエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市桜', '08', '08220', '3050003', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '桜', 'サクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市柴崎', '08', '08220', '3050004', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '柴崎', 'シバサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市天久保', '08', '08220', '3050005', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '天久保', 'アマクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市天王台', '08', '08220', '3050006', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '天王台', 'テンノウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市上境', '08', '08220', '3050011', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '上境', 'カミザカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市中根', '08', '08220', '3050012', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '中根', 'ナカネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市栄', '08', '08220', '3050013', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '栄', 'サカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市松栄', '08', '08220', '3050014', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '松栄', 'ショウエイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市松塚', '08', '08220', '3050015', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '松塚', 'マツヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市大', '08', '08220', '3050016', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '大', 'オオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市横町', '08', '08220', '3050017', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '横町', 'ヨコマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市金田', '08', '08220', '3050018', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '金田', 'コンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市古来', '08', '08220', '3050021', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '古来', 'フルク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市吉瀬', '08', '08220', '3050022', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '吉瀬', 'キセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市上ノ室', '08', '08220', '3050023', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '上ノ室', 'ウエノムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市倉掛', '08', '08220', '3050024', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '倉掛', 'クラカケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市花室', '08', '08220', '3050025', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '花室', 'ハナムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市岡村新田', '08', '08220', '3050026', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '岡村新田', 'オカムラシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市東岡', '08', '08220', '3050027', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '東岡', 'ヒガシオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市妻木', '08', '08220', '3050028', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '妻木', 'サイキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市吾妻', '08', '08220', '3050031', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '吾妻', 'アヅマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市竹園', '08', '08220', '3050032', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '竹園', 'タケゾノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市東新井', '08', '08220', '3050033', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '東新井', 'ヒガシアライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市小野崎', '08', '08220', '3050034', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '小野崎', 'オノザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市松代', '08', '08220', '3050035', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '松代', 'マツシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市西郷', '08', '08220', '3050036', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '西郷', 'サイゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市上広岡', '08', '08220', '3050041', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '上広岡', 'カミヒロオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市下広岡', '08', '08220', '3050042', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '下広岡', 'シモヒロオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市大角豆', '08', '08220', '3050043', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '大角豆', 'ササギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市並木', '08', '08220', '3050044', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '並木', 'ナミキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市梅園', '08', '08220', '3050045', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '梅園', 'ウメゾノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市東', '08', '08220', '3050046', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '東', 'ヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市千現', '08', '08220', '3050047', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '千現', 'センゲン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市二の宮', '08', '08220', '3050051', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '二の宮', 'ニノミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市長峰', '08', '08220', '3050052', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '長峰', 'ナガミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市小野川', '08', '08220', '3050053', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '小野川', 'オノガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市西大沼', '08', '08220', '3050054', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '西大沼', 'ニシオオヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市上原', '08', '08220', '3050055', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '上原', 'カミハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市松野木', '08', '08220', '3050056', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '松野木', 'マツノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市稲荷前', '08', '08220', '3050061', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '稲荷前', 'イナリマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市赤塚', '08', '08220', '3050062', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '赤塚', 'アカツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市下原', '08', '08220', '3050063', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '下原', 'シモハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市梶内', '08', '08220', '3050064', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '梶内', 'カジウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市南中妻', '08', '08220', '3050065', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '南中妻', 'ミナミナカヅマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市北中妻', '08', '08220', '3050066', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '北中妻', 'キタナカヅマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市館野', '08', '08220', '3050067', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '館野', 'タテノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市中内', '08', '08220', '3050068', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '中内', 'ナカウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市稲岡', '08', '08220', '3050071', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '稲岡', 'イナオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市北中島', '08', '08220', '3050072', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '北中島', 'キタナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市市之台', '08', '08220', '3050073', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '市之台', 'イチノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市高野台', '08', '08220', '3050074', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '高野台', 'コウヤダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市下横場', '08', '08220', '3050075', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '下横場', 'シモヨコバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市新牧田', '08', '08220', '3050076', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '新牧田', 'アラマキダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市鷹野原', '08', '08220', '3050077', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '鷹野原', 'タカノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市大穂', '08', '08220', '3050801', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '大穂', 'オオホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市立原', '08', '08220', '3050802', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '立原', 'タチハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市南原', '08', '08220', '3050803', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '南原', 'ミナミハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市旭', '08', '08220', '3050804', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '旭', 'アサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市花畑', '08', '08220', '3050805', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '花畑', 'ハナバタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市北郷', '08', '08220', '3050811', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '北郷', 'キタサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市東平塚', '08', '08220', '3050812', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '東平塚', 'ヒガシヒラツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市下平塚', '08', '08220', '3050813', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '下平塚', 'シモヒラツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市西平塚', '08', '08220', '3050814', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '西平塚', 'ニシヒラツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市西原', '08', '08220', '3050815', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '西原', 'ニシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市学園の森', '08', '08220', '3050816', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '学園の森', 'ガクエンノモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市研究学園', '08', '08220', '3050817', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '研究学園', 'ケンキュウガクエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市学園南', '08', '08220', '3050818', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '学園南', 'ガクエンミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市春日', '08', '08220', '3050821', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '春日', 'カスガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市苅間', '08', '08220', '3050822', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '苅間', 'カリマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市原', '08', '08220', '3050823', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '原', 'ハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市葛城根崎', '08', '08220', '3050824', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '葛城根崎', 'カツラギネサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市西大橋', '08', '08220', '3050831', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '西大橋', 'ニシオオハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市西岡', '08', '08220', '3050832', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '西岡', 'ニシオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市島', '08', '08220', '3050833', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '島', 'シマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市手代木', '08', '08220', '3050834', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '手代木', 'テシロギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市新井', '08', '08220', '3050835', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '新井', 'アライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市山中', '08', '08220', '3050836', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '山中', 'ヤマナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市御幸が丘', '08', '08220', '3050841', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '御幸が丘', 'ミユキガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市柳橋', '08', '08220', '3050842', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '柳橋', 'ヤギハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市八幡台', '08', '08220', '3050843', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '八幡台', 'ハチマンダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市小白硲', '08', '08220', '3050844', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '小白硲', 'コジラハザマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市大白硲', '08', '08220', '3050845', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '大白硲', 'オオジラハザマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市平', '08', '08220', '3050846', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '平', 'タイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市陣場', '08', '08220', '3050847', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '陣場', 'ジンバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市大わし', '08', '08220', '3050851', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '大わし', 'オオワシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市藤本', '08', '08220', '3050852', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '藤本', 'フジモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市榎戸', '08', '08220', '3050853', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '榎戸', 'エノキド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市上横場', '08', '08220', '3050854', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '上横場', 'カミヨコバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市今泉', '08', '08220', '3050855', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '今泉', 'イマイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市観音台', '08', '08220', '3050856', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '観音台', 'カンノンダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市羽成', '08', '08220', '3050857', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '羽成', 'ハナレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市谷田部', '08', '08220', '3050861', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '谷田部', 'ヤタベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市東丸山', '08', '08220', '3050862', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '東丸山', 'ヒガシマルヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市緑が丘', '08', '08220', '3050863', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '緑が丘', 'ミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市境松', '08', '08220', '3050864', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '境松', 'サカイマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市根崎', '08', '08220', '3050865', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '根崎', 'ネサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市古館', '08', '08220', '3050866', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '古館', 'フルダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市境田', '08', '08220', '3050867', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '境田', 'サカイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市上萱丸', '08', '08220', '3050871', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '上萱丸', 'カミカヤマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市下萱丸', '08', '08220', '3050872', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '下萱丸', 'シモカヤマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市中野', '08', '08220', '3050873', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '中野', 'ナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市飯田', '08', '08220', '3050874', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '飯田', 'イイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市花島新田', '08', '08220', '3050875', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '花島新田', 'ハナシマシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市西栗山', '08', '08220', '3050876', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '西栗山', 'ニシクリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市片田', '08', '08220', '3050877', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '片田', 'カタダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市みどりの', '08', '08220', '3050881', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', 'みどりの', 'ミドリノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市みどりの中央', '08', '08220', '3050882', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', 'みどりの中央', 'ミドリノチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市みどりの東', '08', '08220', '3050883', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', 'みどりの東', 'ミドリノヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市みどりの南', '08', '08220', '3050884', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', 'みどりの南', 'ミドリノミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市池の台', '08', '08220', '3050901', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '池の台', 'イケノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市西の沢畜産試験場圃場', '08', '08220', '3050902', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '西の沢', 'ニシノサワ', null, null, '畜産試験場圃場', 'チクサンシケンジョウボジョウ');
INSERT INTO `ms_addresses` VALUES ('21539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県つくば市松の里', '08', '08220', '3050903', '茨城県', 'イバラキケン', 'つくば市', 'ツクバシ', '松の里', 'マツノサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県古河市', '08', '08204', '3060000', '茨城県', 'イバラキケン', '古河市', 'コガシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('21565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県古河市静町', '08', '08204', '3060001', '茨城県', 'イバラキケン', '古河市', 'コガシ', '静町', 'シズカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県古河市三杉町', '08', '08204', '3060002', '茨城県', 'イバラキケン', '古河市', 'コガシ', '三杉町', 'ミスギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県古河市緑町', '08', '08204', '3060003', '茨城県', 'イバラキケン', '古河市', 'コガシ', '緑町', 'ミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県古河市雷電町', '08', '08204', '3060004', '茨城県', 'イバラキケン', '古河市', 'コガシ', '雷電町', 'ライデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県古河市北町', '08', '08204', '3060005', '茨城県', 'イバラキケン', '古河市', 'コガシ', '北町', 'キタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県古河市平和町', '08', '08204', '3060006', '茨城県', 'イバラキケン', '古河市', 'コガシ', '平和町', 'ヘイワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県古河市常盤町', '08', '08204', '3060007', '茨城県', 'イバラキケン', '古河市', 'コガシ', '常盤町', 'トキワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県古河市東', '08', '08204', '3060011', '茨城県', 'イバラキケン', '古河市', 'コガシ', '東', 'ヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県古河市旭町', '08', '08204', '3060012', '茨城県', 'イバラキケン', '古河市', 'コガシ', '旭町', 'アサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県古河市東本町', '08', '08204', '3060013', '茨城県', 'イバラキケン', '古河市', 'コガシ', '東本町', 'ヒガシホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県古河市下山町', '08', '08204', '3060014', '茨城県', 'イバラキケン', '古河市', 'コガシ', '下山町', 'シモヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県古河市南町', '08', '08204', '3060015', '茨城県', 'イバラキケン', '古河市', 'コガシ', '南町', 'ミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県古河市古河', '08', '08204', '3060016', '茨城県', 'イバラキケン', '古河市', 'コガシ', '古河', 'コガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県古河市松並', '08', '08204', '3060021', '茨城県', 'イバラキケン', '古河市', 'コガシ', '松並', 'マツナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県古河市横山町', '08', '08204', '3060022', '茨城県', 'イバラキケン', '古河市', 'コガシ', '横山町', 'ヨコヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県古河市本町', '08', '08204', '3060023', '茨城県', 'イバラキケン', '古河市', 'コガシ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県古河市幸町', '08', '08204', '3060024', '茨城県', 'イバラキケン', '古河市', 'コガシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県古河市原町', '08', '08204', '3060025', '茨城県', 'イバラキケン', '古河市', 'コガシ', '原町', 'ハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県古河市原', '08', '08204', '3060026', '茨城県', 'イバラキケン', '古河市', 'コガシ', '原', 'ハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県古河市宮前町', '08', '08204', '3060031', '茨城県', 'イバラキケン', '古河市', 'コガシ', '宮前町', 'ミヤマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県古河市大手町', '08', '08204', '3060032', '茨城県', 'イバラキケン', '古河市', 'コガシ', '大手町', 'オオテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県古河市中央町', '08', '08204', '3060033', '茨城県', 'イバラキケン', '古河市', 'コガシ', '中央町', 'チュウオウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県古河市長谷町', '08', '08204', '3060034', '茨城県', 'イバラキケン', '古河市', 'コガシ', '長谷町', 'ハセマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県古河市長谷', '08', '08204', '3060035', '茨城県', 'イバラキケン', '古河市', 'コガシ', '長谷', 'ハセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県古河市桜町', '08', '08204', '3060036', '茨城県', 'イバラキケン', '古河市', 'コガシ', '桜町', 'サクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県古河市錦町', '08', '08204', '3060037', '茨城県', 'イバラキケン', '古河市', 'コガシ', '錦町', 'ニシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県古河市西町', '08', '08204', '3060038', '茨城県', 'イバラキケン', '古河市', 'コガシ', '西町', 'ニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県古河市鴻巣', '08', '08204', '3060041', '茨城県', 'イバラキケン', '古河市', 'コガシ', '鴻巣', 'コウノス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県古河市三和', '08', '08204', '3060042', '茨城県', 'イバラキケン', '古河市', 'コガシ', '三和', 'サンワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県古河市鳥喰', '08', '08204', '3060043', '茨城県', 'イバラキケン', '古河市', 'コガシ', '鳥喰', 'トリハミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県古河市新久田', '08', '08204', '3060044', '茨城県', 'イバラキケン', '古河市', 'コガシ', '新久田', 'アラクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県古河市駒ケ崎', '08', '08204', '3060045', '茨城県', 'イバラキケン', '古河市', 'コガシ', '駒ケ崎', 'コマガサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県古河市牧野地', '08', '08204', '3060046', '茨城県', 'イバラキケン', '古河市', 'コガシ', '牧野地', 'マキノジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県古河市立崎', '08', '08204', '3060047', '茨城県', 'イバラキケン', '古河市', 'コガシ', '立崎', 'タツザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県古河市茶屋新田', '08', '08204', '3060051', '茨城県', 'イバラキケン', '古河市', 'コガシ', '茶屋新田', 'チャヤシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県古河市大山', '08', '08204', '3060052', '茨城県', 'イバラキケン', '古河市', 'コガシ', '大山', 'オオヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県古河市中田', '08', '08204', '3060053', '茨城県', 'イバラキケン', '古河市', 'コガシ', '中田', 'ナカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県古河市中田新田', '08', '08204', '3060054', '茨城県', 'イバラキケン', '古河市', 'コガシ', '中田新田', 'ナカダシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県古河市けやき平', '08', '08204', '3060055', '茨城県', 'イバラキケン', '古河市', 'コガシ', 'けやき平', 'ケヤキダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県古河市坂間', '08', '08204', '3060056', '茨城県', 'イバラキケン', '古河市', 'コガシ', '坂間', 'サカマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県古河市尾崎', '08', '08204', '3060101', '茨城県', 'イバラキケン', '古河市', 'コガシ', '尾崎', 'オサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県古河市長左エ門新田', '08', '08204', '3060103', '茨城県', 'イバラキケン', '古河市', 'コガシ', '長左エ門新田', 'チョウザエモンシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県古河市恩名', '08', '08204', '3060104', '茨城県', 'イバラキケン', '古河市', 'コガシ', '恩名', 'オンナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県古河市江口', '08', '08204', '3060105', '茨城県', 'イバラキケン', '古河市', 'コガシ', '江口', 'エグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県古河市北間中橋', '08', '08204', '3060106', '茨城県', 'イバラキケン', '古河市', 'コガシ', '北間中橋', 'キタマナカバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県古河市東間中橋', '08', '08204', '3060107', '茨城県', 'イバラキケン', '古河市', 'コガシ', '東間中橋', 'ヒガシマナカバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県古河市南間中橋', '08', '08204', '3060108', '茨城県', 'イバラキケン', '古河市', 'コガシ', '南間中橋', 'ミナミマナカバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県古河市西間中橋', '08', '08204', '3060109', '茨城県', 'イバラキケン', '古河市', 'コガシ', '西間中橋', 'ニシマナカバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県古河市大和田', '08', '08204', '3060111', '茨城県', 'イバラキケン', '古河市', 'コガシ', '大和田', 'オオワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県古河市東山田', '08', '08204', '3060112', '茨城県', 'イバラキケン', '古河市', 'コガシ', '東山田', 'ヒガシヤマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県古河市谷貝', '08', '08204', '3060113', '茨城県', 'イバラキケン', '古河市', 'コガシ', '谷貝', 'ヤガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県古河市山田', '08', '08204', '3060114', '茨城県', 'イバラキケン', '古河市', 'コガシ', '山田', 'ヤマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県古河市北山田', '08', '08204', '3060115', '茨城県', 'イバラキケン', '古河市', 'コガシ', '北山田', 'キタヤマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県古河市新和田', '08', '08204', '3060116', '茨城県', 'イバラキケン', '古河市', 'コガシ', '新和田', 'シンワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県古河市駒込', '08', '08204', '3060121', '茨城県', 'イバラキケン', '古河市', 'コガシ', '駒込', 'コマゴメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県古河市上和田', '08', '08204', '3060122', '茨城県', 'イバラキケン', '古河市', 'コガシ', '上和田', 'カミワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県古河市五部', '08', '08204', '3060123', '茨城県', 'イバラキケン', '古河市', 'コガシ', '五部', 'ゴヘイ', null, null, null, null), ('21622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県古河市東諸川', '08', '08204', '3060124', '茨城県', 'イバラキケン', '古河市', 'コガシ', '東諸川', 'ヒガシモロカワ', null, null, null, null), ('21623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県古河市仁連', '08', '08204', '3060125', '茨城県', 'イバラキケン', '古河市', 'コガシ', '仁連', 'ニレイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県古河市諸川', '08', '08204', '3060126', '茨城県', 'イバラキケン', '古河市', 'コガシ', '諸川', 'モロカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県古河市下片田', '08', '08204', '3060127', '茨城県', 'イバラキケン', '古河市', 'コガシ', '下片田', 'シモカタタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県古河市上片田', '08', '08204', '3060128', '茨城県', 'イバラキケン', '古河市', 'コガシ', '上片田', 'カミカタタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県古河市上大野', '08', '08204', '3060201', '茨城県', 'イバラキケン', '古河市', 'コガシ', '上大野', 'カミオオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県古河市稲宮', '08', '08204', '3060202', '茨城県', 'イバラキケン', '古河市', 'コガシ', '稲宮', 'イナミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県古河市柳橋', '08', '08204', '3060203', '茨城県', 'イバラキケン', '古河市', 'コガシ', '柳橋', 'ヤギハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県古河市下大野', '08', '08204', '3060204', '茨城県', 'イバラキケン', '古河市', 'コガシ', '下大野', 'シモオオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県古河市関戸', '08', '08204', '3060205', '茨城県', 'イバラキケン', '古河市', 'コガシ', '関戸', 'セキド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県古河市丘里', '08', '08204', '3060206', '茨城県', 'イバラキケン', '古河市', 'コガシ', '丘里', 'オカザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県古河市葛生', '08', '08204', '3060211', '茨城県', 'イバラキケン', '古河市', 'コガシ', '葛生', 'カズロウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県古河市久能', '08', '08204', '3060212', '茨城県', 'イバラキケン', '古河市', 'コガシ', '久能', 'クノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県古河市北利根', '08', '08204', '3060213', '茨城県', 'イバラキケン', '古河市', 'コガシ', '北利根', 'キタトネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県古河市高野', '08', '08204', '3060214', '茨城県', 'イバラキケン', '古河市', 'コガシ', '高野', 'コウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県古河市水海', '08', '08204', '3060215', '茨城県', 'イバラキケン', '古河市', 'コガシ', '水海', 'ミズウミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県古河市前林', '08', '08204', '3060216', '茨城県', 'イバラキケン', '古河市', 'コガシ', '前林', 'マエバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県古河市駒羽根', '08', '08204', '3060221', '茨城県', 'イバラキケン', '古河市', 'コガシ', '駒羽根', 'コマハネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県古河市釈迦', '08', '08204', '3060222', '茨城県', 'イバラキケン', '古河市', 'コガシ', '釈迦', 'シャカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県古河市上砂井', '08', '08204', '3060223', '茨城県', 'イバラキケン', '古河市', 'コガシ', '上砂井', 'カミイサゴイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県古河市砂井新田', '08', '08204', '3060224', '茨城県', 'イバラキケン', '古河市', 'コガシ', '砂井新田', 'イサゴイシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県古河市磯部', '08', '08204', '3060225', '茨城県', 'イバラキケン', '古河市', 'コガシ', '磯部', 'イソベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県古河市女沼', '08', '08204', '3060226', '茨城県', 'イバラキケン', '古河市', 'コガシ', '女沼', 'オナヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県古河市小堤', '08', '08204', '3060231', '茨城県', 'イバラキケン', '古河市', 'コガシ', '小堤', 'コヅツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県古河市東牛谷', '08', '08204', '3060232', '茨城県', 'イバラキケン', '古河市', 'コガシ', '東牛谷', 'ヒガシウシガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県古河市西牛谷', '08', '08204', '3060233', '茨城県', 'イバラキケン', '古河市', 'コガシ', '西牛谷', 'ニシウシガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県古河市上辺見', '08', '08204', '3060234', '茨城県', 'イバラキケン', '古河市', 'コガシ', '上辺見', 'カミヘミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県古河市下辺見', '08', '08204', '3060235', '茨城県', 'イバラキケン', '古河市', 'コガシ', '下辺見', 'シモヘミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県古河市大堤', '08', '08204', '3060236', '茨城県', 'イバラキケン', '古河市', 'コガシ', '大堤', 'オオツツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県猿島郡五霞町', '08', '08542', '3060300', '茨城県', 'イバラキケン', '猿島郡五霞町', 'サシマグンゴカマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('21652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県猿島郡五霞町山王山', '08', '08542', '3060301', '茨城県', 'イバラキケン', '猿島郡五霞町', 'サシマグンゴカマチ', '山王山', 'サンノウヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県猿島郡五霞町山王', '08', '08542', '3060302', '茨城県', 'イバラキケン', '猿島郡五霞町', 'サシマグンゴカマチ', '山王', 'サンノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県猿島郡五霞町江川', '08', '08542', '3060303', '茨城県', 'イバラキケン', '猿島郡五霞町', 'サシマグンゴカマチ', '江川', 'エガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県猿島郡五霞町幸主', '08', '08542', '3060304', '茨城県', 'イバラキケン', '猿島郡五霞町', 'サシマグンゴカマチ', '幸主', 'コウシュ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県猿島郡五霞町冬木', '08', '08542', '3060305', '茨城県', 'イバラキケン', '猿島郡五霞町', 'サシマグンゴカマチ', '冬木', 'フユギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県猿島郡五霞町原宿台', '08', '08542', '3060306', '茨城県', 'イバラキケン', '猿島郡五霞町', 'サシマグンゴカマチ', '原宿台', 'ハラジュクダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県猿島郡五霞町小福田', '08', '08542', '3060307', '茨城県', 'イバラキケン', '猿島郡五霞町', 'サシマグンゴカマチ', '小福田', 'コフクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県猿島郡五霞町大福田', '08', '08542', '3060311', '茨城県', 'イバラキケン', '猿島郡五霞町', 'サシマグンゴカマチ', '大福田', 'オオフクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県猿島郡五霞町新幸谷', '08', '08542', '3060312', '茨城県', 'イバラキケン', '猿島郡五霞町', 'サシマグンゴカマチ', '新幸谷', 'シンコウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県猿島郡五霞町元栗橋', '08', '08542', '3060313', '茨城県', 'イバラキケン', '猿島郡五霞町', 'サシマグンゴカマチ', '元栗橋', 'モトクリハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県猿島郡五霞町川妻', '08', '08542', '3060314', '茨城県', 'イバラキケン', '猿島郡五霞町', 'サシマグンゴカマチ', '川妻', 'カワツマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県猿島郡五霞町小手指', '08', '08542', '3060315', '茨城県', 'イバラキケン', '猿島郡五霞町', 'サシマグンゴカマチ', '小手指', 'コテサシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県猿島郡五霞町釈迦', '08', '08542', '3060316', '茨城県', 'イバラキケン', '猿島郡五霞町', 'サシマグンゴカマチ', '釈迦', 'シャカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県猿島郡五霞町前林', '08', '08542', '3060317', '茨城県', 'イバラキケン', '猿島郡五霞町', 'サシマグンゴカマチ', '前林', 'マエバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県猿島郡境町', '08', '08546', '3060400', '茨城県', 'イバラキケン', '猿島郡境町', 'サシマグンサカイマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('21668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県猿島郡境町志鳥', '08', '08546', '3060401', '茨城県', 'イバラキケン', '猿島郡境町', 'サシマグンサカイマチ', '志鳥', 'シトリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県猿島郡境町猿山', '08', '08546', '3060402', '茨城県', 'イバラキケン', '猿島郡境町', 'サシマグンサカイマチ', '猿山', 'サルヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県猿島郡境町蛇池', '08', '08546', '3060403', '茨城県', 'イバラキケン', '猿島郡境町', 'サシマグンサカイマチ', '蛇池', 'ジャイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県猿島郡境町長井戸', '08', '08546', '3060404', '茨城県', 'イバラキケン', '猿島郡境町', 'サシマグンサカイマチ', '長井戸', 'ナガイド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県猿島郡境町塚崎', '08', '08546', '3060405', '茨城県', 'イバラキケン', '猿島郡境町', 'サシマグンサカイマチ', '塚崎', 'ツカザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県猿島郡境町横塚', '08', '08546', '3060406', '茨城県', 'イバラキケン', '猿島郡境町', 'サシマグンサカイマチ', '横塚', 'ヨコツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県猿島郡境町稲尾', '08', '08546', '3060407', '茨城県', 'イバラキケン', '猿島郡境町', 'サシマグンサカイマチ', '稲尾', 'イナオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県猿島郡境町下砂井', '08', '08546', '3060411', '茨城県', 'イバラキケン', '猿島郡境町', 'サシマグンサカイマチ', '下砂井', 'シモイサゴイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県猿島郡境町栗山', '08', '08546', '3060412', '茨城県', 'イバラキケン', '猿島郡境町', 'サシマグンサカイマチ', '栗山', 'クリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県猿島郡境町山崎', '08', '08546', '3060413', '茨城県', 'イバラキケン', '猿島郡境町', 'サシマグンサカイマチ', '山崎', 'ヤマザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県猿島郡境町内門', '08', '08546', '3060414', '茨城県', 'イバラキケン', '猿島郡境町', 'サシマグンサカイマチ', '内門', 'ウチカド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県猿島郡境町大歩', '08', '08546', '3060415', '茨城県', 'イバラキケン', '猿島郡境町', 'サシマグンサカイマチ', '大歩', 'ワゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県猿島郡境町伏木', '08', '08546', '3060416', '茨城県', 'イバラキケン', '猿島郡境町', 'サシマグンサカイマチ', '伏木', 'フセギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県猿島郡境町若林', '08', '08546', '3060417', '茨城県', 'イバラキケン', '猿島郡境町', 'サシマグンサカイマチ', '若林', 'ワカバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県猿島郡境町染谷', '08', '08546', '3060421', '茨城県', 'イバラキケン', '猿島郡境町', 'サシマグンサカイマチ', '染谷', 'ソメヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県猿島郡境町一ノ谷', '08', '08546', '3060422', '茨城県', 'イバラキケン', '猿島郡境町', 'サシマグンサカイマチ', '一ノ谷', 'イチノヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県猿島郡境町百戸', '08', '08546', '3060423', '茨城県', 'イバラキケン', '猿島郡境町', 'サシマグンサカイマチ', '百戸', 'モド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県猿島郡境町桐ケ作', '08', '08546', '3060424', '茨城県', 'イバラキケン', '猿島郡境町', 'サシマグンサカイマチ', '桐ケ作', 'キリガサク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県猿島郡境町新田戸', '08', '08546', '3060425', '茨城県', 'イバラキケン', '猿島郡境町', 'サシマグンサカイマチ', '新田戸', 'ニッタド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県猿島郡境町金岡', '08', '08546', '3060426', '茨城県', 'イバラキケン', '猿島郡境町', 'サシマグンサカイマチ', '金岡', 'カネオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県猿島郡境町浦向', '08', '08546', '3060427', '茨城県', 'イバラキケン', '猿島郡境町', 'サシマグンサカイマチ', '浦向', 'ウラムコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県猿島郡境町西泉田', '08', '08546', '3060431', '茨城県', 'イバラキケン', '猿島郡境町', 'サシマグンサカイマチ', '西泉田', 'ニシイズミダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県猿島郡境町下小橋', '08', '08546', '3060432', '茨城県', 'イバラキケン', '猿島郡境町', 'サシマグンサカイマチ', '下小橋', 'シモコバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県猿島郡境町', '08', '08546', '3060433', '茨城県', 'イバラキケン', '猿島郡境町', 'サシマグンサカイマチ', null, '　', '（直番地）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('21692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県猿島郡境町上小橋', '08', '08546', '3060434', '茨城県', 'イバラキケン', '猿島郡境町', 'サシマグンサカイマチ', '上小橋', 'カミコバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県猿島郡境町陽光台', '08', '08546', '3060435', '茨城県', 'イバラキケン', '猿島郡境町', 'サシマグンサカイマチ', '陽光台', 'ヨウコウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県坂東市逆井', '08', '08228', '3060501', '茨城県', 'イバラキケン', '坂東市', 'バンドウシ', '逆井', 'サカサイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県坂東市山', '08', '08228', '3060502', '茨城県', 'イバラキケン', '坂東市', 'バンドウシ', '山', 'ヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県坂東市生子新田', '08', '08228', '3060503', '茨城県', 'イバラキケン', '坂東市', 'バンドウシ', '生子新田', 'オイゴシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県坂東市生子', '08', '08228', '3060504', '茨城県', 'イバラキケン', '坂東市', 'バンドウシ', '生子', 'オイゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県坂東市菅谷', '08', '08228', '3060505', '茨城県', 'イバラキケン', '坂東市', 'バンドウシ', '菅谷', 'スガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県坂東市孫兵エ新田', '08', '08228', '3060511', '茨城県', 'イバラキケン', '坂東市', 'バンドウシ', '孫兵エ新田', 'マゴベエシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県坂東市左平太新田', '08', '08228', '3060512', '茨城県', 'イバラキケン', '坂東市', 'バンドウシ', '左平太新田', 'サヘイタシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県坂東市栗山新田', '08', '08228', '3060513', '茨城県', 'イバラキケン', '坂東市', 'バンドウシ', '栗山新田', 'クリヤマシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県坂東市内野山', '08', '08228', '3060514', '茨城県', 'イバラキケン', '坂東市', 'バンドウシ', '内野山', 'ウチノヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県坂東市沓掛', '08', '08228', '3060515', '茨城県', 'イバラキケン', '坂東市', 'バンドウシ', '沓掛', 'クツカケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県坂東市', '08', '08228', '3060600', '茨城県', 'イバラキケン', '坂東市', 'バンドウシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('21710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県坂東市大馬新田', '08', '08228', '3060601', '茨城県', 'イバラキケン', '坂東市', 'バンドウシ', '大馬新田', 'オオマシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県坂東市平八新田', '08', '08228', '3060602', '茨城県', 'イバラキケン', '坂東市', 'バンドウシ', '平八新田', 'ヘイハチシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県坂東市勘助新田', '08', '08228', '3060603', '茨城県', 'イバラキケン', '坂東市', 'バンドウシ', '勘助新田', 'カンスケシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県坂東市幸田新田', '08', '08228', '3060604', '茨城県', 'イバラキケン', '坂東市', 'バンドウシ', '幸田新田', 'コウダシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県坂東市馬立', '08', '08228', '3060605', '茨城県', 'イバラキケン', '坂東市', 'バンドウシ', '馬立', 'マタテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県坂東市幸田', '08', '08228', '3060606', '茨城県', 'イバラキケン', '坂東市', 'バンドウシ', '幸田', 'コウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県坂東市弓田', '08', '08228', '3060607', '茨城県', 'イバラキケン', '坂東市', 'バンドウシ', '弓田', 'ユダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県坂東市幸神平', '08', '08228', '3060608', '茨城県', 'イバラキケン', '坂東市', 'バンドウシ', '幸神平', 'コウシンダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県坂東市神田山新田', '08', '08228', '3060611', '茨城県', 'イバラキケン', '坂東市', 'バンドウシ', '神田山新田', 'カドヤマシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県坂東市猫実新田', '08', '08228', '3060612', '茨城県', 'イバラキケン', '坂東市', 'バンドウシ', '猫実新田', 'ネコザネシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県坂東市大口新田', '08', '08228', '3060613', '茨城県', 'イバラキケン', '坂東市', 'バンドウシ', '大口新田', 'オオグチシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県坂東市庄右衛門新田', '08', '08228', '3060614', '茨城県', 'イバラキケン', '坂東市', 'バンドウシ', '庄右衛門新田', 'ショウエモンシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県坂東市大口', '08', '08228', '3060615', '茨城県', 'イバラキケン', '坂東市', 'バンドウシ', '大口', 'オオグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県坂東市猫実', '08', '08228', '3060616', '茨城県', 'イバラキケン', '坂東市', 'バンドウシ', '猫実', 'ネコザネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県坂東市神田山', '08', '08228', '3060617', '茨城県', 'イバラキケン', '坂東市', 'バンドウシ', '神田山', 'カドヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県坂東市大谷口', '08', '08228', '3060621', '茨城県', 'イバラキケン', '坂東市', 'バンドウシ', '大谷口', 'オオヤグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県坂東市大崎', '08', '08228', '3060622', '茨城県', 'イバラキケン', '坂東市', 'バンドウシ', '大崎', 'オオサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県坂東市法師戸', '08', '08228', '3060623', '茨城県', 'イバラキケン', '坂東市', 'バンドウシ', '法師戸', 'ホウシト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県坂東市矢作', '08', '08228', '3060624', '茨城県', 'イバラキケン', '坂東市', 'バンドウシ', '矢作', 'ヤハギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県坂東市莚打', '08', '08228', '3060625', '茨城県', 'イバラキケン', '坂東市', 'バンドウシ', '莚打', 'ムシロウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県坂東市小山', '08', '08228', '3060626', '茨城県', 'イバラキケン', '坂東市', 'バンドウシ', '小山', 'オヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県坂東市岩井', '08', '08228', '3060631', '茨城県', 'イバラキケン', '坂東市', 'バンドウシ', '岩井', 'イワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県坂東市辺田', '08', '08228', '3060632', '茨城県', 'イバラキケン', '坂東市', 'バンドウシ', '辺田', 'ヘタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県坂東市下出島', '08', '08228', '3060633', '茨城県', 'イバラキケン', '坂東市', 'バンドウシ', '下出島', 'シモイズシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県坂東市中里', '08', '08228', '3060634', '茨城県', 'イバラキケン', '坂東市', 'バンドウシ', '中里', 'ナカザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県坂東市小泉', '08', '08228', '3060635', '茨城県', 'イバラキケン', '坂東市', 'バンドウシ', '小泉', 'コイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県坂東市桐木', '08', '08228', '3060636', '茨城県', 'イバラキケン', '坂東市', 'バンドウシ', '桐木', 'キリノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県坂東市みどり町', '08', '08228', '3060637', '茨城県', 'イバラキケン', '坂東市', 'バンドウシ', 'みどり町', 'ミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県坂東市鵠戸', '08', '08228', '3060641', '茨城県', 'イバラキケン', '坂東市', 'バンドウシ', '鵠戸', 'クグイド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県坂東市長谷', '08', '08228', '3060642', '茨城県', 'イバラキケン', '坂東市', 'バンドウシ', '長谷', 'ナガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県坂東市木間ケ瀬', '08', '08228', '3060643', '茨城県', 'イバラキケン', '坂東市', 'バンドウシ', '木間ケ瀬', 'キマガセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県坂東市古布内', '08', '08228', '3060644', '茨城県', 'イバラキケン', '坂東市', 'バンドウシ', '古布内', 'コブウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県坂東市長須', '08', '08228', '3060645', '茨城県', 'イバラキケン', '坂東市', 'バンドウシ', '長須', 'ナガス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県坂東市半谷', '08', '08228', '3060651', '茨城県', 'イバラキケン', '坂東市', 'バンドウシ', '半谷', 'ハンヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県坂東市冨田', '08', '08228', '3060652', '茨城県', 'イバラキケン', '坂東市', 'バンドウシ', '冨田', 'トミタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県坂東市駒跿', '08', '08228', '3060653', '茨城県', 'イバラキケン', '坂東市', 'バンドウシ', '駒跿', 'コマハネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県坂東市上出島', '08', '08228', '3060654', '茨城県', 'イバラキケン', '坂東市', 'バンドウシ', '上出島', 'カミイズシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県坂東市みむら', '08', '08228', '3060655', '茨城県', 'イバラキケン', '坂東市', 'バンドウシ', 'みむら', 'ミムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県坂東市寺久', '08', '08228', '3060656', '茨城県', 'イバラキケン', '坂東市', 'バンドウシ', '寺久', 'テラク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県坂東市借宿', '08', '08228', '3060657', '茨城県', 'イバラキケン', '坂東市', 'バンドウシ', '借宿', 'カリヤド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県結城市', '08', '08207', '3070000', '茨城県', 'イバラキケン', '結城市', 'ユウキシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('21754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県結城市結城', '08', '08207', '3070001', '茨城県', 'イバラキケン', '結城市', 'ユウキシ', '結城', 'ユウキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県結城市大谷瀬', '08', '08207', '3070002', '茨城県', 'イバラキケン', '結城市', 'ユウキシ', '大谷瀬', 'オオヤゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県結城市富士見町', '08', '08207', '3070003', '茨城県', 'イバラキケン', '結城市', 'ユウキシ', '富士見町', 'フジミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県結城市みどり町', '08', '08207', '3070004', '茨城県', 'イバラキケン', '結城市', 'ユウキシ', 'みどり町', 'ミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県結城市川木谷', '08', '08207', '3070005', '茨城県', 'イバラキケン', '結城市', 'ユウキシ', '川木谷', 'カワキヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県結城市五助', '08', '08207', '3070006', '茨城県', 'イバラキケン', '結城市', 'ユウキシ', '五助', 'ゴスケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県結城市小田林', '08', '08207', '3070007', '茨城県', 'イバラキケン', '結城市', 'ユウキシ', '小田林', 'オダバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県結城市小森', '08', '08207', '3070011', '茨城県', 'イバラキケン', '結城市', 'ユウキシ', '小森', 'コモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県結城市久保田', '08', '08207', '3070012', '茨城県', 'イバラキケン', '結城市', 'ユウキシ', '久保田', 'クボタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県結城市中', '08', '08207', '3070013', '茨城県', 'イバラキケン', '結城市', 'ユウキシ', '中', 'ナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県結城市林', '08', '08207', '3070014', '茨城県', 'イバラキケン', '結城市', 'ユウキシ', '林', 'ハヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県結城市鹿窪', '08', '08207', '3070015', '茨城県', 'イバラキケン', '結城市', 'ユウキシ', '鹿窪', 'カナクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県結城市新堤仲通り', '08', '08207', '3070016', '茨城県', 'イバラキケン', '結城市', 'ユウキシ', '新堤仲通り', 'シンツツミナカドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県結城市若宮', '08', '08207', '3070017', '茨城県', 'イバラキケン', '結城市', 'ユウキシ', '若宮', 'ワカミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県結城市上山川', '08', '08207', '3070021', '茨城県', 'イバラキケン', '結城市', 'ユウキシ', '上山川', 'カミヤマカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県結城市矢畑', '08', '08207', '3070022', '茨城県', 'イバラキケン', '結城市', 'ユウキシ', '矢畑', 'ヤバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県結城市山王', '08', '08207', '3070023', '茨城県', 'イバラキケン', '結城市', 'ユウキシ', '山王', 'サンノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県結城市水海道', '08', '08207', '3070024', '茨城県', 'イバラキケン', '結城市', 'ユウキシ', '水海道', 'ミッカイドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県結城市浜野辺', '08', '08207', '3070025', '茨城県', 'イバラキケン', '結城市', 'ユウキシ', '浜野辺', 'ハマノベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県結城市芳賀崎', '08', '08207', '3070026', '茨城県', 'イバラキケン', '結城市', 'ユウキシ', '芳賀崎', 'ハガサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県結城市粕礼', '08', '08207', '3070027', '茨城県', 'イバラキケン', '結城市', 'ユウキシ', '粕礼', 'カスレイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県結城市今宿', '08', '08207', '3070028', '茨城県', 'イバラキケン', '結城市', 'ユウキシ', '今宿', 'イマジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県結城市大木', '08', '08207', '3070031', '茨城県', 'イバラキケン', '結城市', 'ユウキシ', '大木', 'オオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県結城市古宿新田', '08', '08207', '3070032', '茨城県', 'イバラキケン', '結城市', 'ユウキシ', '古宿新田', 'フルジュクシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県結城市山川新宿', '08', '08207', '3070033', '茨城県', 'イバラキケン', '結城市', 'ユウキシ', '山川新宿', 'ヤマカワシンジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県結城市新宿新田', '08', '08207', '3070034', '茨城県', 'イバラキケン', '結城市', 'ユウキシ', '新宿新田', 'シンジュクシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県結城市善右衛門新田', '08', '08207', '3070035', '茨城県', 'イバラキケン', '結城市', 'ユウキシ', '善右衛門新田', 'ゼンウエモンシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県結城市北南茂呂', '08', '08207', '3070036', '茨城県', 'イバラキケン', '結城市', 'ユウキシ', '北南茂呂', 'ホクナンモロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県結城市東茂呂', '08', '08207', '3070037', '茨城県', 'イバラキケン', '結城市', 'ユウキシ', '東茂呂', 'ヒガシモロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県結城市七五三場', '08', '08207', '3070038', '茨城県', 'イバラキケン', '結城市', 'ユウキシ', '七五三場', 'シメバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県結城市江川大町', '08', '08207', '3070041', '茨城県', 'イバラキケン', '結城市', 'ユウキシ', '江川大町', 'エガワオオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県結城市江川新宿', '08', '08207', '3070042', '茨城県', 'イバラキケン', '結城市', 'ユウキシ', '江川新宿', 'エガワシンジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県結城市武井', '08', '08207', '3070043', '茨城県', 'イバラキケン', '結城市', 'ユウキシ', '武井', 'タケイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県結城市田間', '08', '08207', '3070044', '茨城県', 'イバラキケン', '結城市', 'ユウキシ', '田間', 'タマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県結城市上成', '08', '08207', '3070045', '茨城県', 'イバラキケン', '結城市', 'ユウキシ', '上成', 'ウエナシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県結城市結城作', '08', '08207', '3070046', '茨城県', 'イバラキケン', '結城市', 'ユウキシ', '結城作', 'ユウキサク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県結城市国府町', '08', '08207', '3070051', '茨城県', 'イバラキケン', '結城市', 'ユウキシ', '国府町', 'コクブチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県結城市中央町', '08', '08207', '3070052', '茨城県', 'イバラキケン', '結城市', 'ユウキシ', '中央町', 'チュウオウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県結城市新福寺', '08', '08207', '3070053', '茨城県', 'イバラキケン', '結城市', 'ユウキシ', '新福寺', 'シンプクジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県結城市城南町', '08', '08207', '3070054', '茨城県', 'イバラキケン', '結城市', 'ユウキシ', '城南町', 'ジョウナンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県結城市大橋町', '08', '08207', '3070055', '茨城県', 'イバラキケン', '結城市', 'ユウキシ', '大橋町', 'オオハシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市', '08', '08227', '3080000', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('21799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市樋口', '08', '08227', '3080001', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '樋口', 'ヒグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市落合', '08', '08227', '3080002', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '落合', 'オチアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市蒔田', '08', '08227', '3080003', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '蒔田', 'マクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市国府田', '08', '08227', '3080004', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '国府田', 'コウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市中舘', '08', '08227', '3080005', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '中舘', 'ナカダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市谷部', '08', '08227', '3080006', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '谷部', 'ヤベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市折本', '08', '08227', '3080007', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '折本', 'オリモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市下高田', '08', '08227', '3080011', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '下高田', 'シモタカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市奥田', '08', '08227', '3080012', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '奥田', 'オクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市八田', '08', '08227', '3080013', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '八田', 'ハッタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市羽方', '08', '08227', '3080014', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '羽方', 'ハガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市大関', '08', '08227', '3080015', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '大関', 'オオゼキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市野', '08', '08227', '3080016', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '野', 'ノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市上中山', '08', '08227', '3080017', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '上中山', 'カミナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市甲', '08', '08227', '3080021', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '甲', 'コウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市丙', '08', '08227', '3080031', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '丙', 'ヘイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市乙', '08', '08227', '3080041', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '乙', 'オツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市みどり町', '08', '08227', '3080042', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', 'みどり町', 'ミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市岡芹', '08', '08227', '3080051', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '岡芹', 'オカゼリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市菅谷', '08', '08227', '3080052', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '菅谷', 'スガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市外塚', '08', '08227', '3080053', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '外塚', 'トノヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市西谷貝', '08', '08227', '3080054', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '西谷貝', 'ニシヤガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市石原田', '08', '08227', '3080055', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '石原田', 'イシハラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市谷中', '08', '08227', '3080056', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '谷中', 'ヤナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市栗島', '08', '08227', '3080061', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '栗島', 'クリシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市西大島', '08', '08227', '3080062', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '西大島', 'ニシオオシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市神分', '08', '08227', '3080063', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '神分', 'カミワケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市飯島', '08', '08227', '3080064', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '飯島', 'イイジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市笹塚', '08', '08227', '3080065', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '笹塚', 'ササヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市下平塚', '08', '08227', '3080066', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '下平塚', 'シモヒラツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市上平塚', '08', '08227', '3080067', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '上平塚', 'カミヒラツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市口戸', '08', '08227', '3080071', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '口戸', 'クチド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市柴山', '08', '08227', '3080072', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '柴山', 'シバヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市林', '08', '08227', '3080073', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '林', 'ハヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市筑瀬', '08', '08227', '3080074', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '筑瀬', 'チクゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市石塔', '08', '08227', '3080075', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '石塔', 'イシトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市泉', '08', '08227', '3080076', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '泉', 'イズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市子思儀', '08', '08227', '3080077', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '子思儀', 'コシギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市白石区菊水1条', '01', '01104', '0030801', '北海道', 'ホッカイドウ', '札幌市白石区', 'サッポロシシロイシク', '菊水1条', 'キクスイ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市井上', '08', '08227', '3080101', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '井上', 'イノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市黒子', '08', '08227', '3080102', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '黒子', 'クロゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市辻', '08', '08227', '3080103', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '辻', 'ツジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市木戸', '08', '08227', '3080104', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '木戸', 'キド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市西保末', '08', '08227', '3080105', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '西保末', 'ニシホズエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市稲荷', '08', '08227', '3080106', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '稲荷', 'イナリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市梶内', '08', '08227', '3080107', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '梶内', 'カジウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市中村新田', '08', '08227', '3080108', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '中村新田', 'ナカムラシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市舟生', '08', '08227', '3080111', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '舟生', 'フニュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市藤ケ谷', '08', '08227', '3080112', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '藤ケ谷', 'フジガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市関舘', '08', '08227', '3080113', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '関舘', 'セキタテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市花田', '08', '08227', '3080114', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '花田', 'ハナダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市花橋', '08', '08227', '3080115', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '花橋', 'ハナバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市板橋', '08', '08227', '3080116', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '板橋', 'イタバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市犬塚', '08', '08227', '3080117', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '犬塚', 'イヌヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市船玉', '08', '08227', '3080121', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '船玉', 'フナダマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市関本上', '08', '08227', '3080122', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '関本上', 'セキモトカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市関本上中', '08', '08227', '3080123', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '関本上中', 'セキモトカミナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市関本肥土', '08', '08227', '3080124', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '関本肥土', 'セキモトアクト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市関本分中', '08', '08227', '3080125', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '関本分中', 'セキモトワケナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市関本中', '08', '08227', '3080126', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '関本中', 'セキモトナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市関本下', '08', '08227', '3080127', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '関本下', 'セキモトシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市江', '08', '08227', '3080128', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '江', 'エ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市上野', '08', '08227', '3080129', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '上野', 'ウエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市白石区菊水2条', '01', '01104', '0030802', '北海道', 'ホッカイドウ', '札幌市白石区', 'サッポロシシロイシク', '菊水2条', 'キクスイ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市白石区菊水3条', '01', '01104', '0030803', '北海道', 'ホッカイドウ', '札幌市白石区', 'サッポロシシロイシク', '菊水3条', 'キクスイ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市白石区菊水4条', '01', '01104', '0030804', '北海道', 'ホッカイドウ', '札幌市白石区', 'サッポロシシロイシク', '菊水4条', 'キクスイ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市白石区菊水5条', '01', '01104', '0030805', '北海道', 'ホッカイドウ', '札幌市白石区', 'サッポロシシロイシク', '菊水5条', 'キクスイ05ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市白石区菊水6条', '01', '01104', '0030806', '北海道', 'ホッカイドウ', '札幌市白石区', 'サッポロシシロイシク', '菊水6条', 'キクスイ06ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市白石区菊水7条', '01', '01104', '0030807', '北海道', 'ホッカイドウ', '札幌市白石区', 'サッポロシシロイシク', '菊水7条', 'キクスイ07ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市白石区菊水8条', '01', '01104', '0030808', '北海道', 'ホッカイドウ', '札幌市白石区', 'サッポロシシロイシク', '菊水8条', 'キクスイ08ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市川澄', '08', '08227', '3080801', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '川澄', 'カワスミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市横島', '08', '08227', '3080802', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '横島', 'ヨコシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市直井', '08', '08227', '3080803', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '直井', 'ナオイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市金丸', '08', '08227', '3080804', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '金丸', 'カナマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市稲野辺', '08', '08227', '3080805', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '稲野辺', 'イナノベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市小林', '08', '08227', '3080806', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '小林', 'オバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市高島', '08', '08227', '3080807', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '高島', 'タカシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市茂田', '08', '08227', '3080811', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '茂田', 'モダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市深見', '08', '08227', '3080812', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '深見', 'フカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市大塚', '08', '08227', '3080813', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '大塚', 'オオツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市川連', '08', '08227', '3080814', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '川連', 'カワヅレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市上川中子', '08', '08227', '3080815', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '上川中子', 'カミカワナゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市徳持', '08', '08227', '3080816', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '徳持', 'トクモチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市成田', '08', '08227', '3080821', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '成田', 'ナリタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市塚原', '08', '08227', '3080822', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '塚原', 'ツカハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市島', '08', '08227', '3080823', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '島', 'シマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市蕨', '08', '08227', '3080824', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '蕨', 'ワラビ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市下中山', '08', '08227', '3080825', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '下中山', 'シモナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市下岡崎', '08', '08227', '3080826', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '下岡崎', 'シモオカザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市市野辺', '08', '08227', '3080827', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '市野辺', 'イチノベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市東榎生', '08', '08227', '3080831', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '東榎生', 'ヒガシヨノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市西榎生', '08', '08227', '3080832', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '西榎生', 'ニシヨノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市野田', '08', '08227', '3080833', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '野田', 'ノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市西石田', '08', '08227', '3080834', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '西石田', 'ニシイシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市飯田', '08', '08227', '3080835', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '飯田', 'イイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市旭ケ丘', '08', '08227', '3080836', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '旭ケ丘', 'アサヒガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市嘉家佐和', '08', '08227', '3080837', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '嘉家佐和', 'カゲサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市榎生', '08', '08227', '3080838', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '榎生', 'ヨノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市二木成', '08', '08227', '3080841', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '二木成', 'ニギナリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市一本松', '08', '08227', '3080842', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '一本松', 'イッポンマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市野殿', '08', '08227', '3080843', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '野殿', 'ノドノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市下野殿', '08', '08227', '3080844', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '下野殿', 'シモノドノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市西方', '08', '08227', '3080845', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '西方', 'ニシホウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市布川', '08', '08227', '3080846', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '布川', 'ヌノガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市玉戸', '08', '08227', '3080847', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '玉戸', 'タマド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市幸町', '08', '08227', '3080848', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市下江連', '08', '08227', '3080851', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '下江連', 'シモエヅレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市大谷', '08', '08227', '3080852', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '大谷', 'オオヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市伊讃美', '08', '08227', '3080853', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '伊讃美', 'イサミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市女方', '08', '08227', '3080854', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '女方', 'オザカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市下川島', '08', '08227', '3080855', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '下川島', 'シモカワシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市伊佐山', '08', '08227', '3080856', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '伊佐山', 'イサヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市小川', '08', '08227', '3080857', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '小川', 'オガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市森添島', '08', '08227', '3080861', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '森添島', 'モリソエジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市小塙', '08', '08227', '3080862', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '小塙', 'コバナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市灰塚', '08', '08227', '3080863', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '灰塚', 'ハイツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市掉ケ島', '08', '08227', '3080864', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '掉ケ島', 'ソウカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市山崎', '08', '08227', '3080865', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '山崎', 'ヤマザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市五所宮', '08', '08227', '3080866', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '五所宮', 'ゴショミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市西山田', '08', '08227', '3080867', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '西山田', 'ニシヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市白石区菊水9条', '01', '01104', '0030809', '北海道', 'ホッカイドウ', '札幌市白石区', 'サッポロシシロイシク', '菊水9条', 'キクスイ09ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市白石区菊水上町1条', '01', '01104', '0030811', '北海道', 'ホッカイドウ', '札幌市白石区', 'サッポロシシロイシク', '菊水上町1条', 'キクスイカミマチ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市白石区菊水上町2条', '01', '01104', '0030812', '北海道', 'ホッカイドウ', '札幌市白石区', 'サッポロシシロイシク', '菊水上町2条', 'キクスイカミマチ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市白石区菊水上町3条', '01', '01104', '0030813', '北海道', 'ホッカイドウ', '札幌市白石区', 'サッポロシシロイシク', '菊水上町3条', 'キクスイカミマチ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市白石区菊水上町4条', '01', '01104', '0030814', '北海道', 'ホッカイドウ', '札幌市白石区', 'サッポロシシロイシク', '菊水上町4条', 'キクスイカミマチ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市白石区菊水元町1条', '01', '01104', '0030821', '北海道', 'ホッカイドウ', '札幌市白石区', 'サッポロシシロイシク', '菊水元町1条', 'キクスイモトマチ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市白石区菊水元町2条', '01', '01104', '0030822', '北海道', 'ホッカイドウ', '札幌市白石区', 'サッポロシシロイシク', '菊水元町2条', 'キクスイモトマチ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市白石区菊水元町3条', '01', '01104', '0030823', '北海道', 'ホッカイドウ', '札幌市白石区', 'サッポロシシロイシク', '菊水元町3条', 'キクスイモトマチ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市白石区菊水元町4条', '01', '01104', '0030824', '北海道', 'ホッカイドウ', '札幌市白石区', 'サッポロシシロイシク', '菊水元町4条', 'キクスイモトマチ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市白石区菊水元町5条', '01', '01104', '0030825', '北海道', 'ホッカイドウ', '札幌市白石区', 'サッポロシシロイシク', '菊水元町5条', 'キクスイモトマチ05ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市白石区菊水元町6条', '01', '01104', '0030826', '北海道', 'ホッカイドウ', '札幌市白石区', 'サッポロシシロイシク', '菊水元町6条', 'キクスイモトマチ06ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市白石区菊水元町7条', '01', '01104', '0030827', '北海道', 'ホッカイドウ', '札幌市白石区', 'サッポロシシロイシク', '菊水元町7条', 'キクスイモトマチ07ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市白石区菊水元町8条', '01', '01104', '0030828', '北海道', 'ホッカイドウ', '札幌市白石区', 'サッポロシシロイシク', '菊水元町8条', 'キクスイモトマチ08ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市白石区菊水元町9条', '01', '01104', '0030829', '北海道', 'ホッカイドウ', '札幌市白石区', 'サッポロシシロイシク', '菊水元町9条', 'キクスイモトマチ09ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市白石区菊水元町10条', '01', '01104', '0030830', '北海道', 'ホッカイドウ', '札幌市白石区', 'サッポロシシロイシク', '菊水元町10条', 'キクスイモトマチ10ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市白石区北郷1条', '01', '01104', '0030831', '北海道', 'ホッカイドウ', '札幌市白石区', 'サッポロシシロイシク', '北郷1条', 'キタゴウ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市白石区北郷2条', '01', '01104', '0030832', '北海道', 'ホッカイドウ', '札幌市白石区', 'サッポロシシロイシク', '北郷2条', 'キタゴウ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市白石区北郷3条', '01', '01104', '0030833', '北海道', 'ホッカイドウ', '札幌市白石区', 'サッポロシシロイシク', '北郷3条', 'キタゴウ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市白石区北郷4条', '01', '01104', '0030834', '北海道', 'ホッカイドウ', '札幌市白石区', 'サッポロシシロイシク', '北郷4条', 'キタゴウ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市白石区北郷5条', '01', '01104', '0030835', '北海道', 'ホッカイドウ', '札幌市白石区', 'サッポロシシロイシク', '北郷5条', 'キタゴウ05ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市白石区北郷6条', '01', '01104', '0030836', '北海道', 'ホッカイドウ', '札幌市白石区', 'サッポロシシロイシク', '北郷6条', 'キタゴウ06ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市白石区北郷7条', '01', '01104', '0030837', '北海道', 'ホッカイドウ', '札幌市白石区', 'サッポロシシロイシク', '北郷7条', 'キタゴウ07ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市白石区北郷8条', '01', '01104', '0030838', '北海道', 'ホッカイドウ', '札幌市白石区', 'サッポロシシロイシク', '北郷8条', 'キタゴウ08ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市白石区北郷9条', '01', '01104', '0030839', '北海道', 'ホッカイドウ', '札幌市白石区', 'サッポロシシロイシク', '北郷9条', 'キタゴウ09ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市白石区北郷10条', '01', '01104', '0030840', '北海道', 'ホッカイドウ', '札幌市白石区', 'サッポロシシロイシク', '北郷10条', 'キタゴウ10ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市白石区北郷', '01', '01104', '0030849', '北海道', 'ホッカイドウ', '札幌市白石区', 'サッポロシシロイシク', '北郷', 'キタゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市白石区川北1条', '01', '01104', '0030851', '北海道', 'ホッカイドウ', '札幌市白石区', 'サッポロシシロイシク', '川北1条', 'カワキタ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市白石区川北2条', '01', '01104', '0030852', '北海道', 'ホッカイドウ', '札幌市白石区', 'サッポロシシロイシク', '川北2条', 'カワキタ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市白石区川北3条', '01', '01104', '0030853', '北海道', 'ホッカイドウ', '札幌市白石区', 'サッポロシシロイシク', '川北3条', 'カワキタ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市白石区川北4条', '01', '01104', '0030854', '北海道', 'ホッカイドウ', '札幌市白石区', 'サッポロシシロイシク', '川北4条', 'カワキタ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市白石区川北5条', '01', '01104', '0030855', '北海道', 'ホッカイドウ', '札幌市白石区', 'サッポロシシロイシク', '川北5条', 'カワキタ05ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市白石区川北', '01', '01104', '0030859', '北海道', 'ホッカイドウ', '札幌市白石区', 'サッポロシシロイシク', '川北', 'カワキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市白石区川下1条', '01', '01104', '0030861', '北海道', 'ホッカイドウ', '札幌市白石区', 'サッポロシシロイシク', '川下1条', 'カワシモ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市白石区川下2条', '01', '01104', '0030862', '北海道', 'ホッカイドウ', '札幌市白石区', 'サッポロシシロイシク', '川下2条', 'カワシモ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市白石区川下3条', '01', '01104', '0030863', '北海道', 'ホッカイドウ', '札幌市白石区', 'サッポロシシロイシク', '川下3条', 'カワシモ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市白石区川下4条', '01', '01104', '0030864', '北海道', 'ホッカイドウ', '札幌市白石区', 'サッポロシシロイシク', '川下4条', 'カワシモ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('21995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市白石区川下5条', '01', '01104', '0030865', '北海道', 'ホッカイドウ', '札幌市白石区', 'サッポロシシロイシク', '川下5条', 'カワシモ05ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市白石区川下', '01', '01104', '0030869', '北海道', 'ホッカイドウ', '札幌市白石区', 'サッポロシシロイシク', '川下', 'カワシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市白石区米里1条', '01', '01104', '0030871', '北海道', 'ホッカイドウ', '札幌市白石区', 'サッポロシシロイシク', '米里1条', 'ヨネサト01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市白石区米里2条', '01', '01104', '0030872', '北海道', 'ホッカイドウ', '札幌市白石区', 'サッポロシシロイシク', '米里2条', 'ヨネサト02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市白石区米里3条', '01', '01104', '0030873', '北海道', 'ホッカイドウ', '札幌市白石区', 'サッポロシシロイシク', '米里3条', 'ヨネサト03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市白石区米里4条', '01', '01104', '0030874', '北海道', 'ホッカイドウ', '札幌市白石区', 'サッポロシシロイシク', '米里4条', 'ヨネサト04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市白石区米里5条', '01', '01104', '0030875', '北海道', 'ホッカイドウ', '札幌市白石区', 'サッポロシシロイシク', '米里5条', 'ヨネサト05ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市白石区東米里', '01', '01104', '0030876', '北海道', 'ホッカイドウ', '札幌市白石区', 'サッポロシシロイシク', '東米里', 'ヒガシヨネサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市小栗', '08', '08227', '3091101', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '小栗', 'オグリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市蓬田', '08', '08227', '3091102', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '蓬田', 'ヨモギタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市久地楽', '08', '08227', '3091103', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '久地楽', 'クジラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市古郡', '08', '08227', '3091104', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '古郡', 'フルゴオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市三郷', '08', '08227', '3091105', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '三郷', 'サンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市新治', '08', '08227', '3091106', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '新治', 'ニイハリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市門井', '08', '08227', '3091107', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '門井', 'カドイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市井出蛯沢', '08', '08227', '3091108', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '井出蛯沢', 'イテエビサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市上星谷', '08', '08227', '3091111', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '上星谷', 'カミホシヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市八幡', '08', '08227', '3091112', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '八幡', 'ヤハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市柳', '08', '08227', '3091113', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '柳', 'ヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市細田', '08', '08227', '3091114', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '細田', 'ホソダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市蓮沼', '08', '08227', '3091115', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '蓮沼', 'ハスヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市横塚', '08', '08227', '3091116', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '横塚', 'ヨコツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市向川澄', '08', '08227', '3091117', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '向川澄', 'ムコウカワスミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市谷永島', '08', '08227', '3091121', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '谷永島', 'ヤナガシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市下星谷', '08', '08227', '3091122', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '下星谷', 'シモホシヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市下郷谷', '08', '08227', '3091123', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '下郷谷', 'シモゴウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市知行', '08', '08227', '3091124', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '知行', 'チギョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市大島', '08', '08227', '3091125', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '大島', 'オオシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市清水', '08', '08227', '3091126', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '清水', 'シミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県筑西市桑山', '08', '08227', '3091127', '茨城県', 'イバラキケン', '筑西市', 'チクセイシ', '桑山', 'クワヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県桜川市', '08', '08231', '3091200', '茨城県', 'イバラキケン', '桜川市', 'サクラガワシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('22047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県桜川市大泉', '08', '08231', '3091201', '茨城県', 'イバラキケン', '桜川市', 'サクラガワシ', '大泉', 'オオイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県桜川市飯淵', '08', '08231', '3091202', '茨城県', 'イバラキケン', '桜川市', 'サクラガワシ', '飯淵', 'イイブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県桜川市富岡', '08', '08231', '3091203', '茨城県', 'イバラキケン', '桜川市', 'サクラガワシ', '富岡', 'トミオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県桜川市久原', '08', '08231', '3091204', '茨城県', 'イバラキケン', '桜川市', 'サクラガワシ', '久原', 'クバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県桜川市堤上', '08', '08231', '3091205', '茨城県', 'イバラキケン', '桜川市', 'サクラガワシ', '堤上', 'ツツミノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県桜川市岩瀬', '08', '08231', '3091211', '茨城県', 'イバラキケン', '桜川市', 'サクラガワシ', '岩瀬', 'イワセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県桜川市富士見台', '08', '08231', '3091212', '茨城県', 'イバラキケン', '桜川市', 'サクラガワシ', '富士見台', 'フジミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県桜川市西桜川', '08', '08231', '3091213', '茨城県', 'イバラキケン', '桜川市', 'サクラガワシ', '西桜川', 'ニシサクラガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県桜川市東桜川', '08', '08231', '3091214', '茨城県', 'イバラキケン', '桜川市', 'サクラガワシ', '東桜川', 'ヒガシサクラガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県桜川市御領', '08', '08231', '3091215', '茨城県', 'イバラキケン', '桜川市', 'サクラガワシ', '御領', 'ゴリョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県桜川市明日香', '08', '08231', '3091216', '茨城県', 'イバラキケン', '桜川市', 'サクラガワシ', '明日香', 'アスカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県桜川市犬田', '08', '08231', '3091217', '茨城県', 'イバラキケン', '桜川市', 'サクラガワシ', '犬田', 'イヌタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県桜川市西飯岡', '08', '08231', '3091221', '茨城県', 'イバラキケン', '桜川市', 'サクラガワシ', '西飯岡', 'ニシイイオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県桜川市長方', '08', '08231', '3091222', '茨城県', 'イバラキケン', '桜川市', 'サクラガワシ', '長方', 'オサカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県桜川市鍬田', '08', '08231', '3091223', '茨城県', 'イバラキケン', '桜川市', 'サクラガワシ', '鍬田', 'クワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県桜川市中泉', '08', '08231', '3091224', '茨城県', 'イバラキケン', '桜川市', 'サクラガワシ', '中泉', 'ナカイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県桜川市下泉', '08', '08231', '3091225', '茨城県', 'イバラキケン', '桜川市', 'サクラガワシ', '下泉', 'シモイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県桜川市上野原地新田', '08', '08231', '3091226', '茨城県', 'イバラキケン', '桜川市', 'サクラガワシ', '上野原地新田', 'ウエノハラチシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県桜川市本郷', '08', '08231', '3091227', '茨城県', 'イバラキケン', '桜川市', 'サクラガワシ', '本郷', 'ホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県桜川市本木', '08', '08231', '3091231', '茨城県', 'イバラキケン', '桜川市', 'サクラガワシ', '本木', 'モトギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県桜川市大曽根', '08', '08231', '3091232', '茨城県', 'イバラキケン', '桜川市', 'サクラガワシ', '大曽根', 'オオゾネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県桜川市東飯田', '08', '08231', '3091233', '茨城県', 'イバラキケン', '桜川市', 'サクラガワシ', '東飯田', 'ヒガシイイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県桜川市阿部田', '08', '08231', '3091234', '茨城県', 'イバラキケン', '桜川市', 'サクラガワシ', '阿部田', 'アベタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県桜川市青木', '08', '08231', '3091241', '茨城県', 'イバラキケン', '桜川市', 'サクラガワシ', '青木', 'アオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県桜川市羽田', '08', '08231', '3091242', '茨城県', 'イバラキケン', '桜川市', 'サクラガワシ', '羽田', 'ハネタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県桜川市高久', '08', '08231', '3091243', '茨城県', 'イバラキケン', '桜川市', 'サクラガワシ', '高久', 'タカク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県桜川市大国玉', '08', '08231', '3091244', '茨城県', 'イバラキケン', '桜川市', 'サクラガワシ', '大国玉', 'オオクニタマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県桜川市金敷', '08', '08231', '3091245', '茨城県', 'イバラキケン', '桜川市', 'サクラガワシ', '金敷', 'カナシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県桜川市高森', '08', '08231', '3091246', '茨城県', 'イバラキケン', '桜川市', 'サクラガワシ', '高森', 'タカモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県桜川市平澤', '08', '08231', '3091331', '茨城県', 'イバラキケン', '桜川市', 'サクラガワシ', '平澤', 'ヒラサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県桜川市池亀', '08', '08231', '3091332', '茨城県', 'イバラキケン', '桜川市', 'サクラガワシ', '池亀', 'イケガメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県桜川市山口', '08', '08231', '3091333', '茨城県', 'イバラキケン', '桜川市', 'サクラガワシ', '山口', 'ヤマグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県桜川市坂本', '08', '08231', '3091334', '茨城県', 'イバラキケン', '桜川市', 'サクラガワシ', '坂本', 'サカモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県桜川市大月', '08', '08231', '3091335', '茨城県', 'イバラキケン', '桜川市', 'サクラガワシ', '大月', 'オオツキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県桜川市小塩', '08', '08231', '3091336', '茨城県', 'イバラキケン', '桜川市', 'サクラガワシ', '小塩', 'コシオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県桜川市福崎', '08', '08231', '3091337', '茨城県', 'イバラキケン', '桜川市', 'サクラガワシ', '福崎', 'フクザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県桜川市門毛', '08', '08231', '3091341', '茨城県', 'イバラキケン', '桜川市', 'サクラガワシ', '門毛', 'カドケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県桜川市間中', '08', '08231', '3091342', '茨城県', 'イバラキケン', '桜川市', 'サクラガワシ', '間中', 'マナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県桜川市亀岡', '08', '08231', '3091343', '茨城県', 'イバラキケン', '桜川市', 'サクラガワシ', '亀岡', 'カメオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県桜川市南飯田', '08', '08231', '3091344', '茨城県', 'イバラキケン', '桜川市', 'サクラガワシ', '南飯田', 'ミナミイイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県桜川市入野', '08', '08231', '3091345', '茨城県', 'イバラキケン', '桜川市', 'サクラガワシ', '入野', 'イリノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県桜川市中里', '08', '08231', '3091346', '茨城県', 'イバラキケン', '桜川市', 'サクラガワシ', '中里', 'ナカザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県桜川市富谷', '08', '08231', '3091347', '茨城県', 'イバラキケン', '桜川市', 'サクラガワシ', '富谷', 'トミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県桜川市西小塙', '08', '08231', '3091451', '茨城県', 'イバラキケン', '桜川市', 'サクラガワシ', '西小塙', 'ニシコバナワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県桜川市加茂部', '08', '08231', '3091452', '茨城県', 'イバラキケン', '桜川市', 'サクラガワシ', '加茂部', 'カモベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県桜川市友部', '08', '08231', '3091453', '茨城県', 'イバラキケン', '桜川市', 'サクラガワシ', '友部', 'トモベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県桜川市上城', '08', '08231', '3091454', '茨城県', 'イバラキケン', '桜川市', 'サクラガワシ', '上城', 'カミシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県桜川市水戸', '08', '08231', '3091455', '茨城県', 'イバラキケン', '桜川市', 'サクラガワシ', '水戸', 'ミト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県桜川市青柳', '08', '08231', '3091456', '茨城県', 'イバラキケン', '桜川市', 'サクラガワシ', '青柳', 'アオヤギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県桜川市磯部', '08', '08231', '3091457', '茨城県', 'イバラキケン', '桜川市', 'サクラガワシ', '磯部', 'イソベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県桜川市稲', '08', '08231', '3091458', '茨城県', 'イバラキケン', '桜川市', 'サクラガワシ', '稲', 'イナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県桜川市松田', '08', '08231', '3091461', '茨城県', 'イバラキケン', '桜川市', 'サクラガワシ', '松田', 'マツダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県桜川市曽根', '08', '08231', '3091462', '茨城県', 'イバラキケン', '桜川市', 'サクラガワシ', '曽根', 'ソネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県桜川市高幡', '08', '08231', '3091463', '茨城県', 'イバラキケン', '桜川市', 'サクラガワシ', '高幡', 'タカハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県桜川市今泉', '08', '08231', '3091464', '茨城県', 'イバラキケン', '桜川市', 'サクラガワシ', '今泉', 'イマイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県桜川市木植', '08', '08231', '3091465', '茨城県', 'イバラキケン', '桜川市', 'サクラガワシ', '木植', 'キウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県桜川市猿田', '08', '08231', '3091466', '茨城県', 'イバラキケン', '桜川市', 'サクラガワシ', '猿田', 'サルダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県笠間市', '08', '08216', '3091600', '茨城県', 'イバラキケン', '笠間市', 'カサマシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('22111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県笠間市大橋', '08', '08216', '3091601', '茨城県', 'イバラキケン', '笠間市', 'カサマシ', '大橋', 'オオハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県笠間市池野辺', '08', '08216', '3091602', '茨城県', 'イバラキケン', '笠間市', 'カサマシ', '池野辺', 'イケノベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県笠間市福田', '08', '08216', '3091603', '茨城県', 'イバラキケン', '笠間市', 'カサマシ', '福田', 'フクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県笠間市大渕', '08', '08216', '3091604', '茨城県', 'イバラキケン', '笠間市', 'カサマシ', '大渕', 'オオブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県笠間市飯田', '08', '08216', '3091605', '茨城県', 'イバラキケン', '笠間市', 'カサマシ', '飯田', 'イイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県笠間市日沢', '08', '08216', '3091606', '茨城県', 'イバラキケン', '笠間市', 'カサマシ', '日沢', 'ヒザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県笠間市石寺', '08', '08216', '3091607', '茨城県', 'イバラキケン', '笠間市', 'カサマシ', '石寺', 'イシデラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県笠間市笠間', '08', '08216', '3091611', '茨城県', 'イバラキケン', '笠間市', 'カサマシ', '笠間', 'カサマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県笠間市日草場', '08', '08216', '3091612', '茨城県', 'イバラキケン', '笠間市', 'カサマシ', '日草場', 'ヒクサバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県笠間市石井', '08', '08216', '3091613', '茨城県', 'イバラキケン', '笠間市', 'カサマシ', '石井', 'イシイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県笠間市寺崎', '08', '08216', '3091614', '茨城県', 'イバラキケン', '笠間市', 'カサマシ', '寺崎', 'テラザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県笠間市金井', '08', '08216', '3091615', '茨城県', 'イバラキケン', '笠間市', 'カサマシ', '金井', 'カナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県笠間市赤坂', '08', '08216', '3091616', '茨城県', 'イバラキケン', '笠間市', 'カサマシ', '赤坂', 'アカサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県笠間市手越', '08', '08216', '3091621', '茨城県', 'イバラキケン', '笠間市', 'カサマシ', '手越', 'テゴシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県笠間市南吉原', '08', '08216', '3091622', '茨城県', 'イバラキケン', '笠間市', 'カサマシ', '南吉原', 'ミナミヨシワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県笠間市上加賀田', '08', '08216', '3091623', '茨城県', 'イバラキケン', '笠間市', 'カサマシ', '上加賀田', 'カミカガダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県笠間市北吉原', '08', '08216', '3091624', '茨城県', 'イバラキケン', '笠間市', 'カサマシ', '北吉原', 'キタヨシワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県笠間市来栖', '08', '08216', '3091625', '茨城県', 'イバラキケン', '笠間市', 'カサマシ', '来栖', 'クルス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県笠間市下市毛', '08', '08216', '3091626', '茨城県', 'イバラキケン', '笠間市', 'カサマシ', '下市毛', 'シモイチゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県笠間市箱田', '08', '08216', '3091631', '茨城県', 'イバラキケン', '笠間市', 'カサマシ', '箱田', 'ハコダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県笠間市飯合', '08', '08216', '3091632', '茨城県', 'イバラキケン', '笠間市', 'カサマシ', '飯合', 'イイゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県笠間市本戸', '08', '08216', '3091633', '茨城県', 'イバラキケン', '笠間市', 'カサマシ', '本戸', 'モトド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県笠間市福原', '08', '08216', '3091634', '茨城県', 'イバラキケン', '笠間市', 'カサマシ', '福原', 'フクハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県笠間市稲田', '08', '08216', '3091635', '茨城県', 'イバラキケン', '笠間市', 'カサマシ', '稲田', 'イナダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県笠間市大郷戸', '08', '08216', '3091636', '茨城県', 'イバラキケン', '笠間市', 'カサマシ', '大郷戸', 'オオゴト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県笠間市片庭', '08', '08216', '3091637', '茨城県', 'イバラキケン', '笠間市', 'カサマシ', '片庭', 'カタニワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県笠間市小原', '08', '08216', '3091701', '茨城県', 'イバラキケン', '笠間市', 'カサマシ', '小原', 'オバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県笠間市五平', '08', '08216', '3091702', '茨城県', 'イバラキケン', '笠間市', 'カサマシ', '五平', 'ゴヘイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県笠間市鯉淵', '08', '08216', '3091703', '茨城県', 'イバラキケン', '笠間市', 'カサマシ', '鯉淵', 'コイブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県笠間市美原', '08', '08216', '3091704', '茨城県', 'イバラキケン', '笠間市', 'カサマシ', '美原', 'ミハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県笠間市東平', '08', '08216', '3091705', '茨城県', 'イバラキケン', '笠間市', 'カサマシ', '東平', 'ヒガシダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県笠間市鴻巣', '08', '08216', '3091706', '茨城県', 'イバラキケン', '笠間市', 'カサマシ', '鴻巣', 'コウノス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県笠間市随分附', '08', '08216', '3091711', '茨城県', 'イバラキケン', '笠間市', 'カサマシ', '随分附', 'ナムサンヅケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県笠間市長兎路', '08', '08216', '3091712', '茨城県', 'イバラキケン', '笠間市', 'カサマシ', '長兎路', 'ナガトロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県笠間市柏井', '08', '08216', '3091713', '茨城県', 'イバラキケン', '笠間市', 'カサマシ', '柏井', 'カシワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県笠間市仁古田', '08', '08216', '3091714', '茨城県', 'イバラキケン', '笠間市', 'カサマシ', '仁古田', 'ニコダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県笠間市湯崎', '08', '08216', '3091715', '茨城県', 'イバラキケン', '笠間市', 'カサマシ', '湯崎', 'ユザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県笠間市住吉', '08', '08216', '3091716', '茨城県', 'イバラキケン', '笠間市', 'カサマシ', '住吉', 'スミヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県笠間市旭町', '08', '08216', '3091717', '茨城県', 'イバラキケン', '笠間市', 'カサマシ', '旭町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県笠間市橋爪', '08', '08216', '3091721', '茨城県', 'イバラキケン', '笠間市', 'カサマシ', '橋爪', 'ハシヅメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県笠間市平町', '08', '08216', '3091722', '茨城県', 'イバラキケン', '笠間市', 'カサマシ', '平町', 'タイラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県笠間市矢野下', '08', '08216', '3091723', '茨城県', 'イバラキケン', '笠間市', 'カサマシ', '矢野下', 'ヤノシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県笠間市大古山', '08', '08216', '3091724', '茨城県', 'イバラキケン', '笠間市', 'カサマシ', '大古山', 'オオゴヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県笠間市南小泉', '08', '08216', '3091725', '茨城県', 'イバラキケン', '笠間市', 'カサマシ', '南小泉', 'ミナミコイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県笠間市下加賀田', '08', '08216', '3091726', '茨城県', 'イバラキケン', '笠間市', 'カサマシ', '下加賀田', 'シモカガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県笠間市上市原', '08', '08216', '3091731', '茨城県', 'イバラキケン', '笠間市', 'カサマシ', '上市原', 'カミイチバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県笠間市中市原', '08', '08216', '3091732', '茨城県', 'イバラキケン', '笠間市', 'カサマシ', '中市原', 'ナカイチバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県笠間市下市原', '08', '08216', '3091733', '茨城県', 'イバラキケン', '笠間市', 'カサマシ', '下市原', 'シモイチバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県笠間市南友部', '08', '08216', '3091734', '茨城県', 'イバラキケン', '笠間市', 'カサマシ', '南友部', 'ミナミトモベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県笠間市友部駅前', '08', '08216', '3091735', '茨城県', 'イバラキケン', '笠間市', 'カサマシ', '友部駅前', 'トモベエキマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県笠間市八雲', '08', '08216', '3091736', '茨城県', 'イバラキケン', '笠間市', 'カサマシ', '八雲', 'ヤクモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県笠間市中央', '08', '08216', '3091737', '茨城県', 'イバラキケン', '笠間市', 'カサマシ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県笠間市大田町', '08', '08216', '3091738', '茨城県', 'イバラキケン', '笠間市', 'カサマシ', '大田町', 'オオタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市', '02', '02203', '0310000', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('22168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市', '08', '08201', '3100000', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('22169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市上河内町', '08', '08201', '3100001', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '上河内町', 'カミガチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市中河内町', '08', '08201', '3100002', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '中河内町', 'ナカガチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市柳河町', '08', '08201', '3100003', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '柳河町', 'ヤナカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市青柳町', '08', '08201', '3100004', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '青柳町', 'アオヤギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市水府町', '08', '08201', '3100005', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '水府町', 'スイフチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市類家', '02', '02203', '0310001', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '類家', 'ルイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市三の丸', '08', '08201', '3100011', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '三の丸', 'サンノマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市城東', '08', '08201', '3100012', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '城東', 'ジョウトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市若宮', '08', '08201', '3100013', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '若宮', 'ワカミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市若宮町', '08', '08201', '3100014', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '若宮町', 'ワカミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市宮町', '08', '08201', '3100015', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '宮町', 'ミヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市中居林', '02', '02203', '0310002', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '中居林', 'ナカイバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市南町', '08', '08201', '3100021', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '南町', 'ミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市梅香', '08', '08201', '3100022', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '梅香', 'バイコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市下梅香', '08', '08201', '3100023', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '下梅香', 'シモバイコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市備前町', '08', '08201', '3100024', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '備前町', 'ビゼンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市天王町', '08', '08201', '3100025', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '天王町', 'テンノウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市泉町', '08', '08201', '3100026', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '泉町', 'イズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市吹上', '02', '02203', '0310003', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '吹上', 'フキアゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市大工町', '08', '08201', '3100031', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '大工町', 'ダイクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市元山町', '08', '08201', '3100032', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '元山町', 'モトヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市常磐町', '08', '08201', '3100033', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '常磐町', 'トキワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市緑町', '08', '08201', '3100034', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '緑町', 'ミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市東原', '08', '08201', '3100035', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '東原', 'ヒガシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市新荘', '08', '08201', '3100036', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '新荘', 'シンソウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市南類家', '02', '02203', '0310004', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '南類家', 'ミナミルイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市上水戸', '08', '08201', '3100041', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '上水戸', 'カミミト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市自由が丘', '08', '08201', '3100042', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '自由が丘', 'ジユウガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市松が丘', '08', '08201', '3100043', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '松が丘', 'マツガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市西原', '08', '08201', '3100044', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '西原', 'ニシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市新原', '08', '08201', '3100045', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '新原', 'シンハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市曙町', '08', '08201', '3100046', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '曙町', 'アケボノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市ちとせ', '08', '08201', '3100051', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', 'ちとせ', 'チトセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市松本町', '08', '08201', '3100052', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '松本町', 'マツモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市末広町', '08', '08201', '3100053', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '末広町', 'スエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市愛宕町', '08', '08201', '3100054', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '愛宕町', 'アタゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市袴塚', '08', '08201', '3100055', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '袴塚', 'ハカマツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市文京', '08', '08201', '3100056', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '文京', 'ブンキョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市北見町', '08', '08201', '3100061', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '北見町', 'キタミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市大町', '08', '08201', '3100062', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '大町', 'オオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市五軒町', '08', '08201', '3100063', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '五軒町', 'ゴケンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市栄町', '08', '08201', '3100064', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '栄町', 'サカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市八幡町', '08', '08201', '3100065', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '八幡町', 'ハチマンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市金町', '08', '08201', '3100066', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '金町', 'カネマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市根本', '08', '08201', '3100067', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '根本', 'ネモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市根本町', '08', '08201', '3100068', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '根本町', 'ネモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市櫛引土橋', '02', '02203', '0310007', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '櫛引', 'クシビキ', null, null, '土橋', 'ツチハシ');
INSERT INTO `ms_addresses` VALUES ('22216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市田向', '02', '02203', '0310011', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '田向', 'タムカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市十日市', '02', '02203', '0310012', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '十日市', 'トオカイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市石手洗', '02', '02203', '0310013', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '石手洗', 'イシテアライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市長者', '02', '02203', '0310021', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '長者', 'チョウジャ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市糠塚', '02', '02203', '0310022', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '糠塚', 'ヌカヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市是川', '02', '02203', '0310023', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '是川', 'コレカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市番町', '02', '02203', '0310031', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '番町', 'バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市三日町', '02', '02203', '0310032', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '三日町', 'ミッカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市六日町', '02', '02203', '0310033', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '六日町', 'ムイカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市鷹匠小路', '02', '02203', '0310034', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '鷹匠小路', 'タカショウコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市寺横町', '02', '02203', '0310035', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '寺横町', 'テラヨコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市大工町', '02', '02203', '0310036', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '大工町', 'ダイクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市鍛冶町', '02', '02203', '0310037', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '鍛冶町', 'カジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市山伏小路', '02', '02203', '0310038', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '山伏小路', 'ヤマブシコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市鳥屋部町', '02', '02203', '0310039', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '鳥屋部町', 'トヤベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市廿三日町', '02', '02203', '0310041', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '廿三日町', 'ニジュウサンニチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市十三日町', '02', '02203', '0310042', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '十三日町', 'ジュウサンニチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市十六日町', '02', '02203', '0310043', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '十六日町', 'ジュウロクニチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市廿六日町', '02', '02203', '0310044', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '廿六日町', 'ニジュウロクニチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市本鍛冶町', '02', '02203', '0310045', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '本鍛冶町', 'モトカジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市町組町', '02', '02203', '0310046', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '町組町', 'マチクミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市常番町', '02', '02203', '0310047', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '常番町', 'ジョウバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市堤町', '02', '02203', '0310051', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '堤町', 'ツツミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市本徒士町', '02', '02203', '0310052', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '本徒士町', 'モトカジシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市徒士町', '02', '02203', '0310053', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '徒士町', 'カジシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市稲荷町', '02', '02203', '0310054', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '稲荷町', 'イナリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市荒町', '02', '02203', '0310055', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '荒町', 'アラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市新荒町', '02', '02203', '0310056', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '新荒町', 'シンアラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市上徒士町', '02', '02203', '0310057', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '上徒士町', 'カミカジシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市上組町', '02', '02203', '0310058', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '上組町', 'カミクミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市沼館', '02', '02203', '0310071', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '沼館', 'ヌマダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市城下', '02', '02203', '0310072', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '城下', 'シロシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市売市', '02', '02203', '0310073', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '売市', 'ウルイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市馬場町', '02', '02203', '0310074', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '馬場町', 'ババチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市内丸', '02', '02203', '0310075', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '内丸', 'ウチマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市堀端町', '02', '02203', '0310076', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '堀端町', 'ホリバタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市長根', '02', '02203', '0310077', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '長根', 'ナガネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市桜川', '08', '08201', '3100801', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '桜川', 'サクラガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市柵町', '08', '08201', '3100802', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '柵町', 'サクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市城南', '08', '08201', '3100803', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '城南', 'ジョウナン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市白梅', '08', '08201', '3100804', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '白梅', 'シラウメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市中央', '08', '08201', '3100805', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市柏崎', '02', '02203', '0310081', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '柏崎', 'カシワザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市東桜川', '08', '08201', '3100811', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '東桜川', 'ヒガシサクラガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市浜田', '08', '08201', '3100812', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '浜田', 'ハマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市浜田町', '08', '08201', '3100813', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '浜田町', 'ハマダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市瓦谷', '08', '08201', '3100814', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '瓦谷', 'カワラヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市本町', '08', '08201', '3100815', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市紺屋町', '08', '08201', '3100816', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '紺屋町', 'コンヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市柳町', '08', '08201', '3100817', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '柳町', 'ヤナギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市東台', '08', '08201', '3100818', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '東台', 'ヒガシダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市常海町', '02', '02203', '0310082', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '常海町', 'ジョウカイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市中大野', '08', '08201', '3100821', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '中大野', 'ナカオオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市圷大野', '08', '08201', '3100822', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '圷大野', 'アクツオオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市東大野', '08', '08201', '3100823', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '東大野', 'ヒガシオオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市西大野', '08', '08201', '3100824', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '西大野', 'ニシオオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市谷田町', '08', '08201', '3100825', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '谷田町', 'ヤダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市渋井町', '08', '08201', '3100826', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '渋井町', 'シブイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市吉沼町', '08', '08201', '3100827', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '吉沼町', 'ヨシヌマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市窪町', '02', '02203', '0310083', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '窪町', 'クボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市朝日町', '08', '08201', '3100831', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '朝日町', 'アサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市吉田', '08', '08201', '3100832', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '吉田', 'ヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市藤柄町', '08', '08201', '3100833', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '藤柄町', 'フジガラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市宮内町', '08', '08201', '3100834', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '宮内町', 'ミヤウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市元台町', '08', '08201', '3100835', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '元台町', 'モトダイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市元吉田町', '08', '08201', '3100836', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '元吉田町', 'モトヨシダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市十八日町', '02', '02203', '0310084', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '十八日町', 'ジュウハチニチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市酒門町', '08', '08201', '3100841', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '酒門町', 'サカドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市けやき台', '08', '08201', '3100842', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', 'けやき台', 'ケヤキダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市元石川町', '08', '08201', '3100843', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '元石川町', 'モトイシカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市住吉町', '08', '08201', '3100844', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '住吉町', 'スミヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市吉沢町', '08', '08201', '3100845', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '吉沢町', 'ヨシザワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市東野町', '08', '08201', '3100846', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '東野町', 'トウノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市米沢町', '08', '08201', '3100847', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '米沢町', 'ヨネザワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市十一日町', '02', '02203', '0310085', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '十一日町', 'ジュウイチニチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市千波町', '08', '08201', '3100851', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '千波町', 'センバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市笠原町', '08', '08201', '3100852', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '笠原町', 'カサハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市平須町', '08', '08201', '3100853', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '平須町', 'ヒラスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市八日町', '02', '02203', '0310086', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '八日町', 'ヨウカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市朔日町', '02', '02203', '0310087', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '朔日町', 'ツイタチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市岩泉町', '02', '02203', '0310088', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '岩泉町', 'イワイズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市長横町', '02', '02203', '0310089', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '長横町', 'ナガヨコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市田野町', '08', '08201', '3100901', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '田野町', 'タノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市渡里町', '08', '08201', '3100902', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '渡里町', 'ワタリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市堀町', '08', '08201', '3100903', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '堀町', 'ホリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市石川町', '08', '08201', '3100904', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '石川町', 'イシカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市石川', '08', '08201', '3100905', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '石川', 'イシカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市見和', '08', '08201', '3100911', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '見和', 'ミワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市見川', '08', '08201', '3100912', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '見川', 'ミガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市見川町', '08', '08201', '3100913', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '見川町', 'ミガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市小吹町', '08', '08201', '3100914', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '小吹町', 'コブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市南郷区市野沢', '02', '02203', '0310111', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '南郷区市野沢', 'ナンゴウクイチノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市南郷区大森', '02', '02203', '0310112', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '南郷区大森', 'ナンゴウクオオモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市南郷区泉清水', '02', '02203', '0310113', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '南郷区泉清水', 'ナンゴウクイズミシミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市南郷区中野', '02', '02203', '0310114', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '南郷区中野', 'ナンゴウクナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市南郷区泥障作', '02', '02203', '0310115', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '南郷区泥障作', 'ナンゴウクアオヅクリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市南郷区頃巻沢', '02', '02203', '0310201', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '南郷区頃巻沢', 'ナンゴウクコロマキサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市南郷区島守', '02', '02203', '0310202', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '南郷区島守', 'ナンゴウクシマモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市江陽', '02', '02203', '0310801', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '江陽', 'コウヨウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市小中野', '02', '02203', '0310802', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '小中野', 'コナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市諏訪', '02', '02203', '0310803', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '諏訪', 'スワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市青葉', '02', '02203', '0310804', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '青葉', 'アオバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市新湊', '02', '02203', '0310811', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '新湊', 'シンミナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市湊町', '02', '02203', '0310812', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '湊町', 'ミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市新井田', '02', '02203', '0310813', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '新井田', 'ニイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市妙', '02', '02203', '0310814', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '妙', 'ミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市松館', '02', '02203', '0310815', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '松館', 'マツダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市新井田西', '02', '02203', '0310816', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '新井田西', 'ニイダニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市白銀', '02', '02203', '0310821', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '白銀', 'シロガネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市白銀町', '02', '02203', '0310822', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '白銀町', 'シロガネマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市湊高台', '02', '02203', '0310823', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '湊高台', 'ミナトタカダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市旭ケ丘', '02', '02203', '0310824', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '旭ケ丘', 'アサヒガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市築港街', '02', '02203', '0310831', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '築港街', 'チッコウガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市白銀台', '02', '02203', '0310832', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '白銀台', 'シロガネダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市大久保', '02', '02203', '0310833', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '大久保', 'オオクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市桜ケ丘', '02', '02203', '0310834', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '桜ケ丘', 'サクラガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市鮫町', '02', '02203', '0310841', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '鮫町', 'サメマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市岬台', '02', '02203', '0310842', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '岬台', 'ミサキダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市金浜', '02', '02203', '0310843', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '金浜', 'カネハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市美保野', '02', '02203', '0310844', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '美保野', 'ミホノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県那珂市', '08', '08226', '3110100', '茨城県', 'イバラキケン', '那珂市', 'ナカシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('22377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県那珂市本米崎', '08', '08226', '3110101', '茨城県', 'イバラキケン', '那珂市', 'ナカシ', '本米崎', 'モトコメザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県那珂市向山', '08', '08226', '3110102', '茨城県', 'イバラキケン', '那珂市', 'ナカシ', '向山', 'ムコウヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県那珂市横堀', '08', '08226', '3110103', '茨城県', 'イバラキケン', '那珂市', 'ナカシ', '横堀', 'ヨコボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県那珂市堤', '08', '08226', '3110104', '茨城県', 'イバラキケン', '那珂市', 'ナカシ', '堤', 'ツツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県那珂市菅谷', '08', '08226', '3110105', '茨城県', 'イバラキケン', '那珂市', 'ナカシ', '菅谷', 'スガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県那珂市杉', '08', '08226', '3110106', '茨城県', 'イバラキケン', '那珂市', 'ナカシ', '杉', 'スギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県那珂市額田南郷', '08', '08226', '3110107', '茨城県', 'イバラキケン', '那珂市', 'ナカシ', '額田南郷', 'ヌカダミナミゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県那珂市額田北郷', '08', '08226', '3110108', '茨城県', 'イバラキケン', '那珂市', 'ナカシ', '額田北郷', 'ヌカダキタゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県那珂市額田東郷', '08', '08226', '3110109', '茨城県', 'イバラキケン', '那珂市', 'ナカシ', '額田東郷', 'ヌカダヒガシゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県那珂市竹ノ内', '08', '08226', '3110110', '茨城県', 'イバラキケン', '那珂市', 'ナカシ', '竹ノ内', 'タケノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県那珂市後台', '08', '08226', '3110111', '茨城県', 'イバラキケン', '那珂市', 'ナカシ', '後台', 'ゴダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県那珂市津田', '08', '08226', '3110112', '茨城県', 'イバラキケン', '那珂市', 'ナカシ', '津田', 'ツダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県那珂市中台', '08', '08226', '3110113', '茨城県', 'イバラキケン', '那珂市', 'ナカシ', '中台', 'ナカダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県那珂市東木倉', '08', '08226', '3110114', '茨城県', 'イバラキケン', '那珂市', 'ナカシ', '東木倉', 'ヒガシキノクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県那珂市西木倉', '08', '08226', '3110115', '茨城県', 'イバラキケン', '那珂市', 'ナカシ', '西木倉', 'ニシキノクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県那珂市上河内', '08', '08226', '3110116', '茨城県', 'イバラキケン', '那珂市', 'ナカシ', '上河内', 'カミガチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県那珂市豊喰', '08', '08226', '3110117', '茨城県', 'イバラキケン', '那珂市', 'ナカシ', '豊喰', 'トヨバミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県那珂市福田', '08', '08226', '3110118', '茨城県', 'イバラキケン', '那珂市', 'ナカシ', '福田', 'フクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県那珂市戸崎', '08', '08226', '3110121', '茨城県', 'イバラキケン', '那珂市', 'ナカシ', '戸崎', 'トザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県那珂市戸', '08', '08226', '3110122', '茨城県', 'イバラキケン', '那珂市', 'ナカシ', '戸', 'ト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県那珂市上国井', '08', '08226', '3110123', '茨城県', 'イバラキケン', '那珂市', 'ナカシ', '上国井', 'カミクニイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県那珂市田崎', '08', '08226', '3110124', '茨城県', 'イバラキケン', '那珂市', 'ナカシ', '田崎', 'タサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県那珂市大内', '08', '08226', '3110125', '茨城県', 'イバラキケン', '那珂市', 'ナカシ', '大内', 'オオウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県那珂市下江戸', '08', '08226', '3110126', '茨城県', 'イバラキケン', '那珂市', 'ナカシ', '下江戸', 'シモエド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県那珂市北酒出', '08', '08226', '3110131', '茨城県', 'イバラキケン', '那珂市', 'ナカシ', '北酒出', 'キタサカイデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県那珂市南酒出', '08', '08226', '3110132', '茨城県', 'イバラキケン', '那珂市', 'ナカシ', '南酒出', 'ミナミサカイデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県那珂市鴻巣', '08', '08226', '3110133', '茨城県', 'イバラキケン', '那珂市', 'ナカシ', '鴻巣', 'コウノス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県那珂市飯田', '08', '08226', '3110134', '茨城県', 'イバラキケン', '那珂市', 'ナカシ', '飯田', 'イイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県那珂市鹿島', '08', '08226', '3110135', '茨城県', 'イバラキケン', '那珂市', 'ナカシ', '鹿島', 'カシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県那珂市門部', '08', '08226', '3110136', '茨城県', 'イバラキケン', '那珂市', 'ナカシ', '門部', 'カトベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市河内西町', '08', '08212', '3110301', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', '河内西町', 'カワチニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市町屋町', '08', '08212', '3110311', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', '町屋町', 'マチヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市西河内下町', '08', '08212', '3110312', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', '西河内下町', 'ニシゴウトシモチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市西河内中町', '08', '08212', '3110313', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', '西河内中町', 'ニシゴウトナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市西河内上町', '08', '08212', '3110314', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', '西河内上町', 'ニシゴウトカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市春友町', '08', '08212', '3110321', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', '春友町', 'ハルトモチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市常福地町', '08', '08212', '3110322', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', '常福地町', 'ジョウフクジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市茅根町', '08', '08212', '3110323', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', '茅根町', 'チノネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市白羽町', '08', '08212', '3110324', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', '白羽町', 'シラワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市里野宮町', '08', '08212', '3110325', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', '里野宮町', 'サトノミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県日立市中深荻町', '08', '08202', '3110401', '茨城県', 'イバラキケン', '日立市', 'ヒタチシ', '中深荻町', 'ナカフカオギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県日立市入四間町', '08', '08202', '3110402', '茨城県', 'イバラキケン', '日立市', 'ヒタチシ', '入四間町', 'イリシケンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県日立市東河内町', '08', '08202', '3110403', '茨城県', 'イバラキケン', '日立市', 'ヒタチシ', '東河内町', 'ヒガシゴウドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県日立市下深荻町', '08', '08202', '3110404', '茨城県', 'イバラキケン', '日立市', 'ヒタチシ', '下深荻町', 'シモフカオギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市里川町', '08', '08212', '3110501', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', '里川町', 'サトガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市徳田町', '08', '08212', '3110502', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', '徳田町', 'トクダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市小妻町', '08', '08212', '3110503', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', '小妻町', 'コヅマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市小中町', '08', '08212', '3110504', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', '小中町', 'コナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市大中町', '08', '08212', '3110505', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', '大中町', 'オオナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市折橋町', '08', '08212', '3110506', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', '折橋町', 'オリハシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市小菅町', '08', '08212', '3110507', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', '小菅町', 'コスゲチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市大菅町', '08', '08212', '3110508', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', '大菅町', 'オオスゲチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市上深荻町', '08', '08212', '3110509', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', '上深荻町', 'カミフカオギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市小泉町', '08', '08201', '3111111', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '小泉町', 'コイズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市川又町', '08', '08201', '3111112', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '川又町', 'カワマタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市平戸町', '08', '08201', '3111113', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '平戸町', 'ヒラトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市塩崎町', '08', '08201', '3111114', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '塩崎町', 'シオガサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市大串町', '08', '08201', '3111115', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '大串町', 'オオクシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市島田町', '08', '08201', '3111121', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '島田町', 'シマダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市秋成町', '08', '08201', '3111122', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '秋成町', 'アキナリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市下入野町', '08', '08201', '3111123', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '下入野町', 'シモイリノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市森戸町', '08', '08201', '3111124', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '森戸町', 'モリトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市大場町', '08', '08201', '3111125', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '大場町', 'オオバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市下大野町', '08', '08201', '3111131', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '下大野町', 'シモオオノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市東前町', '08', '08201', '3111132', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '東前町', 'トウマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市栗崎町', '08', '08201', '3111133', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '栗崎町', 'クリサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市百合が丘町', '08', '08201', '3111134', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '百合が丘町', 'ユリガオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市六反田町', '08', '08201', '3111135', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '六反田町', 'ロクタンダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市東前', '08', '08201', '3111136', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '東前', 'トウマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県ひたちなか市阿字ケ浦町', '08', '08221', '3111201', '茨城県', 'イバラキケン', 'ひたちなか市', 'ヒタチナカシ', '阿字ケ浦町', 'アジガウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県ひたちなか市磯崎町', '08', '08221', '3111202', '茨城県', 'イバラキケン', 'ひたちなか市', 'ヒタチナカシ', '磯崎町', 'イソザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県ひたちなか市平磯町', '08', '08221', '3111203', '茨城県', 'イバラキケン', 'ひたちなか市', 'ヒタチナカシ', '平磯町', 'ヒライソチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県ひたちなか市平磯遠原町', '08', '08221', '3111204', '茨城県', 'イバラキケン', 'ひたちなか市', 'ヒタチナカシ', '平磯遠原町', 'ヒライソトオハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県ひたちなか市十三奉行', '08', '08221', '3111205', '茨城県', 'イバラキケン', 'ひたちなか市', 'ヒタチナカシ', '十三奉行', 'ジュウサンブギョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県ひたちなか市西十三奉行', '08', '08221', '3111206', '茨城県', 'イバラキケン', 'ひたちなか市', 'ヒタチナカシ', '西十三奉行', 'ニシジュウサンブギョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県ひたちなか市烏ケ台', '08', '08221', '3111207', '茨城県', 'イバラキケン', 'ひたちなか市', 'ヒタチナカシ', '烏ケ台', 'カラスガダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県ひたちなか市沢メキ', '08', '08221', '3111211', '茨城県', 'イバラキケン', 'ひたちなか市', 'ヒタチナカシ', '沢メキ', 'サワメキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県ひたちなか市殿山町', '08', '08221', '3111212', '茨城県', 'イバラキケン', 'ひたちなか市', 'ヒタチナカシ', '殿山町', 'トノヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県ひたちなか市牛久保', '08', '08221', '3111213', '茨城県', 'イバラキケン', 'ひたちなか市', 'ヒタチナカシ', '牛久保', 'ウシクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県ひたちなか市和田町', '08', '08221', '3111214', '茨城県', 'イバラキケン', 'ひたちなか市', 'ヒタチナカシ', '和田町', 'ワダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県ひたちなか市東本町', '08', '08221', '3111215', '茨城県', 'イバラキケン', 'ひたちなか市', 'ヒタチナカシ', '東本町', 'ヒガシホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県ひたちなか市湊泉町', '08', '08221', '3111216', '茨城県', 'イバラキケン', 'ひたちなか市', 'ヒタチナカシ', '湊泉町', 'ミナトイズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県ひたちなか市富士ノ下', '08', '08221', '3111217', '茨城県', 'イバラキケン', 'ひたちなか市', 'ヒタチナカシ', '富士ノ下', 'フジノシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県ひたちなか市富士ノ上', '08', '08221', '3111218', '茨城県', 'イバラキケン', 'ひたちなか市', 'ヒタチナカシ', '富士ノ上', 'フジノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県ひたちなか市湊本町', '08', '08221', '3111221', '茨城県', 'イバラキケン', 'ひたちなか市', 'ヒタチナカシ', '湊本町', 'ミナトホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県ひたちなか市海門町', '08', '08221', '3111222', '茨城県', 'イバラキケン', 'ひたちなか市', 'ヒタチナカシ', '海門町', 'カイモンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県ひたちなか市栄町', '08', '08221', '3111223', '茨城県', 'イバラキケン', 'ひたちなか市', 'ヒタチナカシ', '栄町', 'サカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県ひたちなか市山ノ上町', '08', '08221', '3111224', '茨城県', 'イバラキケン', 'ひたちなか市', 'ヒタチナカシ', '山ノ上町', 'ヤマノウエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県ひたちなか市釈迦町', '08', '08221', '3111225', '茨城県', 'イバラキケン', 'ひたちなか市', 'ヒタチナカシ', '釈迦町', 'シャカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県ひたちなか市幸町', '08', '08221', '3111226', '茨城県', 'イバラキケン', 'ひたちなか市', 'ヒタチナカシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県ひたちなか市洞下町', '08', '08221', '3111227', '茨城県', 'イバラキケン', 'ひたちなか市', 'ヒタチナカシ', '洞下町', 'ドウシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県ひたちなか市八幡町', '08', '08221', '3111228', '茨城県', 'イバラキケン', 'ひたちなか市', 'ヒタチナカシ', '八幡町', 'ハチマンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県ひたちなか市湊中央', '08', '08221', '3111229', '茨城県', 'イバラキケン', 'ひたちなか市', 'ヒタチナカシ', '湊中央', 'ミナトチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県ひたちなか市柳沢', '08', '08221', '3111231', '茨城県', 'イバラキケン', 'ひたちなか市', 'ヒタチナカシ', '柳沢', 'ヤナギサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県ひたちなか市柳が丘', '08', '08221', '3111232', '茨城県', 'イバラキケン', 'ひたちなか市', 'ヒタチナカシ', '柳が丘', 'ヤナギガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県ひたちなか市堀川', '08', '08221', '3111233', '茨城県', 'イバラキケン', 'ひたちなか市', 'ヒタチナカシ', '堀川', 'ホリカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県ひたちなか市峰後', '08', '08221', '3111234', '茨城県', 'イバラキケン', 'ひたちなか市', 'ヒタチナカシ', '峰後', 'ミネウシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県ひたちなか市田中後', '08', '08221', '3111235', '茨城県', 'イバラキケン', 'ひたちなか市', 'ヒタチナカシ', '田中後', 'タナカウシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県ひたちなか市国神前', '08', '08221', '3111236', '茨城県', 'イバラキケン', 'ひたちなか市', 'ヒタチナカシ', '国神前', 'コクジンマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県ひたちなか市関戸', '08', '08221', '3111237', '茨城県', 'イバラキケン', 'ひたちなか市', 'ヒタチナカシ', '関戸', 'セキド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県ひたちなか市美田多町', '08', '08221', '3111238', '茨城県', 'イバラキケン', 'ひたちなか市', 'ヒタチナカシ', '美田多町', 'ミタダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県ひたちなか市赤坂', '08', '08221', '3111241', '茨城県', 'イバラキケン', 'ひたちなか市', 'ヒタチナカシ', '赤坂', 'アカサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県ひたちなか市西赤坂', '08', '08221', '3111242', '茨城県', 'イバラキケン', 'ひたちなか市', 'ヒタチナカシ', '西赤坂', 'ニシアカサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県ひたちなか市北神敷台', '08', '08221', '3111243', '茨城県', 'イバラキケン', 'ひたちなか市', 'ヒタチナカシ', '北神敷台', 'キタカミシキダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県ひたちなか市南神敷台', '08', '08221', '3111244', '茨城県', 'イバラキケン', 'ひたちなか市', 'ヒタチナカシ', '南神敷台', 'ミナミカミシキダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県ひたちなか市館山', '08', '08221', '3111245', '茨城県', 'イバラキケン', 'ひたちなか市', 'ヒタチナカシ', '館山', 'タテヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県ひたちなか市相金町', '08', '08221', '3111246', '茨城県', 'イバラキケン', 'ひたちなか市', 'ヒタチナカシ', '相金町', 'ソウガネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県ひたちなか市四十発句', '08', '08221', '3111247', '茨城県', 'イバラキケン', 'ひたちなか市', 'ヒタチナカシ', '四十発句', 'シジュウホツク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県ひたちなか市田宮原', '08', '08221', '3111248', '茨城県', 'イバラキケン', 'ひたちなか市', 'ヒタチナカシ', '田宮原', 'タミヤハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県ひたちなか市山崎', '08', '08221', '3111251', '茨城県', 'イバラキケン', 'ひたちなか市', 'ヒタチナカシ', '山崎', 'ヤマザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県ひたちなか市部田野', '08', '08221', '3111252', '茨城県', 'イバラキケン', 'ひたちなか市', 'ヒタチナカシ', '部田野', 'ヘタノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県ひたちなか市小谷金', '08', '08221', '3111253', '茨城県', 'イバラキケン', 'ひたちなか市', 'ヒタチナカシ', '小谷金', 'コヤガネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県ひたちなか市新堤', '08', '08221', '3111254', '茨城県', 'イバラキケン', 'ひたちなか市', 'ヒタチナカシ', '新堤', 'ニイヅツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県ひたちなか市雨沢谷津', '08', '08221', '3111255', '茨城県', 'イバラキケン', 'ひたちなか市', 'ヒタチナカシ', '雨沢谷津', 'アメザワヤツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県ひたちなか市鶴代', '08', '08221', '3111261', '茨城県', 'イバラキケン', 'ひたちなか市', 'ヒタチナカシ', '鶴代', 'ツルシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県ひたちなか市道メキ', '08', '08221', '3111262', '茨城県', 'イバラキケン', 'ひたちなか市', 'ヒタチナカシ', '道メキ', 'ドウメキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県ひたちなか市和尚塚', '08', '08221', '3111263', '茨城県', 'イバラキケン', 'ひたちなか市', 'ヒタチナカシ', '和尚塚', 'オショウツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県ひたちなか市浅井内', '08', '08221', '3111264', '茨城県', 'イバラキケン', 'ひたちなか市', 'ヒタチナカシ', '浅井内', 'アサイナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県ひたちなか市狢谷津', '08', '08221', '3111265', '茨城県', 'イバラキケン', 'ひたちなか市', 'ヒタチナカシ', '狢谷津', 'ムジナヤツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県ひたちなか市船窪', '08', '08221', '3111266', '茨城県', 'イバラキケン', 'ひたちなか市', 'ヒタチナカシ', '船窪', 'フナクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県ひたちなか市廻り目', '08', '08221', '3111267', '茨城県', 'イバラキケン', 'ひたちなか市', 'ヒタチナカシ', '廻り目', 'マワリメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県ひたちなか市湊中原', '08', '08221', '3111268', '茨城県', 'イバラキケン', 'ひたちなか市', 'ヒタチナカシ', '湊中原', 'ミナトナカハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県東茨城郡大洗町', '08', '08309', '3111300', '茨城県', 'イバラキケン', '東茨城郡大洗町', 'ヒガシイバラキグンオオアライマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('22503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県東茨城郡大洗町磯浜町', '08', '08309', '3111301', '茨城県', 'イバラキケン', '東茨城郡大洗町', 'ヒガシイバラキグンオオアライマチ', '磯浜町', 'イソハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県東茨城郡大洗町磯道', '08', '08309', '3111302', '茨城県', 'イバラキケン', '東茨城郡大洗町', 'ヒガシイバラキグンオオアライマチ', '磯道', 'イソミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県東茨城郡大洗町東光台', '08', '08309', '3111303', '茨城県', 'イバラキケン', '東茨城郡大洗町', 'ヒガシイバラキグンオオアライマチ', '東光台', 'トウコウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県東茨城郡大洗町和銅', '08', '08309', '3111304', '茨城県', 'イバラキケン', '東茨城郡大洗町', 'ヒガシイバラキグンオオアライマチ', '和銅', 'ワドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県東茨城郡大洗町港中央', '08', '08309', '3111305', '茨城県', 'イバラキケン', '東茨城郡大洗町', 'ヒガシイバラキグンオオアライマチ', '港中央', 'ミナトチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県東茨城郡大洗町五反田', '08', '08309', '3111306', '茨城県', 'イバラキケン', '東茨城郡大洗町', 'ヒガシイバラキグンオオアライマチ', '五反田', 'ゴタンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県東茨城郡大洗町桜道', '08', '08309', '3111307', '茨城県', 'イバラキケン', '東茨城郡大洗町', 'ヒガシイバラキグンオオアライマチ', '桜道', 'サクラミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県東茨城郡大洗町大貫町', '08', '08309', '3111311', '茨城県', 'イバラキケン', '東茨城郡大洗町', 'ヒガシイバラキグンオオアライマチ', '大貫町', 'オオヌキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県東茨城郡大洗町神山町', '08', '08309', '3111312', '茨城県', 'イバラキケン', '東茨城郡大洗町', 'ヒガシイバラキグンオオアライマチ', '神山町', 'カミヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県東茨城郡大洗町成田町', '08', '08309', '3111313', '茨城県', 'イバラキケン', '東茨城郡大洗町', 'ヒガシイバラキグンオオアライマチ', '成田町', 'ナリタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鉾田市箕輪', '08', '08234', '3111401', '茨城県', 'イバラキケン', '鉾田市', 'ホコタシ', '箕輪', 'ミノワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鉾田市下太田', '08', '08234', '3111402', '茨城県', 'イバラキケン', '鉾田市', 'ホコタシ', '下太田', 'シモオオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鉾田市上釜', '08', '08234', '3111403', '茨城県', 'イバラキケン', '鉾田市', 'ホコタシ', '上釜', 'カミガマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鉾田市沢尻', '08', '08234', '3111404', '茨城県', 'イバラキケン', '鉾田市', 'ホコタシ', '沢尻', 'サワジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鉾田市上太田', '08', '08234', '3111405', '茨城県', 'イバラキケン', '鉾田市', 'ホコタシ', '上太田', 'カミオオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鉾田市田崎', '08', '08234', '3111406', '茨城県', 'イバラキケン', '鉾田市', 'ホコタシ', '田崎', 'タサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鉾田市荒地', '08', '08234', '3111411', '茨城県', 'イバラキケン', '鉾田市', 'ホコタシ', '荒地', 'アラジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鉾田市玉田', '08', '08234', '3111412', '茨城県', 'イバラキケン', '鉾田市', 'ホコタシ', '玉田', 'タマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鉾田市冷水', '08', '08234', '3111413', '茨城県', 'イバラキケン', '鉾田市', 'ホコタシ', '冷水', 'ヒヤミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鉾田市子生', '08', '08234', '3111414', '茨城県', 'イバラキケン', '鉾田市', 'ホコタシ', '子生', 'コナジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鉾田市造谷', '08', '08234', '3111415', '茨城県', 'イバラキケン', '鉾田市', 'ホコタシ', '造谷', 'ツクリヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鉾田市鹿田', '08', '08234', '3111416', '茨城県', 'イバラキケン', '鉾田市', 'ホコタシ', '鹿田', 'シカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鉾田市勝下新田', '08', '08234', '3111421', '茨城県', 'イバラキケン', '鉾田市', 'ホコタシ', '勝下新田', 'カツオリシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鉾田市勝下', '08', '08234', '3111422', '茨城県', 'イバラキケン', '鉾田市', 'ホコタシ', '勝下', 'カツオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鉾田市滝浜', '08', '08234', '3111423', '茨城県', 'イバラキケン', '鉾田市', 'ホコタシ', '滝浜', 'タキハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鉾田市柏熊新田', '08', '08234', '3111424', '茨城県', 'イバラキケン', '鉾田市', 'ホコタシ', '柏熊新田', 'カシワクマシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鉾田市湯坪', '08', '08234', '3111425', '茨城県', 'イバラキケン', '鉾田市', 'ホコタシ', '湯坪', 'ユツボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鉾田市樅山', '08', '08234', '3111426', '茨城県', 'イバラキケン', '鉾田市', 'ホコタシ', '樅山', 'モミヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鉾田市常磐', '08', '08234', '3111427', '茨城県', 'イバラキケン', '鉾田市', 'ホコタシ', '常磐', 'トキワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鉾田市', '08', '08234', '3111500', '茨城県', 'イバラキケン', '鉾田市', 'ホコタシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('22537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鉾田市舟木', '08', '08234', '3111501', '茨城県', 'イバラキケン', '鉾田市', 'ホコタシ', '舟木', 'フナキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鉾田市大戸', '08', '08234', '3111502', '茨城県', 'イバラキケン', '鉾田市', 'ホコタシ', '大戸', 'オオド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鉾田市徳宿', '08', '08234', '3111503', '茨城県', 'イバラキケン', '鉾田市', 'ホコタシ', '徳宿', 'トクシュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鉾田市安房', '08', '08234', '3111504', '茨城県', 'イバラキケン', '鉾田市', 'ホコタシ', '安房', 'アンボウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鉾田市駒木根', '08', '08234', '3111505', '茨城県', 'イバラキケン', '鉾田市', 'ホコタシ', '駒木根', 'コマギネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鉾田市秋山', '08', '08234', '3111506', '茨城県', 'イバラキケン', '鉾田市', 'ホコタシ', '秋山', 'アキヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鉾田市柏熊', '08', '08234', '3111511', '茨城県', 'イバラキケン', '鉾田市', 'ホコタシ', '柏熊', 'カシワクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鉾田市白塚', '08', '08234', '3111512', '茨城県', 'イバラキケン', '鉾田市', 'ホコタシ', '白塚', 'シラツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鉾田市大竹', '08', '08234', '3111513', '茨城県', 'イバラキケン', '鉾田市', 'ホコタシ', '大竹', 'オオタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鉾田市安塚', '08', '08234', '3111514', '茨城県', 'イバラキケン', '鉾田市', 'ホコタシ', '安塚', 'ヤスヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鉾田市烟田', '08', '08234', '3111515', '茨城県', 'イバラキケン', '鉾田市', 'ホコタシ', '烟田', 'カマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鉾田市新鉾田', '08', '08234', '3111516', '茨城県', 'イバラキケン', '鉾田市', 'ホコタシ', '新鉾田', 'シンホコタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鉾田市鉾田', '08', '08234', '3111517', '茨城県', 'イバラキケン', '鉾田市', 'ホコタシ', '鉾田', 'ホコタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鉾田市新鉾田西', '08', '08234', '3111518', '茨城県', 'イバラキケン', '鉾田市', 'ホコタシ', '新鉾田西', 'シンホコタニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鉾田市飯名', '08', '08234', '3111521', '茨城県', 'イバラキケン', '鉾田市', 'ホコタシ', '飯名', 'イイナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鉾田市塔ケ崎', '08', '08234', '3111522', '茨城県', 'イバラキケン', '鉾田市', 'ホコタシ', '塔ケ崎', 'トウガサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鉾田市串挽', '08', '08234', '3111523', '茨城県', 'イバラキケン', '鉾田市', 'ホコタシ', '串挽', 'クシヒキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鉾田市高田', '08', '08234', '3111524', '茨城県', 'イバラキケン', '鉾田市', 'ホコタシ', '高田', 'タカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鉾田市野友', '08', '08234', '3111525', '茨城県', 'イバラキケン', '鉾田市', 'ホコタシ', '野友', 'ノトモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鉾田市半原', '08', '08234', '3111526', '茨城県', 'イバラキケン', '鉾田市', 'ホコタシ', '半原', 'ハバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鉾田市借宿', '08', '08234', '3111527', '茨城県', 'イバラキケン', '鉾田市', 'ホコタシ', '借宿', 'カリヤド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鉾田市当間', '08', '08234', '3111528', '茨城県', 'イバラキケン', '鉾田市', 'ホコタシ', '当間', 'トウマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鉾田市菅野谷', '08', '08234', '3111531', '茨城県', 'イバラキケン', '鉾田市', 'ホコタシ', '菅野谷', 'スゲノヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鉾田市上冨田', '08', '08234', '3111532', '茨城県', 'イバラキケン', '鉾田市', 'ホコタシ', '上冨田', 'カミトミタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鉾田市下冨田', '08', '08234', '3111533', '茨城県', 'イバラキケン', '鉾田市', 'ホコタシ', '下冨田', 'シモトミタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鉾田市鳥栖', '08', '08234', '3111534', '茨城県', 'イバラキケン', '鉾田市', 'ホコタシ', '鳥栖', 'トリノス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鉾田市青柳', '08', '08234', '3111535', '茨城県', 'イバラキケン', '鉾田市', 'ホコタシ', '青柳', 'アオヤギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鉾田市大和田', '08', '08234', '3111536', '茨城県', 'イバラキケン', '鉾田市', 'ホコタシ', '大和田', 'オオワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鉾田市紅葉', '08', '08234', '3111537', '茨城県', 'イバラキケン', '鉾田市', 'ホコタシ', '紅葉', 'モミジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県行方市長野江', '08', '08233', '3111701', '茨城県', 'イバラキケン', '行方市', 'ナメガタシ', '長野江', 'ナガノエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県行方市三和', '08', '08233', '3111702', '茨城県', 'イバラキケン', '行方市', 'ナメガタシ', '三和', 'ミワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県行方市成田', '08', '08233', '3111703', '茨城県', 'イバラキケン', '行方市', 'ナメガタシ', '成田', 'ナリタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県行方市山田', '08', '08233', '3111704', '茨城県', 'イバラキケン', '行方市', 'ナメガタシ', '山田', 'ヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県行方市内宿', '08', '08233', '3111705', '茨城県', 'イバラキケン', '行方市', 'ナメガタシ', '内宿', 'ウチジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県行方市吉川', '08', '08233', '3111711', '茨城県', 'イバラキケン', '行方市', 'ナメガタシ', '吉川', 'ヨシカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県行方市繁昌', '08', '08233', '3111712', '茨城県', 'イバラキケン', '行方市', 'ナメガタシ', '繁昌', 'ハンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県行方市中根', '08', '08233', '3111713', '茨城県', 'イバラキケン', '行方市', 'ナメガタシ', '中根', 'ナカネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県行方市南高岡', '08', '08233', '3111714', '茨城県', 'イバラキケン', '行方市', 'ナメガタシ', '南高岡', 'ミナミタカオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県行方市小幡', '08', '08233', '3111715', '茨城県', 'イバラキケン', '行方市', 'ナメガタシ', '小幡', 'オバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県行方市北高岡', '08', '08233', '3111716', '茨城県', 'イバラキケン', '行方市', 'ナメガタシ', '北高岡', 'キタタカオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県行方市両宿', '08', '08233', '3111721', '茨城県', 'イバラキケン', '行方市', 'ナメガタシ', '両宿', 'リョウシュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県行方市次木', '08', '08233', '3111722', '茨城県', 'イバラキケン', '行方市', 'ナメガタシ', '次木', 'ナミキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県行方市行戸', '08', '08233', '3111723', '茨城県', 'イバラキケン', '行方市', 'ナメガタシ', '行戸', 'ユクド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県行方市小貫', '08', '08233', '3111724', '茨城県', 'イバラキケン', '行方市', 'ナメガタシ', '小貫', 'オヌキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鉾田市青山', '08', '08234', '3112101', '茨城県', 'イバラキケン', '鉾田市', 'ホコタシ', '青山', 'アオヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鉾田市台濁沢', '08', '08234', '3112102', '茨城県', 'イバラキケン', '鉾田市', 'ホコタシ', '台濁沢', 'ダイニゴリサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鉾田市汲上', '08', '08234', '3112103', '茨城県', 'イバラキケン', '鉾田市', 'ホコタシ', '汲上', 'クミアゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鉾田市梶山', '08', '08234', '3112104', '茨城県', 'イバラキケン', '鉾田市', 'ホコタシ', '梶山', 'カジヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鉾田市二重作', '08', '08234', '3112105', '茨城県', 'イバラキケン', '鉾田市', 'ホコタシ', '二重作', 'フタエサク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鉾田市上沢', '08', '08234', '3112111', '茨城県', 'イバラキケン', '鉾田市', 'ホコタシ', '上沢', 'カミザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鉾田市飯島', '08', '08234', '3112112', '茨城県', 'イバラキケン', '鉾田市', 'ホコタシ', '飯島', 'イイジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鉾田市上幡木', '08', '08234', '3112113', '茨城県', 'イバラキケン', '鉾田市', 'ホコタシ', '上幡木', 'カミハタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鉾田市江川', '08', '08234', '3112114', '茨城県', 'イバラキケン', '鉾田市', 'ホコタシ', '江川', 'エガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鉾田市中居', '08', '08234', '3112115', '茨城県', 'イバラキケン', '鉾田市', 'ホコタシ', '中居', 'ナカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鉾田市札', '08', '08234', '3112116', '茨城県', 'イバラキケン', '鉾田市', 'ホコタシ', '札', 'フダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鉾田市大蔵', '08', '08234', '3112117', '茨城県', 'イバラキケン', '鉾田市', 'ホコタシ', '大蔵', 'オオクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鉾田市阿玉', '08', '08234', '3112118', '茨城県', 'イバラキケン', '鉾田市', 'ホコタシ', '阿玉', 'アダマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鹿嶋市大小志崎', '08', '08222', '3112201', '茨城県', 'イバラキケン', '鹿嶋市', 'カシマシ', '大小志崎', 'ダイショウシザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鹿嶋市武井釜', '08', '08222', '3112202', '茨城県', 'イバラキケン', '鹿嶋市', 'カシマシ', '武井釜', 'タケイガマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鹿嶋市浜津賀', '08', '08222', '3112203', '茨城県', 'イバラキケン', '鹿嶋市', 'カシマシ', '浜津賀', 'ハマツガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鹿嶋市荒井', '08', '08222', '3112204', '茨城県', 'イバラキケン', '鹿嶋市', 'カシマシ', '荒井', 'アライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鹿嶋市津賀', '08', '08222', '3112205', '茨城県', 'イバラキケン', '鹿嶋市', 'カシマシ', '津賀', 'ツガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鹿嶋市武井', '08', '08222', '3112206', '茨城県', 'イバラキケン', '鹿嶋市', 'カシマシ', '武井', 'タケイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鹿嶋市志崎', '08', '08222', '3112207', '茨城県', 'イバラキケン', '鹿嶋市', 'カシマシ', '志崎', 'シザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鹿嶋市青塚', '08', '08222', '3112211', '茨城県', 'イバラキケン', '鹿嶋市', 'カシマシ', '青塚', 'アオツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鹿嶋市角折', '08', '08222', '3112212', '茨城県', 'イバラキケン', '鹿嶋市', 'カシマシ', '角折', 'ツノオレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鹿嶋市中', '08', '08222', '3112213', '茨城県', 'イバラキケン', '鹿嶋市', 'カシマシ', '中', 'ナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鹿嶋市棚木', '08', '08222', '3112214', '茨城県', 'イバラキケン', '鹿嶋市', 'カシマシ', '棚木', 'タナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鹿嶋市和', '08', '08222', '3112215', '茨城県', 'イバラキケン', '鹿嶋市', 'カシマシ', '和', 'カズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鹿嶋市荒野', '08', '08222', '3112221', '茨城県', 'イバラキケン', '鹿嶋市', 'カシマシ', '荒野', 'コウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鹿嶋市小山', '08', '08222', '3112222', '茨城県', 'イバラキケン', '鹿嶋市', 'カシマシ', '小山', 'コヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鹿嶋市林', '08', '08222', '3112223', '茨城県', 'イバラキケン', '鹿嶋市', 'カシマシ', '林', 'ハヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鹿嶋市奈良毛', '08', '08222', '3112224', '茨城県', 'イバラキケン', '鹿嶋市', 'カシマシ', '奈良毛', 'ナラゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県潮来市', '08', '08223', '3112400', '茨城県', 'イバラキケン', '潮来市', 'イタコシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('22614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県潮来市大賀', '08', '08223', '3112401', '茨城県', 'イバラキケン', '潮来市', 'イタコシ', '大賀', 'オオガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県潮来市大生', '08', '08223', '3112402', '茨城県', 'イバラキケン', '潮来市', 'イタコシ', '大生', 'オオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県潮来市釜谷', '08', '08223', '3112403', '茨城県', 'イバラキケン', '潮来市', 'イタコシ', '釜谷', 'カマヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県潮来市水原', '08', '08223', '3112404', '茨城県', 'イバラキケン', '潮来市', 'イタコシ', '水原', 'ミズハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県潮来市築地', '08', '08223', '3112405', '茨城県', 'イバラキケン', '潮来市', 'イタコシ', '築地', 'ツイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県潮来市新宮', '08', '08223', '3112406', '茨城県', 'イバラキケン', '潮来市', 'イタコシ', '新宮', 'シングウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県潮来市下田', '08', '08223', '3112407', '茨城県', 'イバラキケン', '潮来市', 'イタコシ', '下田', 'シタダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県潮来市洲崎', '08', '08223', '3112408', '茨城県', 'イバラキケン', '潮来市', 'イタコシ', '洲崎', 'スサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県潮来市延方東', '08', '08223', '3112409', '茨城県', 'イバラキケン', '潮来市', 'イタコシ', '延方東', 'ノブカタヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県潮来市延方西', '08', '08223', '3112410', '茨城県', 'イバラキケン', '潮来市', 'イタコシ', '延方西', 'ノブカタニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県潮来市宮前', '08', '08223', '3112412', '茨城県', 'イバラキケン', '潮来市', 'イタコシ', '宮前', 'ミヤマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県潮来市延方', '08', '08223', '3112415', '茨城県', 'イバラキケン', '潮来市', 'イタコシ', '延方', 'ノブカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県潮来市前川', '08', '08223', '3112416', '茨城県', 'イバラキケン', '潮来市', 'イタコシ', '前川', 'マエカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県潮来市米島', '08', '08223', '3112417', '茨城県', 'イバラキケン', '潮来市', 'イタコシ', '米島', 'ヨネジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県潮来市徳島', '08', '08223', '3112418', '茨城県', 'イバラキケン', '潮来市', 'イタコシ', '徳島', 'トクシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県潮来市福島', '08', '08223', '3112419', '茨城県', 'イバラキケン', '潮来市', 'イタコシ', '福島', 'フクシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県潮来市辻', '08', '08223', '3112421', '茨城県', 'イバラキケン', '潮来市', 'イタコシ', '辻', 'ツジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県潮来市大洲', '08', '08223', '3112422', '茨城県', 'イバラキケン', '潮来市', 'イタコシ', '大洲', 'オオス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県潮来市日の出', '08', '08223', '3112423', '茨城県', 'イバラキケン', '潮来市', 'イタコシ', '日の出', 'ヒノデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県潮来市潮来', '08', '08223', '3112424', '茨城県', 'イバラキケン', '潮来市', 'イタコシ', '潮来', 'イタコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県潮来市あやめ', '08', '08223', '3112425', '茨城県', 'イバラキケン', '潮来市', 'イタコシ', 'あやめ', 'アヤメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県潮来市大塚野', '08', '08223', '3112426', '茨城県', 'イバラキケン', '潮来市', 'イタコシ', '大塚野', 'オオツカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県潮来市清水', '08', '08223', '3112431', '茨城県', 'イバラキケン', '潮来市', 'イタコシ', '清水', 'キヨミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県潮来市茂木', '08', '08223', '3112432', '茨城県', 'イバラキケン', '潮来市', 'イタコシ', '茂木', 'モトギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県潮来市堀之内', '08', '08223', '3112433', '茨城県', 'イバラキケン', '潮来市', 'イタコシ', '堀之内', 'ホリノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県潮来市島須', '08', '08223', '3112434', '茨城県', 'イバラキケン', '潮来市', 'イタコシ', '島須', 'シマス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県潮来市上戸', '08', '08223', '3112435', '茨城県', 'イバラキケン', '潮来市', 'イタコシ', '上戸', 'ウワト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県潮来市牛堀', '08', '08223', '3112436', '茨城県', 'イバラキケン', '潮来市', 'イタコシ', '牛堀', 'ウシボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県潮来市永山', '08', '08223', '3112437', '茨城県', 'イバラキケン', '潮来市', 'イタコシ', '永山', 'ナガヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県潮来市川尾', '08', '08223', '3112440', '茨城県', 'イバラキケン', '潮来市', 'イタコシ', '川尾', 'カワオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県潮来市大山', '08', '08223', '3112441', '茨城県', 'イバラキケン', '潮来市', 'イタコシ', '大山', 'オオヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県潮来市小泉', '08', '08223', '3112442', '茨城県', 'イバラキケン', '潮来市', 'イタコシ', '小泉', 'コイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県潮来市新宮南', '08', '08223', '3112443', '茨城県', 'イバラキケン', '潮来市', 'イタコシ', '新宮南', 'シングウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県潮来市小泉南', '08', '08223', '3112444', '茨城県', 'イバラキケン', '潮来市', 'イタコシ', '小泉南', 'コイズミミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県潮来市曲松南', '08', '08223', '3112445', '茨城県', 'イバラキケン', '潮来市', 'イタコシ', '曲松南', 'マガリマツミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県潮来市須賀南', '08', '08223', '3112446', '茨城県', 'イバラキケン', '潮来市', 'イタコシ', '須賀南', 'スカミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県潮来市曲松', '08', '08223', '3112447', '茨城県', 'イバラキケン', '潮来市', 'イタコシ', '曲松', 'マガリマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県潮来市須賀', '08', '08223', '3112448', '茨城県', 'イバラキケン', '潮来市', 'イタコシ', '須賀', 'スカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県潮来市古高', '08', '08223', '3112449', '茨城県', 'イバラキケン', '潮来市', 'イタコシ', '古高', 'フッタカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県東茨城郡茨城町', '08', '08302', '3113100', '茨城県', 'イバラキケン', '東茨城郡茨城町', 'ヒガシイバラキグンイバラキマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('22657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県東茨城郡茨城町南川又', '08', '08302', '3113101', '茨城県', 'イバラキケン', '東茨城郡茨城町', 'ヒガシイバラキグンイバラキマチ', '南川又', 'ミナミカワマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県東茨城郡茨城町南栗崎', '08', '08302', '3113102', '茨城県', 'イバラキケン', '東茨城郡茨城町', 'ヒガシイバラキグンイバラキマチ', '南栗崎', 'ミナミクリザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県東茨城郡茨城町野曽', '08', '08302', '3113103', '茨城県', 'イバラキケン', '東茨城郡茨城町', 'ヒガシイバラキグンイバラキマチ', '野曽', 'ノソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県東茨城郡茨城町駒渡', '08', '08302', '3113104', '茨城県', 'イバラキケン', '東茨城郡茨城町', 'ヒガシイバラキグンイバラキマチ', '駒渡', 'コマワタリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県東茨城郡茨城町蕎麦原', '08', '08302', '3113105', '茨城県', 'イバラキケン', '東茨城郡茨城町', 'ヒガシイバラキグンイバラキマチ', '蕎麦原', 'ソバハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県東茨城郡茨城町越安', '08', '08302', '3113106', '茨城県', 'イバラキケン', '東茨城郡茨城町', 'ヒガシイバラキグンイバラキマチ', '越安', 'コヤス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県東茨城郡茨城町小鶴', '08', '08302', '3113107', '茨城県', 'イバラキケン', '東茨城郡茨城町', 'ヒガシイバラキグンイバラキマチ', '小鶴', 'コヅル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県東茨城郡茨城町中央工業団地', '08', '08302', '3113108', '茨城県', 'イバラキケン', '東茨城郡茨城町', 'ヒガシイバラキグンイバラキマチ', '中央工業団地', 'チュウオウコウギョウダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県東茨城郡茨城町馬渡', '08', '08302', '3113111', '茨城県', 'イバラキケン', '東茨城郡茨城町', 'ヒガシイバラキグンイバラキマチ', '馬渡', 'ウマワタリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県東茨城郡茨城町常井', '08', '08302', '3113112', '茨城県', 'イバラキケン', '東茨城郡茨城町', 'ヒガシイバラキグンイバラキマチ', '常井', 'トコイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県東茨城郡茨城町近藤', '08', '08302', '3113113', '茨城県', 'イバラキケン', '東茨城郡茨城町', 'ヒガシイバラキグンイバラキマチ', '近藤', 'コンドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県東茨城郡茨城町大戸', '08', '08302', '3113114', '茨城県', 'イバラキケン', '東茨城郡茨城町', 'ヒガシイバラキグンイバラキマチ', '大戸', 'オオド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県東茨城郡茨城町前田', '08', '08302', '3113115', '茨城県', 'イバラキケン', '東茨城郡茨城町', 'ヒガシイバラキグンイバラキマチ', '前田', 'マエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県東茨城郡茨城町長岡', '08', '08302', '3113116', '茨城県', 'イバラキケン', '東茨城郡茨城町', 'ヒガシイバラキグンイバラキマチ', '長岡', 'ナガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県東茨城郡茨城町桜の郷', '08', '08302', '3113117', '茨城県', 'イバラキケン', '東茨城郡茨城町', 'ヒガシイバラキグンイバラキマチ', '桜の郷', 'サクラノサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県東茨城郡茨城町谷田部', '08', '08302', '3113121', '茨城県', 'イバラキケン', '東茨城郡茨城町', 'ヒガシイバラキグンイバラキマチ', '谷田部', 'ヤタベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県東茨城郡茨城町上石崎', '08', '08302', '3113122', '茨城県', 'イバラキケン', '東茨城郡茨城町', 'ヒガシイバラキグンイバラキマチ', '上石崎', 'カミイシザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県東茨城郡茨城町若宮', '08', '08302', '3113123', '茨城県', 'イバラキケン', '東茨城郡茨城町', 'ヒガシイバラキグンイバラキマチ', '若宮', 'ワカミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県東茨城郡茨城町中石崎', '08', '08302', '3113124', '茨城県', 'イバラキケン', '東茨城郡茨城町', 'ヒガシイバラキグンイバラキマチ', '中石崎', 'ナカイシザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県東茨城郡茨城町下石崎', '08', '08302', '3113125', '茨城県', 'イバラキケン', '東茨城郡茨城町', 'ヒガシイバラキグンイバラキマチ', '下石崎', 'シモイシザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県東茨城郡茨城町小堤', '08', '08302', '3113131', '茨城県', 'イバラキケン', '東茨城郡茨城町', 'ヒガシイバラキグンイバラキマチ', '小堤', 'オヅツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県東茨城郡茨城町駒場', '08', '08302', '3113132', '茨城県', 'イバラキケン', '東茨城郡茨城町', 'ヒガシイバラキグンイバラキマチ', '駒場', 'コマバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県東茨城郡茨城町南島田', '08', '08302', '3113133', '茨城県', 'イバラキケン', '東茨城郡茨城町', 'ヒガシイバラキグンイバラキマチ', '南島田', 'ミナミシマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県東茨城郡茨城町神宿', '08', '08302', '3113134', '茨城県', 'イバラキケン', '東茨城郡茨城町', 'ヒガシイバラキグンイバラキマチ', '神宿', 'カミヤド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県東茨城郡茨城町海老沢', '08', '08302', '3113135', '茨城県', 'イバラキケン', '東茨城郡茨城町', 'ヒガシイバラキグンイバラキマチ', '海老沢', 'エビサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県東茨城郡茨城町宮ケ崎', '08', '08302', '3113136', '茨城県', 'イバラキケン', '東茨城郡茨城町', 'ヒガシイバラキグンイバラキマチ', '宮ケ崎', 'ミヤガサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県東茨城郡茨城町網掛', '08', '08302', '3113137', '茨城県', 'イバラキケン', '東茨城郡茨城町', 'ヒガシイバラキグンイバラキマチ', '網掛', 'アガケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県東茨城郡茨城町城之内', '08', '08302', '3113138', '茨城県', 'イバラキケン', '東茨城郡茨城町', 'ヒガシイバラキグンイバラキマチ', '城之内', 'ジョウノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県東茨城郡茨城町神谷', '08', '08302', '3113141', '茨城県', 'イバラキケン', '東茨城郡茨城町', 'ヒガシイバラキグンイバラキマチ', '神谷', 'カンヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県東茨城郡茨城町鳥羽田', '08', '08302', '3113142', '茨城県', 'イバラキケン', '東茨城郡茨城町', 'ヒガシイバラキグンイバラキマチ', '鳥羽田', 'トリハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県東茨城郡茨城町生井沢', '08', '08302', '3113143', '茨城県', 'イバラキケン', '東茨城郡茨城町', 'ヒガシイバラキグンイバラキマチ', '生井沢', 'ナマイザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県東茨城郡茨城町下雨ケ谷', '08', '08302', '3113144', '茨城県', 'イバラキケン', '東茨城郡茨城町', 'ヒガシイバラキグンイバラキマチ', '下雨ケ谷', 'シモアマガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県東茨城郡茨城町上雨ケ谷', '08', '08302', '3113145', '茨城県', 'イバラキケン', '東茨城郡茨城町', 'ヒガシイバラキグンイバラキマチ', '上雨ケ谷', 'カミアマガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県東茨城郡茨城町下座', '08', '08302', '3113146', '茨城県', 'イバラキケン', '東茨城郡茨城町', 'ヒガシイバラキグンイバラキマチ', '下座', 'ゲザ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県東茨城郡茨城町秋葉', '08', '08302', '3113147', '茨城県', 'イバラキケン', '東茨城郡茨城町', 'ヒガシイバラキグンイバラキマチ', '秋葉', 'アキバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県東茨城郡茨城町木部', '08', '08302', '3113151', '茨城県', 'イバラキケン', '東茨城郡茨城町', 'ヒガシイバラキグンイバラキマチ', '木部', 'キベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県東茨城郡茨城町飯沼', '08', '08302', '3113152', '茨城県', 'イバラキケン', '東茨城郡茨城町', 'ヒガシイバラキグンイバラキマチ', '飯沼', 'イイヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県東茨城郡茨城町上飯沼', '08', '08302', '3113153', '茨城県', 'イバラキケン', '東茨城郡茨城町', 'ヒガシイバラキグンイバラキマチ', '上飯沼', 'カミイイヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県東茨城郡茨城町下飯沼', '08', '08302', '3113154', '茨城県', 'イバラキケン', '東茨城郡茨城町', 'ヒガシイバラキグンイバラキマチ', '下飯沼', 'シモイイヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県東茨城郡茨城町下土師', '08', '08302', '3113155', '茨城県', 'イバラキケン', '東茨城郡茨城町', 'ヒガシイバラキグンイバラキマチ', '下土師', 'シモハジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県東茨城郡茨城町奥谷', '08', '08302', '3113156', '茨城県', 'イバラキケン', '東茨城郡茨城町', 'ヒガシイバラキグンイバラキマチ', '奥谷', 'オクノヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県東茨城郡茨城町小幡', '08', '08302', '3113157', '茨城県', 'イバラキケン', '東茨城郡茨城町', 'ヒガシイバラキグンイバラキマチ', '小幡', 'オバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県小美玉市世楽', '08', '08236', '3113401', '茨城県', 'イバラキケン', '小美玉市', 'オミタマシ', '世楽', 'セラク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県小美玉市佐才', '08', '08236', '3113402', '茨城県', 'イバラキケン', '小美玉市', 'オミタマシ', '佐才', 'サザイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県小美玉市上吉影', '08', '08236', '3113403', '茨城県', 'イバラキケン', '小美玉市', 'オミタマシ', '上吉影', 'カミヨシカゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県小美玉市飯前', '08', '08236', '3113404', '茨城県', 'イバラキケン', '小美玉市', 'オミタマシ', '飯前', 'イイサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県小美玉市上合', '08', '08236', '3113405', '茨城県', 'イバラキケン', '小美玉市', 'オミタマシ', '上合', 'カミアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県小美玉市下吉影', '08', '08236', '3113406', '茨城県', 'イバラキケン', '小美玉市', 'オミタマシ', '下吉影', 'シモヨシカゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県小美玉市野田', '08', '08236', '3113411', '茨城県', 'イバラキケン', '小美玉市', 'オミタマシ', '野田', 'ノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県小美玉市川戸', '08', '08236', '3113412', '茨城県', 'イバラキケン', '小美玉市', 'オミタマシ', '川戸', 'カワド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県小美玉市山野', '08', '08236', '3113413', '茨城県', 'イバラキケン', '小美玉市', 'オミタマシ', '山野', 'ヤマノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県小美玉市外之内', '08', '08236', '3113414', '茨城県', 'イバラキケン', '小美玉市', 'オミタマシ', '外之内', 'トノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県小美玉市百里', '08', '08236', '3113415', '茨城県', 'イバラキケン', '小美玉市', 'オミタマシ', '百里', 'ヒャクリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県小美玉市与沢', '08', '08236', '3113416', '茨城県', 'イバラキケン', '小美玉市', 'オミタマシ', '与沢', 'ヨザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県小美玉市倉数', '08', '08236', '3113417', '茨城県', 'イバラキケン', '小美玉市', 'オミタマシ', '倉数', 'クラカズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県小美玉市宮田', '08', '08236', '3113421', '茨城県', 'イバラキケン', '小美玉市', 'オミタマシ', '宮田', 'ミヤタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県小美玉市中延', '08', '08236', '3113422', '茨城県', 'イバラキケン', '小美玉市', 'オミタマシ', '中延', 'ナカノベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県小美玉市小川', '08', '08236', '3113423', '茨城県', 'イバラキケン', '小美玉市', 'オミタマシ', '小川', 'オガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県小美玉市幡谷', '08', '08236', '3113424', '茨城県', 'イバラキケン', '小美玉市', 'オミタマシ', '幡谷', 'ハタヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県小美玉市小塙', '08', '08236', '3113425', '茨城県', 'イバラキケン', '小美玉市', 'オミタマシ', '小塙', 'コバナワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県小美玉市下馬場', '08', '08236', '3113426', '茨城県', 'イバラキケン', '小美玉市', 'オミタマシ', '下馬場', 'シモババ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県小美玉市川中子', '08', '08236', '3113431', '茨城県', 'イバラキケン', '小美玉市', 'オミタマシ', '川中子', 'カワナゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県小美玉市下玉里', '08', '08236', '3113432', '茨城県', 'イバラキケン', '小美玉市', 'オミタマシ', '下玉里', 'シモタマリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県小美玉市高崎', '08', '08236', '3113433', '茨城県', 'イバラキケン', '小美玉市', 'オミタマシ', '高崎', 'タカサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県小美玉市栗又四ケ', '08', '08236', '3113434', '茨城県', 'イバラキケン', '小美玉市', 'オミタマシ', '栗又四ケ', 'クリマタシカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県小美玉市田木谷', '08', '08236', '3113435', '茨城県', 'イバラキケン', '小美玉市', 'オミタマシ', '田木谷', 'タギヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県小美玉市上玉里', '08', '08236', '3113436', '茨城県', 'イバラキケン', '小美玉市', 'オミタマシ', '上玉里', 'カミタマリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県小美玉市東田中', '08', '08236', '3113437', '茨城県', 'イバラキケン', '小美玉市', 'オミタマシ', '東田中', 'ヒガシタナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県行方市芹沢', '08', '08233', '3113501', '茨城県', 'イバラキケン', '行方市', 'ナメガタシ', '芹沢', 'セリザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県行方市若海', '08', '08233', '3113502', '茨城県', 'イバラキケン', '行方市', 'ナメガタシ', '若海', 'ワカウミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県行方市捻木', '08', '08233', '3113503', '茨城県', 'イバラキケン', '行方市', 'ナメガタシ', '捻木', 'ネジキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県行方市谷島', '08', '08233', '3113504', '茨城県', 'イバラキケン', '行方市', 'ナメガタシ', '谷島', 'ヤジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県行方市浜', '08', '08233', '3113505', '茨城県', 'イバラキケン', '行方市', 'ナメガタシ', '浜', 'ハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県行方市八木蒔', '08', '08233', '3113506', '茨城県', 'イバラキケン', '行方市', 'ナメガタシ', '八木蒔', 'ヤキマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県行方市羽生', '08', '08233', '3113507', '茨城県', 'イバラキケン', '行方市', 'ナメガタシ', '羽生', 'ハニュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県行方市沖洲', '08', '08233', '3113508', '茨城県', 'イバラキケン', '行方市', 'ナメガタシ', '沖洲', 'オキス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県行方市玉造乙', '08', '08233', '3113511', '茨城県', 'イバラキケン', '行方市', 'ナメガタシ', '玉造乙', 'タマツクリオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県行方市玉造甲', '08', '08233', '3113512', '茨城県', 'イバラキケン', '行方市', 'ナメガタシ', '玉造甲', 'タマツクリコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県行方市手賀', '08', '08233', '3113513', '茨城県', 'イバラキケン', '行方市', 'ナメガタシ', '手賀', 'テガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県行方市西蓮寺', '08', '08233', '3113514', '茨城県', 'イバラキケン', '行方市', 'ナメガタシ', '西蓮寺', 'サイレンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県行方市井上', '08', '08233', '3113515', '茨城県', 'イバラキケン', '行方市', 'ナメガタシ', '井上', 'イノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県行方市井上藤井', '08', '08233', '3113516', '茨城県', 'イバラキケン', '行方市', 'ナメガタシ', '井上藤井', 'イノウエフジイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県行方市藤井', '08', '08233', '3113517', '茨城県', 'イバラキケン', '行方市', 'ナメガタシ', '藤井', 'フジイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県行方市荒宿', '08', '08233', '3113518', '茨城県', 'イバラキケン', '行方市', 'ナメガタシ', '荒宿', 'アラジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県行方市', '08', '08233', '3113800', '茨城県', 'イバラキケン', '行方市', 'ナメガタシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('22752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県行方市行方', '08', '08233', '3113801', '茨城県', 'イバラキケン', '行方市', 'ナメガタシ', '行方', 'ナメカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県行方市於下', '08', '08233', '3113802', '茨城県', 'イバラキケン', '行方市', 'ナメガタシ', '於下', 'オシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県行方市井貝', '08', '08233', '3113803', '茨城県', 'イバラキケン', '行方市', 'ナメガタシ', '井貝', 'イガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県行方市小高', '08', '08233', '3113804', '茨城県', 'イバラキケン', '行方市', 'ナメガタシ', '小高', 'オダカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県行方市橋門', '08', '08233', '3113805', '茨城県', 'イバラキケン', '行方市', 'ナメガタシ', '橋門', 'ハシカド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県行方市船子', '08', '08233', '3113806', '茨城県', 'イバラキケン', '行方市', 'ナメガタシ', '船子', 'フナコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県行方市五町田', '08', '08233', '3113807', '茨城県', 'イバラキケン', '行方市', 'ナメガタシ', '五町田', 'ゴチョウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県行方市四鹿', '08', '08233', '3113811', '茨城県', 'イバラキケン', '行方市', 'ナメガタシ', '四鹿', 'シロク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県行方市杉平', '08', '08233', '3113812', '茨城県', 'イバラキケン', '行方市', 'ナメガタシ', '杉平', 'スギダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県行方市籠田', '08', '08233', '3113813', '茨城県', 'イバラキケン', '行方市', 'ナメガタシ', '籠田', 'コモタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県行方市天掛', '08', '08233', '3113814', '茨城県', 'イバラキケン', '行方市', 'ナメガタシ', '天掛', 'アマガケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県行方市新宮', '08', '08233', '3113815', '茨城県', 'イバラキケン', '行方市', 'ナメガタシ', '新宮', 'シングウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県行方市小牧', '08', '08233', '3113816', '茨城県', 'イバラキケン', '行方市', 'ナメガタシ', '小牧', 'コマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県行方市板峰', '08', '08233', '3113817', '茨城県', 'イバラキケン', '行方市', 'ナメガタシ', '板峰', 'イタノミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県行方市蔵川', '08', '08233', '3113821', '茨城県', 'イバラキケン', '行方市', 'ナメガタシ', '蔵川', 'クラカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県行方市岡', '08', '08233', '3113822', '茨城県', 'イバラキケン', '行方市', 'ナメガタシ', '岡', 'オカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県行方市白浜', '08', '08233', '3113823', '茨城県', 'イバラキケン', '行方市', 'ナメガタシ', '白浜', 'シラハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県行方市宇崎', '08', '08233', '3113824', '茨城県', 'イバラキケン', '行方市', 'ナメガタシ', '宇崎', 'ウザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県行方市根小屋', '08', '08233', '3113825', '茨城県', 'イバラキケン', '行方市', 'ナメガタシ', '根小屋', 'ネゴヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県行方市矢幡', '08', '08233', '3113826', '茨城県', 'イバラキケン', '行方市', 'ナメガタシ', '矢幡', 'ヤバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県行方市石神', '08', '08233', '3113827', '茨城県', 'イバラキケン', '行方市', 'ナメガタシ', '石神', 'イシガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県行方市青沼', '08', '08233', '3113831', '茨城県', 'イバラキケン', '行方市', 'ナメガタシ', '青沼', 'アオヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県行方市麻生', '08', '08233', '3113832', '茨城県', 'イバラキケン', '行方市', 'ナメガタシ', '麻生', 'アソウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県行方市富田', '08', '08233', '3113833', '茨城県', 'イバラキケン', '行方市', 'ナメガタシ', '富田', 'トミタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県行方市粗毛', '08', '08233', '3113834', '茨城県', 'イバラキケン', '行方市', 'ナメガタシ', '粗毛', 'ホボケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県行方市島並', '08', '08233', '3113835', '茨城県', 'イバラキケン', '行方市', 'ナメガタシ', '島並', 'シマナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県行方市南', '08', '08233', '3113836', '茨城県', 'イバラキケン', '行方市', 'ナメガタシ', '南', 'ミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市赤塚', '08', '08201', '3114141', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '赤塚', 'アカツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市東赤塚', '08', '08201', '3114142', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '東赤塚', 'ヒガシアカツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市大塚町', '08', '08201', '3114143', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '大塚町', 'オオツカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市開江町', '08', '08201', '3114144', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '開江町', 'ヒラクエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市双葉台', '08', '08201', '3114145', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '双葉台', 'フタバダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市中丸町', '08', '08201', '3114146', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '中丸町', 'ナカマルチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市姫子', '08', '08201', '3114151', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '姫子', 'ヒメゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市河和田', '08', '08201', '3114152', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '河和田', 'カワワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市河和田町', '08', '08201', '3114153', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '河和田町', 'カワワダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市萱場町', '08', '08201', '3114154', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '萱場町', 'カヤバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市飯島町', '08', '08201', '3114155', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '飯島町', 'イイジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市全隈町', '08', '08201', '3114161', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '全隈町', 'マタグマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市金谷町', '08', '08201', '3114162', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '金谷町', 'カナヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市加倉井町', '08', '08201', '3114163', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '加倉井町', 'カクライチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市谷津町', '08', '08201', '3114164', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '谷津町', 'ヤツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市木葉下町', '08', '08201', '3114165', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '木葉下町', 'アボッケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市藤井町', '08', '08201', '3114201', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '藤井町', 'フジイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市岩根町', '08', '08201', '3114202', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '岩根町', 'イワネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市上国井町', '08', '08201', '3114203', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '上国井町', 'カミクニイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市田谷町', '08', '08201', '3114204', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '田谷町', 'タヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市下国井町', '08', '08201', '3114205', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '下国井町', 'シモクニイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市飯富町', '08', '08201', '3114206', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '飯富町', 'イイトミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市成沢町', '08', '08201', '3114207', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '成沢町', 'ナルサワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市藤が原', '08', '08201', '3114208', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '藤が原', 'フジガハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県東茨城郡城里町', '08', '08310', '3114300', '茨城県', 'イバラキケン', '東茨城郡城里町', 'ヒガシイバラキグンシロサトマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('22812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県東茨城郡城里町上泉', '08', '08310', '3114301', '茨城県', 'イバラキケン', '東茨城郡城里町', 'ヒガシイバラキグンシロサトマチ', '上泉', 'カミイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県東茨城郡城里町那珂西', '08', '08310', '3114302', '茨城県', 'イバラキケン', '東茨城郡城里町', 'ヒガシイバラキグンシロサトマチ', '那珂西', 'ナカサイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県東茨城郡城里町石塚', '08', '08310', '3114303', '茨城県', 'イバラキケン', '東茨城郡城里町', 'ヒガシイバラキグンシロサトマチ', '石塚', 'イシツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県東茨城郡城里町下青山', '08', '08310', '3114304', '茨城県', 'イバラキケン', '東茨城郡城里町', 'ヒガシイバラキグンシロサトマチ', '下青山', 'シモアオヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県東茨城郡城里町上青山', '08', '08310', '3114305', '茨城県', 'イバラキケン', '東茨城郡城里町', 'ヒガシイバラキグンシロサトマチ', '上青山', 'カミアオヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県東茨城郡城里町春園', '08', '08310', '3114306', '茨城県', 'イバラキケン', '東茨城郡城里町', 'ヒガシイバラキグンシロサトマチ', '春園', 'ハルソノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県東茨城郡城里町増井', '08', '08310', '3114311', '茨城県', 'イバラキケン', '東茨城郡城里町', 'ヒガシイバラキグンシロサトマチ', '増井', 'マシイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県東茨城郡城里町磯野', '08', '08310', '3114312', '茨城県', 'イバラキケン', '東茨城郡城里町', 'ヒガシイバラキグンシロサトマチ', '磯野', 'イソノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県東茨城郡城里町上入野', '08', '08310', '3114313', '茨城県', 'イバラキケン', '東茨城郡城里町', 'ヒガシイバラキグンシロサトマチ', '上入野', 'カミイリノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県東茨城郡城里町下古内', '08', '08310', '3114314', '茨城県', 'イバラキケン', '東茨城郡城里町', 'ヒガシイバラキグンシロサトマチ', '下古内', 'シモフルウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県東茨城郡城里町上古内', '08', '08310', '3114315', '茨城県', 'イバラキケン', '東茨城郡城里町', 'ヒガシイバラキグンシロサトマチ', '上古内', 'カミフルウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県東茨城郡城里町小坂', '08', '08310', '3114316', '茨城県', 'イバラキケン', '東茨城郡城里町', 'ヒガシイバラキグンシロサトマチ', '小坂', 'オサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県東茨城郡城里町勝見沢', '08', '08310', '3114317', '茨城県', 'イバラキケン', '東茨城郡城里町', 'ヒガシイバラキグンシロサトマチ', '勝見沢', 'カツミザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県東茨城郡城里町粟', '08', '08310', '3114321', '茨城県', 'イバラキケン', '東茨城郡城里町', 'ヒガシイバラキグンシロサトマチ', '粟', 'アワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県東茨城郡城里町下圷', '08', '08310', '3114322', '茨城県', 'イバラキケン', '東茨城郡城里町', 'ヒガシイバラキグンシロサトマチ', '下圷', 'シモアクツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県東茨城郡城里町上圷', '08', '08310', '3114323', '茨城県', 'イバラキケン', '東茨城郡城里町', 'ヒガシイバラキグンシロサトマチ', '上圷', 'カミアクツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県東茨城郡城里町高久', '08', '08310', '3114324', '茨城県', 'イバラキケン', '東茨城郡城里町', 'ヒガシイバラキグンシロサトマチ', '高久', 'タカク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県東茨城郡城里町北方', '08', '08310', '3114325', '茨城県', 'イバラキケン', '東茨城郡城里町', 'ヒガシイバラキグンシロサトマチ', '北方', 'キタカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県東茨城郡城里町岩船', '08', '08310', '3114331', '茨城県', 'イバラキケン', '東茨城郡城里町', 'ヒガシイバラキグンシロサトマチ', '岩船', 'イワフネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県東茨城郡城里町高根台', '08', '08310', '3114332', '茨城県', 'イバラキケン', '東茨城郡城里町', 'ヒガシイバラキグンシロサトマチ', '高根台', 'タカネダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県東茨城郡城里町高根', '08', '08310', '3114333', '茨城県', 'イバラキケン', '東茨城郡城里町', 'ヒガシイバラキグンシロサトマチ', '高根', 'タカネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県東茨城郡城里町孫根', '08', '08310', '3114334', '茨城県', 'イバラキケン', '東茨城郡城里町', 'ヒガシイバラキグンシロサトマチ', '孫根', 'マゴネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県東茨城郡城里町錫高野', '08', '08310', '3114335', '茨城県', 'イバラキケン', '東茨城郡城里町', 'ヒガシイバラキグンシロサトマチ', '錫高野', 'スズコウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県東茨城郡城里町御前山', '08', '08310', '3114341', '茨城県', 'イバラキケン', '東茨城郡城里町', 'ヒガシイバラキグンシロサトマチ', '御前山', 'ゴゼンヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県東茨城郡城里町上阿野沢', '08', '08310', '3114342', '茨城県', 'イバラキケン', '東茨城郡城里町', 'ヒガシイバラキグンシロサトマチ', '上阿野沢', 'カミアノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県東茨城郡城里町下阿野沢', '08', '08310', '3114343', '茨城県', 'イバラキケン', '東茨城郡城里町', 'ヒガシイバラキグンシロサトマチ', '下阿野沢', 'シモアノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県東茨城郡城里町阿波山', '08', '08310', '3114344', '茨城県', 'イバラキケン', '東茨城郡城里町', 'ヒガシイバラキグンシロサトマチ', '阿波山', 'アワヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県東茨城郡城里町塩子', '08', '08310', '3114401', '茨城県', 'イバラキケン', '東茨城郡城里町', 'ヒガシイバラキグンシロサトマチ', '塩子', 'シオゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県東茨城郡城里町小勝', '08', '08310', '3114402', '茨城県', 'イバラキケン', '東茨城郡城里町', 'ヒガシイバラキグンシロサトマチ', '小勝', 'オガチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県東茨城郡城里町大網', '08', '08310', '3114403', '茨城県', 'イバラキケン', '東茨城郡城里町', 'ヒガシイバラキグンシロサトマチ', '大網', 'オオアミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県東茨城郡城里町真端', '08', '08310', '3114404', '茨城県', 'イバラキケン', '東茨城郡城里町', 'ヒガシイバラキグンシロサトマチ', '真端', 'サナバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県東茨城郡城里町上赤沢', '08', '08310', '3114405', '茨城県', 'イバラキケン', '東茨城郡城里町', 'ヒガシイバラキグンシロサトマチ', '上赤沢', 'カミアカサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県東茨城郡城里町下赤沢', '08', '08310', '3114406', '茨城県', 'イバラキケン', '東茨城郡城里町', 'ヒガシイバラキグンシロサトマチ', '下赤沢', 'シモアカサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県東茨城郡城里町徳蔵', '08', '08310', '3114407', '茨城県', 'イバラキケン', '東茨城郡城里町', 'ヒガシイバラキグンシロサトマチ', '徳蔵', 'トクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県芳賀郡茂木町桧山道木橋', '09', '09343', '3114411', '栃木県', 'トチギケン', '芳賀郡茂木町', 'ハガグンモテギマチ', '桧山', 'ヒヤマ', null, null, '道木橋', 'ドウギバシ');
INSERT INTO `ms_addresses` VALUES ('22850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸大宮市門井', '08', '08225', '3114501', '茨城県', 'イバラキケン', '常陸大宮市', 'ヒタチオオミヤシ', '門井', 'カドイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸大宮市野口平', '08', '08225', '3114502', '茨城県', 'イバラキケン', '常陸大宮市', 'ヒタチオオミヤシ', '野口平', 'ノグチダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸大宮市野口', '08', '08225', '3114503', '茨城県', 'イバラキケン', '常陸大宮市', 'ヒタチオオミヤシ', '野口', 'ノグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸大宮市秋田', '08', '08225', '3114611', '茨城県', 'イバラキケン', '常陸大宮市', 'ヒタチオオミヤシ', '秋田', 'アキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸大宮市中居', '08', '08225', '3114612', '茨城県', 'イバラキケン', '常陸大宮市', 'ヒタチオオミヤシ', '中居', 'ナカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸大宮市長倉', '08', '08225', '3114613', '茨城県', 'イバラキケン', '常陸大宮市', 'ヒタチオオミヤシ', '長倉', 'ナガクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸大宮市金井', '08', '08225', '3114614', '茨城県', 'イバラキケン', '常陸大宮市', 'ヒタチオオミヤシ', '金井', 'カナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸大宮市下伊勢畑', '08', '08225', '3114615', '茨城県', 'イバラキケン', '常陸大宮市', 'ヒタチオオミヤシ', '下伊勢畑', 'シモイセハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸大宮市桧山', '08', '08225', '3114616', '茨城県', 'イバラキケン', '常陸大宮市', 'ヒタチオオミヤシ', '桧山', 'ヒヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸大宮市上伊勢畑', '08', '08225', '3114617', '茨城県', 'イバラキケン', '常陸大宮市', 'ヒタチオオミヤシ', '上伊勢畑', 'カミイセハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸大宮市野田', '08', '08225', '3114618', '茨城県', 'イバラキケン', '常陸大宮市', 'ヒタチオオミヤシ', '野田', 'ノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県ひたちなか市', '08', '08221', '3120000', '茨城県', 'イバラキケン', 'ひたちなか市', 'ヒタチナカシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('22864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県ひたちなか市佐和', '08', '08221', '3120001', '茨城県', 'イバラキケン', 'ひたちなか市', 'ヒタチナカシ', '佐和', 'サワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県ひたちなか市高野', '08', '08221', '3120002', '茨城県', 'イバラキケン', 'ひたちなか市', 'ヒタチナカシ', '高野', 'コウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県ひたちなか市足崎', '08', '08221', '3120003', '茨城県', 'イバラキケン', 'ひたちなか市', 'ヒタチナカシ', '足崎', 'タラザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県ひたちなか市長砂', '08', '08221', '3120004', '茨城県', 'イバラキケン', 'ひたちなか市', 'ヒタチナカシ', '長砂', 'ナガスナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県ひたちなか市新光町', '08', '08221', '3120005', '茨城県', 'イバラキケン', 'ひたちなか市', 'ヒタチナカシ', '新光町', 'シンコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県ひたちなか市前浜', '08', '08221', '3120006', '茨城県', 'イバラキケン', 'ひたちなか市', 'ヒタチナカシ', '前浜', 'マエハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県ひたちなか市小貫山', '08', '08221', '3120007', '茨城県', 'イバラキケン', 'ひたちなか市', 'ヒタチナカシ', '小貫山', 'オヌキヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県ひたちなか市中根', '08', '08221', '3120011', '茨城県', 'イバラキケン', 'ひたちなか市', 'ヒタチナカシ', '中根', 'ナカネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県ひたちなか市馬渡', '08', '08221', '3120012', '茨城県', 'イバラキケン', 'ひたちなか市', 'ヒタチナカシ', '馬渡', 'マワタリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県ひたちなか市上野', '08', '08221', '3120013', '茨城県', 'イバラキケン', 'ひたちなか市', 'ヒタチナカシ', '上野', 'カミノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県ひたちなか市後野', '08', '08221', '3120014', '茨城県', 'イバラキケン', 'ひたちなか市', 'ヒタチナカシ', '後野', 'ウシロノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県ひたちなか市小砂町', '08', '08221', '3120015', '茨城県', 'イバラキケン', 'ひたちなか市', 'ヒタチナカシ', '小砂町', 'コスナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県ひたちなか市松戸町', '08', '08221', '3120016', '茨城県', 'イバラキケン', 'ひたちなか市', 'ヒタチナカシ', '松戸町', 'マツドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県ひたちなか市長堀町', '08', '08221', '3120017', '茨城県', 'イバラキケン', 'ひたちなか市', 'ヒタチナカシ', '長堀町', 'ナガホリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県ひたちなか市笹野町', '08', '08221', '3120018', '茨城県', 'イバラキケン', 'ひたちなか市', 'ヒタチナカシ', '笹野町', 'ササノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県ひたちなか市三反田', '08', '08221', '3120021', '茨城県', 'イバラキケン', 'ひたちなか市', 'ヒタチナカシ', '三反田', 'ミタンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県ひたちなか市金上', '08', '08221', '3120022', '茨城県', 'イバラキケン', 'ひたちなか市', 'ヒタチナカシ', '金上', 'カネアゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県ひたちなか市大平', '08', '08221', '3120023', '茨城県', 'イバラキケン', 'ひたちなか市', 'ヒタチナカシ', '大平', 'オオダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県ひたちなか市勝倉', '08', '08221', '3120024', '茨城県', 'イバラキケン', 'ひたちなか市', 'ヒタチナカシ', '勝倉', 'カツクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県ひたちなか市武田', '08', '08221', '3120025', '茨城県', 'イバラキケン', 'ひたちなか市', 'ヒタチナカシ', '武田', 'タケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県ひたちなか市勝田本町', '08', '08221', '3120026', '茨城県', 'イバラキケン', 'ひたちなか市', 'ヒタチナカシ', '勝田本町', 'カツタホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県ひたちなか市勝田中原町', '08', '08221', '3120027', '茨城県', 'イバラキケン', 'ひたちなか市', 'ヒタチナカシ', '勝田中原町', 'カツタナカハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県ひたちなか市後台', '08', '08221', '3120031', '茨城県', 'イバラキケン', 'ひたちなか市', 'ヒタチナカシ', '後台', 'ゴダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県ひたちなか市津田', '08', '08221', '3120032', '茨城県', 'イバラキケン', 'ひたちなか市', 'ヒタチナカシ', '津田', 'ツダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県ひたちなか市市毛', '08', '08221', '3120033', '茨城県', 'イバラキケン', 'ひたちなか市', 'ヒタチナカシ', '市毛', 'イチゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県ひたちなか市堀口', '08', '08221', '3120034', '茨城県', 'イバラキケン', 'ひたちなか市', 'ヒタチナカシ', '堀口', 'ホリグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県ひたちなか市枝川', '08', '08221', '3120035', '茨城県', 'イバラキケン', 'ひたちなか市', 'ヒタチナカシ', '枝川', 'エダカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県ひたちなか市津田東', '08', '08221', '3120036', '茨城県', 'イバラキケン', 'ひたちなか市', 'ヒタチナカシ', '津田東', 'ツダヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県ひたちなか市西大島', '08', '08221', '3120041', '茨城県', 'イバラキケン', 'ひたちなか市', 'ヒタチナカシ', '西大島', 'ニシオオシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県ひたちなか市東大島', '08', '08221', '3120042', '茨城県', 'イバラキケン', 'ひたちなか市', 'ヒタチナカシ', '東大島', 'ヒガシオオシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県ひたちなか市共栄町', '08', '08221', '3120043', '茨城県', 'イバラキケン', 'ひたちなか市', 'ヒタチナカシ', '共栄町', 'キョウエイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県ひたちなか市元町', '08', '08221', '3120044', '茨城県', 'イバラキケン', 'ひたちなか市', 'ヒタチナカシ', '元町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県ひたちなか市勝田中央', '08', '08221', '3120045', '茨城県', 'イバラキケン', 'ひたちなか市', 'ヒタチナカシ', '勝田中央', 'カツタチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県ひたちなか市勝田泉町', '08', '08221', '3120046', '茨城県', 'イバラキケン', 'ひたちなか市', 'ヒタチナカシ', '勝田泉町', 'カツタイズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県ひたちなか市表町', '08', '08221', '3120047', '茨城県', 'イバラキケン', 'ひたちなか市', 'ヒタチナカシ', '表町', 'オモテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県ひたちなか市春日町', '08', '08221', '3120048', '茨城県', 'イバラキケン', 'ひたちなか市', 'ヒタチナカシ', '春日町', 'カスガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県ひたちなか市堂端', '08', '08221', '3120051', '茨城県', 'イバラキケン', 'ひたちなか市', 'ヒタチナカシ', '堂端', 'ドウハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県ひたちなか市東石川', '08', '08221', '3120052', '茨城県', 'イバラキケン', 'ひたちなか市', 'ヒタチナカシ', '東石川', 'ヒガシイシカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県ひたちなか市外野', '08', '08221', '3120053', '茨城県', 'イバラキケン', 'ひたちなか市', 'ヒタチナカシ', '外野', 'ソトノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県ひたちなか市はしかべ', '08', '08221', '3120054', '茨城県', 'イバラキケン', 'ひたちなか市', 'ヒタチナカシ', 'はしかべ', 'ハシカベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県ひたちなか市大成町', '08', '08221', '3120055', '茨城県', 'イバラキケン', 'ひたちなか市', 'ヒタチナカシ', '大成町', 'タイセイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県ひたちなか市青葉町', '08', '08221', '3120056', '茨城県', 'イバラキケン', 'ひたちなか市', 'ヒタチナカシ', '青葉町', 'アオバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県ひたちなか市石川町', '08', '08221', '3120057', '茨城県', 'イバラキケン', 'ひたちなか市', 'ヒタチナカシ', '石川町', 'イシカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県ひたちなか市稲田', '08', '08221', '3120061', '茨城県', 'イバラキケン', 'ひたちなか市', 'ヒタチナカシ', '稲田', 'イナダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県ひたちなか市高場', '08', '08221', '3120062', '茨城県', 'イバラキケン', 'ひたちなか市', 'ヒタチナカシ', '高場', 'タカバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県ひたちなか市田彦', '08', '08221', '3120063', '茨城県', 'イバラキケン', 'ひたちなか市', 'ヒタチナカシ', '田彦', 'タビコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市', '08', '08212', '3130000', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('22919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市上大門町', '08', '08212', '3130001', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', '上大門町', 'カミオオカドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市下大門町', '08', '08212', '3130002', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', '下大門町', 'シモオオカドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市瑞龍町', '08', '08212', '3130003', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', '瑞龍町', 'ズイリュウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市馬場町', '08', '08212', '3130004', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', '馬場町', 'ババチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市栄町', '08', '08212', '3130005', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', '栄町', 'サカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市宮本町', '08', '08212', '3130006', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', '宮本町', 'ミヤモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市新宿町', '08', '08212', '3130007', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', '新宿町', 'アラジュクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市増井町', '08', '08212', '3130008', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', '増井町', 'マシイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市西宮町', '08', '08212', '3130011', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', '西宮町', 'ニシミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市三才町', '08', '08212', '3130012', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', '三才町', 'サンザイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市山下町', '08', '08212', '3130013', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', '山下町', 'ヤマシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市木崎二町', '08', '08212', '3130014', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', '木崎二町', 'キザキニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市木崎一町', '08', '08212', '3130015', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', '木崎一町', 'キザキイチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市金井町', '08', '08212', '3130016', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', '金井町', 'カナイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市大森町', '08', '08212', '3130021', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', '大森町', 'オオモリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市真弓町', '08', '08212', '3130022', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', '真弓町', 'マユミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市亀作町', '08', '08212', '3130023', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', '亀作町', 'カメザクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市高貫町', '08', '08212', '3130024', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', '高貫町', 'タカヌキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市幡町', '08', '08212', '3130025', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', '幡町', 'ハタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市田渡町', '08', '08212', '3130026', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', '田渡町', 'タワタリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市長谷町', '08', '08212', '3130027', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', '長谷町', 'ハセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市岡田町', '08', '08212', '3130031', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', '岡田町', 'オカダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市沢目町', '08', '08212', '3130032', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', '沢目町', 'サワメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市小目町', '08', '08212', '3130033', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', '小目町', 'オメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市上土木内町', '08', '08212', '3130034', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', '上土木内町', 'カミドギウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市堅磐町', '08', '08212', '3130035', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', '堅磐町', 'カキワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市落合町', '08', '08212', '3130036', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', '落合町', 'オチアイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市内田町', '08', '08212', '3130037', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', '内田町', 'ウチダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市小沢町', '08', '08212', '3130038', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', '小沢町', 'オザワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市稲木町', '08', '08212', '3130041', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', '稲木町', 'イナギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市磯部町', '08', '08212', '3130042', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', '磯部町', 'イソベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市谷河原町', '08', '08212', '3130043', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', '谷河原町', 'ヤガワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市下河合町', '08', '08212', '3130044', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', '下河合町', 'シモカワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市粟原町', '08', '08212', '3130045', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', '粟原町', 'アワバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市上河合町', '08', '08212', '3130046', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', '上河合町', 'カミカワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市島町', '08', '08212', '3130047', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', '島町', 'シマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市藤田町', '08', '08212', '3130048', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', '藤田町', 'フジタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市天神林町', '08', '08212', '3130049', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', '天神林町', 'テンジンバヤシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市東一町', '08', '08212', '3130051', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', '東一町', 'ヒガシイチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市東二町', '08', '08212', '3130052', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', '東二町', 'ヒガシニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市東三町', '08', '08212', '3130053', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', '東三町', 'ヒガシサンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市西三町', '08', '08212', '3130054', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', '西三町', 'ニシサンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市西二町', '08', '08212', '3130055', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', '西二町', 'ニシニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市西一町', '08', '08212', '3130056', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', '西一町', 'ニシイチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市中城町', '08', '08212', '3130061', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', '中城町', 'ナカジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市塙町', '08', '08212', '3130062', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', '塙町', 'ハナワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市内堀町', '08', '08212', '3130063', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', '内堀町', 'ウチボリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市寿町', '08', '08212', '3130064', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', '寿町', 'コトブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市上宮河内町', '08', '08212', '3130101', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', '上宮河内町', 'カミミヤカワウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市赤土町', '08', '08212', '3130102', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', '赤土町', 'アカヅチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市下宮河内町', '08', '08212', '3130103', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', '下宮河内町', 'シモミヤカワウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市上利員町', '08', '08212', '3130104', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', '上利員町', 'カミトシカズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市中利員町', '08', '08212', '3130105', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', '中利員町', 'ナカトシカズチョウ', null, null, null, null), ('22972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市下利員町', '08', '08212', '3130106', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', '下利員町', 'シモトシカズチョウ', null, null, null, null), ('22973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市千寿町', '08', '08212', '3130111', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', '千寿町', 'センズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市岩手町', '08', '08212', '3130112', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', '岩手町', 'イワテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市高柿町', '08', '08212', '3130113', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', '高柿町', 'タカガキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市箕町', '08', '08212', '3130114', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', '箕町', 'ミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市竹合町', '08', '08212', '3130115', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', '竹合町', 'タケアイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市大方町', '08', '08212', '3130116', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', '大方町', 'オオカタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市宮の郷町', '08', '08212', '3130117', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', '宮の郷町', 'ミヤノサトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市芦間町', '08', '08212', '3130121', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', '芦間町', 'アシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市玉造町', '08', '08212', '3130122', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', '玉造町', 'タマツクリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市久米町', '08', '08212', '3130123', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', '久米町', 'クメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市大平町', '08', '08212', '3130124', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', '大平町', 'オオダイラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市大里町', '08', '08212', '3130125', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', '大里町', 'オオサトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市薬谷町', '08', '08212', '3130126', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', '薬谷町', 'クスリヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市花房町', '08', '08212', '3130131', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', '花房町', 'ハナブサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市新地町', '08', '08212', '3130132', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', '新地町', 'アラジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市松栄町', '08', '08212', '3130133', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', '松栄町', 'マツザカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市中野町', '08', '08212', '3130134', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', '中野町', 'ナカノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市小島町', '08', '08212', '3130135', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', '小島町', 'オジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市東染町', '08', '08212', '3130211', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', '東染町', 'ヒガシゾメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市中染町', '08', '08212', '3130212', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', '中染町', 'ナカゾメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市町田町', '08', '08212', '3130213', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', '町田町', 'マチダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市和久町', '08', '08212', '3130214', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', '和久町', 'ワグチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市西染町', '08', '08212', '3130215', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', '西染町', 'ニシゾメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市国安町', '08', '08212', '3130221', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', '国安町', 'クニヤスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市松平町', '08', '08212', '3130222', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', '松平町', 'マツダイラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市和田町', '08', '08212', '3130223', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', '和田町', 'ワダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('22999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市東連地町', '08', '08212', '3130224', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', '東連地町', 'トウレンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市棚谷町', '08', '08212', '3130225', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', '棚谷町', 'タナヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市天下野町', '08', '08212', '3130351', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', '天下野町', 'ケガノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市下高倉町', '08', '08212', '3130352', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', '下高倉町', 'シモタカクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸太田市上高倉町', '08', '08212', '3130353', '茨城県', 'イバラキケン', '常陸太田市', 'ヒタチオオタシ', '上高倉町', 'カミタカクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鹿嶋市', '08', '08222', '3140000', '茨城県', 'イバラキケン', '鹿嶋市', 'カシマシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('23011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鹿嶋市清水', '08', '08222', '3140001', '茨城県', 'イバラキケン', '鹿嶋市', 'カシマシ', '清水', 'シミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鹿嶋市明石', '08', '08222', '3140002', '茨城県', 'イバラキケン', '鹿嶋市', 'カシマシ', '明石', 'アカシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鹿嶋市小宮作', '08', '08222', '3140003', '茨城県', 'イバラキケン', '鹿嶋市', 'カシマシ', '小宮作', 'コミヤサク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鹿嶋市下津', '08', '08222', '3140004', '茨城県', 'イバラキケン', '鹿嶋市', 'カシマシ', '下津', 'オリツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鹿嶋市高天原', '08', '08222', '3140005', '茨城県', 'イバラキケン', '鹿嶋市', 'カシマシ', '高天原', 'タカマガハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鹿嶋市宮津台', '08', '08222', '3140006', '茨城県', 'イバラキケン', '鹿嶋市', 'カシマシ', '宮津台', 'ミヤツダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鹿嶋市神向寺', '08', '08222', '3140007', '茨城県', 'イバラキケン', '鹿嶋市', 'カシマシ', '神向寺', 'ジンコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鹿嶋市港ケ丘', '08', '08222', '3140011', '茨城県', 'イバラキケン', '鹿嶋市', 'カシマシ', '港ケ丘', 'ミナトガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鹿嶋市平井', '08', '08222', '3140012', '茨城県', 'イバラキケン', '鹿嶋市', 'カシマシ', '平井', 'ヒライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鹿嶋市新浜', '08', '08222', '3140013', '茨城県', 'イバラキケン', '鹿嶋市', 'カシマシ', '新浜', 'シンハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鹿嶋市光', '08', '08222', '3140014', '茨城県', 'イバラキケン', '鹿嶋市', 'カシマシ', '光', 'ヒカリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鹿嶋市泉川', '08', '08222', '3140015', '茨城県', 'イバラキケン', '鹿嶋市', 'カシマシ', '泉川', 'イズミガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鹿嶋市国末', '08', '08222', '3140016', '茨城県', 'イバラキケン', '鹿嶋市', 'カシマシ', '国末', 'クニスエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鹿嶋市旭ケ丘', '08', '08222', '3140017', '茨城県', 'イバラキケン', '鹿嶋市', 'カシマシ', '旭ケ丘', 'アサヒガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鹿嶋市粟生', '08', '08222', '3140021', '茨城県', 'イバラキケン', '鹿嶋市', 'カシマシ', '粟生', 'アオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鹿嶋市長栖', '08', '08222', '3140022', '茨城県', 'イバラキケン', '鹿嶋市', 'カシマシ', '長栖', 'ナガス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鹿嶋市谷原', '08', '08222', '3140023', '茨城県', 'イバラキケン', '鹿嶋市', 'カシマシ', '谷原', 'ヤワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鹿嶋市鰐川', '08', '08222', '3140024', '茨城県', 'イバラキケン', '鹿嶋市', 'カシマシ', '鰐川', 'ワニガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鹿嶋市下塙', '08', '08222', '3140025', '茨城県', 'イバラキケン', '鹿嶋市', 'カシマシ', '下塙', 'シモハナワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鹿嶋市木滝佐田谷原入会', '08', '08222', '3140026', '茨城県', 'イバラキケン', '鹿嶋市', 'カシマシ', '木滝佐田谷原入会', 'キタキサダヤワライリアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鹿嶋市佐田', '08', '08222', '3140027', '茨城県', 'イバラキケン', '鹿嶋市', 'カシマシ', '佐田', 'サダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鹿嶋市木滝', '08', '08222', '3140028', '茨城県', 'イバラキケン', '鹿嶋市', 'カシマシ', '木滝', 'キタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鹿嶋市宮中', '08', '08222', '3140031', '茨城県', 'イバラキケン', '鹿嶋市', 'カシマシ', '宮中', 'キュウチュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鹿嶋市宮下', '08', '08222', '3140032', '茨城県', 'イバラキケン', '鹿嶋市', 'カシマシ', '宮下', 'ミヤシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鹿嶋市鉢形台', '08', '08222', '3140033', '茨城県', 'イバラキケン', '鹿嶋市', 'カシマシ', '鉢形台', 'ハチガタダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鹿嶋市鉢形', '08', '08222', '3140034', '茨城県', 'イバラキケン', '鹿嶋市', 'カシマシ', '鉢形', 'ハチガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鹿嶋市根三田', '08', '08222', '3140035', '茨城県', 'イバラキケン', '鹿嶋市', 'カシマシ', '根三田', 'ネサンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鹿嶋市大船津', '08', '08222', '3140036', '茨城県', 'イバラキケン', '鹿嶋市', 'カシマシ', '大船津', 'オオフナツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鹿嶋市神野', '08', '08222', '3140037', '茨城県', 'イバラキケン', '鹿嶋市', 'カシマシ', '神野', 'カノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鹿嶋市城山', '08', '08222', '3140038', '茨城県', 'イバラキケン', '鹿嶋市', 'カシマシ', '城山', 'シロヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鹿嶋市沼尾', '08', '08222', '3140041', '茨城県', 'イバラキケン', '鹿嶋市', 'カシマシ', '沼尾', 'ヌマオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鹿嶋市田野辺', '08', '08222', '3140042', '茨城県', 'イバラキケン', '鹿嶋市', 'カシマシ', '田野辺', 'タノベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鹿嶋市田谷', '08', '08222', '3140043', '茨城県', 'イバラキケン', '鹿嶋市', 'カシマシ', '田谷', 'タヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鹿嶋市猿田', '08', '08222', '3140044', '茨城県', 'イバラキケン', '鹿嶋市', 'カシマシ', '猿田', 'サルタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鹿嶋市山之上', '08', '08222', '3140045', '茨城県', 'イバラキケン', '鹿嶋市', 'カシマシ', '山之上', 'ヤマノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鹿嶋市爪木', '08', '08222', '3140046', '茨城県', 'イバラキケン', '鹿嶋市', 'カシマシ', '爪木', 'ツマギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鹿嶋市須賀', '08', '08222', '3140047', '茨城県', 'イバラキケン', '鹿嶋市', 'カシマシ', '須賀', 'スカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県鹿嶋市田谷沼', '08', '08222', '3140048', '茨城県', 'イバラキケン', '鹿嶋市', 'カシマシ', '田谷沼', 'タヤヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県神栖市光', '08', '08232', '3140051', '茨城県', 'イバラキケン', '神栖市', 'カミスシ', '光', 'ヒカリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県神栖市居切', '08', '08232', '3140052', '茨城県', 'イバラキケン', '神栖市', 'カミスシ', '居切', 'イギリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県神栖市', '08', '08232', '3140100', '茨城県', 'イバラキケン', '神栖市', 'カミスシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('23052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県神栖市北浜', '08', '08232', '3140101', '茨城県', 'イバラキケン', '神栖市', 'カミスシ', '北浜', 'キタハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県神栖市東和田', '08', '08232', '3140102', '茨城県', 'イバラキケン', '神栖市', 'カミスシ', '東和田', 'トウワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県神栖市東深芝', '08', '08232', '3140103', '茨城県', 'イバラキケン', '神栖市', 'カミスシ', '東深芝', 'ヒガシフカシバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県神栖市南浜', '08', '08232', '3140111', '茨城県', 'イバラキケン', '神栖市', 'カミスシ', '南浜', 'ミナミハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県神栖市知手中央', '08', '08232', '3140112', '茨城県', 'イバラキケン', '神栖市', 'カミスシ', '知手中央', 'シツテチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県神栖市横瀬', '08', '08232', '3140113', '茨城県', 'イバラキケン', '神栖市', 'カミスシ', '横瀬', 'ヨコセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県神栖市日川', '08', '08232', '3140114', '茨城県', 'イバラキケン', '神栖市', 'カミスシ', '日川', 'ニッカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県神栖市知手', '08', '08232', '3140115', '茨城県', 'イバラキケン', '神栖市', 'カミスシ', '知手', 'シッテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県神栖市奥野谷', '08', '08232', '3140116', '茨城県', 'イバラキケン', '神栖市', 'カミスシ', '奥野谷', 'オクノヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県神栖市溝口', '08', '08232', '3140121', '茨城県', 'イバラキケン', '神栖市', 'カミスシ', '溝口', 'ミゾグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県神栖市萩原', '08', '08232', '3140122', '茨城県', 'イバラキケン', '神栖市', 'カミスシ', '萩原', 'ハギワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県神栖市芝崎', '08', '08232', '3140123', '茨城県', 'イバラキケン', '神栖市', 'カミスシ', '芝崎', 'シバサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県神栖市石神', '08', '08232', '3140124', '茨城県', 'イバラキケン', '神栖市', 'カミスシ', '石神', 'イシガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県神栖市高浜', '08', '08232', '3140125', '茨城県', 'イバラキケン', '神栖市', 'カミスシ', '高浜', 'タカハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県神栖市田畑', '08', '08232', '3140126', '茨城県', 'イバラキケン', '神栖市', 'カミスシ', '田畑', 'タバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県神栖市木崎', '08', '08232', '3140127', '茨城県', 'イバラキケン', '神栖市', 'カミスシ', '木崎', 'キサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県神栖市大野原中央', '08', '08232', '3140128', '茨城県', 'イバラキケン', '神栖市', 'カミスシ', '大野原中央', 'オオノハラチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県神栖市下幡木', '08', '08232', '3140131', '茨城県', 'イバラキケン', '神栖市', 'カミスシ', '下幡木', 'シモハタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県神栖市筒井', '08', '08232', '3140132', '茨城県', 'イバラキケン', '神栖市', 'カミスシ', '筒井', 'ツツイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県神栖市息栖', '08', '08232', '3140133', '茨城県', 'イバラキケン', '神栖市', 'カミスシ', '息栖', 'イキス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県神栖市賀', '08', '08232', '3140134', '茨城県', 'イバラキケン', '神栖市', 'カミスシ', '賀', 'ガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県神栖市堀割', '08', '08232', '3140135', '茨城県', 'イバラキケン', '神栖市', 'カミスシ', '堀割', 'ホリワリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県神栖市居切', '08', '08232', '3140141', '茨城県', 'イバラキケン', '神栖市', 'カミスシ', '居切', 'イギリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県神栖市深芝南', '08', '08232', '3140142', '茨城県', 'イバラキケン', '神栖市', 'カミスシ', '深芝南', 'フカシバミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県神栖市神栖', '08', '08232', '3140143', '茨城県', 'イバラキケン', '神栖市', 'カミスシ', '神栖', 'カミス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県神栖市大野原', '08', '08232', '3140144', '茨城県', 'イバラキケン', '神栖市', 'カミスシ', '大野原', 'オオノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県神栖市平泉外12入会', '08', '08232', '3140145', '茨城県', 'イバラキケン', '神栖市', 'カミスシ', '平泉外12入会', 'ヒライズミソト12イリアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県神栖市平泉東', '08', '08232', '3140145', '茨城県', 'イバラキケン', '神栖市', 'カミスシ', '平泉東', 'ヒライズミヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県神栖市平泉', '08', '08232', '3140146', '茨城県', 'イバラキケン', '神栖市', 'カミスシ', '平泉', 'ヒライズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県神栖市鰐川', '08', '08232', '3140147', '茨城県', 'イバラキケン', '神栖市', 'カミスシ', '鰐川', 'ワニガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県神栖市深芝', '08', '08232', '3140148', '茨城県', 'イバラキケン', '神栖市', 'カミスシ', '深芝', 'フカシバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県神栖市柳川', '08', '08232', '3140252', '茨城県', 'イバラキケン', '神栖市', 'カミスシ', '柳川', 'ヤナガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県神栖市須田', '08', '08232', '3140253', '茨城県', 'イバラキケン', '神栖市', 'カミスシ', '須田', 'スダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県神栖市太田', '08', '08232', '3140254', '茨城県', 'イバラキケン', '神栖市', 'カミスシ', '太田', 'オオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県神栖市砂山', '08', '08232', '3140255', '茨城県', 'イバラキケン', '神栖市', 'カミスシ', '砂山', 'スナヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県神栖市若松中央', '08', '08232', '3140256', '茨城県', 'イバラキケン', '神栖市', 'カミスシ', '若松中央', 'ワカマツチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県神栖市太田新町', '08', '08232', '3140257', '茨城県', 'イバラキケン', '神栖市', 'カミスシ', '太田新町', 'オオタシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県神栖市柳川中央', '08', '08232', '3140258', '茨城県', 'イバラキケン', '神栖市', 'カミスシ', '柳川中央', 'ヤナガワチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県神栖市矢田部', '08', '08232', '3140341', '茨城県', 'イバラキケン', '神栖市', 'カミスシ', '矢田部', 'ヤタベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県神栖市土合北', '08', '08232', '3140342', '茨城県', 'イバラキケン', '神栖市', 'カミスシ', '土合北', 'ドアイキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県神栖市土合本町', '08', '08232', '3140343', '茨城県', 'イバラキケン', '神栖市', 'カミスシ', '土合本町', 'ドアイホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県神栖市土合東', '08', '08232', '3140344', '茨城県', 'イバラキケン', '神栖市', 'カミスシ', '土合東', 'ドアイヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県神栖市土合南', '08', '08232', '3140345', '茨城県', 'イバラキケン', '神栖市', 'カミスシ', '土合南', 'ドアイミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県神栖市土合西', '08', '08232', '3140346', '茨城県', 'イバラキケン', '神栖市', 'カミスシ', '土合西', 'ドアイニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県神栖市土合中央', '08', '08232', '3140347', '茨城県', 'イバラキケン', '神栖市', 'カミスシ', '土合中央', 'ドアイチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県神栖市波崎新港', '08', '08232', '3140407', '茨城県', 'イバラキケン', '神栖市', 'カミスシ', '波崎新港', 'ハサキシンコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県神栖市波崎', '08', '08232', '3140408', '茨城県', 'イバラキケン', '神栖市', 'カミスシ', '波崎', 'ハサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県石岡市', '08', '08205', '3150000', '茨城県', 'イバラキケン', '石岡市', 'イシオカシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('23108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県かすみがうら市', '08', '08230', '3150000', '茨城県', 'イバラキケン', 'かすみがうら市', 'カスミガウラシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('23109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県石岡市石岡', '08', '08205', '3150001', '茨城県', 'イバラキケン', '石岡市', 'イシオカシ', '石岡', 'イシオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県石岡市柏原', '08', '08205', '3150002', '茨城県', 'イバラキケン', '石岡市', 'イシオカシ', '柏原', 'カシワバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県石岡市谷向町', '08', '08205', '3150003', '茨城県', 'イバラキケン', '石岡市', 'イシオカシ', '谷向町', 'ヤムカイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県石岡市柏原町', '08', '08205', '3150004', '茨城県', 'イバラキケン', '石岡市', 'イシオカシ', '柏原町', 'カシワバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県石岡市鹿の子', '08', '08205', '3150005', '茨城県', 'イバラキケン', '石岡市', 'イシオカシ', '鹿の子', 'カノコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県石岡市並木', '08', '08205', '3150006', '茨城県', 'イバラキケン', '石岡市', 'イシオカシ', '並木', 'ナミキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県石岡市染谷', '08', '08205', '3150007', '茨城県', 'イバラキケン', '石岡市', 'イシオカシ', '染谷', 'ソメヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県石岡市村上', '08', '08205', '3150008', '茨城県', 'イバラキケン', '石岡市', 'イシオカシ', '村上', 'ムラカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県石岡市大砂', '08', '08205', '3150009', '茨城県', 'イバラキケン', '石岡市', 'イシオカシ', '大砂', 'オオスナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県石岡市碁石沢', '08', '08205', '3150010', '茨城県', 'イバラキケン', '石岡市', 'イシオカシ', '碁石沢', 'ゴイシザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県石岡市正上内', '08', '08205', '3150011', '茨城県', 'イバラキケン', '石岡市', 'イシオカシ', '正上内', 'ショウジョウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県石岡市北府中', '08', '08205', '3150012', '茨城県', 'イバラキケン', '石岡市', 'イシオカシ', '北府中', 'キタフチュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県石岡市府中', '08', '08205', '3150013', '茨城県', 'イバラキケン', '石岡市', 'イシオカシ', '府中', 'フチュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県石岡市国府', '08', '08205', '3150014', '茨城県', 'イバラキケン', '石岡市', 'イシオカシ', '国府', 'コクフ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県石岡市貝地', '08', '08205', '3150015', '茨城県', 'イバラキケン', '石岡市', 'イシオカシ', '貝地', 'カイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県石岡市総社', '08', '08205', '3150016', '茨城県', 'イバラキケン', '石岡市', 'イシオカシ', '総社', 'ソウシャ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県石岡市若宮', '08', '08205', '3150017', '茨城県', 'イバラキケン', '石岡市', 'イシオカシ', '若宮', 'ワカミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県石岡市若松', '08', '08205', '3150018', '茨城県', 'イバラキケン', '石岡市', 'イシオカシ', '若松', 'ワカマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県石岡市栄松', '08', '08205', '3150019', '茨城県', 'イバラキケン', '石岡市', 'イシオカシ', '栄松', 'サカエマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県石岡市荒金', '08', '08205', '3150021', '茨城県', 'イバラキケン', '石岡市', 'イシオカシ', '荒金', 'アラガネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県石岡市行里川', '08', '08205', '3150022', '茨城県', 'イバラキケン', '石岡市', 'イシオカシ', '行里川', 'ナメリカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県石岡市東府中', '08', '08205', '3150023', '茨城県', 'イバラキケン', '石岡市', 'イシオカシ', '東府中', 'ヒガシフチュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県石岡市八軒台', '08', '08205', '3150024', '茨城県', 'イバラキケン', '石岡市', 'イシオカシ', '八軒台', 'ハチケンダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県石岡市泉町', '08', '08205', '3150025', '茨城県', 'イバラキケン', '石岡市', 'イシオカシ', '泉町', 'イズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県石岡市杉の井', '08', '08205', '3150026', '茨城県', 'イバラキケン', '石岡市', 'イシオカシ', '杉の井', 'スギノイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県石岡市杉並', '08', '08205', '3150027', '茨城県', 'イバラキケン', '石岡市', 'イシオカシ', '杉並', 'スギナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県石岡市半ノ木', '08', '08205', '3150028', '茨城県', 'イバラキケン', '石岡市', 'イシオカシ', '半ノ木', 'ハンノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県石岡市根当', '08', '08205', '3150029', '茨城県', 'イバラキケン', '石岡市', 'イシオカシ', '根当', 'ネアタリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県石岡市池の台', '08', '08205', '3150030', '茨城県', 'イバラキケン', '石岡市', 'イシオカシ', '池の台', 'イケノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県石岡市東大橋', '08', '08205', '3150031', '茨城県', 'イバラキケン', '石岡市', 'イシオカシ', '東大橋', 'ヒガシオオハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県石岡市小井戸', '08', '08205', '3150032', '茨城県', 'イバラキケン', '石岡市', 'イシオカシ', '小井戸', 'コイド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県石岡市東光台', '08', '08205', '3150033', '茨城県', 'イバラキケン', '石岡市', 'イシオカシ', '東光台', 'トウコウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県石岡市東田中', '08', '08205', '3150034', '茨城県', 'イバラキケン', '石岡市', 'イシオカシ', '東田中', 'ヒガシタナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県石岡市南台', '08', '08205', '3150035', '茨城県', 'イバラキケン', '石岡市', 'イシオカシ', '南台', 'ミナミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県石岡市大谷津', '08', '08205', '3150036', '茨城県', 'イバラキケン', '石岡市', 'イシオカシ', '大谷津', 'オオヤツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県石岡市東石岡', '08', '08205', '3150037', '茨城県', 'イバラキケン', '石岡市', 'イシオカシ', '東石岡', 'ヒガシイシオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県石岡市旭台', '08', '08205', '3150038', '茨城県', 'イバラキケン', '石岡市', 'イシオカシ', '旭台', 'アサヒダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県石岡市田島', '08', '08205', '3150041', '茨城県', 'イバラキケン', '石岡市', 'イシオカシ', '田島', 'タジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県石岡市茨城', '08', '08205', '3150042', '茨城県', 'イバラキケン', '石岡市', 'イシオカシ', '茨城', 'バラキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県石岡市中津川', '08', '08205', '3150043', '茨城県', 'イバラキケン', '石岡市', 'イシオカシ', '中津川', 'ナカツガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県石岡市北根本', '08', '08205', '3150044', '茨城県', 'イバラキケン', '石岡市', 'イシオカシ', '北根本', 'キタネモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県石岡市高浜', '08', '08205', '3150045', '茨城県', 'イバラキケン', '石岡市', 'イシオカシ', '高浜', 'タカハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県石岡市石川', '08', '08205', '3150046', '茨城県', 'イバラキケン', '石岡市', 'イシオカシ', '石川', 'イシカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県石岡市井関', '08', '08205', '3150047', '茨城県', 'イバラキケン', '石岡市', 'イシオカシ', '井関', 'イセキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県石岡市三村', '08', '08205', '3150048', '茨城県', 'イバラキケン', '石岡市', 'イシオカシ', '三村', 'ミムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県かすみがうら市新治', '08', '08230', '3150051', '茨城県', 'イバラキケン', 'かすみがうら市', 'カスミガウラシ', '新治', 'ニイハリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県かすみがうら市下稲吉', '08', '08230', '3150052', '茨城県', 'イバラキケン', 'かすみがうら市', 'カスミガウラシ', '下稲吉', 'シモイナヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県かすみがうら市稲吉東', '08', '08230', '3150053', '茨城県', 'イバラキケン', 'かすみがうら市', 'カスミガウラシ', '稲吉東', 'イナヨシヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県かすみがうら市稲吉', '08', '08230', '3150054', '茨城県', 'イバラキケン', 'かすみがうら市', 'カスミガウラシ', '稲吉', 'イナヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県かすみがうら市稲吉南', '08', '08230', '3150055', '茨城県', 'イバラキケン', 'かすみがうら市', 'カスミガウラシ', '稲吉南', 'イナヨシミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県かすみがうら市上稲吉', '08', '08230', '3150056', '茨城県', 'イバラキケン', 'かすみがうら市', 'カスミガウラシ', '上稲吉', 'カミイナヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県かすみがうら市上土田', '08', '08230', '3150057', '茨城県', 'イバラキケン', 'かすみがうら市', 'カスミガウラシ', '上土田', 'カミツチダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県かすみがうら市下土田', '08', '08230', '3150058', '茨城県', 'イバラキケン', 'かすみがうら市', 'カスミガウラシ', '下土田', 'シモツチダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県かすみがうら市五反田', '08', '08230', '3150061', '茨城県', 'イバラキケン', 'かすみがうら市', 'カスミガウラシ', '五反田', 'ゴタンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県かすみがうら市横堀', '08', '08230', '3150062', '茨城県', 'イバラキケン', 'かすみがうら市', 'カスミガウラシ', '横堀', 'ヨコボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県かすみがうら市飯田', '08', '08230', '3150063', '茨城県', 'イバラキケン', 'かすみがうら市', 'カスミガウラシ', '飯田', 'イイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県かすみがうら市大峰', '08', '08230', '3150064', '茨城県', 'イバラキケン', 'かすみがうら市', 'カスミガウラシ', '大峰', 'オオミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県かすみがうら市上佐谷', '08', '08230', '3150065', '茨城県', 'イバラキケン', 'かすみがうら市', 'カスミガウラシ', '上佐谷', 'カミサヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県かすみがうら市中佐谷', '08', '08230', '3150066', '茨城県', 'イバラキケン', 'かすみがうら市', 'カスミガウラシ', '中佐谷', 'ナカサヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県かすみがうら市下佐谷', '08', '08230', '3150067', '茨城県', 'イバラキケン', 'かすみがうら市', 'カスミガウラシ', '下佐谷', 'シモサヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県かすみがうら市山本', '08', '08230', '3150068', '茨城県', 'イバラキケン', 'かすみがうら市', 'カスミガウラシ', '山本', 'ヤマモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県かすみがうら市雪入', '08', '08230', '3150069', '茨城県', 'イバラキケン', 'かすみがうら市', 'カスミガウラシ', '雪入', 'ユキイリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県かすみがうら市市川', '08', '08230', '3150071', '茨城県', 'イバラキケン', 'かすみがうら市', 'カスミガウラシ', '市川', 'イチカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県かすみがうら市東野寺', '08', '08230', '3150072', '茨城県', 'イバラキケン', 'かすみがうら市', 'カスミガウラシ', '東野寺', 'ヒガシノデラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県かすみがうら市西野寺', '08', '08230', '3150073', '茨城県', 'イバラキケン', 'かすみがうら市', 'カスミガウラシ', '西野寺', 'ニシノデラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県かすみがうら市下志筑', '08', '08230', '3150074', '茨城県', 'イバラキケン', 'かすみがうら市', 'カスミガウラシ', '下志筑', 'シモシヅク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県かすみがうら市中志筑', '08', '08230', '3150075', '茨城県', 'イバラキケン', 'かすみがうら市', 'カスミガウラシ', '中志筑', 'ナカシヅク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県かすみがうら市上志筑', '08', '08230', '3150076', '茨城県', 'イバラキケン', 'かすみがうら市', 'カスミガウラシ', '上志筑', 'カミシヅク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県かすみがうら市高倉', '08', '08230', '3150077', '茨城県', 'イバラキケン', 'かすみがうら市', 'カスミガウラシ', '高倉', 'タカクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県かすみがうら市粟田', '08', '08230', '3150078', '茨城県', 'イバラキケン', 'かすみがうら市', 'カスミガウラシ', '粟田', 'アワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県石岡市大増', '08', '08205', '3150101', '茨城県', 'イバラキケン', '石岡市', 'イシオカシ', '大増', 'オオマス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県石岡市太田', '08', '08205', '3150102', '茨城県', 'イバラキケン', '石岡市', 'イシオカシ', '太田', 'オオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県石岡市中戸', '08', '08205', '3150103', '茨城県', 'イバラキケン', '石岡市', 'イシオカシ', '中戸', 'ナカド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県石岡市小見', '08', '08205', '3150104', '茨城県', 'イバラキケン', '石岡市', 'イシオカシ', '小見', 'オミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県石岡市大塚', '08', '08205', '3150105', '茨城県', 'イバラキケン', '石岡市', 'イシオカシ', '大塚', 'オオツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県石岡市瓦谷', '08', '08205', '3150111', '茨城県', 'イバラキケン', '石岡市', 'イシオカシ', '瓦谷', 'カワラヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県石岡市部原', '08', '08205', '3150112', '茨城県', 'イバラキケン', '石岡市', 'イシオカシ', '部原', 'ヘバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県石岡市片岡', '08', '08205', '3150113', '茨城県', 'イバラキケン', '石岡市', 'イシオカシ', '片岡', 'カタオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県石岡市嘉良寿理', '08', '08205', '3150114', '茨城県', 'イバラキケン', '石岡市', 'イシオカシ', '嘉良寿理', 'カラスリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県石岡市浦須', '08', '08205', '3150115', '茨城県', 'イバラキケン', '石岡市', 'イシオカシ', '浦須', 'ウラス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県石岡市柿岡', '08', '08205', '3150116', '茨城県', 'イバラキケン', '石岡市', 'イシオカシ', '柿岡', 'カキオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県石岡市佐久', '08', '08205', '3150117', '茨城県', 'イバラキケン', '石岡市', 'イシオカシ', '佐久', 'サク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県石岡市野田', '08', '08205', '3150118', '茨城県', 'イバラキケン', '石岡市', 'イシオカシ', '野田', 'ノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県石岡市真家', '08', '08205', '3150121', '茨城県', 'イバラキケン', '石岡市', 'イシオカシ', '真家', 'マイエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県石岡市東成井', '08', '08205', '3150122', '茨城県', 'イバラキケン', '石岡市', 'イシオカシ', '東成井', 'ヒガシナルイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県石岡市宮ケ崎', '08', '08205', '3150123', '茨城県', 'イバラキケン', '石岡市', 'イシオカシ', '宮ケ崎', 'ミヤガサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県石岡市柴間', '08', '08205', '3150124', '茨城県', 'イバラキケン', '石岡市', 'イシオカシ', '柴間', 'シバマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県石岡市山崎', '08', '08205', '3150125', '茨城県', 'イバラキケン', '石岡市', 'イシオカシ', '山崎', 'ヤマザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県石岡市下林', '08', '08205', '3150131', '茨城県', 'イバラキケン', '石岡市', 'イシオカシ', '下林', 'シモバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県石岡市根小屋', '08', '08205', '3150132', '茨城県', 'イバラキケン', '石岡市', 'イシオカシ', '根小屋', 'ネゴヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県石岡市半田', '08', '08205', '3150133', '茨城県', 'イバラキケン', '石岡市', 'イシオカシ', '半田', 'ハンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県石岡市川又', '08', '08205', '3150134', '茨城県', 'イバラキケン', '石岡市', 'イシオカシ', '川又', 'カワマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県石岡市加生野', '08', '08205', '3150135', '茨城県', 'イバラキケン', '石岡市', 'イシオカシ', '加生野', 'カヨウノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県石岡市片野', '08', '08205', '3150136', '茨城県', 'イバラキケン', '石岡市', 'イシオカシ', '片野', 'カタノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県石岡市金指', '08', '08205', '3150137', '茨城県', 'イバラキケン', '石岡市', 'イシオカシ', '金指', 'カナサシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県石岡市上林', '08', '08205', '3150138', '茨城県', 'イバラキケン', '石岡市', 'イシオカシ', '上林', 'カミバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県石岡市月岡', '08', '08205', '3150141', '茨城県', 'イバラキケン', '石岡市', 'イシオカシ', '月岡', 'ツキオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県石岡市弓弦', '08', '08205', '3150142', '茨城県', 'イバラキケン', '石岡市', 'イシオカシ', '弓弦', 'ユヅリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県石岡市柴内', '08', '08205', '3150143', '茨城県', 'イバラキケン', '石岡市', 'イシオカシ', '柴内', 'シバウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県石岡市小野越', '08', '08205', '3150144', '茨城県', 'イバラキケン', '石岡市', 'イシオカシ', '小野越', 'オノゴエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県石岡市仏生寺', '08', '08205', '3150145', '茨城県', 'イバラキケン', '石岡市', 'イシオカシ', '仏生寺', 'ブッショウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県石岡市菖蒲沢', '08', '08205', '3150146', '茨城県', 'イバラキケン', '石岡市', 'イシオカシ', '菖蒲沢', 'ショウブザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県石岡市辻', '08', '08205', '3150147', '茨城県', 'イバラキケン', '石岡市', 'イシオカシ', '辻', 'ツジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県石岡市青田', '08', '08205', '3150148', '茨城県', 'イバラキケン', '石岡市', 'イシオカシ', '青田', 'アオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県石岡市須釜', '08', '08205', '3150151', '茨城県', 'イバラキケン', '石岡市', 'イシオカシ', '須釜', 'スガマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県石岡市細谷', '08', '08205', '3150152', '茨城県', 'イバラキケン', '石岡市', 'イシオカシ', '細谷', 'ホソヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県石岡市下青柳', '08', '08205', '3150153', '茨城県', 'イバラキケン', '石岡市', 'イシオカシ', '下青柳', 'シモアオヤギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県石岡市上青柳', '08', '08205', '3150154', '茨城県', 'イバラキケン', '石岡市', 'イシオカシ', '上青柳', 'カミアオヤギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県石岡市小幡', '08', '08205', '3150155', '茨城県', 'イバラキケン', '石岡市', 'イシオカシ', '小幡', 'オバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県石岡市吉生', '08', '08205', '3150156', '茨城県', 'イバラキケン', '石岡市', 'イシオカシ', '吉生', 'ヨシウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県石岡市上曽', '08', '08205', '3150157', '茨城県', 'イバラキケン', '石岡市', 'イシオカシ', '上曽', 'ウワソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県石岡市小塙', '08', '08205', '3150161', '茨城県', 'イバラキケン', '石岡市', 'イシオカシ', '小塙', 'コバナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県石岡市宇治会', '08', '08205', '3150162', '茨城県', 'イバラキケン', '石岡市', 'イシオカシ', '宇治会', 'ウジエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県石岡市鯨岡', '08', '08205', '3150163', '茨城県', 'イバラキケン', '石岡市', 'イシオカシ', '鯨岡', 'クジラオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県石岡市小屋', '08', '08205', '3150164', '茨城県', 'イバラキケン', '石岡市', 'イシオカシ', '小屋', 'コヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県石岡市小倉', '08', '08205', '3150165', '茨城県', 'イバラキケン', '石岡市', 'イシオカシ', '小倉', 'オグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県石岡市小山田', '08', '08205', '3150166', '茨城県', 'イバラキケン', '石岡市', 'イシオカシ', '小山田', 'オヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県石岡市龍明', '08', '08205', '3150167', '茨城県', 'イバラキケン', '石岡市', 'イシオカシ', '龍明', 'リュウメイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県日立市諏訪町', '08', '08202', '3160001', '茨城県', 'イバラキケン', '日立市', 'ヒタチシ', '諏訪町', 'スワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県日立市桜川町', '08', '08202', '3160002', '茨城県', 'イバラキケン', '日立市', 'ヒタチシ', '桜川町', 'サクラガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県日立市多賀町', '08', '08202', '3160003', '茨城県', 'イバラキケン', '日立市', 'ヒタチシ', '多賀町', 'タガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県日立市東多賀町', '08', '08202', '3160004', '茨城県', 'イバラキケン', '日立市', 'ヒタチシ', '東多賀町', 'ヒガシタガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県日立市河原子町', '08', '08202', '3160005', '茨城県', 'イバラキケン', '日立市', 'ヒタチシ', '河原子町', 'カワラゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県日立市末広町', '08', '08202', '3160006', '茨城県', 'イバラキケン', '日立市', 'ヒタチシ', '末広町', 'スエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県日立市中丸町', '08', '08202', '3160007', '茨城県', 'イバラキケン', '日立市', 'ヒタチシ', '中丸町', 'ナカマルチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県日立市塙山町', '08', '08202', '3160011', '茨城県', 'イバラキケン', '日立市', 'ヒタチシ', '塙山町', 'ハナヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県日立市大久保町', '08', '08202', '3160012', '茨城県', 'イバラキケン', '日立市', 'ヒタチシ', '大久保町', 'オオクボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県日立市千石町', '08', '08202', '3160013', '茨城県', 'イバラキケン', '日立市', 'ヒタチシ', '千石町', 'チコクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県日立市東金沢町', '08', '08202', '3160014', '茨城県', 'イバラキケン', '日立市', 'ヒタチシ', '東金沢町', 'ヒガシカネサワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県日立市金沢町', '08', '08202', '3160015', '茨城県', 'イバラキケン', '日立市', 'ヒタチシ', '金沢町', 'カネサワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県日立市台原町', '08', '08202', '3160021', '茨城県', 'イバラキケン', '日立市', 'ヒタチシ', '台原町', 'ダイハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県日立市大沼町', '08', '08202', '3160022', '茨城県', 'イバラキケン', '日立市', 'ヒタチシ', '大沼町', 'オオヌマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県日立市東大沼町', '08', '08202', '3160023', '茨城県', 'イバラキケン', '日立市', 'ヒタチシ', '東大沼町', 'ヒガシオオヌマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県日立市水木町', '08', '08202', '3160024', '茨城県', 'イバラキケン', '日立市', 'ヒタチシ', '水木町', 'ミズキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県日立市森山町', '08', '08202', '3160025', '茨城県', 'イバラキケン', '日立市', 'ヒタチシ', '森山町', 'モリヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県日立市みかの原町', '08', '08202', '3160026', '茨城県', 'イバラキケン', '日立市', 'ヒタチシ', 'みかの原町', 'ミカノハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県日立市成沢町', '08', '08202', '3160031', '茨城県', 'イバラキケン', '日立市', 'ヒタチシ', '成沢町', 'ナルサワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県日立市西成沢町', '08', '08202', '3160032', '茨城県', 'イバラキケン', '日立市', 'ヒタチシ', '西成沢町', 'ニシナルサワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県日立市中成沢町', '08', '08202', '3160033', '茨城県', 'イバラキケン', '日立市', 'ヒタチシ', '中成沢町', 'ナカナルサワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県日立市東成沢町', '08', '08202', '3160034', '茨城県', 'イバラキケン', '日立市', 'ヒタチシ', '東成沢町', 'ヒガシナルサワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県日立市国分町', '08', '08202', '3160035', '茨城県', 'イバラキケン', '日立市', 'ヒタチシ', '国分町', 'コクブチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県日立市鮎川町', '08', '08202', '3160036', '茨城県', 'イバラキケン', '日立市', 'ヒタチシ', '鮎川町', 'アユカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県日立市', '08', '08202', '3170000', '茨城県', 'イバラキケン', '日立市', 'ヒタチシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('23262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県日立市滑川本町', '08', '08202', '3170051', '茨城県', 'イバラキケン', '日立市', 'ヒタチシ', '滑川本町', 'ナメカワホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県日立市東滑川町', '08', '08202', '3170052', '茨城県', 'イバラキケン', '日立市', 'ヒタチシ', '東滑川町', 'ヒガシナメカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県日立市滑川町', '08', '08202', '3170053', '茨城県', 'イバラキケン', '日立市', 'ヒタチシ', '滑川町', 'ナメカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県日立市本宮町', '08', '08202', '3170054', '茨城県', 'イバラキケン', '日立市', 'ヒタチシ', '本宮町', 'モトミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県日立市宮田町', '08', '08202', '3170055', '茨城県', 'イバラキケン', '日立市', 'ヒタチシ', '宮田町', 'ミヤタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県日立市白銀町', '08', '08202', '3170056', '茨城県', 'イバラキケン', '日立市', 'ヒタチシ', '白銀町', 'シロガネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県日立市東町', '08', '08202', '3170061', '茨城県', 'イバラキケン', '日立市', 'ヒタチシ', '東町', 'ヒガシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県日立市平和町', '08', '08202', '3170062', '茨城県', 'イバラキケン', '日立市', 'ヒタチシ', '平和町', 'ヘイワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県日立市若葉町', '08', '08202', '3170063', '茨城県', 'イバラキケン', '日立市', 'ヒタチシ', '若葉町', 'ワカバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県日立市神峰町', '08', '08202', '3170064', '茨城県', 'イバラキケン', '日立市', 'ヒタチシ', '神峰町', 'カミネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県日立市助川町', '08', '08202', '3170065', '茨城県', 'イバラキケン', '日立市', 'ヒタチシ', '助川町', 'スケガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県日立市高鈴町', '08', '08202', '3170066', '茨城県', 'イバラキケン', '日立市', 'ヒタチシ', '高鈴町', 'タカスズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県日立市鹿島町', '08', '08202', '3170071', '茨城県', 'イバラキケン', '日立市', 'ヒタチシ', '鹿島町', 'カシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県日立市弁天町', '08', '08202', '3170072', '茨城県', 'イバラキケン', '日立市', 'ヒタチシ', '弁天町', 'ベンテンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県日立市幸町', '08', '08202', '3170073', '茨城県', 'イバラキケン', '日立市', 'ヒタチシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県日立市旭町', '08', '08202', '3170074', '茨城県', 'イバラキケン', '日立市', 'ヒタチシ', '旭町', 'アサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県日立市相賀町', '08', '08202', '3170075', '茨城県', 'イバラキケン', '日立市', 'ヒタチシ', '相賀町', 'アイガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県日立市会瀬町', '08', '08202', '3170076', '茨城県', 'イバラキケン', '日立市', 'ヒタチシ', '会瀬町', 'オウセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県日立市城南町', '08', '08202', '3170077', '茨城県', 'イバラキケン', '日立市', 'ヒタチシ', '城南町', 'ジョウナンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県高萩市', '08', '08214', '3180000', '茨城県', 'イバラキケン', '高萩市', 'タカハギシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('23286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県高萩市赤浜', '08', '08214', '3180001', '茨城県', 'イバラキケン', '高萩市', 'タカハギシ', '赤浜', 'アカハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県高萩市高戸', '08', '08214', '3180002', '茨城県', 'イバラキケン', '高萩市', 'タカハギシ', '高戸', 'タカド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県高萩市下手綱', '08', '08214', '3180003', '茨城県', 'イバラキケン', '高萩市', 'タカハギシ', '下手綱', 'シモテヅナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県高萩市上手綱', '08', '08214', '3180004', '茨城県', 'イバラキケン', '高萩市', 'タカハギシ', '上手綱', 'カミテヅナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県高萩市望海', '08', '08214', '3180005', '茨城県', 'イバラキケン', '高萩市', 'タカハギシ', '望海', 'ボウカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県高萩市肥前町', '08', '08214', '3180011', '茨城県', 'イバラキケン', '高萩市', 'タカハギシ', '肥前町', 'ヒゼンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県高萩市有明町', '08', '08214', '3180012', '茨城県', 'イバラキケン', '高萩市', 'タカハギシ', '有明町', 'アリアケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県高萩市高浜町', '08', '08214', '3180013', '茨城県', 'イバラキケン', '高萩市', 'タカハギシ', '高浜町', 'タカハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県高萩市東本町', '08', '08214', '3180014', '茨城県', 'イバラキケン', '高萩市', 'タカハギシ', '東本町', 'ヒガシホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県高萩市安良川', '08', '08214', '3180021', '茨城県', 'イバラキケン', '高萩市', 'タカハギシ', '安良川', 'アラカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県高萩市石滝', '08', '08214', '3180022', '茨城県', 'イバラキケン', '高萩市', 'タカハギシ', '石滝', 'イシタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県高萩市島名', '08', '08214', '3180023', '茨城県', 'イバラキケン', '高萩市', 'タカハギシ', '島名', 'シマナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県高萩市秋山', '08', '08214', '3180024', '茨城県', 'イバラキケン', '高萩市', 'タカハギシ', '秋山', 'アキヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県高萩市福平', '08', '08214', '3180025', '茨城県', 'イバラキケン', '高萩市', 'タカハギシ', '福平', 'フクダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県高萩市春日町', '08', '08214', '3180031', '茨城県', 'イバラキケン', '高萩市', 'タカハギシ', '春日町', 'カスガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県高萩市大和町', '08', '08214', '3180032', '茨城県', 'イバラキケン', '高萩市', 'タカハギシ', '大和町', 'ヤマトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県高萩市本町', '08', '08214', '3180033', '茨城県', 'イバラキケン', '高萩市', 'タカハギシ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県高萩市高萩', '08', '08214', '3180034', '茨城県', 'イバラキケン', '高萩市', 'タカハギシ', '高萩', 'タカハギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県高萩市横川', '08', '08214', '3180101', '茨城県', 'イバラキケン', '高萩市', 'タカハギシ', '横川', 'ヨコカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県高萩市若栗', '08', '08214', '3180102', '茨城県', 'イバラキケン', '高萩市', 'タカハギシ', '若栗', 'ワカグリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県高萩市大能', '08', '08214', '3180103', '茨城県', 'イバラキケン', '高萩市', 'タカハギシ', '大能', 'オオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県高萩市中戸川', '08', '08214', '3180104', '茨城県', 'イバラキケン', '高萩市', 'タカハギシ', '中戸川', 'ナカドガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県高萩市上君田', '08', '08214', '3180105', '茨城県', 'イバラキケン', '高萩市', 'タカハギシ', '上君田', 'カミキミダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県高萩市下君田', '08', '08214', '3180106', '茨城県', 'イバラキケン', '高萩市', 'タカハギシ', '下君田', 'シモキミダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県小美玉市', '08', '08236', '3190100', '茨城県', 'イバラキケン', '小美玉市', 'オミタマシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('23339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県小美玉市橋場美', '08', '08236', '3190101', '茨城県', 'イバラキケン', '小美玉市', 'オミタマシ', '橋場美', 'ハシバミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県小美玉市西郷地', '08', '08236', '3190102', '茨城県', 'イバラキケン', '小美玉市', 'オミタマシ', '西郷地', 'サイゴウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県小美玉市柴高', '08', '08236', '3190103', '茨城県', 'イバラキケン', '小美玉市', 'オミタマシ', '柴高', 'シバタカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県小美玉市三箇', '08', '08236', '3190104', '茨城県', 'イバラキケン', '小美玉市', 'オミタマシ', '三箇', 'サンガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県小美玉市鶴田', '08', '08236', '3190105', '茨城県', 'イバラキケン', '小美玉市', 'オミタマシ', '鶴田', 'ツルタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県小美玉市堅倉', '08', '08236', '3190106', '茨城県', 'イバラキケン', '小美玉市', 'オミタマシ', '堅倉', 'カタクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県小美玉市小岩戸', '08', '08236', '3190107', '茨城県', 'イバラキケン', '小美玉市', 'オミタマシ', '小岩戸', 'コイワト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県小美玉市先後', '08', '08236', '3190108', '茨城県', 'イバラキケン', '小美玉市', 'オミタマシ', '先後', 'マツノチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県小美玉市中野谷', '08', '08236', '3190111', '茨城県', 'イバラキケン', '小美玉市', 'オミタマシ', '中野谷', 'ナカノヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県小美玉市竹原下郷', '08', '08236', '3190112', '茨城県', 'イバラキケン', '小美玉市', 'オミタマシ', '竹原下郷', 'タケハラシモゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県小美玉市竹原', '08', '08236', '3190113', '茨城県', 'イバラキケン', '小美玉市', 'オミタマシ', '竹原', 'タケハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県小美玉市竹原中郷', '08', '08236', '3190114', '茨城県', 'イバラキケン', '小美玉市', 'オミタマシ', '竹原中郷', 'タケハラナカゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県小美玉市上馬場', '08', '08236', '3190115', '茨城県', 'イバラキケン', '小美玉市', 'オミタマシ', '上馬場', 'カミババ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県小美玉市中台', '08', '08236', '3190116', '茨城県', 'イバラキケン', '小美玉市', 'オミタマシ', '中台', 'ナカダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県小美玉市羽刈', '08', '08236', '3190121', '茨城県', 'イバラキケン', '小美玉市', 'オミタマシ', '羽刈', 'ハカリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県小美玉市江戸', '08', '08236', '3190122', '茨城県', 'イバラキケン', '小美玉市', 'オミタマシ', '江戸', 'エド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県小美玉市羽鳥', '08', '08236', '3190123', '茨城県', 'イバラキケン', '小美玉市', 'オミタマシ', '羽鳥', 'ハトリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県小美玉市花野井', '08', '08236', '3190124', '茨城県', 'イバラキケン', '小美玉市', 'オミタマシ', '花野井', 'ハナノイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県小美玉市小曽納', '08', '08236', '3190125', '茨城県', 'イバラキケン', '小美玉市', 'オミタマシ', '小曽納', 'オソノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県小美玉市大谷', '08', '08236', '3190126', '茨城県', 'イバラキケン', '小美玉市', 'オミタマシ', '大谷', 'オオヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県小美玉市寺崎', '08', '08236', '3190131', '茨城県', 'イバラキケン', '小美玉市', 'オミタマシ', '寺崎', 'テラザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県小美玉市部室', '08', '08236', '3190132', '茨城県', 'イバラキケン', '小美玉市', 'オミタマシ', '部室', 'ヘムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県小美玉市張星', '08', '08236', '3190133', '茨城県', 'イバラキケン', '小美玉市', 'オミタマシ', '張星', 'ハリホシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県小美玉市納場', '08', '08236', '3190134', '茨城県', 'イバラキケン', '小美玉市', 'オミタマシ', '納場', 'ノウバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県小美玉市高田', '08', '08236', '3190135', '茨城県', 'イバラキケン', '小美玉市', 'オミタマシ', '高田', 'タカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県小美玉市手堤', '08', '08236', '3190136', '茨城県', 'イバラキケン', '小美玉市', 'オミタマシ', '手堤', 'テツヅミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県小美玉市大笹', '08', '08236', '3190137', '茨城県', 'イバラキケン', '小美玉市', 'オミタマシ', '大笹', 'オオザサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県笠間市上郷', '08', '08216', '3190201', '茨城県', 'イバラキケン', '笠間市', 'カサマシ', '上郷', 'カミゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県笠間市下郷', '08', '08216', '3190202', '茨城県', 'イバラキケン', '笠間市', 'カサマシ', '下郷', 'シモゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県笠間市吉岡', '08', '08216', '3190203', '茨城県', 'イバラキケン', '笠間市', 'カサマシ', '吉岡', 'ヨシオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県笠間市土師', '08', '08216', '3190204', '茨城県', 'イバラキケン', '笠間市', 'カサマシ', '土師', 'ハジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県笠間市押辺', '08', '08216', '3190205', '茨城県', 'イバラキケン', '笠間市', 'カサマシ', '押辺', 'オシノベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県笠間市安居', '08', '08216', '3190206', '茨城県', 'イバラキケン', '笠間市', 'カサマシ', '安居', 'アゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県笠間市福島', '08', '08216', '3190207', '茨城県', 'イバラキケン', '笠間市', 'カサマシ', '福島', 'フクシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県笠間市市野谷', '08', '08216', '3190208', '茨城県', 'イバラキケン', '笠間市', 'カサマシ', '市野谷', 'イチノヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県笠間市泉', '08', '08216', '3190209', '茨城県', 'イバラキケン', '笠間市', 'カサマシ', '泉', 'イズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市田島町', '08', '08201', '3190301', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '田島町', 'タジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市三野輪町', '08', '08201', '3190302', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '三野輪町', 'ミノワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市黒磯町', '08', '08201', '3190303', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '黒磯町', 'クロイソチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市有賀町', '08', '08201', '3190304', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '有賀町', 'アリガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市中原町', '08', '08201', '3190305', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '中原町', 'ナカハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市杉崎町', '08', '08201', '3190306', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '杉崎町', 'スギサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市小原町', '08', '08201', '3190307', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '小原町', 'オバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市牛伏町', '08', '08201', '3190311', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '牛伏町', 'ウシブシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市大足町', '08', '08201', '3190312', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '大足町', 'オオダラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市筑地町', '08', '08201', '3190313', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '筑地町', 'ツイジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市赤尾関町', '08', '08201', '3190314', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '赤尾関町', 'アカオセキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市内原町', '08', '08201', '3190315', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '内原町', 'ウチハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市三湯町', '08', '08201', '3190316', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '三湯町', 'ミユチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市高田町', '08', '08201', '3190321', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '高田町', 'タカダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市下野町', '08', '08201', '3190322', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '下野町', 'シモノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市鯉淵町', '08', '08201', '3190323', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '鯉淵町', 'コイブチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市五平町', '08', '08201', '3190324', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '五平町', 'ゴヘイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県水戸市小林町', '08', '08201', '3190325', '茨城県', 'イバラキケン', '水戸市', 'ミトシ', '小林町', 'コバヤシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県那珂郡東海村', '08', '08341', '3191100', '茨城県', 'イバラキケン', '那珂郡東海村', 'ナカグントウカイムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('23404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県那珂郡東海村石神外宿', '08', '08341', '3191101', '茨城県', 'イバラキケン', '那珂郡東海村', 'ナカグントウカイムラ', '石神外宿', 'イシガミトジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県那珂郡東海村石神内宿', '08', '08341', '3191102', '茨城県', 'イバラキケン', '那珂郡東海村', 'ナカグントウカイムラ', '石神内宿', 'イシガミウチジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県那珂郡東海村竹瓦', '08', '08341', '3191103', '茨城県', 'イバラキケン', '那珂郡東海村', 'ナカグントウカイムラ', '竹瓦', 'タケガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県那珂郡東海村亀下', '08', '08341', '3191104', '茨城県', 'イバラキケン', '那珂郡東海村', 'ナカグントウカイムラ', '亀下', 'カメシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県那珂郡東海村豊岡', '08', '08341', '3191105', '茨城県', 'イバラキケン', '那珂郡東海村', 'ナカグントウカイムラ', '豊岡', 'トヨオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県那珂郡東海村白方', '08', '08341', '3191106', '茨城県', 'イバラキケン', '那珂郡東海村', 'ナカグントウカイムラ', '白方', 'シラカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県那珂郡東海村豊白', '08', '08341', '3191107', '茨城県', 'イバラキケン', '那珂郡東海村', 'ナカグントウカイムラ', '豊白', 'トヨシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県那珂郡東海村村松北', '08', '08341', '3191108', '茨城県', 'イバラキケン', '那珂郡東海村', 'ナカグントウカイムラ', '村松北', 'ムラマツキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県那珂郡東海村白方中央', '08', '08341', '3191109', '茨城県', 'イバラキケン', '那珂郡東海村', 'ナカグントウカイムラ', '白方中央', 'シラカタチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県那珂郡東海村舟石川', '08', '08341', '3191111', '茨城県', 'イバラキケン', '那珂郡東海村', 'ナカグントウカイムラ', '舟石川', 'フナイシカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県那珂郡東海村村松', '08', '08341', '3191112', '茨城県', 'イバラキケン', '那珂郡東海村', 'ナカグントウカイムラ', '村松', 'ムラマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県那珂郡東海村照沼', '08', '08341', '3191113', '茨城県', 'イバラキケン', '那珂郡東海村', 'ナカグントウカイムラ', '照沼', 'テルヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県那珂郡東海村須和間', '08', '08341', '3191114', '茨城県', 'イバラキケン', '那珂郡東海村', 'ナカグントウカイムラ', '須和間', 'スワマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県那珂郡東海村船場', '08', '08341', '3191115', '茨城県', 'イバラキケン', '那珂郡東海村', 'ナカグントウカイムラ', '船場', 'フナバ', null, null, null, null), ('23418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県那珂郡東海村舟石川駅西', '08', '08341', '3191116', '茨城県', 'イバラキケン', '那珂郡東海村', 'ナカグントウカイムラ', '舟石川駅西', 'フナイシカワエキニシ', null, null, null, null), ('23419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県那珂郡東海村東海', '08', '08341', '3191117', '茨城県', 'イバラキケン', '那珂郡東海村', 'ナカグントウカイムラ', '東海', 'トウカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県那珂郡東海村舟石川駅東', '08', '08341', '3191118', '茨城県', 'イバラキケン', '那珂郡東海村', 'ナカグントウカイムラ', '舟石川駅東', 'フナイシカワエキヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県日立市大みか町', '08', '08202', '3191221', '茨城県', 'イバラキケン', '日立市', 'ヒタチシ', '大みか町', 'オオミカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県日立市久慈町', '08', '08202', '3191222', '茨城県', 'イバラキケン', '日立市', 'ヒタチシ', '久慈町', 'クジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県日立市みなと町', '08', '08202', '3191223', '茨城県', 'イバラキケン', '日立市', 'ヒタチシ', 'みなと町', 'ミナトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県日立市南高野町', '08', '08202', '3191224', '茨城県', 'イバラキケン', '日立市', 'ヒタチシ', '南高野町', 'ミナミコウヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県日立市石名坂町', '08', '08202', '3191225', '茨城県', 'イバラキケン', '日立市', 'ヒタチシ', '石名坂町', 'イシナザカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県日立市留町', '08', '08202', '3191231', '茨城県', 'イバラキケン', '日立市', 'ヒタチシ', '留町', 'トメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県日立市下土木内町', '08', '08202', '3191232', '茨城県', 'イバラキケン', '日立市', 'ヒタチシ', '下土木内町', 'シモドギウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県日立市神田町', '08', '08202', '3191233', '茨城県', 'イバラキケン', '日立市', 'ヒタチシ', '神田町', 'カンダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県日立市大和田町', '08', '08202', '3191234', '茨城県', 'イバラキケン', '日立市', 'ヒタチシ', '大和田町', 'オオワダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県日立市茂宮町', '08', '08202', '3191235', '茨城県', 'イバラキケン', '日立市', 'ヒタチシ', '茂宮町', 'モミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県日立市十王町伊師', '08', '08202', '3191301', '茨城県', 'イバラキケン', '日立市', 'ヒタチシ', '十王町伊師', 'ジュウオウチョウイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県日立市十王町伊師本郷', '08', '08202', '3191302', '茨城県', 'イバラキケン', '日立市', 'ヒタチシ', '十王町伊師本郷', 'ジュウオウチョウイシホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県日立市十王町友部東', '08', '08202', '3191303', '茨城県', 'イバラキケン', '日立市', 'ヒタチシ', '十王町友部東', 'ジュウオウチョウトモベヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県日立市十王町友部', '08', '08202', '3191304', '茨城県', 'イバラキケン', '日立市', 'ヒタチシ', '十王町友部', 'ジュウオウチョウトモベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県日立市十王町高原', '08', '08202', '3191305', '茨城県', 'イバラキケン', '日立市', 'ヒタチシ', '十王町高原', 'ジュウオウチョウタカハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県日立市十王町黒坂', '08', '08202', '3191306', '茨城県', 'イバラキケン', '日立市', 'ヒタチシ', '十王町黒坂', 'ジュウオウチョウクロサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県日立市十王町山部', '08', '08202', '3191307', '茨城県', 'イバラキケン', '日立市', 'ヒタチシ', '十王町山部', 'ジュウオウチョウヤマベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県日立市十王町城の丘', '08', '08202', '3191308', '茨城県', 'イバラキケン', '日立市', 'ヒタチシ', '十王町城の丘', 'ジュウオウチョウシロノオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県日立市川尻町', '08', '08202', '3191411', '茨城県', 'イバラキケン', '日立市', 'ヒタチシ', '川尻町', 'カワジリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県日立市折笠町', '08', '08202', '3191412', '茨城県', 'イバラキケン', '日立市', 'ヒタチシ', '折笠町', 'オリカサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県日立市小木津町', '08', '08202', '3191413', '茨城県', 'イバラキケン', '日立市', 'ヒタチシ', '小木津町', 'オギツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県日立市日高町', '08', '08202', '3191414', '茨城県', 'イバラキケン', '日立市', 'ヒタチシ', '日高町', 'ヒタカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県日立市相田町', '08', '08202', '3191415', '茨城県', 'イバラキケン', '日立市', 'ヒタチシ', '相田町', 'アイダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県日立市田尻町', '08', '08202', '3191416', '茨城県', 'イバラキケン', '日立市', 'ヒタチシ', '田尻町', 'タジリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県日立市かみあい町', '08', '08202', '3191417', '茨城県', 'イバラキケン', '日立市', 'ヒタチシ', 'かみあい町', 'カミアイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県日立市砂沢町', '08', '08202', '3191418', '茨城県', 'イバラキケン', '日立市', 'ヒタチシ', '砂沢町', 'イサゴザワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県北茨城市', '08', '08215', '3191500', '茨城県', 'イバラキケン', '北茨城市', 'キタイバラキシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('23458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県北茨城市華川町花園', '08', '08215', '3191531', '茨城県', 'イバラキケン', '北茨城市', 'キタイバラキシ', '華川町花園', 'ハナカワチョウハナゾノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県北茨城市華川町上小津田', '08', '08215', '3191532', '茨城県', 'イバラキケン', '北茨城市', 'キタイバラキシ', '華川町上小津田', 'ハナカワチョウカミコツダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県北茨城市華川町下小津田', '08', '08215', '3191533', '茨城県', 'イバラキケン', '北茨城市', 'キタイバラキシ', '華川町下小津田', 'ハナカワチョウシモコツダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県北茨城市華川町車', '08', '08215', '3191534', '茨城県', 'イバラキケン', '北茨城市', 'キタイバラキシ', '華川町車', 'ハナカワチョウクルマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県北茨城市華川町臼場', '08', '08215', '3191535', '茨城県', 'イバラキケン', '北茨城市', 'キタイバラキシ', '華川町臼場', 'ハナカワチョウウスバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県北茨城市華川町中妻', '08', '08215', '3191536', '茨城県', 'イバラキケン', '北茨城市', 'キタイバラキシ', '華川町中妻', 'ハナカワチョウナカツマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県北茨城市華川町下相田', '08', '08215', '3191537', '茨城県', 'イバラキケン', '北茨城市', 'キタイバラキシ', '華川町下相田', 'ハナカワチョウシモソウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県北茨城市華川町小豆畑', '08', '08215', '3191538', '茨城県', 'イバラキケン', '北茨城市', 'キタイバラキシ', '華川町小豆畑', 'ハナカワチョウアズハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県北茨城市磯原町磯原', '08', '08215', '3191541', '茨城県', 'イバラキケン', '北茨城市', 'キタイバラキシ', '磯原町磯原', 'イソハラチョウイソハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県北茨城市磯原町本町', '08', '08215', '3191542', '茨城県', 'イバラキケン', '北茨城市', 'キタイバラキシ', '磯原町本町', 'イソハラチョウホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県北茨城市磯原町豊田', '08', '08215', '3191543', '茨城県', 'イバラキケン', '北茨城市', 'キタイバラキシ', '磯原町豊田', 'イソハラチョウトヨダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県北茨城市磯原町上相田', '08', '08215', '3191544', '茨城県', 'イバラキケン', '北茨城市', 'キタイバラキシ', '磯原町上相田', 'イソハラチョウカミソウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県北茨城市磯原町木皿', '08', '08215', '3191545', '茨城県', 'イバラキケン', '北茨城市', 'キタイバラキシ', '磯原町木皿', 'イソハラチョウキサラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県北茨城市磯原町大塚', '08', '08215', '3191546', '茨城県', 'イバラキケン', '北茨城市', 'キタイバラキシ', '磯原町大塚', 'イソハラチョウオオツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県北茨城市磯原町内野', '08', '08215', '3191547', '茨城県', 'イバラキケン', '北茨城市', 'キタイバラキシ', '磯原町内野', 'イソハラチョウウツノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県北茨城市中郷町下桜井', '08', '08215', '3191551', '茨城県', 'イバラキケン', '北茨城市', 'キタイバラキシ', '中郷町下桜井', 'ナカゴウチョウシモサクライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県北茨城市中郷町足洗', '08', '08215', '3191552', '茨城県', 'イバラキケン', '北茨城市', 'キタイバラキシ', '中郷町足洗', 'ナカゴウチョウアシアライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県北茨城市中郷町汐見ケ丘', '08', '08215', '3191553', '茨城県', 'イバラキケン', '北茨城市', 'キタイバラキシ', '中郷町汐見ケ丘', 'ナカゴウチョウシオミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県北茨城市中郷町粟野', '08', '08215', '3191554', '茨城県', 'イバラキケン', '北茨城市', 'キタイバラキシ', '中郷町粟野', 'ナカゴウチョウアワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県北茨城市中郷町小野矢指', '08', '08215', '3191555', '茨城県', 'イバラキケン', '北茨城市', 'キタイバラキシ', '中郷町小野矢指', 'ナカゴウチョウオノヤサシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県北茨城市中郷町日棚', '08', '08215', '3191556', '茨城県', 'イバラキケン', '北茨城市', 'キタイバラキシ', '中郷町日棚', 'ナカゴウチョウヒタナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県北茨城市中郷町松井', '08', '08215', '3191557', '茨城県', 'イバラキケン', '北茨城市', 'キタイバラキシ', '中郷町松井', 'ナカゴウチョウマツイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県北茨城市中郷町石岡', '08', '08215', '3191558', '茨城県', 'イバラキケン', '北茨城市', 'キタイバラキシ', '中郷町石岡', 'ナカゴウチョウイシオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県北茨城市中郷町上桜井', '08', '08215', '3191559', '茨城県', 'イバラキケン', '北茨城市', 'キタイバラキシ', '中郷町上桜井', 'ナカゴウチョウカミサクライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県北茨城市平潟町', '08', '08215', '3191701', '茨城県', 'イバラキケン', '北茨城市', 'キタイバラキシ', '平潟町', 'ヒラカタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県北茨城市大津町', '08', '08215', '3191702', '茨城県', 'イバラキケン', '北茨城市', 'キタイバラキシ', '大津町', 'オオツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県北茨城市大津町五浦', '08', '08215', '3191703', '茨城県', 'イバラキケン', '北茨城市', 'キタイバラキシ', '大津町五浦', 'オオツチョウイヅラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県北茨城市大津町北町', '08', '08215', '3191704', '茨城県', 'イバラキケン', '北茨城市', 'キタイバラキシ', '大津町北町', 'オオツチョウキタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県北茨城市関南町関本下', '08', '08215', '3191711', '茨城県', 'イバラキケン', '北茨城市', 'キタイバラキシ', '関南町関本下', 'セキナミチョウセキモトシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県北茨城市関南町里根川', '08', '08215', '3191712', '茨城県', 'イバラキケン', '北茨城市', 'キタイバラキシ', '関南町里根川', 'セキナミチョウサトネガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県北茨城市関南町仁井田', '08', '08215', '3191713', '茨城県', 'イバラキケン', '北茨城市', 'キタイバラキシ', '関南町仁井田', 'セキナミチョウニイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県北茨城市関南町神岡上', '08', '08215', '3191714', '茨城県', 'イバラキケン', '北茨城市', 'キタイバラキシ', '関南町神岡上', 'セキナミチョウカミオカカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県北茨城市関南町神岡下', '08', '08215', '3191715', '茨城県', 'イバラキケン', '北茨城市', 'キタイバラキシ', '関南町神岡下', 'セキナミチョウカミオカシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県北茨城市関本町関本上', '08', '08215', '3191721', '茨城県', 'イバラキケン', '北茨城市', 'キタイバラキシ', '関本町関本上', 'セキモトチョウセキモトカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県北茨城市関本町福田', '08', '08215', '3191722', '茨城県', 'イバラキケン', '北茨城市', 'キタイバラキシ', '関本町福田', 'セキモトチョウフクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県北茨城市関本町関本中', '08', '08215', '3191723', '茨城県', 'イバラキケン', '北茨城市', 'キタイバラキシ', '関本町関本中', 'セキモトチョウセキモトナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県北茨城市関本町八反', '08', '08215', '3191724', '茨城県', 'イバラキケン', '北茨城市', 'キタイバラキシ', '関本町八反', 'セキモトチョウハッタン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県北茨城市関本町富士ケ丘', '08', '08215', '3191725', '茨城県', 'イバラキケン', '北茨城市', 'キタイバラキシ', '関本町富士ケ丘', 'セキモトチョウフジガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県北茨城市関本町才丸', '08', '08215', '3191726', '茨城県', 'イバラキケン', '北茨城市', 'キタイバラキシ', '関本町才丸', 'セキモトチョウサイマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県北茨城市関本町小川', '08', '08215', '3191727', '茨城県', 'イバラキケン', '北茨城市', 'キタイバラキシ', '関本町小川', 'セキモトチョウオガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県那珂市瓜連', '08', '08226', '3192102', '茨城県', 'イバラキケン', '那珂市', 'ナカシ', '瓜連', 'ウリヅラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県那珂市中里', '08', '08226', '3192103', '茨城県', 'イバラキケン', '那珂市', 'ナカシ', '中里', 'ナカザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県那珂市平野', '08', '08226', '3192104', '茨城県', 'イバラキケン', '那珂市', 'ナカシ', '平野', 'ヒラノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県那珂市古徳', '08', '08226', '3192105', '茨城県', 'イバラキケン', '那珂市', 'ナカシ', '古徳', 'コトク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県那珂市静', '08', '08226', '3192106', '茨城県', 'イバラキケン', '那珂市', 'ナカシ', '静', 'シズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県那珂市下大賀', '08', '08226', '3192107', '茨城県', 'イバラキケン', '那珂市', 'ナカシ', '下大賀', 'シモオオガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸大宮市下村田', '08', '08225', '3192131', '茨城県', 'イバラキケン', '常陸大宮市', 'ヒタチオオミヤシ', '下村田', 'シモムラタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸大宮市小場', '08', '08225', '3192132', '茨城県', 'イバラキケン', '常陸大宮市', 'ヒタチオオミヤシ', '小場', 'オバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸大宮市小野', '08', '08225', '3192133', '茨城県', 'イバラキケン', '常陸大宮市', 'ヒタチオオミヤシ', '小野', 'オノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸大宮市工業団地', '08', '08225', '3192134', '茨城県', 'イバラキケン', '常陸大宮市', 'ヒタチオオミヤシ', '工業団地', 'コウギョウダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸大宮市石沢', '08', '08225', '3192135', '茨城県', 'イバラキケン', '常陸大宮市', 'ヒタチオオミヤシ', '石沢', 'イシザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸大宮市上村田', '08', '08225', '3192136', '茨城県', 'イバラキケン', '常陸大宮市', 'ヒタチオオミヤシ', '上村田', 'カミムラタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸大宮市下岩瀬', '08', '08225', '3192141', '茨城県', 'イバラキケン', '常陸大宮市', 'ヒタチオオミヤシ', '下岩瀬', 'シモイワセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸大宮市上岩瀬', '08', '08225', '3192142', '茨城県', 'イバラキケン', '常陸大宮市', 'ヒタチオオミヤシ', '上岩瀬', 'カミイワセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸大宮市根本', '08', '08225', '3192143', '茨城県', 'イバラキケン', '常陸大宮市', 'ヒタチオオミヤシ', '根本', 'ネモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸大宮市泉', '08', '08225', '3192144', '茨城県', 'イバラキケン', '常陸大宮市', 'ヒタチオオミヤシ', '泉', 'イズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸大宮市宇留野', '08', '08225', '3192145', '茨城県', 'イバラキケン', '常陸大宮市', 'ヒタチオオミヤシ', '宇留野', 'ウルノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸大宮市', '08', '08225', '3192200', '茨城県', 'イバラキケン', '常陸大宮市', 'ヒタチオオミヤシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('23518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸大宮市辰ノ口', '08', '08225', '3192201', '茨城県', 'イバラキケン', '常陸大宮市', 'ヒタチオオミヤシ', '辰ノ口', 'タツノクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸大宮市塩原', '08', '08225', '3192202', '茨城県', 'イバラキケン', '常陸大宮市', 'ヒタチオオミヤシ', '塩原', 'シオバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸大宮市小倉', '08', '08225', '3192203', '茨城県', 'イバラキケン', '常陸大宮市', 'ヒタチオオミヤシ', '小倉', 'オグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸大宮市富岡', '08', '08225', '3192204', '茨城県', 'イバラキケン', '常陸大宮市', 'ヒタチオオミヤシ', '富岡', 'トミオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸大宮市宮の郷', '08', '08225', '3192205', '茨城県', 'イバラキケン', '常陸大宮市', 'ヒタチオオミヤシ', '宮の郷', 'ミヤノサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸大宮市岩崎', '08', '08225', '3192211', '茨城県', 'イバラキケン', '常陸大宮市', 'ヒタチオオミヤシ', '岩崎', 'イワザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸大宮市上大賀', '08', '08225', '3192212', '茨城県', 'イバラキケン', '常陸大宮市', 'ヒタチオオミヤシ', '上大賀', 'カミオオガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸大宮市小祝', '08', '08225', '3192213', '茨城県', 'イバラキケン', '常陸大宮市', 'ヒタチオオミヤシ', '小祝', 'コイワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸大宮市鷹巣', '08', '08225', '3192214', '茨城県', 'イバラキケン', '常陸大宮市', 'ヒタチオオミヤシ', '鷹巣', 'タカス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸大宮市八田', '08', '08225', '3192221', '茨城県', 'イバラキケン', '常陸大宮市', 'ヒタチオオミヤシ', '八田', 'ハッタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸大宮市若林', '08', '08225', '3192222', '茨城県', 'イバラキケン', '常陸大宮市', 'ヒタチオオミヤシ', '若林', 'ワカバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸大宮市三美', '08', '08225', '3192223', '茨城県', 'イバラキケン', '常陸大宮市', 'ヒタチオオミヤシ', '三美', 'ミヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸大宮市東野', '08', '08225', '3192224', '茨城県', 'イバラキケン', '常陸大宮市', 'ヒタチオオミヤシ', '東野', 'トウノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸大宮市西塩子', '08', '08225', '3192225', '茨城県', 'イバラキケン', '常陸大宮市', 'ヒタチオオミヤシ', '西塩子', 'ニシシオゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸大宮市北塩子', '08', '08225', '3192226', '茨城県', 'イバラキケン', '常陸大宮市', 'ヒタチオオミヤシ', '北塩子', 'キタシオゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸大宮市照田', '08', '08225', '3192227', '茨城県', 'イバラキケン', '常陸大宮市', 'ヒタチオオミヤシ', '照田', 'テルダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸大宮市姥賀町', '08', '08225', '3192251', '茨城県', 'イバラキケン', '常陸大宮市', 'ヒタチオオミヤシ', '姥賀町', 'ウバガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸大宮市東富町', '08', '08225', '3192252', '茨城県', 'イバラキケン', '常陸大宮市', 'ヒタチオオミヤシ', '東富町', 'ヒガシトミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸大宮市高渡町', '08', '08225', '3192253', '茨城県', 'イバラキケン', '常陸大宮市', 'ヒタチオオミヤシ', '高渡町', 'タカワタリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸大宮市北町', '08', '08225', '3192254', '茨城県', 'イバラキケン', '常陸大宮市', 'ヒタチオオミヤシ', '北町', 'キタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸大宮市野中町', '08', '08225', '3192255', '茨城県', 'イバラキケン', '常陸大宮市', 'ヒタチオオミヤシ', '野中町', 'ノナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸大宮市田子内町', '08', '08225', '3192256', '茨城県', 'イバラキケン', '常陸大宮市', 'ヒタチオオミヤシ', '田子内町', 'タゴウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸大宮市上町', '08', '08225', '3192261', '茨城県', 'イバラキケン', '常陸大宮市', 'ヒタチオオミヤシ', '上町', 'カミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸大宮市下町', '08', '08225', '3192262', '茨城県', 'イバラキケン', '常陸大宮市', 'ヒタチオオミヤシ', '下町', 'シモチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸大宮市南町', '08', '08225', '3192263', '茨城県', 'イバラキケン', '常陸大宮市', 'ヒタチオオミヤシ', '南町', 'ミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸大宮市栄町', '08', '08225', '3192264', '茨城県', 'イバラキケン', '常陸大宮市', 'ヒタチオオミヤシ', '栄町', 'サカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸大宮市中富町', '08', '08225', '3192265', '茨城県', 'イバラキケン', '常陸大宮市', 'ヒタチオオミヤシ', '中富町', 'ナカトミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸大宮市抽ケ台町', '08', '08225', '3192266', '茨城県', 'イバラキケン', '常陸大宮市', 'ヒタチオオミヤシ', '抽ケ台町', 'ユガダイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸大宮市上小瀬', '08', '08225', '3192401', '茨城県', 'イバラキケン', '常陸大宮市', 'ヒタチオオミヤシ', '上小瀬', 'カミオセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸大宮市下小瀬', '08', '08225', '3192402', '茨城県', 'イバラキケン', '常陸大宮市', 'ヒタチオオミヤシ', '下小瀬', 'シモオセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸大宮市那賀', '08', '08225', '3192403', '茨城県', 'イバラキケン', '常陸大宮市', 'ヒタチオオミヤシ', '那賀', 'ナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸大宮市国長', '08', '08225', '3192404', '茨城県', 'イバラキケン', '常陸大宮市', 'ヒタチオオミヤシ', '国長', 'クニオサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸大宮市小玉', '08', '08225', '3192405', '茨城県', 'イバラキケン', '常陸大宮市', 'ヒタチオオミヤシ', '小玉', 'オダマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸大宮市小舟', '08', '08225', '3192411', '茨城県', 'イバラキケン', '常陸大宮市', 'ヒタチオオミヤシ', '小舟', 'コブネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸大宮市小瀬沢', '08', '08225', '3192412', '茨城県', 'イバラキケン', '常陸大宮市', 'ヒタチオオミヤシ', '小瀬沢', 'オセザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸大宮市松之草', '08', '08225', '3192413', '茨城県', 'イバラキケン', '常陸大宮市', 'ヒタチオオミヤシ', '松之草', 'マツノクサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸大宮市吉丸', '08', '08225', '3192414', '茨城県', 'イバラキケン', '常陸大宮市', 'ヒタチオオミヤシ', '吉丸', 'ヨシマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸大宮市入本郷', '08', '08225', '3192415', '茨城県', 'イバラキケン', '常陸大宮市', 'ヒタチオオミヤシ', '入本郷', 'イリホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸大宮市千田', '08', '08225', '3192416', '茨城県', 'イバラキケン', '常陸大宮市', 'ヒタチオオミヤシ', '千田', 'センダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸大宮市油河内', '08', '08225', '3192417', '茨城県', 'イバラキケン', '常陸大宮市', 'ヒタチオオミヤシ', '油河内', 'ユゴウト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸大宮市大岩', '08', '08225', '3192418', '茨城県', 'イバラキケン', '常陸大宮市', 'ヒタチオオミヤシ', '大岩', 'オオイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸大宮市上檜沢', '08', '08225', '3192511', '茨城県', 'イバラキケン', '常陸大宮市', 'ヒタチオオミヤシ', '上檜沢', 'カミヒザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸大宮市下檜沢', '08', '08225', '3192512', '茨城県', 'イバラキケン', '常陸大宮市', 'ヒタチオオミヤシ', '下檜沢', 'シモヒザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸大宮市氷之沢', '08', '08225', '3192513', '茨城県', 'イバラキケン', '常陸大宮市', 'ヒタチオオミヤシ', '氷之沢', 'ヒノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸大宮市高部', '08', '08225', '3192601', '茨城県', 'イバラキケン', '常陸大宮市', 'ヒタチオオミヤシ', '高部', 'タカブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸大宮市小田野', '08', '08225', '3192602', '茨城県', 'イバラキケン', '常陸大宮市', 'ヒタチオオミヤシ', '小田野', 'オタノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸大宮市鷲子', '08', '08225', '3192603', '茨城県', 'イバラキケン', '常陸大宮市', 'ヒタチオオミヤシ', '鷲子', 'トリノコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸大宮市久隆', '08', '08225', '3193101', '茨城県', 'イバラキケン', '常陸大宮市', 'ヒタチオオミヤシ', '久隆', 'クリュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸大宮市盛金', '08', '08225', '3193102', '茨城県', 'イバラキケン', '常陸大宮市', 'ヒタチオオミヤシ', '盛金', 'モリガネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸大宮市家和楽', '08', '08225', '3193103', '茨城県', 'イバラキケン', '常陸大宮市', 'ヒタチオオミヤシ', '家和楽', 'ヤワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸大宮市北富田', '08', '08225', '3193104', '茨城県', 'イバラキケン', '常陸大宮市', 'ヒタチオオミヤシ', '北富田', 'キタトミダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸大宮市諸沢', '08', '08225', '3193105', '茨城県', 'イバラキケン', '常陸大宮市', 'ヒタチオオミヤシ', '諸沢', 'モロザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸大宮市西野内', '08', '08225', '3193106', '茨城県', 'イバラキケン', '常陸大宮市', 'ヒタチオオミヤシ', '西野内', 'ニシノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸大宮市舟生', '08', '08225', '3193107', '茨城県', 'イバラキケン', '常陸大宮市', 'ヒタチオオミヤシ', '舟生', 'フニュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸大宮市山方', '08', '08225', '3193111', '茨城県', 'イバラキケン', '常陸大宮市', 'ヒタチオオミヤシ', '山方', 'ヤマガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸大宮市小貫', '08', '08225', '3193112', '茨城県', 'イバラキケン', '常陸大宮市', 'ヒタチオオミヤシ', '小貫', 'オヌキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸大宮市照山', '08', '08225', '3193113', '茨城県', 'イバラキケン', '常陸大宮市', 'ヒタチオオミヤシ', '照山', 'テルヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸大宮市野上', '08', '08225', '3193114', '茨城県', 'イバラキケン', '常陸大宮市', 'ヒタチオオミヤシ', '野上', 'ノガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸大宮市照田', '08', '08225', '3193115', '茨城県', 'イバラキケン', '常陸大宮市', 'ヒタチオオミヤシ', '照田', 'テルダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸大宮市長田', '08', '08225', '3193116', '茨城県', 'イバラキケン', '常陸大宮市', 'ヒタチオオミヤシ', '長田', 'オサダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県常陸大宮市長沢', '08', '08225', '3193117', '茨城県', 'イバラキケン', '常陸大宮市', 'ヒタチオオミヤシ', '長沢', 'ナガサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県久慈郡大子町頃藤', '08', '08364', '3193361', '茨城県', 'イバラキケン', '久慈郡大子町', 'クジグンダイゴマチ', '頃藤', 'コロフジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県久慈郡大子町西金', '08', '08364', '3193362', '茨城県', 'イバラキケン', '久慈郡大子町', 'クジグンダイゴマチ', '西金', 'サイガネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県久慈郡大子町北富田', '08', '08364', '3193363', '茨城県', 'イバラキケン', '久慈郡大子町', 'クジグンダイゴマチ', '北富田', 'キタトミタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県久慈郡大子町盛金', '08', '08364', '3193364', '茨城県', 'イバラキケン', '久慈郡大子町', 'クジグンダイゴマチ', '盛金', 'モリガネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県久慈郡大子町栃原', '08', '08364', '3193365', '茨城県', 'イバラキケン', '久慈郡大子町', 'クジグンダイゴマチ', '栃原', 'トチハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県久慈郡大子町大沢', '08', '08364', '3193366', '茨城県', 'イバラキケン', '久慈郡大子町', 'クジグンダイゴマチ', '大沢', 'オオサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県久慈郡大子町', '08', '08364', '3193500', '茨城県', 'イバラキケン', '久慈郡大子町', 'クジグンダイゴマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('23587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県久慈郡大子町高柴', '08', '08364', '3193511', '茨城県', 'イバラキケン', '久慈郡大子町', 'クジグンダイゴマチ', '高柴', 'タカシバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県久慈郡大子町小生瀬', '08', '08364', '3193512', '茨城県', 'イバラキケン', '久慈郡大子町', 'クジグンダイゴマチ', '小生瀬', 'コナマセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県久慈郡大子町大生瀬', '08', '08364', '3193513', '茨城県', 'イバラキケン', '久慈郡大子町', 'クジグンダイゴマチ', '大生瀬', 'オオナマセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県久慈郡大子町外大野', '08', '08364', '3193514', '茨城県', 'イバラキケン', '久慈郡大子町', 'クジグンダイゴマチ', '外大野', 'ソトオオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県久慈郡大子町内大野', '08', '08364', '3193515', '茨城県', 'イバラキケン', '久慈郡大子町', 'クジグンダイゴマチ', '内大野', 'ウチオオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県久慈郡大子町北田気', '08', '08364', '3193521', '茨城県', 'イバラキケン', '久慈郡大子町', 'クジグンダイゴマチ', '北田気', 'キタタゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県久慈郡大子町久野瀬', '08', '08364', '3193522', '茨城県', 'イバラキケン', '久慈郡大子町', 'クジグンダイゴマチ', '久野瀬', 'クノセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県久慈郡大子町袋田', '08', '08364', '3193523', '茨城県', 'イバラキケン', '久慈郡大子町', 'クジグンダイゴマチ', '袋田', 'フクロダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県久慈郡大子町下津原', '08', '08364', '3193524', '茨城県', 'イバラキケン', '久慈郡大子町', 'クジグンダイゴマチ', '下津原', 'シモツハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県久慈郡大子町南田気', '08', '08364', '3193525', '茨城県', 'イバラキケン', '久慈郡大子町', 'クジグンダイゴマチ', '南田気', 'ミナミタゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県久慈郡大子町大子', '08', '08364', '3193526', '茨城県', 'イバラキケン', '久慈郡大子町', 'クジグンダイゴマチ', '大子', 'ダイゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県久慈郡大子町上岡', '08', '08364', '3193531', '茨城県', 'イバラキケン', '久慈郡大子町', 'クジグンダイゴマチ', '上岡', 'ウワオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県久慈郡大子町山田', '08', '08364', '3193532', '茨城県', 'イバラキケン', '久慈郡大子町', 'クジグンダイゴマチ', '山田', 'ヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県久慈郡大子町下金沢', '08', '08364', '3193533', '茨城県', 'イバラキケン', '久慈郡大子町', 'クジグンダイゴマチ', '下金沢', 'シモカネサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県久慈郡大子町相川', '08', '08364', '3193534', '茨城県', 'イバラキケン', '久慈郡大子町', 'クジグンダイゴマチ', '相川', 'アイカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県久慈郡大子町上金沢', '08', '08364', '3193535', '茨城県', 'イバラキケン', '久慈郡大子町', 'クジグンダイゴマチ', '上金沢', 'カミカネサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県久慈郡大子町田野沢', '08', '08364', '3193536', '茨城県', 'イバラキケン', '久慈郡大子町', 'クジグンダイゴマチ', '田野沢', 'タノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県久慈郡大子町塙', '08', '08364', '3193537', '茨城県', 'イバラキケン', '久慈郡大子町', 'クジグンダイゴマチ', '塙', 'ハナワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県久慈郡大子町芦野倉', '08', '08364', '3193538', '茨城県', 'イバラキケン', '久慈郡大子町', 'クジグンダイゴマチ', '芦野倉', 'アシノクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県久慈郡大子町浅川', '08', '08364', '3193541', '茨城県', 'イバラキケン', '久慈郡大子町', 'クジグンダイゴマチ', '浅川', 'アサカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県久慈郡大子町初原', '08', '08364', '3193542', '茨城県', 'イバラキケン', '久慈郡大子町', 'クジグンダイゴマチ', '初原', 'ハツバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県久慈郡大子町左貫', '08', '08364', '3193543', '茨城県', 'イバラキケン', '久慈郡大子町', 'クジグンダイゴマチ', '左貫', 'サヌキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県久慈郡大子町槇野地', '08', '08364', '3193544', '茨城県', 'イバラキケン', '久慈郡大子町', 'クジグンダイゴマチ', '槇野地', 'マギノチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県久慈郡大子町池田', '08', '08364', '3193551', '茨城県', 'イバラキケン', '久慈郡大子町', 'クジグンダイゴマチ', '池田', 'イケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県久慈郡大子町矢田', '08', '08364', '3193552', '茨城県', 'イバラキケン', '久慈郡大子町', 'クジグンダイゴマチ', '矢田', 'ヤダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県久慈郡大子町冥賀', '08', '08364', '3193553', '茨城県', 'イバラキケン', '久慈郡大子町', 'クジグンダイゴマチ', '冥賀', 'ミョウガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県久慈郡大子町高田', '08', '08364', '3193554', '茨城県', 'イバラキケン', '久慈郡大子町', 'クジグンダイゴマチ', '高田', 'タカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県久慈郡大子町下野宮', '08', '08364', '3193555', '茨城県', 'イバラキケン', '久慈郡大子町', 'クジグンダイゴマチ', '下野宮', 'シモノミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県久慈郡大子町川山', '08', '08364', '3193556', '茨城県', 'イバラキケン', '久慈郡大子町', 'クジグンダイゴマチ', '川山', 'カワヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県久慈郡大子町北吉沢', '08', '08364', '3193701', '茨城県', 'イバラキケン', '久慈郡大子町', 'クジグンダイゴマチ', '北吉沢', 'キタヨシザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県久慈郡大子町町付', '08', '08364', '3193702', '茨城県', 'イバラキケン', '久慈郡大子町', 'クジグンダイゴマチ', '町付', 'マチツキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県久慈郡大子町上郷', '08', '08364', '3193703', '茨城県', 'イバラキケン', '久慈郡大子町', 'クジグンダイゴマチ', '上郷', 'カミゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県久慈郡大子町上野宮', '08', '08364', '3193704', '茨城県', 'イバラキケン', '久慈郡大子町', 'クジグンダイゴマチ', '上野宮', 'カミノミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '茨城県久慈郡大子町中郷', '08', '08364', '3193705', '茨城県', 'イバラキケン', '久慈郡大子町', 'クジグンダイゴマチ', '中郷', 'ナカゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市横山町', '09', '09201', '3200001', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '横山町', 'ヨコヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市瓦谷町', '09', '09201', '3200002', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '瓦谷町', 'カワラヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市豊郷台', '09', '09201', '3200003', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '豊郷台', 'トヨサトダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市長岡町', '09', '09201', '3200004', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '長岡町', 'ナガオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市横山', '09', '09201', '3200005', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '横山', 'ヨコヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市富士見が丘', '09', '09201', '3200011', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '富士見が丘', 'フジミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市山本', '09', '09201', '3200012', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '山本', 'ヤマモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市上大曽町', '09', '09201', '3200013', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '上大曽町', 'カミオオゾマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市大曽', '09', '09201', '3200014', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '大曽', 'オオゾ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市八幡台', '09', '09201', '3200015', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '八幡台', 'ハチマンダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市山本町', '09', '09201', '3200016', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '山本町', 'ヤマモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市戸祭台', '09', '09201', '3200017', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '戸祭台', 'トマツリダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市東塙田', '09', '09201', '3200021', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '東塙田', 'ヒガシハナワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市千波町', '09', '09201', '3200022', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '千波町', 'センナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市仲町', '09', '09201', '3200023', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '仲町', 'ナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市栄町', '09', '09201', '3200024', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '栄町', 'サカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市宮町', '09', '09201', '3200025', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '宮町', 'ミヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市馬場通り', '09', '09201', '3200026', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '馬場通り', 'ババドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市塙田', '09', '09201', '3200027', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '塙田', 'ハナワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市戸祭元町', '09', '09201', '3200031', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '戸祭元町', 'トマツリモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市昭和', '09', '09201', '3200032', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '昭和', 'ショウワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市本町', '09', '09201', '3200033', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市泉町', '09', '09201', '3200034', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '泉町', 'イズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市伝馬町', '09', '09201', '3200035', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '伝馬町', 'デンマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市小幡', '09', '09201', '3200036', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '小幡', 'オバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市清住', '09', '09201', '3200037', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '清住', 'キヨスミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市星が丘', '09', '09201', '3200038', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '星が丘', 'ホシガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市松原', '09', '09201', '3200041', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '松原', 'マツバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市材木町', '09', '09201', '3200042', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '材木町', 'ザイモクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市桜', '09', '09201', '3200043', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '桜', 'サクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市南一の沢町', '09', '09201', '3200044', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '南一の沢町', 'ミナミイチノサワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市中一の沢町', '09', '09201', '3200045', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '中一の沢町', 'ナカイチノサワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市西一の沢町', '09', '09201', '3200046', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '西一の沢町', 'ニシイチノサワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市一の沢', '09', '09201', '3200047', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '一の沢', 'イチノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市北一の沢町', '09', '09201', '3200048', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '北一の沢町', 'キタイチノサワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市一ノ沢町', '09', '09201', '3200049', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '一ノ沢町', 'イチノサワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市上戸祭町', '09', '09201', '3200051', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '上戸祭町', 'カミトマツリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市中戸祭町', '09', '09201', '3200052', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '中戸祭町', 'ナカトマツリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市戸祭町', '09', '09201', '3200053', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '戸祭町', 'トマツリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市東戸祭', '09', '09201', '3200054', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '東戸祭', 'ヒガシトマツリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市下戸祭', '09', '09201', '3200055', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '下戸祭', 'シモトマツリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市戸祭', '09', '09201', '3200056', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '戸祭', 'トマツリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市中戸祭', '09', '09201', '3200057', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '中戸祭', 'ナカトマツリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市上戸祭', '09', '09201', '3200058', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '上戸祭', 'カミトマツリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市宝木町', '09', '09201', '3200061', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '宝木町', 'タカラギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市東宝木町', '09', '09201', '3200062', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '東宝木町', 'ヒガシタカラギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市陽西町', '09', '09201', '3200063', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '陽西町', 'ヨウサイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市西の宮', '09', '09201', '3200064', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '西の宮', 'ニシノミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市駒生町', '09', '09201', '3200065', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '駒生町', 'コマニュウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市駒生', '09', '09201', '3200066', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '駒生', 'コマニュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市野沢町', '09', '09201', '3200071', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '野沢町', 'ノザワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市若草', '09', '09201', '3200072', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '若草', 'ワカクサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市細谷', '09', '09201', '3200073', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '細谷', 'ホソヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市細谷町', '09', '09201', '3200074', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '細谷町', 'ホソヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市宝木本町', '09', '09201', '3200075', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '宝木本町', 'タカラギホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市池上町', '09', '09201', '3200801', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '池上町', 'イケガミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市江野町', '09', '09201', '3200802', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '江野町', 'エノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市曲師町', '09', '09201', '3200803', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '曲師町', 'マゲシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市二荒町', '09', '09201', '3200804', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '二荒町', 'フタアラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市中央本町', '09', '09201', '3200805', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '中央本町', 'チュウオウホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市中央', '09', '09201', '3200806', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市松が峰', '09', '09201', '3200807', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '松が峰', 'マツガミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市宮園町', '09', '09201', '3200808', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '宮園町', 'ミヤゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市大通り', '09', '09201', '3200811', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '大通り', 'オオドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市一番町', '09', '09201', '3200812', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '一番町', 'イチバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市二番町', '09', '09201', '3200813', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '二番町', 'ニバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市三番町', '09', '09201', '3200814', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '三番町', 'サンバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市中河原町', '09', '09201', '3200815', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '中河原町', 'ナカガワラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市天神', '09', '09201', '3200816', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '天神', 'テンジン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市本丸町', '09', '09201', '3200817', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '本丸町', 'ホンマルチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市旭', '09', '09201', '3200818', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '旭', 'アサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市一条', '09', '09201', '3200821', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '一条', 'イチジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市河原町', '09', '09201', '3200822', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '河原町', 'カワラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市御蔵町', '09', '09201', '3200823', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '御蔵町', 'オクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市下河原', '09', '09201', '3200824', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '下河原', 'シモガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市下河原町', '09', '09201', '3200825', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '下河原町', 'シモガワラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市西原町', '09', '09201', '3200826', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '西原町', 'ニシハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市花房', '09', '09201', '3200827', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '花房', 'ハナブサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市花房本町', '09', '09201', '3200828', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '花房本町', 'ハナブサホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市新町', '09', '09201', '3200831', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市日の出', '09', '09201', '3200832', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '日の出', 'ヒノデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市不動前', '09', '09201', '3200833', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '不動前', 'フドウマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市陽南', '09', '09201', '3200834', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '陽南', 'ヨウナン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市宮原', '09', '09201', '3200835', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '宮原', 'ミヤハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市大和3丁目', '09', '09201', '3200836', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '大和', 'ヤマト', null, null, '3丁目', '03チョウメ');
INSERT INTO `ms_addresses` VALUES ('23707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市弥生', '09', '09201', '3200837', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '弥生', 'ヤヨイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市吉野', '09', '09201', '3200838', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '吉野', 'ヨシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市六道町', '09', '09201', '3200841', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '六道町', 'ロクドウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市京町', '09', '09201', '3200842', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '京町', 'キョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市花園町', '09', '09201', '3200843', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '花園町', 'ハナゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市菊水町', '09', '09201', '3200844', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '菊水町', 'キクスイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市明保野町', '09', '09201', '3200845', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '明保野町', 'アケボノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市滝の原', '09', '09201', '3200846', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '滝の原', 'タキノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市滝谷町', '09', '09201', '3200847', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '滝谷町', 'タキヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市幸町', '09', '09201', '3200848', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市鶴田町', '09', '09201', '3200851', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '鶴田町', 'ツルタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市下砥上町', '09', '09201', '3200852', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '下砥上町', 'シモトカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市下欠町', '09', '09201', '3200853', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '下欠町', 'シモカケマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市鷺の谷町', '09', '09201', '3200854', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '鷺の谷町', 'サギノヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市上欠町', '09', '09201', '3200855', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '上欠町', 'カミカケマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市砥上町', '09', '09201', '3200856', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '砥上町', 'トカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市西', '09', '09201', '3200861', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '西', 'ニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市西原', '09', '09201', '3200862', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '西原', 'ニシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市操町', '09', '09201', '3200863', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '操町', 'ミサオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市住吉町', '09', '09201', '3200864', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '住吉町', 'スミヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市睦町', '09', '09201', '3200865', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '睦町', 'ムツミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市西大寛', '09', '09201', '3200866', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '西大寛', 'ニシダイカン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市大寛', '09', '09201', '3200867', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '大寛', 'ダイカン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市', '09', '09201', '3210000', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('23780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市江曽島本町', '09', '09201', '3210101', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '江曽島本町', 'エソジマホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市江曽島町', '09', '09201', '3210102', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '江曽島町', 'エソジママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市台新田町', '09', '09201', '3210103', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '台新田町', 'ダイシンデンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市台新田', '09', '09201', '3210104', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '台新田', 'ダイシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市横田新町', '09', '09201', '3210105', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '横田新町', 'ヨコタシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市上横田町', '09', '09201', '3210106', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '上横田町', 'カミヨコタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市江曽島', '09', '09201', '3210107', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '江曽島', 'エソジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市春日町', '09', '09201', '3210108', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '春日町', 'カスガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市川田町', '09', '09201', '3210111', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '川田町', 'カワダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市屋板町', '09', '09201', '3210112', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '屋板町', 'ヤイタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市砂田町', '09', '09201', '3210113', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '砂田町', 'スナタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市中島町', '09', '09201', '3210114', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '中島町', 'ナカジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市上御田町', '09', '09201', '3210115', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '上御田町', 'カミミタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市東横田町', '09', '09201', '3210116', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '東横田町', 'ヒガシヨコタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市城南', '09', '09201', '3210117', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '城南', 'ジョウナン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市インターパーク', '09', '09201', '3210118', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', 'インターパーク', 'インターパーク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市雀宮町', '09', '09201', '3210121', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '雀宮町', 'スズメノミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市下反町町', '09', '09201', '3210122', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '下反町町', 'シモソリマチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市東谷町', '09', '09201', '3210123', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '東谷町', 'トウヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市下横田町', '09', '09201', '3210124', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '下横田町', 'シモヨコタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市御田長島町', '09', '09201', '3210125', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '御田長島町', 'ミタナガシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市茂原町', '09', '09201', '3210126', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '茂原町', 'モバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市羽牛田町', '09', '09201', '3210127', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '羽牛田町', 'ハギュウダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市宮の内', '09', '09201', '3210131', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '宮の内', 'ミヤノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市雀の宮', '09', '09201', '3210132', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '雀の宮', 'スズメノミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市新富町', '09', '09201', '3210133', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '新富町', 'シントミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市高砂町', '09', '09201', '3210134', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '高砂町', 'タカサゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市五代', '09', '09201', '3210135', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '五代', 'ゴダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市みどり野町', '09', '09201', '3210136', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', 'みどり野町', 'ミドリノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市針ケ谷', '09', '09201', '3210137', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '針ケ谷', 'ハリガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市兵庫塚', '09', '09201', '3210138', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '兵庫塚', 'ヒョウゴツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市若松原', '09', '09201', '3210139', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '若松原', 'ワカマツハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市さつき', '09', '09201', '3210141', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', 'さつき', 'サツキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市南町', '09', '09201', '3210142', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '南町', 'ミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市南高砂町', '09', '09201', '3210143', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '南高砂町', 'ミナミタカサゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市末広', '09', '09201', '3210144', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '末広', 'スエヒロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市茂原', '09', '09201', '3210145', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '茂原', 'モバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市富士見町', '09', '09201', '3210146', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '富士見町', 'フジミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市針ケ谷町', '09', '09201', '3210147', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '針ケ谷町', 'ハリガヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市西川田町', '09', '09201', '3210151', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '西川田町', 'ニシカワタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市西川田', '09', '09201', '3210152', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '西川田', 'ニシカワタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市北若松原', '09', '09201', '3210153', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '北若松原', 'キタワカマツハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市西川田東町', '09', '09201', '3210154', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '西川田東町', 'ニシカワタヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市西川田南', '09', '09201', '3210155', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '西川田南', 'ニシカワタミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市兵庫塚町', '09', '09201', '3210156', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '兵庫塚町', 'ヒョウゴツカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市幕田町', '09', '09201', '3210157', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '幕田町', 'マクタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市西川田本町', '09', '09201', '3210158', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '西川田本町', 'ニシカワタホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市大塚町', '09', '09201', '3210161', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '大塚町', 'オオツカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市大和1丁目', '09', '09201', '3210162', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '大和', 'ヤマト', null, null, '1丁目', '01チョウメ');
INSERT INTO `ms_addresses` VALUES ('23829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市大和2丁目', '09', '09201', '3210162', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '大和', 'ヤマト', null, null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('23830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市宮本町', '09', '09201', '3210163', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '宮本町', 'ミヤモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市双葉', '09', '09201', '3210164', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '双葉', 'フタバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市緑', '09', '09201', '3210165', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '緑', 'ミドリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市今宮', '09', '09201', '3210166', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '今宮', 'イマミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市東浦町', '09', '09201', '3210167', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '東浦町', 'ヒガシウラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市東原町', '09', '09201', '3210168', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '東原町', 'ヒガシハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市八千代', '09', '09201', '3210169', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '八千代', 'ヤチヨ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡壬生町', '09', '09361', '3210200', '栃木県', 'トチギケン', '下都賀郡壬生町', 'シモツガグンミブマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('23840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡壬生町安塚', '09', '09361', '3210201', '栃木県', 'トチギケン', '下都賀郡壬生町', 'シモツガグンミブマチ', '安塚', 'ヤスヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡壬生町おもちゃのまち', '09', '09361', '3210202', '栃木県', 'トチギケン', '下都賀郡壬生町', 'シモツガグンミブマチ', 'おもちゃのまち', 'オモチャノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡壬生町幸町', '09', '09361', '3210203', '栃木県', 'トチギケン', '下都賀郡壬生町', 'シモツガグンミブマチ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡壬生町緑町', '09', '09361', '3210204', '栃木県', 'トチギケン', '下都賀郡壬生町', 'シモツガグンミブマチ', '緑町', 'ミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡壬生町若草町', '09', '09361', '3210205', '栃木県', 'トチギケン', '下都賀郡壬生町', 'シモツガグンミブマチ', '若草町', 'ワカクサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡壬生町あけぼの町', '09', '09361', '3210206', '栃木県', 'トチギケン', '下都賀郡壬生町', 'シモツガグンミブマチ', 'あけぼの町', 'アケボノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡壬生町北小林', '09', '09361', '3210207', '栃木県', 'トチギケン', '下都賀郡壬生町', 'シモツガグンミブマチ', '北小林', 'キタコバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡壬生町国谷', '09', '09361', '3210211', '栃木県', 'トチギケン', '下都賀郡壬生町', 'シモツガグンミブマチ', '国谷', 'クニヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡壬生町寿町', '09', '09361', '3210212', '栃木県', 'トチギケン', '下都賀郡壬生町', 'シモツガグンミブマチ', '寿町', 'コトブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡壬生町いずみ町', '09', '09361', '3210213', '栃木県', 'トチギケン', '下都賀郡壬生町', 'シモツガグンミブマチ', 'いずみ町', 'イズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡壬生町壬生甲', '09', '09361', '3210214', '栃木県', 'トチギケン', '下都賀郡壬生町', 'シモツガグンミブマチ', '壬生甲', 'ミブコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡壬生町壬生乙', '09', '09361', '3210215', '栃木県', 'トチギケン', '下都賀郡壬生町', 'シモツガグンミブマチ', '壬生乙', 'ミブオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡壬生町壬生丁', '09', '09361', '3210216', '栃木県', 'トチギケン', '下都賀郡壬生町', 'シモツガグンミブマチ', '壬生丁', 'ミブテイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡壬生町至宝', '09', '09361', '3210217', '栃木県', 'トチギケン', '下都賀郡壬生町', 'シモツガグンミブマチ', '至宝', 'シホウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡壬生町落合', '09', '09361', '3210218', '栃木県', 'トチギケン', '下都賀郡壬生町', 'シモツガグンミブマチ', '落合', 'オチアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡壬生町福和田', '09', '09361', '3210219', '栃木県', 'トチギケン', '下都賀郡壬生町', 'シモツガグンミブマチ', '福和田', 'フクワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡壬生町藤井', '09', '09361', '3210221', '栃木県', 'トチギケン', '下都賀郡壬生町', 'シモツガグンミブマチ', '藤井', 'フジイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡壬生町駅東町', '09', '09361', '3210222', '栃木県', 'トチギケン', '下都賀郡壬生町', 'シモツガグンミブマチ', '駅東町', 'エキヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡壬生町元町', '09', '09361', '3210223', '栃木県', 'トチギケン', '下都賀郡壬生町', 'シモツガグンミブマチ', '元町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡壬生町表町', '09', '09361', '3210224', '栃木県', 'トチギケン', '下都賀郡壬生町', 'シモツガグンミブマチ', '表町', 'オモテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡壬生町本丸', '09', '09361', '3210225', '栃木県', 'トチギケン', '下都賀郡壬生町', 'シモツガグンミブマチ', '本丸', 'ホンマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡壬生町中央町', '09', '09361', '3210226', '栃木県', 'トチギケン', '下都賀郡壬生町', 'シモツガグンミブマチ', '中央町', 'チュウオウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡壬生町通町', '09', '09361', '3210227', '栃木県', 'トチギケン', '下都賀郡壬生町', 'シモツガグンミブマチ', '通町', 'トオリマチ', null, null, null, null), ('23863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡壬生町大師町', '09', '09361', '3210228', '栃木県', 'トチギケン', '下都賀郡壬生町', 'シモツガグンミブマチ', '大師町', 'ダイシマチ', null, null, null, null), ('23864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡壬生町上田', '09', '09361', '3210231', '栃木県', 'トチギケン', '下都賀郡壬生町', 'シモツガグンミブマチ', '上田', 'カミダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡壬生町中泉', '09', '09361', '3210232', '栃木県', 'トチギケン', '下都賀郡壬生町', 'シモツガグンミブマチ', '中泉', 'ナカイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡壬生町助谷', '09', '09361', '3210233', '栃木県', 'トチギケン', '下都賀郡壬生町', 'シモツガグンミブマチ', '助谷', 'スケガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡壬生町羽生田', '09', '09361', '3210234', '栃木県', 'トチギケン', '下都賀郡壬生町', 'シモツガグンミブマチ', '羽生田', 'ハニュウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡壬生町七ツ石', '09', '09361', '3210235', '栃木県', 'トチギケン', '下都賀郡壬生町', 'シモツガグンミブマチ', '七ツ石', 'ナナツイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡壬生町上稲葉', '09', '09361', '3210236', '栃木県', 'トチギケン', '下都賀郡壬生町', 'シモツガグンミブマチ', '上稲葉', 'カミイナバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡壬生町下稲葉', '09', '09361', '3210237', '栃木県', 'トチギケン', '下都賀郡壬生町', 'シモツガグンミブマチ', '下稲葉', 'シモイナバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市古賀志町', '09', '09201', '3210341', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '古賀志町', 'コガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市福岡町', '09', '09201', '3210342', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '福岡町', 'フクオカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市田下町', '09', '09201', '3210343', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '田下町', 'タゲマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市田野町', '09', '09201', '3210344', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '田野町', 'タノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市大谷町', '09', '09201', '3210345', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '大谷町', 'オオヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市下荒針町', '09', '09201', '3210346', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '下荒針町', 'シモアラハリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市飯田町', '09', '09201', '3210347', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '飯田町', 'イイダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市上小倉町', '09', '09201', '3210401', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '上小倉町', 'カミコグラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市今里町', '09', '09201', '3210402', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '今里町', 'イマザトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市下小倉町', '09', '09201', '3210403', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '下小倉町', 'シモコグラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市芦沼町', '09', '09201', '3210404', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '芦沼町', 'アシヌマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市上田町', '09', '09201', '3210405', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '上田町', 'ウワダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市金田町', '09', '09201', '3210406', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '金田町', 'カネダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市松田新田町', '09', '09201', '3210407', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '松田新田町', 'マツダシンデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市宮山田町', '09', '09201', '3210411', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '宮山田町', 'ミヤヤマダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市関白町', '09', '09201', '3210412', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '関白町', 'カンパクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市松風台', '09', '09201', '3210413', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '松風台', 'ショウフウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市中里町', '09', '09201', '3210414', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '中里町', 'ナカザトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市免ノ内町', '09', '09201', '3210415', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '免ノ内町', 'メンノウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市高松町', '09', '09201', '3210416', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '高松町', 'タカマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市冬室町', '09', '09201', '3210417', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '冬室町', 'フユムロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須烏山市志鳥', '09', '09215', '3210501', '栃木県', 'トチギケン', '那須烏山市', 'ナスカラスヤマシ', '志鳥', 'シトリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須烏山市熊田', '09', '09215', '3210502', '栃木県', 'トチギケン', '那須烏山市', 'ナスカラスヤマシ', '熊田', 'クマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須烏山市月次', '09', '09215', '3210503', '栃木県', 'トチギケン', '那須烏山市', 'ナスカラスヤマシ', '月次', 'ツキナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須烏山市下川井', '09', '09215', '3210504', '栃木県', 'トチギケン', '那須烏山市', 'ナスカラスヤマシ', '下川井', 'シモカワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須烏山市上川井', '09', '09215', '3210505', '栃木県', 'トチギケン', '那須烏山市', 'ナスカラスヤマシ', '上川井', 'カミカワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須烏山市小河原', '09', '09215', '3210511', '栃木県', 'トチギケン', '那須烏山市', 'ナスカラスヤマシ', '小河原', 'コガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須烏山市高瀬', '09', '09215', '3210512', '栃木県', 'トチギケン', '那須烏山市', 'ナスカラスヤマシ', '高瀬', 'タカセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須烏山市小塙', '09', '09215', '3210513', '栃木県', 'トチギケン', '那須烏山市', 'ナスカラスヤマシ', '小塙', 'コバナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須烏山市森田', '09', '09215', '3210514', '栃木県', 'トチギケン', '那須烏山市', 'ナスカラスヤマシ', '森田', 'モリタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須烏山市曲田', '09', '09215', '3210515', '栃木県', 'トチギケン', '那須烏山市', 'ナスカラスヤマシ', '曲田', 'マガツタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須烏山市大里', '09', '09215', '3210516', '栃木県', 'トチギケン', '那須烏山市', 'ナスカラスヤマシ', '大里', 'オオサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須烏山市東原', '09', '09215', '3210517', '栃木県', 'トチギケン', '那須烏山市', 'ナスカラスヤマシ', '東原', 'トウバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須烏山市岩子', '09', '09215', '3210521', '栃木県', 'トチギケン', '那須烏山市', 'ナスカラスヤマシ', '岩子', 'イワコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須烏山市大金', '09', '09215', '3210522', '栃木県', 'トチギケン', '那須烏山市', 'ナスカラスヤマシ', '大金', 'オオガネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須烏山市曲畑', '09', '09215', '3210523', '栃木県', 'トチギケン', '那須烏山市', 'ナスカラスヤマシ', '曲畑', 'ソリハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須烏山市八ケ代', '09', '09215', '3210524', '栃木県', 'トチギケン', '那須烏山市', 'ナスカラスヤマシ', '八ケ代', 'ヤカシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須烏山市福岡', '09', '09215', '3210525', '栃木県', 'トチギケン', '那須烏山市', 'ナスカラスヤマシ', '福岡', 'フクオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須烏山市田野倉', '09', '09215', '3210526', '栃木県', 'トチギケン', '那須烏山市', 'ナスカラスヤマシ', '田野倉', 'タノクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須烏山市宇井', '09', '09215', '3210527', '栃木県', 'トチギケン', '那須烏山市', 'ナスカラスヤマシ', '宇井', 'ウイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須烏山市小倉', '09', '09215', '3210528', '栃木県', 'トチギケン', '那須烏山市', 'ナスカラスヤマシ', '小倉', 'オグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須烏山市三箇', '09', '09215', '3210531', '栃木県', 'トチギケン', '那須烏山市', 'ナスカラスヤマシ', '三箇', 'サンガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須烏山市藤田', '09', '09215', '3210532', '栃木県', 'トチギケン', '那須烏山市', 'ナスカラスヤマシ', '藤田', 'フジタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須烏山市南大和久', '09', '09215', '3210533', '栃木県', 'トチギケン', '那須烏山市', 'ナスカラスヤマシ', '南大和久', 'ミナミオオワグ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須烏山市鴻野山', '09', '09215', '3210534', '栃木県', 'トチギケン', '那須烏山市', 'ナスカラスヤマシ', '鴻野山', 'コウノヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須烏山市小白井', '09', '09215', '3210535', '栃木県', 'トチギケン', '那須烏山市', 'ナスカラスヤマシ', '小白井', 'コジロイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須烏山市', '09', '09215', '3210600', '栃木県', 'トチギケン', '那須烏山市', 'ナスカラスヤマシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('23925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須烏山市白久', '09', '09215', '3210601', '栃木県', 'トチギケン', '那須烏山市', 'ナスカラスヤマシ', '白久', 'シラク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須烏山市大桶', '09', '09215', '3210602', '栃木県', 'トチギケン', '那須烏山市', 'ナスカラスヤマシ', '大桶', 'オオケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須烏山市谷浅見', '09', '09215', '3210603', '栃木県', 'トチギケン', '那須烏山市', 'ナスカラスヤマシ', '谷浅見', 'ヤアザミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須烏山市中山', '09', '09215', '3210604', '栃木県', 'トチギケン', '那須烏山市', 'ナスカラスヤマシ', '中山', 'ナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須烏山市滝田', '09', '09215', '3210605', '栃木県', 'トチギケン', '那須烏山市', 'ナスカラスヤマシ', '滝田', 'タキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須烏山市興野', '09', '09215', '3210611', '栃木県', 'トチギケン', '那須烏山市', 'ナスカラスヤマシ', '興野', 'キョウノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須烏山市大沢', '09', '09215', '3210612', '栃木県', 'トチギケン', '那須烏山市', 'ナスカラスヤマシ', '大沢', 'オオサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須烏山市大木須', '09', '09215', '3210613', '栃木県', 'トチギケン', '那須烏山市', 'ナスカラスヤマシ', '大木須', 'オオギス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須烏山市小木須', '09', '09215', '3210614', '栃木県', 'トチギケン', '那須烏山市', 'ナスカラスヤマシ', '小木須', 'コギス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須烏山市小原沢', '09', '09215', '3210615', '栃木県', 'トチギケン', '那須烏山市', 'ナスカラスヤマシ', '小原沢', 'コハラザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須烏山市下境', '09', '09215', '3210616', '栃木県', 'トチギケン', '那須烏山市', 'ナスカラスヤマシ', '下境', 'シモザカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須烏山市上境', '09', '09215', '3210617', '栃木県', 'トチギケン', '那須烏山市', 'ナスカラスヤマシ', '上境', 'カミザカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須烏山市横枕', '09', '09215', '3210618', '栃木県', 'トチギケン', '那須烏山市', 'ナスカラスヤマシ', '横枕', 'ヨコマクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須烏山市中央', '09', '09215', '3210621', '栃木県', 'トチギケン', '那須烏山市', 'ナスカラスヤマシ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須烏山市城東', '09', '09215', '3210622', '栃木県', 'トチギケン', '那須烏山市', 'ナスカラスヤマシ', '城東', 'ジョウトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須烏山市表', '09', '09215', '3210623', '栃木県', 'トチギケン', '那須烏山市', 'ナスカラスヤマシ', '表', 'オモテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須烏山市旭', '09', '09215', '3210624', '栃木県', 'トチギケン', '那須烏山市', 'ナスカラスヤマシ', '旭', 'アサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須烏山市宮原', '09', '09215', '3210625', '栃木県', 'トチギケン', '那須烏山市', 'ナスカラスヤマシ', '宮原', 'ミヤバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須烏山市初音', '09', '09215', '3210626', '栃木県', 'トチギケン', '那須烏山市', 'ナスカラスヤマシ', '初音', 'ハツネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須烏山市南', '09', '09215', '3210627', '栃木県', 'トチギケン', '那須烏山市', 'ナスカラスヤマシ', '南', 'ミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須烏山市金井', '09', '09215', '3210628', '栃木県', 'トチギケン', '那須烏山市', 'ナスカラスヤマシ', '金井', 'カナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須烏山市愛宕台', '09', '09215', '3210629', '栃木県', 'トチギケン', '那須烏山市', 'ナスカラスヤマシ', '愛宕台', 'アタゴダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須烏山市城山', '09', '09215', '3210631', '栃木県', 'トチギケン', '那須烏山市', 'ナスカラスヤマシ', '城山', 'シロヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須烏山市神長', '09', '09215', '3210632', '栃木県', 'トチギケン', '那須烏山市', 'ナスカラスヤマシ', '神長', 'カナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須烏山市滝', '09', '09215', '3210633', '栃木県', 'トチギケン', '那須烏山市', 'ナスカラスヤマシ', '滝', 'タキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須烏山市野上', '09', '09215', '3210634', '栃木県', 'トチギケン', '那須烏山市', 'ナスカラスヤマシ', '野上', 'ノガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須烏山市向田', '09', '09215', '3210635', '栃木県', 'トチギケン', '那須烏山市', 'ナスカラスヤマシ', '向田', 'ムカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須烏山市落合', '09', '09215', '3210636', '栃木県', 'トチギケン', '那須烏山市', 'ナスカラスヤマシ', '落合', 'オチアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市平出町', '09', '09201', '3210901', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '平出町', 'ヒライデマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市柳田町', '09', '09201', '3210902', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '柳田町', 'ヤナギタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市下平出町', '09', '09201', '3210903', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '下平出町', 'シモヒライデマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市陽東', '09', '09201', '3210904', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '陽東', 'ヨウトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市平出工業団地', '09', '09201', '3210905', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '平出工業団地', 'ヒライデコウギョウダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市中久保', '09', '09201', '3210906', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '中久保', 'ナカクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市問屋町', '09', '09201', '3210911', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '問屋町', 'トンヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市石井町', '09', '09201', '3210912', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '石井町', 'イシイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市上桑島町', '09', '09201', '3210913', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '上桑島町', 'カミクワジママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市下桑島町', '09', '09201', '3210914', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '下桑島町', 'シモクワジママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市東刑部町', '09', '09201', '3210915', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '東刑部町', 'ヒガシオサカベマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市東木代町', '09', '09201', '3210916', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '東木代町', 'ヒガシキノシロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市西刑部町', '09', '09201', '3210917', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '西刑部町', 'ニシオサカベマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市平塚町', '09', '09201', '3210918', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '平塚町', 'ヒラツカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市瑞穂', '09', '09201', '3210921', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '瑞穂', 'ミズホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市さるやま町', '09', '09201', '3210922', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', 'さるやま町', 'サルヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市下栗町', '09', '09201', '3210923', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '下栗町', 'シモグリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市下栗', '09', '09201', '3210924', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '下栗', 'シモグリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市東簗瀬', '09', '09201', '3210925', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '東簗瀬', 'ヒガシヤナゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市平松町', '09', '09201', '3210931', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '平松町', 'ヒラマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市平松本町', '09', '09201', '3210932', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '平松本町', 'ヒラマツホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市簗瀬町', '09', '09201', '3210933', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '簗瀬町', 'ヤナゼマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市簗瀬', '09', '09201', '3210934', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '簗瀬', 'ヤナゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市東今泉', '09', '09201', '3210941', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '東今泉', 'ヒガシイマイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市峰', '09', '09201', '3210942', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '峰', 'ミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市峰町', '09', '09201', '3210943', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '峰町', 'ミネマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市東峰町', '09', '09201', '3210944', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '東峰町', 'ヒガシミネマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市宿郷', '09', '09201', '3210945', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '宿郷', 'シュクゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市越戸', '09', '09201', '3210951', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '越戸', 'コエド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市越戸町', '09', '09201', '3210951', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '越戸町', 'コエドマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市泉が丘', '09', '09201', '3210952', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '泉が丘', 'イズミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市東宿郷', '09', '09201', '3210953', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '東宿郷', 'ヒガシシュクゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市元今泉', '09', '09201', '3210954', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '元今泉', 'モトイマイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市今泉新町', '09', '09201', '3210961', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '今泉新町', 'イマイズミシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市今泉町', '09', '09201', '3210962', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '今泉町', 'イマイズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市南大通り', '09', '09201', '3210963', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '南大通り', 'ミナミオオドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市駅前通り', '09', '09201', '3210964', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '駅前通り', 'エキマエドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市川向町', '09', '09201', '3210965', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '川向町', 'カワムコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市今泉', '09', '09201', '3210966', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '今泉', 'イマイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市錦', '09', '09201', '3210967', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '錦', 'ニシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市中今泉', '09', '09201', '3210968', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '中今泉', 'ナカイマイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市海道町', '09', '09201', '3210971', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '海道町', 'カイドウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市下川俣町', '09', '09201', '3210972', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '下川俣町', 'シモカワマタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市岩曽町', '09', '09201', '3210973', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '岩曽町', 'イワゾマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市竹林町', '09', '09201', '3210974', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '竹林町', 'タケバヤシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('23999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市関堀町', '09', '09201', '3210975', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '関堀町', 'セキボリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市岩本町', '09', '09201', '3210976', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '岩本町', 'イワモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市川俣町', '09', '09201', '3210977', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '川俣町', 'カワマタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市上野町', '09', '09201', '3210981', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '上野町', 'ウエノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市御幸ケ原町', '09', '09201', '3210982', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '御幸ケ原町', 'ミユキガハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市御幸本町', '09', '09201', '3210983', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '御幸本町', 'ミユキホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市御幸町', '09', '09201', '3210984', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '御幸町', 'ミユキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市東町', '09', '09201', '3210985', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '東町', 'ヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市明神', '09', '09206', '3211101', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '明神', 'ミョウジン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市板橋', '09', '09206', '3211102', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '板橋', 'イタバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市手岡', '09', '09206', '3211103', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '手岡', 'チョウカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市岩崎', '09', '09206', '3211104', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '岩崎', 'イワザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市文挾町', '09', '09206', '3211105', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '文挾町', 'フバサミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市小倉', '09', '09206', '3211106', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '小倉', 'コグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市小代', '09', '09206', '3211107', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '小代', 'コシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市長畑', '09', '09206', '3211108', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '長畑', 'ナガハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市板荷', '09', '09205', '3211111', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '板荷', 'イタガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市今市', '09', '09206', '3211261', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '今市', 'イマイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市平ケ崎', '09', '09206', '3211262', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '平ケ崎', 'ヒラガサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市瀬川', '09', '09206', '3211263', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '瀬川', 'セガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市瀬尾', '09', '09206', '3211264', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '瀬尾', 'セノオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市小百', '09', '09206', '3211265', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '小百', 'コビャク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市並木町', '09', '09206', '3211271', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '並木町', 'ナミキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市今市本町', '09', '09206', '3211272', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '今市本町', 'イマイチホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市吉沢', '09', '09206', '3211273', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '吉沢', 'キチサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市土沢', '09', '09206', '3211274', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '土沢', 'ドサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市室瀬', '09', '09206', '3211275', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '室瀬', 'ムロゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市下の内', '09', '09206', '3211276', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '下の内', 'シモノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市千本木', '09', '09206', '3211277', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '千本木', 'センボンギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市東小来川', '09', '09206', '3211351', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '東小来川', 'ヒガシオコロガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市宮小来川', '09', '09206', '3211352', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '宮小来川', 'ミヤオコロガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市南小来川', '09', '09206', '3211353', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '南小来川', 'ミナミオコロガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市中小来川', '09', '09206', '3211354', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '中小来川', 'ナカオコロガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市西小来川', '09', '09206', '3211355', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '西小来川', 'ニシオコロガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市滝ケ原', '09', '09206', '3211356', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '滝ケ原', 'タキガハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市', '09', '09206', '3211400', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('24037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市上鉢石町', '09', '09206', '3211401', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '上鉢石町', 'カミハツイシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市中鉢石町', '09', '09206', '3211402', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '中鉢石町', 'ナカハツイシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市下鉢石町', '09', '09206', '3211403', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '下鉢石町', 'シモハツイシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市御幸町', '09', '09206', '3211404', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '御幸町', 'ゴコウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市石屋町', '09', '09206', '3211405', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '石屋町', 'イシヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市松原町', '09', '09206', '3211406', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '松原町', 'マツバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市若杉町', '09', '09206', '3211407', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '若杉町', 'ワカスギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市稲荷町', '09', '09206', '3211411', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '稲荷町', 'イナリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市東和町', '09', '09206', '3211412', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '東和町', 'トウワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市相生町', '09', '09206', '3211413', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '相生町', 'アイオイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市萩垣面', '09', '09206', '3211414', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '萩垣面', 'ハンガキメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市日光', '09', '09206', '3211415', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '日光', 'ニッコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市所野', '09', '09206', '3211421', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '所野', 'トコロノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市宝殿', '09', '09206', '3211422', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '宝殿', 'ホウデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市七里', '09', '09206', '3211423', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '七里', 'シチリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市野口', '09', '09206', '3211424', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '野口', 'ノグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市和泉', '09', '09206', '3211425', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '和泉', 'イズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市山久保', '09', '09206', '3211426', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '山久保', 'ヤマクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市山内', '09', '09206', '3211431', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '山内', 'サンナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市安川町', '09', '09206', '3211432', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '安川町', 'ヤスカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市匠町', '09', '09206', '3211433', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '匠町', 'タクミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市本町', '09', '09206', '3211434', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市花石町', '09', '09206', '3211435', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '花石町', 'ハナイシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市久次良町', '09', '09206', '3211436', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '久次良町', 'クジラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市清滝安良沢町', '09', '09206', '3211441', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '清滝安良沢町', 'キヨタキアラサワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市清滝丹勢町', '09', '09206', '3211442', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '清滝丹勢町', 'キヨタキタンゼマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市清滝桜ケ丘町', '09', '09206', '3211443', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '清滝桜ケ丘町', 'キヨタキサクラガオカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市清滝', '09', '09206', '3211444', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '清滝', 'キヨタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市細尾町', '09', '09206', '3211445', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '細尾町', 'ホソオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市清滝中安戸町', '09', '09206', '3211446', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '清滝中安戸町', 'キヨタキナカヤスドマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市清滝和の代町', '09', '09206', '3211447', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '清滝和の代町', 'キヨタキワノシロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市清滝新細尾町', '09', '09206', '3211448', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '清滝新細尾町', 'キヨタキシンホソオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市丹勢', '09', '09206', '3211449', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '丹勢', 'タンゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市足尾町愛宕下', '09', '09206', '3211501', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '足尾町愛宕下', 'アシオマチアタゴシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市足尾町赤倉', '09', '09206', '3211502', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '足尾町赤倉', 'アシオマチアカクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市足尾町深沢', '09', '09206', '3211503', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '足尾町深沢', 'アシオマチフカサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市足尾町上間藤', '09', '09206', '3211504', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '足尾町上間藤', 'アシオマチカミマトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市足尾町上の平', '09', '09206', '3211505', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '足尾町上の平', 'アシオマチウエノタイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市足尾町下間藤', '09', '09206', '3211506', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '足尾町下間藤', 'アシオマチシモマトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市足尾町南橋', '09', '09206', '3211507', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '足尾町南橋', 'アシオマチナンキョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市足尾町本山', '09', '09206', '3211508', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '足尾町本山', 'アシオマチホンザン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市足尾町', '09', '09206', '3211511', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '足尾町', 'アシオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市足尾町掛水', '09', '09206', '3211512', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '足尾町掛水', 'アシオマチカケミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市足尾町向原', '09', '09206', '3211513', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '足尾町向原', 'アシオマチムカイハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市足尾町通洞', '09', '09206', '3211514', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '足尾町通洞', 'アシオマチツウドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市足尾町砂畑', '09', '09206', '3211515', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '足尾町砂畑', 'アシオマチスナハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市足尾町遠下', '09', '09206', '3211521', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '足尾町遠下', 'アシオマチトオジモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市足尾町中才', '09', '09206', '3211522', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '足尾町中才', 'アシオマチナカサイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市足尾町松原', '09', '09206', '3211523', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '足尾町松原', 'アシオマチマツバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市足尾町赤沢', '09', '09206', '3211524', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '足尾町赤沢', 'アシオマチアカサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市中宮祠', '09', '09206', '3211661', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '中宮祠', 'チュウグウシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市湯元', '09', '09206', '3211662', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '湯元', 'ユモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市飯山町', '09', '09201', '3212101', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '飯山町', 'イイヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市篠井町', '09', '09201', '3212102', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '篠井町', 'シノイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市石那田町', '09', '09201', '3212103', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '石那田町', 'イシナダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市上小池町', '09', '09201', '3212104', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '上小池町', 'カミコイケマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市下小池町', '09', '09201', '3212105', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '下小池町', 'シモコイケマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市大網町', '09', '09201', '3212111', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '大網町', 'オオアミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市上横倉町', '09', '09201', '3212112', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '上横倉町', 'カミヨコクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市下横倉町', '09', '09201', '3212113', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '下横倉町', 'シモヨコクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市下金井町', '09', '09201', '3212114', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '下金井町', 'シモカナイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市上金井町', '09', '09201', '3212115', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '上金井町', 'カミカナイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市徳次郎町', '09', '09201', '3212116', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '徳次郎町', 'トクジロウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市岩原町', '09', '09201', '3212117', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '岩原町', 'イワハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市新里町', '09', '09201', '3212118', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '新里町', 'ニッサトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市針貝', '09', '09206', '3212331', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '針貝', 'ハリガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市大室', '09', '09206', '3212332', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '大室', 'オオムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市薄井沢', '09', '09206', '3212333', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '薄井沢', 'ウスイザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市水無', '09', '09206', '3212334', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '水無', 'ミズナシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市森友', '09', '09206', '3212335', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '森友', 'モリトモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市荊沢', '09', '09206', '3212336', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '荊沢', 'オトロザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市大沢町', '09', '09206', '3212341', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '大沢町', 'オオサワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市根室', '09', '09206', '3212342', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '根室', 'ネムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市山口', '09', '09206', '3212343', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '山口', 'ヤマグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市猪倉', '09', '09206', '3212344', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '猪倉', 'イノクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市木和田島', '09', '09206', '3212345', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '木和田島', 'キワダシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市塩野室町', '09', '09206', '3212351', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '塩野室町', 'シオノムロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市小林', '09', '09206', '3212352', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '小林', 'コバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市沓掛', '09', '09206', '3212353', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '沓掛', 'クツカケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市嘉多蔵', '09', '09206', '3212354', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '嘉多蔵', 'カタクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市沢又', '09', '09206', '3212355', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '沢又', 'サワマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市矢野口', '09', '09206', '3212356', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '矢野口', 'ヤノクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市川室', '09', '09206', '3212401', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '川室', 'カワムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市大渡', '09', '09206', '3212402', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '大渡', 'オオワタリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市町谷', '09', '09206', '3212403', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '町谷', 'マチヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市轟', '09', '09206', '3212404', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '轟', 'トドロク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市芹沼', '09', '09206', '3212405', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '芹沼', 'セリヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市大桑町', '09', '09206', '3212411', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '大桑町', 'オオクワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市倉ケ崎', '09', '09206', '3212412', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '倉ケ崎', 'クラガサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市倉ケ崎新田', '09', '09206', '3212413', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '倉ケ崎新田', 'クラガサキシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市豊田', '09', '09206', '3212414', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '豊田', 'トヨダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市栗原', '09', '09206', '3212421', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '栗原', 'クリバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市高柴', '09', '09206', '3212422', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '高柴', 'タカシバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市原宿', '09', '09206', '3212423', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '原宿', 'ハラジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市小百鳥屋下', '09', '09206', '3212424', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '小百', 'コビャク', null, null, '鳥屋下', 'トヤシタ');
INSERT INTO `ms_addresses` VALUES ('24135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市小百楢原', '09', '09206', '3212425', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '小百', 'コビャク', null, null, '楢原', 'ナラハラ');
INSERT INTO `ms_addresses` VALUES ('24136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市小百筒置', '09', '09206', '3212426', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '小百', 'コビャク', null, null, '筒置', 'ツツオキ');
INSERT INTO `ms_addresses` VALUES ('24137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市佐下部', '09', '09206', '3212427', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '佐下部', 'サゲブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県塩谷郡塩谷町上寺島', '09', '09384', '3212501', '栃木県', 'トチギケン', '塩谷郡塩谷町', 'シオヤグンシオヤマチ', '上寺島', 'カミテラシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市藤原', '09', '09206', '3212521', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '藤原', 'フジハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市鬼怒川温泉大原', '09', '09206', '3212522', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '鬼怒川温泉大原', 'キヌガワオンセンオオハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市高徳', '09', '09206', '3212523', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '高徳', 'タカトク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市柄倉', '09', '09206', '3212524', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '柄倉', 'カラクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市小佐越', '09', '09206', '3212525', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '小佐越', 'コサゴエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市鬼怒川温泉滝', '09', '09206', '3212526', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '鬼怒川温泉滝', 'キヌガワオンセンタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市湯西川', '09', '09206', '3212601', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '湯西川', 'ユニシカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市一ツ石', '09', '09206', '3212602', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '一ツ石', 'ヒトツイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市西川', '09', '09206', '3212603', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '西川', 'ニシカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市赤下', '09', '09206', '3212604', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '赤下', 'アカシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市川治温泉川治', '09', '09206', '3212611', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '川治温泉川治', 'カワジオンセンカワジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市川治温泉高原', '09', '09206', '3212612', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '川治温泉高原', 'カワジオンセンタカハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市藤原', '09', '09206', '3212613', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '藤原', 'フジハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市川治温泉滝', '09', '09206', '3212614', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '川治温泉滝', 'カワジオンセンタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市五十里東山', '09', '09206', '3212615', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '五十里', 'イカリ', null, null, '東山', 'ヒガシヤマ');
INSERT INTO `ms_addresses` VALUES ('24161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市高原', '09', '09206', '3212616', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '高原', 'タカハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市日向', '09', '09206', '3212711', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '日向', 'ヒナタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市日蔭', '09', '09206', '3212712', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '日蔭', 'ヒカゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市黒部', '09', '09206', '3212713', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '黒部', 'クロベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市土呂部', '09', '09206', '3212714', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '土呂部', 'ドロブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市上栗山', '09', '09206', '3212715', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '上栗山', 'カミクリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市野門', '09', '09206', '3212716', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '野門', 'ノカド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市川俣', '09', '09206', '3212717', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '川俣', 'カワマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市若間', '09', '09206', '3212718', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '若間', 'ワカマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市横川', '09', '09206', '3212801', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '横川', 'ヨコカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市上三依', '09', '09206', '3212802', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '上三依', 'カミミヨリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市中三依', '09', '09206', '3212803', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '中三依', 'ナカミヨリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市芹沢', '09', '09206', '3212804', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '芹沢', 'セリサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市独鈷沢', '09', '09206', '3212805', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '独鈷沢', 'トッコザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県日光市五十里', '09', '09206', '3212806', '栃木県', 'トチギケン', '日光市', 'ニッコウシ', '五十里', 'イカリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市板戸町', '09', '09201', '3213221', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '板戸町', 'イタドマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市野高谷町', '09', '09201', '3213222', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '野高谷町', 'ノゴヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市清原台', '09', '09201', '3213223', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '清原台', 'キヨハラダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市刈沼町', '09', '09201', '3213224', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '刈沼町', 'カリヌママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市満美穴町', '09', '09201', '3213225', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '満美穴町', 'マミアナマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市清原工業団地', '09', '09201', '3213231', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '清原工業団地', 'キヨハラコウギョウダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市氷室町', '09', '09201', '3213232', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '氷室町', 'ヒムロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市上籠谷町', '09', '09201', '3213233', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '上籠谷町', 'カミコモリヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市桑島町', '09', '09201', '3213234', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '桑島町', 'クワジママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市鐺山町', '09', '09201', '3213235', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '鐺山町', 'コテヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市竹下町', '09', '09201', '3213236', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '竹下町', 'タケシタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市道場宿町', '09', '09201', '3213237', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '道場宿町', 'ドウジョウジュクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県芳賀郡芳賀町', '09', '09345', '3213300', '栃木県', 'トチギケン', '芳賀郡芳賀町', 'ハガグンハガマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('24196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県芳賀郡芳賀町給部', '09', '09345', '3213301', '栃木県', 'トチギケン', '芳賀郡芳賀町', 'ハガグンハガマチ', '給部', 'キュウブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県芳賀郡芳賀町上稲毛田', '09', '09345', '3213302', '栃木県', 'トチギケン', '芳賀郡芳賀町', 'ハガグンハガマチ', '上稲毛田', 'カミイナゲタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県芳賀郡芳賀町稲毛田', '09', '09345', '3213303', '栃木県', 'トチギケン', '芳賀郡芳賀町', 'ハガグンハガマチ', '稲毛田', 'イナゲタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県芳賀郡芳賀町祖母井', '09', '09345', '3213304', '栃木県', 'トチギケン', '芳賀郡芳賀町', 'ハガグンハガマチ', '祖母井', 'ウバガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県芳賀郡芳賀町芳志戸', '09', '09345', '3213305', '栃木県', 'トチギケン', '芳賀郡芳賀町', 'ハガグンハガマチ', '芳志戸', 'ホウシト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県芳賀郡芳賀町八ッ木', '09', '09345', '3213306', '栃木県', 'トチギケン', '芳賀郡芳賀町', 'ハガグンハガマチ', '八ッ木', 'ヤツキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県芳賀郡芳賀町上延生', '09', '09345', '3213311', '栃木県', 'トチギケン', '芳賀郡芳賀町', 'ハガグンハガマチ', '上延生', 'カミノブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県芳賀郡芳賀町下延生', '09', '09345', '3213312', '栃木県', 'トチギケン', '芳賀郡芳賀町', 'ハガグンハガマチ', '下延生', 'シモノブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県芳賀郡芳賀町東高橋', '09', '09345', '3213313', '栃木県', 'トチギケン', '芳賀郡芳賀町', 'ハガグンハガマチ', '東高橋', 'ヒガシタカハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県芳賀郡芳賀町打越新田', '09', '09345', '3213314', '栃木県', 'トチギケン', '芳賀郡芳賀町', 'ハガグンハガマチ', '打越新田', 'ウチゴシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県芳賀郡芳賀町西高橋', '09', '09345', '3213315', '栃木県', 'トチギケン', '芳賀郡芳賀町', 'ハガグンハガマチ', '西高橋', 'ニシタカハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県芳賀郡芳賀町与能', '09', '09345', '3213316', '栃木県', 'トチギケン', '芳賀郡芳賀町', 'ハガグンハガマチ', '与能', 'ヨノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県芳賀郡芳賀町下高根沢', '09', '09345', '3213321', '栃木県', 'トチギケン', '芳賀郡芳賀町', 'ハガグンハガマチ', '下高根沢', 'シモタカネサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県芳賀郡芳賀町東水沼', '09', '09345', '3213322', '栃木県', 'トチギケン', '芳賀郡芳賀町', 'ハガグンハガマチ', '東水沼', 'ヒガシミズヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県芳賀郡芳賀町北長島', '09', '09345', '3213323', '栃木県', 'トチギケン', '芳賀郡芳賀町', 'ハガグンハガマチ', '北長島', 'キタナガシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県芳賀郡芳賀町西水沼', '09', '09345', '3213324', '栃木県', 'トチギケン', '芳賀郡芳賀町', 'ハガグンハガマチ', '西水沼', 'ニシミズヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県芳賀郡芳賀町芳賀台', '09', '09345', '3213325', '栃木県', 'トチギケン', '芳賀郡芳賀町', 'ハガグンハガマチ', '芳賀台', 'ハガダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県芳賀郡市貝町', '09', '09344', '3213400', '栃木県', 'トチギケン', '芳賀郡市貝町', 'ハガグンイチカイマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('24215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県芳賀郡市貝町竹内', '09', '09344', '3213401', '栃木県', 'トチギケン', '芳賀郡市貝町', 'ハガグンイチカイマチ', '竹内', 'タケウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県芳賀郡市貝町見上', '09', '09344', '3213402', '栃木県', 'トチギケン', '芳賀郡市貝町', 'ハガグンイチカイマチ', '見上', 'ミアゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県芳賀郡市貝町羽仏', '09', '09344', '3213403', '栃木県', 'トチギケン', '芳賀郡市貝町', 'ハガグンイチカイマチ', '羽仏', 'ハブツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県芳賀郡市貝町続谷', '09', '09344', '3213404', '栃木県', 'トチギケン', '芳賀郡市貝町', 'ハガグンイチカイマチ', '続谷', 'ツヅキヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県芳賀郡市貝町大谷津', '09', '09344', '3213405', '栃木県', 'トチギケン', '芳賀郡市貝町', 'ハガグンイチカイマチ', '大谷津', 'オオヤツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県芳賀郡市貝町塩田', '09', '09344', '3213406', '栃木県', 'トチギケン', '芳賀郡市貝町', 'ハガグンイチカイマチ', '塩田', 'シオダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県芳賀郡市貝町刈生田', '09', '09344', '3213411', '栃木県', 'トチギケン', '芳賀郡市貝町', 'ハガグンイチカイマチ', '刈生田', 'カリウタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県芳賀郡市貝町田野辺', '09', '09344', '3213412', '栃木県', 'トチギケン', '芳賀郡市貝町', 'ハガグンイチカイマチ', '田野辺', 'タノベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県芳賀郡市貝町文谷', '09', '09344', '3213413', '栃木県', 'トチギケン', '芳賀郡市貝町', 'ハガグンイチカイマチ', '文谷', 'フミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県芳賀郡市貝町椎谷', '09', '09344', '3213414', '栃木県', 'トチギケン', '芳賀郡市貝町', 'ハガグンイチカイマチ', '椎谷', 'シュウガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県芳賀郡市貝町杉山', '09', '09344', '3213415', '栃木県', 'トチギケン', '芳賀郡市貝町', 'ハガグンイチカイマチ', '杉山', 'スギヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県芳賀郡市貝町笹原田', '09', '09344', '3213421', '栃木県', 'トチギケン', '芳賀郡市貝町', 'ハガグンイチカイマチ', '笹原田', 'ササハラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県芳賀郡市貝町石下', '09', '09344', '3213422', '栃木県', 'トチギケン', '芳賀郡市貝町', 'ハガグンイチカイマチ', '石下', 'イシオロシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県芳賀郡市貝町市塙', '09', '09344', '3213423', '栃木県', 'トチギケン', '芳賀郡市貝町', 'ハガグンイチカイマチ', '市塙', 'イチハナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県芳賀郡市貝町上根', '09', '09344', '3213424', '栃木県', 'トチギケン', '芳賀郡市貝町', 'ハガグンイチカイマチ', '上根', 'カミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県芳賀郡市貝町多田羅', '09', '09344', '3213425', '栃木県', 'トチギケン', '芳賀郡市貝町', 'ハガグンイチカイマチ', '多田羅', 'タタラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県芳賀郡市貝町赤羽', '09', '09344', '3213426', '栃木県', 'トチギケン', '芳賀郡市貝町', 'ハガグンイチカイマチ', '赤羽', 'アカバネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県芳賀郡茂木町', '09', '09343', '3213500', '栃木県', 'トチギケン', '芳賀郡茂木町', 'ハガグンモテギマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('24236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県芳賀郡茂木町茂木', '09', '09343', '3213531', '栃木県', 'トチギケン', '芳賀郡茂木町', 'ハガグンモテギマチ', '茂木', 'モテギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県芳賀郡茂木町三坂', '09', '09343', '3213532', '栃木県', 'トチギケン', '芳賀郡茂木町', 'ハガグンモテギマチ', '三坂', 'ミサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県芳賀郡茂木町桧山', '09', '09343', '3213533', '栃木県', 'トチギケン', '芳賀郡茂木町', 'ハガグンモテギマチ', '桧山', 'ヒヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県芳賀郡茂木町青梅', '09', '09343', '3213534', '栃木県', 'トチギケン', '芳賀郡茂木町', 'ハガグンモテギマチ', '青梅', 'オウメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県芳賀郡茂木町鮎田', '09', '09343', '3213535', '栃木県', 'トチギケン', '芳賀郡茂木町', 'ハガグンモテギマチ', '鮎田', 'アイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県芳賀郡茂木町神井', '09', '09343', '3213536', '栃木県', 'トチギケン', '芳賀郡茂木町', 'ハガグンモテギマチ', '神井', 'カノイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県芳賀郡茂木町烏生田', '09', '09343', '3213541', '栃木県', 'トチギケン', '芳賀郡茂木町', 'ハガグンモテギマチ', '烏生田', 'ウゴウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県芳賀郡茂木町九石', '09', '09343', '3213542', '栃木県', 'トチギケン', '芳賀郡茂木町', 'ハガグンモテギマチ', '九石', 'サザラシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県芳賀郡茂木町上後郷', '09', '09343', '3213543', '栃木県', 'トチギケン', '芳賀郡茂木町', 'ハガグンモテギマチ', '上後郷', 'カミウラゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県芳賀郡茂木町坂井', '09', '09343', '3213544', '栃木県', 'トチギケン', '芳賀郡茂木町', 'ハガグンモテギマチ', '坂井', 'サカノイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県芳賀郡茂木町下菅又', '09', '09343', '3213545', '栃木県', 'トチギケン', '芳賀郡茂木町', 'ハガグンモテギマチ', '下菅又', 'シモスガマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県芳賀郡茂木町上菅又', '09', '09343', '3213546', '栃木県', 'トチギケン', '芳賀郡茂木町', 'ハガグンモテギマチ', '上菅又', 'カミスガマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県芳賀郡茂木町千本', '09', '09343', '3213547', '栃木県', 'トチギケン', '芳賀郡茂木町', 'ハガグンモテギマチ', '千本', 'センボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県芳賀郡茂木町生井', '09', '09343', '3213551', '栃木県', 'トチギケン', '芳賀郡茂木町', 'ハガグンモテギマチ', '生井', 'ナマイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県芳賀郡茂木町竹原', '09', '09343', '3213552', '栃木県', 'トチギケン', '芳賀郡茂木町', 'ハガグンモテギマチ', '竹原', 'タケワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県芳賀郡茂木町大畑', '09', '09343', '3213553', '栃木県', 'トチギケン', '芳賀郡茂木町', 'ハガグンモテギマチ', '大畑', 'オオバタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県芳賀郡茂木町大瀬', '09', '09343', '3213554', '栃木県', 'トチギケン', '芳賀郡茂木町', 'ハガグンモテギマチ', '大瀬', 'オオセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県芳賀郡茂木町所草', '09', '09343', '3213555', '栃木県', 'トチギケン', '芳賀郡茂木町', 'ハガグンモテギマチ', '所草', 'トコロクサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県芳賀郡茂木町町田', '09', '09343', '3213556', '栃木県', 'トチギケン', '芳賀郡茂木町', 'ハガグンモテギマチ', '町田', 'マチダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県芳賀郡茂木町黒田', '09', '09343', '3213557', '栃木県', 'トチギケン', '芳賀郡茂木町', 'ハガグンモテギマチ', '黒田', 'クロダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県芳賀郡茂木町後郷', '09', '09343', '3213561', '栃木県', 'トチギケン', '芳賀郡茂木町', 'ハガグンモテギマチ', '後郷', 'ウラゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県芳賀郡茂木町馬門', '09', '09343', '3213562', '栃木県', 'トチギケン', '芳賀郡茂木町', 'ハガグンモテギマチ', '馬門', 'マカド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県芳賀郡茂木町林', '09', '09343', '3213563', '栃木県', 'トチギケン', '芳賀郡茂木町', 'ハガグンモテギマチ', '林', 'ハヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県芳賀郡茂木町増井', '09', '09343', '3213564', '栃木県', 'トチギケン', '芳賀郡茂木町', 'ハガグンモテギマチ', '増井', 'マシイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県芳賀郡茂木町塩田', '09', '09343', '3213565', '栃木県', 'トチギケン', '芳賀郡茂木町', 'ハガグンモテギマチ', '塩田', 'シオダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県芳賀郡茂木町小井戸', '09', '09343', '3213566', '栃木県', 'トチギケン', '芳賀郡茂木町', 'ハガグンモテギマチ', '小井戸', 'コイド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県芳賀郡茂木町天子', '09', '09343', '3213621', '栃木県', 'トチギケン', '芳賀郡茂木町', 'ハガグンモテギマチ', '天子', 'アマコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県芳賀郡茂木町北高岡', '09', '09343', '3213622', '栃木県', 'トチギケン', '芳賀郡茂木町', 'ハガグンモテギマチ', '北高岡', 'キタタカオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県芳賀郡茂木町木幡', '09', '09343', '3213623', '栃木県', 'トチギケン', '芳賀郡茂木町', 'ハガグンモテギマチ', '木幡', 'キバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県芳賀郡茂木町小山', '09', '09343', '3213624', '栃木県', 'トチギケン', '芳賀郡茂木町', 'ハガグンモテギマチ', '小山', 'オヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県芳賀郡茂木町福手', '09', '09343', '3213625', '栃木県', 'トチギケン', '芳賀郡茂木町', 'ハガグンモテギマチ', '福手', 'フグテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県芳賀郡茂木町飯', '09', '09343', '3213626', '栃木県', 'トチギケン', '芳賀郡茂木町', 'ハガグンモテギマチ', '飯', 'イイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県芳賀郡茂木町小貫', '09', '09343', '3213627', '栃木県', 'トチギケン', '芳賀郡茂木町', 'ハガグンモテギマチ', '小貫', 'オヌキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県芳賀郡茂木町深沢', '09', '09343', '3213628', '栃木県', 'トチギケン', '芳賀郡茂木町', 'ハガグンモテギマチ', '深沢', 'フカサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県芳賀郡茂木町山内', '09', '09343', '3213701', '栃木県', 'トチギケン', '芳賀郡茂木町', 'ハガグンモテギマチ', '山内', 'ヤマウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県芳賀郡茂木町飯野', '09', '09343', '3213702', '栃木県', 'トチギケン', '芳賀郡茂木町', 'ハガグンモテギマチ', '飯野', 'イイノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県芳賀郡茂木町河井', '09', '09343', '3213703', '栃木県', 'トチギケン', '芳賀郡茂木町', 'ハガグンモテギマチ', '河井', 'カワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県芳賀郡茂木町牧野', '09', '09343', '3213704', '栃木県', 'トチギケン', '芳賀郡茂木町', 'ハガグンモテギマチ', '牧野', 'マギノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県芳賀郡茂木町入郷', '09', '09343', '3213705', '栃木県', 'トチギケン', '芳賀郡茂木町', 'ハガグンモテギマチ', '入郷', 'イリゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県芳賀郡茂木町河又', '09', '09343', '3213706', '栃木県', 'トチギケン', '芳賀郡茂木町', 'ハガグンモテギマチ', '河又', 'カワマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県芳賀郡茂木町小深', '09', '09343', '3213707', '栃木県', 'トチギケン', '芳賀郡茂木町', 'ハガグンモテギマチ', '小深', 'オブカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県芳賀郡益子町小宅', '09', '09342', '3214101', '栃木県', 'トチギケン', '芳賀郡益子町', 'ハガグンマシコマチ', '小宅', 'オヤケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県芳賀郡益子町芦沼', '09', '09342', '3214102', '栃木県', 'トチギケン', '芳賀郡益子町', 'ハガグンマシコマチ', '芦沼', 'アシヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県芳賀郡益子町大平', '09', '09342', '3214103', '栃木県', 'トチギケン', '芳賀郡益子町', 'ハガグンマシコマチ', '大平', 'オオヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県芳賀郡益子町大沢', '09', '09342', '3214104', '栃木県', 'トチギケン', '芳賀郡益子町', 'ハガグンマシコマチ', '大沢', 'オオサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県芳賀郡益子町北中', '09', '09342', '3214105', '栃木県', 'トチギケン', '芳賀郡益子町', 'ハガグンマシコマチ', '北中', 'キタナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県芳賀郡益子町七井', '09', '09342', '3214106', '栃木県', 'トチギケン', '芳賀郡益子町', 'ハガグンマシコマチ', '七井', 'ナナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県芳賀郡益子町', '09', '09342', '3214200', '栃木県', 'トチギケン', '芳賀郡益子町', 'ハガグンマシコマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('24286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県芳賀郡益子町下大羽', '09', '09342', '3214211', '栃木県', 'トチギケン', '芳賀郡益子町', 'ハガグンマシコマチ', '下大羽', 'シモオオバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県芳賀郡益子町上大羽', '09', '09342', '3214212', '栃木県', 'トチギケン', '芳賀郡益子町', 'ハガグンマシコマチ', '上大羽', 'カミオオバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県芳賀郡益子町山本', '09', '09342', '3214213', '栃木県', 'トチギケン', '芳賀郡益子町', 'ハガグンマシコマチ', '山本', 'ヤマモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県芳賀郡益子町前沢', '09', '09342', '3214214', '栃木県', 'トチギケン', '芳賀郡益子町', 'ハガグンマシコマチ', '前沢', 'マエザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県芳賀郡益子町生田目', '09', '09342', '3214215', '栃木県', 'トチギケン', '芳賀郡益子町', 'ハガグンマシコマチ', '生田目', 'ナバタメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県芳賀郡益子町塙', '09', '09342', '3214216', '栃木県', 'トチギケン', '芳賀郡益子町', 'ハガグンマシコマチ', '塙', 'ハナワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県芳賀郡益子町益子', '09', '09342', '3214217', '栃木県', 'トチギケン', '芳賀郡益子町', 'ハガグンマシコマチ', '益子', 'マシコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県芳賀郡益子町城内坂', '09', '09342', '3214218', '栃木県', 'トチギケン', '芳賀郡益子町', 'ハガグンマシコマチ', '城内坂', 'ジョウナイザカ', null, null, null, null), ('24294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県芳賀郡益子町大郷戸', '09', '09342', '3214221', '栃木県', 'トチギケン', '芳賀郡益子町', 'ハガグンマシコマチ', '大郷戸', 'オオゴウド', null, null, null, null), ('24295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県芳賀郡益子町小泉', '09', '09342', '3214222', '栃木県', 'トチギケン', '芳賀郡益子町', 'ハガグンマシコマチ', '小泉', 'コイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県芳賀郡益子町梅ケ内', '09', '09342', '3214223', '栃木県', 'トチギケン', '芳賀郡益子町', 'ハガグンマシコマチ', '梅ケ内', 'ウメガウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県芳賀郡益子町本沼', '09', '09342', '3214224', '栃木県', 'トチギケン', '芳賀郡益子町', 'ハガグンマシコマチ', '本沼', 'モトヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県芳賀郡益子町長堤', '09', '09342', '3214225', '栃木県', 'トチギケン', '芳賀郡益子町', 'ハガグンマシコマチ', '長堤', 'ナガツツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県芳賀郡益子町上山', '09', '09342', '3214226', '栃木県', 'トチギケン', '芳賀郡益子町', 'ハガグンマシコマチ', '上山', 'カミヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県芳賀郡益子町東田井', '09', '09342', '3214227', '栃木県', 'トチギケン', '芳賀郡益子町', 'ハガグンマシコマチ', '東田井', 'ヒガシダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県真岡市', '09', '09209', '3214300', '栃木県', 'トチギケン', '真岡市', 'モオカシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('24305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県真岡市西田井', '09', '09209', '3214301', '栃木県', 'トチギケン', '真岡市', 'モオカシ', '西田井', 'ニシダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県真岡市鶴田', '09', '09209', '3214302', '栃木県', 'トチギケン', '真岡市', 'モオカシ', '鶴田', 'ツルタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県真岡市八條', '09', '09209', '3214303', '栃木県', 'トチギケン', '真岡市', 'モオカシ', '八條', 'ハチジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県真岡市東郷', '09', '09209', '3214304', '栃木県', 'トチギケン', '真岡市', 'モオカシ', '東郷', 'ヒガシゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県真岡市荒町', '09', '09209', '3214305', '栃木県', 'トチギケン', '真岡市', 'モオカシ', '荒町', 'アラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県真岡市台町', '09', '09209', '3214306', '栃木県', 'トチギケン', '真岡市', 'モオカシ', '台町', 'ダイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県真岡市西郷', '09', '09209', '3214307', '栃木県', 'トチギケン', '真岡市', 'モオカシ', '西郷', 'ニシゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県真岡市中郷', '09', '09209', '3214308', '栃木県', 'トチギケン', '真岡市', 'モオカシ', '中郷', 'ナカゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県真岡市根本', '09', '09209', '3214311', '栃木県', 'トチギケン', '真岡市', 'モオカシ', '根本', 'ネモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県真岡市青谷', '09', '09209', '3214312', '栃木県', 'トチギケン', '真岡市', 'モオカシ', '青谷', 'アオヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県真岡市須釜', '09', '09209', '3214313', '栃木県', 'トチギケン', '真岡市', 'モオカシ', '須釜', 'スガマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県真岡市南高岡', '09', '09209', '3214314', '栃木県', 'トチギケン', '真岡市', 'モオカシ', '南高岡', 'ミナミタカオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県真岡市道祖土', '09', '09209', '3214315', '栃木県', 'トチギケン', '真岡市', 'モオカシ', '道祖土', 'サヤド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県真岡市君島', '09', '09209', '3214316', '栃木県', 'トチギケン', '真岡市', 'モオカシ', '君島', 'キミジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県真岡市小林', '09', '09209', '3214321', '栃木県', 'トチギケン', '真岡市', 'モオカシ', '小林', 'コバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県真岡市東大島', '09', '09209', '3214322', '栃木県', 'トチギケン', '真岡市', 'モオカシ', '東大島', 'ヒガシオオシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県真岡市東沼', '09', '09209', '3214323', '栃木県', 'トチギケン', '真岡市', 'モオカシ', '東沼', 'ヒガシヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県真岡市西沼', '09', '09209', '3214324', '栃木県', 'トチギケン', '真岡市', 'モオカシ', '西沼', 'ニシヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県真岡市田町', '09', '09209', '3214325', '栃木県', 'トチギケン', '真岡市', 'モオカシ', '田町', 'タマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県真岡市島', '09', '09209', '3214326', '栃木県', 'トチギケン', '真岡市', 'モオカシ', '島', 'シマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県真岡市白布ケ丘', '09', '09209', '3214331', '栃木県', 'トチギケン', '真岡市', 'モオカシ', '白布ケ丘', 'ハクフガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県真岡市大谷新町', '09', '09209', '3214332', '栃木県', 'トチギケン', '真岡市', 'モオカシ', '大谷新町', 'オオヤシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県真岡市大谷本町', '09', '09209', '3214333', '栃木県', 'トチギケン', '真岡市', 'モオカシ', '大谷本町', 'オオヤホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県真岡市八木岡', '09', '09209', '3214334', '栃木県', 'トチギケン', '真岡市', 'モオカシ', '八木岡', 'ヤギオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県真岡市下高間木', '09', '09209', '3214335', '栃木県', 'トチギケン', '真岡市', 'モオカシ', '下高間木', 'シモコウマギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県真岡市西高間木', '09', '09209', '3214336', '栃木県', 'トチギケン', '真岡市', 'モオカシ', '西高間木', 'ニシコウマギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県真岡市上高間木', '09', '09209', '3214337', '栃木県', 'トチギケン', '真岡市', 'モオカシ', '上高間木', 'カミコウマギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県真岡市大谷台町', '09', '09209', '3214338', '栃木県', 'トチギケン', '真岡市', 'モオカシ', '大谷台町', 'オオヤダイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県真岡市高勢町', '09', '09209', '3214341', '栃木県', 'トチギケン', '真岡市', 'モオカシ', '高勢町', 'タカセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県真岡市伊勢崎', '09', '09209', '3214342', '栃木県', 'トチギケン', '真岡市', 'モオカシ', '伊勢崎', 'イセサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県真岡市小橋', '09', '09209', '3214343', '栃木県', 'トチギケン', '真岡市', 'モオカシ', '小橋', 'コバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県真岡市茅堤', '09', '09209', '3214344', '栃木県', 'トチギケン', '真岡市', 'モオカシ', '茅堤', 'カヤツツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県真岡市寺内', '09', '09209', '3214345', '栃木県', 'トチギケン', '真岡市', 'モオカシ', '寺内', 'テラウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県真岡市松山町', '09', '09209', '3214346', '栃木県', 'トチギケン', '真岡市', 'モオカシ', '松山町', 'マツヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県真岡市加倉', '09', '09209', '3214347', '栃木県', 'トチギケン', '真岡市', 'モオカシ', '加倉', 'カクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県真岡市中', '09', '09209', '3214351', '栃木県', 'トチギケン', '真岡市', 'モオカシ', '中', 'ナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県真岡市若旅', '09', '09209', '3214352', '栃木県', 'トチギケン', '真岡市', 'モオカシ', '若旅', 'ワカタビ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県真岡市粕田', '09', '09209', '3214353', '栃木県', 'トチギケン', '真岡市', 'モオカシ', '粕田', 'カスダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県真岡市寺分', '09', '09209', '3214354', '栃木県', 'トチギケン', '真岡市', 'モオカシ', '寺分', 'テラブン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県真岡市上大沼', '09', '09209', '3214355', '栃木県', 'トチギケン', '真岡市', 'モオカシ', '上大沼', 'カミオオヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県真岡市大沼', '09', '09209', '3214356', '栃木県', 'トチギケン', '真岡市', 'モオカシ', '大沼', 'オオヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県真岡市下大沼', '09', '09209', '3214357', '栃木県', 'トチギケン', '真岡市', 'モオカシ', '下大沼', 'シモオオヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県真岡市並木町', '09', '09209', '3214361', '栃木県', 'トチギケン', '真岡市', 'モオカシ', '並木町', 'ナミキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県真岡市熊倉町', '09', '09209', '3214362', '栃木県', 'トチギケン', '真岡市', 'モオカシ', '熊倉町', 'クマクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県真岡市亀山', '09', '09209', '3214363', '栃木県', 'トチギケン', '真岡市', 'モオカシ', '亀山', 'カメヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県真岡市長田', '09', '09209', '3214364', '栃木県', 'トチギケン', '真岡市', 'モオカシ', '長田', 'ナガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県真岡市柳林', '09', '09209', '3214365', '栃木県', 'トチギケン', '真岡市', 'モオカシ', '柳林', 'ヤナギバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県真岡市勝瓜', '09', '09209', '3214366', '栃木県', 'トチギケン', '真岡市', 'モオカシ', '勝瓜', 'カツウリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県真岡市鬼怒ケ丘', '09', '09209', '3214367', '栃木県', 'トチギケン', '真岡市', 'モオカシ', '鬼怒ケ丘', 'キヌガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県真岡市寺久保', '09', '09209', '3214368', '栃木県', 'トチギケン', '真岡市', 'モオカシ', '寺久保', 'テラクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県真岡市赤羽', '09', '09209', '3214401', '栃木県', 'トチギケン', '真岡市', 'モオカシ', '赤羽', 'アカバネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県真岡市清水', '09', '09209', '3214402', '栃木県', 'トチギケン', '真岡市', 'モオカシ', '清水', 'シミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県真岡市原町', '09', '09209', '3214403', '栃木県', 'トチギケン', '真岡市', 'モオカシ', '原町', 'ハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県真岡市田島', '09', '09209', '3214404', '栃木県', 'トチギケン', '真岡市', 'モオカシ', '田島', 'タジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県真岡市飯貝', '09', '09209', '3214405', '栃木県', 'トチギケン', '真岡市', 'モオカシ', '飯貝', 'イイガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県真岡市京泉', '09', '09209', '3214406', '栃木県', 'トチギケン', '真岡市', 'モオカシ', '京泉', 'キョウセン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県真岡市上大田和', '09', '09209', '3214411', '栃木県', 'トチギケン', '真岡市', 'モオカシ', '上大田和', 'カミオオダワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県真岡市堀内', '09', '09209', '3214412', '栃木県', 'トチギケン', '真岡市', 'モオカシ', '堀内', 'ホリウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県真岡市下大田和', '09', '09209', '3214413', '栃木県', 'トチギケン', '真岡市', 'モオカシ', '下大田和', 'シモオオダワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県真岡市下鷺谷', '09', '09209', '3214414', '栃木県', 'トチギケン', '真岡市', 'モオカシ', '下鷺谷', 'シモサギノヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県真岡市下籠谷', '09', '09209', '3214415', '栃木県', 'トチギケン', '真岡市', 'モオカシ', '下籠谷', 'シモコモリヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県真岡市上鷺谷', '09', '09209', '3214416', '栃木県', 'トチギケン', '真岡市', 'モオカシ', '上鷺谷', 'カミサギノヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県真岡市横田', '09', '09209', '3214501', '栃木県', 'トチギケン', '真岡市', 'モオカシ', '横田', 'ヨコタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県真岡市物井', '09', '09209', '3214502', '栃木県', 'トチギケン', '真岡市', 'モオカシ', '物井', 'モノイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県真岡市桑ノ川', '09', '09209', '3214503', '栃木県', 'トチギケン', '真岡市', 'モオカシ', '桑ノ川', 'クワノガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県真岡市鹿', '09', '09209', '3214504', '栃木県', 'トチギケン', '真岡市', 'モオカシ', '鹿', 'シカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県真岡市沖', '09', '09209', '3214505', '栃木県', 'トチギケン', '真岡市', 'モオカシ', '沖', 'オキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県真岡市大根田', '09', '09209', '3214506', '栃木県', 'トチギケン', '真岡市', 'モオカシ', '大根田', 'オオネダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県真岡市石島', '09', '09209', '3214507', '栃木県', 'トチギケン', '真岡市', 'モオカシ', '石島', 'イシジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県真岡市大和田', '09', '09209', '3214508', '栃木県', 'トチギケン', '真岡市', 'モオカシ', '大和田', 'オオワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県真岡市高田', '09', '09209', '3214511', '栃木県', 'トチギケン', '真岡市', 'モオカシ', '高田', 'タカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県真岡市阿部岡', '09', '09209', '3214512', '栃木県', 'トチギケン', '真岡市', 'モオカシ', '阿部岡', 'アベオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県真岡市三谷', '09', '09209', '3214513', '栃木県', 'トチギケン', '真岡市', 'モオカシ', '三谷', 'ミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県真岡市水戸部', '09', '09209', '3214514', '栃木県', 'トチギケン', '真岡市', 'モオカシ', '水戸部', 'ミトベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県真岡市反町', '09', '09209', '3214515', '栃木県', 'トチギケン', '真岡市', 'モオカシ', '反町', 'ソリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県真岡市根小屋', '09', '09209', '3214516', '栃木県', 'トチギケン', '真岡市', 'モオカシ', '根小屋', 'ネゴヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県真岡市阿部品', '09', '09209', '3214517', '栃木県', 'トチギケン', '真岡市', 'モオカシ', '阿部品', 'アベシナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県真岡市久下田', '09', '09209', '3214521', '栃木県', 'トチギケン', '真岡市', 'モオカシ', '久下田', 'クゲタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県真岡市久下田西', '09', '09209', '3214522', '栃木県', 'トチギケン', '真岡市', 'モオカシ', '久下田西', 'クゲタニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県真岡市さくら', '09', '09209', '3214523', '栃木県', 'トチギケン', '真岡市', 'モオカシ', 'さくら', 'サクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県真岡市青田', '09', '09209', '3214531', '栃木県', 'トチギケン', '真岡市', 'モオカシ', '青田', 'アオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県真岡市長島', '09', '09209', '3214532', '栃木県', 'トチギケン', '真岡市', 'モオカシ', '長島', 'ナガシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県真岡市程島', '09', '09209', '3214533', '栃木県', 'トチギケン', '真岡市', 'モオカシ', '程島', 'ホドシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県真岡市境', '09', '09209', '3214534', '栃木県', 'トチギケン', '真岡市', 'モオカシ', '境', 'サカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県真岡市古山', '09', '09209', '3214535', '栃木県', 'トチギケン', '真岡市', 'モオカシ', '古山', 'コヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県真岡市上江連', '09', '09209', '3214536', '栃木県', 'トチギケン', '真岡市', 'モオカシ', '上江連', 'カミエヅラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県真岡市西大島', '09', '09209', '3214537', '栃木県', 'トチギケン', '真岡市', 'モオカシ', '西大島', 'ニシオオジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県真岡市鷲巣', '09', '09209', '3214538', '栃木県', 'トチギケン', '真岡市', 'モオカシ', '鷲巣', 'ワシノス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県真岡市長沼', '09', '09209', '3214539', '栃木県', 'トチギケン', '真岡市', 'モオカシ', '長沼', 'ナガヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県真岡市上谷貝', '09', '09209', '3214541', '栃木県', 'トチギケン', '真岡市', 'モオカシ', '上谷貝', 'カミヤガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県真岡市上大曽', '09', '09209', '3214542', '栃木県', 'トチギケン', '真岡市', 'モオカシ', '上大曽', 'カミオオゾ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県真岡市下大曽', '09', '09209', '3214543', '栃木県', 'トチギケン', '真岡市', 'モオカシ', '下大曽', 'シモオオゾ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県真岡市堀込', '09', '09209', '3214544', '栃木県', 'トチギケン', '真岡市', 'モオカシ', '堀込', 'ホリゴメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県真岡市大道泉', '09', '09209', '3214545', '栃木県', 'トチギケン', '真岡市', 'モオカシ', '大道泉', 'ダイドウイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県真岡市砂ケ原', '09', '09209', '3214546', '栃木県', 'トチギケン', '真岡市', 'モオカシ', '砂ケ原', 'イサガハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県真岡市谷貝新田', '09', '09209', '3214547', '栃木県', 'トチギケン', '真岡市', 'モオカシ', '谷貝新田', 'ヤガイシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県真岡市若旅五丁歩', '09', '09209', '3214551', '栃木県', 'トチギケン', '真岡市', 'モオカシ', '若旅', 'ワカタビ', null, null, '五丁歩', '05チョウブ');
INSERT INTO `ms_addresses` VALUES ('24413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市', '09', '09205', '3220000', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('24414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市栃窪', '09', '09205', '3220001', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '栃窪', 'トチクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市千渡', '09', '09205', '3220002', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '千渡', 'センド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市仁神堂町', '09', '09205', '3220003', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '仁神堂町', 'ニガミドウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市下武子町', '09', '09205', '3220004', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '下武子町', 'シモタケシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市御成橋町', '09', '09205', '3220005', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '御成橋町', 'オナリバシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市富岡', '09', '09205', '3220006', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '富岡', 'トミオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市武子', '09', '09205', '3220007', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '武子', 'タケシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市古賀志町', '09', '09205', '3220008', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '古賀志町', 'コガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市高谷', '09', '09205', '3220009', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '高谷', 'コウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市白桑田', '09', '09205', '3220011', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '白桑田', 'シラクワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市松原', '09', '09205', '3220012', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '松原', 'マツバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市深津', '09', '09205', '3220013', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '深津', 'フカヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市さつき町', '09', '09205', '3220014', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', 'さつき町', 'サツキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市上石川', '09', '09205', '3220015', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '上石川', 'カミイシカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市流通センター', '09', '09205', '3220016', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '流通センター', 'リュウツウセンター', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市下石川', '09', '09205', '3220017', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '下石川', 'シモイシカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市池ノ森', '09', '09205', '3220018', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '池ノ森', 'イケノモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市上野町', '09', '09205', '3220021', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '上野町', 'ウワノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市東町', '09', '09205', '3220022', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '東町', 'アズマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市幸町', '09', '09205', '3220023', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市晃望台', '09', '09205', '3220024', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '晃望台', 'コウボウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市緑町', '09', '09205', '3220025', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '緑町', 'ミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市茂呂', '09', '09205', '3220026', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '茂呂', 'モロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市貝島町', '09', '09205', '3220027', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '貝島町', 'カイジママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市栄町', '09', '09205', '3220028', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '栄町', 'サカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市西茂呂', '09', '09205', '3220029', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '西茂呂', 'ニシモロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市睦町', '09', '09205', '3220031', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '睦町', 'ムツミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市府所本町', '09', '09205', '3220032', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '府所本町', 'フドコロホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市府所町', '09', '09205', '3220033', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '府所町', 'フドコロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市府中町', '09', '09205', '3220034', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '府中町', 'フチュウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市朝日町', '09', '09205', '3220035', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '朝日町', 'アサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市下田町', '09', '09205', '3220036', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '下田町', 'シモタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市中田町', '09', '09205', '3220037', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '中田町', 'ナカタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市末広町', '09', '09205', '3220038', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '末広町', 'スエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市東末広町', '09', '09205', '3220039', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '東末広町', 'ヒガシスエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市三幸町', '09', '09205', '3220041', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '三幸町', 'サンコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市蓬莱町', '09', '09205', '3220042', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '蓬莱町', 'ホウライチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市万町', '09', '09205', '3220043', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '万町', 'ヨロズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市鳥居跡町', '09', '09205', '3220044', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '鳥居跡町', 'トリイドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市上殿町', '09', '09205', '3220045', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '上殿町', 'カミドノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市樅山町', '09', '09205', '3220046', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '樅山町', 'モミヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市酒野谷', '09', '09205', '3220047', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '酒野谷', 'サケノヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市村井町', '09', '09205', '3220048', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '村井町', 'ムライマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市花岡町', '09', '09205', '3220049', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '花岡町', 'ハナオカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市久保町', '09', '09205', '3220051', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '久保町', 'クボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市銀座', '09', '09205', '3220052', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '銀座', 'ギンザ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市仲町', '09', '09205', '3220053', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '仲町', 'ナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市下横町', '09', '09205', '3220054', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '下横町', 'シモヨコマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市石橋町', '09', '09205', '3220055', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '石橋町', 'イシバシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市下材木町', '09', '09205', '3220056', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '下材木町', 'シモザイモクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市寺町', '09', '09205', '3220057', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '寺町', 'テラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市麻苧町', '09', '09205', '3220058', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '麻苧町', 'アサウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市千手町', '09', '09205', '3220061', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '千手町', 'センジュマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市泉町', '09', '09205', '3220062', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '泉町', 'イズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市戸張町', '09', '09205', '3220063', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '戸張町', 'トハリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市文化橋町', '09', '09205', '3220064', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '文化橋町', 'ブンカバシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市上材木町', '09', '09205', '3220065', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '上材木町', 'カミザイモクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市上田町', '09', '09205', '3220066', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '上田町', 'カミタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市天神町', '09', '09205', '3220067', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '天神町', 'テンジンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市今宮町', '09', '09205', '3220068', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '今宮町', 'イマミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市坂田山', '09', '09205', '3220069', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '坂田山', 'サカタヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市見野', '09', '09205', '3220071', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '見野', 'ミノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市玉田町', '09', '09205', '3220072', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '玉田町', 'タマダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市西鹿沼町', '09', '09205', '3220073', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '西鹿沼町', 'ニシカヌママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市日吉町', '09', '09205', '3220074', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '日吉町', 'ヒヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市下日向', '09', '09205', '3220075', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '下日向', 'シモヒナタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市上日向', '09', '09205', '3220076', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '上日向', 'カミヒナタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市深岩', '09', '09205', '3220077', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '深岩', 'フカイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市笹原田', '09', '09205', '3220078', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '笹原田', 'ササハラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市下遠部', '09', '09205', '3220079', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '下遠部', 'シモトオベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市草久', '09', '09205', '3220101', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '草久', 'クサギュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市上大久保', '09', '09205', '3220102', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '上大久保', 'カミオオクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市下大久保', '09', '09205', '3220103', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '下大久保', 'シモオオクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市野尻', '09', '09205', '3220251', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '野尻', 'ノジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市加園', '09', '09205', '3220252', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '加園', 'カゾノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市下久我', '09', '09205', '3220253', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '下久我', 'シモクガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市上久我', '09', '09205', '3220254', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '上久我', 'カミクガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市引田', '09', '09205', '3220255', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '引田', 'ヒキダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市下沢', '09', '09205', '3220256', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '下沢', 'シモザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市北半田', '09', '09205', '3220301', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '北半田', 'キタハンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市深程', '09', '09205', '3220302', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '深程', 'フカホド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市久野', '09', '09205', '3220303', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '久野', 'クノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市柏木', '09', '09205', '3220304', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '柏木', 'カシワギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市口粟野', '09', '09205', '3220305', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '口粟野', 'クチアワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市中粟野', '09', '09205', '3220306', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '中粟野', 'ナカアワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市入粟野', '09', '09205', '3220307', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '入粟野', 'イリアワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市下南摩町', '09', '09205', '3220341', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '下南摩町', 'シモナンママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市油田町', '09', '09205', '3220342', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '油田町', 'アブラデンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市佐目町', '09', '09205', '3220343', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '佐目町', 'サメマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市西沢町', '09', '09205', '3220344', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '西沢町', 'ニシザワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市旭が丘', '09', '09205', '3220345', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '旭が丘', 'アサヒガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市上南摩町', '09', '09205', '3220346', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '上南摩町', 'カミナンママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市下粕尾', '09', '09205', '3220421', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '下粕尾', 'シモカスオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市中粕尾', '09', '09205', '3220422', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '中粕尾', 'ナカカスオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市上粕尾', '09', '09205', '3220423', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '上粕尾', 'カミカスオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市日光奈良部町', '09', '09205', '3220521', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '日光奈良部町', 'ニッコウナラブマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市上奈良部町', '09', '09205', '3220522', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '上奈良部町', 'カミナラブマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市下奈良部町', '09', '09205', '3220523', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '下奈良部町', 'シモナラブマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市みなみ町', '09', '09205', '3220524', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', 'みなみ町', 'ミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市大和田町', '09', '09205', '3220525', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '大和田町', 'オオワダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市楡木町', '09', '09205', '3220526', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '楡木町', 'ニレギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市塩山町', '09', '09205', '3220527', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '塩山町', 'シオヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市奈佐原町', '09', '09205', '3220528', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '奈佐原町', 'ナサハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市南上野町', '09', '09205', '3220531', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '南上野町', 'ミナミウエノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市藤江町', '09', '09205', '3220532', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '藤江町', 'フジエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市北赤塚町', '09', '09205', '3220533', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '北赤塚町', 'キタアカヅカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市亀和田町', '09', '09205', '3220534', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '亀和田町', 'カメワダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市野沢町', '09', '09205', '3220535', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '野沢町', 'ノザワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市磯町', '09', '09205', '3220536', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '磯町', 'イソマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県上都賀郡西方町', '09', '09321', '3220600', '栃木県', 'トチギケン', '上都賀郡西方町', 'カミツガグンニシカタマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('24525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県上都賀郡西方町金崎', '09', '09321', '3220601', '栃木県', 'トチギケン', '上都賀郡西方町', 'カミツガグンニシカタマチ', '金崎', 'カナサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県上都賀郡西方町金井', '09', '09321', '3220602', '栃木県', 'トチギケン', '上都賀郡西方町', 'カミツガグンニシカタマチ', '金井', 'カナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県上都賀郡西方町本郷', '09', '09321', '3220603', '栃木県', 'トチギケン', '上都賀郡西方町', 'カミツガグンニシカタマチ', '本郷', 'ホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県上都賀郡西方町元', '09', '09321', '3220604', '栃木県', 'トチギケン', '上都賀郡西方町', 'カミツガグンニシカタマチ', '元', 'モト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県上都賀郡西方町真名子', '09', '09321', '3220605', '栃木県', 'トチギケン', '上都賀郡西方町', 'カミツガグンニシカタマチ', '真名子', 'マナゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県上都賀郡西方町本城', '09', '09321', '3220606', '栃木県', 'トチギケン', '上都賀郡西方町', 'カミツガグンニシカタマチ', '本城', 'ホンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市', '09', '09208', '3230000', '栃木県', 'トチギケン', '小山市', 'オヤマシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('24545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市小宅', '09', '09208', '3230001', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '小宅', 'オヤケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市黒本', '09', '09208', '3230002', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '黒本', 'クロモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市東島田', '09', '09208', '3230003', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '東島田', 'ヒガシシマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市島田', '09', '09208', '3230004', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '島田', 'シマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市渋井', '09', '09208', '3230005', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '渋井', 'シブイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市荒川', '09', '09208', '3230006', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '荒川', 'アラカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市松沼', '09', '09208', '3230007', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '松沼', 'マツヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市小薬', '09', '09208', '3230008', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '小薬', 'コグスリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市大本', '09', '09208', '3230009', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '大本', 'オオモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市南半田', '09', '09208', '3230011', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '南半田', 'ミナミハンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市羽川', '09', '09208', '3230012', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '羽川', 'ハネカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市荒井', '09', '09208', '3230013', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '荒井', 'アライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市喜沢', '09', '09208', '3230014', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '喜沢', 'キザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市三拝川岸', '09', '09208', '3230015', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '三拝川岸', 'サンバイカワギシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市扶桑', '09', '09208', '3230016', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '扶桑', 'フソウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市飯塚', '09', '09208', '3230017', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '飯塚', 'イイヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市稲葉郷', '09', '09208', '3230021', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '稲葉郷', 'イナバゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市駅東通り', '09', '09208', '3230022', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '駅東通り', 'エキヒガシドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市中央町', '09', '09208', '3230023', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '中央町', 'チュウオウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市宮本町', '09', '09208', '3230024', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '宮本町', 'ミヤモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市城山町', '09', '09208', '3230025', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '城山町', 'シロヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市本郷町', '09', '09208', '3230026', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '本郷町', 'ホンゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市花垣町', '09', '09208', '3230027', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '花垣町', 'ハナガキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市若木町', '09', '09208', '3230028', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '若木町', 'ワカギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市城北', '09', '09208', '3230029', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '城北', 'ジョウホク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市八幡町', '09', '09208', '3230031', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '八幡町', 'ヤハタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市天神町', '09', '09208', '3230032', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '天神町', 'テンジンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市神明町', '09', '09208', '3230033', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '神明町', 'シンメイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市神鳥谷', '09', '09208', '3230034', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '神鳥谷', 'ヒトトノヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市大行寺', '09', '09208', '3230041', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '大行寺', 'ダイギョウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市外城', '09', '09208', '3230042', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '外城', 'トジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市塩沢', '09', '09208', '3230043', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '塩沢', 'シオザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市間中', '09', '09208', '3230044', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '間中', 'マナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市石ノ上', '09', '09208', '3230045', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '石ノ上', 'イシノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市萩島', '09', '09208', '3230046', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '萩島', 'ハギシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市生駒', '09', '09208', '3230051', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '生駒', 'イコマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市下河原田', '09', '09208', '3230052', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '下河原田', 'シモカワラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市小袋', '09', '09208', '3230053', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '小袋', 'コブクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市井岡', '09', '09208', '3230054', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '井岡', 'イオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市下泉', '09', '09208', '3230055', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '下泉', 'シモイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市上泉', '09', '09208', '3230056', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '上泉', 'カミイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市南小林', '09', '09208', '3230057', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '南小林', 'ミナミオバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市大川島', '09', '09208', '3230058', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '大川島', 'オオカワシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市卒島', '09', '09208', '3230061', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '卒島', 'ソシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市立木', '09', '09208', '3230062', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '立木', 'タツギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市上石塚', '09', '09208', '3230063', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '上石塚', 'カミイシヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市下石塚', '09', '09208', '3230064', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '下石塚', 'シモイシヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市下国府塚', '09', '09208', '3230065', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '下国府塚', 'シモコウヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市上国府塚', '09', '09208', '3230066', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '上国府塚', 'カミコウヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市今里', '09', '09208', '3230067', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '今里', 'イマザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市下初田', '09', '09208', '3230068', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '下初田', 'シモハツダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市上初田', '09', '09208', '3230069', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '上初田', 'カミハツダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下野市三王山', '09', '09216', '3230101', '栃木県', 'トチギケン', '下野市', 'シモツケシ', '三王山', 'サンノウヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下野市上吉田', '09', '09216', '3230102', '栃木県', 'トチギケン', '下野市', 'シモツケシ', '上吉田', 'カミヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下野市上川島', '09', '09216', '3230103', '栃木県', 'トチギケン', '下野市', 'シモツケシ', '上川島', 'カミカワシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下野市中川島', '09', '09216', '3230104', '栃木県', 'トチギケン', '下野市', 'シモツケシ', '中川島', 'ナカカワシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下野市本吉田', '09', '09216', '3230105', '栃木県', 'トチギケン', '下野市', 'シモツケシ', '本吉田', 'モトヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下野市下吉田', '09', '09216', '3230106', '栃木県', 'トチギケン', '下野市', 'シモツケシ', '下吉田', 'シモヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下野市別当河原', '09', '09216', '3230107', '栃木県', 'トチギケン', '下野市', 'シモツケシ', '別当河原', 'ベツトウカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下野市磯部', '09', '09216', '3230111', '栃木県', 'トチギケン', '下野市', 'シモツケシ', '磯部', 'イソベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下野市東根', '09', '09216', '3230112', '栃木県', 'トチギケン', '下野市', 'シモツケシ', '東根', 'ヒガシネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下野市上坪山', '09', '09216', '3230113', '栃木県', 'トチギケン', '下野市', 'シモツケシ', '上坪山', 'カミツボヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下野市絹板', '09', '09216', '3230114', '栃木県', 'トチギケン', '下野市', 'シモツケシ', '絹板', 'キヌイタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下野市下坪山', '09', '09216', '3230115', '栃木県', 'トチギケン', '下野市', 'シモツケシ', '下坪山', 'シモツボヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下野市花田', '09', '09216', '3230116', '栃木県', 'トチギケン', '下野市', 'シモツケシ', '花田', 'ハナダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市田川', '09', '09208', '3230151', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '田川', 'タガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市延島', '09', '09208', '3230152', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '延島', 'ノブシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市延島新田', '09', '09208', '3230153', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '延島新田', 'ノブシマシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市高椅', '09', '09208', '3230154', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '高椅', 'タカハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市福良', '09', '09208', '3230155', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '福良', 'フクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市中島', '09', '09208', '3230156', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '中島', 'ナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市中河原', '09', '09208', '3230157', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '中河原', 'ナカガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市梁', '09', '09208', '3230158', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '梁', 'ヤナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市鉢形', '09', '09208', '3230801', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '鉢形', 'ハチガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市東山田', '09', '09208', '3230802', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '東山田', 'ヒガシヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市北飯田', '09', '09208', '3230803', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '北飯田', 'キタイイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市萱橋', '09', '09208', '3230804', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '萱橋', 'カヤバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市向野', '09', '09208', '3230805', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '向野', 'ムカイノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市中久喜', '09', '09208', '3230806', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '中久喜', 'ナカクキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市城東', '09', '09208', '3230807', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '城東', 'ジョウトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市出井', '09', '09208', '3230808', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '出井', 'イデイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市犬塚', '09', '09208', '3230811', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '犬塚', 'イヌヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市土塔', '09', '09208', '3230812', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '土塔', 'ドトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市横倉', '09', '09208', '3230813', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '横倉', 'ヨコクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市田間', '09', '09208', '3230814', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '田間', 'タマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市武井', '09', '09208', '3230815', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '武井', 'タケイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市南和泉', '09', '09208', '3230816', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '南和泉', 'ミナミイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市東野田', '09', '09208', '3230817', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '東野田', 'ヒガシノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市塚崎', '09', '09208', '3230818', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '塚崎', 'ツカザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市横倉新田', '09', '09208', '3230819', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '横倉新田', 'ヨコクラシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市西城南', '09', '09208', '3230820', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '西城南', 'ニシジョウナン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市三峯', '09', '09208', '3230821', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '三峯', 'ミツミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市駅南町', '09', '09208', '3230822', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '駅南町', 'エキミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市向原新田', '09', '09208', '3230823', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '向原新田', 'ムカイハラシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市雨ケ谷新田', '09', '09208', '3230824', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '雨ケ谷新田', 'アマガヤシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市小山', '09', '09208', '3230825', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '小山', 'オヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市雨ケ谷', '09', '09208', '3230826', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '雨ケ谷', 'アマガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市神鳥谷', '09', '09208', '3230827', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '神鳥谷', 'ヒトトノヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市神山', '09', '09208', '3230828', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '神山', 'カミヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市東城南', '09', '09208', '3230829', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '東城南', 'ヒガシジョウナン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡藤岡町', '09', '09366', '3231100', '栃木県', 'トチギケン', '下都賀郡藤岡町', 'シモツガグンフジオカマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('24647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡藤岡町大前', '09', '09366', '3231101', '栃木県', 'トチギケン', '下都賀郡藤岡町', 'シモツガグンフジオカマチ', '大前', 'オオマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡藤岡町赤麻', '09', '09366', '3231102', '栃木県', 'トチギケン', '下都賀郡藤岡町', 'シモツガグンフジオカマチ', '赤麻', 'アカマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡藤岡町内野', '09', '09366', '3231103', '栃木県', 'トチギケン', '下都賀郡藤岡町', 'シモツガグンフジオカマチ', '内野', 'ウチノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡藤岡町藤岡', '09', '09366', '3231104', '栃木県', 'トチギケン', '下都賀郡藤岡町', 'シモツガグンフジオカマチ', '藤岡', 'フジオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡藤岡町甲', '09', '09366', '3231105', '栃木県', 'トチギケン', '下都賀郡藤岡町', 'シモツガグンフジオカマチ', '甲', 'コウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡藤岡町都賀', '09', '09366', '3231106', '栃木県', 'トチギケン', '下都賀郡藤岡町', 'シモツガグンフジオカマチ', '都賀', 'ツガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡藤岡町大田和', '09', '09366', '3231107', '栃木県', 'トチギケン', '下都賀郡藤岡町', 'シモツガグンフジオカマチ', '大田和', 'オオダワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡藤岡町太田', '09', '09366', '3231108', '栃木県', 'トチギケン', '下都賀郡藤岡町', 'シモツガグンフジオカマチ', '太田', 'オオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県大田原市', '09', '09210', '3240000', '栃木県', 'トチギケン', '大田原市', 'オオタワラシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('24665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県大田原市乙連沢', '09', '09210', '3240001', '栃木県', 'トチギケン', '大田原市', 'オオタワラシ', '乙連沢', 'オトレザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県大田原市羽田', '09', '09210', '3240002', '栃木県', 'トチギケン', '大田原市', 'オオタワラシ', '羽田', 'ハンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県大田原市小滝', '09', '09210', '3240003', '栃木県', 'トチギケン', '大田原市', 'オオタワラシ', '小滝', 'コダキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県大田原市富池', '09', '09210', '3240004', '栃木県', 'トチギケン', '大田原市', 'オオタワラシ', '富池', 'トミイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県大田原市練貫', '09', '09210', '3240005', '栃木県', 'トチギケン', '大田原市', 'オオタワラシ', '練貫', 'ネリヌキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県大田原市市野沢', '09', '09210', '3240006', '栃木県', 'トチギケン', '大田原市', 'オオタワラシ', '市野沢', 'イチノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県大田原市北金丸', '09', '09210', '3240011', '栃木県', 'トチギケン', '大田原市', 'オオタワラシ', '北金丸', 'キタカネマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県大田原市南金丸', '09', '09210', '3240012', '栃木県', 'トチギケン', '大田原市', 'オオタワラシ', '南金丸', 'ミナミカネマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県大田原市鹿畑', '09', '09210', '3240013', '栃木県', 'トチギケン', '大田原市', 'オオタワラシ', '鹿畑', 'カバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県大田原市倉骨', '09', '09210', '3240014', '栃木県', 'トチギケン', '大田原市', 'オオタワラシ', '倉骨', 'クラホネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県大田原市赤瀬', '09', '09210', '3240015', '栃木県', 'トチギケン', '大田原市', 'オオタワラシ', '赤瀬', 'アカゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県大田原市北大和久', '09', '09210', '3240016', '栃木県', 'トチギケン', '大田原市', 'オオタワラシ', '北大和久', 'キタオオワグ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県大田原市奥沢', '09', '09210', '3240017', '栃木県', 'トチギケン', '大田原市', 'オオタワラシ', '奥沢', 'オクサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県大田原市上奥沢', '09', '09210', '3240018', '栃木県', 'トチギケン', '大田原市', 'オオタワラシ', '上奥沢', 'カミオクサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県大田原市若草', '09', '09210', '3240021', '栃木県', 'トチギケン', '大田原市', 'オオタワラシ', '若草', 'ワカクサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県大田原市宇田川', '09', '09210', '3240022', '栃木県', 'トチギケン', '大田原市', 'オオタワラシ', '宇田川', 'ウダガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県大田原市花園', '09', '09210', '3240023', '栃木県', 'トチギケン', '大田原市', 'オオタワラシ', '花園', 'ハナゾノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県大田原市福原', '09', '09210', '3240024', '栃木県', 'トチギケン', '大田原市', 'オオタワラシ', '福原', 'フクワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県大田原市大神', '09', '09210', '3240025', '栃木県', 'トチギケン', '大田原市', 'オオタワラシ', '大神', 'オオガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県大田原市滝岡', '09', '09210', '3240026', '栃木県', 'トチギケン', '大田原市', 'オオタワラシ', '滝岡', 'タキオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県大田原市荻野目', '09', '09210', '3240027', '栃木県', 'トチギケン', '大田原市', 'オオタワラシ', '荻野目', 'オギノメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県大田原市富士見', '09', '09210', '3240028', '栃木県', 'トチギケン', '大田原市', 'オオタワラシ', '富士見', 'フジミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県大田原市藤沢', '09', '09210', '3240031', '栃木県', 'トチギケン', '大田原市', 'オオタワラシ', '藤沢', 'フジサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県大田原市佐久山', '09', '09210', '3240032', '栃木県', 'トチギケン', '大田原市', 'オオタワラシ', '佐久山', 'サクヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県大田原市滝沢', '09', '09210', '3240033', '栃木県', 'トチギケン', '大田原市', 'オオタワラシ', '滝沢', 'タキザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県大田原市平沢', '09', '09210', '3240034', '栃木県', 'トチギケン', '大田原市', 'オオタワラシ', '平沢', 'ヒラサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県大田原市薄葉', '09', '09210', '3240035', '栃木県', 'トチギケン', '大田原市', 'オオタワラシ', '薄葉', 'ウスバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県大田原市下石上', '09', '09210', '3240036', '栃木県', 'トチギケン', '大田原市', 'オオタワラシ', '下石上', 'シモイシガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県大田原市上石上', '09', '09210', '3240037', '栃木県', 'トチギケン', '大田原市', 'オオタワラシ', '上石上', 'カミイシガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県大田原市本町', '09', '09210', '3240041', '栃木県', 'トチギケン', '大田原市', 'オオタワラシ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県大田原市末広', '09', '09210', '3240042', '栃木県', 'トチギケン', '大田原市', 'オオタワラシ', '末広', 'スエヒロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県大田原市浅香', '09', '09210', '3240043', '栃木県', 'トチギケン', '大田原市', 'オオタワラシ', '浅香', 'アサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県大田原市親園', '09', '09210', '3240044', '栃木県', 'トチギケン', '大田原市', 'オオタワラシ', '親園', 'チカソノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県大田原市実取', '09', '09210', '3240045', '栃木県', 'トチギケン', '大田原市', 'オオタワラシ', '実取', 'ミドリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県大田原市加治屋', '09', '09210', '3240046', '栃木県', 'トチギケン', '大田原市', 'オオタワラシ', '加治屋', 'カジヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県大田原市美原', '09', '09210', '3240047', '栃木県', 'トチギケン', '大田原市', 'オオタワラシ', '美原', 'ミハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県大田原市山の手', '09', '09210', '3240051', '栃木県', 'トチギケン', '大田原市', 'オオタワラシ', '山の手', 'ヤマノテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県大田原市城山', '09', '09210', '3240052', '栃木県', 'トチギケン', '大田原市', 'オオタワラシ', '城山', 'シロヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県大田原市元町', '09', '09210', '3240053', '栃木県', 'トチギケン', '大田原市', 'オオタワラシ', '元町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県大田原市若松町', '09', '09210', '3240054', '栃木県', 'トチギケン', '大田原市', 'オオタワラシ', '若松町', 'ワカマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県大田原市新富町', '09', '09210', '3240055', '栃木県', 'トチギケン', '大田原市', 'オオタワラシ', '新富町', 'シントミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県大田原市中央', '09', '09210', '3240056', '栃木県', 'トチギケン', '大田原市', 'オオタワラシ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県大田原市住吉町', '09', '09210', '3240057', '栃木県', 'トチギケン', '大田原市', 'オオタワラシ', '住吉町', 'スミヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県大田原市紫塚', '09', '09210', '3240058', '栃木県', 'トチギケン', '大田原市', 'オオタワラシ', '紫塚', 'ムラサキヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県大田原市荒井', '09', '09210', '3240061', '栃木県', 'トチギケン', '大田原市', 'オオタワラシ', '荒井', 'アライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県大田原市中田原', '09', '09210', '3240062', '栃木県', 'トチギケン', '大田原市', 'オオタワラシ', '中田原', 'ナカダワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県大田原市町島', '09', '09210', '3240063', '栃木県', 'トチギケン', '大田原市', 'オオタワラシ', '町島', 'マチジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県大田原市今泉', '09', '09210', '3240064', '栃木県', 'トチギケン', '大田原市', 'オオタワラシ', '今泉', 'イマイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県大田原市岡', '09', '09210', '3240065', '栃木県', 'トチギケン', '大田原市', 'オオタワラシ', '岡', 'オカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県大田原市戸野内', '09', '09210', '3240066', '栃木県', 'トチギケン', '大田原市', 'オオタワラシ', '戸野内', 'トノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県大田原市両郷', '09', '09210', '3240201', '栃木県', 'トチギケン', '大田原市', 'オオタワラシ', '両郷', 'リョウゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県大田原市木佐美', '09', '09210', '3240202', '栃木県', 'トチギケン', '大田原市', 'オオタワラシ', '木佐美', 'キザミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県大田原市寺宿', '09', '09210', '3240203', '栃木県', 'トチギケン', '大田原市', 'オオタワラシ', '寺宿', 'テラジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県大田原市大久保', '09', '09210', '3240204', '栃木県', 'トチギケン', '大田原市', 'オオタワラシ', '大久保', 'オオクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県大田原市久野又', '09', '09210', '3240205', '栃木県', 'トチギケン', '大田原市', 'オオタワラシ', '久野又', 'クノマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県大田原市中野内', '09', '09210', '3240206', '栃木県', 'トチギケン', '大田原市', 'オオタワラシ', '中野内', 'ナカノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県大田原市河原', '09', '09210', '3240207', '栃木県', 'トチギケン', '大田原市', 'オオタワラシ', '河原', 'カワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県大田原市川田', '09', '09210', '3240208', '栃木県', 'トチギケン', '大田原市', 'オオタワラシ', '川田', 'カワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県大田原市須賀川', '09', '09210', '3240211', '栃木県', 'トチギケン', '大田原市', 'オオタワラシ', '須賀川', 'スカガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県大田原市須佐木', '09', '09210', '3240212', '栃木県', 'トチギケン', '大田原市', 'オオタワラシ', '須佐木', 'スサギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県大田原市雲岩寺', '09', '09210', '3240213', '栃木県', 'トチギケン', '大田原市', 'オオタワラシ', '雲岩寺', 'ウンガンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県大田原市川上', '09', '09210', '3240214', '栃木県', 'トチギケン', '大田原市', 'オオタワラシ', '川上', 'カワカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県大田原市南方', '09', '09210', '3240215', '栃木県', 'トチギケン', '大田原市', 'オオタワラシ', '南方', 'ナンボウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県大田原市亀久', '09', '09210', '3240221', '栃木県', 'トチギケン', '大田原市', 'オオタワラシ', '亀久', 'カメヒサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県大田原市矢倉', '09', '09210', '3240222', '栃木県', 'トチギケン', '大田原市', 'オオタワラシ', '矢倉', 'ヤグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県大田原市片田', '09', '09210', '3240223', '栃木県', 'トチギケン', '大田原市', 'オオタワラシ', '片田', 'カタタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県大田原市北滝', '09', '09210', '3240224', '栃木県', 'トチギケン', '大田原市', 'オオタワラシ', '北滝', 'キタタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県大田原市北野上', '09', '09210', '3240231', '栃木県', 'トチギケン', '大田原市', 'オオタワラシ', '北野上', 'キタノガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県大田原市八塩', '09', '09210', '3240232', '栃木県', 'トチギケン', '大田原市', 'オオタワラシ', '八塩', 'ヤシオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県大田原市黒羽田町', '09', '09210', '3240233', '栃木県', 'トチギケン', '大田原市', 'オオタワラシ', '黒羽田町', 'クロバネタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県大田原市前田', '09', '09210', '3240234', '栃木県', 'トチギケン', '大田原市', 'オオタワラシ', '前田', 'マエタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県大田原市堀之内', '09', '09210', '3240235', '栃木県', 'トチギケン', '大田原市', 'オオタワラシ', '堀之内', 'ホリノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県大田原市大輪', '09', '09210', '3240236', '栃木県', 'トチギケン', '大田原市', 'オオタワラシ', '大輪', 'オオワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県大田原市黒羽向町', '09', '09210', '3240241', '栃木県', 'トチギケン', '大田原市', 'オオタワラシ', '黒羽向町', 'クロバネムコウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県大田原市大豆田', '09', '09210', '3240242', '栃木県', 'トチギケン', '大田原市', 'オオタワラシ', '大豆田', 'オオマメダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県大田原市余瀬', '09', '09210', '3240243', '栃木県', 'トチギケン', '大田原市', 'オオタワラシ', '余瀬', 'ヨゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県大田原市蜂巣', '09', '09210', '3240244', '栃木県', 'トチギケン', '大田原市', 'オオタワラシ', '蜂巣', 'ハチス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県大田原市桧木沢', '09', '09210', '3240245', '栃木県', 'トチギケン', '大田原市', 'オオタワラシ', '桧木沢', 'ヒノキザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県大田原市寒井', '09', '09210', '3240246', '栃木県', 'トチギケン', '大田原市', 'オオタワラシ', '寒井', 'サブイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県大田原市狭原', '09', '09210', '3240401', '栃木県', 'トチギケン', '大田原市', 'オオタワラシ', '狭原', 'セバハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県大田原市小船渡', '09', '09210', '3240402', '栃木県', 'トチギケン', '大田原市', 'オオタワラシ', '小船渡', 'コブナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県大田原市湯津上', '09', '09210', '3240403', '栃木県', 'トチギケン', '大田原市', 'オオタワラシ', '湯津上', 'ユヅカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県大田原市佐良土', '09', '09210', '3240404', '栃木県', 'トチギケン', '大田原市', 'オオタワラシ', '佐良土', 'サラド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県大田原市中の原', '09', '09210', '3240405', '栃木県', 'トチギケン', '大田原市', 'オオタワラシ', '中の原', 'ナカノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県大田原市蛭畑', '09', '09210', '3240411', '栃木県', 'トチギケン', '大田原市', 'オオタワラシ', '蛭畑', 'ヒルハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県大田原市蛭田', '09', '09210', '3240412', '栃木県', 'トチギケン', '大田原市', 'オオタワラシ', '蛭田', 'ヒルタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県大田原市新宿', '09', '09210', '3240413', '栃木県', 'トチギケン', '大田原市', 'オオタワラシ', '新宿', 'アラジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県大田原市片府田', '09', '09210', '3240414', '栃木県', 'トチギケン', '大田原市', 'オオタワラシ', '片府田', 'カタフタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県大田原市品川', '09', '09210', '3240415', '栃木県', 'トチギケン', '大田原市', 'オオタワラシ', '品川', 'シナガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須郡那珂川町小川', '09', '09411', '3240501', '栃木県', 'トチギケン', '那須郡那珂川町', 'ナスグンナカガワマチ', '小川', 'オガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須郡那珂川町三輪', '09', '09411', '3240502', '栃木県', 'トチギケン', '那須郡那珂川町', 'ナスグンナカガワマチ', '三輪', 'ミワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須郡那珂川町恩田', '09', '09411', '3240503', '栃木県', 'トチギケン', '那須郡那珂川町', 'ナスグンナカガワマチ', '恩田', 'オンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須郡那珂川町薬利', '09', '09411', '3240504', '栃木県', 'トチギケン', '那須郡那珂川町', 'ナスグンナカガワマチ', '薬利', 'クズリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須郡那珂川町芳井', '09', '09411', '3240505', '栃木県', 'トチギケン', '那須郡那珂川町', 'ナスグンナカガワマチ', '芳井', 'ヨシイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須郡那珂川町浄法寺', '09', '09411', '3240506', '栃木県', 'トチギケン', '那須郡那珂川町', 'ナスグンナカガワマチ', '浄法寺', 'ジョウホウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須郡那珂川町吉田', '09', '09411', '3240511', '栃木県', 'トチギケン', '那須郡那珂川町', 'ナスグンナカガワマチ', '吉田', 'ヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須郡那珂川町谷田', '09', '09411', '3240512', '栃木県', 'トチギケン', '那須郡那珂川町', 'ナスグンナカガワマチ', '谷田', 'ヤダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須郡那珂川町白久', '09', '09411', '3240513', '栃木県', 'トチギケン', '那須郡那珂川町', 'ナスグンナカガワマチ', '白久', 'シラク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須郡那珂川町高岡', '09', '09411', '3240514', '栃木県', 'トチギケン', '那須郡那珂川町', 'ナスグンナカガワマチ', '高岡', 'タカオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須郡那珂川町片平', '09', '09411', '3240515', '栃木県', 'トチギケン', '那須郡那珂川町', 'ナスグンナカガワマチ', '片平', 'カタヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須郡那珂川町東戸田', '09', '09411', '3240516', '栃木県', 'トチギケン', '那須郡那珂川町', 'ナスグンナカガワマチ', '東戸田', 'ヒガシトダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須郡那珂川町', '09', '09411', '3240600', '栃木県', 'トチギケン', '那須郡那珂川町', 'ナスグンナカガワマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('24775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須郡那珂川町大山田上郷', '09', '09411', '3240601', '栃木県', 'トチギケン', '那須郡那珂川町', 'ナスグンナカガワマチ', '大山田上郷', 'オオヤマダカミゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須郡那珂川町大山田下郷', '09', '09411', '3240602', '栃木県', 'トチギケン', '那須郡那珂川町', 'ナスグンナカガワマチ', '大山田下郷', 'オオヤマダシモゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須郡那珂川町谷川', '09', '09411', '3240603', '栃木県', 'トチギケン', '那須郡那珂川町', 'ナスグンナカガワマチ', '谷川', 'ヤカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須郡那珂川町盛泉', '09', '09411', '3240604', '栃木県', 'トチギケン', '那須郡那珂川町', 'ナスグンナカガワマチ', '盛泉', 'モリイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須郡那珂川町大内', '09', '09411', '3240605', '栃木県', 'トチギケン', '那須郡那珂川町', 'ナスグンナカガワマチ', '大内', 'オオウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須郡那珂川町大那地', '09', '09411', '3240606', '栃木県', 'トチギケン', '那須郡那珂川町', 'ナスグンナカガワマチ', '大那地', 'オオナチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須郡那珂川町矢又', '09', '09411', '3240607', '栃木県', 'トチギケン', '那須郡那珂川町', 'ナスグンナカガワマチ', '矢又', 'ヤマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須郡那珂川町健武', '09', '09411', '3240608', '栃木県', 'トチギケン', '那須郡那珂川町', 'ナスグンナカガワマチ', '健武', 'タケブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須郡那珂川町小砂', '09', '09411', '3240611', '栃木県', 'トチギケン', '那須郡那珂川町', 'ナスグンナカガワマチ', '小砂', 'コイサゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須郡那珂川町和見', '09', '09411', '3240612', '栃木県', 'トチギケン', '那須郡那珂川町', 'ナスグンナカガワマチ', '和見', 'ワミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須郡那珂川町馬頭', '09', '09411', '3240613', '栃木県', 'トチギケン', '那須郡那珂川町', 'ナスグンナカガワマチ', '馬頭', 'バトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須郡那珂川町久那瀬', '09', '09411', '3240614', '栃木県', 'トチギケン', '那須郡那珂川町', 'ナスグンナカガワマチ', '久那瀬', 'クナセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須郡那珂川町松野', '09', '09411', '3240615', '栃木県', 'トチギケン', '那須郡那珂川町', 'ナスグンナカガワマチ', '松野', 'マツノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須郡那珂川町富山', '09', '09411', '3240616', '栃木県', 'トチギケン', '那須郡那珂川町', 'ナスグンナカガワマチ', '富山', 'トミヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須郡那珂川町北向田', '09', '09411', '3240617', '栃木県', 'トチギケン', '那須郡那珂川町', 'ナスグンナカガワマチ', '北向田', 'キタムカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須郡那珂川町小口', '09', '09411', '3240618', '栃木県', 'トチギケン', '那須郡那珂川町', 'ナスグンナカガワマチ', '小口', 'コグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市', '09', '09213', '3250000', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('24803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須郡那須町高久甲', '09', '09407', '3250001', '栃木県', 'トチギケン', '那須郡那須町', 'ナスグンナスマチ', '高久甲', 'タカクコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須郡那須町高久丙穂積', '09', '09407', '3250002', '栃木県', 'トチギケン', '那須郡那須町', 'ナスグンナスマチ', '高久丙', 'タカクヘイ', null, null, '穂積', 'ホヅミ');
INSERT INTO `ms_addresses` VALUES ('24805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須郡那須町高久丙山梨子', '09', '09407', '3250002', '栃木県', 'トチギケン', '那須郡那須町', 'ナスグンナスマチ', '高久丙', 'タカクヘイ', null, null, '山梨子', 'ヤマナシ');
INSERT INTO `ms_addresses` VALUES ('24806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須郡那須町寺子乙', '09', '09407', '3250003', '栃木県', 'トチギケン', '那須郡那須町', 'ナスグンナスマチ', '寺子乙', 'テラコオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市寺子', '09', '09213', '3250011', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '寺子', 'テラゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市越堀', '09', '09213', '3250012', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '越堀', 'コエボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市鍋掛', '09', '09213', '3250013', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '鍋掛', 'ナベカケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市野間', '09', '09213', '3250014', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '野間', 'ノマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市原町', '09', '09213', '3250015', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '原町', 'ハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市東栄', '09', '09213', '3250016', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '東栄', 'トウエイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市黒磯', '09', '09213', '3250017', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '黒磯', 'クロイソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市安藤町', '09', '09213', '3250021', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '安藤町', 'アンドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市東豊浦', '09', '09213', '3250022', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '東豊浦', 'ヒガシトヨウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市豊浦', '09', '09213', '3250023', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '豊浦', 'トヨウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市渡辺', '09', '09213', '3250024', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '渡辺', 'ワタナベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市下厚崎', '09', '09213', '3250025', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '下厚崎', 'シモアツサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市上厚崎', '09', '09213', '3250026', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '上厚崎', 'カミアツサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市共墾社', '09', '09213', '3250027', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '共墾社', 'キョウコンシャ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市並木町', '09', '09213', '3250031', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '並木町', 'ナミキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市若草町', '09', '09213', '3250032', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '若草町', 'ワカクサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市埼玉', '09', '09213', '3250033', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '埼玉', 'サキタマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市東原', '09', '09213', '3250034', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '東原', 'ヒガシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市小結', '09', '09213', '3250035', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '小結', 'コユイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市鳥野目', '09', '09213', '3250036', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '鳥野目', 'トリノメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市美原町', '09', '09213', '3250037', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '美原町', 'ミハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市豊浦北町', '09', '09213', '3250038', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '豊浦北町', 'トヨウラキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市北栄町', '09', '09213', '3250039', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '北栄町', 'キタサカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市東大和町', '09', '09213', '3250041', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '東大和町', 'ヒガシヤマトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市桜町', '09', '09213', '3250042', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '桜町', 'サクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市橋本町', '09', '09213', '3250043', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '橋本町', 'ハシモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市弥生町', '09', '09213', '3250044', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '弥生町', 'ヤヨイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市高砂町', '09', '09213', '3250045', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '高砂町', 'タカサゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市大黒町', '09', '09213', '3250046', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '大黒町', 'ダイコクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市若葉町', '09', '09213', '3250047', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '若葉町', 'ワカバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市材木町', '09', '09213', '3250048', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '材木町', 'ザイモクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市豊町', '09', '09213', '3250051', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '豊町', 'ユタカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市中央町', '09', '09213', '3250052', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '中央町', 'チュウオウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市本郷町', '09', '09213', '3250053', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '本郷町', 'ホンゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市新朝日', '09', '09213', '3250054', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '新朝日', 'シンアサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市宮町', '09', '09213', '3250055', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '宮町', 'ミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市本町', '09', '09213', '3250056', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市黒磯幸町', '09', '09213', '3250057', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '黒磯幸町', 'クロイソサイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市錦町', '09', '09213', '3250058', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '錦町', 'ニシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市末広町', '09', '09213', '3250061', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '末広町', 'スエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市住吉町', '09', '09213', '3250062', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '住吉町', 'スミヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市豊浦中町', '09', '09213', '3250063', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '豊浦中町', 'トヨウラナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市豊浦町', '09', '09213', '3250064', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '豊浦町', 'トヨウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市豊浦南町', '09', '09213', '3250065', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '豊浦南町', 'トヨウラミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市新緑町', '09', '09213', '3250066', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '新緑町', 'シンミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市清住町', '09', '09213', '3250067', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '清住町', 'キヨスミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市新町', '09', '09213', '3250071', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市豊住町', '09', '09213', '3250072', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '豊住町', 'トヨスミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市阿波町', '09', '09213', '3250073', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '阿波町', 'アワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市松浦町', '09', '09213', '3250074', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '松浦町', 'マツウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市春日町', '09', '09213', '3250075', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '春日町', 'カスガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市西新町', '09', '09213', '3250076', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '西新町', 'ニシシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市西岩崎', '09', '09213', '3250101', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '西岩崎', 'ニシイワザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市亀山', '09', '09213', '3250102', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '亀山', 'カメヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市青木', '09', '09213', '3250103', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '青木', 'アオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市鹿野崎新田', '09', '09213', '3250104', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '鹿野崎新田', 'カノサキシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市箕輪', '09', '09213', '3250105', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '箕輪', 'ミノワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市洞島', '09', '09213', '3250106', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '洞島', 'ドウジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市高林', '09', '09213', '3250107', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '高林', 'タカバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市箭坪', '09', '09213', '3250108', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '箭坪', 'ヤツボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市板室', '09', '09213', '3250111', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '板室', 'イタムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市油井', '09', '09213', '3250112', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '油井', 'ユイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市細竹', '09', '09213', '3250113', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '細竹', 'ホソダケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市戸田', '09', '09213', '3250114', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '戸田', 'トダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市百村', '09', '09213', '3250115', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '百村', 'モムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市木綿畑', '09', '09213', '3250116', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '木綿畑', 'キワタハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市湯宮', '09', '09213', '3250117', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '湯宮', 'ユグウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市鴫内', '09', '09213', '3250118', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '鴫内', 'シギウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須郡那須町湯本', '09', '09407', '3250301', '栃木県', 'トチギケン', '那須郡那須町', 'ナスグンナスマチ', '湯本', 'ユモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須郡那須町高久丙', '09', '09407', '3250302', '栃木県', 'トチギケン', '那須郡那須町', 'ナスグンナスマチ', '高久丙', 'タカクヘイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須郡那須町高久乙', '09', '09407', '3250303', '栃木県', 'トチギケン', '那須郡那須町', 'ナスグンナスマチ', '高久乙', 'タカクオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須郡那須町高久甲', '09', '09407', '3250304', '栃木県', 'トチギケン', '那須郡那須町', 'ナスグンナスマチ', '高久甲', 'タカクコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市', '09', '09202', '3260000', '栃木県', 'トチギケン', '足利市', 'アシカガシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('24885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市名草上町', '09', '09202', '3260001', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '名草上町', 'ナグサカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市名草中町', '09', '09202', '3260002', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '名草中町', 'ナグサナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市名草下町', '09', '09202', '3260003', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '名草下町', 'ナグサシモチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市樺崎町', '09', '09202', '3260004', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '樺崎町', 'カバサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市大月町', '09', '09202', '3260005', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '大月町', 'オオツキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市利保町', '09', '09202', '3260006', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '利保町', 'カカボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市菅田町', '09', '09202', '3260007', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '菅田町', 'スゲタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市大沼田町', '09', '09202', '3260011', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '大沼田町', 'オオヌマタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市大久保町', '09', '09202', '3260012', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '大久保町', 'オオクボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市川崎町', '09', '09202', '3260013', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '川崎町', 'カワサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市鵤木町', '09', '09202', '3260014', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '鵤木町', 'イカルギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市八椚町', '09', '09202', '3260015', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '八椚町', 'ヤツクヌギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市毛野新町', '09', '09202', '3260016', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '毛野新町', 'ケノシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市山川町', '09', '09202', '3260021', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '山川町', 'ヤマガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市常見町', '09', '09202', '3260022', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '常見町', 'ツネミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市猿田町', '09', '09202', '3260023', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '猿田町', 'サルタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市若草町', '09', '09202', '3260024', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '若草町', 'ワカクサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市寿町', '09', '09202', '3260025', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '寿町', 'コトブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市常盤町', '09', '09202', '3260026', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '常盤町', 'トキワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市宮北町', '09', '09202', '3260027', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '宮北町', 'ミヤキタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市末広町', '09', '09202', '3260031', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '末広町', 'スエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市真砂町', '09', '09202', '3260032', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '真砂町', 'マサゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市花園町', '09', '09202', '3260033', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '花園町', 'ハナゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市久松町', '09', '09202', '3260034', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '久松町', 'ヒサマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市芳町', '09', '09202', '3260035', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '芳町', 'ヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市弥生町', '09', '09202', '3260036', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '弥生町', 'ヤヨイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市富士見町', '09', '09202', '3260037', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '富士見町', 'フジミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市助戸新山町', '09', '09202', '3260041', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '助戸新山町', 'スケドシンヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市助戸東山町', '09', '09202', '3260042', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '助戸東山町', 'スケドヒガシヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市助戸仲町', '09', '09202', '3260043', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '助戸仲町', 'スケドナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市助戸', '09', '09202', '3260044', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '助戸', 'スケド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市千歳町', '09', '09202', '3260045', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '千歳町', 'チトセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市岩井町', '09', '09202', '3260046', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '岩井町', 'イワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市錦町', '09', '09202', '3260047', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '錦町', 'ニシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市助戸大橋町', '09', '09202', '3260048', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '助戸大橋町', 'スケドオオハシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市大橋町', '09', '09202', '3260051', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '大橋町', 'オオハシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市相生町', '09', '09202', '3260052', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '相生町', 'アイオイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市伊勢町', '09', '09202', '3260053', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '伊勢町', 'イセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市伊勢南町', '09', '09202', '3260054', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '伊勢南町', 'イセミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市永楽町', '09', '09202', '3260055', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '永楽町', 'エイラクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市大町', '09', '09202', '3260056', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '大町', 'ダイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市丸山町', '09', '09202', '3260057', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '丸山町', 'マルヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市元学町', '09', '09202', '3260058', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '元学町', 'モトガクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市田島町', '09', '09202', '3260061', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '田島町', 'タジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市赤松台', '09', '09202', '3260062', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '赤松台', 'アカマツダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市新山町', '09', '09202', '3260063', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '新山町', 'シンヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市東砂原後町', '09', '09202', '3260064', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '東砂原後町', 'ヒガシサワラゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市西砂原後町', '09', '09202', '3260065', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '西砂原後町', 'ニシサワラゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市田所町', '09', '09202', '3260066', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '田所町', 'タドコロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市江川町', '09', '09202', '3260067', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '江川町', 'エガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市月谷町', '09', '09202', '3260068', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '月谷町', 'ツキヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市松田町', '09', '09202', '3260101', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '松田町', 'マツダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市板倉町', '09', '09202', '3260102', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '板倉町', 'イタクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市粟谷町', '09', '09202', '3260103', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '粟谷町', 'アワノヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市小俣町', '09', '09202', '3260141', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '小俣町', 'オマタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市小俣南町', '09', '09202', '3260142', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '小俣南町', 'オマタミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市葉鹿町', '09', '09202', '3260143', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '葉鹿町', 'ハジカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市葉鹿南町', '09', '09202', '3260144', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '葉鹿南町', 'ハジカミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市梁田町', '09', '09202', '3260321', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '梁田町', 'ヤナダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市野田町', '09', '09202', '3260322', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '野田町', 'ノダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市瑞穂野町', '09', '09202', '3260323', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '瑞穂野町', 'ミズホノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市久保田町', '09', '09202', '3260324', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '久保田町', 'クボタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市高松町', '09', '09202', '3260325', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '高松町', 'タカマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市小曽根町', '09', '09202', '3260326', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '小曽根町', 'オゾネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市羽刈町', '09', '09202', '3260327', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '羽刈町', 'ハカリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市県町', '09', '09202', '3260328', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '県町', 'アガタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市福富町', '09', '09202', '3260331', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '福富町', 'フクトミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市福富新町', '09', '09202', '3260332', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '福富新町', 'フクトミシンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市問屋町', '09', '09202', '3260333', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '問屋町', 'トンヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市下渋垂町', '09', '09202', '3260334', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '下渋垂町', 'シモシブタレチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市上渋垂町', '09', '09202', '3260335', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '上渋垂町', 'カミシブタレチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市百頭町', '09', '09202', '3260336', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '百頭町', 'モモガシラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市島田町', '09', '09202', '3260337', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '島田町', 'シマダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市福居町', '09', '09202', '3260338', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '福居町', 'フクイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市有楽町', '09', '09202', '3260801', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '有楽町', 'ユウラクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市旭町', '09', '09202', '3260802', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '旭町', 'アサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市家富町', '09', '09202', '3260803', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '家富町', 'イエトミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市雪輪町', '09', '09202', '3260804', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '雪輪町', 'ユキワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市巴町', '09', '09202', '3260805', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '巴町', 'トモエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市柳原町', '09', '09202', '3260806', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '柳原町', 'ヤナギワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市大正町', '09', '09202', '3260807', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '大正町', 'タイショウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市本城', '09', '09202', '3260808', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '本城', 'ホンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市井草町', '09', '09202', '3260811', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '井草町', 'イグサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市大門通', '09', '09202', '3260812', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '大門通', 'ダイモンドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市昌平町', '09', '09202', '3260813', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '昌平町', 'ショウヘイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市通', '09', '09202', '3260814', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '通', 'トオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市栄町', '09', '09202', '3260815', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '栄町', 'サカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市緑町', '09', '09202', '3260816', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '緑町', 'ミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市西宮町', '09', '09202', '3260817', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '西宮町', 'ニシノミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市南町', '09', '09202', '3260821', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '南町', 'ミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市田中町', '09', '09202', '3260822', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '田中町', 'タナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市朝倉町', '09', '09202', '3260823', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '朝倉町', 'アサクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市八幡町', '09', '09202', '3260824', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '八幡町', 'ヤワタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市中川町', '09', '09202', '3260825', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '中川町', 'ナカガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市借宿町', '09', '09202', '3260826', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '借宿町', 'カリヤドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市堀込町', '09', '09202', '3260831', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '堀込町', 'ホリゴメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市荒金町', '09', '09202', '3260832', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '荒金町', 'アラカネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市藤本町', '09', '09202', '3260833', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '藤本町', 'フジモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市新宿町', '09', '09202', '3260834', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '新宿町', 'アラジュクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市里矢場町', '09', '09202', '3260835', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '里矢場町', 'サトヤバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市南大町', '09', '09202', '3260836', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '南大町', 'ミナミオオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市西新井町', '09', '09202', '3260837', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '西新井町', 'ニシアライチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市大岩町', '09', '09202', '3260841', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '大岩町', 'オオイワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市今福町', '09', '09202', '3260842', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '今福町', 'イマフクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市五十部町', '09', '09202', '3260843', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '五十部町', 'ヨベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市鹿島町', '09', '09202', '3260844', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '鹿島町', 'カシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市大前町', '09', '09202', '3260845', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '大前町', 'オオマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('24995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市山下町', '09', '09202', '3260846', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '山下町', 'ヤマシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市', '09', '09204', '3270000', '栃木県', 'トチギケン', '佐野市', 'サノシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('25013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市小中町', '09', '09204', '3270001', '栃木県', 'トチギケン', '佐野市', 'サノシ', '小中町', 'コナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市並木町', '09', '09204', '3270002', '栃木県', 'トチギケン', '佐野市', 'サノシ', '並木町', 'ナミキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市大橋町', '09', '09204', '3270003', '栃木県', 'トチギケン', '佐野市', 'サノシ', '大橋町', 'オオハシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市赤坂町', '09', '09204', '3270004', '栃木県', 'トチギケン', '佐野市', 'サノシ', '赤坂町', 'アカサカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市七軒町', '09', '09204', '3270005', '栃木県', 'トチギケン', '佐野市', 'サノシ', '七軒町', 'シチケンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市上台町', '09', '09204', '3270006', '栃木県', 'トチギケン', '佐野市', 'サノシ', '上台町', 'カミダイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市金吹町', '09', '09204', '3270007', '栃木県', 'トチギケン', '佐野市', 'サノシ', '金吹町', 'カナフキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市朝日町', '09', '09204', '3270011', '栃木県', 'トチギケン', '佐野市', 'サノシ', '朝日町', 'アサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市大蔵町', '09', '09204', '3270012', '栃木県', 'トチギケン', '佐野市', 'サノシ', '大蔵町', 'オオクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市本町', '09', '09204', '3270013', '栃木県', 'トチギケン', '佐野市', 'サノシ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市天明町', '09', '09204', '3270014', '栃木県', 'トチギケン', '佐野市', 'サノシ', '天明町', 'テンミョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市金井上町', '09', '09204', '3270015', '栃木県', 'トチギケン', '佐野市', 'サノシ', '金井上町', 'カナイカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市大祝町', '09', '09204', '3270016', '栃木県', 'トチギケン', '佐野市', 'サノシ', '大祝町', 'ダイシュクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市大町', '09', '09204', '3270017', '栃木県', 'トチギケン', '佐野市', 'サノシ', '大町', 'ダイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市伊賀町', '09', '09204', '3270021', '栃木県', 'トチギケン', '佐野市', 'サノシ', '伊賀町', 'イガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市高砂町', '09', '09204', '3270022', '栃木県', 'トチギケン', '佐野市', 'サノシ', '高砂町', 'タカサゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市相生町', '09', '09204', '3270023', '栃木県', 'トチギケン', '佐野市', 'サノシ', '相生町', 'アイオイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市亀井町', '09', '09204', '3270024', '栃木県', 'トチギケン', '佐野市', 'サノシ', '亀井町', 'カメイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市金屋下町', '09', '09204', '3270025', '栃木県', 'トチギケン', '佐野市', 'サノシ', '金屋下町', 'カナヤシモチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市金屋仲町', '09', '09204', '3270026', '栃木県', 'トチギケン', '佐野市', 'サノシ', '金屋仲町', 'カナヤナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市大和町', '09', '09204', '3270027', '栃木県', 'トチギケン', '佐野市', 'サノシ', '大和町', 'ヤマトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市万町', '09', '09204', '3270028', '栃木県', 'トチギケン', '佐野市', 'サノシ', '万町', 'ヨロズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市田島町', '09', '09204', '3270031', '栃木県', 'トチギケン', '佐野市', 'サノシ', '田島町', 'タジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市庚申塚町', '09', '09204', '3270032', '栃木県', 'トチギケン', '佐野市', 'サノシ', '庚申塚町', 'カネヅカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市大古屋町', '09', '09204', '3270033', '栃木県', 'トチギケン', '佐野市', 'サノシ', '大古屋町', 'オオゴヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市伊保内町', '09', '09204', '3270034', '栃木県', 'トチギケン', '佐野市', 'サノシ', '伊保内町', 'イボウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市船津川町', '09', '09204', '3270035', '栃木県', 'トチギケン', '佐野市', 'サノシ', '船津川町', 'フナツガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市免鳥町', '09', '09204', '3270041', '栃木県', 'トチギケン', '佐野市', 'サノシ', '免鳥町', 'メンドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市上羽田町', '09', '09204', '3270042', '栃木県', 'トチギケン', '佐野市', 'サノシ', '上羽田町', 'カミハネダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市君田町', '09', '09204', '3270043', '栃木県', 'トチギケン', '佐野市', 'サノシ', '君田町', 'キミタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市下羽田町', '09', '09204', '3270044', '栃木県', 'トチギケン', '佐野市', 'サノシ', '下羽田町', 'シモハネダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市高橋町', '09', '09204', '3270045', '栃木県', 'トチギケン', '佐野市', 'サノシ', '高橋町', 'タカハシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市村上町', '09', '09204', '3270046', '栃木県', 'トチギケン', '佐野市', 'サノシ', '村上町', 'ムラカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市寺久保町', '09', '09204', '3270101', '栃木県', 'トチギケン', '佐野市', 'サノシ', '寺久保町', 'テラクボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市出流原町', '09', '09204', '3270102', '栃木県', 'トチギケン', '佐野市', 'サノシ', '出流原町', 'イズルハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市石塚町', '09', '09204', '3270103', '栃木県', 'トチギケン', '佐野市', 'サノシ', '石塚町', 'イシヅカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市赤見町', '09', '09204', '3270104', '栃木県', 'トチギケン', '佐野市', 'サノシ', '赤見町', 'アカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市飛駒町', '09', '09204', '3270231', '栃木県', 'トチギケン', '佐野市', 'サノシ', '飛駒町', 'ヒコマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市作原町', '09', '09204', '3270301', '栃木県', 'トチギケン', '佐野市', 'サノシ', '作原町', 'サクハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市白岩町', '09', '09204', '3270302', '栃木県', 'トチギケン', '佐野市', 'サノシ', '白岩町', 'シライワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市長谷場町', '09', '09204', '3270303', '栃木県', 'トチギケン', '佐野市', 'サノシ', '長谷場町', 'ハセバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市御神楽町', '09', '09204', '3270304', '栃木県', 'トチギケン', '佐野市', 'サノシ', '御神楽町', 'ミカグラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市船越町', '09', '09204', '3270305', '栃木県', 'トチギケン', '佐野市', 'サノシ', '船越町', 'フナコシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市戸室町', '09', '09204', '3270306', '栃木県', 'トチギケン', '佐野市', 'サノシ', '戸室町', 'トムロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市岩崎町', '09', '09204', '3270307', '栃木県', 'トチギケン', '佐野市', 'サノシ', '岩崎町', 'イワザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市多田町', '09', '09204', '3270311', '栃木県', 'トチギケン', '佐野市', 'サノシ', '多田町', 'タダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市栃本町', '09', '09204', '3270312', '栃木県', 'トチギケン', '佐野市', 'サノシ', '栃本町', 'トチモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市吉水町', '09', '09204', '3270313', '栃木県', 'トチギケン', '佐野市', 'サノシ', '吉水町', 'ヨシミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市新吉水町', '09', '09204', '3270314', '栃木県', 'トチギケン', '佐野市', 'サノシ', '新吉水町', 'シンヨシミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市吉水駅前', '09', '09204', '3270315', '栃木県', 'トチギケン', '佐野市', 'サノシ', '吉水駅前', 'ヨシミズエキマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市小見町', '09', '09204', '3270316', '栃木県', 'トチギケン', '佐野市', 'サノシ', '小見町', 'オミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市田沼町', '09', '09204', '3270317', '栃木県', 'トチギケン', '佐野市', 'サノシ', '田沼町', 'タヌマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市山越町', '09', '09204', '3270318', '栃木県', 'トチギケン', '佐野市', 'サノシ', '山越町', 'ヤマコシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市閑馬町', '09', '09204', '3270321', '栃木県', 'トチギケン', '佐野市', 'サノシ', '閑馬町', 'カンマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市梅園町', '09', '09204', '3270322', '栃木県', 'トチギケン', '佐野市', 'サノシ', '梅園町', 'ウメゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市戸奈良町', '09', '09204', '3270323', '栃木県', 'トチギケン', '佐野市', 'サノシ', '戸奈良町', 'トナラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市山形町', '09', '09204', '3270324', '栃木県', 'トチギケン', '佐野市', 'サノシ', '山形町', 'ヤマガタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市下彦間町', '09', '09204', '3270325', '栃木県', 'トチギケン', '佐野市', 'サノシ', '下彦間町', 'シモヒコマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市葛生東', '09', '09204', '3270501', '栃木県', 'トチギケン', '佐野市', 'サノシ', '葛生東', 'クズウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市築地町', '09', '09204', '3270502', '栃木県', 'トチギケン', '佐野市', 'サノシ', '築地町', 'ツイジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市富士見町', '09', '09204', '3270503', '栃木県', 'トチギケン', '佐野市', 'サノシ', '富士見町', 'フジミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市中町', '09', '09204', '3270504', '栃木県', 'トチギケン', '佐野市', 'サノシ', '中町', 'ナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市山菅町', '09', '09204', '3270505', '栃木県', 'トチギケン', '佐野市', 'サノシ', '山菅町', 'ヤマスゲチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市葛生西', '09', '09204', '3270507', '栃木県', 'トチギケン', '佐野市', 'サノシ', '葛生西', 'クズウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市鉢木町', '09', '09204', '3270508', '栃木県', 'トチギケン', '佐野市', 'サノシ', '鉢木町', 'ハチノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市宮下町', '09', '09204', '3270509', '栃木県', 'トチギケン', '佐野市', 'サノシ', '宮下町', 'ミヤシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市会沢町', '09', '09204', '3270511', '栃木県', 'トチギケン', '佐野市', 'サノシ', '会沢町', 'アイサワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市豊代町', '09', '09204', '3270512', '栃木県', 'トチギケン', '佐野市', 'サノシ', '豊代町', 'トヨシロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市牧町', '09', '09204', '3270513', '栃木県', 'トチギケン', '佐野市', 'サノシ', '牧町', 'マギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市仙波町', '09', '09204', '3270514', '栃木県', 'トチギケン', '佐野市', 'サノシ', '仙波町', 'センバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市柿平町', '09', '09204', '3270515', '栃木県', 'トチギケン', '佐野市', 'サノシ', '柿平町', 'カキダイラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市水木町', '09', '09204', '3270516', '栃木県', 'トチギケン', '佐野市', 'サノシ', '水木町', 'ミズキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市秋山町', '09', '09204', '3270517', '栃木県', 'トチギケン', '佐野市', 'サノシ', '秋山町', 'アキヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市嘉多山町', '09', '09204', '3270523', '栃木県', 'トチギケン', '佐野市', 'サノシ', '嘉多山町', 'カタヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市長坂町', '09', '09204', '3270524', '栃木県', 'トチギケン', '佐野市', 'サノシ', '長坂町', 'ナガサカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市あくと町', '09', '09204', '3270525', '栃木県', 'トチギケン', '佐野市', 'サノシ', 'あくと町', 'アクトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市富士町', '09', '09204', '3270801', '栃木県', 'トチギケン', '佐野市', 'サノシ', '富士町', 'フジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市韮川町', '09', '09204', '3270802', '栃木県', 'トチギケン', '佐野市', 'サノシ', '韮川町', 'ニラガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市犬伏新町', '09', '09204', '3270803', '栃木県', 'トチギケン', '佐野市', 'サノシ', '犬伏新町', 'イヌブシシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市犬伏下町', '09', '09204', '3270804', '栃木県', 'トチギケン', '佐野市', 'サノシ', '犬伏下町', 'イヌブシシモチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市犬伏中町', '09', '09204', '3270805', '栃木県', 'トチギケン', '佐野市', 'サノシ', '犬伏中町', 'イヌブシナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市犬伏上町', '09', '09204', '3270806', '栃木県', 'トチギケン', '佐野市', 'サノシ', '犬伏上町', 'イヌブシカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市大栗町', '09', '09204', '3270807', '栃木県', 'トチギケン', '佐野市', 'サノシ', '大栗町', 'オオグリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市関川町', '09', '09204', '3270811', '栃木県', 'トチギケン', '佐野市', 'サノシ', '関川町', 'セキガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市町谷町', '09', '09204', '3270812', '栃木県', 'トチギケン', '佐野市', 'サノシ', '町谷町', 'マチヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市黒袴町', '09', '09204', '3270813', '栃木県', 'トチギケン', '佐野市', 'サノシ', '黒袴町', 'クロハカマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市西浦町', '09', '09204', '3270814', '栃木県', 'トチギケン', '佐野市', 'サノシ', '西浦町', 'ニシウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市鐙塚町', '09', '09204', '3270815', '栃木県', 'トチギケン', '佐野市', 'サノシ', '鐙塚町', 'アブツカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市栄町', '09', '09204', '3270816', '栃木県', 'トチギケン', '佐野市', 'サノシ', '栄町', 'サカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市伊勢山町', '09', '09204', '3270817', '栃木県', 'トチギケン', '佐野市', 'サノシ', '伊勢山町', 'イセヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市米山南町', '09', '09204', '3270818', '栃木県', 'トチギケン', '佐野市', 'サノシ', '米山南町', 'ヨネヤマミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市高萩町', '09', '09204', '3270821', '栃木県', 'トチギケン', '佐野市', 'サノシ', '高萩町', 'タカハギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市越名町', '09', '09204', '3270822', '栃木県', 'トチギケン', '佐野市', 'サノシ', '越名町', 'コエナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市高山町', '09', '09204', '3270823', '栃木県', 'トチギケン', '佐野市', 'サノシ', '高山町', 'タカヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市馬門町', '09', '09204', '3270824', '栃木県', 'トチギケン', '佐野市', 'サノシ', '馬門町', 'マカドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市飯田町', '09', '09204', '3270825', '栃木県', 'トチギケン', '佐野市', 'サノシ', '飯田町', 'イイタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市茂呂山町', '09', '09204', '3270826', '栃木県', 'トチギケン', '佐野市', 'サノシ', '茂呂山町', 'モロヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市北茂呂町', '09', '09204', '3270827', '栃木県', 'トチギケン', '佐野市', 'サノシ', '北茂呂町', 'キタモロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市浅沼町', '09', '09204', '3270831', '栃木県', 'トチギケン', '佐野市', 'サノシ', '浅沼町', 'アサヌマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市植上町', '09', '09204', '3270832', '栃木県', 'トチギケン', '佐野市', 'サノシ', '植上町', 'ウエカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市若宮上町', '09', '09204', '3270833', '栃木県', 'トチギケン', '佐野市', 'サノシ', '若宮上町', 'ワカミヤカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市若宮下町', '09', '09204', '3270834', '栃木県', 'トチギケン', '佐野市', 'サノシ', '若宮下町', 'ワカミヤシモチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市植下町', '09', '09204', '3270835', '栃木県', 'トチギケン', '佐野市', 'サノシ', '植下町', 'ウエシモチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市寺中町', '09', '09204', '3270836', '栃木県', 'トチギケン', '佐野市', 'サノシ', '寺中町', 'ジチュウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市植野町', '09', '09204', '3270837', '栃木県', 'トチギケン', '佐野市', 'サノシ', '植野町', 'ウエノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市田之入町', '09', '09204', '3270841', '栃木県', 'トチギケン', '佐野市', 'サノシ', '田之入町', 'タノイリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市奈良渕町', '09', '09204', '3270842', '栃木県', 'トチギケン', '佐野市', 'サノシ', '奈良渕町', 'ナラブチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市堀米町', '09', '09204', '3270843', '栃木県', 'トチギケン', '佐野市', 'サノシ', '堀米町', 'ホリゴメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市富岡町', '09', '09204', '3270844', '栃木県', 'トチギケン', '佐野市', 'サノシ', '富岡町', 'トミオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市久保町', '09', '09204', '3270845', '栃木県', 'トチギケン', '佐野市', 'サノシ', '久保町', 'クボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市若松町', '09', '09204', '3270846', '栃木県', 'トチギケン', '佐野市', 'サノシ', '若松町', 'ワカマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市天神町', '09', '09204', '3270847', '栃木県', 'トチギケン', '佐野市', 'サノシ', '天神町', 'テンジンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県栃木市', '09', '09203', '3280000', '栃木県', 'トチギケン', '栃木市', 'トチギシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('25136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県栃木市柳原町', '09', '09203', '3280001', '栃木県', 'トチギケン', '栃木市', 'トチギシ', '柳原町', 'ヤナギハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県栃木市惣社町', '09', '09203', '3280002', '栃木県', 'トチギケン', '栃木市', 'トチギシ', '惣社町', 'ソウジャマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県栃木市大光寺町', '09', '09203', '3280003', '栃木県', 'トチギケン', '栃木市', 'トチギシ', '大光寺町', 'ダイコウジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県栃木市田村町', '09', '09203', '3280004', '栃木県', 'トチギケン', '栃木市', 'トチギシ', '田村町', 'タムラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県栃木市寄居町', '09', '09203', '3280005', '栃木県', 'トチギケン', '栃木市', 'トチギシ', '寄居町', 'ヨリイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県栃木市国府町', '09', '09203', '3280006', '栃木県', 'トチギケン', '栃木市', 'トチギシ', '国府町', 'コウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県栃木市大塚町', '09', '09203', '3280007', '栃木県', 'トチギケン', '栃木市', 'トチギシ', '大塚町', 'オオツカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県栃木市大宮町', '09', '09203', '3280011', '栃木県', 'トチギケン', '栃木市', 'トチギシ', '大宮町', 'オオミヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県栃木市平柳町', '09', '09203', '3280012', '栃木県', 'トチギケン', '栃木市', 'トチギシ', '平柳町', 'ヒラヤナギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県栃木市昭和町', '09', '09203', '3280013', '栃木県', 'トチギケン', '栃木市', 'トチギシ', '昭和町', 'ショウワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県栃木市泉町', '09', '09203', '3280014', '栃木県', 'トチギケン', '栃木市', 'トチギシ', '泉町', 'イズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県栃木市万町', '09', '09203', '3280015', '栃木県', 'トチギケン', '栃木市', 'トチギシ', '万町', 'ヨロズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県栃木市入舟町', '09', '09203', '3280016', '栃木県', 'トチギケン', '栃木市', 'トチギシ', '入舟町', 'イリフネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県栃木市錦町', '09', '09203', '3280017', '栃木県', 'トチギケン', '栃木市', 'トチギシ', '錦町', 'ニシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県栃木市久保田町', '09', '09203', '3280021', '栃木県', 'トチギケン', '栃木市', 'トチギシ', '久保田町', 'クボタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県栃木市宮田町', '09', '09203', '3280022', '栃木県', 'トチギケン', '栃木市', 'トチギシ', '宮田町', 'ミヤタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県栃木市高谷町', '09', '09203', '3280023', '栃木県', 'トチギケン', '栃木市', 'トチギシ', '高谷町', 'コウヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県栃木市樋ノ口町', '09', '09203', '3280024', '栃木県', 'トチギケン', '栃木市', 'トチギシ', '樋ノ口町', 'ヒノクチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県栃木市仲仕上町', '09', '09203', '3280025', '栃木県', 'トチギケン', '栃木市', 'トチギシ', '仲仕上町', 'ナカシアゲマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県栃木市藤田町', '09', '09203', '3280026', '栃木県', 'トチギケン', '栃木市', 'トチギシ', '藤田町', 'フジタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県栃木市今泉町', '09', '09203', '3280027', '栃木県', 'トチギケン', '栃木市', 'トチギシ', '今泉町', 'イマイズミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県栃木市日ノ出町', '09', '09203', '3280031', '栃木県', 'トチギケン', '栃木市', 'トチギシ', '日ノ出町', 'ヒノデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県栃木市神田町', '09', '09203', '3280032', '栃木県', 'トチギケン', '栃木市', 'トチギシ', '神田町', 'カンダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県栃木市城内町', '09', '09203', '3280033', '栃木県', 'トチギケン', '栃木市', 'トチギシ', '城内町', 'ジョウナイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県栃木市本町', '09', '09203', '3280034', '栃木県', 'トチギケン', '栃木市', 'トチギシ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県栃木市旭町', '09', '09203', '3280035', '栃木県', 'トチギケン', '栃木市', 'トチギシ', '旭町', 'アサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県栃木市室町', '09', '09203', '3280036', '栃木県', 'トチギケン', '栃木市', 'トチギシ', '室町', 'ムロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県栃木市倭町', '09', '09203', '3280037', '栃木県', 'トチギケン', '栃木市', 'トチギシ', '倭町', 'ヤマトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県栃木市河合町', '09', '09203', '3280041', '栃木県', 'トチギケン', '栃木市', 'トチギシ', '河合町', 'カワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県栃木市沼和田町', '09', '09203', '3280042', '栃木県', 'トチギケン', '栃木市', 'トチギシ', '沼和田町', 'ヌマワダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県栃木市境町', '09', '09203', '3280043', '栃木県', 'トチギケン', '栃木市', 'トチギシ', '境町', 'サカイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県栃木市富士見町', '09', '09203', '3280044', '栃木県', 'トチギケン', '栃木市', 'トチギシ', '富士見町', 'フジミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県栃木市湊町', '09', '09203', '3280045', '栃木県', 'トチギケン', '栃木市', 'トチギシ', '湊町', 'ミナトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県栃木市柳橋町', '09', '09203', '3280051', '栃木県', 'トチギケン', '栃木市', 'トチギシ', '柳橋町', 'ヤナギバシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県栃木市祝町', '09', '09203', '3280052', '栃木県', 'トチギケン', '栃木市', 'トチギシ', '祝町', 'イワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県栃木市片柳町', '09', '09203', '3280053', '栃木県', 'トチギケン', '栃木市', 'トチギシ', '片柳町', 'カタヤナギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県栃木市平井町', '09', '09203', '3280054', '栃木県', 'トチギケン', '栃木市', 'トチギシ', '平井町', 'ヒライチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県栃木市新井町', '09', '09203', '3280061', '栃木県', 'トチギケン', '栃木市', 'トチギシ', '新井町', 'アライマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県栃木市泉川町', '09', '09203', '3280062', '栃木県', 'トチギケン', '栃木市', 'トチギシ', '泉川町', 'イズミガワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県栃木市岩出町', '09', '09203', '3280063', '栃木県', 'トチギケン', '栃木市', 'トチギシ', '岩出町', 'イワデマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県栃木市志鳥町', '09', '09203', '3280064', '栃木県', 'トチギケン', '栃木市', 'トチギシ', '志鳥町', 'シトリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県栃木市小野口町', '09', '09203', '3280065', '栃木県', 'トチギケン', '栃木市', 'トチギシ', '小野口町', 'オノグチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県栃木市柏倉町', '09', '09203', '3280066', '栃木県', 'トチギケン', '栃木市', 'トチギシ', '柏倉町', 'カシワグラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県栃木市皆川城内町', '09', '09203', '3280067', '栃木県', 'トチギケン', '栃木市', 'トチギシ', '皆川城内町', 'ミナガワジョウナイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県栃木市大皆川町', '09', '09203', '3280068', '栃木県', 'トチギケン', '栃木市', 'トチギシ', '大皆川町', 'オオミナガワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県栃木市大町', '09', '09203', '3280071', '栃木県', 'トチギケン', '栃木市', 'トチギシ', '大町', 'ダイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県栃木市嘉右衛門町', '09', '09203', '3280072', '栃木県', 'トチギケン', '栃木市', 'トチギシ', '嘉右衛門町', 'カウエモンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県栃木市小平町', '09', '09203', '3280073', '栃木県', 'トチギケン', '栃木市', 'トチギシ', '小平町', 'コヒラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県栃木市薗部町', '09', '09203', '3280074', '栃木県', 'トチギケン', '栃木市', 'トチギシ', '薗部町', 'ソノベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県栃木市箱森町', '09', '09203', '3280075', '栃木県', 'トチギケン', '栃木市', 'トチギシ', '箱森町', 'ハコノモリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡都賀町', '09', '09368', '3280100', '栃木県', 'トチギケン', '下都賀郡都賀町', 'シモツガグンツガマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('25187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡都賀町大柿', '09', '09368', '3280101', '栃木県', 'トチギケン', '下都賀郡都賀町', 'シモツガグンツガマチ', '大柿', 'オオガキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡都賀町富張', '09', '09368', '3280102', '栃木県', 'トチギケン', '下都賀郡都賀町', 'シモツガグンツガマチ', '富張', 'トミハリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡都賀町原宿', '09', '09368', '3280103', '栃木県', 'トチギケン', '下都賀郡都賀町', 'シモツガグンツガマチ', '原宿', 'ハラジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡都賀町木', '09', '09368', '3280104', '栃木県', 'トチギケン', '下都賀郡都賀町', 'シモツガグンツガマチ', '木', 'キ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡都賀町臼久保', '09', '09368', '3280105', '栃木県', 'トチギケン', '下都賀郡都賀町', 'シモツガグンツガマチ', '臼久保', 'ウスクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡都賀町大橋', '09', '09368', '3280106', '栃木県', 'トチギケン', '下都賀郡都賀町', 'シモツガグンツガマチ', '大橋', 'オオハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡都賀町深沢', '09', '09368', '3280107', '栃木県', 'トチギケン', '下都賀郡都賀町', 'シモツガグンツガマチ', '深沢', 'フカサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡都賀町家中', '09', '09368', '3280111', '栃木県', 'トチギケン', '下都賀郡都賀町', 'シモツガグンツガマチ', '家中', 'イエナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡都賀町平川', '09', '09368', '3280112', '栃木県', 'トチギケン', '下都賀郡都賀町', 'シモツガグンツガマチ', '平川', 'ヒラカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡都賀町合戦場', '09', '09368', '3280113', '栃木県', 'トチギケン', '下都賀郡都賀町', 'シモツガグンツガマチ', '合戦場', 'カッセンバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡都賀町升塚', '09', '09368', '3280114', '栃木県', 'トチギケン', '下都賀郡都賀町', 'シモツガグンツガマチ', '升塚', 'マスヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県栃木市細堀町', '09', '09203', '3280121', '栃木県', 'トチギケン', '栃木市', 'トチギシ', '細堀町', 'ホソボリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県栃木市木野地町', '09', '09203', '3280122', '栃木県', 'トチギケン', '栃木市', 'トチギシ', '木野地町', 'キノジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県栃木市川原田町', '09', '09203', '3280123', '栃木県', 'トチギケン', '栃木市', 'トチギシ', '川原田町', 'カワラダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県栃木市野中町', '09', '09203', '3280124', '栃木県', 'トチギケン', '栃木市', 'トチギシ', '野中町', 'ノナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県栃木市吹上町', '09', '09203', '3280125', '栃木県', 'トチギケン', '栃木市', 'トチギシ', '吹上町', 'フキアゲマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県栃木市梓町', '09', '09203', '3280131', '栃木県', 'トチギケン', '栃木市', 'トチギシ', '梓町', 'アズサマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県栃木市仲方町', '09', '09203', '3280132', '栃木県', 'トチギケン', '栃木市', 'トチギシ', '仲方町', 'ナカガタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県栃木市大森町', '09', '09203', '3280133', '栃木県', 'トチギケン', '栃木市', 'トチギシ', '大森町', 'オオモリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県栃木市宮町', '09', '09203', '3280134', '栃木県', 'トチギケン', '栃木市', 'トチギシ', '宮町', 'ミヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県栃木市千塚町', '09', '09203', '3280135', '栃木県', 'トチギケン', '栃木市', 'トチギシ', '千塚町', 'チヅカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県栃木市星野町', '09', '09203', '3280201', '栃木県', 'トチギケン', '栃木市', 'トチギシ', '星野町', 'ホシノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県栃木市大久保町', '09', '09203', '3280202', '栃木県', 'トチギケン', '栃木市', 'トチギシ', '大久保町', 'オオクボマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県栃木市尻内町', '09', '09203', '3280203', '栃木県', 'トチギケン', '栃木市', 'トチギシ', '尻内町', 'シリウチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県栃木市梅沢町', '09', '09203', '3280204', '栃木県', 'トチギケン', '栃木市', 'トチギシ', '梅沢町', 'ウメザワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県栃木市鍋山町', '09', '09203', '3280205', '栃木県', 'トチギケン', '栃木市', 'トチギシ', '鍋山町', 'ナベヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県栃木市出流町', '09', '09203', '3280206', '栃木県', 'トチギケン', '栃木市', 'トチギシ', '出流町', 'イズルマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市上永野', '09', '09205', '3280211', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '上永野', 'カミナガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県鹿沼市下永野', '09', '09205', '3280212', '栃木県', 'トチギケン', '鹿沼市', 'カヌマシ', '下永野', 'シモナガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市仙波町坂東', '09', '09204', '3280221', '栃木県', 'トチギケン', '佐野市', 'サノシ', '仙波町', 'センバチョウ', null, null, '坂東', 'バンドウ');
INSERT INTO `ms_addresses` VALUES ('25218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県佐野市仙波町松ケ坂', '09', '09204', '3280221', '栃木県', 'トチギケン', '佐野市', 'サノシ', '仙波町', 'センバチョウ', null, null, '松ケ坂', 'マツガサカ');
INSERT INTO `ms_addresses` VALUES ('25235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡野木町', '09', '09364', '3290100', '栃木県', 'トチギケン', '下都賀郡野木町', 'シモツガグンノギマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('25236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡野木町友沼', '09', '09364', '3290101', '栃木県', 'トチギケン', '下都賀郡野木町', 'シモツガグンノギマチ', '友沼', 'トモヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡野木町潤島', '09', '09364', '3290102', '栃木県', 'トチギケン', '下都賀郡野木町', 'シモツガグンノギマチ', '潤島', 'ウルウジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡野木町若林', '09', '09364', '3290103', '栃木県', 'トチギケン', '下都賀郡野木町', 'シモツガグンノギマチ', '若林', 'ワカバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡野木町佐川野', '09', '09364', '3290104', '栃木県', 'トチギケン', '下都賀郡野木町', 'シモツガグンノギマチ', '佐川野', 'サガワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡野木町川田', '09', '09364', '3290105', '栃木県', 'トチギケン', '下都賀郡野木町', 'シモツガグンノギマチ', '川田', 'カワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡野木町丸林', '09', '09364', '3290111', '栃木県', 'トチギケン', '下都賀郡野木町', 'シモツガグンノギマチ', '丸林', 'マルバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡野木町南赤塚', '09', '09364', '3290112', '栃木県', 'トチギケン', '下都賀郡野木町', 'シモツガグンノギマチ', '南赤塚', 'ミナミアカツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡野木町中谷', '09', '09364', '3290113', '栃木県', 'トチギケン', '下都賀郡野木町', 'シモツガグンノギマチ', '中谷', 'ナカヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡野木町野木', '09', '09364', '3290114', '栃木県', 'トチギケン', '下都賀郡野木町', 'シモツガグンノギマチ', '野木', 'ノギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡野木町野渡', '09', '09364', '3290115', '栃木県', 'トチギケン', '下都賀郡野木町', 'シモツガグンノギマチ', '野渡', 'ノワタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市粟宮', '09', '09208', '3290201', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '粟宮', 'アワノミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市千駄塚', '09', '09208', '3290202', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '千駄塚', 'センダヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市西黒田', '09', '09208', '3290203', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '西黒田', 'ニシクロダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市東黒田', '09', '09208', '3290204', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '東黒田', 'ヒガシクロダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市間々田', '09', '09208', '3290205', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '間々田', 'ママダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市東間々田', '09', '09208', '3290206', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '東間々田', 'ヒガシママダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市美しが丘', '09', '09208', '3290207', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '美しが丘', 'ウツクシガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市暁', '09', '09208', '3290211', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '暁', 'アカツキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市平和', '09', '09208', '3290212', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '平和', 'ヒラワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市南飯田', '09', '09208', '3290213', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '南飯田', 'ミナミイイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市乙女', '09', '09208', '3290214', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '乙女', 'オトメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市網戸', '09', '09208', '3290215', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '網戸', 'アジト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市楢木', '09', '09208', '3290216', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '楢木', 'ナラノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市南乙女', '09', '09208', '3290217', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '南乙女', 'ミナミオトメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市生良', '09', '09208', '3290221', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '生良', 'キラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市上生井', '09', '09208', '3290222', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '上生井', 'カミナマイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市下生井', '09', '09208', '3290223', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '下生井', 'シモナマイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市白鳥', '09', '09208', '3290224', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '白鳥', 'シラトリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市迫間田', '09', '09208', '3290225', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '迫間田', 'ハサマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市寒川', '09', '09208', '3290226', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '寒川', 'サムカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市中里', '09', '09208', '3290227', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '中里', 'ナカザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市押切', '09', '09208', '3290228', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '押切', 'オシキリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県小山市鏡', '09', '09208', '3290229', '栃木県', 'トチギケン', '小山市', 'オヤマシ', '鏡', 'カガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡藤岡町富吉', '09', '09366', '3290311', '栃木県', 'トチギケン', '下都賀郡藤岡町', 'シモツガグンフジオカマチ', '富吉', 'トミヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡藤岡町蛭沼', '09', '09366', '3290312', '栃木県', 'トチギケン', '下都賀郡藤岡町', 'シモツガグンフジオカマチ', '蛭沼', 'ヒルヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡藤岡町緑川', '09', '09366', '3290313', '栃木県', 'トチギケン', '下都賀郡藤岡町', 'シモツガグンフジオカマチ', '緑川', 'ミドリカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡藤岡町新波', '09', '09366', '3290314', '栃木県', 'トチギケン', '下都賀郡藤岡町', 'シモツガグンフジオカマチ', '新波', 'ニッパ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡藤岡町部屋', '09', '09366', '3290315', '栃木県', 'トチギケン', '下都賀郡藤岡町', 'シモツガグンフジオカマチ', '部屋', 'ヘヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡藤岡町石川', '09', '09366', '3290316', '栃木県', 'トチギケン', '下都賀郡藤岡町', 'シモツガグンフジオカマチ', '石川', 'イシカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡藤岡町帯刀', '09', '09366', '3290317', '栃木県', 'トチギケン', '下都賀郡藤岡町', 'シモツガグンフジオカマチ', '帯刀', 'タテワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡藤岡町西前原', '09', '09366', '3290318', '栃木県', 'トチギケン', '下都賀郡藤岡町', 'シモツガグンフジオカマチ', '西前原', 'ニシマエバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡藤岡町中根', '09', '09366', '3290319', '栃木県', 'トチギケン', '下都賀郡藤岡町', 'シモツガグンフジオカマチ', '中根', 'ナカネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下野市', '09', '09216', '3290400', '栃木県', 'トチギケン', '下野市', 'シモツケシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('25280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下野市箕輪', '09', '09216', '3290401', '栃木県', 'トチギケン', '下野市', 'シモツケシ', '箕輪', 'ミノワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下野市笹原', '09', '09216', '3290402', '栃木県', 'トチギケン', '下野市', 'シモツケシ', '笹原', 'ササハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下野市医大前', '09', '09216', '3290403', '栃木県', 'トチギケン', '下野市', 'シモツケシ', '医大前', 'イダイマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下野市烏ケ森', '09', '09216', '3290411', '栃木県', 'トチギケン', '下野市', 'シモツケシ', '烏ケ森', 'カラスガモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下野市柴', '09', '09216', '3290412', '栃木県', 'トチギケン', '下野市', 'シモツケシ', '柴', 'シバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下野市駅東', '09', '09216', '3290413', '栃木県', 'トチギケン', '下野市', 'シモツケシ', '駅東', 'エキヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下野市小金井', '09', '09216', '3290414', '栃木県', 'トチギケン', '下野市', 'シモツケシ', '小金井', 'コガネイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下野市川中子', '09', '09216', '3290415', '栃木県', 'トチギケン', '下野市', 'シモツケシ', '川中子', 'カワナゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下野市国分寺', '09', '09216', '3290417', '栃木県', 'トチギケン', '下野市', 'シモツケシ', '国分寺', 'コクブンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下野市紫', '09', '09216', '3290418', '栃木県', 'トチギケン', '下野市', 'シモツケシ', '紫', 'ムラサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下野市成田', '09', '09216', '3290421', '栃木県', 'トチギケン', '下野市', 'シモツケシ', '成田', 'ナリタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下野市町田', '09', '09216', '3290422', '栃木県', 'トチギケン', '下野市', 'シモツケシ', '町田', 'マチダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下野市谷地賀', '09', '09216', '3290423', '栃木県', 'トチギケン', '下野市', 'シモツケシ', '谷地賀', 'ヤジツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下野市下文狹', '09', '09216', '3290424', '栃木県', 'トチギケン', '下野市', 'シモツケシ', '下文狹', 'シモフバサミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下野市田中', '09', '09216', '3290425', '栃木県', 'トチギケン', '下野市', 'シモツケシ', '田中', 'タナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下野市薬師寺', '09', '09216', '3290431', '栃木県', 'トチギケン', '下野市', 'シモツケシ', '薬師寺', 'ヤクシジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下野市仁良川', '09', '09216', '3290432', '栃木県', 'トチギケン', '下野市', 'シモツケシ', '仁良川', 'ニラガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下野市緑', '09', '09216', '3290433', '栃木県', 'トチギケン', '下野市', 'シモツケシ', '緑', 'ミドリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下野市祇園', '09', '09216', '3290434', '栃木県', 'トチギケン', '下野市', 'シモツケシ', '祇園', 'ギオン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下野市上古山', '09', '09216', '3290501', '栃木県', 'トチギケン', '下野市', 'シモツケシ', '上古山', 'カミコヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下野市下古山', '09', '09216', '3290502', '栃木県', 'トチギケン', '下野市', 'シモツケシ', '下古山', 'シモコヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下野市下長田', '09', '09216', '3290503', '栃木県', 'トチギケン', '下野市', 'シモツケシ', '下長田', 'シモナガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下野市上台', '09', '09216', '3290504', '栃木県', 'トチギケン', '下野市', 'シモツケシ', '上台', 'カミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下野市細谷', '09', '09216', '3290505', '栃木県', 'トチギケン', '下野市', 'シモツケシ', '細谷', 'ホソヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下野市橋本', '09', '09216', '3290506', '栃木県', 'トチギケン', '下野市', 'シモツケシ', '橋本', 'ハシモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下野市文教', '09', '09216', '3290507', '栃木県', 'トチギケン', '下野市', 'シモツケシ', '文教', 'ブンキョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下野市石橋', '09', '09216', '3290511', '栃木県', 'トチギケン', '下野市', 'シモツケシ', '石橋', 'イシバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下野市下石橋', '09', '09216', '3290512', '栃木県', 'トチギケン', '下野市', 'シモツケシ', '下石橋', 'シモイシバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下野市下大領', '09', '09216', '3290513', '栃木県', 'トチギケン', '下野市', 'シモツケシ', '下大領', 'シモダイリョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下野市東前原', '09', '09216', '3290514', '栃木県', 'トチギケン', '下野市', 'シモツケシ', '東前原', 'ヒガシマエハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下野市中大領', '09', '09216', '3290515', '栃木県', 'トチギケン', '下野市', 'シモツケシ', '中大領', 'ナカダイリョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下野市大光寺', '09', '09216', '3290516', '栃木県', 'トチギケン', '下野市', 'シモツケシ', '大光寺', 'ダイコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下野市上大領', '09', '09216', '3290517', '栃木県', 'トチギケン', '下野市', 'シモツケシ', '上大領', 'カミダイリョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下野市花の木', '09', '09216', '3290518', '栃木県', 'トチギケン', '下野市', 'シモツケシ', '花の木', 'ハナノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下野市大松山', '09', '09216', '3290519', '栃木県', 'トチギケン', '下野市', 'シモツケシ', '大松山', 'オオマツヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県河内郡上三川町石田', '09', '09301', '3290521', '栃木県', 'トチギケン', '河内郡上三川町', 'カワチグンカミノカワマチ', '石田', 'イシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県河内郡上三川町川中子', '09', '09301', '3290522', '栃木県', 'トチギケン', '河内郡上三川町', 'カワチグンカミノカワマチ', '川中子', 'カワナゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県河内郡上三川町梁', '09', '09301', '3290523', '栃木県', 'トチギケン', '河内郡上三川町', 'カワチグンカミノカワマチ', '梁', 'ヤナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県河内郡上三川町多功', '09', '09301', '3290524', '栃木県', 'トチギケン', '河内郡上三川町', 'カワチグンカミノカワマチ', '多功', 'タコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県河内郡上三川町大山', '09', '09301', '3290525', '栃木県', 'トチギケン', '河内郡上三川町', 'カワチグンカミノカワマチ', '大山', 'オオヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県河内郡上三川町鞘堂', '09', '09301', '3290526', '栃木県', 'トチギケン', '河内郡上三川町', 'カワチグンカミノカワマチ', '鞘堂', 'サヤドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県河内郡上三川町上神主', '09', '09301', '3290527', '栃木県', 'トチギケン', '河内郡上三川町', 'カワチグンカミノカワマチ', '上神主', 'カミコウヌシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県河内郡上三川町ゆうきが丘', '09', '09301', '3290528', '栃木県', 'トチギケン', '河内郡上三川町', 'カワチグンカミノカワマチ', 'ゆうきが丘', 'ユウキガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県河内郡上三川町下神主', '09', '09301', '3290529', '栃木県', 'トチギケン', '河内郡上三川町', 'カワチグンカミノカワマチ', '下神主', 'シモコウヌシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県河内郡上三川町天神町', '09', '09301', '3290530', '栃木県', 'トチギケン', '河内郡上三川町', 'カワチグンカミノカワマチ', '天神町', 'テンジンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県河内郡上三川町', '09', '09301', '3290600', '栃木県', 'トチギケン', '河内郡上三川町', 'カワチグンカミノカワマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('25331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県河内郡上三川町上文挾', '09', '09301', '3290601', '栃木県', 'トチギケン', '河内郡上三川町', 'カワチグンカミノカワマチ', '上文挾', 'カミフバサミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県河内郡上三川町東汗', '09', '09301', '3290602', '栃木県', 'トチギケン', '河内郡上三川町', 'カワチグンカミノカワマチ', '東汗', 'ヒガシフザカシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県河内郡上三川町東蓼沼', '09', '09301', '3290603', '栃木県', 'トチギケン', '河内郡上三川町', 'カワチグンカミノカワマチ', '東蓼沼', 'ヒガシタテヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県河内郡上三川町上郷', '09', '09301', '3290604', '栃木県', 'トチギケン', '河内郡上三川町', 'カワチグンカミノカワマチ', '上郷', 'カミゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県河内郡上三川町西蓼沼', '09', '09301', '3290605', '栃木県', 'トチギケン', '河内郡上三川町', 'カワチグンカミノカワマチ', '西蓼沼', 'ニシタテヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県河内郡上三川町磯岡', '09', '09301', '3290606', '栃木県', 'トチギケン', '河内郡上三川町', 'カワチグンカミノカワマチ', '磯岡', 'イソオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県河内郡上三川町西汗', '09', '09301', '3290607', '栃木県', 'トチギケン', '河内郡上三川町', 'カワチグンカミノカワマチ', '西汗', 'ニシフザカシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県河内郡上三川町西木代', '09', '09301', '3290608', '栃木県', 'トチギケン', '河内郡上三川町', 'カワチグンカミノカワマチ', '西木代', 'ニシキノシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県河内郡上三川町上三川', '09', '09301', '3290611', '栃木県', 'トチギケン', '河内郡上三川町', 'カワチグンカミノカワマチ', '上三川', 'カミノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県河内郡上三川町三本木', '09', '09301', '3290612', '栃木県', 'トチギケン', '河内郡上三川町', 'カワチグンカミノカワマチ', '三本木', 'サンボンギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県河内郡上三川町坂上', '09', '09301', '3290613', '栃木県', 'トチギケン', '河内郡上三川町', 'カワチグンカミノカワマチ', '坂上', 'サカウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県河内郡上三川町五分一', '09', '09301', '3290614', '栃木県', 'トチギケン', '河内郡上三川町', 'カワチグンカミノカワマチ', '五分一', 'ゴブイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県河内郡上三川町三村', '09', '09301', '3290615', '栃木県', 'トチギケン', '河内郡上三川町', 'カワチグンカミノカワマチ', '三村', 'ミムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県河内郡上三川町下蒲生', '09', '09301', '3290616', '栃木県', 'トチギケン', '河内郡上三川町', 'カワチグンカミノカワマチ', '下蒲生', 'シモカモウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県河内郡上三川町上蒲生', '09', '09301', '3290617', '栃木県', 'トチギケン', '河内郡上三川町', 'カワチグンカミノカワマチ', '上蒲生', 'カミカモウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県河内郡上三川町しらさぎ', '09', '09301', '3290618', '栃木県', 'トチギケン', '河内郡上三川町', 'カワチグンカミノカワマチ', 'しらさぎ', 'シラサギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市下ケ橋町', '09', '09201', '3291101', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '下ケ橋町', 'サゲハシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市白沢町', '09', '09201', '3291102', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '白沢町', 'シラサワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市東岡本町', '09', '09201', '3291103', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '東岡本町', 'ヒガシオカモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市下岡本町', '09', '09201', '3291104', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '下岡本町', 'シモオカモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市中岡本町', '09', '09201', '3291105', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '中岡本町', 'ナカオカモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市上大塚町', '09', '09201', '3291106', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '上大塚町', 'カミオオツカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市長峰町', '09', '09201', '3291107', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '長峰町', 'ナガミネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市古田町', '09', '09201', '3291108', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '古田町', 'フルタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市逆面町', '09', '09201', '3291111', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '逆面町', 'サカヅラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市上田原町', '09', '09201', '3291112', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '上田原町', 'カミタワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市相野沢町', '09', '09201', '3291113', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '相野沢町', 'アイノサワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市宝井町', '09', '09201', '3291114', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '宝井町', 'タカライチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市下田原町', '09', '09201', '3291115', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '下田原町', 'シモタワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市立伏町', '09', '09201', '3291116', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '立伏町', 'リュウブクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県宇都宮市叶谷町', '09', '09201', '3291117', '栃木県', 'トチギケン', '宇都宮市', 'ウツノミヤシ', '叶谷町', 'カノウヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県塩谷郡高根沢町', '09', '09386', '3291200', '栃木県', 'トチギケン', '塩谷郡高根沢町', 'シオヤグンタカネザワマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('25370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県塩谷郡高根沢町柿木沢', '09', '09386', '3291201', '栃木県', 'トチギケン', '塩谷郡高根沢町', 'シオヤグンタカネザワマチ', '柿木沢', 'カキノキザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県塩谷郡高根沢町狭間田', '09', '09386', '3291202', '栃木県', 'トチギケン', '塩谷郡高根沢町', 'シオヤグンタカネザワマチ', '狭間田', 'ハサマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県塩谷郡高根沢町伏久', '09', '09386', '3291203', '栃木県', 'トチギケン', '塩谷郡高根沢町', 'シオヤグンタカネザワマチ', '伏久', 'フスク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県塩谷郡高根沢町文挾', '09', '09386', '3291204', '栃木県', 'トチギケン', '塩谷郡高根沢町', 'シオヤグンタカネザワマチ', '文挾', 'フバサミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県塩谷郡高根沢町飯室', '09', '09386', '3291205', '栃木県', 'トチギケン', '塩谷郡高根沢町', 'シオヤグンタカネザワマチ', '飯室', 'イイムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県塩谷郡高根沢町平田', '09', '09386', '3291206', '栃木県', 'トチギケン', '塩谷郡高根沢町', 'シオヤグンタカネザワマチ', '平田', 'ヒラタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県塩谷郡高根沢町花岡', '09', '09386', '3291207', '栃木県', 'トチギケン', '塩谷郡高根沢町', 'シオヤグンタカネザワマチ', '花岡', 'ハナオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県塩谷郡高根沢町亀梨', '09', '09386', '3291211', '栃木県', 'トチギケン', '塩谷郡高根沢町', 'シオヤグンタカネザワマチ', '亀梨', 'カメナシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県塩谷郡高根沢町上柏崎', '09', '09386', '3291212', '栃木県', 'トチギケン', '塩谷郡高根沢町', 'シオヤグンタカネザワマチ', '上柏崎', 'カミカシワザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県塩谷郡高根沢町下柏崎', '09', '09386', '3291213', '栃木県', 'トチギケン', '塩谷郡高根沢町', 'シオヤグンタカネザワマチ', '下柏崎', 'シモカシワザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県塩谷郡高根沢町中柏崎', '09', '09386', '3291214', '栃木県', 'トチギケン', '塩谷郡高根沢町', 'シオヤグンタカネザワマチ', '中柏崎', 'ナカカシワザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県塩谷郡高根沢町給部', '09', '09386', '3291215', '栃木県', 'トチギケン', '塩谷郡高根沢町', 'シオヤグンタカネザワマチ', '給部', 'キュウブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県塩谷郡高根沢町桑窪', '09', '09386', '3291216', '栃木県', 'トチギケン', '塩谷郡高根沢町', 'シオヤグンタカネザワマチ', '桑窪', 'クワクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県塩谷郡高根沢町太田', '09', '09386', '3291217', '栃木県', 'トチギケン', '塩谷郡高根沢町', 'シオヤグンタカネザワマチ', '太田', 'オオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県塩谷郡高根沢町西高谷', '09', '09386', '3291221', '栃木県', 'トチギケン', '塩谷郡高根沢町', 'シオヤグンタカネザワマチ', '西高谷', 'ニシゴウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県塩谷郡高根沢町寺渡戸', '09', '09386', '3291222', '栃木県', 'トチギケン', '塩谷郡高根沢町', 'シオヤグンタカネザワマチ', '寺渡戸', 'テラワタド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県塩谷郡高根沢町栗ケ島', '09', '09386', '3291223', '栃木県', 'トチギケン', '塩谷郡高根沢町', 'シオヤグンタカネザワマチ', '栗ケ島', 'クリガシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県塩谷郡高根沢町上高根沢', '09', '09386', '3291224', '栃木県', 'トチギケン', '塩谷郡高根沢町', 'シオヤグンタカネザワマチ', '上高根沢', 'カミタカネザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県塩谷郡高根沢町石末', '09', '09386', '3291225', '栃木県', 'トチギケン', '塩谷郡高根沢町', 'シオヤグンタカネザワマチ', '石末', 'イシヅエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県塩谷郡高根沢町大谷', '09', '09386', '3291226', '栃木県', 'トチギケン', '塩谷郡高根沢町', 'シオヤグンタカネザワマチ', '大谷', 'オオヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県塩谷郡高根沢町宝石台', '09', '09386', '3291231', '栃木県', 'トチギケン', '塩谷郡高根沢町', 'シオヤグンタカネザワマチ', '宝石台', 'ホウセキダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県塩谷郡高根沢町光陽台', '09', '09386', '3291232', '栃木県', 'トチギケン', '塩谷郡高根沢町', 'シオヤグンタカネザワマチ', '光陽台', 'コウヨウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県塩谷郡高根沢町宝積寺', '09', '09386', '3291233', '栃木県', 'トチギケン', '塩谷郡高根沢町', 'シオヤグンタカネザワマチ', '宝積寺', 'ホウシャクジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県塩谷郡高根沢町中阿久津', '09', '09386', '3291234', '栃木県', 'トチギケン', '塩谷郡高根沢町', 'シオヤグンタカネザワマチ', '中阿久津', 'ナカアクツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県塩谷郡高根沢町上阿久津', '09', '09386', '3291235', '栃木県', 'トチギケン', '塩谷郡高根沢町', 'シオヤグンタカネザワマチ', '上阿久津', 'カミアクツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県さくら市', '09', '09214', '3291300', '栃木県', 'トチギケン', 'さくら市', 'サクラシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('25397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県さくら市箱森新田', '09', '09214', '3291301', '栃木県', 'トチギケン', 'さくら市', 'サクラシ', '箱森新田', 'ハコノモリシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県さくら市松山新田', '09', '09214', '3291302', '栃木県', 'トチギケン', 'さくら市', 'サクラシ', '松山新田', 'マツヤマシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県さくら市松山', '09', '09214', '3291303', '栃木県', 'トチギケン', 'さくら市', 'サクラシ', '松山', 'マツヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県さくら市鍛冶ケ沢', '09', '09214', '3291304', '栃木県', 'トチギケン', 'さくら市', 'サクラシ', '鍛冶ケ沢', 'カジガサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県さくら市狹間田', '09', '09214', '3291305', '栃木県', 'トチギケン', 'さくら市', 'サクラシ', '狹間田', 'ハサマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県さくら市上野', '09', '09214', '3291306', '栃木県', 'トチギケン', 'さくら市', 'サクラシ', '上野', 'ウワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県さくら市氏家', '09', '09214', '3291311', '栃木県', 'トチギケン', 'さくら市', 'サクラシ', '氏家', 'ウジイエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県さくら市櫻野', '09', '09214', '3291312', '栃木県', 'トチギケン', 'さくら市', 'サクラシ', '櫻野', 'サクラノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県さくら市柿木沢新田', '09', '09214', '3291313', '栃木県', 'トチギケン', 'さくら市', 'サクラシ', '柿木沢新田', 'カキノキザワシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県さくら市柿木沢', '09', '09214', '3291314', '栃木県', 'トチギケン', 'さくら市', 'サクラシ', '柿木沢', 'カキノキザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県さくら市氏家新田', '09', '09214', '3291315', '栃木県', 'トチギケン', 'さくら市', 'サクラシ', '氏家新田', 'ウジイエシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県さくら市上阿久津', '09', '09214', '3291316', '栃木県', 'トチギケン', 'さくら市', 'サクラシ', '上阿久津', 'カミアクツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県さくら市馬場', '09', '09214', '3291321', '栃木県', 'トチギケン', 'さくら市', 'サクラシ', '馬場', 'ババ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県さくら市北草川', '09', '09214', '3291322', '栃木県', 'トチギケン', 'さくら市', 'サクラシ', '北草川', 'キタクサガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県さくら市卯の里', '09', '09214', '3291323', '栃木県', 'トチギケン', 'さくら市', 'サクラシ', '卯の里', 'ウノサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県さくら市草川', '09', '09214', '3291324', '栃木県', 'トチギケン', 'さくら市', 'サクラシ', '草川', 'クサガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県さくら市大中', '09', '09214', '3291325', '栃木県', 'トチギケン', 'さくら市', 'サクラシ', '大中', 'オオナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県さくら市向河原', '09', '09214', '3291326', '栃木県', 'トチギケン', 'さくら市', 'サクラシ', '向河原', 'ムコウガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県さくら市富野岡', '09', '09214', '3291327', '栃木県', 'トチギケン', 'さくら市', 'サクラシ', '富野岡', 'トミノオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県さくら市松島', '09', '09214', '3291331', '栃木県', 'トチギケン', 'さくら市', 'サクラシ', '松島', 'マツシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県さくら市蒲須坂', '09', '09214', '3291332', '栃木県', 'トチギケン', 'さくら市', 'サクラシ', '蒲須坂', 'カマスサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県さくら市長久保', '09', '09214', '3291333', '栃木県', 'トチギケン', 'さくら市', 'サクラシ', '長久保', 'ナガクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県さくら市押上', '09', '09214', '3291334', '栃木県', 'トチギケン', 'さくら市', 'サクラシ', '押上', 'オシアゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県さくら市上河戸', '09', '09214', '3291401', '栃木県', 'トチギケン', 'さくら市', 'サクラシ', '上河戸', 'カミコウド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県さくら市下河戸', '09', '09214', '3291402', '栃木県', 'トチギケン', 'さくら市', 'サクラシ', '下河戸', 'シモコウド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県さくら市穂積', '09', '09214', '3291403', '栃木県', 'トチギケン', 'さくら市', 'サクラシ', '穂積', 'ホヅミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県さくら市鹿子畑', '09', '09214', '3291404', '栃木県', 'トチギケン', 'さくら市', 'サクラシ', '鹿子畑', 'カノコハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県さくら市金枝', '09', '09214', '3291405', '栃木県', 'トチギケン', 'さくら市', 'サクラシ', '金枝', 'カナエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県さくら市南和田', '09', '09214', '3291406', '栃木県', 'トチギケン', 'さくら市', 'サクラシ', '南和田', 'ミナミワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県さくら市鷲宿', '09', '09214', '3291411', '栃木県', 'トチギケン', 'さくら市', 'サクラシ', '鷲宿', 'ワシジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県さくら市喜連川', '09', '09214', '3291412', '栃木県', 'トチギケン', 'さくら市', 'サクラシ', '喜連川', 'キツレガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県さくら市葛城', '09', '09214', '3291413', '栃木県', 'トチギケン', 'さくら市', 'サクラシ', '葛城', 'カツラギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県さくら市早乙女', '09', '09214', '3291414', '栃木県', 'トチギケン', 'さくら市', 'サクラシ', '早乙女', 'ソウトメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県さくら市小入', '09', '09214', '3291415', '栃木県', 'トチギケン', 'さくら市', 'サクラシ', '小入', 'オイレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県さくら市桜ケ丘', '09', '09214', '3291416', '栃木県', 'トチギケン', 'さくら市', 'サクラシ', '桜ケ丘', 'サクラガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県さくら市フィオーレ喜連川', '09', '09214', '3291417', '栃木県', 'トチギケン', 'さくら市', 'サクラシ', 'フィオーレ喜連川', 'フィオーレキツレガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県矢板市片岡', '09', '09211', '3291571', '栃木県', 'トチギケン', '矢板市', 'ヤイタシ', '片岡', 'カタオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県矢板市安沢', '09', '09211', '3291572', '栃木県', 'トチギケン', '矢板市', 'ヤイタシ', '安沢', 'アンザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県矢板市越畑', '09', '09211', '3291573', '栃木県', 'トチギケン', '矢板市', 'ヤイタシ', '越畑', 'コエハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県矢板市乙畑', '09', '09211', '3291574', '栃木県', 'トチギケン', '矢板市', 'ヤイタシ', '乙畑', 'オツハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県矢板市大槻', '09', '09211', '3291575', '栃木県', 'トチギケン', '矢板市', 'ヤイタシ', '大槻', 'オオツキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県矢板市石関', '09', '09211', '3291576', '栃木県', 'トチギケン', '矢板市', 'ヤイタシ', '石関', 'イシゼキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県矢板市玉田', '09', '09211', '3291577', '栃木県', 'トチギケン', '矢板市', 'ヤイタシ', '玉田', 'タマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県矢板市山苗代', '09', '09211', '3291578', '栃木県', 'トチギケン', '矢板市', 'ヤイタシ', '山苗代', 'ヤマナワシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県矢板市こぶし台', '09', '09211', '3291579', '栃木県', 'トチギケン', '矢板市', 'ヤイタシ', 'こぶし台', 'コブシダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県矢板市', '09', '09211', '3292100', '栃木県', 'トチギケン', '矢板市', 'ヤイタシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('25448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県矢板市荒井', '09', '09211', '3292121', '栃木県', 'トチギケン', '矢板市', 'ヤイタシ', '荒井', 'アライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県矢板市針生', '09', '09211', '3292122', '栃木県', 'トチギケン', '矢板市', 'ヤイタシ', '針生', 'ハリウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県矢板市上町', '09', '09211', '3292123', '栃木県', 'トチギケン', '矢板市', 'ヤイタシ', '上町', 'カミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県矢板市下太田', '09', '09211', '3292124', '栃木県', 'トチギケン', '矢板市', 'ヤイタシ', '下太田', 'シモオオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県矢板市土屋', '09', '09211', '3292131', '栃木県', 'トチギケン', '矢板市', 'ヤイタシ', '土屋', 'ツチヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県矢板市沢', '09', '09211', '3292132', '栃木県', 'トチギケン', '矢板市', 'ヤイタシ', '沢', 'サワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県矢板市豊田', '09', '09211', '3292133', '栃木県', 'トチギケン', '矢板市', 'ヤイタシ', '豊田', 'トヨダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県矢板市成田', '09', '09211', '3292134', '栃木県', 'トチギケン', '矢板市', 'ヤイタシ', '成田', 'ナリタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県矢板市中', '09', '09211', '3292135', '栃木県', 'トチギケン', '矢板市', 'ヤイタシ', '中', 'ナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県矢板市東町', '09', '09211', '3292136', '栃木県', 'トチギケン', '矢板市', 'ヤイタシ', '東町', 'アズマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県矢板市早川町', '09', '09211', '3292141', '栃木県', 'トチギケン', '矢板市', 'ヤイタシ', '早川町', 'ハヤカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県矢板市木幡', '09', '09211', '3292142', '栃木県', 'トチギケン', '矢板市', 'ヤイタシ', '木幡', 'キバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県矢板市境林', '09', '09211', '3292143', '栃木県', 'トチギケン', '矢板市', 'ヤイタシ', '境林', 'サカイバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県矢板市川崎反町', '09', '09211', '3292144', '栃木県', 'トチギケン', '矢板市', 'ヤイタシ', '川崎反町', 'カワサキソリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県矢板市富田', '09', '09211', '3292145', '栃木県', 'トチギケン', '矢板市', 'ヤイタシ', '富田', 'トミタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県矢板市幸岡', '09', '09211', '3292151', '栃木県', 'トチギケン', '矢板市', 'ヤイタシ', '幸岡', 'コウオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県矢板市館ノ川', '09', '09211', '3292152', '栃木県', 'トチギケン', '矢板市', 'ヤイタシ', '館ノ川', 'タテノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県矢板市高塩', '09', '09211', '3292153', '栃木県', 'トチギケン', '矢板市', 'ヤイタシ', '高塩', 'タカシオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県矢板市倉掛', '09', '09211', '3292154', '栃木県', 'トチギケン', '矢板市', 'ヤイタシ', '倉掛', 'クラカケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県矢板市片俣', '09', '09211', '3292155', '栃木県', 'トチギケン', '矢板市', 'ヤイタシ', '片俣', 'カタマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県矢板市塩田', '09', '09211', '3292156', '栃木県', 'トチギケン', '矢板市', 'ヤイタシ', '塩田', 'シオダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県矢板市扇町', '09', '09211', '3292161', '栃木県', 'トチギケン', '矢板市', 'ヤイタシ', '扇町', 'オウギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県矢板市末広町', '09', '09211', '3292162', '栃木県', 'トチギケン', '矢板市', 'ヤイタシ', '末広町', 'スエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県矢板市鹿島町', '09', '09211', '3292163', '栃木県', 'トチギケン', '矢板市', 'ヤイタシ', '鹿島町', 'カシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県矢板市本町', '09', '09211', '3292164', '栃木県', 'トチギケン', '矢板市', 'ヤイタシ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県矢板市矢板', '09', '09211', '3292165', '栃木県', 'トチギケン', '矢板市', 'ヤイタシ', '矢板', 'ヤイタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県塩谷郡塩谷町', '09', '09384', '3292200', '栃木県', 'トチギケン', '塩谷郡塩谷町', 'シオヤグンシオヤマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('25477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県塩谷郡塩谷町鳥羽新田', '09', '09384', '3292211', '栃木県', 'トチギケン', '塩谷郡塩谷町', 'シオヤグンシオヤマチ', '鳥羽新田', 'トバシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県塩谷郡塩谷町喜佐見', '09', '09384', '3292212', '栃木県', 'トチギケン', '塩谷郡塩谷町', 'シオヤグンシオヤマチ', '喜佐見', 'キザミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県塩谷郡塩谷町熊ノ木', '09', '09384', '3292213', '栃木県', 'トチギケン', '塩谷郡塩谷町', 'シオヤグンシオヤマチ', '熊ノ木', 'クマノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県塩谷郡塩谷町東房', '09', '09384', '3292214', '栃木県', 'トチギケン', '塩谷郡塩谷町', 'シオヤグンシオヤマチ', '東房', 'ヒガシボウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県塩谷郡塩谷町下寺島', '09', '09384', '3292215', '栃木県', 'トチギケン', '塩谷郡塩谷町', 'シオヤグンシオヤマチ', '下寺島', 'シモテラシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県塩谷郡塩谷町上寺島', '09', '09384', '3292216', '栃木県', 'トチギケン', '塩谷郡塩谷町', 'シオヤグンシオヤマチ', '上寺島', 'カミテラシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県塩谷郡塩谷町玉生', '09', '09384', '3292221', '栃木県', 'トチギケン', '塩谷郡塩谷町', 'シオヤグンシオヤマチ', '玉生', 'タマニュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県塩谷郡塩谷町道下', '09', '09384', '3292222', '栃木県', 'トチギケン', '塩谷郡塩谷町', 'シオヤグンシオヤマチ', '道下', 'ドウシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県塩谷郡塩谷町原荻野目', '09', '09384', '3292223', '栃木県', 'トチギケン', '塩谷郡塩谷町', 'シオヤグンシオヤマチ', '原荻野目', 'ハラオギノメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県塩谷郡塩谷町金枝', '09', '09384', '3292224', '栃木県', 'トチギケン', '塩谷郡塩谷町', 'シオヤグンシオヤマチ', '金枝', 'カナエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県塩谷郡塩谷町飯岡', '09', '09384', '3292225', '栃木県', 'トチギケン', '塩谷郡塩谷町', 'シオヤグンシオヤマチ', '飯岡', 'イイオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県塩谷郡塩谷町芦場新田', '09', '09384', '3292226', '栃木県', 'トチギケン', '塩谷郡塩谷町', 'シオヤグンシオヤマチ', '芦場新田', 'ヨシバシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県塩谷郡塩谷町田所', '09', '09384', '3292331', '栃木県', 'トチギケン', '塩谷郡塩谷町', 'シオヤグンシオヤマチ', '田所', 'タドコロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県塩谷郡塩谷町大宮', '09', '09384', '3292332', '栃木県', 'トチギケン', '塩谷郡塩谷町', 'シオヤグンシオヤマチ', '大宮', 'オオミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県塩谷郡塩谷町肘内', '09', '09384', '3292333', '栃木県', 'トチギケン', '塩谷郡塩谷町', 'シオヤグンシオヤマチ', '肘内', 'ヒジウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県塩谷郡塩谷町大久保', '09', '09384', '3292334', '栃木県', 'トチギケン', '塩谷郡塩谷町', 'シオヤグンシオヤマチ', '大久保', 'オオクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県塩谷郡塩谷町上平', '09', '09384', '3292335', '栃木県', 'トチギケン', '塩谷郡塩谷町', 'シオヤグンシオヤマチ', '上平', 'ウワタイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県塩谷郡塩谷町風見', '09', '09384', '3292336', '栃木県', 'トチギケン', '塩谷郡塩谷町', 'シオヤグンシオヤマチ', '風見', 'カザミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県塩谷郡塩谷町泉', '09', '09384', '3292337', '栃木県', 'トチギケン', '塩谷郡塩谷町', 'シオヤグンシオヤマチ', '泉', 'イズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県塩谷郡塩谷町風見山田', '09', '09384', '3292338', '栃木県', 'トチギケン', '塩谷郡塩谷町', 'シオヤグンシオヤマチ', '風見山田', 'カザミヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県塩谷郡塩谷町上沢', '09', '09384', '3292339', '栃木県', 'トチギケン', '塩谷郡塩谷町', 'シオヤグンシオヤマチ', '上沢', 'ウワサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県塩谷郡塩谷町船生', '09', '09384', '3292441', '栃木県', 'トチギケン', '塩谷郡塩谷町', 'シオヤグンシオヤマチ', '船生', 'フニュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県塩谷郡塩谷町佐貫', '09', '09384', '3292442', '栃木県', 'トチギケン', '塩谷郡塩谷町', 'シオヤグンシオヤマチ', '佐貫', 'サヌキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県矢板市上伊佐野', '09', '09211', '3292501', '栃木県', 'トチギケン', '矢板市', 'ヤイタシ', '上伊佐野', 'カミイサノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県矢板市下伊佐野', '09', '09211', '3292502', '栃木県', 'トチギケン', '矢板市', 'ヤイタシ', '下伊佐野', 'シモイサノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県矢板市田野原', '09', '09211', '3292503', '栃木県', 'トチギケン', '矢板市', 'ヤイタシ', '田野原', 'タノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県矢板市泉', '09', '09211', '3292504', '栃木県', 'トチギケン', '矢板市', 'ヤイタシ', '泉', 'イズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県矢板市立足', '09', '09211', '3292505', '栃木県', 'トチギケン', '矢板市', 'ヤイタシ', '立足', 'タツアシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県矢板市平野', '09', '09211', '3292506', '栃木県', 'トチギケン', '矢板市', 'ヤイタシ', '平野', 'ヒラノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県矢板市山田', '09', '09211', '3292511', '栃木県', 'トチギケン', '矢板市', 'ヤイタシ', '山田', 'ヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県矢板市東泉', '09', '09211', '3292512', '栃木県', 'トチギケン', '矢板市', 'ヤイタシ', '東泉', 'ヒガシイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県矢板市上太田', '09', '09211', '3292513', '栃木県', 'トチギケン', '矢板市', 'ヤイタシ', '上太田', 'カミオオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県矢板市長井', '09', '09211', '3292514', '栃木県', 'トチギケン', '矢板市', 'ヤイタシ', '長井', 'ナガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市関根', '09', '09213', '3292701', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '関根', 'セキネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市東関根', '09', '09213', '3292702', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '東関根', 'ヒガシセキネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市槻沢', '09', '09213', '3292703', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '槻沢', 'ツキヌキザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市新南', '09', '09213', '3292704', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '新南', 'シンナン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市南郷屋', '09', '09213', '3292705', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '南郷屋', 'ミナミゴウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市睦', '09', '09213', '3292706', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '睦', 'ムツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市高柳', '09', '09213', '3292707', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '高柳', 'タカヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市石林', '09', '09213', '3292711', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '石林', 'イシバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市下永田', '09', '09213', '3292712', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '下永田', 'シモナガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市緑', '09', '09213', '3292713', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '緑', 'ミドリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市東町', '09', '09213', '3292721', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '東町', 'アズマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市西朝日町', '09', '09213', '3292722', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '西朝日町', 'ニシアサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市南町', '09', '09213', '3292723', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '南町', 'ミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市西幸町', '09', '09213', '3292724', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '西幸町', 'ニシサイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市あたご町', '09', '09213', '3292725', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', 'あたご町', 'アタゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市扇町', '09', '09213', '3292726', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '扇町', 'オウギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市永田町', '09', '09213', '3292727', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '永田町', 'ナガタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市西栄町', '09', '09213', '3292728', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '西栄町', 'ニシサカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市二つ室', '09', '09213', '3292731', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '二つ室', 'フタツムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市一区町', '09', '09213', '3292732', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '一区町', 'イックチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市二区町', '09', '09213', '3292733', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '二区町', 'ニクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市北二つ室', '09', '09213', '3292734', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '北二つ室', 'キタフタツムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市太夫塚', '09', '09213', '3292735', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '太夫塚', 'タユウヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市北赤田', '09', '09213', '3292741', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '北赤田', 'キタアカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市東赤田', '09', '09213', '3292742', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '東赤田', 'ヒガシアカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市南赤田', '09', '09213', '3292743', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '南赤田', 'ミナミアカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市西赤田', '09', '09213', '3292744', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '西赤田', 'ニシアカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市三区町', '09', '09213', '3292745', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '三区町', 'サンクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市四区町', '09', '09213', '3292746', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '四区町', 'ヨンクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市千本松', '09', '09213', '3292747', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '千本松', 'センボンマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市上赤田', '09', '09213', '3292748', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '上赤田', 'カミアカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市東三島', '09', '09213', '3292751', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '東三島', 'ヒガシミシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市三島', '09', '09213', '3292752', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '三島', 'ミシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市五軒町', '09', '09213', '3292753', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '五軒町', 'ゴケンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市西大和', '09', '09213', '3292754', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '西大和', 'ニシヤマト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市西原町', '09', '09213', '3292755', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '西原町', 'ニシハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市西三島', '09', '09213', '3292756', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '西三島', 'ニシミシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市東遅沢', '09', '09213', '3292761', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '東遅沢', 'ヒガシオソザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市西富山', '09', '09213', '3292762', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '西富山', 'ニシトミヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市井口', '09', '09213', '3292763', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '井口', 'イグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市西遅沢', '09', '09213', '3292764', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '西遅沢', 'ニシオソザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市関谷', '09', '09213', '3292801', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '関谷', 'セキヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市蟇沼', '09', '09213', '3292802', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '蟇沼', 'ヒキヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市遅野沢', '09', '09213', '3292803', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '遅野沢', 'オソノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市折戸', '09', '09213', '3292804', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '折戸', 'オリド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市上横林', '09', '09213', '3292805', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '上横林', 'カミヨコバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市横林', '09', '09213', '3292806', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '横林', 'ヨコバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市接骨木', '09', '09213', '3292807', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '接骨木', 'ニワトコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市下田野', '09', '09213', '3292811', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '下田野', 'シモタノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市金沢', '09', '09213', '3292812', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '金沢', 'カネザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市高阿津', '09', '09213', '3292813', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '高阿津', 'タカアツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市上大貫', '09', '09213', '3292814', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '上大貫', 'カミオオヌキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市下大貫', '09', '09213', '3292815', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '下大貫', 'シモオオヌキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市宇都野', '09', '09213', '3292816', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '宇都野', 'ウツノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市塩原', '09', '09213', '3292921', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '塩原', 'シオバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市湯本塩原', '09', '09213', '3292922', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '湯本塩原', 'ユモトシオバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市上塩原', '09', '09213', '3292923', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '上塩原', 'カミシオバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市中塩原', '09', '09213', '3292924', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '中塩原', 'ナカシオバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市鹿野崎', '09', '09213', '3293121', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '鹿野崎', 'カノサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市塩野崎', '09', '09213', '3293122', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '塩野崎', 'シオノサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市塩野崎新田', '09', '09213', '3293123', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '塩野崎新田', 'シオノサキシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市波立', '09', '09213', '3293124', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '波立', 'ハッタチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市無栗屋', '09', '09213', '3293125', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '無栗屋', 'ムクリヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市中内', '09', '09213', '3293126', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '中内', 'ナカウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市上郷屋', '09', '09213', '3293127', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '上郷屋', 'カミゴウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市唐杉', '09', '09213', '3293131', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '唐杉', 'カラスギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市北弥六', '09', '09213', '3293132', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '北弥六', 'キタヤロク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市沓掛', '09', '09213', '3293133', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '沓掛', 'クツカケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市上大塚新田', '09', '09213', '3293134', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '上大塚新田', 'カミオオツカシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市前弥六', '09', '09213', '3293135', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '前弥六', 'マエヤロク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市前弥六南町', '09', '09213', '3293136', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '前弥六南町', 'マエヤロクミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市山中新田', '09', '09213', '3293141', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '山中新田', 'ヤマナカシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市佐野', '09', '09213', '3293142', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '佐野', 'サノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市三本木', '09', '09213', '3293143', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '三本木', 'サンボンギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市沼野田和', '09', '09213', '3293144', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '沼野田和', 'ヌマノタワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市木曾畑中', '09', '09213', '3293145', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '木曾畑中', 'キソハタナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市下中野', '09', '09213', '3293146', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '下中野', 'シモナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市東小屋', '09', '09213', '3293147', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '東小屋', 'ヒガシコヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市北和田', '09', '09213', '3293151', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '北和田', 'キタワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市島方', '09', '09213', '3293152', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '島方', 'シマカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市大原間', '09', '09213', '3293153', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '大原間', 'オオハラマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市上中野', '09', '09213', '3293154', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '上中野', 'カミナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市笹沼', '09', '09213', '3293155', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '笹沼', 'ササヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市方京', '09', '09213', '3293156', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '方京', 'ホウキョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須塩原市大原間西', '09', '09213', '3293157', '栃木県', 'トチギケン', '那須塩原市', 'ナスシオバラシ', '大原間西', 'オオハラマニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須郡那須町', '09', '09407', '3293200', '栃木県', 'トチギケン', '那須郡那須町', 'ナスグンナスマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('25602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須郡那須町豊原甲', '09', '09407', '3293211', '栃木県', 'トチギケン', '那須郡那須町', 'ナスグンナスマチ', '豊原甲', 'トヨハラコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須郡那須町富岡', '09', '09407', '3293212', '栃木県', 'トチギケン', '那須郡那須町', 'ナスグンナスマチ', '富岡', 'トミオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須郡那須町豊原', '09', '09407', '3293213', '栃木県', 'トチギケン', '那須郡那須町', 'ナスグンナスマチ', '豊原', 'トヨハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須郡那須町横岡', '09', '09407', '3293214', '栃木県', 'トチギケン', '那須郡那須町', 'ナスグンナスマチ', '横岡', 'ヨコオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須郡那須町寺子乙', '09', '09407', '3293215', '栃木県', 'トチギケン', '那須郡那須町', 'ナスグンナスマチ', '寺子乙', 'テラコオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須郡那須町漆塚', '09', '09407', '3293221', '栃木県', 'トチギケン', '那須郡那須町', 'ナスグンナスマチ', '漆塚', 'ウルシツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須郡那須町寺子丙', '09', '09407', '3293222', '栃木県', 'トチギケン', '那須郡那須町', 'ナスグンナスマチ', '寺子丙', 'テラコヘイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須郡那須町大島', '09', '09407', '3293223', '栃木県', 'トチギケン', '那須郡那須町', 'ナスグンナスマチ', '大島', 'オオシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須郡那須町豊原乙', '09', '09407', '3293224', '栃木県', 'トチギケン', '那須郡那須町', 'ナスグンナスマチ', '豊原乙', 'トヨハラオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須郡那須町豊原丙', '09', '09407', '3293225', '栃木県', 'トチギケン', '那須郡那須町', 'ナスグンナスマチ', '豊原丙', 'トヨハラヘイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須郡那須町大畑', '09', '09407', '3293431', '栃木県', 'トチギケン', '那須郡那須町', 'ナスグンナスマチ', '大畑', 'オオハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須郡那須町梓', '09', '09407', '3293432', '栃木県', 'トチギケン', '那須郡那須町', 'ナスグンナスマチ', '梓', 'アズサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須郡那須町大和須', '09', '09407', '3293433', '栃木県', 'トチギケン', '那須郡那須町', 'ナスグンナスマチ', '大和須', 'オオワス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須郡那須町梁瀬', '09', '09407', '3293434', '栃木県', 'トチギケン', '那須郡那須町', 'ナスグンナスマチ', '梁瀬', 'ヤナゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須郡那須町睦家', '09', '09407', '3293435', '栃木県', 'トチギケン', '那須郡那須町', 'ナスグンナスマチ', '睦家', 'ムツヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須郡那須町伊王野', '09', '09407', '3293436', '栃木県', 'トチギケン', '那須郡那須町', 'ナスグンナスマチ', '伊王野', 'イオウノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須郡那須町蓑沢', '09', '09407', '3293437', '栃木県', 'トチギケン', '那須郡那須町', 'ナスグンナスマチ', '蓑沢', 'ミノザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須郡那須町寄居', '09', '09407', '3293441', '栃木県', 'トチギケン', '那須郡那須町', 'ナスグンナスマチ', '寄居', 'ヨリイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須郡那須町横岡', '09', '09407', '3293442', '栃木県', 'トチギケン', '那須郡那須町', 'ナスグンナスマチ', '横岡', 'ヨコオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須郡那須町芦野', '09', '09407', '3293443', '栃木県', 'トチギケン', '那須郡那須町', 'ナスグンナスマチ', '芦野', 'アシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須郡那須町寺子', '09', '09407', '3293444', '栃木県', 'トチギケン', '那須郡那須町', 'ナスグンナスマチ', '寺子', 'テラコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須郡那須町東岩崎', '09', '09407', '3293445', '栃木県', 'トチギケン', '那須郡那須町', 'ナスグンナスマチ', '東岩崎', 'ヒガシイワザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須郡那須町沼野井', '09', '09407', '3293446', '栃木県', 'トチギケン', '那須郡那須町', 'ナスグンナスマチ', '沼野井', 'ヌマノイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県那須郡那須町稲沢', '09', '09407', '3293447', '栃木県', 'トチギケン', '那須郡那須町', 'ナスグンナスマチ', '稲沢', 'イナザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市西場町', '09', '09202', '3294211', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '西場町', 'ニシバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市稲岡町', '09', '09202', '3294212', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '稲岡町', 'イナオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市寺岡町', '09', '09202', '3294213', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '寺岡町', 'テラオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市多田木町', '09', '09202', '3294214', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '多田木町', 'タダキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市奥戸町', '09', '09202', '3294215', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '奥戸町', 'オクドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市迫間町', '09', '09202', '3294216', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '迫間町', 'ハサマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県足利市駒場町', '09', '09202', '3294217', '栃木県', 'トチギケン', '足利市', 'アシカガシ', '駒場町', 'コマバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡岩舟町', '09', '09367', '3294300', '栃木県', 'トチギケン', '下都賀郡岩舟町', 'シモツガグンイワフネマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('25635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡岩舟町鷲巣', '09', '09367', '3294301', '栃木県', 'トチギケン', '下都賀郡岩舟町', 'シモツガグンイワフネマチ', '鷲巣', 'ワシノス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡岩舟町五十畑', '09', '09367', '3294302', '栃木県', 'トチギケン', '下都賀郡岩舟町', 'シモツガグンイワフネマチ', '五十畑', 'イカバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡岩舟町和泉', '09', '09367', '3294303', '栃木県', 'トチギケン', '下都賀郡岩舟町', 'シモツガグンイワフネマチ', '和泉', 'イズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡岩舟町静和', '09', '09367', '3294304', '栃木県', 'トチギケン', '下都賀郡岩舟町', 'シモツガグンイワフネマチ', '静和', 'シズワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡岩舟町静戸', '09', '09367', '3294305', '栃木県', 'トチギケン', '下都賀郡岩舟町', 'シモツガグンイワフネマチ', '静戸', 'シズコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡岩舟町曲ケ島', '09', '09367', '3294306', '栃木県', 'トチギケン', '下都賀郡岩舟町', 'シモツガグンイワフネマチ', '曲ケ島', 'マガノシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡岩舟町静', '09', '09367', '3294307', '栃木県', 'トチギケン', '下都賀郡岩舟町', 'シモツガグンイワフネマチ', '静', 'シズカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡岩舟町下津原', '09', '09367', '3294308', '栃木県', 'トチギケン', '下都賀郡岩舟町', 'シモツガグンイワフネマチ', '下津原', 'シモツバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡岩舟町畳岡', '09', '09367', '3294309', '栃木県', 'トチギケン', '下都賀郡岩舟町', 'シモツガグンイワフネマチ', '畳岡', 'タタミオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡岩舟町古江', '09', '09367', '3294311', '栃木県', 'トチギケン', '下都賀郡岩舟町', 'シモツガグンイワフネマチ', '古江', 'フルエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡岩舟町下岡', '09', '09367', '3294312', '栃木県', 'トチギケン', '下都賀郡岩舟町', 'シモツガグンイワフネマチ', '下岡', 'シモオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡岩舟町上岡', '09', '09367', '3294313', '栃木県', 'トチギケン', '下都賀郡岩舟町', 'シモツガグンイワフネマチ', '上岡', 'カミオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡岩舟町小野寺', '09', '09367', '3294314', '栃木県', 'トチギケン', '下都賀郡岩舟町', 'シモツガグンイワフネマチ', '小野寺', 'オノデラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡岩舟町三谷', '09', '09367', '3294315', '栃木県', 'トチギケン', '下都賀郡岩舟町', 'シモツガグンイワフネマチ', '三谷', 'ミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡岩舟町新里', '09', '09367', '3294316', '栃木県', 'トチギケン', '下都賀郡岩舟町', 'シモツガグンイワフネマチ', '新里', 'ニッサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡大平町', '09', '09365', '3294400', '栃木県', 'トチギケン', '下都賀郡大平町', 'シモツガグンオオヒラマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('25652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡大平町牛久', '09', '09365', '3294401', '栃木県', 'トチギケン', '下都賀郡大平町', 'シモツガグンオオヒラマチ', '牛久', 'ウシク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡大平町土与', '09', '09365', '3294402', '栃木県', 'トチギケン', '下都賀郡大平町', 'シモツガグンオオヒラマチ', '土与', 'ドヨ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡大平町蔵井', '09', '09365', '3294403', '栃木県', 'トチギケン', '下都賀郡大平町', 'シモツガグンオオヒラマチ', '蔵井', 'クライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡大平町富田', '09', '09365', '3294404', '栃木県', 'トチギケン', '下都賀郡大平町', 'シモツガグンオオヒラマチ', '富田', 'トミダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡大平町西山田', '09', '09365', '3294405', '栃木県', 'トチギケン', '下都賀郡大平町', 'シモツガグンオオヒラマチ', '西山田', 'ニシヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡大平町下皆川', '09', '09365', '3294406', '栃木県', 'トチギケン', '下都賀郡大平町', 'シモツガグンオオヒラマチ', '下皆川', 'シモミナガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡大平町川連', '09', '09365', '3294407', '栃木県', 'トチギケン', '下都賀郡大平町', 'シモツガグンオオヒラマチ', '川連', 'カワツレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡大平町横堀', '09', '09365', '3294411', '栃木県', 'トチギケン', '下都賀郡大平町', 'シモツガグンオオヒラマチ', '横堀', 'ヨコボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡大平町北武井', '09', '09365', '3294412', '栃木県', 'トチギケン', '下都賀郡大平町', 'シモツガグンオオヒラマチ', '北武井', 'キタタケイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡大平町上高島', '09', '09365', '3294413', '栃木県', 'トチギケン', '下都賀郡大平町', 'シモツガグンオオヒラマチ', '上高島', 'カミタカシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡大平町下高島', '09', '09365', '3294414', '栃木県', 'トチギケン', '下都賀郡大平町', 'シモツガグンオオヒラマチ', '下高島', 'シモタカシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡大平町真弓', '09', '09365', '3294415', '栃木県', 'トチギケン', '下都賀郡大平町', 'シモツガグンオオヒラマチ', '真弓', 'マユミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡大平町西野田', '09', '09365', '3294421', '栃木県', 'トチギケン', '下都賀郡大平町', 'シモツガグンオオヒラマチ', '西野田', 'ニシノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡大平町榎本', '09', '09365', '3294422', '栃木県', 'トチギケン', '下都賀郡大平町', 'シモツガグンオオヒラマチ', '榎本', 'エノモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡大平町西水代', '09', '09365', '3294423', '栃木県', 'トチギケン', '下都賀郡大平町', 'シモツガグンオオヒラマチ', '西水代', 'ニシミズシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡大平町伯仲', '09', '09365', '3294424', '栃木県', 'トチギケン', '下都賀郡大平町', 'シモツガグンオオヒラマチ', '伯仲', 'ハクチュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡大平町新', '09', '09365', '3294425', '栃木県', 'トチギケン', '下都賀郡大平町', 'シモツガグンオオヒラマチ', '新', 'アライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三沢市', '02', '02207', '0330000', '青森県', 'アオモリケン', '三沢市', 'ミサワシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('25672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市中央区', '11', '11105', '3300000', '埼玉県', 'サイタマケン', 'さいたま市中央区', 'サイタマシチュウオウク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('25673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市浦和区', '11', '11107', '3300000', '埼玉県', 'サイタマケン', 'さいたま市浦和区', 'サイタマシウラワク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('25674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三沢市中央町', '02', '02207', '0330001', '青森県', 'アオモリケン', '三沢市', 'ミサワシ', '中央町', 'チュウオウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市浦和区三崎', '11', '11107', '3300041', '埼玉県', 'サイタマケン', 'さいたま市浦和区', 'サイタマシウラワク', '三崎', 'ミサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市浦和区木崎', '11', '11107', '3300042', '埼玉県', 'サイタマケン', 'さいたま市浦和区', 'サイタマシウラワク', '木崎', 'キザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市浦和区大東', '11', '11107', '3300043', '埼玉県', 'サイタマケン', 'さいたま市浦和区', 'サイタマシウラワク', '大東', 'ダイトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市浦和区瀬ケ崎', '11', '11107', '3300044', '埼玉県', 'サイタマケン', 'さいたま市浦和区', 'サイタマシウラワク', '瀬ケ崎', 'セガサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市浦和区皇山町', '11', '11107', '3300045', '埼玉県', 'サイタマケン', 'さいたま市浦和区', 'サイタマシウラワク', '皇山町', 'コウザンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市浦和区大原', '11', '11107', '3300046', '埼玉県', 'サイタマケン', 'さいたま市浦和区', 'サイタマシウラワク', '大原', 'オオハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市浦和区駒場', '11', '11107', '3300051', '埼玉県', 'サイタマケン', 'さいたま市浦和区', 'サイタマシウラワク', '駒場', 'コマバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市浦和区本太', '11', '11107', '3300052', '埼玉県', 'サイタマケン', 'さいたま市浦和区', 'サイタマシウラワク', '本太', 'モトブト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市浦和区前地', '11', '11107', '3300053', '埼玉県', 'サイタマケン', 'さいたま市浦和区', 'サイタマシウラワク', '前地', 'マエジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市浦和区東岸町', '11', '11107', '3300054', '埼玉県', 'サイタマケン', 'さいたま市浦和区', 'サイタマシウラワク', '東岸町', 'ヒガシキシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市浦和区東高砂町', '11', '11107', '3300055', '埼玉県', 'サイタマケン', 'さいたま市浦和区', 'サイタマシウラワク', '東高砂町', 'ヒガシタカサゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市浦和区東仲町', '11', '11107', '3300056', '埼玉県', 'サイタマケン', 'さいたま市浦和区', 'サイタマシウラワク', '東仲町', 'ヒガシナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市浦和区常盤', '11', '11107', '3300061', '埼玉県', 'サイタマケン', 'さいたま市浦和区', 'サイタマシウラワク', '常盤', 'トキワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市浦和区仲町', '11', '11107', '3300062', '埼玉県', 'サイタマケン', 'さいたま市浦和区', 'サイタマシウラワク', '仲町', 'ナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市浦和区高砂', '11', '11107', '3300063', '埼玉県', 'サイタマケン', 'さいたま市浦和区', 'サイタマシウラワク', '高砂', 'タカサゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市浦和区岸町', '11', '11107', '3300064', '埼玉県', 'サイタマケン', 'さいたま市浦和区', 'サイタマシウラワク', '岸町', 'キシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市浦和区神明', '11', '11107', '3300065', '埼玉県', 'サイタマケン', 'さいたま市浦和区', 'サイタマシウラワク', '神明', 'シンメイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市浦和区上木崎', '11', '11107', '3300071', '埼玉県', 'サイタマケン', 'さいたま市浦和区', 'サイタマシウラワク', '上木崎', 'カミキザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市浦和区領家', '11', '11107', '3300072', '埼玉県', 'サイタマケン', 'さいたま市浦和区', 'サイタマシウラワク', '領家', 'リョウケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市浦和区元町', '11', '11107', '3300073', '埼玉県', 'サイタマケン', 'さいたま市浦和区', 'サイタマシウラワク', '元町', 'モトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市浦和区北浦和', '11', '11107', '3300074', '埼玉県', 'サイタマケン', 'さいたま市浦和区', 'サイタマシウラワク', '北浦和', 'キタウラワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市浦和区針ケ谷', '11', '11107', '3300075', '埼玉県', 'サイタマケン', 'さいたま市浦和区', 'サイタマシウラワク', '針ケ谷', 'ハリガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市中央区新都心', '11', '11105', '3300081', '埼玉県', 'サイタマケン', 'さいたま市中央区', 'サイタマシチュウオウク', '新都心', 'シントシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三沢市幸町', '02', '02207', '0330011', '青森県', 'アオモリケン', '三沢市', 'ミサワシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三沢市平畑', '02', '02207', '0330012', '青森県', 'アオモリケン', '三沢市', 'ミサワシ', '平畑', 'ヒラハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三沢市岡三沢', '02', '02207', '0330021', '青森県', 'アオモリケン', '三沢市', 'ミサワシ', '岡三沢', 'オカミサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三沢市三沢', '02', '02207', '0330022', '青森県', 'アオモリケン', '三沢市', 'ミサワシ', '三沢', 'ミサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三沢市下久保', '02', '02207', '0330023', '青森県', 'アオモリケン', '三沢市', 'ミサワシ', '下久保', 'シモクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三沢市東岡三沢', '02', '02207', '0330024', '青森県', 'アオモリケン', '三沢市', 'ミサワシ', '東岡三沢', 'ヒガシオカミサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三沢市桜町', '02', '02207', '0330031', '青森県', 'アオモリケン', '三沢市', 'ミサワシ', '桜町', 'サクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三沢市緑町', '02', '02207', '0330032', '青森県', 'アオモリケン', '三沢市', 'ミサワシ', '緑町', 'ミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三沢市美野原', '02', '02207', '0330033', '青森県', 'アオモリケン', '三沢市', 'ミサワシ', '美野原', 'ミノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三沢市東町', '02', '02207', '0330034', '青森県', 'アオモリケン', '三沢市', 'ミサワシ', '東町', 'ヒガシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三沢市松原町', '02', '02207', '0330035', '青森県', 'アオモリケン', '三沢市', 'ミサワシ', '松原町', 'マツバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三沢市南町', '02', '02207', '0330036', '青森県', 'アオモリケン', '三沢市', 'ミサワシ', '南町', 'ミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三沢市松園町', '02', '02207', '0330037', '青森県', 'アオモリケン', '三沢市', 'ミサワシ', '松園町', 'マツゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三沢市大町', '02', '02207', '0330041', '青森県', 'アオモリケン', '三沢市', 'ミサワシ', '大町', 'オオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三沢市栄町', '02', '02207', '0330042', '青森県', 'アオモリケン', '三沢市', 'ミサワシ', '栄町', 'サカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三沢市千代田町', '02', '02207', '0330043', '青森県', 'アオモリケン', '三沢市', 'ミサワシ', '千代田町', 'チヨダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三沢市古間木山', '02', '02207', '0330044', '青森県', 'アオモリケン', '三沢市', 'ミサワシ', '古間木山', 'フルマキヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三沢市薬師町', '02', '02207', '0330045', '青森県', 'アオモリケン', '三沢市', 'ミサワシ', '薬師町', 'ヤクシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三沢市古間木', '02', '02207', '0330051', '青森県', 'アオモリケン', '三沢市', 'ミサワシ', '古間木', 'フルマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三沢市本町', '02', '02207', '0330052', '青森県', 'アオモリケン', '三沢市', 'ミサワシ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三沢市春日台', '02', '02207', '0330053', '青森県', 'アオモリケン', '三沢市', 'ミサワシ', '春日台', 'カスガダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三沢市花園町', '02', '02207', '0330061', '青森県', 'アオモリケン', '三沢市', 'ミサワシ', '花園町', 'ハナゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三沢市新町', '02', '02207', '0330062', '青森県', 'アオモリケン', '三沢市', 'ミサワシ', '新町', 'シンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三沢市上久保', '02', '02207', '0330063', '青森県', 'アオモリケン', '三沢市', 'ミサワシ', '上久保', 'カミクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡六戸町犬落瀬', '02', '02405', '0330071', '青森県', 'アオモリケン', '上北郡六戸町', 'カミキタグンロクノヘマチ', '犬落瀬', 'イヌオトセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡六戸町犬落瀬内金矢', '02', '02405', '0330071', '青森県', 'アオモリケン', '上北郡六戸町', 'カミキタグンロクノヘマチ', '犬落瀬', 'イヌオトセ', null, null, '内金矢', 'ウチカナヤ');
INSERT INTO `ms_addresses` VALUES ('25724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡六戸町犬落瀬内山', '02', '02405', '0330071', '青森県', 'アオモリケン', '上北郡六戸町', 'カミキタグンロクノヘマチ', '犬落瀬', 'イヌオトセ', null, null, '内山', 'ウチヤマ');
INSERT INTO `ms_addresses` VALUES ('25725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡六戸町犬落瀬大曲', '02', '02405', '0330071', '青森県', 'アオモリケン', '上北郡六戸町', 'カミキタグンロクノヘマチ', '犬落瀬', 'イヌオトセ', null, null, '大曲', 'オオマガリ');
INSERT INTO `ms_addresses` VALUES ('25726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡六戸町犬落瀬岡沼', '02', '02405', '0330071', '青森県', 'アオモリケン', '上北郡六戸町', 'カミキタグンロクノヘマチ', '犬落瀬', 'イヌオトセ', null, null, '岡沼', 'オカヌマ');
INSERT INTO `ms_addresses` VALUES ('25727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡六戸町犬落瀬金沢', '02', '02405', '0330071', '青森県', 'アオモリケン', '上北郡六戸町', 'カミキタグンロクノヘマチ', '犬落瀬', 'イヌオトセ', null, null, '金沢', 'カナザワ');
INSERT INTO `ms_addresses` VALUES ('25728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡六戸町犬落瀬金矢', '02', '02405', '0330071', '青森県', 'アオモリケン', '上北郡六戸町', 'カミキタグンロクノヘマチ', '犬落瀬', 'イヌオトセ', null, null, '金矢', 'カナヤ');
INSERT INTO `ms_addresses` VALUES ('25729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡六戸町犬落瀬上淋代', '02', '02405', '0330071', '青森県', 'アオモリケン', '上北郡六戸町', 'カミキタグンロクノヘマチ', '犬落瀬', 'イヌオトセ', null, null, '上淋代', 'カミサビシロ');
INSERT INTO `ms_addresses` VALUES ('25730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡六戸町犬落瀬木越', '02', '02405', '0330071', '青森県', 'アオモリケン', '上北郡六戸町', 'カミキタグンロクノヘマチ', '犬落瀬', 'イヌオトセ', null, null, '木越', 'キコシ');
INSERT INTO `ms_addresses` VALUES ('25731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡六戸町犬落瀬権現沢', '02', '02405', '0330071', '青森県', 'アオモリケン', '上北郡六戸町', 'カミキタグンロクノヘマチ', '犬落瀬', 'イヌオトセ', null, null, '権現沢', 'ゴンゲンサワ');
INSERT INTO `ms_addresses` VALUES ('25732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡六戸町犬落瀬四木', '02', '02405', '0330071', '青森県', 'アオモリケン', '上北郡六戸町', 'カミキタグンロクノヘマチ', '犬落瀬', 'イヌオトセ', null, null, '四木', 'シキ');
INSERT INTO `ms_addresses` VALUES ('25733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡六戸町犬落瀬七百', '02', '02405', '0330071', '青森県', 'アオモリケン', '上北郡六戸町', 'カミキタグンロクノヘマチ', '犬落瀬', 'イヌオトセ', null, null, '七百', 'シチヒャク');
INSERT INTO `ms_addresses` VALUES ('25734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡六戸町犬落瀬下淋代', '02', '02405', '0330071', '青森県', 'アオモリケン', '上北郡六戸町', 'カミキタグンロクノヘマチ', '犬落瀬', 'イヌオトセ', null, null, '下淋代', 'シモサビシロ');
INSERT INTO `ms_addresses` VALUES ('25735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡六戸町犬落瀬高森', '02', '02405', '0330071', '青森県', 'アオモリケン', '上北郡六戸町', 'カミキタグンロクノヘマチ', '犬落瀬', 'イヌオトセ', null, null, '高森', 'タカモリ');
INSERT INTO `ms_addresses` VALUES ('25736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡六戸町犬落瀬通目木', '02', '02405', '0330071', '青森県', 'アオモリケン', '上北郡六戸町', 'カミキタグンロクノヘマチ', '犬落瀬', 'イヌオトセ', null, null, '通目木', 'ヅメキ');
INSERT INTO `ms_addresses` VALUES ('25737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡六戸町犬落瀬中屋敷', '02', '02405', '0330071', '青森県', 'アオモリケン', '上北郡六戸町', 'カミキタグンロクノヘマチ', '犬落瀬', 'イヌオトセ', null, null, '中屋敷', 'ナカヤシキ');
INSERT INTO `ms_addresses` VALUES ('25738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡六戸町犬落瀬沼久保', '02', '02405', '0330071', '青森県', 'アオモリケン', '上北郡六戸町', 'カミキタグンロクノヘマチ', '犬落瀬', 'イヌオトセ', null, null, '沼久保', 'ヌマクボ');
INSERT INTO `ms_addresses` VALUES ('25739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡六戸町犬落瀬根古橋', '02', '02405', '0330071', '青森県', 'アオモリケン', '上北郡六戸町', 'カミキタグンロクノヘマチ', '犬落瀬', 'イヌオトセ', null, null, '根古橋', 'ネコハシ');
INSERT INTO `ms_addresses` VALUES ('25740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡六戸町犬落瀬堀切沢', '02', '02405', '0330071', '青森県', 'アオモリケン', '上北郡六戸町', 'カミキタグンロクノヘマチ', '犬落瀬', 'イヌオトセ', null, null, '堀切沢', 'ホリキリサワ');
INSERT INTO `ms_addresses` VALUES ('25741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡六戸町犬落瀬南平', '02', '02405', '0330071', '青森県', 'アオモリケン', '上北郡六戸町', 'カミキタグンロクノヘマチ', '犬落瀬', 'イヌオトセ', null, null, '南平', 'ミナミタイ');
INSERT INTO `ms_addresses` VALUES ('25742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡六戸町犬落瀬柳沢', '02', '02405', '0330071', '青森県', 'アオモリケン', '上北郡六戸町', 'カミキタグンロクノヘマチ', '犬落瀬', 'イヌオトセ', null, null, '柳沢', 'ヤナギサワ');
INSERT INTO `ms_addresses` VALUES ('25743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡六戸町折茂', '02', '02405', '0330072', '青森県', 'アオモリケン', '上北郡六戸町', 'カミキタグンロクノヘマチ', '折茂', 'オリモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡六戸町折茂大原', '02', '02405', '0330072', '青森県', 'アオモリケン', '上北郡六戸町', 'カミキタグンロクノヘマチ', '折茂', 'オリモ', null, null, '大原', 'オオハラ');
INSERT INTO `ms_addresses` VALUES ('25745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡六戸町折茂沖山', '02', '02405', '0330072', '青森県', 'アオモリケン', '上北郡六戸町', 'カミキタグンロクノヘマチ', '折茂', 'オリモ', null, null, '沖山', 'オキヤマ');
INSERT INTO `ms_addresses` VALUES ('25746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡六戸町金矢', '02', '02405', '0330073', '青森県', 'アオモリケン', '上北郡六戸町', 'カミキタグンロクノヘマチ', '金矢', 'カナヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡六戸町小松ケ丘', '02', '02405', '0330074', '青森県', 'アオモリケン', '上北郡六戸町', 'カミキタグンロクノヘマチ', '小松ケ丘', 'コマツガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市大宮区', '11', '11103', '3300800', '埼玉県', 'サイタマケン', 'さいたま市大宮区', 'サイタマシオオミヤク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('25749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市大宮区土手町', '11', '11103', '3300801', '埼玉県', 'サイタマケン', 'さいたま市大宮区', 'サイタマシオオミヤク', '土手町', 'ドテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市大宮区宮町', '11', '11103', '3300802', '埼玉県', 'サイタマケン', 'さいたま市大宮区', 'サイタマシオオミヤク', '宮町', 'ミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市大宮区高鼻町', '11', '11103', '3300803', '埼玉県', 'サイタマケン', 'さいたま市大宮区', 'サイタマシオオミヤク', '高鼻町', 'タカハナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市大宮区堀の内町', '11', '11103', '3300804', '埼玉県', 'サイタマケン', 'さいたま市大宮区', 'サイタマシオオミヤク', '堀の内町', 'ホリノウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市大宮区寿能町', '11', '11103', '3300805', '埼玉県', 'サイタマケン', 'さいたま市大宮区', 'サイタマシオオミヤク', '寿能町', 'ジュノウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市大宮区天沼町', '11', '11103', '3300834', '埼玉県', 'サイタマケン', 'さいたま市大宮区', 'サイタマシオオミヤク', '天沼町', 'アマヌマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市大宮区北袋町', '11', '11103', '3300835', '埼玉県', 'サイタマケン', 'さいたま市大宮区', 'サイタマシオオミヤク', '北袋町', 'キタブクロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市大宮区大原', '11', '11103', '3300836', '埼玉県', 'サイタマケン', 'さいたま市大宮区', 'サイタマシオオミヤク', '大原', 'オオハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市大宮区東町', '11', '11103', '3300841', '埼玉県', 'サイタマケン', 'さいたま市大宮区', 'サイタマシオオミヤク', '東町', 'アズマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市大宮区浅間町', '11', '11103', '3300842', '埼玉県', 'サイタマケン', 'さいたま市大宮区', 'サイタマシオオミヤク', '浅間町', 'センゲンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市大宮区吉敷町', '11', '11103', '3300843', '埼玉県', 'サイタマケン', 'さいたま市大宮区', 'サイタマシオオミヤク', '吉敷町', 'キシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市大宮区下町', '11', '11103', '3300844', '埼玉県', 'サイタマケン', 'さいたま市大宮区', 'サイタマシオオミヤク', '下町', 'シモチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市大宮区仲町', '11', '11103', '3300845', '埼玉県', 'サイタマケン', 'さいたま市大宮区', 'サイタマシオオミヤク', '仲町', 'ナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市大宮区大門町', '11', '11103', '3300846', '埼玉県', 'サイタマケン', 'さいたま市大宮区', 'サイタマシオオミヤク', '大門町', 'ダイモンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市大宮区櫛引町', '11', '11103', '3300851', '埼玉県', 'サイタマケン', 'さいたま市大宮区', 'サイタマシオオミヤク', '櫛引町', 'クシヒキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市大宮区大成町', '11', '11103', '3300852', '埼玉県', 'サイタマケン', 'さいたま市大宮区', 'サイタマシオオミヤク', '大成町', 'オオナリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市大宮区錦町', '11', '11103', '3300853', '埼玉県', 'サイタマケン', 'さいたま市大宮区', 'サイタマシオオミヤク', '錦町', 'ニシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市大宮区桜木町', '11', '11103', '3300854', '埼玉県', 'サイタマケン', 'さいたま市大宮区', 'サイタマシオオミヤク', '桜木町', 'サクラギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市大宮区上小町', '11', '11103', '3300855', '埼玉県', 'サイタマケン', 'さいたま市大宮区', 'サイタマシオオミヤク', '上小町', 'カミコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市大宮区三橋', '11', '11103', '3300856', '埼玉県', 'サイタマケン', 'さいたま市大宮区', 'サイタマシオオミヤク', '三橋', 'ミハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三沢市天ケ森', '02', '02207', '0330101', '青森県', 'アオモリケン', '三沢市', 'ミサワシ', '天ケ森', 'アマガモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三沢市砂森', '02', '02207', '0330102', '青森県', 'アオモリケン', '三沢市', 'ミサワシ', '砂森', 'スナモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三沢市塩釜', '02', '02207', '0330103', '青森県', 'アオモリケン', '三沢市', 'ミサワシ', '塩釜', 'シオガマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三沢市織笠', '02', '02207', '0330104', '青森県', 'アオモリケン', '三沢市', 'ミサワシ', '織笠', 'オリカサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三沢市新森', '02', '02207', '0330105', '青森県', 'アオモリケン', '三沢市', 'ミサワシ', '新森', 'シンモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三沢市六川目', '02', '02207', '0330111', '青森県', 'アオモリケン', '三沢市', 'ミサワシ', '六川目', 'ムカワメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三沢市細谷', '02', '02207', '0330112', '青森県', 'アオモリケン', '三沢市', 'ミサワシ', '細谷', 'ホソヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三沢市淋代', '02', '02207', '0330113', '青森県', 'アオモリケン', '三沢市', 'ミサワシ', '淋代', 'サビシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三沢市堀口', '02', '02207', '0330123', '青森県', 'アオモリケン', '三沢市', 'ミサワシ', '堀口', 'ホリグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三沢市五川目', '02', '02207', '0330131', '青森県', 'アオモリケン', '三沢市', 'ミサワシ', '五川目', 'イツカワメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三沢市四川目', '02', '02207', '0330132', '青森県', 'アオモリケン', '三沢市', 'ミサワシ', '四川目', 'ヨカワメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三沢市鹿中', '02', '02207', '0330133', '青森県', 'アオモリケン', '三沢市', 'ミサワシ', '鹿中', 'シカナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三沢市大津', '02', '02207', '0330134', '青森県', 'アオモリケン', '三沢市', 'ミサワシ', '大津', 'オオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三沢市港町', '02', '02207', '0330141', '青森県', 'アオモリケン', '三沢市', 'ミサワシ', '港町', 'ミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三沢市三川目', '02', '02207', '0330142', '青森県', 'アオモリケン', '三沢市', 'ミサワシ', '三川目', 'ミカワメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三沢市前平', '02', '02207', '0330143', '青森県', 'アオモリケン', '三沢市', 'ミサワシ', '前平', 'マエタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三沢市南山', '02', '02207', '0330151', '青森県', 'アオモリケン', '三沢市', 'ミサワシ', '南山', 'ミナミヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三沢市深谷', '02', '02207', '0330152', '青森県', 'アオモリケン', '三沢市', 'ミサワシ', '深谷', 'フカヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三沢市泉町', '02', '02207', '0330153', '青森県', 'アオモリケン', '三沢市', 'ミサワシ', '泉町', 'イズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三沢市日の出', '02', '02207', '0330154', '青森県', 'アオモリケン', '三沢市', 'ミサワシ', '日の出', 'ヒノデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三沢市八幡', '02', '02207', '0330161', '青森県', 'アオモリケン', '三沢市', 'ミサワシ', '八幡', 'ヤワタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三沢市越下', '02', '02207', '0330162', '青森県', 'アオモリケン', '三沢市', 'ミサワシ', '越下', 'コシシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三沢市富崎', '02', '02207', '0330163', '青森県', 'アオモリケン', '三沢市', 'ミサワシ', '富崎', 'トミサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三沢市谷地頭', '02', '02207', '0330164', '青森県', 'アオモリケン', '三沢市', 'ミサワシ', '谷地頭', 'ヤチガシラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三沢市高野沢', '02', '02207', '0330165', '青森県', 'アオモリケン', '三沢市', 'ミサワシ', '高野沢', 'タカノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三沢市朝日', '02', '02207', '0330166', '青森県', 'アオモリケン', '三沢市', 'ミサワシ', '朝日', 'アサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三沢市根井', '02', '02207', '0330167', '青森県', 'アオモリケン', '三沢市', 'ミサワシ', '根井', 'ネイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市中央区新都心明治安田生命さいたま新都心ビル　1階', '11', '11105', '3306001', '埼玉県', 'サイタマケン', 'さいたま市中央区', 'サイタマシチュウオウク', '新都心', 'シントシン', null, null, '明治安田生命さいたま新都心ビル　1階', 'メイジヤスダセイメイサイタマシントシンビル　01カイ');
INSERT INTO `ms_addresses` VALUES ('25797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市中央区新都心明治安田生命さいたま新都心ビル　2階', '11', '11105', '3306002', '埼玉県', 'サイタマケン', 'さいたま市中央区', 'サイタマシチュウオウク', '新都心', 'シントシン', null, null, '明治安田生命さいたま新都心ビル　2階', 'メイジヤスダセイメイサイタマシントシンビル　02カイ');
INSERT INTO `ms_addresses` VALUES ('25798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市中央区新都心明治安田生命さいたま新都心ビル　3階', '11', '11105', '3306003', '埼玉県', 'サイタマケン', 'さいたま市中央区', 'サイタマシチュウオウク', '新都心', 'シントシン', null, null, '明治安田生命さいたま新都心ビル　3階', 'メイジヤスダセイメイサイタマシントシンビル　03カイ');
INSERT INTO `ms_addresses` VALUES ('25799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市中央区新都心明治安田生命さいたま新都心ビル　4階', '11', '11105', '3306004', '埼玉県', 'サイタマケン', 'さいたま市中央区', 'サイタマシチュウオウク', '新都心', 'シントシン', null, null, '明治安田生命さいたま新都心ビル　4階', 'メイジヤスダセイメイサイタマシントシンビル　04カイ');
INSERT INTO `ms_addresses` VALUES ('25800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市中央区新都心明治安田生命さいたま新都心ビル　5階', '11', '11105', '3306005', '埼玉県', 'サイタマケン', 'さいたま市中央区', 'サイタマシチュウオウク', '新都心', 'シントシン', null, null, '明治安田生命さいたま新都心ビル　5階', 'メイジヤスダセイメイサイタマシントシンビル　05カイ');
INSERT INTO `ms_addresses` VALUES ('25801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市中央区新都心明治安田生命さいたま新都心ビル　6階', '11', '11105', '3306006', '埼玉県', 'サイタマケン', 'さいたま市中央区', 'サイタマシチュウオウク', '新都心', 'シントシン', null, null, '明治安田生命さいたま新都心ビル　6階', 'メイジヤスダセイメイサイタマシントシンビル　06カイ');
INSERT INTO `ms_addresses` VALUES ('25802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市中央区新都心明治安田生命さいたま新都心ビル　7階', '11', '11105', '3306007', '埼玉県', 'サイタマケン', 'さいたま市中央区', 'サイタマシチュウオウク', '新都心', 'シントシン', null, null, '明治安田生命さいたま新都心ビル　7階', 'メイジヤスダセイメイサイタマシントシンビル　07カイ');
INSERT INTO `ms_addresses` VALUES ('25803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市中央区新都心明治安田生命さいたま新都心ビル　8階', '11', '11105', '3306008', '埼玉県', 'サイタマケン', 'さいたま市中央区', 'サイタマシチュウオウク', '新都心', 'シントシン', null, null, '明治安田生命さいたま新都心ビル　8階', 'メイジヤスダセイメイサイタマシントシンビル　08カイ');
INSERT INTO `ms_addresses` VALUES ('25804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市中央区新都心明治安田生命さいたま新都心ビル　9階', '11', '11105', '3306009', '埼玉県', 'サイタマケン', 'さいたま市中央区', 'サイタマシチュウオウク', '新都心', 'シントシン', null, null, '明治安田生命さいたま新都心ビル　9階', 'メイジヤスダセイメイサイタマシントシンビル　09カイ');
INSERT INTO `ms_addresses` VALUES ('25805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市中央区新都心明治安田生命さいたま新都心ビル　10階', '11', '11105', '3306010', '埼玉県', 'サイタマケン', 'さいたま市中央区', 'サイタマシチュウオウク', '新都心', 'シントシン', null, null, '明治安田生命さいたま新都心ビル　10階', 'メイジヤスダセイメイサイタマシントシンビル　10カイ');
INSERT INTO `ms_addresses` VALUES ('25806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市中央区新都心明治安田生命さいたま新都心ビル　11階', '11', '11105', '3306011', '埼玉県', 'サイタマケン', 'さいたま市中央区', 'サイタマシチュウオウク', '新都心', 'シントシン', null, null, '明治安田生命さいたま新都心ビル　11階', 'メイジヤスダセイメイサイタマシントシンビル　11カイ');
INSERT INTO `ms_addresses` VALUES ('25807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市中央区新都心明治安田生命さいたま新都心ビル　12階', '11', '11105', '3306012', '埼玉県', 'サイタマケン', 'さいたま市中央区', 'サイタマシチュウオウク', '新都心', 'シントシン', null, null, '明治安田生命さいたま新都心ビル　12階', 'メイジヤスダセイメイサイタマシントシンビル　12カイ');
INSERT INTO `ms_addresses` VALUES ('25808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市中央区新都心明治安田生命さいたま新都心ビル　13階', '11', '11105', '3306013', '埼玉県', 'サイタマケン', 'さいたま市中央区', 'サイタマシチュウオウク', '新都心', 'シントシン', null, null, '明治安田生命さいたま新都心ビル　13階', 'メイジヤスダセイメイサイタマシントシンビル　13カイ');
INSERT INTO `ms_addresses` VALUES ('25809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市中央区新都心明治安田生命さいたま新都心ビル　14階', '11', '11105', '3306014', '埼玉県', 'サイタマケン', 'さいたま市中央区', 'サイタマシチュウオウク', '新都心', 'シントシン', null, null, '明治安田生命さいたま新都心ビル　14階', 'メイジヤスダセイメイサイタマシントシンビル　14カイ');
INSERT INTO `ms_addresses` VALUES ('25810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市中央区新都心明治安田生命さいたま新都心ビル　15階', '11', '11105', '3306015', '埼玉県', 'サイタマケン', 'さいたま市中央区', 'サイタマシチュウオウク', '新都心', 'シントシン', null, null, '明治安田生命さいたま新都心ビル　15階', 'メイジヤスダセイメイサイタマシントシンビル　15カイ');
INSERT INTO `ms_addresses` VALUES ('25811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市中央区新都心明治安田生命さいたま新都心ビル　16階', '11', '11105', '3306016', '埼玉県', 'サイタマケン', 'さいたま市中央区', 'サイタマシチュウオウク', '新都心', 'シントシン', null, null, '明治安田生命さいたま新都心ビル　16階', 'メイジヤスダセイメイサイタマシントシンビル　16カイ');
INSERT INTO `ms_addresses` VALUES ('25812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市中央区新都心明治安田生命さいたま新都心ビル　17階', '11', '11105', '3306017', '埼玉県', 'サイタマケン', 'さいたま市中央区', 'サイタマシチュウオウク', '新都心', 'シントシン', null, null, '明治安田生命さいたま新都心ビル　17階', 'メイジヤスダセイメイサイタマシントシンビル　17カイ');
INSERT INTO `ms_addresses` VALUES ('25813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市中央区新都心明治安田生命さいたま新都心ビル　18階', '11', '11105', '3306018', '埼玉県', 'サイタマケン', 'さいたま市中央区', 'サイタマシチュウオウク', '新都心', 'シントシン', null, null, '明治安田生命さいたま新都心ビル　18階', 'メイジヤスダセイメイサイタマシントシンビル　18カイ');
INSERT INTO `ms_addresses` VALUES ('25814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市中央区新都心明治安田生命さいたま新都心ビル　19階', '11', '11105', '3306019', '埼玉県', 'サイタマケン', 'さいたま市中央区', 'サイタマシチュウオウク', '新都心', 'シントシン', null, null, '明治安田生命さいたま新都心ビル　19階', 'メイジヤスダセイメイサイタマシントシンビル　19カイ');
INSERT INTO `ms_addresses` VALUES ('25815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市中央区新都心明治安田生命さいたま新都心ビル　20階', '11', '11105', '3306020', '埼玉県', 'サイタマケン', 'さいたま市中央区', 'サイタマシチュウオウク', '新都心', 'シントシン', null, null, '明治安田生命さいたま新都心ビル　20階', 'メイジヤスダセイメイサイタマシントシンビル　20カイ');
INSERT INTO `ms_addresses` VALUES ('25816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市中央区新都心明治安田生命さいたま新都心ビル　21階', '11', '11105', '3306021', '埼玉県', 'サイタマケン', 'さいたま市中央区', 'サイタマシチュウオウク', '新都心', 'シントシン', null, null, '明治安田生命さいたま新都心ビル　21階', 'メイジヤスダセイメイサイタマシントシンビル　21カイ');
INSERT INTO `ms_addresses` VALUES ('25817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市中央区新都心明治安田生命さいたま新都心ビル　22階', '11', '11105', '3306022', '埼玉県', 'サイタマケン', 'さいたま市中央区', 'サイタマシチュウオウク', '新都心', 'シントシン', null, null, '明治安田生命さいたま新都心ビル　22階', 'メイジヤスダセイメイサイタマシントシンビル　22カイ');
INSERT INTO `ms_addresses` VALUES ('25818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市中央区新都心明治安田生命さいたま新都心ビル　23階', '11', '11105', '3306023', '埼玉県', 'サイタマケン', 'さいたま市中央区', 'サイタマシチュウオウク', '新都心', 'シントシン', null, null, '明治安田生命さいたま新都心ビル　23階', 'メイジヤスダセイメイサイタマシントシンビル　23カイ');
INSERT INTO `ms_addresses` VALUES ('25819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市中央区新都心明治安田生命さいたま新都心ビル　24階', '11', '11105', '3306024', '埼玉県', 'サイタマケン', 'さいたま市中央区', 'サイタマシチュウオウク', '新都心', 'シントシン', null, null, '明治安田生命さいたま新都心ビル　24階', 'メイジヤスダセイメイサイタマシントシンビル　24カイ');
INSERT INTO `ms_addresses` VALUES ('25820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市中央区新都心明治安田生命さいたま新都心ビル　25階', '11', '11105', '3306025', '埼玉県', 'サイタマケン', 'さいたま市中央区', 'サイタマシチュウオウク', '新都心', 'シントシン', null, null, '明治安田生命さいたま新都心ビル　25階', 'メイジヤスダセイメイサイタマシントシンビル　25カイ');
INSERT INTO `ms_addresses` VALUES ('25821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市中央区新都心明治安田生命さいたま新都心ビル　26階', '11', '11105', '3306026', '埼玉県', 'サイタマケン', 'さいたま市中央区', 'サイタマシチュウオウク', '新都心', 'シントシン', null, null, '明治安田生命さいたま新都心ビル　26階', 'メイジヤスダセイメイサイタマシントシンビル　26カイ');
INSERT INTO `ms_addresses` VALUES ('25822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市中央区新都心明治安田生命さいたま新都心ビル　27階', '11', '11105', '3306027', '埼玉県', 'サイタマケン', 'さいたま市中央区', 'サイタマシチュウオウク', '新都心', 'シントシン', null, null, '明治安田生命さいたま新都心ビル　27階', 'メイジヤスダセイメイサイタマシントシンビル　27カイ');
INSERT INTO `ms_addresses` VALUES ('25823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市中央区新都心明治安田生命さいたま新都心ビル　28階', '11', '11105', '3306028', '埼玉県', 'サイタマケン', 'さいたま市中央区', 'サイタマシチュウオウク', '新都心', 'シントシン', null, null, '明治安田生命さいたま新都心ビル　28階', 'メイジヤスダセイメイサイタマシントシンビル　28カイ');
INSERT INTO `ms_addresses` VALUES ('25824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市中央区新都心明治安田生命さいたま新都心ビル　29階', '11', '11105', '3306029', '埼玉県', 'サイタマケン', 'さいたま市中央区', 'サイタマシチュウオウク', '新都心', 'シントシン', null, null, '明治安田生命さいたま新都心ビル　29階', 'メイジヤスダセイメイサイタマシントシンビル　29カイ');
INSERT INTO `ms_addresses` VALUES ('25825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市中央区新都心明治安田生命さいたま新都心ビル　30階', '11', '11105', '3306030', '埼玉県', 'サイタマケン', 'さいたま市中央区', 'サイタマシチュウオウク', '新都心', 'シントシン', null, null, '明治安田生命さいたま新都心ビル　30階', 'メイジヤスダセイメイサイタマシントシンビル　30カイ');
INSERT INTO `ms_addresses` VALUES ('25826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市中央区新都心明治安田生命さいたま新都心ビル　31階', '11', '11105', '3306031', '埼玉県', 'サイタマケン', 'さいたま市中央区', 'サイタマシチュウオウク', '新都心', 'シントシン', null, null, '明治安田生命さいたま新都心ビル　31階', 'メイジヤスダセイメイサイタマシントシンビル　31カイ');
INSERT INTO `ms_addresses` VALUES ('25827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市中央区新都心明治安田生命さいたま新都心ビル　32階', '11', '11105', '3306032', '埼玉県', 'サイタマケン', 'さいたま市中央区', 'サイタマシチュウオウク', '新都心', 'シントシン', null, null, '明治安田生命さいたま新都心ビル　32階', 'メイジヤスダセイメイサイタマシントシンビル　32カイ');
INSERT INTO `ms_addresses` VALUES ('25828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市中央区新都心明治安田生命さいたま新都心ビル　33階', '11', '11105', '3306033', '埼玉県', 'サイタマケン', 'さいたま市中央区', 'サイタマシチュウオウク', '新都心', 'シントシン', null, null, '明治安田生命さいたま新都心ビル　33階', 'メイジヤスダセイメイサイタマシントシンビル　33カイ');
INSERT INTO `ms_addresses` VALUES ('25829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市中央区新都心明治安田生命さいたま新都心ビル　34階', '11', '11105', '3306034', '埼玉県', 'サイタマケン', 'さいたま市中央区', 'サイタマシチュウオウク', '新都心', 'シントシン', null, null, '明治安田生命さいたま新都心ビル　34階', 'メイジヤスダセイメイサイタマシントシンビル　34カイ');
INSERT INTO `ms_addresses` VALUES ('25830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市中央区新都心明治安田生命さいたま新都心ビル　35階', '11', '11105', '3306035', '埼玉県', 'サイタマケン', 'さいたま市中央区', 'サイタマシチュウオウク', '新都心', 'シントシン', null, null, '明治安田生命さいたま新都心ビル　35階', 'メイジヤスダセイメイサイタマシントシンビル　35カイ');
INSERT INTO `ms_addresses` VALUES ('25831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市中央区新都心明治安田生命さいたま新都心ビル　', '11', '11105', '3306090', '埼玉県', 'サイタマケン', 'さいたま市中央区', 'サイタマシチュウオウク', '新都心', 'シントシン', null, null, '明治安田生命さいたま新都心ビル　', 'メイジヤスダセイメイサイタマシントシンビル　');
INSERT INTO `ms_addresses` VALUES ('25927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市西区', '11', '11101', '3310000', '埼玉県', 'サイタマケン', 'さいたま市西区', 'サイタマシニシク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('25928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市西区内野本郷', '11', '11101', '3310045', '埼玉県', 'サイタマケン', 'さいたま市西区', 'サイタマシニシク', '内野本郷', 'ウチノホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市西区宮前町', '11', '11101', '3310046', '埼玉県', 'サイタマケン', 'さいたま市西区', 'サイタマシニシク', '宮前町', 'ミヤマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市西区指扇', '11', '11101', '3310047', '埼玉県', 'サイタマケン', 'さいたま市西区', 'サイタマシニシク', '指扇', 'サシオウギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市西区清河寺', '11', '11101', '3310048', '埼玉県', 'サイタマケン', 'さいたま市西区', 'サイタマシニシク', '清河寺', 'セイガンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市西区西新井', '11', '11101', '3310049', '埼玉県', 'サイタマケン', 'さいたま市西区', 'サイタマシニシク', '西新井', 'ニシアライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市西区三橋', '11', '11101', '3310052', '埼玉県', 'サイタマケン', 'さいたま市西区', 'サイタマシニシク', '三橋', 'ミハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市西区植田谷本', '11', '11101', '3310053', '埼玉県', 'サイタマケン', 'さいたま市西区', 'サイタマシニシク', '植田谷本', 'ウエタヤホン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市西区島根', '11', '11101', '3310054', '埼玉県', 'サイタマケン', 'さいたま市西区', 'サイタマシニシク', '島根', 'シマネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市西区昭和', '11', '11101', '3310055', '埼玉県', 'サイタマケン', 'さいたま市西区', 'サイタマシニシク', '昭和', 'ショウワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市西区三条町', '11', '11101', '3310056', '埼玉県', 'サイタマケン', 'さいたま市西区', 'サイタマシニシク', '三条町', 'サンジョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市西区中野林', '11', '11101', '3310057', '埼玉県', 'サイタマケン', 'さいたま市西区', 'サイタマシニシク', '中野林', 'ナカノバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市西区飯田', '11', '11101', '3310058', '埼玉県', 'サイタマケン', 'さいたま市西区', 'サイタマシニシク', '飯田', 'イイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市西区水判土', '11', '11101', '3310059', '埼玉県', 'サイタマケン', 'さいたま市西区', 'サイタマシニシク', '水判土', 'ミズハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市西区塚本町', '11', '11101', '3310060', '埼玉県', 'サイタマケン', 'さいたま市西区', 'サイタマシニシク', '塚本町', 'ツカモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市西区西遊馬', '11', '11101', '3310061', '埼玉県', 'サイタマケン', 'さいたま市西区', 'サイタマシニシク', '西遊馬', 'ニシアスマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市西区土屋', '11', '11101', '3310062', '埼玉県', 'サイタマケン', 'さいたま市西区', 'サイタマシニシク', '土屋', 'ツチヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市西区プラザ', '11', '11101', '3310063', '埼玉県', 'サイタマケン', 'さいたま市西区', 'サイタマシニシク', 'プラザ', 'プラザ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市西区佐知川', '11', '11101', '3310064', '埼玉県', 'サイタマケン', 'さいたま市西区', 'サイタマシニシク', '佐知川', 'サジカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市西区二ツ宮', '11', '11101', '3310065', '埼玉県', 'サイタマケン', 'さいたま市西区', 'サイタマシニシク', '二ツ宮', 'フタツミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市西区塚本', '11', '11101', '3310066', '埼玉県', 'サイタマケン', 'さいたま市西区', 'サイタマシニシク', '塚本', 'ツカモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市西区植田谷本村新田', '11', '11101', '3310067', '埼玉県', 'サイタマケン', 'さいたま市西区', 'サイタマシニシク', '植田谷本村新田', 'ウエタヤホンムラシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市西区飯田新田', '11', '11101', '3310068', '埼玉県', 'サイタマケン', 'さいたま市西区', 'サイタマシニシク', '飯田新田', 'イイダシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市西区湯木町', '11', '11101', '3310069', '埼玉県', 'サイタマケン', 'さいたま市西区', 'サイタマシニシク', '湯木町', 'ユギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市西区高木', '11', '11101', '3310071', '埼玉県', 'サイタマケン', 'さいたま市西区', 'サイタマシニシク', '高木', 'タカギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市西区平方領々家', '11', '11101', '3310072', '埼玉県', 'サイタマケン', 'さいたま市西区', 'サイタマシニシク', '平方領々家', 'ヒラカタリョウリョウケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市西区指扇領別所', '11', '11101', '3310073', '埼玉県', 'サイタマケン', 'さいたま市西区', 'サイタマシニシク', '指扇領別所', 'サシオウギリョウベッショ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市西区宝来', '11', '11101', '3310074', '埼玉県', 'サイタマケン', 'さいたま市西区', 'サイタマシニシク', '宝来', 'ホウライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市西区峰岸', '11', '11101', '3310075', '埼玉県', 'サイタマケン', 'さいたま市西区', 'サイタマシニシク', '峰岸', 'ミネギシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市西区指扇領辻', '11', '11101', '3310076', '埼玉県', 'サイタマケン', 'さいたま市西区', 'サイタマシニシク', '指扇領辻', 'サシオウギリョウツジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市西区中釘', '11', '11101', '3310077', '埼玉県', 'サイタマケン', 'さいたま市西区', 'サイタマシニシク', '中釘', 'ナカクギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市北区', '11', '11102', '3310800', '埼玉県', 'サイタマケン', 'さいたま市北区', 'サイタマシキタク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('25959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市北区今羽町', '11', '11102', '3310801', '埼玉県', 'サイタマケン', 'さいたま市北区', 'サイタマシキタク', '今羽町', 'コンバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市北区本郷町', '11', '11102', '3310802', '埼玉県', 'サイタマケン', 'さいたま市北区', 'サイタマシキタク', '本郷町', 'ホンゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市北区見沼', '11', '11102', '3310803', '埼玉県', 'サイタマケン', 'さいたま市北区', 'サイタマシキタク', '見沼', 'ミヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市北区土呂町', '11', '11102', '3310804', '埼玉県', 'サイタマケン', 'さいたま市北区', 'サイタマシキタク', '土呂町', 'トロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市北区盆栽町', '11', '11102', '3310805', '埼玉県', 'サイタマケン', 'さいたま市北区', 'サイタマシキタク', '盆栽町', 'ボンサイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市北区吉野町', '11', '11102', '3310811', '埼玉県', 'サイタマケン', 'さいたま市北区', 'サイタマシキタク', '吉野町', 'ヨシノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市北区宮原町', '11', '11102', '3310812', '埼玉県', 'サイタマケン', 'さいたま市北区', 'サイタマシキタク', '宮原町', 'ミヤハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市北区植竹町', '11', '11102', '3310813', '埼玉県', 'サイタマケン', 'さいたま市北区', 'サイタマシキタク', '植竹町', 'ウエタケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市北区東大成町', '11', '11102', '3310814', '埼玉県', 'サイタマケン', 'さいたま市北区', 'サイタマシキタク', '東大成町', 'ヒガシオオナリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市北区大成町', '11', '11102', '3310815', '埼玉県', 'サイタマケン', 'さいたま市北区', 'サイタマシキタク', '大成町', 'オオナリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市北区別所町', '11', '11102', '3310821', '埼玉県', 'サイタマケン', 'さいたま市北区', 'サイタマシキタク', '別所町', 'ベッショチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市北区奈良町', '11', '11102', '3310822', '埼玉県', 'サイタマケン', 'さいたま市北区', 'サイタマシキタク', '奈良町', 'ナラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市北区日進町', '11', '11102', '3310823', '埼玉県', 'サイタマケン', 'さいたま市北区', 'サイタマシキタク', '日進町', 'ニッシンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市北区上加', '11', '11102', '3310824', '埼玉県', 'サイタマケン', 'さいたま市北区', 'サイタマシキタク', '上加', 'カミカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市北区櫛引町', '11', '11102', '3310825', '埼玉県', 'サイタマケン', 'さいたま市北区', 'サイタマシキタク', '櫛引町', 'クシヒキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川口市', '11', '11203', '3320000', '埼玉県', 'サイタマケン', '川口市', 'カワグチシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('25998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川口市朝日', '11', '11203', '3320001', '埼玉県', 'サイタマケン', '川口市', 'カワグチシ', '朝日', 'アサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('25999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川口市弥平', '11', '11203', '3320002', '埼玉県', 'サイタマケン', '川口市', 'カワグチシ', '弥平', 'ヤヘイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川口市東領家', '11', '11203', '3320003', '埼玉県', 'サイタマケン', '川口市', 'カワグチシ', '東領家', 'ヒガシリョウケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川口市領家', '11', '11203', '3320004', '埼玉県', 'サイタマケン', '川口市', 'カワグチシ', '領家', 'リョウケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川口市新井町', '11', '11203', '3320005', '埼玉県', 'サイタマケン', '川口市', 'カワグチシ', '新井町', 'アライチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川口市末広', '11', '11203', '3320006', '埼玉県', 'サイタマケン', '川口市', 'カワグチシ', '末広', 'スエヒロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川口市河原町', '11', '11203', '3320007', '埼玉県', 'サイタマケン', '川口市', 'カワグチシ', '河原町', 'カワハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川口市元郷', '11', '11203', '3320011', '埼玉県', 'サイタマケン', '川口市', 'カワグチシ', '元郷', 'モトゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川口市本町', '11', '11203', '3320012', '埼玉県', 'サイタマケン', '川口市', 'カワグチシ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川口市舟戸町', '11', '11203', '3320013', '埼玉県', 'サイタマケン', '川口市', 'カワグチシ', '舟戸町', 'フナトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川口市金山町', '11', '11203', '3320014', '埼玉県', 'サイタマケン', '川口市', 'カワグチシ', '金山町', 'カナヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川口市川口', '11', '11203', '3320015', '埼玉県', 'サイタマケン', '川口市', 'カワグチシ', '川口', 'カワグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川口市幸町', '11', '11203', '3320016', '埼玉県', 'サイタマケン', '川口市', 'カワグチシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川口市栄町', '11', '11203', '3320017', '埼玉県', 'サイタマケン', '川口市', 'カワグチシ', '栄町', 'サカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川口市西川口', '11', '11203', '3320021', '埼玉県', 'サイタマケン', '川口市', 'カワグチシ', '西川口', 'ニシカワグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川口市仲町', '11', '11203', '3320022', '埼玉県', 'サイタマケン', '川口市', 'カワグチシ', '仲町', 'ナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川口市飯塚', '11', '11203', '3320023', '埼玉県', 'サイタマケン', '川口市', 'カワグチシ', '飯塚', 'イイヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川口市飯原町', '11', '11203', '3320024', '埼玉県', 'サイタマケン', '川口市', 'カワグチシ', '飯原町', 'イイハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川口市原町', '11', '11203', '3320025', '埼玉県', 'サイタマケン', '川口市', 'カワグチシ', '原町', 'ハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川口市南町', '11', '11203', '3320026', '埼玉県', 'サイタマケン', '川口市', 'カワグチシ', '南町', 'ミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川口市緑町', '11', '11203', '3320027', '埼玉県', 'サイタマケン', '川口市', 'カワグチシ', '緑町', 'ミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川口市宮町', '11', '11203', '3320028', '埼玉県', 'サイタマケン', '川口市', 'カワグチシ', '宮町', 'ミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川口市荒川町', '11', '11203', '3320029', '埼玉県', 'サイタマケン', '川口市', 'カワグチシ', '荒川町', 'アラカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川口市青木', '11', '11203', '3320031', '埼玉県', 'サイタマケン', '川口市', 'カワグチシ', '青木', 'アオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川口市中青木', '11', '11203', '3320032', '埼玉県', 'サイタマケン', '川口市', 'カワグチシ', '中青木', 'ナカアオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川口市並木元町', '11', '11203', '3320033', '埼玉県', 'サイタマケン', '川口市', 'カワグチシ', '並木元町', 'ナミキモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川口市並木', '11', '11203', '3320034', '埼玉県', 'サイタマケン', '川口市', 'カワグチシ', '並木', 'ナミキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川口市西青木', '11', '11203', '3320035', '埼玉県', 'サイタマケン', '川口市', 'カワグチシ', '西青木', 'ニシアオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川口市東川口', '11', '11203', '3330801', '埼玉県', 'サイタマケン', '川口市', 'カワグチシ', '東川口', 'ヒガシカワグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川口市戸塚東', '11', '11203', '3330802', '埼玉県', 'サイタマケン', '川口市', 'カワグチシ', '戸塚東', 'トヅカヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川口市藤兵衛新田', '11', '11203', '3330803', '埼玉県', 'サイタマケン', '川口市', 'カワグチシ', '藤兵衛新田', 'トウベエシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川口市久左衛門新田', '11', '11203', '3330804', '埼玉県', 'サイタマケン', '川口市', 'カワグチシ', '久左衛門新田', 'キュウザエモンシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川口市戸塚鋏町', '11', '11203', '3330805', '埼玉県', 'サイタマケン', '川口市', 'カワグチシ', '戸塚鋏町', 'トヅカハサミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川口市戸塚境町', '11', '11203', '3330806', '埼玉県', 'サイタマケン', '川口市', 'カワグチシ', '戸塚境町', 'トヅカサカイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川口市長蔵', '11', '11203', '3330807', '埼玉県', 'サイタマケン', '川口市', 'カワグチシ', '長蔵', 'チョウゾウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川口市長蔵新田', '11', '11203', '3330808', '埼玉県', 'サイタマケン', '川口市', 'カワグチシ', '長蔵新田', 'チョウゾウシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川口市戸塚', '11', '11203', '3330811', '埼玉県', 'サイタマケン', '川口市', 'カワグチシ', '戸塚', 'トヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川口市安行西立野', '11', '11203', '3330812', '埼玉県', 'サイタマケン', '川口市', 'カワグチシ', '安行西立野', 'アンギョウニシタテノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川口市西立野', '11', '11203', '3330813', '埼玉県', 'サイタマケン', '川口市', 'カワグチシ', '西立野', 'ニシタテノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川口市行衛', '11', '11203', '3330814', '埼玉県', 'サイタマケン', '川口市', 'カワグチシ', '行衛', 'ギョエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川口市北原台', '11', '11203', '3330815', '埼玉県', 'サイタマケン', '川口市', 'カワグチシ', '北原台', 'キタハラダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川口市差間', '11', '11203', '3330816', '埼玉県', 'サイタマケン', '川口市', 'カワグチシ', '差間', 'サシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川口市東内野', '11', '11203', '3330821', '埼玉県', 'サイタマケン', '川口市', 'カワグチシ', '東内野', 'ヒガシウチノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川口市源左衛門新田', '11', '11203', '3330822', '埼玉県', 'サイタマケン', '川口市', 'カワグチシ', '源左衛門新田', 'ゲンザエモンシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川口市石神', '11', '11203', '3330823', '埼玉県', 'サイタマケン', '川口市', 'カワグチシ', '石神', 'イシガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川口市赤芝新田', '11', '11203', '3330824', '埼玉県', 'サイタマケン', '川口市', 'カワグチシ', '赤芝新田', 'アカシバシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川口市赤山', '11', '11203', '3330825', '埼玉県', 'サイタマケン', '川口市', 'カワグチシ', '赤山', 'アカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川口市新井宿', '11', '11203', '3330826', '埼玉県', 'サイタマケン', '川口市', 'カワグチシ', '新井宿', 'アライジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川口市木曽呂', '11', '11203', '3330831', '埼玉県', 'サイタマケン', '川口市', 'カワグチシ', '木曽呂', 'キゾロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川口市神戸', '11', '11203', '3330832', '埼玉県', 'サイタマケン', '川口市', 'カワグチシ', '神戸', 'ゴウド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川口市西新井宿', '11', '11203', '3330833', '埼玉県', 'サイタマケン', '川口市', 'カワグチシ', '西新井宿', 'ニシアライジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川口市安行領根岸', '11', '11203', '3330834', '埼玉県', 'サイタマケン', '川口市', 'カワグチシ', '安行領根岸', 'アンギョウリョウネギシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川口市道合', '11', '11203', '3330835', '埼玉県', 'サイタマケン', '川口市', 'カワグチシ', '道合', 'ミチアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川口市安行領在家', '11', '11203', '3330836', '埼玉県', 'サイタマケン', '川口市', 'カワグチシ', '安行領在家', 'アンギョウリョウザイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川口市前川町', '11', '11203', '3330841', '埼玉県', 'サイタマケン', '川口市', 'カワグチシ', '前川町', 'マエカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川口市前川', '11', '11203', '3330842', '埼玉県', 'サイタマケン', '川口市', 'カワグチシ', '前川', 'マエカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川口市前上町', '11', '11203', '3330843', '埼玉県', 'サイタマケン', '川口市', 'カワグチシ', '前上町', 'マエカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川口市上青木', '11', '11203', '3330844', '埼玉県', 'サイタマケン', '川口市', 'カワグチシ', '上青木', 'カミアオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川口市上青木西', '11', '11203', '3330845', '埼玉県', 'サイタマケン', '川口市', 'カワグチシ', '上青木西', 'カミアオキニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川口市南前川', '11', '11203', '3330846', '埼玉県', 'サイタマケン', '川口市', 'カワグチシ', '南前川', 'ミナミマエカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川口市芝中田', '11', '11203', '3330847', '埼玉県', 'サイタマケン', '川口市', 'カワグチシ', '芝中田', 'シバナカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川口市芝下', '11', '11203', '3330848', '埼玉県', 'サイタマケン', '川口市', 'カワグチシ', '芝下', 'シバシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川口市芝新町', '11', '11203', '3330851', '埼玉県', 'サイタマケン', '川口市', 'カワグチシ', '芝新町', 'シバシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川口市芝樋ノ爪', '11', '11203', '3330852', '埼玉県', 'サイタマケン', '川口市', 'カワグチシ', '芝樋ノ爪', 'シバヒノツメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川口市芝園町', '11', '11203', '3330853', '埼玉県', 'サイタマケン', '川口市', 'カワグチシ', '芝園町', 'シバゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川口市芝富士', '11', '11203', '3330854', '埼玉県', 'サイタマケン', '川口市', 'カワグチシ', '芝富士', 'シバフジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川口市芝西', '11', '11203', '3330855', '埼玉県', 'サイタマケン', '川口市', 'カワグチシ', '芝西', 'シバニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川口市芝塚原', '11', '11203', '3330856', '埼玉県', 'サイタマケン', '川口市', 'カワグチシ', '芝塚原', 'シバツカバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川口市小谷場', '11', '11203', '3330857', '埼玉県', 'サイタマケン', '川口市', 'カワグチシ', '小谷場', 'コヤバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川口市柳崎', '11', '11203', '3330861', '埼玉県', 'サイタマケン', '川口市', 'カワグチシ', '柳崎', 'ヤナギサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川口市北園町', '11', '11203', '3330862', '埼玉県', 'サイタマケン', '川口市', 'カワグチシ', '北園町', 'キタゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川口市在家町', '11', '11203', '3330863', '埼玉県', 'サイタマケン', '川口市', 'カワグチシ', '在家町', 'ザイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川口市柳根町', '11', '11203', '3330864', '埼玉県', 'サイタマケン', '川口市', 'カワグチシ', '柳根町', 'ヤナネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川口市伊刈', '11', '11203', '3330865', '埼玉県', 'サイタマケン', '川口市', 'カワグチシ', '伊刈', 'イカリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川口市芝', '11', '11203', '3330866', '埼玉県', 'サイタマケン', '川口市', 'カワグチシ', '芝', 'シバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川口市芝東町', '11', '11203', '3330867', '埼玉県', 'サイタマケン', '川口市', 'カワグチシ', '芝東町', 'シバヒガシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川口市芝高木', '11', '11203', '3330868', '埼玉県', 'サイタマケン', '川口市', 'カワグチシ', '芝高木', 'シバタカギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川口市芝宮根町', '11', '11203', '3330869', '埼玉県', 'サイタマケン', '川口市', 'カワグチシ', '芝宮根町', 'シバミヤネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鳩ケ谷市', '11', '11226', '3340000', '埼玉県', 'サイタマケン', '鳩ケ谷市', 'ハトガヤシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('26094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鳩ケ谷市桜町', '11', '11226', '3340001', '埼玉県', 'サイタマケン', '鳩ケ谷市', 'ハトガヤシ', '桜町', 'サクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鳩ケ谷市本町', '11', '11226', '3340002', '埼玉県', 'サイタマケン', '鳩ケ谷市', 'ハトガヤシ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鳩ケ谷市坂下町', '11', '11226', '3340003', '埼玉県', 'サイタマケン', '鳩ケ谷市', 'ハトガヤシ', '坂下町', 'サカシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鳩ケ谷市辻', '11', '11226', '3340004', '埼玉県', 'サイタマケン', '鳩ケ谷市', 'ハトガヤシ', '辻', 'ツジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鳩ケ谷市里', '11', '11226', '3340005', '埼玉県', 'サイタマケン', '鳩ケ谷市', 'ハトガヤシ', '里', 'サト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鳩ケ谷市三ツ和', '11', '11226', '3340011', '埼玉県', 'サイタマケン', '鳩ケ谷市', 'ハトガヤシ', '三ツ和', 'ミツワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鳩ケ谷市八幡木', '11', '11226', '3340012', '埼玉県', 'サイタマケン', '鳩ケ谷市', 'ハトガヤシ', '八幡木', 'ハチマンギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鳩ケ谷市南', '11', '11226', '3340013', '埼玉県', 'サイタマケン', '鳩ケ谷市', 'ハトガヤシ', '南', 'ミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鳩ケ谷市前田', '11', '11226', '3340014', '埼玉県', 'サイタマケン', '鳩ケ谷市', 'ハトガヤシ', '前田', 'マエタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鳩ケ谷市緑町', '11', '11226', '3340015', '埼玉県', 'サイタマケン', '鳩ケ谷市', 'ハトガヤシ', '緑町', 'ミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川口市安行藤八', '11', '11203', '3340051', '埼玉県', 'サイタマケン', '川口市', 'カワグチシ', '安行藤八', 'アンギョウトウハチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川口市安行出羽', '11', '11203', '3340052', '埼玉県', 'サイタマケン', '川口市', 'カワグチシ', '安行出羽', 'アンギョウデワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川口市安行吉蔵', '11', '11203', '3340053', '埼玉県', 'サイタマケン', '川口市', 'カワグチシ', '安行吉蔵', 'アンギョウキチゾウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川口市安行北谷', '11', '11203', '3340054', '埼玉県', 'サイタマケン', '川口市', 'カワグチシ', '安行北谷', 'アンギョウキタヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川口市安行小山', '11', '11203', '3340055', '埼玉県', 'サイタマケン', '川口市', 'カワグチシ', '安行小山', 'アンギョウコヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川口市峯', '11', '11203', '3340056', '埼玉県', 'サイタマケン', '川口市', 'カワグチシ', '峯', 'ミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川口市安行原', '11', '11203', '3340057', '埼玉県', 'サイタマケン', '川口市', 'カワグチシ', '安行原', 'アンギョウハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川口市安行領家', '11', '11203', '3340058', '埼玉県', 'サイタマケン', '川口市', 'カワグチシ', '安行領家', 'アンギョウリョウケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川口市安行', '11', '11203', '3340059', '埼玉県', 'サイタマケン', '川口市', 'カワグチシ', '安行', 'アンギョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川口市新堀', '11', '11203', '3340061', '埼玉県', 'サイタマケン', '川口市', 'カワグチシ', '新堀', 'ニイホリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川口市榛松', '11', '11203', '3340062', '埼玉県', 'サイタマケン', '川口市', 'カワグチシ', '榛松', 'ハエマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川口市東本郷', '11', '11203', '3340063', '埼玉県', 'サイタマケン', '川口市', 'カワグチシ', '東本郷', 'ヒガシホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川口市蓮沼', '11', '11203', '3340064', '埼玉県', 'サイタマケン', '川口市', 'カワグチシ', '蓮沼', 'ハスヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川口市前野宿', '11', '11203', '3340065', '埼玉県', 'サイタマケン', '川口市', 'カワグチシ', '前野宿', 'マエノシュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川口市東貝塚', '11', '11203', '3340066', '埼玉県', 'サイタマケン', '川口市', 'カワグチシ', '東貝塚', 'ヒガシカイヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川口市大竹', '11', '11203', '3340067', '埼玉県', 'サイタマケン', '川口市', 'カワグチシ', '大竹', 'オオタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川口市新堀町', '11', '11203', '3340068', '埼玉県', 'サイタマケン', '川口市', 'カワグチシ', '新堀町', 'ニイホリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川口市安行慈林', '11', '11203', '3340071', '埼玉県', 'サイタマケン', '川口市', 'カワグチシ', '安行慈林', 'アンギョウジリン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川口市安行吉岡', '11', '11203', '3340072', '埼玉県', 'サイタマケン', '川口市', 'カワグチシ', '安行吉岡', 'アンギョウヨシオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川口市赤井', '11', '11203', '3340073', '埼玉県', 'サイタマケン', '川口市', 'カワグチシ', '赤井', 'アカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川口市江戸', '11', '11203', '3340074', '埼玉県', 'サイタマケン', '川口市', 'カワグチシ', '江戸', 'エド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川口市江戸袋', '11', '11203', '3340075', '埼玉県', 'サイタマケン', '川口市', 'カワグチシ', '江戸袋', 'エドブクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川口市本蓮', '11', '11203', '3340076', '埼玉県', 'サイタマケン', '川口市', 'カワグチシ', '本蓮', 'ホンバス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県蕨市', '11', '11223', '3350000', '埼玉県', 'サイタマケン', '蕨市', 'ワラビシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('26130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県戸田市', '11', '11224', '3350000', '埼玉県', 'サイタマケン', '戸田市', 'トダシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('26131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県蕨市北町', '11', '11223', '3350001', '埼玉県', 'サイタマケン', '蕨市', 'ワラビシ', '北町', 'キタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県蕨市塚越', '11', '11223', '3350002', '埼玉県', 'サイタマケン', '蕨市', 'ワラビシ', '塚越', 'ツカゴシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県蕨市南町', '11', '11223', '3350003', '埼玉県', 'サイタマケン', '蕨市', 'ワラビシ', '南町', 'ミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県蕨市中央', '11', '11223', '3350004', '埼玉県', 'サイタマケン', '蕨市', 'ワラビシ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県蕨市錦町', '11', '11223', '3350005', '埼玉県', 'サイタマケン', '蕨市', 'ワラビシ', '錦町', 'ニシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県戸田市下戸田', '11', '11224', '3350011', '埼玉県', 'サイタマケン', '戸田市', 'トダシ', '下戸田', 'シモトダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県戸田市中町', '11', '11224', '3350012', '埼玉県', 'サイタマケン', '戸田市', 'トダシ', '中町', 'ナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県戸田市喜沢', '11', '11224', '3350013', '埼玉県', 'サイタマケン', '戸田市', 'トダシ', '喜沢', 'キザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県戸田市喜沢南', '11', '11224', '3350014', '埼玉県', 'サイタマケン', '戸田市', 'トダシ', '喜沢南', 'キザワミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県戸田市川岸', '11', '11224', '3350015', '埼玉県', 'サイタマケン', '戸田市', 'トダシ', '川岸', 'カワギシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県戸田市下前', '11', '11224', '3350016', '埼玉県', 'サイタマケン', '戸田市', 'トダシ', '下前', 'シモマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県戸田市新曽', '11', '11224', '3350021', '埼玉県', 'サイタマケン', '戸田市', 'トダシ', '新曽', 'ニイゾ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県戸田市上戸田', '11', '11224', '3350022', '埼玉県', 'サイタマケン', '戸田市', 'トダシ', '上戸田', 'カミトダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県戸田市本町', '11', '11224', '3350023', '埼玉県', 'サイタマケン', '戸田市', 'トダシ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県戸田市戸田公園', '11', '11224', '3350024', '埼玉県', 'サイタマケン', '戸田市', 'トダシ', '戸田公園', 'トダコウエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県戸田市南町', '11', '11224', '3350025', '埼玉県', 'サイタマケン', '戸田市', 'トダシ', '南町', 'ミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県戸田市新曽南', '11', '11224', '3350026', '埼玉県', 'サイタマケン', '戸田市', 'トダシ', '新曽南', 'ニイゾミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県戸田市氷川町', '11', '11224', '3350027', '埼玉県', 'サイタマケン', '戸田市', 'トダシ', '氷川町', 'ヒカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県戸田市美女木', '11', '11224', '3350031', '埼玉県', 'サイタマケン', '戸田市', 'トダシ', '美女木', 'ビジョギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県戸田市美女木東', '11', '11224', '3350032', '埼玉県', 'サイタマケン', '戸田市', 'トダシ', '美女木東', 'ビジョギヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県戸田市笹目北町', '11', '11224', '3350033', '埼玉県', 'サイタマケン', '戸田市', 'トダシ', '笹目北町', 'ササメキタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県戸田市笹目', '11', '11224', '3350034', '埼玉県', 'サイタマケン', '戸田市', 'トダシ', '笹目', 'ササメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県戸田市笹目南町', '11', '11224', '3350035', '埼玉県', 'サイタマケン', '戸田市', 'トダシ', '笹目南町', 'ササメミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県戸田市早瀬', '11', '11224', '3350036', '埼玉県', 'サイタマケン', '戸田市', 'トダシ', '早瀬', 'ハヤセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県戸田市下笹目', '11', '11224', '3350037', '埼玉県', 'サイタマケン', '戸田市', 'トダシ', '下笹目', 'シモササメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市南区', '11', '11108', '3360000', '埼玉県', 'サイタマケン', 'さいたま市南区', 'サイタマシミナミク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('26171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市南区太田窪', '11', '11108', '3360015', '埼玉県', 'サイタマケン', 'さいたま市南区', 'サイタマシミナミク', '太田窪', 'ダイタクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市南区大谷場', '11', '11108', '3360016', '埼玉県', 'サイタマケン', 'さいたま市南区', 'サイタマシミナミク', '大谷場', 'オオヤバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市南区南浦和', '11', '11108', '3360017', '埼玉県', 'サイタマケン', 'さいたま市南区', 'サイタマシミナミク', '南浦和', 'ミナミウラワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市南区南本町', '11', '11108', '3360018', '埼玉県', 'サイタマケン', 'さいたま市南区', 'サイタマシミナミク', '南本町', 'ミナミホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市南区別所', '11', '11108', '3360021', '埼玉県', 'サイタマケン', 'さいたま市南区', 'サイタマシミナミク', '別所', 'ベッショ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市南区白幡', '11', '11108', '3360022', '埼玉県', 'サイタマケン', 'さいたま市南区', 'サイタマシミナミク', '白幡', 'シラハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市南区神明', '11', '11108', '3360023', '埼玉県', 'サイタマケン', 'さいたま市南区', 'サイタマシミナミク', '神明', 'シンメイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市南区根岸', '11', '11108', '3360024', '埼玉県', 'サイタマケン', 'さいたま市南区', 'サイタマシミナミク', '根岸', 'ネギシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市南区文蔵', '11', '11108', '3360025', '埼玉県', 'サイタマケン', 'さいたま市南区', 'サイタマシミナミク', '文蔵', 'ブゾウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市南区辻', '11', '11108', '3360026', '埼玉県', 'サイタマケン', 'さいたま市南区', 'サイタマシミナミク', '辻', 'ツジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市南区沼影', '11', '11108', '3360027', '埼玉県', 'サイタマケン', 'さいたま市南区', 'サイタマシミナミク', '沼影', 'ヌマカゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市南区鹿手袋', '11', '11108', '3360031', '埼玉県', 'サイタマケン', 'さいたま市南区', 'サイタマシミナミク', '鹿手袋', 'シカテブクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市南区四谷', '11', '11108', '3360032', '埼玉県', 'サイタマケン', 'さいたま市南区', 'サイタマシミナミク', '四谷', 'ヨツヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市南区曲本', '11', '11108', '3360033', '埼玉県', 'サイタマケン', 'さいたま市南区', 'サイタマシミナミク', '曲本', 'マガモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市南区内谷', '11', '11108', '3360034', '埼玉県', 'サイタマケン', 'さいたま市南区', 'サイタマシミナミク', '内谷', 'ウチヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市南区松本', '11', '11108', '3360035', '埼玉県', 'サイタマケン', 'さいたま市南区', 'サイタマシミナミク', '松本', 'マツモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市南区堤外', '11', '11108', '3360036', '埼玉県', 'サイタマケン', 'さいたま市南区', 'サイタマシミナミク', '堤外', 'テイガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市南区関', '11', '11108', '3360038', '埼玉県', 'サイタマケン', 'さいたま市南区', 'サイタマシミナミク', '関', 'セキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市南区広ケ谷戸', '11', '11108', '3360041', '埼玉県', 'サイタマケン', 'さいたま市南区', 'サイタマシミナミク', '広ケ谷戸', 'ヒロガヤト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市南区大谷口', '11', '11108', '3360042', '埼玉県', 'サイタマケン', 'さいたま市南区', 'サイタマシミナミク', '大谷口', 'オオヤグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市南区円正寺', '11', '11108', '3360043', '埼玉県', 'サイタマケン', 'さいたま市南区', 'サイタマシミナミク', '円正寺', 'エンショウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市緑区', '11', '11109', '3360900', '埼玉県', 'サイタマケン', 'さいたま市緑区', 'サイタマシミドリク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('26193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市緑区山崎', '11', '11109', '3360903', '埼玉県', 'サイタマケン', 'さいたま市緑区', 'サイタマシミドリク', '山崎', 'ヤマザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市緑区大道', '11', '11109', '3360905', '埼玉県', 'サイタマケン', 'さいたま市緑区', 'サイタマシミドリク', '大道', 'ダイドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市緑区三浦', '11', '11109', '3360906', '埼玉県', 'サイタマケン', 'さいたま市緑区', 'サイタマシミドリク', '三浦', 'ミウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市緑区道祖土', '11', '11109', '3360907', '埼玉県', 'サイタマケン', 'さいたま市緑区', 'サイタマシミドリク', '道祖土', 'サイド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市緑区三室', '11', '11109', '3360911', '埼玉県', 'サイタマケン', 'さいたま市緑区', 'サイタマシミドリク', '三室', 'ミムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市緑区馬場', '11', '11109', '3360912', '埼玉県', 'サイタマケン', 'さいたま市緑区', 'サイタマシミドリク', '馬場', 'バンバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市緑区新宿', '11', '11109', '3360913', '埼玉県', 'サイタマケン', 'さいたま市緑区', 'サイタマシミドリク', '新宿', 'シンジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市緑区宮後', '11', '11109', '3360914', '埼玉県', 'サイタマケン', 'さいたま市緑区', 'サイタマシミドリク', '宮後', 'ミヤウシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市緑区見沼', '11', '11109', '3360915', '埼玉県', 'サイタマケン', 'さいたま市緑区', 'サイタマシミドリク', '見沼', 'ミヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市緑区宮本', '11', '11109', '3360916', '埼玉県', 'サイタマケン', 'さいたま市緑区', 'サイタマシミドリク', '宮本', 'ミヤモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市緑区芝原', '11', '11109', '3360917', '埼玉県', 'サイタマケン', 'さいたま市緑区', 'サイタマシミドリク', '芝原', 'シバハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市緑区松木', '11', '11109', '3360918', '埼玉県', 'サイタマケン', 'さいたま市緑区', 'サイタマシミドリク', '松木', 'マツキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市緑区井沼方', '11', '11109', '3360921', '埼玉県', 'サイタマケン', 'さいたま市緑区', 'サイタマシミドリク', '井沼方', 'イヌマカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市緑区大牧', '11', '11109', '3360922', '埼玉県', 'サイタマケン', 'さいたま市緑区', 'サイタマシミドリク', '大牧', 'オオマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市緑区大間木', '11', '11109', '3360923', '埼玉県', 'サイタマケン', 'さいたま市緑区', 'サイタマシミドリク', '大間木', 'オオマギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市緑区蓮見新田', '11', '11109', '3360924', '埼玉県', 'サイタマケン', 'さいたま市緑区', 'サイタマシミドリク', '蓮見新田', 'ハスミシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市緑区下山口新田', '11', '11109', '3360925', '埼玉県', 'サイタマケン', 'さいたま市緑区', 'サイタマシミドリク', '下山口新田', 'シモヤマグチシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市緑区東浦和', '11', '11109', '3360926', '埼玉県', 'サイタマケン', 'さいたま市緑区', 'サイタマシミドリク', '東浦和', 'ヒガシウラワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市緑区原山', '11', '11109', '3360931', '埼玉県', 'サイタマケン', 'さいたま市緑区', 'サイタマシミドリク', '原山', 'ハラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市緑区中尾', '11', '11109', '3360932', '埼玉県', 'サイタマケン', 'さいたま市緑区', 'サイタマシミドリク', '中尾', 'ナカオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市緑区大谷口', '11', '11109', '3360934', '埼玉県', 'サイタマケン', 'さいたま市緑区', 'サイタマシミドリク', '大谷口', 'オオヤグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市緑区太田窪', '11', '11109', '3360936', '埼玉県', 'サイタマケン', 'さいたま市緑区', 'サイタマシミドリク', '太田窪', 'ダイタクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市緑区玄蕃新田', '11', '11109', '3360961', '埼玉県', 'サイタマケン', 'さいたま市緑区', 'サイタマシミドリク', '玄蕃新田', 'ゲンバシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市緑区下野田', '11', '11109', '3360962', '埼玉県', 'サイタマケン', 'さいたま市緑区', 'サイタマシミドリク', '下野田', 'シモノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市緑区大門', '11', '11109', '3360963', '埼玉県', 'サイタマケン', 'さいたま市緑区', 'サイタマシミドリク', '大門', 'ダイモン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市緑区東大門', '11', '11109', '3360964', '埼玉県', 'サイタマケン', 'さいたま市緑区', 'サイタマシミドリク', '東大門', 'ヒガシダイモン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市緑区間宮', '11', '11109', '3360965', '埼玉県', 'サイタマケン', 'さいたま市緑区', 'サイタマシミドリク', '間宮', 'マミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市緑区北原', '11', '11109', '3360966', '埼玉県', 'サイタマケン', 'さいたま市緑区', 'サイタマシミドリク', '北原', 'キタハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市緑区高畑', '11', '11109', '3360971', '埼玉県', 'サイタマケン', 'さいたま市緑区', 'サイタマシミドリク', '高畑', 'タカバタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市緑区中野田', '11', '11109', '3360972', '埼玉県', 'サイタマケン', 'さいたま市緑区', 'サイタマシミドリク', '中野田', 'ナカノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市緑区南部領辻', '11', '11109', '3360973', '埼玉県', 'サイタマケン', 'さいたま市緑区', 'サイタマシミドリク', '南部領辻', 'ナンブリョウツジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市緑区大崎', '11', '11109', '3360974', '埼玉県', 'サイタマケン', 'さいたま市緑区', 'サイタマシミドリク', '大崎', 'オオサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市緑区代山', '11', '11109', '3360975', '埼玉県', 'サイタマケン', 'さいたま市緑区', 'サイタマシミドリク', '代山', 'ダイヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市緑区寺山', '11', '11109', '3360976', '埼玉県', 'サイタマケン', 'さいたま市緑区', 'サイタマシミドリク', '寺山', 'テラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市緑区上野田', '11', '11109', '3360977', '埼玉県', 'サイタマケン', 'さいたま市緑区', 'サイタマシミドリク', '上野田', 'カミノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市見沼区', '11', '11104', '3370000', '埼玉県', 'サイタマケン', 'さいたま市見沼区', 'サイタマシミヌマク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('26250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市見沼区丸ケ崎', '11', '11104', '3370001', '埼玉県', 'サイタマケン', 'さいたま市見沼区', 'サイタマシミヌマク', '丸ケ崎', 'マルガサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市見沼区春野', '11', '11104', '3370002', '埼玉県', 'サイタマケン', 'さいたま市見沼区', 'サイタマシミヌマク', '春野', 'ハルノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市見沼区深作', '11', '11104', '3370003', '埼玉県', 'サイタマケン', 'さいたま市見沼区', 'サイタマシミヌマク', '深作', 'フカサク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市見沼区卸町', '11', '11104', '3370004', '埼玉県', 'サイタマケン', 'さいたま市見沼区', 'サイタマシミヌマク', '卸町', 'オロシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市見沼区小深作', '11', '11104', '3370005', '埼玉県', 'サイタマケン', 'さいたま市見沼区', 'サイタマシミヌマク', '小深作', 'コフカサク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市見沼区島町', '11', '11104', '3370006', '埼玉県', 'サイタマケン', 'さいたま市見沼区', 'サイタマシミヌマク', '島町', 'シマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市見沼区丸ケ崎町', '11', '11104', '3370007', '埼玉県', 'サイタマケン', 'さいたま市見沼区', 'サイタマシミヌマク', '丸ケ崎町', 'マルガサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市見沼区春岡', '11', '11104', '3370008', '埼玉県', 'サイタマケン', 'さいたま市見沼区', 'サイタマシミヌマク', '春岡', 'ハルオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市見沼区宮ケ谷塔', '11', '11104', '3370011', '埼玉県', 'サイタマケン', 'さいたま市見沼区', 'サイタマシミヌマク', '宮ケ谷塔', 'ミヤガヤトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市見沼区東宮下', '11', '11104', '3370012', '埼玉県', 'サイタマケン', 'さいたま市見沼区', 'サイタマシミヌマク', '東宮下', 'ヒガシミヤシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市見沼区新堤', '11', '11104', '3370013', '埼玉県', 'サイタマケン', 'さいたま市見沼区', 'サイタマシミヌマク', '新堤', 'ニイヅツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市見沼区大谷', '11', '11104', '3370014', '埼玉県', 'サイタマケン', 'さいたま市見沼区', 'サイタマシミヌマク', '大谷', 'オオヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市見沼区蓮沼', '11', '11104', '3370015', '埼玉県', 'サイタマケン', 'さいたま市見沼区', 'サイタマシミヌマク', '蓮沼', 'ハスヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市見沼区東門前', '11', '11104', '3370016', '埼玉県', 'サイタマケン', 'さいたま市見沼区', 'サイタマシミヌマク', '東門前', 'ヒガシモンゼン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市見沼区風渡野', '11', '11104', '3370017', '埼玉県', 'サイタマケン', 'さいたま市見沼区', 'サイタマシミヌマク', '風渡野', 'フットノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市見沼区膝子', '11', '11104', '3370021', '埼玉県', 'サイタマケン', 'さいたま市見沼区', 'サイタマシミヌマク', '膝子', 'ヒザコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市見沼区加田屋', '11', '11104', '3370022', '埼玉県', 'サイタマケン', 'さいたま市見沼区', 'サイタマシミヌマク', '加田屋', 'カタヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市見沼区片柳東', '11', '11104', '3370023', '埼玉県', 'サイタマケン', 'さいたま市見沼区', 'サイタマシミヌマク', '片柳東', 'カタヤナギヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市見沼区片柳', '11', '11104', '3370024', '埼玉県', 'サイタマケン', 'さいたま市見沼区', 'サイタマシミヌマク', '片柳', 'カタヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市見沼区山', '11', '11104', '3370025', '埼玉県', 'サイタマケン', 'さいたま市見沼区', 'サイタマシミヌマク', '山', 'ヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市見沼区染谷', '11', '11104', '3370026', '埼玉県', 'サイタマケン', 'さいたま市見沼区', 'サイタマシミヌマク', '染谷', 'ソメヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市見沼区加田屋新田', '11', '11104', '3370027', '埼玉県', 'サイタマケン', 'さいたま市見沼区', 'サイタマシミヌマク', '加田屋新田', 'カタヤシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市見沼区笹丸', '11', '11104', '3370031', '埼玉県', 'サイタマケン', 'さいたま市見沼区', 'サイタマシミヌマク', '笹丸', 'ササマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市見沼区東新井', '11', '11104', '3370032', '埼玉県', 'サイタマケン', 'さいたま市見沼区', 'サイタマシミヌマク', '東新井', 'ヒガシアライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市見沼区御蔵', '11', '11104', '3370033', '埼玉県', 'サイタマケン', 'さいたま市見沼区', 'サイタマシミヌマク', '御蔵', 'ミクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市見沼区西山村新田', '11', '11104', '3370034', '埼玉県', 'サイタマケン', 'さいたま市見沼区', 'サイタマシミヌマク', '西山村新田', 'ニシヤマムラシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市見沼区西山新田', '11', '11104', '3370035', '埼玉県', 'サイタマケン', 'さいたま市見沼区', 'サイタマシミヌマク', '西山新田', 'ニシヤマシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市見沼区見山', '11', '11104', '3370036', '埼玉県', 'サイタマケン', 'さいたま市見沼区', 'サイタマシミヌマク', '見山', 'ミヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市見沼区南中丸', '11', '11104', '3370041', '埼玉県', 'サイタマケン', 'さいたま市見沼区', 'サイタマシミヌマク', '南中丸', 'ミナミナカマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市見沼区南中野', '11', '11104', '3370042', '埼玉県', 'サイタマケン', 'さいたま市見沼区', 'サイタマシミヌマク', '南中野', 'ミナミナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市見沼区中川', '11', '11104', '3370043', '埼玉県', 'サイタマケン', 'さいたま市見沼区', 'サイタマシミヌマク', '中川', 'ナカガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市見沼区上山口新田', '11', '11104', '3370044', '埼玉県', 'サイタマケン', 'さいたま市見沼区', 'サイタマシミヌマク', '上山口新田', 'カミヤマグチシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市見沼区新右エ門新田', '11', '11104', '3370045', '埼玉県', 'サイタマケン', 'さいたま市見沼区', 'サイタマシミヌマク', '新右エ門新田', 'シンウエモンシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市見沼区東大宮', '11', '11104', '3370051', '埼玉県', 'サイタマケン', 'さいたま市見沼区', 'サイタマシミヌマク', '東大宮', 'ヒガシオオミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市見沼区堀崎町', '11', '11104', '3370052', '埼玉県', 'サイタマケン', 'さいたま市見沼区', 'サイタマシミヌマク', '堀崎町', 'ホリサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市見沼区大和田町', '11', '11104', '3370053', '埼玉県', 'サイタマケン', 'さいたま市見沼区', 'サイタマシミヌマク', '大和田町', 'オオワダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市見沼区砂町', '11', '11104', '3370054', '埼玉県', 'サイタマケン', 'さいたま市見沼区', 'サイタマシミヌマク', '砂町', 'スナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市中央区上落合', '11', '11105', '3380001', '埼玉県', 'サイタマケン', 'さいたま市中央区', 'サイタマシチュウオウク', '上落合', 'カミオチアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市中央区下落合', '11', '11105', '3380002', '埼玉県', 'サイタマケン', 'さいたま市中央区', 'サイタマシチュウオウク', '下落合', 'シモオチアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市中央区本町東', '11', '11105', '3380003', '埼玉県', 'サイタマケン', 'さいたま市中央区', 'サイタマシチュウオウク', '本町東', 'ホンマチヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市中央区本町西', '11', '11105', '3380004', '埼玉県', 'サイタマケン', 'さいたま市中央区', 'サイタマシチュウオウク', '本町西', 'ホンマチニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市中央区桜丘', '11', '11105', '3380005', '埼玉県', 'サイタマケン', 'さいたま市中央区', 'サイタマシチュウオウク', '桜丘', 'サクラオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市中央区八王子', '11', '11105', '3380006', '埼玉県', 'サイタマケン', 'さいたま市中央区', 'サイタマシチュウオウク', '八王子', 'ハチオウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市中央区円阿弥', '11', '11105', '3380007', '埼玉県', 'サイタマケン', 'さいたま市中央区', 'サイタマシチュウオウク', '円阿弥', 'エンナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市中央区新中里', '11', '11105', '3380011', '埼玉県', 'サイタマケン', 'さいたま市中央区', 'サイタマシチュウオウク', '新中里', 'シンナカザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市中央区大戸', '11', '11105', '3380012', '埼玉県', 'サイタマケン', 'さいたま市中央区', 'サイタマシチュウオウク', '大戸', 'オオト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市中央区鈴谷', '11', '11105', '3380013', '埼玉県', 'サイタマケン', 'さいたま市中央区', 'サイタマシチュウオウク', '鈴谷', 'スズヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市中央区上峰', '11', '11105', '3380014', '埼玉県', 'サイタマケン', 'さいたま市中央区', 'サイタマシチュウオウク', '上峰', 'ウエミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市桜区', '11', '11106', '3380800', '埼玉県', 'サイタマケン', 'さいたま市桜区', 'サイタマシサクラク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('26304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市桜区白鍬', '11', '11106', '3380811', '埼玉県', 'サイタマケン', 'さいたま市桜区', 'サイタマシサクラク', '白鍬', 'シラクワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市桜区神田', '11', '11106', '3380812', '埼玉県', 'サイタマケン', 'さいたま市桜区', 'サイタマシサクラク', '神田', 'ジンデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市桜区在家', '11', '11106', '3380813', '埼玉県', 'サイタマケン', 'さいたま市桜区', 'サイタマシサクラク', '在家', 'ザイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市桜区宿', '11', '11106', '3380814', '埼玉県', 'サイタマケン', 'さいたま市桜区', 'サイタマシサクラク', '宿', 'シュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市桜区五関', '11', '11106', '3380815', '埼玉県', 'サイタマケン', 'さいたま市桜区', 'サイタマシサクラク', '五関', 'ゴセキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市桜区塚本', '11', '11106', '3380816', '埼玉県', 'サイタマケン', 'さいたま市桜区', 'サイタマシサクラク', '塚本', 'ツカモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市桜区昭和', '11', '11106', '3380817', '埼玉県', 'サイタマケン', 'さいたま市桜区', 'サイタマシサクラク', '昭和', 'ショウワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市桜区山久保', '11', '11106', '3380821', '埼玉県', 'サイタマケン', 'さいたま市桜区', 'サイタマシサクラク', '山久保', 'ヤマクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市桜区中島', '11', '11106', '3380822', '埼玉県', 'サイタマケン', 'さいたま市桜区', 'サイタマシサクラク', '中島', 'ナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市桜区栄和', '11', '11106', '3380823', '埼玉県', 'サイタマケン', 'さいたま市桜区', 'サイタマシサクラク', '栄和', 'サカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市桜区上大久保', '11', '11106', '3380824', '埼玉県', 'サイタマケン', 'さいたま市桜区', 'サイタマシサクラク', '上大久保', 'カミオオクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市桜区下大久保', '11', '11106', '3380825', '埼玉県', 'サイタマケン', 'さいたま市桜区', 'サイタマシサクラク', '下大久保', 'シモオオクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市桜区大久保領家', '11', '11106', '3380826', '埼玉県', 'サイタマケン', 'さいたま市桜区', 'サイタマシサクラク', '大久保領家', 'オオクボリョウケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市桜区南元宿', '11', '11106', '3380831', '埼玉県', 'サイタマケン', 'さいたま市桜区', 'サイタマシサクラク', '南元宿', 'ミナミモトジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市桜区西堀', '11', '11106', '3380832', '埼玉県', 'サイタマケン', 'さいたま市桜区', 'サイタマシサクラク', '西堀', 'ニシボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市桜区桜田', '11', '11106', '3380833', '埼玉県', 'サイタマケン', 'さいたま市桜区', 'サイタマシサクラク', '桜田', 'サクラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市桜区新開', '11', '11106', '3380834', '埼玉県', 'サイタマケン', 'さいたま市桜区', 'サイタマシサクラク', '新開', 'シビラキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市桜区道場', '11', '11106', '3380835', '埼玉県', 'サイタマケン', 'さいたま市桜区', 'サイタマシサクラク', '道場', 'ドウジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市桜区町谷', '11', '11106', '3380836', '埼玉県', 'サイタマケン', 'さいたま市桜区', 'サイタマシサクラク', '町谷', 'マチヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市桜区田島', '11', '11106', '3380837', '埼玉県', 'サイタマケン', 'さいたま市桜区', 'サイタマシサクラク', '田島', 'タジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市岩槻区', '11', '11110', '3390000', '埼玉県', 'サイタマケン', 'さいたま市岩槻区', 'サイタマシイワツキク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('26357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市岩槻区鹿室', '11', '11110', '3390001', '埼玉県', 'サイタマケン', 'さいたま市岩槻区', 'サイタマシイワツキク', '鹿室', 'カナムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市岩槻区裏慈恩寺', '11', '11110', '3390002', '埼玉県', 'サイタマケン', 'さいたま市岩槻区', 'サイタマシイワツキク', '裏慈恩寺', 'ウラジオンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市岩槻区小溝', '11', '11110', '3390003', '埼玉県', 'サイタマケン', 'さいたま市岩槻区', 'サイタマシイワツキク', '小溝', 'コミゾ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市岩槻区徳力', '11', '11110', '3390004', '埼玉県', 'サイタマケン', 'さいたま市岩槻区', 'サイタマシイワツキク', '徳力', 'トクリキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市岩槻区東岩槻', '11', '11110', '3390005', '埼玉県', 'サイタマケン', 'さいたま市岩槻区', 'サイタマシイワツキク', '東岩槻', 'ヒガシイワツキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市岩槻区上里', '11', '11110', '3390006', '埼玉県', 'サイタマケン', 'さいたま市岩槻区', 'サイタマシイワツキク', '上里', 'カミサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市岩槻区諏訪', '11', '11110', '3390007', '埼玉県', 'サイタマケン', 'さいたま市岩槻区', 'サイタマシイワツキク', '諏訪', 'スワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市岩槻区表慈恩寺', '11', '11110', '3390008', '埼玉県', 'サイタマケン', 'さいたま市岩槻区', 'サイタマシイワツキク', '表慈恩寺', 'オモテジオンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市岩槻区慈恩寺', '11', '11110', '3390009', '埼玉県', 'サイタマケン', 'さいたま市岩槻区', 'サイタマシイワツキク', '慈恩寺', 'ジオンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市岩槻区長宮', '11', '11110', '3390011', '埼玉県', 'サイタマケン', 'さいたま市岩槻区', 'サイタマシイワツキク', '長宮', 'ナガミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市岩槻区増長', '11', '11110', '3390012', '埼玉県', 'サイタマケン', 'さいたま市岩槻区', 'サイタマシイワツキク', '増長', 'マシナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市岩槻区大口', '11', '11110', '3390013', '埼玉県', 'サイタマケン', 'さいたま市岩槻区', 'サイタマシイワツキク', '大口', 'オオグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市岩槻区大戸', '11', '11110', '3390014', '埼玉県', 'サイタマケン', 'さいたま市岩槻区', 'サイタマシイワツキク', '大戸', 'オオト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市岩槻区大谷', '11', '11110', '3390015', '埼玉県', 'サイタマケン', 'さいたま市岩槻区', 'サイタマシイワツキク', '大谷', 'オオヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市岩槻区新方須賀', '11', '11110', '3390016', '埼玉県', 'サイタマケン', 'さいたま市岩槻区', 'サイタマシイワツキク', '新方須賀', 'ニイガタスカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市岩槻区大森', '11', '11110', '3390017', '埼玉県', 'サイタマケン', 'さいたま市岩槻区', 'サイタマシイワツキク', '大森', 'オオモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市岩槻区大野島', '11', '11110', '3390018', '埼玉県', 'サイタマケン', 'さいたま市岩槻区', 'サイタマシイワツキク', '大野島', 'オオノジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市岩槻区末田', '11', '11110', '3390021', '埼玉県', 'サイタマケン', 'さいたま市岩槻区', 'サイタマシイワツキク', '末田', 'スエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市岩槻区高曽根', '11', '11110', '3390022', '埼玉県', 'サイタマケン', 'さいたま市岩槻区', 'サイタマシイワツキク', '高曽根', 'タカソネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市岩槻区野孫', '11', '11110', '3390023', '埼玉県', 'サイタマケン', 'さいたま市岩槻区', 'サイタマシイワツキク', '野孫', 'ノマゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市岩槻区釣上', '11', '11110', '3390024', '埼玉県', 'サイタマケン', 'さいたま市岩槻区', 'サイタマシイワツキク', '釣上', 'カギアゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市岩槻区釣上新田', '11', '11110', '3390025', '埼玉県', 'サイタマケン', 'さいたま市岩槻区', 'サイタマシイワツキク', '釣上新田', 'カギアゲシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市岩槻区尾ケ崎新田', '11', '11110', '3390026', '埼玉県', 'サイタマケン', 'さいたま市岩槻区', 'サイタマシイワツキク', '尾ケ崎新田', 'オガサキシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市岩槻区尾ケ崎', '11', '11110', '3390027', '埼玉県', 'サイタマケン', 'さいたま市岩槻区', 'サイタマシイワツキク', '尾ケ崎', 'オガサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市岩槻区飯塚', '11', '11110', '3390031', '埼玉県', 'サイタマケン', 'さいたま市岩槻区', 'サイタマシイワツキク', '飯塚', 'イイヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市岩槻区南下新井', '11', '11110', '3390032', '埼玉県', 'サイタマケン', 'さいたま市岩槻区', 'サイタマシイワツキク', '南下新井', 'ミナミシモアライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市岩槻区黒谷', '11', '11110', '3390033', '埼玉県', 'サイタマケン', 'さいたま市岩槻区', 'サイタマシイワツキク', '黒谷', 'クロヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市岩槻区笹久保', '11', '11110', '3390034', '埼玉県', 'サイタマケン', 'さいたま市岩槻区', 'サイタマシイワツキク', '笹久保', 'ササクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市岩槻区笹久保新田', '11', '11110', '3390035', '埼玉県', 'サイタマケン', 'さいたま市岩槻区', 'サイタマシイワツキク', '笹久保新田', 'ササクボシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市岩槻区横根', '11', '11110', '3390036', '埼玉県', 'サイタマケン', 'さいたま市岩槻区', 'サイタマシイワツキク', '横根', 'ヨコネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市岩槻区浮谷', '11', '11110', '3390037', '埼玉県', 'サイタマケン', 'さいたま市岩槻区', 'サイタマシイワツキク', '浮谷', 'ウキヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市岩槻区村国', '11', '11110', '3390041', '埼玉県', 'サイタマケン', 'さいたま市岩槻区', 'サイタマシイワツキク', '村国', 'ムラクニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市岩槻区府内', '11', '11110', '3390042', '埼玉県', 'サイタマケン', 'さいたま市岩槻区', 'サイタマシイワツキク', '府内', 'フナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市岩槻区城南', '11', '11110', '3390043', '埼玉県', 'サイタマケン', 'さいたま市岩槻区', 'サイタマシイワツキク', '城南', 'ジョウナン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市岩槻区真福寺', '11', '11110', '3390044', '埼玉県', 'サイタマケン', 'さいたま市岩槻区', 'サイタマシイワツキク', '真福寺', 'シンプクジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市岩槻区柏崎', '11', '11110', '3390045', '埼玉県', 'サイタマケン', 'さいたま市岩槻区', 'サイタマシイワツキク', '柏崎', 'カシワザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市岩槻区谷下', '11', '11110', '3390046', '埼玉県', 'サイタマケン', 'さいたま市岩槻区', 'サイタマシイワツキク', '谷下', 'ヤジタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市岩槻区原町', '11', '11110', '3390047', '埼玉県', 'サイタマケン', 'さいたま市岩槻区', 'サイタマシイワツキク', '原町', 'ハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市岩槻区南平野', '11', '11110', '3390051', '埼玉県', 'サイタマケン', 'さいたま市岩槻区', 'サイタマシイワツキク', '南平野', 'ミナミヒラノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市岩槻区太田', '11', '11110', '3390052', '埼玉県', 'サイタマケン', 'さいたま市岩槻区', 'サイタマシイワツキク', '太田', 'オオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市岩槻区城町', '11', '11110', '3390053', '埼玉県', 'サイタマケン', 'さいたま市岩槻区', 'サイタマシイワツキク', '城町', 'シロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市岩槻区仲町', '11', '11110', '3390054', '埼玉県', 'サイタマケン', 'さいたま市岩槻区', 'サイタマシイワツキク', '仲町', 'ナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市岩槻区東町', '11', '11110', '3390055', '埼玉県', 'サイタマケン', 'さいたま市岩槻区', 'サイタマシイワツキク', '東町', 'ヒガシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市岩槻区加倉', '11', '11110', '3390056', '埼玉県', 'サイタマケン', 'さいたま市岩槻区', 'サイタマシイワツキク', '加倉', 'カクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市岩槻区本町', '11', '11110', '3390057', '埼玉県', 'サイタマケン', 'さいたま市岩槻区', 'サイタマシイワツキク', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市岩槻区本丸', '11', '11110', '3390058', '埼玉県', 'サイタマケン', 'さいたま市岩槻区', 'サイタマシイワツキク', '本丸', 'ホンマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市岩槻区岩槻', '11', '11110', '3390061', '埼玉県', 'サイタマケン', 'さいたま市岩槻区', 'サイタマシイワツキク', '岩槻', 'イワツキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市岩槻区南辻', '11', '11110', '3390062', '埼玉県', 'サイタマケン', 'さいたま市岩槻区', 'サイタマシイワツキク', '南辻', 'ミナミツジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市岩槻区美幸町', '11', '11110', '3390063', '埼玉県', 'サイタマケン', 'さいたま市岩槻区', 'サイタマシイワツキク', '美幸町', 'ミユキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市岩槻区日の出町', '11', '11110', '3390064', '埼玉県', 'サイタマケン', 'さいたま市岩槻区', 'サイタマシイワツキク', '日の出町', 'ヒノデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市岩槻区宮町', '11', '11110', '3390065', '埼玉県', 'サイタマケン', 'さいたま市岩槻区', 'サイタマシイワツキク', '宮町', 'ミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市岩槻区愛宕町', '11', '11110', '3390066', '埼玉県', 'サイタマケン', 'さいたま市岩槻区', 'サイタマシイワツキク', '愛宕町', 'アタゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市岩槻区西町', '11', '11110', '3390067', '埼玉県', 'サイタマケン', 'さいたま市岩槻区', 'サイタマシイワツキク', '西町', 'ニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市岩槻区並木', '11', '11110', '3390068', '埼玉県', 'サイタマケン', 'さいたま市岩槻区', 'サイタマシイワツキク', '並木', 'ナミキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市岩槻区箕輪', '11', '11110', '3390069', '埼玉県', 'サイタマケン', 'さいたま市岩槻区', 'サイタマシイワツキク', '箕輪', 'ミノワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市岩槻区相野原', '11', '11110', '3390071', '埼玉県', 'サイタマケン', 'さいたま市岩槻区', 'サイタマシイワツキク', '相野原', 'アイノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市岩槻区古ケ場', '11', '11110', '3390072', '埼玉県', 'サイタマケン', 'さいたま市岩槻区', 'サイタマシイワツキク', '古ケ場', 'コカバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市岩槻区上野', '11', '11110', '3390073', '埼玉県', 'サイタマケン', 'さいたま市岩槻区', 'サイタマシイワツキク', '上野', 'ウエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市岩槻区本宿', '11', '11110', '3390074', '埼玉県', 'サイタマケン', 'さいたま市岩槻区', 'サイタマシイワツキク', '本宿', 'ホンジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市岩槻区金重', '11', '11110', '3390075', '埼玉県', 'サイタマケン', 'さいたま市岩槻区', 'サイタマシイワツキク', '金重', 'カナシゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市岩槻区平林寺', '11', '11110', '3390076', '埼玉県', 'サイタマケン', 'さいたま市岩槻区', 'サイタマシイワツキク', '平林寺', 'ヘイリンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市岩槻区馬込', '11', '11110', '3390077', '埼玉県', 'サイタマケン', 'さいたま市岩槻区', 'サイタマシイワツキク', '馬込', 'マゴメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市岩槻区掛', '11', '11110', '3390078', '埼玉県', 'サイタマケン', 'さいたま市岩槻区', 'サイタマシイワツキク', '掛', 'カケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市岩槻区西原', '11', '11110', '3390081', '埼玉県', 'サイタマケン', 'さいたま市岩槻区', 'サイタマシイワツキク', '西原', 'ニシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県さいたま市岩槻区西原台', '11', '11110', '3390082', '埼玉県', 'サイタマケン', 'さいたま市岩槻区', 'サイタマシイワツキク', '西原台', 'ニシハラダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県十和田市', '02', '02206', '0340000', '青森県', 'アオモリケン', '十和田市', 'トワダシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('26435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県草加市', '11', '11221', '3400000', '埼玉県', 'サイタマケン', '草加市', 'ソウカシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('26436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県草加市柿木町', '11', '11221', '3400001', '埼玉県', 'サイタマケン', '草加市', 'ソウカシ', '柿木町', 'カキノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県草加市青柳', '11', '11221', '3400002', '埼玉県', 'サイタマケン', '草加市', 'ソウカシ', '青柳', 'アオヤギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県草加市稲荷', '11', '11221', '3400003', '埼玉県', 'サイタマケン', '草加市', 'ソウカシ', '稲荷', 'イナリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県草加市弁天', '11', '11221', '3400004', '埼玉県', 'サイタマケン', '草加市', 'ソウカシ', '弁天', 'ベンテン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県草加市中根', '11', '11221', '3400005', '埼玉県', 'サイタマケン', '草加市', 'ソウカシ', '中根', 'ナカネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県草加市八幡町', '11', '11221', '3400006', '埼玉県', 'サイタマケン', '草加市', 'ソウカシ', '八幡町', 'ヤワタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県草加市青柳町', '11', '11221', '3400007', '埼玉県', 'サイタマケン', '草加市', 'ソウカシ', '青柳町', 'アオヤギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県十和田市三本木', '02', '02206', '0340001', '青森県', 'アオモリケン', '十和田市', 'トワダシ', '三本木', 'サンボンギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県草加市栄町', '11', '11221', '3400011', '埼玉県', 'サイタマケン', '草加市', 'ソウカシ', '栄町', 'サカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県草加市神明', '11', '11221', '3400012', '埼玉県', 'サイタマケン', '草加市', 'ソウカシ', '神明', 'シンメイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県草加市松江', '11', '11221', '3400013', '埼玉県', 'サイタマケン', '草加市', 'ソウカシ', '松江', 'マツエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県草加市住吉', '11', '11221', '3400014', '埼玉県', 'サイタマケン', '草加市', 'ソウカシ', '住吉', 'スミヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県草加市高砂', '11', '11221', '3400015', '埼玉県', 'サイタマケン', '草加市', 'ソウカシ', '高砂', 'タカサゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県草加市中央', '11', '11221', '3400016', '埼玉県', 'サイタマケン', '草加市', 'ソウカシ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県草加市吉町', '11', '11221', '3400017', '埼玉県', 'サイタマケン', '草加市', 'ソウカシ', '吉町', 'ヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県十和田市元町西', '02', '02206', '0340002', '青森県', 'アオモリケン', '十和田市', 'トワダシ', '元町西', 'モトマチニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県草加市手代町', '11', '11221', '3400021', '埼玉県', 'サイタマケン', '草加市', 'ソウカシ', '手代町', 'テシロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県草加市瀬崎町', '11', '11221', '3400022', '埼玉県', 'サイタマケン', '草加市', 'ソウカシ', '瀬崎町', 'セザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県草加市谷塚町', '11', '11221', '3400023', '埼玉県', 'サイタマケン', '草加市', 'ソウカシ', '谷塚町', 'ヤツカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県草加市谷塚上町', '11', '11221', '3400024', '埼玉県', 'サイタマケン', '草加市', 'ソウカシ', '谷塚上町', 'ヤツカカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県草加市谷塚仲町', '11', '11221', '3400025', '埼玉県', 'サイタマケン', '草加市', 'ソウカシ', '谷塚仲町', 'ヤツカナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県草加市両新田東町', '11', '11221', '3400026', '埼玉県', 'サイタマケン', '草加市', 'ソウカシ', '両新田東町', 'リョウシンデンヒガシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県草加市両新田西町', '11', '11221', '3400027', '埼玉県', 'サイタマケン', '草加市', 'ソウカシ', '両新田西町', 'リョウシンデンニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県十和田市元町東', '02', '02206', '0340003', '青森県', 'アオモリケン', '十和田市', 'トワダシ', '元町東', 'モトマチヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県草加市新里町', '11', '11221', '3400031', '埼玉県', 'サイタマケン', '草加市', 'ソウカシ', '新里町', 'ニッサトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県草加市遊馬町', '11', '11221', '3400032', '埼玉県', 'サイタマケン', '草加市', 'ソウカシ', '遊馬町', 'アスマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県草加市柳島町', '11', '11221', '3400033', '埼玉県', 'サイタマケン', '草加市', 'ソウカシ', '柳島町', 'ヤナギシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県草加市氷川町', '11', '11221', '3400034', '埼玉県', 'サイタマケン', '草加市', 'ソウカシ', '氷川町', 'ヒカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県草加市西町', '11', '11221', '3400035', '埼玉県', 'サイタマケン', '草加市', 'ソウカシ', '西町', 'ニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県草加市苗塚町', '11', '11221', '3400036', '埼玉県', 'サイタマケン', '草加市', 'ソウカシ', '苗塚町', 'ナエヅカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県十和田市ひがしの', '02', '02206', '0340004', '青森県', 'アオモリケン', '十和田市', 'トワダシ', 'ひがしの', 'ヒガシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県草加市松原', '11', '11221', '3400041', '埼玉県', 'サイタマケン', '草加市', 'ソウカシ', '松原', 'マツバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県草加市学園町', '11', '11221', '3400042', '埼玉県', 'サイタマケン', '草加市', 'ソウカシ', '学園町', 'ガクエンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県草加市草加', '11', '11221', '3400043', '埼玉県', 'サイタマケン', '草加市', 'ソウカシ', '草加', 'ソウカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県草加市花栗', '11', '11221', '3400044', '埼玉県', 'サイタマケン', '草加市', 'ソウカシ', '花栗', 'ハナグリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県草加市小山', '11', '11221', '3400045', '埼玉県', 'サイタマケン', '草加市', 'ソウカシ', '小山', 'コヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県草加市北谷', '11', '11221', '3400046', '埼玉県', 'サイタマケン', '草加市', 'ソウカシ', '北谷', 'キタヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県草加市北谷町', '11', '11221', '3400047', '埼玉県', 'サイタマケン', '草加市', 'ソウカシ', '北谷町', 'キタヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県草加市原町', '11', '11221', '3400048', '埼玉県', 'サイタマケン', '草加市', 'ソウカシ', '原町', 'ハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県十和田市一本木沢', '02', '02206', '0340005', '青森県', 'アオモリケン', '十和田市', 'トワダシ', '一本木沢', 'イッポンギサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県草加市長栄町', '11', '11221', '3400051', '埼玉県', 'サイタマケン', '草加市', 'ソウカシ', '長栄町', 'チョウエイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県草加市金明町', '11', '11221', '3400052', '埼玉県', 'サイタマケン', '草加市', 'ソウカシ', '金明町', 'キンメイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県草加市旭町', '11', '11221', '3400053', '埼玉県', 'サイタマケン', '草加市', 'ソウカシ', '旭町', 'アサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県草加市新善町', '11', '11221', '3400054', '埼玉県', 'サイタマケン', '草加市', 'ソウカシ', '新善町', 'シンゼンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県草加市清門町', '11', '11221', '3400055', '埼玉県', 'サイタマケン', '草加市', 'ソウカシ', '清門町', 'セイモンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県草加市新栄町', '11', '11221', '3400056', '埼玉県', 'サイタマケン', '草加市', 'ソウカシ', '新栄町', 'シンエイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県幸手市', '11', '11240', '3400100', '埼玉県', 'サイタマケン', '幸手市', 'サッテシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('26483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県幸手市外国府間', '11', '11240', '3400101', '埼玉県', 'サイタマケン', '幸手市', 'サッテシ', '外国府間', 'ソトゴウマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県幸手市高須賀', '11', '11240', '3400102', '埼玉県', 'サイタマケン', '幸手市', 'サッテシ', '高須賀', 'タカスカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県幸手市内国府間', '11', '11240', '3400103', '埼玉県', 'サイタマケン', '幸手市', 'サッテシ', '内国府間', 'ウチゴウマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県幸手市円藤内', '11', '11240', '3400104', '埼玉県', 'サイタマケン', '幸手市', 'サッテシ', '円藤内', 'エンドウウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県幸手市松石', '11', '11240', '3400105', '埼玉県', 'サイタマケン', '幸手市', 'サッテシ', '松石', 'マツイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県十和田市稲生町', '02', '02206', '0340011', '青森県', 'アオモリケン', '十和田市', 'トワダシ', '稲生町', 'イナオイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県幸手市北', '11', '11240', '3400111', '埼玉県', 'サイタマケン', '幸手市', 'サッテシ', '北', 'キタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県幸手市権現堂', '11', '11240', '3400112', '埼玉県', 'サイタマケン', '幸手市', 'サッテシ', '権現堂', 'ゴンゲンドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県幸手市幸手', '11', '11240', '3400113', '埼玉県', 'サイタマケン', '幸手市', 'サッテシ', '幸手', 'サッテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県幸手市東', '11', '11240', '3400114', '埼玉県', 'サイタマケン', '幸手市', 'サッテシ', '東', 'ヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県幸手市中', '11', '11240', '3400115', '埼玉県', 'サイタマケン', '幸手市', 'サッテシ', '中', 'ナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県幸手市西', '11', '11240', '3400116', '埼玉県', 'サイタマケン', '幸手市', 'サッテシ', '西', 'ニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県十和田市東一番町', '02', '02206', '0340012', '青森県', 'アオモリケン', '十和田市', 'トワダシ', '東一番町', 'ヒガシ01バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県幸手市上吉羽', '11', '11240', '3400121', '埼玉県', 'サイタマケン', '幸手市', 'サッテシ', '上吉羽', 'カミヨシバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県幸手市神明内', '11', '11240', '3400122', '埼玉県', 'サイタマケン', '幸手市', 'サッテシ', '神明内', 'シンメイウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県幸手市木立', '11', '11240', '3400123', '埼玉県', 'サイタマケン', '幸手市', 'サッテシ', '木立', 'キダチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県幸手市上宇和田', '11', '11240', '3400124', '埼玉県', 'サイタマケン', '幸手市', 'サッテシ', '上宇和田', 'カミウワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県幸手市下宇和田', '11', '11240', '3400125', '埼玉県', 'サイタマケン', '幸手市', 'サッテシ', '下宇和田', 'シモウワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県幸手市下吉羽', '11', '11240', '3400126', '埼玉県', 'サイタマケン', '幸手市', 'サッテシ', '下吉羽', 'シモヨシバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県十和田市東十一番町', '02', '02206', '0340013', '青森県', 'アオモリケン', '十和田市', 'トワダシ', '東十一番町', 'ヒガシ11バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県幸手市西関宿', '11', '11240', '3400131', '埼玉県', 'サイタマケン', '幸手市', 'サッテシ', '西関宿', 'ニシセキヤド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県幸手市中島', '11', '11240', '3400132', '埼玉県', 'サイタマケン', '幸手市', 'サッテシ', '中島', 'ナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県幸手市惣新田', '11', '11240', '3400133', '埼玉県', 'サイタマケン', '幸手市', 'サッテシ', '惣新田', 'ソウシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県幸手市花島', '11', '11240', '3400134', '埼玉県', 'サイタマケン', '幸手市', 'サッテシ', '花島', 'ハナジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県幸手市槇野地', '11', '11240', '3400135', '埼玉県', 'サイタマケン', '幸手市', 'サッテシ', '槇野地', 'マキノジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県幸手市細野', '11', '11240', '3400136', '埼玉県', 'サイタマケン', '幸手市', 'サッテシ', '細野', 'ホソノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県十和田市東二十一番町', '02', '02206', '0340014', '青森県', 'アオモリケン', '十和田市', 'トワダシ', '東二十一番町', 'ヒガシ21バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県幸手市平野', '11', '11240', '3400141', '埼玉県', 'サイタマケン', '幸手市', 'サッテシ', '平野', 'ヒラノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県幸手市中野', '11', '11240', '3400142', '埼玉県', 'サイタマケン', '幸手市', 'サッテシ', '中野', 'ナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県幸手市長間', '11', '11240', '3400143', '埼玉県', 'サイタマケン', '幸手市', 'サッテシ', '長間', 'ナガマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県幸手市戸島', '11', '11240', '3400144', '埼玉県', 'サイタマケン', '幸手市', 'サッテシ', '戸島', 'トシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県幸手市平須賀', '11', '11240', '3400145', '埼玉県', 'サイタマケン', '幸手市', 'サッテシ', '平須賀', 'ヒラスカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県幸手市神扇', '11', '11240', '3400146', '埼玉県', 'サイタマケン', '幸手市', 'サッテシ', '神扇', 'カミオウギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県十和田市東二十二番町', '02', '02206', '0340015', '青森県', 'アオモリケン', '十和田市', 'トワダシ', '東二十二番町', 'ヒガシ22バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県幸手市緑台', '11', '11240', '3400151', '埼玉県', 'サイタマケン', '幸手市', 'サッテシ', '緑台', 'ミドリダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県幸手市天神島', '11', '11240', '3400152', '埼玉県', 'サイタマケン', '幸手市', 'サッテシ', '天神島', 'テンジンシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県幸手市吉野', '11', '11240', '3400153', '埼玉県', 'サイタマケン', '幸手市', 'サッテシ', '吉野', 'ヨシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県幸手市栄', '11', '11240', '3400154', '埼玉県', 'サイタマケン', '幸手市', 'サッテシ', '栄', 'サカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県幸手市上高野', '11', '11240', '3400155', '埼玉県', 'サイタマケン', '幸手市', 'サッテシ', '上高野', 'カミタカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県幸手市南', '11', '11240', '3400156', '埼玉県', 'サイタマケン', '幸手市', 'サッテシ', '南', 'ミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県十和田市東十二番町', '02', '02206', '0340016', '青森県', 'アオモリケン', '十和田市', 'トワダシ', '東十二番町', 'ヒガシ12バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県幸手市千塚', '11', '11240', '3400161', '埼玉県', 'サイタマケン', '幸手市', 'サッテシ', '千塚', 'チヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県幸手市下川崎', '11', '11240', '3400162', '埼玉県', 'サイタマケン', '幸手市', 'サッテシ', '下川崎', 'シモカワサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県幸手市中川崎', '11', '11240', '3400163', '埼玉県', 'サイタマケン', '幸手市', 'サッテシ', '中川崎', 'ナカカワサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県幸手市香日向', '11', '11240', '3400164', '埼玉県', 'サイタマケン', '幸手市', 'サッテシ', '香日向', 'カヒナタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県十和田市東二番町', '02', '02206', '0340017', '青森県', 'アオモリケン', '十和田市', 'トワダシ', '東二番町', 'ヒガシ02バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北葛飾郡鷲宮町', '11', '11462', '3400200', '埼玉県', 'サイタマケン', '北葛飾郡鷲宮町', 'キタカツシカグンワシミヤマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('26532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北葛飾郡鷲宮町八甫', '11', '11462', '3400201', '埼玉県', 'サイタマケン', '北葛飾郡鷲宮町', 'キタカツシカグンワシミヤマチ', '八甫', 'ハッポウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北葛飾郡鷲宮町東大輪', '11', '11462', '3400202', '埼玉県', 'サイタマケン', '北葛飾郡鷲宮町', 'キタカツシカグンワシミヤマチ', '東大輪', 'ヒガシオオワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北葛飾郡鷲宮町桜田', '11', '11462', '3400203', '埼玉県', 'サイタマケン', '北葛飾郡鷲宮町', 'キタカツシカグンワシミヤマチ', '桜田', 'サクラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北葛飾郡鷲宮町上川崎', '11', '11462', '3400204', '埼玉県', 'サイタマケン', '北葛飾郡鷲宮町', 'キタカツシカグンワシミヤマチ', '上川崎', 'カミカワサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北葛飾郡鷲宮町外野', '11', '11462', '3400205', '埼玉県', 'サイタマケン', '北葛飾郡鷲宮町', 'キタカツシカグンワシミヤマチ', '外野', 'ソトノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北葛飾郡鷲宮町西大輪', '11', '11462', '3400206', '埼玉県', 'サイタマケン', '北葛飾郡鷲宮町', 'キタカツシカグンワシミヤマチ', '西大輪', 'ニシオオワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県十和田市東二十三番町', '02', '02206', '0340021', '青森県', 'アオモリケン', '十和田市', 'トワダシ', '東二十三番町', 'ヒガシ23バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北葛飾郡鷲宮町上内', '11', '11462', '3400211', '埼玉県', 'サイタマケン', '北葛飾郡鷲宮町', 'キタカツシカグンワシミヤマチ', '上内', 'ウエウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北葛飾郡鷲宮町久本寺', '11', '11462', '3400212', '埼玉県', 'サイタマケン', '北葛飾郡鷲宮町', 'キタカツシカグンワシミヤマチ', '久本寺', 'キュウホンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北葛飾郡鷲宮町中妻', '11', '11462', '3400213', '埼玉県', 'サイタマケン', '北葛飾郡鷲宮町', 'キタカツシカグンワシミヤマチ', '中妻', 'ナカヅマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北葛飾郡鷲宮町葛梅', '11', '11462', '3400214', '埼玉県', 'サイタマケン', '北葛飾郡鷲宮町', 'キタカツシカグンワシミヤマチ', '葛梅', 'クズメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北葛飾郡鷲宮町栄', '11', '11462', '3400215', '埼玉県', 'サイタマケン', '北葛飾郡鷲宮町', 'キタカツシカグンワシミヤマチ', '栄', 'サカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北葛飾郡鷲宮町中央', '11', '11462', '3400216', '埼玉県', 'サイタマケン', '北葛飾郡鷲宮町', 'キタカツシカグンワシミヤマチ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北葛飾郡鷲宮町鷲宮', '11', '11462', '3400217', '埼玉県', 'サイタマケン', '北葛飾郡鷲宮町', 'キタカツシカグンワシミヤマチ', '鷲宮', 'ワシミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北葛飾郡鷲宮町砂原', '11', '11462', '3400218', '埼玉県', 'サイタマケン', '北葛飾郡鷲宮町', 'キタカツシカグンワシミヤマチ', '砂原', 'スナハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県十和田市東二十四番町', '02', '02206', '0340022', '青森県', 'アオモリケン', '十和田市', 'トワダシ', '東二十四番町', 'ヒガシ24バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県十和田市東十三番町', '02', '02206', '0340023', '青森県', 'アオモリケン', '十和田市', 'トワダシ', '東十三番町', 'ヒガシ13バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県十和田市東十四番町', '02', '02206', '0340024', '青森県', 'アオモリケン', '十和田市', 'トワダシ', '東十四番町', 'ヒガシ14バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県十和田市東三番町', '02', '02206', '0340031', '青森県', 'アオモリケン', '十和田市', 'トワダシ', '東三番町', 'ヒガシ03バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県十和田市東四番町', '02', '02206', '0340032', '青森県', 'アオモリケン', '十和田市', 'トワダシ', '東四番町', 'ヒガシ04バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県十和田市東五番町', '02', '02206', '0340033', '青森県', 'アオモリケン', '十和田市', 'トワダシ', '東五番町', 'ヒガシ05バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県十和田市東十五番町', '02', '02206', '0340034', '青森県', 'アオモリケン', '十和田市', 'トワダシ', '東十五番町', 'ヒガシ15バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県十和田市東十六番町', '02', '02206', '0340035', '青森県', 'アオモリケン', '十和田市', 'トワダシ', '東十六番町', 'ヒガシ16バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県十和田市東六番町', '02', '02206', '0340036', '青森県', 'アオモリケン', '十和田市', 'トワダシ', '東六番町', 'ヒガシ06バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県十和田市穂並町', '02', '02206', '0340037', '青森県', 'アオモリケン', '十和田市', 'トワダシ', '穂並町', 'ホナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県十和田市西六番町', '02', '02206', '0340038', '青森県', 'アオモリケン', '十和田市', 'トワダシ', '西六番町', 'ニシ06バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県十和田市相坂', '02', '02206', '0340041', '青森県', 'アオモリケン', '十和田市', 'トワダシ', '相坂', 'オウサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県十和田市伝法寺', '02', '02206', '0340051', '青森県', 'アオモリケン', '十和田市', 'トワダシ', '伝法寺', 'デンポウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県十和田市藤島', '02', '02206', '0340052', '青森県', 'アオモリケン', '十和田市', 'トワダシ', '藤島', 'フジシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県十和田市切田', '02', '02206', '0340061', '青森県', 'アオモリケン', '十和田市', 'トワダシ', '切田', 'キリダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県十和田市赤沼', '02', '02206', '0340071', '青森県', 'アオモリケン', '十和田市', 'トワダシ', '赤沼', 'アカヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県八潮市', '11', '11234', '3400800', '埼玉県', 'サイタマケン', '八潮市', 'ヤシオシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('26565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県八潮市八條', '11', '11234', '3400801', '埼玉県', 'サイタマケン', '八潮市', 'ヤシオシ', '八條', 'ハチジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県八潮市鶴ケ曽根', '11', '11234', '3400802', '埼玉県', 'サイタマケン', '八潮市', 'ヤシオシ', '鶴ケ曽根', 'ツルガソネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県八潮市上馬場', '11', '11234', '3400803', '埼玉県', 'サイタマケン', '八潮市', 'ヤシオシ', '上馬場', 'カミバンバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県八潮市小作田', '11', '11234', '3400804', '埼玉県', 'サイタマケン', '八潮市', 'ヤシオシ', '小作田', 'コサクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県八潮市松之木', '11', '11234', '3400805', '埼玉県', 'サイタマケン', '八潮市', 'ヤシオシ', '松之木', 'マツノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県八潮市伊草', '11', '11234', '3400806', '埼玉県', 'サイタマケン', '八潮市', 'ヤシオシ', '伊草', 'イグサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県八潮市新町', '11', '11234', '3400807', '埼玉県', 'サイタマケン', '八潮市', 'ヤシオシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県八潮市緑町', '11', '11234', '3400808', '埼玉県', 'サイタマケン', '八潮市', 'ヤシオシ', '緑町', 'ミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県十和田市西十三番町', '02', '02206', '0340081', '青森県', 'アオモリケン', '十和田市', 'トワダシ', '西十三番町', 'ニシ13バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県八潮市二丁目', '11', '11234', '3400811', '埼玉県', 'サイタマケン', '八潮市', 'ヤシオシ', '二丁目', 'ニチョウメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県八潮市中馬場', '11', '11234', '3400812', '埼玉県', 'サイタマケン', '八潮市', 'ヤシオシ', '中馬場', 'ナカバンバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県八潮市木曽根', '11', '11234', '3400813', '埼玉県', 'サイタマケン', '八潮市', 'ヤシオシ', '木曽根', 'キゾネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県八潮市南川崎', '11', '11234', '3400814', '埼玉県', 'サイタマケン', '八潮市', 'ヤシオシ', '南川崎', 'ミナミカワサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県八潮市八潮', '11', '11234', '3400815', '埼玉県', 'サイタマケン', '八潮市', 'ヤシオシ', '八潮', 'ヤシオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県八潮市中央', '11', '11234', '3400816', '埼玉県', 'サイタマケン', '八潮市', 'ヤシオシ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県十和田市西二番町', '02', '02206', '0340082', '青森県', 'アオモリケン', '十和田市', 'トワダシ', '西二番町', 'ニシ02バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県八潮市伊勢野', '11', '11234', '3400821', '埼玉県', 'サイタマケン', '八潮市', 'ヤシオシ', '伊勢野', 'イセノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県八潮市大瀬', '11', '11234', '3400822', '埼玉県', 'サイタマケン', '八潮市', 'ヤシオシ', '大瀬', 'オオゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県八潮市古新田', '11', '11234', '3400823', '埼玉県', 'サイタマケン', '八潮市', 'ヤシオシ', '古新田', 'コシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県八潮市垳', '11', '11234', '3400824', '埼玉県', 'サイタマケン', '八潮市', 'ヤシオシ', '垳', 'ガケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県八潮市大原', '11', '11234', '3400825', '埼玉県', 'サイタマケン', '八潮市', 'ヤシオシ', '大原', 'ダイバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県十和田市西三番町', '02', '02206', '0340083', '青森県', 'アオモリケン', '十和田市', 'トワダシ', '西三番町', 'ニシ03バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県八潮市南後谷', '11', '11234', '3400831', '埼玉県', 'サイタマケン', '八潮市', 'ヤシオシ', '南後谷', 'ミナミウシロヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県八潮市柳之宮', '11', '11234', '3400832', '埼玉県', 'サイタマケン', '八潮市', 'ヤシオシ', '柳之宮', 'ヤナギノミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県八潮市西袋', '11', '11234', '3400833', '埼玉県', 'サイタマケン', '八潮市', 'ヤシオシ', '西袋', 'ニシブクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県八潮市大曽根', '11', '11234', '3400834', '埼玉県', 'サイタマケン', '八潮市', 'ヤシオシ', '大曽根', 'オオソネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県八潮市浮塚', '11', '11234', '3400835', '埼玉県', 'サイタマケン', '八潮市', 'ヤシオシ', '浮塚', 'ウキヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県十和田市西四番町', '02', '02206', '0340084', '青森県', 'アオモリケン', '十和田市', 'トワダシ', '西四番町', 'ニシ04バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県十和田市西五番町', '02', '02206', '0340085', '青森県', 'アオモリケン', '十和田市', 'トワダシ', '西五番町', 'ニシ05バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県十和田市西十六番町', '02', '02206', '0340086', '青森県', 'アオモリケン', '十和田市', 'トワダシ', '西十六番町', 'ニシ16バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県十和田市西十五番町', '02', '02206', '0340087', '青森県', 'アオモリケン', '十和田市', 'トワダシ', '西十五番町', 'ニシ15バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県十和田市西十四番町', '02', '02206', '0340088', '青森県', 'アオモリケン', '十和田市', 'トワダシ', '西十四番町', 'ニシ14バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県十和田市西二十三番町', '02', '02206', '0340089', '青森県', 'アオモリケン', '十和田市', 'トワダシ', '西二十三番町', 'ニシ23バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県十和田市西十一番町', '02', '02206', '0340091', '青森県', 'アオモリケン', '十和田市', 'トワダシ', '西十一番町', 'ニシ11バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県十和田市西一番町', '02', '02206', '0340092', '青森県', 'アオモリケン', '十和田市', 'トワダシ', '西一番町', 'ニシ01バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県十和田市西十二番町', '02', '02206', '0340093', '青森県', 'アオモリケン', '十和田市', 'トワダシ', '西十二番町', 'ニシ12バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県十和田市西二十二番町', '02', '02206', '0340094', '青森県', 'アオモリケン', '十和田市', 'トワダシ', '西二十二番町', 'ニシ22バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県十和田市西二十一番町', '02', '02206', '0340095', '青森県', 'アオモリケン', '十和田市', 'トワダシ', '西二十一番町', 'ニシ21バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県十和田市馬洗場', '02', '02206', '0340101', '青森県', 'アオモリケン', '十和田市', 'トワダシ', '馬洗場', 'ウマアライバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県十和田市大沢田', '02', '02206', '0340102', '青森県', 'アオモリケン', '十和田市', 'トワダシ', '大沢田', 'オオサワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県十和田市立崎', '02', '02206', '0340103', '青森県', 'アオモリケン', '十和田市', 'トワダシ', '立崎', 'タチザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県十和田市豊ケ岡', '02', '02206', '0340104', '青森県', 'アオモリケン', '十和田市', 'トワダシ', '豊ケ岡', 'トヨガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県十和田市八斗沢', '02', '02206', '0340105', '青森県', 'アオモリケン', '十和田市', 'トワダシ', '八斗沢', 'ハットザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県十和田市深持', '02', '02206', '0340106', '青森県', 'アオモリケン', '十和田市', 'トワダシ', '深持', 'フカモチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県十和田市洞内', '02', '02206', '0340107', '青森県', 'アオモリケン', '十和田市', 'トワダシ', '洞内', 'ホラナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県十和田市大不動', '02', '02206', '0340211', '青森県', 'アオモリケン', '十和田市', 'トワダシ', '大不動', 'オオフドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県十和田市米田', '02', '02206', '0340212', '青森県', 'アオモリケン', '十和田市', 'トワダシ', '米田', 'マイタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県十和田市滝沢', '02', '02206', '0340213', '青森県', 'アオモリケン', '十和田市', 'トワダシ', '滝沢', 'タキサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県十和田市奥瀬', '02', '02206', '0340301', '青森県', 'アオモリケン', '十和田市', 'トワダシ', '奥瀬', 'オクセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県十和田市沢田', '02', '02206', '0340302', '青森県', 'アオモリケン', '十和田市', 'トワダシ', '沢田', 'サワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県十和田市法量', '02', '02206', '0340303', '青森県', 'アオモリケン', '十和田市', 'トワダシ', '法量', 'ホウリョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県三郷市', '11', '11237', '3410000', '埼玉県', 'サイタマケン', '三郷市', 'ミサトシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('26639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県三郷市彦糸', '11', '11237', '3410001', '埼玉県', 'サイタマケン', '三郷市', 'ミサトシ', '彦糸', 'ヒコイト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県三郷市彦音', '11', '11237', '3410002', '埼玉県', 'サイタマケン', '三郷市', 'ミサトシ', '彦音', 'ヒコオト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県三郷市彦成', '11', '11237', '3410003', '埼玉県', 'サイタマケン', '三郷市', 'ミサトシ', '彦成', 'ヒコナリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県三郷市上彦名', '11', '11237', '3410004', '埼玉県', 'サイタマケン', '三郷市', 'ミサトシ', '上彦名', 'カミヒコナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県三郷市彦川戸', '11', '11237', '3410005', '埼玉県', 'サイタマケン', '三郷市', 'ミサトシ', '彦川戸', 'ヒコカワド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県三郷市上彦川戸', '11', '11237', '3410006', '埼玉県', 'サイタマケン', '三郷市', 'ミサトシ', '上彦川戸', 'カミヒコカワド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県三郷市下彦川戸', '11', '11237', '3410007', '埼玉県', 'サイタマケン', '三郷市', 'ミサトシ', '下彦川戸', 'シモヒコカワド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県三郷市駒形', '11', '11237', '3410008', '埼玉県', 'サイタマケン', '三郷市', 'ミサトシ', '駒形', 'コマガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県三郷市新三郷ららシティ', '11', '11237', '3410009', '埼玉県', 'サイタマケン', '三郷市', 'ミサトシ', '新三郷ららシティ', 'シンミサトララシティ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県三郷市釆女', '11', '11237', '3410011', '埼玉県', 'サイタマケン', '三郷市', 'ミサトシ', '釆女', 'ウネメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県三郷市半田', '11', '11237', '3410012', '埼玉県', 'サイタマケン', '三郷市', 'ミサトシ', '半田', 'ハンタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県三郷市小谷堀', '11', '11237', '3410013', '埼玉県', 'サイタマケン', '三郷市', 'ミサトシ', '小谷堀', 'コヤボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県三郷市後谷', '11', '11237', '3410014', '埼玉県', 'サイタマケン', '三郷市', 'ミサトシ', '後谷', 'ウシロヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県三郷市前間', '11', '11237', '3410015', '埼玉県', 'サイタマケン', '三郷市', 'ミサトシ', '前間', 'ゼンマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県三郷市田中新田', '11', '11237', '3410016', '埼玉県', 'サイタマケン', '三郷市', 'ミサトシ', '田中新田', 'タナカシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県三郷市丹後', '11', '11237', '3410017', '埼玉県', 'サイタマケン', '三郷市', 'ミサトシ', '丹後', 'タンゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県三郷市早稲田', '11', '11237', '3410018', '埼玉県', 'サイタマケン', '三郷市', 'ミサトシ', '早稲田', 'ワセダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県三郷市さつき平', '11', '11237', '3410021', '埼玉県', 'サイタマケン', '三郷市', 'ミサトシ', 'さつき平', 'サツキダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県三郷市大広戸', '11', '11237', '3410022', '埼玉県', 'サイタマケン', '三郷市', 'ミサトシ', '大広戸', 'オオヒロト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県三郷市仁蔵', '11', '11237', '3410023', '埼玉県', 'サイタマケン', '三郷市', 'ミサトシ', '仁蔵', 'ニゾウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県三郷市三郷', '11', '11237', '3410024', '埼玉県', 'サイタマケン', '三郷市', 'ミサトシ', '三郷', 'ミサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県三郷市茂田井', '11', '11237', '3410025', '埼玉県', 'サイタマケン', '三郷市', 'ミサトシ', '茂田井', 'モタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県三郷市幸房', '11', '11237', '3410026', '埼玉県', 'サイタマケン', '三郷市', 'ミサトシ', '幸房', 'コウボウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県三郷市笹塚', '11', '11237', '3410027', '埼玉県', 'サイタマケン', '三郷市', 'ミサトシ', '笹塚', 'ササヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県三郷市南蓮沼', '11', '11237', '3410028', '埼玉県', 'サイタマケン', '三郷市', 'ミサトシ', '南蓮沼', 'ミナミハスヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県三郷市岩野木', '11', '11237', '3410031', '埼玉県', 'サイタマケン', '三郷市', 'ミサトシ', '岩野木', 'イワノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県三郷市谷中', '11', '11237', '3410032', '埼玉県', 'サイタマケン', '三郷市', 'ミサトシ', '谷中', 'ヤナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県三郷市市助', '11', '11237', '3410033', '埼玉県', 'サイタマケン', '三郷市', 'ミサトシ', '市助', 'イチスケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県三郷市新和', '11', '11237', '3410034', '埼玉県', 'サイタマケン', '三郷市', 'ミサトシ', '新和', 'シンワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県三郷市鷹野', '11', '11237', '3410035', '埼玉県', 'サイタマケン', '三郷市', 'ミサトシ', '鷹野', 'タカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県三郷市東町', '11', '11237', '3410036', '埼玉県', 'サイタマケン', '三郷市', 'ミサトシ', '東町', 'アズマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県三郷市高州', '11', '11237', '3410037', '埼玉県', 'サイタマケン', '三郷市', 'ミサトシ', '高州', 'タカス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県三郷市花和田', '11', '11237', '3410041', '埼玉県', 'サイタマケン', '三郷市', 'ミサトシ', '花和田', 'ハナワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県三郷市谷口', '11', '11237', '3410042', '埼玉県', 'サイタマケン', '三郷市', 'ミサトシ', '谷口', 'ヤグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県三郷市栄', '11', '11237', '3410043', '埼玉県', 'サイタマケン', '三郷市', 'ミサトシ', '栄', 'サカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県三郷市戸ケ崎', '11', '11237', '3410044', '埼玉県', 'サイタマケン', '三郷市', 'ミサトシ', '戸ケ崎', 'トガサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県三郷市寄巻', '11', '11237', '3410045', '埼玉県', 'サイタマケン', '三郷市', 'ミサトシ', '寄巻', 'ヨマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県三郷市鎌倉', '11', '11237', '3410046', '埼玉県', 'サイタマケン', '三郷市', 'ミサトシ', '鎌倉', 'カマクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県三郷市天神', '11', '11237', '3410051', '埼玉県', 'サイタマケン', '三郷市', 'ミサトシ', '天神', 'テンジン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県三郷市彦野', '11', '11237', '3410052', '埼玉県', 'サイタマケン', '三郷市', 'ミサトシ', '彦野', 'ヒコノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県三郷市彦倉', '11', '11237', '3410053', '埼玉県', 'サイタマケン', '三郷市', 'ミサトシ', '彦倉', 'ヒコクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県三郷市泉', '11', '11237', '3410054', '埼玉県', 'サイタマケン', '三郷市', 'ミサトシ', '泉', 'イズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県三郷市上口', '11', '11237', '3410055', '埼玉県', 'サイタマケン', '三郷市', 'ミサトシ', '上口', 'カミグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県三郷市番匠免', '11', '11237', '3410056', '埼玉県', 'サイタマケン', '三郷市', 'ミサトシ', '番匠免', 'バンショウメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県三郷市彦沢', '11', '11237', '3410057', '埼玉県', 'サイタマケン', '三郷市', 'ミサトシ', '彦沢', 'ヒコサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県三郷市彦江', '11', '11237', '3410058', '埼玉県', 'サイタマケン', '三郷市', 'ミサトシ', '彦江', 'ヒコエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県吉川市', '11', '11243', '3420000', '埼玉県', 'サイタマケン', '吉川市', 'ヨシカワシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('26691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県吉川市上内川', '11', '11243', '3420001', '埼玉県', 'サイタマケン', '吉川市', 'ヨシカワシ', '上内川', 'カミウチカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県吉川市下内川', '11', '11243', '3420002', '埼玉県', 'サイタマケン', '吉川市', 'ヨシカワシ', '下内川', 'シモウチカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県吉川市八子新田', '11', '11243', '3420003', '埼玉県', 'サイタマケン', '吉川市', 'ヨシカワシ', '八子新田', 'ハチコシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県吉川市鍋小路', '11', '11243', '3420004', '埼玉県', 'サイタマケン', '吉川市', 'ヨシカワシ', '鍋小路', 'ナベコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県吉川市川藤', '11', '11243', '3420005', '埼玉県', 'サイタマケン', '吉川市', 'ヨシカワシ', '川藤', 'カワフジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県吉川市南広島', '11', '11243', '3420006', '埼玉県', 'サイタマケン', '吉川市', 'ヨシカワシ', '南広島', 'ミナミヒロシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県吉川市拾壱軒', '11', '11243', '3420007', '埼玉県', 'サイタマケン', '吉川市', 'ヨシカワシ', '拾壱軒', 'ジュウイッケン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県吉川市旭', '11', '11243', '3420008', '埼玉県', 'サイタマケン', '吉川市', 'ヨシカワシ', '旭', 'アサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県吉川市深井新田', '11', '11243', '3420011', '埼玉県', 'サイタマケン', '吉川市', 'ヨシカワシ', '深井新田', 'フカイシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県吉川市平方新田', '11', '11243', '3420012', '埼玉県', 'サイタマケン', '吉川市', 'ヨシカワシ', '平方新田', 'ヒラカタシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県吉川市吉屋', '11', '11243', '3420013', '埼玉県', 'サイタマケン', '吉川市', 'ヨシカワシ', '吉屋', 'ヨシヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県吉川市関新田', '11', '11243', '3420014', '埼玉県', 'サイタマケン', '吉川市', 'ヨシカワシ', '関新田', 'セキシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県吉川市中井', '11', '11243', '3420015', '埼玉県', 'サイタマケン', '吉川市', 'ヨシカワシ', '中井', 'ナカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県吉川市会野谷', '11', '11243', '3420016', '埼玉県', 'サイタマケン', '吉川市', 'ヨシカワシ', '会野谷', 'アイノヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県吉川市上笹塚', '11', '11243', '3420017', '埼玉県', 'サイタマケン', '吉川市', 'ヨシカワシ', '上笹塚', 'カミササヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県吉川市鹿見塚', '11', '11243', '3420021', '埼玉県', 'サイタマケン', '吉川市', 'ヨシカワシ', '鹿見塚', 'シシミヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県吉川市加藤', '11', '11243', '3420022', '埼玉県', 'サイタマケン', '吉川市', 'ヨシカワシ', '加藤', 'カトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県吉川市皿沼', '11', '11243', '3420023', '埼玉県', 'サイタマケン', '吉川市', 'ヨシカワシ', '皿沼', 'サラヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県吉川市半割', '11', '11243', '3420024', '埼玉県', 'サイタマケン', '吉川市', 'ヨシカワシ', '半割', 'ハンワリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県吉川市飯島', '11', '11243', '3420025', '埼玉県', 'サイタマケン', '吉川市', 'ヨシカワシ', '飯島', 'イイジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県吉川市土場', '11', '11243', '3420026', '埼玉県', 'サイタマケン', '吉川市', 'ヨシカワシ', '土場', 'ドジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県吉川市三輪野江', '11', '11243', '3420027', '埼玉県', 'サイタマケン', '吉川市', 'ヨシカワシ', '三輪野江', 'ミワノエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県吉川市中島', '11', '11243', '3420031', '埼玉県', 'サイタマケン', '吉川市', 'ヨシカワシ', '中島', 'ナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県吉川市二ツ沼', '11', '11243', '3420032', '埼玉県', 'サイタマケン', '吉川市', 'ヨシカワシ', '二ツ沼', 'フタツヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県吉川市中曽根', '11', '11243', '3420033', '埼玉県', 'サイタマケン', '吉川市', 'ヨシカワシ', '中曽根', 'ナカソネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県吉川市道庭', '11', '11243', '3420034', '埼玉県', 'サイタマケン', '吉川市', 'ヨシカワシ', '道庭', 'ドウニワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県吉川市高久', '11', '11243', '3420035', '埼玉県', 'サイタマケン', '吉川市', 'ヨシカワシ', '高久', 'タカヒサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県吉川市高富', '11', '11243', '3420036', '埼玉県', 'サイタマケン', '吉川市', 'ヨシカワシ', '高富', 'タカドミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県吉川市富新田', '11', '11243', '3420037', '埼玉県', 'サイタマケン', '吉川市', 'ヨシカワシ', '富新田', 'トミシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県吉川市保', '11', '11243', '3420041', '埼玉県', 'サイタマケン', '吉川市', 'ヨシカワシ', '保', 'ホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県吉川市中野', '11', '11243', '3420042', '埼玉県', 'サイタマケン', '吉川市', 'ヨシカワシ', '中野', 'ナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県吉川市小松川', '11', '11243', '3420043', '埼玉県', 'サイタマケン', '吉川市', 'ヨシカワシ', '小松川', 'コマツガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県吉川市木売新田', '11', '11243', '3420044', '埼玉県', 'サイタマケン', '吉川市', 'ヨシカワシ', '木売新田', 'キウリシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県吉川市木売', '11', '11243', '3420045', '埼玉県', 'サイタマケン', '吉川市', 'ヨシカワシ', '木売', 'キウリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県吉川市共保', '11', '11243', '3420046', '埼玉県', 'サイタマケン', '吉川市', 'ヨシカワシ', '共保', 'キョウホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県吉川市中川台', '11', '11243', '3420047', '埼玉県', 'サイタマケン', '吉川市', 'ヨシカワシ', '中川台', 'ナカガワダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県吉川市栄町', '11', '11243', '3420050', '埼玉県', 'サイタマケン', '吉川市', 'ヨシカワシ', '栄町', 'サカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県吉川市川野', '11', '11243', '3420051', '埼玉県', 'サイタマケン', '吉川市', 'ヨシカワシ', '川野', 'カワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県吉川市川富', '11', '11243', '3420052', '埼玉県', 'サイタマケン', '吉川市', 'ヨシカワシ', '川富', 'カワドミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県吉川市関', '11', '11243', '3420053', '埼玉県', 'サイタマケン', '吉川市', 'ヨシカワシ', '関', 'セキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県吉川市吉川団地', '11', '11243', '3420054', '埼玉県', 'サイタマケン', '吉川市', 'ヨシカワシ', '吉川団地', 'ヨシカワダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県吉川市吉川', '11', '11243', '3420055', '埼玉県', 'サイタマケン', '吉川市', 'ヨシカワシ', '吉川', 'ヨシカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県吉川市平沼', '11', '11243', '3420056', '埼玉県', 'サイタマケン', '吉川市', 'ヨシカワシ', '平沼', 'ヒラヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県吉川市須賀', '11', '11243', '3420057', '埼玉県', 'サイタマケン', '吉川市', 'ヨシカワシ', '須賀', 'スカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県吉川市きよみ野', '11', '11243', '3420058', '埼玉県', 'サイタマケン', '吉川市', 'ヨシカワシ', 'きよみ野', 'キヨミノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県吉川市新栄', '11', '11243', '3420059', '埼玉県', 'サイタマケン', '吉川市', 'ヨシカワシ', '新栄', 'シンエイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県越谷市', '11', '11222', '3430000', '埼玉県', 'サイタマケン', '越谷市', 'コシガヤシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('26742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県越谷市平方南町', '11', '11222', '3430001', '埼玉県', 'サイタマケン', '越谷市', 'コシガヤシ', '平方南町', 'ヒラカタミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県越谷市平方', '11', '11222', '3430002', '埼玉県', 'サイタマケン', '越谷市', 'コシガヤシ', '平方', 'ヒラカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県越谷市船渡', '11', '11222', '3430003', '埼玉県', 'サイタマケン', '越谷市', 'コシガヤシ', '船渡', 'フナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県越谷市大松', '11', '11222', '3430004', '埼玉県', 'サイタマケン', '越谷市', 'コシガヤシ', '大松', 'オオマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県越谷市大杉', '11', '11222', '3430005', '埼玉県', 'サイタマケン', '越谷市', 'コシガヤシ', '大杉', 'オオスギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県越谷市北川崎', '11', '11222', '3430006', '埼玉県', 'サイタマケン', '越谷市', 'コシガヤシ', '北川崎', 'キタカワサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県越谷市向畑', '11', '11222', '3430007', '埼玉県', 'サイタマケン', '越谷市', 'コシガヤシ', '向畑', 'ムコウバタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県越谷市大吉', '11', '11222', '3430008', '埼玉県', 'サイタマケン', '越谷市', 'コシガヤシ', '大吉', 'オオヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県越谷市増林', '11', '11222', '3430011', '埼玉県', 'サイタマケン', '越谷市', 'コシガヤシ', '増林', 'マシバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県越谷市増森', '11', '11222', '3430012', '埼玉県', 'サイタマケン', '越谷市', 'コシガヤシ', '増森', 'マシモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県越谷市中島', '11', '11222', '3430013', '埼玉県', 'サイタマケン', '越谷市', 'コシガヤシ', '中島', 'ナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県越谷市宮前', '11', '11222', '3430014', '埼玉県', 'サイタマケン', '越谷市', 'コシガヤシ', '宮前', 'ミヤマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県越谷市花田', '11', '11222', '3430015', '埼玉県', 'サイタマケン', '越谷市', 'コシガヤシ', '花田', 'ハナタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県越谷市大林', '11', '11222', '3430021', '埼玉県', 'サイタマケン', '越谷市', 'コシガヤシ', '大林', 'オオバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県越谷市東大沢', '11', '11222', '3430022', '埼玉県', 'サイタマケン', '越谷市', 'コシガヤシ', '東大沢', 'ヒガシオオサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県越谷市東越谷', '11', '11222', '3430023', '埼玉県', 'サイタマケン', '越谷市', 'コシガヤシ', '東越谷', 'ヒガシコシガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県越谷市越ケ谷', '11', '11222', '3430024', '埼玉県', 'サイタマケン', '越谷市', 'コシガヤシ', '越ケ谷', 'コシガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県越谷市大澤', '11', '11222', '3430025', '埼玉県', 'サイタマケン', '越谷市', 'コシガヤシ', '大澤', 'オオサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県越谷市北越谷', '11', '11222', '3430026', '埼玉県', 'サイタマケン', '越谷市', 'コシガヤシ', '北越谷', 'キタコシガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県越谷市大房', '11', '11222', '3430027', '埼玉県', 'サイタマケン', '越谷市', 'コシガヤシ', '大房', 'オオフサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県越谷市大里', '11', '11222', '3430031', '埼玉県', 'サイタマケン', '越谷市', 'コシガヤシ', '大里', 'オオザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県越谷市袋山', '11', '11222', '3430032', '埼玉県', 'サイタマケン', '越谷市', 'コシガヤシ', '袋山', 'フクロヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県越谷市恩間', '11', '11222', '3430033', '埼玉県', 'サイタマケン', '越谷市', 'コシガヤシ', '恩間', 'オンマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県越谷市大竹', '11', '11222', '3430034', '埼玉県', 'サイタマケン', '越谷市', 'コシガヤシ', '大竹', 'オオタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県越谷市大道', '11', '11222', '3430035', '埼玉県', 'サイタマケン', '越谷市', 'コシガヤシ', '大道', 'オオミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県越谷市三野宮', '11', '11222', '3430036', '埼玉県', 'サイタマケン', '越谷市', 'コシガヤシ', '三野宮', 'サンノミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県越谷市恩間新田', '11', '11222', '3430037', '埼玉県', 'サイタマケン', '越谷市', 'コシガヤシ', '恩間新田', 'オンマシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県越谷市千間台西', '11', '11222', '3430041', '埼玉県', 'サイタマケン', '越谷市', 'コシガヤシ', '千間台西', 'センゲンダイニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県越谷市千間台東', '11', '11222', '3430042', '埼玉県', 'サイタマケン', '越谷市', 'コシガヤシ', '千間台東', 'センゲンダイヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県越谷市上間久里', '11', '11222', '3430043', '埼玉県', 'サイタマケン', '越谷市', 'コシガヤシ', '上間久里', 'カミマクリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県越谷市大泊', '11', '11222', '3430044', '埼玉県', 'サイタマケン', '越谷市', 'コシガヤシ', '大泊', 'オオドマリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県越谷市下間久里', '11', '11222', '3430045', '埼玉県', 'サイタマケン', '越谷市', 'コシガヤシ', '下間久里', 'シモマクリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県越谷市弥栄町', '11', '11222', '3430046', '埼玉県', 'サイタマケン', '越谷市', 'コシガヤシ', '弥栄町', 'ヤサカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県越谷市弥十郎', '11', '11222', '3430047', '埼玉県', 'サイタマケン', '越谷市', 'コシガヤシ', '弥十郎', 'ヤジュウロウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北葛飾郡松伏町', '11', '11465', '3430100', '埼玉県', 'サイタマケン', '北葛飾郡松伏町', 'キタカツシカグンマツブシマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('26777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北葛飾郡松伏町魚沼', '11', '11465', '3430101', '埼玉県', 'サイタマケン', '北葛飾郡松伏町', 'キタカツシカグンマツブシマチ', '魚沼', 'ウオヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北葛飾郡松伏町築比地', '11', '11465', '3430102', '埼玉県', 'サイタマケン', '北葛飾郡松伏町', 'キタカツシカグンマツブシマチ', '築比地', 'ツキヒジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北葛飾郡松伏町金杉', '11', '11465', '3430103', '埼玉県', 'サイタマケン', '北葛飾郡松伏町', 'キタカツシカグンマツブシマチ', '金杉', 'カナスギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北葛飾郡松伏町田島東', '11', '11465', '3430104', '埼玉県', 'サイタマケン', '北葛飾郡松伏町', 'キタカツシカグンマツブシマチ', '田島東', 'タジマヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北葛飾郡松伏町田島', '11', '11465', '3430105', '埼玉県', 'サイタマケン', '北葛飾郡松伏町', 'キタカツシカグンマツブシマチ', '田島', 'タジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北葛飾郡松伏町大川戸', '11', '11465', '3430106', '埼玉県', 'サイタマケン', '北葛飾郡松伏町', 'キタカツシカグンマツブシマチ', '大川戸', 'オオカワド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北葛飾郡松伏町松伏', '11', '11465', '3430111', '埼玉県', 'サイタマケン', '北葛飾郡松伏町', 'キタカツシカグンマツブシマチ', '松伏', 'マツブシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北葛飾郡松伏町松葉', '11', '11465', '3430112', '埼玉県', 'サイタマケン', '北葛飾郡松伏町', 'キタカツシカグンマツブシマチ', '松葉', 'マツバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北葛飾郡松伏町ゆめみ野', '11', '11465', '3430113', '埼玉県', 'サイタマケン', '北葛飾郡松伏町', 'キタカツシカグンマツブシマチ', 'ゆめみ野', 'ユメミノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北葛飾郡松伏町ゆめみ野東', '11', '11465', '3430114', '埼玉県', 'サイタマケン', '北葛飾郡松伏町', 'キタカツシカグンマツブシマチ', 'ゆめみ野東', 'ユメミノヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北葛飾郡松伏町上赤岩', '11', '11465', '3430115', '埼玉県', 'サイタマケン', '北葛飾郡松伏町', 'キタカツシカグンマツブシマチ', '上赤岩', 'カミアカイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北葛飾郡松伏町下赤岩', '11', '11465', '3430116', '埼玉県', 'サイタマケン', '北葛飾郡松伏町', 'キタカツシカグンマツブシマチ', '下赤岩', 'シモアカイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北葛飾郡松伏町田中', '11', '11465', '3430117', '埼玉県', 'サイタマケン', '北葛飾郡松伏町', 'キタカツシカグンマツブシマチ', '田中', 'タナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県越谷市野島', '11', '11222', '3430801', '埼玉県', 'サイタマケン', '越谷市', 'コシガヤシ', '野島', 'ノジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県越谷市小曽川', '11', '11222', '3430802', '埼玉県', 'サイタマケン', '越谷市', 'コシガヤシ', '小曽川', 'オソガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県越谷市砂原', '11', '11222', '3430803', '埼玉県', 'サイタマケン', '越谷市', 'コシガヤシ', '砂原', 'スナハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県越谷市南荻島', '11', '11222', '3430804', '埼玉県', 'サイタマケン', '越谷市', 'コシガヤシ', '南荻島', 'ミナミオギシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県越谷市神明町', '11', '11222', '3430805', '埼玉県', 'サイタマケン', '越谷市', 'コシガヤシ', '神明町', 'シンメイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県越谷市宮本町', '11', '11222', '3430806', '埼玉県', 'サイタマケン', '越谷市', 'コシガヤシ', '宮本町', 'ミヤモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県越谷市赤山町', '11', '11222', '3430807', '埼玉県', 'サイタマケン', '越谷市', 'コシガヤシ', '赤山町', 'アカヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県越谷市赤山本町', '11', '11222', '3430808', '埼玉県', 'サイタマケン', '越谷市', 'コシガヤシ', '赤山本町', 'アカヤマホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県越谷市御殿町', '11', '11222', '3430811', '埼玉県', 'サイタマケン', '越谷市', 'コシガヤシ', '御殿町', 'ゴテンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県越谷市柳町', '11', '11222', '3430812', '埼玉県', 'サイタマケン', '越谷市', 'コシガヤシ', '柳町', 'ヤナギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県越谷市越ケ谷', '11', '11222', '3430813', '埼玉県', 'サイタマケン', '越谷市', 'コシガヤシ', '越ケ谷', 'コシガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県越谷市東柳田町', '11', '11222', '3430814', '埼玉県', 'サイタマケン', '越谷市', 'コシガヤシ', '東柳田町', 'ヒガシヤナギダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県越谷市元柳田町', '11', '11222', '3430815', '埼玉県', 'サイタマケン', '越谷市', 'コシガヤシ', '元柳田町', 'モトヤナギダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県越谷市弥生町', '11', '11222', '3430816', '埼玉県', 'サイタマケン', '越谷市', 'コシガヤシ', '弥生町', 'ヤヨイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県越谷市中町', '11', '11222', '3430817', '埼玉県', 'サイタマケン', '越谷市', 'コシガヤシ', '中町', 'ナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県越谷市越ケ谷本町', '11', '11222', '3430818', '埼玉県', 'サイタマケン', '越谷市', 'コシガヤシ', '越ケ谷本町', 'コシガヤホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県越谷市瓦曽根', '11', '11222', '3430821', '埼玉県', 'サイタマケン', '越谷市', 'コシガヤシ', '瓦曽根', 'カワラゾネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県越谷市西方', '11', '11222', '3430822', '埼玉県', 'サイタマケン', '越谷市', 'コシガヤシ', '西方', 'ニシカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県越谷市相模町', '11', '11222', '3430823', '埼玉県', 'サイタマケン', '越谷市', 'コシガヤシ', '相模町', 'サガミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県越谷市流通団地', '11', '11222', '3430824', '埼玉県', 'サイタマケン', '越谷市', 'コシガヤシ', '流通団地', 'リュウツウダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県越谷市大成町', '11', '11222', '3430825', '埼玉県', 'サイタマケン', '越谷市', 'コシガヤシ', '大成町', 'タイセイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県越谷市東町', '11', '11222', '3430826', '埼玉県', 'サイタマケン', '越谷市', 'コシガヤシ', '東町', 'アズマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県越谷市川柳町', '11', '11222', '3430827', '埼玉県', 'サイタマケン', '越谷市', 'コシガヤシ', '川柳町', 'カワヤナギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県越谷市伊原', '11', '11222', '3430831', '埼玉県', 'サイタマケン', '越谷市', 'コシガヤシ', '伊原', 'イハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県越谷市南町', '11', '11222', '3430832', '埼玉県', 'サイタマケン', '越谷市', 'コシガヤシ', '南町', 'ミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県越谷市蒲生南町', '11', '11222', '3430833', '埼玉県', 'サイタマケン', '越谷市', 'コシガヤシ', '蒲生南町', 'ガモウミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県越谷市蒲生愛宕町', '11', '11222', '3430834', '埼玉県', 'サイタマケン', '越谷市', 'コシガヤシ', '蒲生愛宕町', 'ガモウアタゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県越谷市蒲生西町', '11', '11222', '3430835', '埼玉県', 'サイタマケン', '越谷市', 'コシガヤシ', '蒲生西町', 'ガモウニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県越谷市蒲生寿町', '11', '11222', '3430836', '埼玉県', 'サイタマケン', '越谷市', 'コシガヤシ', '蒲生寿町', 'ガモウコトブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県越谷市蒲生本町', '11', '11222', '3430837', '埼玉県', 'サイタマケン', '越谷市', 'コシガヤシ', '蒲生本町', 'ガモウホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県越谷市蒲生', '11', '11222', '3430838', '埼玉県', 'サイタマケン', '越谷市', 'コシガヤシ', '蒲生', 'ガモウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県越谷市蒲生東町', '11', '11222', '3430841', '埼玉県', 'サイタマケン', '越谷市', 'コシガヤシ', '蒲生東町', 'ガモウヒガシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県越谷市蒲生旭町', '11', '11222', '3430842', '埼玉県', 'サイタマケン', '越谷市', 'コシガヤシ', '蒲生旭町', 'ガモウアサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県越谷市蒲生茜町', '11', '11222', '3430843', '埼玉県', 'サイタマケン', '越谷市', 'コシガヤシ', '蒲生茜町', 'ガモウアカネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県越谷市大間野町', '11', '11222', '3430844', '埼玉県', 'サイタマケン', '越谷市', 'コシガヤシ', '大間野町', 'オオマノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県越谷市南越谷', '11', '11222', '3430845', '埼玉県', 'サイタマケン', '越谷市', 'コシガヤシ', '南越谷', 'ミナミコシガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県越谷市登戸町', '11', '11222', '3430846', '埼玉県', 'サイタマケン', '越谷市', 'コシガヤシ', '登戸町', 'ノボリトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県越谷市七左町', '11', '11222', '3430851', '埼玉県', 'サイタマケン', '越谷市', 'コシガヤシ', '七左町', 'シチザチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県越谷市新川町', '11', '11222', '3430852', '埼玉県', 'サイタマケン', '越谷市', 'コシガヤシ', '新川町', 'シンカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県越谷市長島', '11', '11222', '3430853', '埼玉県', 'サイタマケン', '越谷市', 'コシガヤシ', '長島', 'ナガシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県越谷市北後谷', '11', '11222', '3430854', '埼玉県', 'サイタマケン', '越谷市', 'コシガヤシ', '北後谷', 'キタウシロヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県越谷市西新井', '11', '11222', '3430855', '埼玉県', 'サイタマケン', '越谷市', 'コシガヤシ', '西新井', 'ニシアライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県越谷市谷中町', '11', '11222', '3430856', '埼玉県', 'サイタマケン', '越谷市', 'コシガヤシ', '谷中町', 'ヤナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県春日部市', '11', '11214', '3440000', '埼玉県', 'サイタマケン', '春日部市', 'カスカベシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('26844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県春日部市不動院野', '11', '11214', '3440001', '埼玉県', 'サイタマケン', '春日部市', 'カスカベシ', '不動院野', 'フドウインノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県春日部市樋籠', '11', '11214', '3440002', '埼玉県', 'サイタマケン', '春日部市', 'カスカベシ', '樋籠', 'ヒロウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県春日部市新川', '11', '11214', '3440003', '埼玉県', 'サイタマケン', '春日部市', 'カスカベシ', '新川', 'シンカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県春日部市牛島', '11', '11214', '3440004', '埼玉県', 'サイタマケン', '春日部市', 'カスカベシ', '牛島', 'ウシジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県春日部市樋堀', '11', '11214', '3440005', '埼玉県', 'サイタマケン', '春日部市', 'カスカベシ', '樋堀', 'ヒボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県春日部市八丁目', '11', '11214', '3440006', '埼玉県', 'サイタマケン', '春日部市', 'カスカベシ', '八丁目', 'ハッチョウメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県春日部市小渕', '11', '11214', '3440007', '埼玉県', 'サイタマケン', '春日部市', 'カスカベシ', '小渕', 'コブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県春日部市藤塚', '11', '11214', '3440011', '埼玉県', 'サイタマケン', '春日部市', 'カスカベシ', '藤塚', 'フジツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県春日部市六軒町', '11', '11214', '3440012', '埼玉県', 'サイタマケン', '春日部市', 'カスカベシ', '六軒町', 'ロッケンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県春日部市銚子口', '11', '11214', '3440013', '埼玉県', 'サイタマケン', '春日部市', 'カスカベシ', '銚子口', 'チョウシグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県春日部市豊野町', '11', '11214', '3440014', '埼玉県', 'サイタマケン', '春日部市', 'カスカベシ', '豊野町', 'トヨノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県春日部市赤沼', '11', '11214', '3440015', '埼玉県', 'サイタマケン', '春日部市', 'カスカベシ', '赤沼', 'アカヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県春日部市本田町', '11', '11214', '3440016', '埼玉県', 'サイタマケン', '春日部市', 'カスカベシ', '本田町', 'ホンデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県春日部市大場', '11', '11214', '3440021', '埼玉県', 'サイタマケン', '春日部市', 'カスカベシ', '大場', 'オオバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県春日部市大畑', '11', '11214', '3440022', '埼玉県', 'サイタマケン', '春日部市', 'カスカベシ', '大畑', 'オオハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県春日部市大枝', '11', '11214', '3440023', '埼玉県', 'サイタマケン', '春日部市', 'カスカベシ', '大枝', 'オオエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県春日部市千間', '11', '11214', '3440024', '埼玉県', 'サイタマケン', '春日部市', 'カスカベシ', '千間', 'センゲン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県春日部市増田新田', '11', '11214', '3440025', '埼玉県', 'サイタマケン', '春日部市', 'カスカベシ', '増田新田', 'マスダシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県春日部市武里中野', '11', '11214', '3440026', '埼玉県', 'サイタマケン', '春日部市', 'カスカベシ', '武里中野', 'タケサトナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県春日部市一ノ割', '11', '11214', '3440031', '埼玉県', 'サイタマケン', '春日部市', 'カスカベシ', '一ノ割', 'イチノワリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県春日部市備後東', '11', '11214', '3440032', '埼玉県', 'サイタマケン', '春日部市', 'カスカベシ', '備後東', 'ビンゴヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県春日部市備後西', '11', '11214', '3440033', '埼玉県', 'サイタマケン', '春日部市', 'カスカベシ', '備後西', 'ビンゴニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県春日部市薄谷', '11', '11214', '3440034', '埼玉県', 'サイタマケン', '春日部市', 'カスカベシ', '薄谷', 'ススキヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県春日部市谷原新田', '11', '11214', '3440035', '埼玉県', 'サイタマケン', '春日部市', 'カスカベシ', '谷原新田', 'ヤハラシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県春日部市下大増新田', '11', '11214', '3440036', '埼玉県', 'サイタマケン', '春日部市', 'カスカベシ', '下大増新田', 'シモオオマシシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県春日部市上大増新田', '11', '11214', '3440037', '埼玉県', 'サイタマケン', '春日部市', 'カスカベシ', '上大増新田', 'カミオオマシシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県春日部市大沼', '11', '11214', '3440038', '埼玉県', 'サイタマケン', '春日部市', 'カスカベシ', '大沼', 'オオヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県春日部市増富', '11', '11214', '3440041', '埼玉県', 'サイタマケン', '春日部市', 'カスカベシ', '増富', 'マシトミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県春日部市増戸', '11', '11214', '3440042', '埼玉県', 'サイタマケン', '春日部市', 'カスカベシ', '増戸', 'マシト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県春日部市下蛭田', '11', '11214', '3440043', '埼玉県', 'サイタマケン', '春日部市', 'カスカベシ', '下蛭田', 'シモヒルダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県春日部市花積', '11', '11214', '3440044', '埼玉県', 'サイタマケン', '春日部市', 'カスカベシ', '花積', 'ハナヅミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県春日部市道口蛭田', '11', '11214', '3440045', '埼玉県', 'サイタマケン', '春日部市', 'カスカベシ', '道口蛭田', 'ドウグチヒルダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県春日部市上蛭田', '11', '11214', '3440046', '埼玉県', 'サイタマケン', '春日部市', 'カスカベシ', '上蛭田', 'カミヒルダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県春日部市道順川戸', '11', '11214', '3440047', '埼玉県', 'サイタマケン', '春日部市', 'カスカベシ', '道順川戸', 'ドウジュンカワド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県春日部市南中曽根', '11', '11214', '3440048', '埼玉県', 'サイタマケン', '春日部市', 'カスカベシ', '南中曽根', 'ミナミナカゾネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県春日部市内牧', '11', '11214', '3440051', '埼玉県', 'サイタマケン', '春日部市', 'カスカベシ', '内牧', 'ウチマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県春日部市梅田', '11', '11214', '3440052', '埼玉県', 'サイタマケン', '春日部市', 'カスカベシ', '梅田', 'ウメダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県春日部市梅田本町', '11', '11214', '3440053', '埼玉県', 'サイタマケン', '春日部市', 'カスカベシ', '梅田本町', 'ウメダホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県春日部市浜川戸', '11', '11214', '3440054', '埼玉県', 'サイタマケン', '春日部市', 'カスカベシ', '浜川戸', 'ハマカワド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県春日部市八木崎町', '11', '11214', '3440055', '埼玉県', 'サイタマケン', '春日部市', 'カスカベシ', '八木崎町', 'ヤギサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県春日部市新方袋', '11', '11214', '3440056', '埼玉県', 'サイタマケン', '春日部市', 'カスカベシ', '新方袋', 'ニイガタフクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県春日部市南栄町', '11', '11214', '3440057', '埼玉県', 'サイタマケン', '春日部市', 'カスカベシ', '南栄町', 'ミナミサカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県春日部市栄町', '11', '11214', '3440058', '埼玉県', 'サイタマケン', '春日部市', 'カスカベシ', '栄町', 'サカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県春日部市西八木崎', '11', '11214', '3440059', '埼玉県', 'サイタマケン', '春日部市', 'カスカベシ', '西八木崎', 'ニシヤギサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県春日部市粕壁', '11', '11214', '3440061', '埼玉県', 'サイタマケン', '春日部市', 'カスカベシ', '粕壁', 'カスカベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県春日部市粕壁東', '11', '11214', '3440062', '埼玉県', 'サイタマケン', '春日部市', 'カスカベシ', '粕壁東', 'カスカベヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県春日部市緑町', '11', '11214', '3440063', '埼玉県', 'サイタマケン', '春日部市', 'カスカベシ', '緑町', 'ミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県春日部市南', '11', '11214', '3440064', '埼玉県', 'サイタマケン', '春日部市', 'カスカベシ', '南', 'ミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県春日部市谷原', '11', '11214', '3440065', '埼玉県', 'サイタマケン', '春日部市', 'カスカベシ', '谷原', 'ヤハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県春日部市豊町', '11', '11214', '3440066', '埼玉県', 'サイタマケン', '春日部市', 'カスカベシ', '豊町', 'ユタカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県春日部市中央', '11', '11214', '3440067', '埼玉県', 'サイタマケン', '春日部市', 'カスカベシ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県春日部市西親野井', '11', '11214', '3440101', '埼玉県', 'サイタマケン', '春日部市', 'カスカベシ', '西親野井', 'ニシオヤノイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県春日部市西宝珠花', '11', '11214', '3440102', '埼玉県', 'サイタマケン', '春日部市', 'カスカベシ', '西宝珠花', 'ニシホウシュバナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県春日部市上吉妻', '11', '11214', '3440103', '埼玉県', 'サイタマケン', '春日部市', 'カスカベシ', '上吉妻', 'カミキツマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県春日部市下吉妻', '11', '11214', '3440104', '埼玉県', 'サイタマケン', '春日部市', 'カスカベシ', '下吉妻', 'シモキツマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県春日部市小平', '11', '11214', '3440105', '埼玉県', 'サイタマケン', '春日部市', 'カスカベシ', '小平', 'コダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県春日部市木崎', '11', '11214', '3440106', '埼玉県', 'サイタマケン', '春日部市', 'カスカベシ', '木崎', 'キサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県春日部市塚崎', '11', '11214', '3440107', '埼玉県', 'サイタマケン', '春日部市', 'カスカベシ', '塚崎', 'ツカサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県春日部市上金崎', '11', '11214', '3440111', '埼玉県', 'サイタマケン', '春日部市', 'カスカベシ', '上金崎', 'カミカナサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県春日部市西金野井', '11', '11214', '3440112', '埼玉県', 'サイタマケン', '春日部市', 'カスカベシ', '西金野井', 'ニシカナノイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県春日部市新宿新田', '11', '11214', '3440113', '埼玉県', 'サイタマケン', '春日部市', 'カスカベシ', '新宿新田', 'シンシュクシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県春日部市東中野', '11', '11214', '3440114', '埼玉県', 'サイタマケン', '春日部市', 'カスカベシ', '東中野', 'ヒガシナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県春日部市米島', '11', '11214', '3440115', '埼玉県', 'サイタマケン', '春日部市', 'カスカベシ', '米島', 'コメジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県春日部市大衾', '11', '11214', '3440116', '埼玉県', 'サイタマケン', '春日部市', 'カスカベシ', '大衾', 'オオブスマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県春日部市金崎', '11', '11214', '3440117', '埼玉県', 'サイタマケン', '春日部市', 'カスカベシ', '金崎', 'カナサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県春日部市上柳', '11', '11214', '3440121', '埼玉県', 'サイタマケン', '春日部市', 'カスカベシ', '上柳', 'カミヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県春日部市下柳', '11', '11214', '3440122', '埼玉県', 'サイタマケン', '春日部市', 'カスカベシ', '下柳', 'シモヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県春日部市永沼', '11', '11214', '3440123', '埼玉県', 'サイタマケン', '春日部市', 'カスカベシ', '永沼', 'ナガヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県春日部市米崎', '11', '11214', '3440124', '埼玉県', 'サイタマケン', '春日部市', 'カスカベシ', '米崎', 'コメサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県春日部市飯沼', '11', '11214', '3440125', '埼玉県', 'サイタマケン', '春日部市', 'カスカベシ', '飯沼', 'イイヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県春日部市赤崎', '11', '11214', '3440126', '埼玉県', 'サイタマケン', '春日部市', 'カスカベシ', '赤崎', 'アカサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県春日部市水角', '11', '11214', '3440127', '埼玉県', 'サイタマケン', '春日部市', 'カスカベシ', '水角', 'スイカク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県春日部市芦橋', '11', '11214', '3440131', '埼玉県', 'サイタマケン', '春日部市', 'カスカベシ', '芦橋', 'ヨシハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県春日部市神間', '11', '11214', '3440132', '埼玉県', 'サイタマケン', '春日部市', 'カスカベシ', '神間', 'カンマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県春日部市椚', '11', '11214', '3440133', '埼玉県', 'サイタマケン', '春日部市', 'カスカベシ', '椚', 'クヌギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県春日部市立野', '11', '11214', '3440134', '埼玉県', 'サイタマケン', '春日部市', 'カスカベシ', '立野', 'タテノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県春日部市榎', '11', '11214', '3440135', '埼玉県', 'サイタマケン', '春日部市', 'カスカベシ', '榎', 'エノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県春日部市倉常', '11', '11214', '3440136', '埼玉県', 'サイタマケン', '春日部市', 'カスカベシ', '倉常', 'クラツネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県南埼玉郡宮代町', '11', '11442', '3450000', '埼玉県', 'サイタマケン', '南埼玉郡宮代町', 'ミナミサイタマグンミヤシロマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('26938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北葛飾郡杉戸町', '11', '11464', '3450000', '埼玉県', 'サイタマケン', '北葛飾郡杉戸町', 'キタカツシカグンスギトマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('26939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北葛飾郡杉戸町木津内', '11', '11464', '3450001', '埼玉県', 'サイタマケン', '北葛飾郡杉戸町', 'キタカツシカグンスギトマチ', '木津内', 'キヅウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北葛飾郡杉戸町鷲巣', '11', '11464', '3450002', '埼玉県', 'サイタマケン', '北葛飾郡杉戸町', 'キタカツシカグンスギトマチ', '鷲巣', 'ワシノス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北葛飾郡杉戸町木野川', '11', '11464', '3450003', '埼玉県', 'サイタマケン', '北葛飾郡杉戸町', 'キタカツシカグンスギトマチ', '木野川', 'キノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北葛飾郡杉戸町宮前', '11', '11464', '3450004', '埼玉県', 'サイタマケン', '北葛飾郡杉戸町', 'キタカツシカグンスギトマチ', '宮前', 'ミヤマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北葛飾郡杉戸町目沼', '11', '11464', '3450005', '埼玉県', 'サイタマケン', '北葛飾郡杉戸町', 'キタカツシカグンスギトマチ', '目沼', 'メヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北葛飾郡杉戸町屏風', '11', '11464', '3450011', '埼玉県', 'サイタマケン', '北葛飾郡杉戸町', 'キタカツシカグンスギトマチ', '屏風', 'ビョウブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北葛飾郡杉戸町深輪', '11', '11464', '3450012', '埼玉県', 'サイタマケン', '北葛飾郡杉戸町', 'キタカツシカグンスギトマチ', '深輪', 'フカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北葛飾郡杉戸町椿', '11', '11464', '3450013', '埼玉県', 'サイタマケン', '北葛飾郡杉戸町', 'キタカツシカグンスギトマチ', '椿', 'ツバキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北葛飾郡杉戸町才羽', '11', '11464', '3450014', '埼玉県', 'サイタマケン', '北葛飾郡杉戸町', 'キタカツシカグンスギトマチ', '才羽', 'サイバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北葛飾郡杉戸町並塚', '11', '11464', '3450015', '埼玉県', 'サイタマケン', '北葛飾郡杉戸町', 'キタカツシカグンスギトマチ', '並塚', 'ナラビツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北葛飾郡杉戸町北蓮沼', '11', '11464', '3450021', '埼玉県', 'サイタマケン', '北葛飾郡杉戸町', 'キタカツシカグンスギトマチ', '北蓮沼', 'キタハスヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北葛飾郡杉戸町大塚', '11', '11464', '3450022', '埼玉県', 'サイタマケン', '北葛飾郡杉戸町', 'キタカツシカグンスギトマチ', '大塚', 'オオツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北葛飾郡杉戸町本郷', '11', '11464', '3450023', '埼玉県', 'サイタマケン', '北葛飾郡杉戸町', 'キタカツシカグンスギトマチ', '本郷', 'ホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北葛飾郡杉戸町堤根', '11', '11464', '3450024', '埼玉県', 'サイタマケン', '北葛飾郡杉戸町', 'キタカツシカグンスギトマチ', '堤根', 'ツツミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北葛飾郡杉戸町清地', '11', '11464', '3450025', '埼玉県', 'サイタマケン', '北葛飾郡杉戸町', 'キタカツシカグンスギトマチ', '清地', 'セイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北葛飾郡杉戸町遠野', '11', '11464', '3450031', '埼玉県', 'サイタマケン', '北葛飾郡杉戸町', 'キタカツシカグンスギトマチ', '遠野', 'トオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北葛飾郡杉戸町広戸沼', '11', '11464', '3450032', '埼玉県', 'サイタマケン', '北葛飾郡杉戸町', 'キタカツシカグンスギトマチ', '広戸沼', 'ヒロトヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北葛飾郡杉戸町佐左エ門', '11', '11464', '3450033', '埼玉県', 'サイタマケン', '北葛飾郡杉戸町', 'キタカツシカグンスギトマチ', '佐左エ門', 'サザエモン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北葛飾郡杉戸町倉松', '11', '11464', '3450034', '埼玉県', 'サイタマケン', '北葛飾郡杉戸町', 'キタカツシカグンスギトマチ', '倉松', 'クラマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北葛飾郡杉戸町内田', '11', '11464', '3450035', '埼玉県', 'サイタマケン', '北葛飾郡杉戸町', 'キタカツシカグンスギトマチ', '内田', 'ウチダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北葛飾郡杉戸町杉戸', '11', '11464', '3450036', '埼玉県', 'サイタマケン', '北葛飾郡杉戸町', 'キタカツシカグンスギトマチ', '杉戸', 'スギト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北葛飾郡杉戸町本島', '11', '11464', '3450037', '埼玉県', 'サイタマケン', '北葛飾郡杉戸町', 'キタカツシカグンスギトマチ', '本島', 'モトジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北葛飾郡杉戸町茨島', '11', '11464', '3450041', '埼玉県', 'サイタマケン', '北葛飾郡杉戸町', 'キタカツシカグンスギトマチ', '茨島', 'バラジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北葛飾郡杉戸町大島', '11', '11464', '3450042', '埼玉県', 'サイタマケン', '北葛飾郡杉戸町', 'キタカツシカグンスギトマチ', '大島', 'オオジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北葛飾郡杉戸町下高野', '11', '11464', '3450043', '埼玉県', 'サイタマケン', '北葛飾郡杉戸町', 'キタカツシカグンスギトマチ', '下高野', 'シモタカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北葛飾郡杉戸町下野', '11', '11464', '3450044', '埼玉県', 'サイタマケン', '北葛飾郡杉戸町', 'キタカツシカグンスギトマチ', '下野', 'シモノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北葛飾郡杉戸町高野台西', '11', '11464', '3450045', '埼玉県', 'サイタマケン', '北葛飾郡杉戸町', 'キタカツシカグンスギトマチ', '高野台西', 'タカノダイニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北葛飾郡杉戸町高野台南', '11', '11464', '3450046', '埼玉県', 'サイタマケン', '北葛飾郡杉戸町', 'キタカツシカグンスギトマチ', '高野台南', 'タカノダイミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北葛飾郡杉戸町高野台東', '11', '11464', '3450047', '埼玉県', 'サイタマケン', '北葛飾郡杉戸町', 'キタカツシカグンスギトマチ', '高野台東', 'タカノダイヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県南埼玉郡宮代町百間', '11', '11442', '3450801', '埼玉県', 'サイタマケン', '南埼玉郡宮代町', 'ミナミサイタマグンミヤシロマチ', '百間', 'モンマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県南埼玉郡宮代町中島', '11', '11442', '3450802', '埼玉県', 'サイタマケン', '南埼玉郡宮代町', 'ミナミサイタマグンミヤシロマチ', '中島', 'ナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県南埼玉郡宮代町宮東', '11', '11442', '3450803', '埼玉県', 'サイタマケン', '南埼玉郡宮代町', 'ミナミサイタマグンミヤシロマチ', '宮東', 'ミヤヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県南埼玉郡宮代町川端', '11', '11442', '3450804', '埼玉県', 'サイタマケン', '南埼玉郡宮代町', 'ミナミサイタマグンミヤシロマチ', '川端', 'カワバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県南埼玉郡宮代町道佛', '11', '11442', '3450811', '埼玉県', 'サイタマケン', '南埼玉郡宮代町', 'ミナミサイタマグンミヤシロマチ', '道佛', 'ドウブツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県南埼玉郡宮代町姫宮', '11', '11442', '3450812', '埼玉県', 'サイタマケン', '南埼玉郡宮代町', 'ミナミサイタマグンミヤシロマチ', '姫宮', 'ヒメミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県南埼玉郡宮代町東姫宮', '11', '11442', '3450813', '埼玉県', 'サイタマケン', '南埼玉郡宮代町', 'ミナミサイタマグンミヤシロマチ', '東姫宮', 'ヒガシヒメミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県南埼玉郡宮代町東', '11', '11442', '3450814', '埼玉県', 'サイタマケン', '南埼玉郡宮代町', 'ミナミサイタマグンミヤシロマチ', '東', 'ヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県南埼玉郡宮代町中', '11', '11442', '3450815', '埼玉県', 'サイタマケン', '南埼玉郡宮代町', 'ミナミサイタマグンミヤシロマチ', '中', 'ナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県南埼玉郡宮代町金原', '11', '11442', '3450816', '埼玉県', 'サイタマケン', '南埼玉郡宮代町', 'ミナミサイタマグンミヤシロマチ', '金原', 'カネハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県南埼玉郡宮代町西原', '11', '11442', '3450817', '埼玉県', 'サイタマケン', '南埼玉郡宮代町', 'ミナミサイタマグンミヤシロマチ', '西原', 'ニシバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県南埼玉郡宮代町中央', '11', '11442', '3450821', '埼玉県', 'サイタマケン', '南埼玉郡宮代町', 'ミナミサイタマグンミヤシロマチ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県南埼玉郡宮代町笠原', '11', '11442', '3450822', '埼玉県', 'サイタマケン', '南埼玉郡宮代町', 'ミナミサイタマグンミヤシロマチ', '笠原', 'カサハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県南埼玉郡宮代町宮代', '11', '11442', '3450823', '埼玉県', 'サイタマケン', '南埼玉郡宮代町', 'ミナミサイタマグンミヤシロマチ', '宮代', 'ミヤシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県南埼玉郡宮代町山崎', '11', '11442', '3450824', '埼玉県', 'サイタマケン', '南埼玉郡宮代町', 'ミナミサイタマグンミヤシロマチ', '山崎', 'ヤマザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県南埼玉郡宮代町逆井', '11', '11442', '3450825', '埼玉県', 'サイタマケン', '南埼玉郡宮代町', 'ミナミサイタマグンミヤシロマチ', '逆井', 'サカサイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県南埼玉郡宮代町学園台', '11', '11442', '3450826', '埼玉県', 'サイタマケン', '南埼玉郡宮代町', 'ミナミサイタマグンミヤシロマチ', '学園台', 'ガクエンダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県南埼玉郡宮代町本田', '11', '11442', '3450827', '埼玉県', 'サイタマケン', '南埼玉郡宮代町', 'ミナミサイタマグンミヤシロマチ', '本田', 'ホンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県南埼玉郡宮代町須賀', '11', '11442', '3450831', '埼玉県', 'サイタマケン', '南埼玉郡宮代町', 'ミナミサイタマグンミヤシロマチ', '須賀', 'スカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県南埼玉郡宮代町東粂原', '11', '11442', '3450832', '埼玉県', 'サイタマケン', '南埼玉郡宮代町', 'ミナミサイタマグンミヤシロマチ', '東粂原', 'ヒガシクメハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県南埼玉郡宮代町西粂原', '11', '11442', '3450833', '埼玉県', 'サイタマケン', '南埼玉郡宮代町', 'ミナミサイタマグンミヤシロマチ', '西粂原', 'ニシクメハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県南埼玉郡宮代町国納', '11', '11442', '3450834', '埼玉県', 'サイタマケン', '南埼玉郡宮代町', 'ミナミサイタマグンミヤシロマチ', '国納', 'コクノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県南埼玉郡宮代町宮代台', '11', '11442', '3450835', '埼玉県', 'サイタマケン', '南埼玉郡宮代町', 'ミナミサイタマグンミヤシロマチ', '宮代台', 'ミヤシロダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県南埼玉郡宮代町和戸', '11', '11442', '3450836', '埼玉県', 'サイタマケン', '南埼玉郡宮代町', 'ミナミサイタマグンミヤシロマチ', '和戸', 'ワド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県久喜市', '11', '11232', '3460000', '埼玉県', 'サイタマケン', '久喜市', 'クキシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('26997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県久喜市古久喜', '11', '11232', '3460001', '埼玉県', 'サイタマケン', '久喜市', 'クキシ', '古久喜', 'コグキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県久喜市野久喜', '11', '11232', '3460002', '埼玉県', 'サイタマケン', '久喜市', 'クキシ', '野久喜', 'ノグキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('26999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県久喜市中央', '11', '11232', '3460003', '埼玉県', 'サイタマケン', '久喜市', 'クキシ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県久喜市南', '11', '11232', '3460004', '埼玉県', 'サイタマケン', '久喜市', 'クキシ', '南', 'ミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県久喜市本町', '11', '11232', '3460005', '埼玉県', 'サイタマケン', '久喜市', 'クキシ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県久喜市上町', '11', '11232', '3460006', '埼玉県', 'サイタマケン', '久喜市', 'クキシ', '上町', 'カミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県久喜市北', '11', '11232', '3460007', '埼玉県', 'サイタマケン', '久喜市', 'クキシ', '北', 'キタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県久喜市青毛', '11', '11232', '3460011', '埼玉県', 'サイタマケン', '久喜市', 'クキシ', '青毛', 'アオゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県久喜市栗原', '11', '11232', '3460012', '埼玉県', 'サイタマケン', '久喜市', 'クキシ', '栗原', 'クリハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県久喜市青葉', '11', '11232', '3460013', '埼玉県', 'サイタマケン', '久喜市', 'クキシ', '青葉', 'アオバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県久喜市吉羽', '11', '11232', '3460014', '埼玉県', 'サイタマケン', '久喜市', 'クキシ', '吉羽', 'ヨシバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県久喜市西', '11', '11232', '3460015', '埼玉県', 'サイタマケン', '久喜市', 'クキシ', '西', 'ニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県久喜市東', '11', '11232', '3460016', '埼玉県', 'サイタマケン', '久喜市', 'クキシ', '東', 'ヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県久喜市上早見', '11', '11232', '3460021', '埼玉県', 'サイタマケン', '久喜市', 'クキシ', '上早見', 'カミハヤミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県久喜市下早見', '11', '11232', '3460022', '埼玉県', 'サイタマケン', '久喜市', 'クキシ', '下早見', 'シモハヤミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県久喜市太田袋', '11', '11232', '3460023', '埼玉県', 'サイタマケン', '久喜市', 'クキシ', '太田袋', 'オオタブクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県久喜市北青柳', '11', '11232', '3460024', '埼玉県', 'サイタマケン', '久喜市', 'クキシ', '北青柳', 'キタアオヤギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県久喜市樋ノ口', '11', '11232', '3460025', '埼玉県', 'サイタマケン', '久喜市', 'クキシ', '樋ノ口', 'ヒノクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県久喜市原', '11', '11232', '3460026', '埼玉県', 'サイタマケン', '久喜市', 'クキシ', '原', 'ハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県久喜市除堀', '11', '11232', '3460027', '埼玉県', 'サイタマケン', '久喜市', 'クキシ', '除堀', 'ヨケボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県久喜市河原井町', '11', '11232', '3460028', '埼玉県', 'サイタマケン', '久喜市', 'クキシ', '河原井町', 'カワライチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県久喜市江面', '11', '11232', '3460029', '埼玉県', 'サイタマケン', '久喜市', 'クキシ', '江面', 'エヅラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県久喜市久喜本', '11', '11232', '3460031', '埼玉県', 'サイタマケン', '久喜市', 'クキシ', '久喜本', 'クキホン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県久喜市久喜新', '11', '11232', '3460032', '埼玉県', 'サイタマケン', '久喜市', 'クキシ', '久喜新', 'クキシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県久喜市下清久', '11', '11232', '3460033', '埼玉県', 'サイタマケン', '久喜市', 'クキシ', '下清久', 'シモキヨク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県久喜市所久喜', '11', '11232', '3460034', '埼玉県', 'サイタマケン', '久喜市', 'クキシ', '所久喜', 'トコログキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県久喜市清久町', '11', '11232', '3460035', '埼玉県', 'サイタマケン', '久喜市', 'クキシ', '清久町', 'キヨクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県久喜市北中曽根', '11', '11232', '3460036', '埼玉県', 'サイタマケン', '久喜市', 'クキシ', '北中曽根', 'キタナカゾネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県久喜市六万部', '11', '11232', '3460037', '埼玉県', 'サイタマケン', '久喜市', 'クキシ', '六万部', 'ロクマンブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県久喜市上清久', '11', '11232', '3460038', '埼玉県', 'サイタマケン', '久喜市', 'クキシ', '上清久', 'カミキヨク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県南埼玉郡菖蒲町', '11', '11446', '3460100', '埼玉県', 'サイタマケン', '南埼玉郡菖蒲町', 'ミナミサイタマグンショウブマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('27028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県南埼玉郡菖蒲町昭和沼', '11', '11446', '3460101', '埼玉県', 'サイタマケン', '南埼玉郡菖蒲町', 'ミナミサイタマグンショウブマチ', '昭和沼', 'ショウワヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県南埼玉郡菖蒲町河原井', '11', '11446', '3460102', '埼玉県', 'サイタマケン', '南埼玉郡菖蒲町', 'ミナミサイタマグンショウブマチ', '河原井', 'カワハライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県南埼玉郡菖蒲町台', '11', '11446', '3460103', '埼玉県', 'サイタマケン', '南埼玉郡菖蒲町', 'ミナミサイタマグンショウブマチ', '台', 'ダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県南埼玉郡菖蒲町三箇', '11', '11446', '3460104', '埼玉県', 'サイタマケン', '南埼玉郡菖蒲町', 'ミナミサイタマグンショウブマチ', '三箇', 'サンガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県南埼玉郡菖蒲町新堀', '11', '11446', '3460105', '埼玉県', 'サイタマケン', '南埼玉郡菖蒲町', 'ミナミサイタマグンショウブマチ', '新堀', 'ニイボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県南埼玉郡菖蒲町菖蒲', '11', '11446', '3460106', '埼玉県', 'サイタマケン', '南埼玉郡菖蒲町', 'ミナミサイタマグンショウブマチ', '菖蒲', 'ショウブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県南埼玉郡菖蒲町上大崎', '11', '11446', '3460111', '埼玉県', 'サイタマケン', '南埼玉郡菖蒲町', 'ミナミサイタマグンショウブマチ', '上大崎', 'カミオオサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県南埼玉郡菖蒲町柴山枝郷', '11', '11446', '3460112', '埼玉県', 'サイタマケン', '南埼玉郡菖蒲町', 'ミナミサイタマグンショウブマチ', '柴山枝郷', 'シバヤマシゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県南埼玉郡菖蒲町下栢間', '11', '11446', '3460113', '埼玉県', 'サイタマケン', '南埼玉郡菖蒲町', 'ミナミサイタマグンショウブマチ', '下栢間', 'シモカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県南埼玉郡菖蒲町上栢間', '11', '11446', '3460114', '埼玉県', 'サイタマケン', '南埼玉郡菖蒲町', 'ミナミサイタマグンショウブマチ', '上栢間', 'カミカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県南埼玉郡菖蒲町小林', '11', '11446', '3460115', '埼玉県', 'サイタマケン', '南埼玉郡菖蒲町', 'ミナミサイタマグンショウブマチ', '小林', 'オバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県加須市', '11', '11210', '3470000', '埼玉県', 'サイタマケン', '加須市', 'カゾシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('27052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県加須市大越', '11', '11210', '3470001', '埼玉県', 'サイタマケン', '加須市', 'カゾシ', '大越', 'オオゴエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県加須市外野', '11', '11210', '3470002', '埼玉県', 'サイタマケン', '加須市', 'カゾシ', '外野', 'ソトノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県加須市上樋遣川', '11', '11210', '3470003', '埼玉県', 'サイタマケン', '加須市', 'カゾシ', '上樋遣川', 'カミヒヤリカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県加須市古川', '11', '11210', '3470004', '埼玉県', 'サイタマケン', '加須市', 'カゾシ', '古川', 'フルカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県加須市下樋遣川', '11', '11210', '3470005', '埼玉県', 'サイタマケン', '加須市', 'カゾシ', '下樋遣川', 'シモヒヤリカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県加須市上三俣', '11', '11210', '3470006', '埼玉県', 'サイタマケン', '加須市', 'カゾシ', '上三俣', 'カミミツマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県加須市下三俣', '11', '11210', '3470007', '埼玉県', 'サイタマケン', '加須市', 'カゾシ', '下三俣', 'シモミツマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県加須市中樋遣川', '11', '11210', '3470008', '埼玉県', 'サイタマケン', '加須市', 'カゾシ', '中樋遣川', 'ナカヒヤリカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県加須市大桑', '11', '11210', '3470010', '埼玉県', 'サイタマケン', '加須市', 'カゾシ', '大桑', 'オオクワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県加須市北小浜', '11', '11210', '3470011', '埼玉県', 'サイタマケン', '加須市', 'カゾシ', '北小浜', 'キタコバマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県加須市多門寺', '11', '11210', '3470012', '埼玉県', 'サイタマケン', '加須市', 'カゾシ', '多門寺', 'タモンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県加須市北篠崎', '11', '11210', '3470013', '埼玉県', 'サイタマケン', '加須市', 'カゾシ', '北篠崎', 'キタシノザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県加須市川口', '11', '11210', '3470014', '埼玉県', 'サイタマケン', '加須市', 'カゾシ', '川口', 'カワグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県加須市南大桑', '11', '11210', '3470015', '埼玉県', 'サイタマケン', '加須市', 'カゾシ', '南大桑', 'ミナミオオクワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県加須市花崎北', '11', '11210', '3470016', '埼玉県', 'サイタマケン', '加須市', 'カゾシ', '花崎北', 'ハナサキキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県加須市南篠崎', '11', '11210', '3470017', '埼玉県', 'サイタマケン', '加須市', 'カゾシ', '南篠崎', 'ミナミシノザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県加須市浜町', '11', '11210', '3470018', '埼玉県', 'サイタマケン', '加須市', 'カゾシ', '浜町', 'ハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県加須市鳩山町', '11', '11210', '3470019', '埼玉県', 'サイタマケン', '加須市', 'カゾシ', '鳩山町', 'ハトヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県加須市船越', '11', '11210', '3470021', '埼玉県', 'サイタマケン', '加須市', 'カゾシ', '船越', 'フナコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県加須市水深', '11', '11210', '3470022', '埼玉県', 'サイタマケン', '加須市', 'カゾシ', '水深', 'ミズブカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県加須市北辻', '11', '11210', '3470023', '埼玉県', 'サイタマケン', '加須市', 'カゾシ', '北辻', 'キタツジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県加須市今鉾', '11', '11210', '3470024', '埼玉県', 'サイタマケン', '加須市', 'カゾシ', '今鉾', 'イマボコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県加須市割目', '11', '11210', '3470025', '埼玉県', 'サイタマケン', '加須市', 'カゾシ', '割目', 'ワリメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県加須市油井ケ島', '11', '11210', '3470026', '埼玉県', 'サイタマケン', '加須市', 'カゾシ', '油井ケ島', 'ユイガシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県加須市大室', '11', '11210', '3470027', '埼玉県', 'サイタマケン', '加須市', 'カゾシ', '大室', 'オオムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県加須市南小浜', '11', '11210', '3470028', '埼玉県', 'サイタマケン', '加須市', 'カゾシ', '南小浜', 'ミナミオバマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県加須市南町', '11', '11210', '3470031', '埼玉県', 'サイタマケン', '加須市', 'カゾシ', '南町', 'ミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県加須市花崎', '11', '11210', '3470032', '埼玉県', 'サイタマケン', '加須市', 'カゾシ', '花崎', 'ハナサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県加須市下高柳', '11', '11210', '3470033', '埼玉県', 'サイタマケン', '加須市', 'カゾシ', '下高柳', 'シモタカヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県加須市常泉', '11', '11210', '3470034', '埼玉県', 'サイタマケン', '加須市', 'カゾシ', '常泉', 'ツネイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県加須市串作', '11', '11210', '3470041', '埼玉県', 'サイタマケン', '加須市', 'カゾシ', '串作', 'クシツクリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県加須市志多見', '11', '11210', '3470042', '埼玉県', 'サイタマケン', '加須市', 'カゾシ', '志多見', 'シダミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県加須市馬内', '11', '11210', '3470043', '埼玉県', 'サイタマケン', '加須市', 'カゾシ', '馬内', 'モウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県加須市礼羽', '11', '11210', '3470044', '埼玉県', 'サイタマケン', '加須市', 'カゾシ', '礼羽', 'ライハ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県加須市富士見町', '11', '11210', '3470045', '埼玉県', 'サイタマケン', '加須市', 'カゾシ', '富士見町', 'フジミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県加須市平永', '11', '11210', '3470046', '埼玉県', 'サイタマケン', '加須市', 'カゾシ', '平永', 'ヒラナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県加須市阿良川', '11', '11210', '3470047', '埼玉県', 'サイタマケン', '加須市', 'カゾシ', '阿良川', 'アラカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県加須市戸川', '11', '11210', '3470051', '埼玉県', 'サイタマケン', '加須市', 'カゾシ', '戸川', 'トガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県加須市町屋新田', '11', '11210', '3470052', '埼玉県', 'サイタマケン', '加須市', 'カゾシ', '町屋新田', 'マチヤシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県加須市下谷', '11', '11210', '3470053', '埼玉県', 'サイタマケン', '加須市', 'カゾシ', '下谷', 'シモヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県加須市不動岡', '11', '11210', '3470054', '埼玉県', 'サイタマケン', '加須市', 'カゾシ', '不動岡', 'フドウオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県加須市中央', '11', '11210', '3470055', '埼玉県', 'サイタマケン', '加須市', 'カゾシ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県加須市土手', '11', '11210', '3470056', '埼玉県', 'サイタマケン', '加須市', 'カゾシ', '土手', 'ドテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県加須市愛宕', '11', '11210', '3470057', '埼玉県', 'サイタマケン', '加須市', 'カゾシ', '愛宕', 'アタゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県加須市岡古井', '11', '11210', '3470058', '埼玉県', 'サイタマケン', '加須市', 'カゾシ', '岡古井', 'オカフルイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県加須市諏訪', '11', '11210', '3470061', '埼玉県', 'サイタマケン', '加須市', 'カゾシ', '諏訪', 'スワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県加須市睦町', '11', '11210', '3470062', '埼玉県', 'サイタマケン', '加須市', 'カゾシ', '睦町', 'ムツミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県加須市久下', '11', '11210', '3470063', '埼玉県', 'サイタマケン', '加須市', 'カゾシ', '久下', 'クゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県加須市東栄', '11', '11210', '3470064', '埼玉県', 'サイタマケン', '加須市', 'カゾシ', '東栄', 'トウエイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県加須市元町', '11', '11210', '3470065', '埼玉県', 'サイタマケン', '加須市', 'カゾシ', '元町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県加須市本町', '11', '11210', '3470066', '埼玉県', 'サイタマケン', '加須市', 'カゾシ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県加須市向川岸町', '11', '11210', '3470067', '埼玉県', 'サイタマケン', '加須市', 'カゾシ', '向川岸町', 'ムコウガシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県加須市大門町', '11', '11210', '3470068', '埼玉県', 'サイタマケン', '加須市', 'カゾシ', '大門町', 'ダイモンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北埼玉郡騎西町', '11', '11421', '3470100', '埼玉県', 'サイタマケン', '北埼玉郡騎西町', 'キタサイタマグンキサイマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('27106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北埼玉郡騎西町上高柳', '11', '11421', '3470101', '埼玉県', 'サイタマケン', '北埼玉郡騎西町', 'キタサイタマグンキサイマチ', '上高柳', 'カミタカヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北埼玉郡騎西町日出安', '11', '11421', '3470102', '埼玉県', 'サイタマケン', '北埼玉郡騎西町', 'キタサイタマグンキサイマチ', '日出安', 'ヒデヤス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北埼玉郡騎西町牛重', '11', '11421', '3470103', '埼玉県', 'サイタマケン', '北埼玉郡騎西町', 'キタサイタマグンキサイマチ', '牛重', 'ウシガサネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北埼玉郡騎西町根古屋', '11', '11421', '3470104', '埼玉県', 'サイタマケン', '北埼玉郡騎西町', 'キタサイタマグンキサイマチ', '根古屋', 'ネゴヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北埼玉郡騎西町騎西', '11', '11421', '3470105', '埼玉県', 'サイタマケン', '北埼玉郡騎西町', 'キタサイタマグンキサイマチ', '騎西', 'キサイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北埼玉郡騎西町外川', '11', '11421', '3470106', '埼玉県', 'サイタマケン', '北埼玉郡騎西町', 'キタサイタマグンキサイマチ', '外川', 'ソトカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北埼玉郡騎西町正能', '11', '11421', '3470107', '埼玉県', 'サイタマケン', '北埼玉郡騎西町', 'キタサイタマグンキサイマチ', '正能', 'ショウノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北埼玉郡騎西町戸崎', '11', '11421', '3470108', '埼玉県', 'サイタマケン', '北埼玉郡騎西町', 'キタサイタマグンキサイマチ', '戸崎', 'トサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北埼玉郡騎西町鴻茎', '11', '11421', '3470111', '埼玉県', 'サイタマケン', '北埼玉郡騎西町', 'キタサイタマグンキサイマチ', '鴻茎', 'コウグキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北埼玉郡騎西町芋茎', '11', '11421', '3470112', '埼玉県', 'サイタマケン', '北埼玉郡騎西町', 'キタサイタマグンキサイマチ', '芋茎', 'イモグキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北埼玉郡騎西町下種足', '11', '11421', '3470113', '埼玉県', 'サイタマケン', '北埼玉郡騎西町', 'キタサイタマグンキサイマチ', '下種足', 'シモタナダレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北埼玉郡騎西町中種足', '11', '11421', '3470114', '埼玉県', 'サイタマケン', '北埼玉郡騎西町', 'キタサイタマグンキサイマチ', '中種足', 'ナカタナダレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北埼玉郡騎西町上種足', '11', '11421', '3470115', '埼玉県', 'サイタマケン', '北埼玉郡騎西町', 'キタサイタマグンキサイマチ', '上種足', 'カミタナダレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北埼玉郡騎西町戸室', '11', '11421', '3470116', '埼玉県', 'サイタマケン', '北埼玉郡騎西町', 'キタサイタマグンキサイマチ', '戸室', 'トムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北埼玉郡騎西町西ノ谷', '11', '11421', '3470117', '埼玉県', 'サイタマケン', '北埼玉郡騎西町', 'キタサイタマグンキサイマチ', '西ノ谷', 'ニシノヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北埼玉郡騎西町道地', '11', '11421', '3470121', '埼玉県', 'サイタマケン', '北埼玉郡騎西町', 'キタサイタマグンキサイマチ', '道地', 'ドウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北埼玉郡騎西町内田ケ谷', '11', '11421', '3470122', '埼玉県', 'サイタマケン', '北埼玉郡騎西町', 'キタサイタマグンキサイマチ', '内田ケ谷', 'ウチタガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北埼玉郡騎西町下崎', '11', '11421', '3470123', '埼玉県', 'サイタマケン', '北埼玉郡騎西町', 'キタサイタマグンキサイマチ', '下崎', 'シモサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北埼玉郡騎西町中ノ目', '11', '11421', '3470124', '埼玉県', 'サイタマケン', '北埼玉郡騎西町', 'キタサイタマグンキサイマチ', '中ノ目', 'ナカノメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北埼玉郡騎西町上崎', '11', '11421', '3470125', '埼玉県', 'サイタマケン', '北埼玉郡騎西町', 'キタサイタマグンキサイマチ', '上崎', 'カミサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北埼玉郡騎西町外田ケ谷', '11', '11421', '3470126', '埼玉県', 'サイタマケン', '北埼玉郡騎西町', 'キタサイタマグンキサイマチ', '外田ケ谷', 'ソトタガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県羽生市', '11', '11216', '3480000', '埼玉県', 'サイタマケン', '羽生市', 'ハニュウシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('27140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県羽生市堤', '11', '11216', '3480001', '埼玉県', 'サイタマケン', '羽生市', 'ハニュウシ', '堤', 'ツツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県羽生市名', '11', '11216', '3480002', '埼玉県', 'サイタマケン', '羽生市', 'ハニュウシ', '名', 'ミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県羽生市常木', '11', '11216', '3480003', '埼玉県', 'サイタマケン', '羽生市', 'ハニュウシ', '常木', 'ツネギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県羽生市弥勒', '11', '11216', '3480004', '埼玉県', 'サイタマケン', '羽生市', 'ハニュウシ', '弥勒', 'ミロク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県羽生市上村君', '11', '11216', '3480005', '埼玉県', 'サイタマケン', '羽生市', 'ハニュウシ', '上村君', 'カミムラキミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県羽生市下村君', '11', '11216', '3480006', '埼玉県', 'サイタマケン', '羽生市', 'ハニュウシ', '下村君', 'シモムラキミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県羽生市三田ケ谷', '11', '11216', '3480011', '埼玉県', 'サイタマケン', '羽生市', 'ハニュウシ', '三田ケ谷', 'ミタカヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県羽生市与兵エ新田', '11', '11216', '3480012', '埼玉県', 'サイタマケン', '羽生市', 'ハニュウシ', '与兵エ新田', 'ヨヘエシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県羽生市日野手新田', '11', '11216', '3480013', '埼玉県', 'サイタマケン', '羽生市', 'ハニュウシ', '日野手新田', 'ヒノテシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県羽生市喜右エ門新田', '11', '11216', '3480014', '埼玉県', 'サイタマケン', '羽生市', 'ハニュウシ', '喜右エ門新田', 'キウエモンシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県羽生市北荻島', '11', '11216', '3480015', '埼玉県', 'サイタマケン', '羽生市', 'ハニュウシ', '北荻島', 'キタオギシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県羽生市大沼', '11', '11216', '3480016', '埼玉県', 'サイタマケン', '羽生市', 'ハニュウシ', '大沼', 'オオヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県羽生市今泉', '11', '11216', '3480017', '埼玉県', 'サイタマケン', '羽生市', 'ハニュウシ', '今泉', 'イマイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県羽生市中手子林', '11', '11216', '3480021', '埼玉県', 'サイタマケン', '羽生市', 'ハニュウシ', '中手子林', 'ナカテコバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県羽生市下手子林', '11', '11216', '3480022', '埼玉県', 'サイタマケン', '羽生市', 'ハニュウシ', '下手子林', 'シモテコバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県羽生市町屋', '11', '11216', '3480023', '埼玉県', 'サイタマケン', '羽生市', 'ハニュウシ', '町屋', 'マチヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県羽生市神戸', '11', '11216', '3480024', '埼玉県', 'サイタマケン', '羽生市', 'ハニュウシ', '神戸', 'ゴウド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県羽生市上手子林', '11', '11216', '3480025', '埼玉県', 'サイタマケン', '羽生市', 'ハニュウシ', '上手子林', 'カミテコバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県羽生市下羽生', '11', '11216', '3480026', '埼玉県', 'サイタマケン', '羽生市', 'ハニュウシ', '下羽生', 'シモハニュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県羽生市上羽生', '11', '11216', '3480027', '埼玉県', 'サイタマケン', '羽生市', 'ハニュウシ', '上羽生', 'カミハニュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県羽生市北袋', '11', '11216', '3480028', '埼玉県', 'サイタマケン', '羽生市', 'ハニュウシ', '北袋', 'キタブクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県羽生市加羽ケ崎', '11', '11216', '3480031', '埼玉県', 'サイタマケン', '羽生市', 'ハニュウシ', '加羽ケ崎', 'カバガサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県羽生市秀安', '11', '11216', '3480032', '埼玉県', 'サイタマケン', '羽生市', 'ハニュウシ', '秀安', 'ヒデヤス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県羽生市須影', '11', '11216', '3480033', '埼玉県', 'サイタマケン', '羽生市', 'ハニュウシ', '須影', 'スカゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県羽生市下川崎', '11', '11216', '3480034', '埼玉県', 'サイタマケン', '羽生市', 'ハニュウシ', '下川崎', 'シモカワサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県羽生市上川崎', '11', '11216', '3480035', '埼玉県', 'サイタマケン', '羽生市', 'ハニュウシ', '上川崎', 'カミカワサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県羽生市砂山', '11', '11216', '3480036', '埼玉県', 'サイタマケン', '羽生市', 'ハニュウシ', '砂山', 'スナヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県羽生市小松', '11', '11216', '3480037', '埼玉県', 'サイタマケン', '羽生市', 'ハニュウシ', '小松', 'コマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県羽生市小松台', '11', '11216', '3480038', '埼玉県', 'サイタマケン', '羽生市', 'ハニュウシ', '小松台', 'コマツダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県羽生市川崎', '11', '11216', '3480039', '埼玉県', 'サイタマケン', '羽生市', 'ハニュウシ', '川崎', 'カワサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県羽生市上新郷', '11', '11216', '3480041', '埼玉県', 'サイタマケン', '羽生市', 'ハニュウシ', '上新郷', 'カミシンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県羽生市小須賀', '11', '11216', '3480042', '埼玉県', 'サイタマケン', '羽生市', 'ハニュウシ', '小須賀', 'コスカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県羽生市桑崎', '11', '11216', '3480043', '埼玉県', 'サイタマケン', '羽生市', 'ハニュウシ', '桑崎', 'クワサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県羽生市上岩瀬', '11', '11216', '3480044', '埼玉県', 'サイタマケン', '羽生市', 'ハニュウシ', '上岩瀬', 'カミイワセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県羽生市下岩瀬', '11', '11216', '3480045', '埼玉県', 'サイタマケン', '羽生市', 'ハニュウシ', '下岩瀬', 'シモイワセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県羽生市中岩瀬', '11', '11216', '3480046', '埼玉県', 'サイタマケン', '羽生市', 'ハニュウシ', '中岩瀬', 'ナカイワセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県羽生市下新郷', '11', '11216', '3480047', '埼玉県', 'サイタマケン', '羽生市', 'ハニュウシ', '下新郷', 'シモシンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県羽生市下新田', '11', '11216', '3480048', '埼玉県', 'サイタマケン', '羽生市', 'ハニュウシ', '下新田', 'シモシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県羽生市本川俣', '11', '11216', '3480051', '埼玉県', 'サイタマケン', '羽生市', 'ハニュウシ', '本川俣', 'ホンカワマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県羽生市東', '11', '11216', '3480052', '埼玉県', 'サイタマケン', '羽生市', 'ハニュウシ', '東', 'ヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県羽生市南', '11', '11216', '3480053', '埼玉県', 'サイタマケン', '羽生市', 'ハニュウシ', '南', 'ミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県羽生市西', '11', '11216', '3480054', '埼玉県', 'サイタマケン', '羽生市', 'ハニュウシ', '西', 'ニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県羽生市羽生', '11', '11216', '3480055', '埼玉県', 'サイタマケン', '羽生市', 'ハニュウシ', '羽生', 'ハニュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県羽生市上川俣', '11', '11216', '3480056', '埼玉県', 'サイタマケン', '羽生市', 'ハニュウシ', '上川俣', 'カミカワマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県羽生市北', '11', '11216', '3480057', '埼玉県', 'サイタマケン', '羽生市', 'ハニュウシ', '北', 'キタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県羽生市中央', '11', '11216', '3480058', '埼玉県', 'サイタマケン', '羽生市', 'ハニュウシ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県羽生市稲子', '11', '11216', '3480061', '埼玉県', 'サイタマケン', '羽生市', 'ハニュウシ', '稲子', 'イナゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県羽生市尾崎', '11', '11216', '3480062', '埼玉県', 'サイタマケン', '羽生市', 'ハニュウシ', '尾崎', 'オサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県羽生市発戸', '11', '11216', '3480063', '埼玉県', 'サイタマケン', '羽生市', 'ハニュウシ', '発戸', 'ホット', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県羽生市藤井上組', '11', '11216', '3480064', '埼玉県', 'サイタマケン', '羽生市', 'ハニュウシ', '藤井上組', 'フジイカミグミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県羽生市藤井下組', '11', '11216', '3480065', '埼玉県', 'サイタマケン', '羽生市', 'ハニュウシ', '藤井下組', 'フジイシモグミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県羽生市南羽生', '11', '11216', '3480071', '埼玉県', 'サイタマケン', '羽生市', 'ハニュウシ', '南羽生', 'ミナミハニュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県蓮田市', '11', '11238', '3490100', '埼玉県', 'サイタマケン', '蓮田市', 'ハスダシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('27215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県蓮田市黒浜', '11', '11238', '3490101', '埼玉県', 'サイタマケン', '蓮田市', 'ハスダシ', '黒浜', 'クロハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県蓮田市江ケ崎', '11', '11238', '3490102', '埼玉県', 'サイタマケン', '蓮田市', 'ハスダシ', '江ケ崎', 'エガサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県蓮田市笹山', '11', '11238', '3490103', '埼玉県', 'サイタマケン', '蓮田市', 'ハスダシ', '笹山', 'ササヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県蓮田市緑町', '11', '11238', '3490104', '埼玉県', 'サイタマケン', '蓮田市', 'ハスダシ', '緑町', 'ミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県蓮田市東', '11', '11238', '3490111', '埼玉県', 'サイタマケン', '蓮田市', 'ハスダシ', '東', 'ヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県蓮田市川島', '11', '11238', '3490112', '埼玉県', 'サイタマケン', '蓮田市', 'ハスダシ', '川島', 'カワジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県蓮田市桜台', '11', '11238', '3490113', '埼玉県', 'サイタマケン', '蓮田市', 'ハスダシ', '桜台', 'サクラダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県蓮田市馬込', '11', '11238', '3490114', '埼玉県', 'サイタマケン', '蓮田市', 'ハスダシ', '馬込', 'マゴメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県蓮田市蓮田', '11', '11238', '3490115', '埼玉県', 'サイタマケン', '蓮田市', 'ハスダシ', '蓮田', 'ハスダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県蓮田市関山', '11', '11238', '3490121', '埼玉県', 'サイタマケン', '蓮田市', 'ハスダシ', '関山', 'セキヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県蓮田市上', '11', '11238', '3490122', '埼玉県', 'サイタマケン', '蓮田市', 'ハスダシ', '上', 'カミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県蓮田市本町', '11', '11238', '3490123', '埼玉県', 'サイタマケン', '蓮田市', 'ハスダシ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県蓮田市末広', '11', '11238', '3490124', '埼玉県', 'サイタマケン', '蓮田市', 'ハスダシ', '末広', 'スエヒロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県蓮田市御前橋', '11', '11238', '3490125', '埼玉県', 'サイタマケン', '蓮田市', 'ハスダシ', '御前橋', 'オマエバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県蓮田市綾瀬', '11', '11238', '3490126', '埼玉県', 'サイタマケン', '蓮田市', 'ハスダシ', '綾瀬', 'アヤセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県蓮田市見沼町', '11', '11238', '3490127', '埼玉県', 'サイタマケン', '蓮田市', 'ハスダシ', '見沼町', 'ミヌマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県蓮田市山ノ内', '11', '11238', '3490128', '埼玉県', 'サイタマケン', '蓮田市', 'ハスダシ', '山ノ内', 'ヤマノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県蓮田市根金', '11', '11238', '3490131', '埼玉県', 'サイタマケン', '蓮田市', 'ハスダシ', '根金', 'ネガネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県蓮田市貝塚', '11', '11238', '3490132', '埼玉県', 'サイタマケン', '蓮田市', 'ハスダシ', '貝塚', 'カイヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県蓮田市閏戸', '11', '11238', '3490133', '埼玉県', 'サイタマケン', '蓮田市', 'ハスダシ', '閏戸', 'ウルイド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県蓮田市駒崎', '11', '11238', '3490134', '埼玉県', 'サイタマケン', '蓮田市', 'ハスダシ', '駒崎', 'コマサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県蓮田市井沼', '11', '11238', '3490135', '埼玉県', 'サイタマケン', '蓮田市', 'ハスダシ', '井沼', 'イヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県蓮田市上平野', '11', '11238', '3490136', '埼玉県', 'サイタマケン', '蓮田市', 'ハスダシ', '上平野', 'カミヒラノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県蓮田市高虫', '11', '11238', '3490137', '埼玉県', 'サイタマケン', '蓮田市', 'ハスダシ', '高虫', 'タカムシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県蓮田市西新宿', '11', '11238', '3490141', '埼玉県', 'サイタマケン', '蓮田市', 'ハスダシ', '西新宿', 'ニシシンシュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県蓮田市南新宿', '11', '11238', '3490142', '埼玉県', 'サイタマケン', '蓮田市', 'ハスダシ', '南新宿', 'ミナミシンシュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県蓮田市城', '11', '11238', '3490143', '埼玉県', 'サイタマケン', '蓮田市', 'ハスダシ', '城', 'ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県蓮田市椿山', '11', '11238', '3490144', '埼玉県', 'サイタマケン', '蓮田市', 'ハスダシ', '椿山', 'ツバキヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県蓮田市西城', '11', '11238', '3490145', '埼玉県', 'サイタマケン', '蓮田市', 'ハスダシ', '西城', 'ニシジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県南埼玉郡白岡町', '11', '11445', '3490200', '埼玉県', 'サイタマケン', '南埼玉郡白岡町', 'ミナミサイタマグンシラオカマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('27250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県南埼玉郡白岡町柴山', '11', '11445', '3490201', '埼玉県', 'サイタマケン', '南埼玉郡白岡町', 'ミナミサイタマグンシラオカマチ', '柴山', 'シバヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県南埼玉郡白岡町荒井新田', '11', '11445', '3490202', '埼玉県', 'サイタマケン', '南埼玉郡白岡町', 'ミナミサイタマグンシラオカマチ', '荒井新田', 'アライシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県南埼玉郡白岡町下大崎', '11', '11445', '3490203', '埼玉県', 'サイタマケン', '南埼玉郡白岡町', 'ミナミサイタマグンシラオカマチ', '下大崎', 'シモオオサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県南埼玉郡白岡町篠津', '11', '11445', '3490204', '埼玉県', 'サイタマケン', '南埼玉郡白岡町', 'ミナミサイタマグンシラオカマチ', '篠津', 'シノヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県南埼玉郡白岡町西', '11', '11445', '3490205', '埼玉県', 'サイタマケン', '南埼玉郡白岡町', 'ミナミサイタマグンシラオカマチ', '西', 'ニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県南埼玉郡白岡町野牛', '11', '11445', '3490211', '埼玉県', 'サイタマケン', '南埼玉郡白岡町', 'ミナミサイタマグンシラオカマチ', '野牛', 'ヤギュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県南埼玉郡白岡町新白岡', '11', '11445', '3490212', '埼玉県', 'サイタマケン', '南埼玉郡白岡町', 'ミナミサイタマグンシラオカマチ', '新白岡', 'シンシラオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県南埼玉郡白岡町高岩', '11', '11445', '3490213', '埼玉県', 'サイタマケン', '南埼玉郡白岡町', 'ミナミサイタマグンシラオカマチ', '高岩', 'タカイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県南埼玉郡白岡町寺塚', '11', '11445', '3490214', '埼玉県', 'サイタマケン', '南埼玉郡白岡町', 'ミナミサイタマグンシラオカマチ', '寺塚', 'テラツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県南埼玉郡白岡町千駄野', '11', '11445', '3490215', '埼玉県', 'サイタマケン', '南埼玉郡白岡町', 'ミナミサイタマグンシラオカマチ', '千駄野', 'センダノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県南埼玉郡白岡町実ケ谷', '11', '11445', '3490216', '埼玉県', 'サイタマケン', '南埼玉郡白岡町', 'ミナミサイタマグンシラオカマチ', '実ケ谷', 'サナガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県南埼玉郡白岡町小久喜', '11', '11445', '3490217', '埼玉県', 'サイタマケン', '南埼玉郡白岡町', 'ミナミサイタマグンシラオカマチ', '小久喜', 'コグキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県南埼玉郡白岡町白岡', '11', '11445', '3490218', '埼玉県', 'サイタマケン', '南埼玉郡白岡町', 'ミナミサイタマグンシラオカマチ', '白岡', 'シラオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県南埼玉郡白岡町白岡東', '11', '11445', '3490219', '埼玉県', 'サイタマケン', '南埼玉郡白岡町', 'ミナミサイタマグンシラオカマチ', '白岡東', 'シラオカヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県南埼玉郡白岡町上野田', '11', '11445', '3490221', '埼玉県', 'サイタマケン', '南埼玉郡白岡町', 'ミナミサイタマグンシラオカマチ', '上野田', 'カミノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県南埼玉郡白岡町爪田ケ谷', '11', '11445', '3490222', '埼玉県', 'サイタマケン', '南埼玉郡白岡町', 'ミナミサイタマグンシラオカマチ', '爪田ケ谷', 'ツメタガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県南埼玉郡白岡町下野田', '11', '11445', '3490223', '埼玉県', 'サイタマケン', '南埼玉郡白岡町', 'ミナミサイタマグンシラオカマチ', '下野田', 'シモノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県南埼玉郡白岡町彦兵衛', '11', '11445', '3490224', '埼玉県', 'サイタマケン', '南埼玉郡白岡町', 'ミナミサイタマグンシラオカマチ', '彦兵衛', 'ヒコベエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県南埼玉郡白岡町太田新井', '11', '11445', '3490225', '埼玉県', 'サイタマケン', '南埼玉郡白岡町', 'ミナミサイタマグンシラオカマチ', '太田新井', 'オオタアライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県南埼玉郡白岡町岡泉', '11', '11445', '3490226', '埼玉県', 'サイタマケン', '南埼玉郡白岡町', 'ミナミサイタマグンシラオカマチ', '岡泉', 'オカイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北埼玉郡大利根町', '11', '11425', '3491100', '埼玉県', 'サイタマケン', '北埼玉郡大利根町', 'キタサイタマグンオオトネマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('27274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北葛飾郡栗橋町', '11', '11461', '3491100', '埼玉県', 'サイタマケン', '北葛飾郡栗橋町', 'キタカツシカグンクリハシマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('27275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北葛飾郡栗橋町北', '11', '11461', '3491101', '埼玉県', 'サイタマケン', '北葛飾郡栗橋町', 'キタカツシカグンクリハシマチ', '北', 'キタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北葛飾郡栗橋町中央', '11', '11461', '3491102', '埼玉県', 'サイタマケン', '北葛飾郡栗橋町', 'キタカツシカグンクリハシマチ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北葛飾郡栗橋町東', '11', '11461', '3491103', '埼玉県', 'サイタマケン', '北葛飾郡栗橋町', 'キタカツシカグンクリハシマチ', '東', 'ヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北葛飾郡栗橋町栗橋', '11', '11461', '3491104', '埼玉県', 'サイタマケン', '北葛飾郡栗橋町', 'キタカツシカグンクリハシマチ', '栗橋', 'クリハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北葛飾郡栗橋町小右衛門', '11', '11461', '3491105', '埼玉県', 'サイタマケン', '北葛飾郡栗橋町', 'キタカツシカグンクリハシマチ', '小右衛門', 'コウエモン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北葛飾郡栗橋町緑', '11', '11461', '3491106', '埼玉県', 'サイタマケン', '北葛飾郡栗橋町', 'キタカツシカグンクリハシマチ', '緑', 'ミドリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北葛飾郡栗橋町北広島', '11', '11461', '3491111', '埼玉県', 'サイタマケン', '北葛飾郡栗橋町', 'キタカツシカグンクリハシマチ', '北広島', 'キタヒロシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北葛飾郡栗橋町中里', '11', '11461', '3491112', '埼玉県', 'サイタマケン', '北葛飾郡栗橋町', 'キタカツシカグンクリハシマチ', '中里', 'ナカザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北葛飾郡栗橋町狐塚', '11', '11461', '3491113', '埼玉県', 'サイタマケン', '北葛飾郡栗橋町', 'キタカツシカグンクリハシマチ', '狐塚', 'キツネヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北葛飾郡栗橋町河原代', '11', '11461', '3491114', '埼玉県', 'サイタマケン', '北葛飾郡栗橋町', 'キタカツシカグンクリハシマチ', '河原代', 'カワハラダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北葛飾郡栗橋町新井', '11', '11461', '3491115', '埼玉県', 'サイタマケン', '北葛飾郡栗橋町', 'キタカツシカグンクリハシマチ', '新井', 'アライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北葛飾郡栗橋町島川', '11', '11461', '3491116', '埼玉県', 'サイタマケン', '北葛飾郡栗橋町', 'キタカツシカグンクリハシマチ', '島川', 'シマガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北葛飾郡栗橋町南栗橋', '11', '11461', '3491117', '埼玉県', 'サイタマケン', '北葛飾郡栗橋町', 'キタカツシカグンクリハシマチ', '南栗橋', 'ミナミクリハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北葛飾郡栗橋町伊坂', '11', '11461', '3491121', '埼玉県', 'サイタマケン', '北葛飾郡栗橋町', 'キタカツシカグンクリハシマチ', '伊坂', 'イサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北葛飾郡栗橋町松永', '11', '11461', '3491122', '埼玉県', 'サイタマケン', '北葛飾郡栗橋町', 'キタカツシカグンクリハシマチ', '松永', 'マツナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北葛飾郡栗橋町間鎌', '11', '11461', '3491123', '埼玉県', 'サイタマケン', '北葛飾郡栗橋町', 'キタカツシカグンクリハシマチ', '間鎌', 'マガマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北葛飾郡栗橋町佐間', '11', '11461', '3491124', '埼玉県', 'サイタマケン', '北葛飾郡栗橋町', 'キタカツシカグンクリハシマチ', '佐間', 'サマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北葛飾郡栗橋町高柳', '11', '11461', '3491125', '埼玉県', 'サイタマケン', '北葛飾郡栗橋町', 'キタカツシカグンクリハシマチ', '高柳', 'タカヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北埼玉郡大利根町中渡', '11', '11425', '3491131', '埼玉県', 'サイタマケン', '北埼玉郡大利根町', 'キタサイタマグンオオトネマチ', '中渡', 'ナカワタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北埼玉郡大利根町旗井', '11', '11425', '3491132', '埼玉県', 'サイタマケン', '北埼玉郡大利根町', 'キタサイタマグンオオトネマチ', '旗井', 'ハタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北埼玉郡大利根町琴寄', '11', '11425', '3491133', '埼玉県', 'サイタマケン', '北埼玉郡大利根町', 'キタサイタマグンオオトネマチ', '琴寄', 'コトヨリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北埼玉郡大利根町北下新井', '11', '11425', '3491134', '埼玉県', 'サイタマケン', '北埼玉郡大利根町', 'キタサイタマグンオオトネマチ', '北下新井', 'キタシモアライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北埼玉郡大利根町北平野', '11', '11425', '3491135', '埼玉県', 'サイタマケン', '北埼玉郡大利根町', 'キタサイタマグンオオトネマチ', '北平野', 'キタヒラノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北埼玉郡大利根町松永新田', '11', '11425', '3491141', '埼玉県', 'サイタマケン', '北埼玉郡大利根町', 'キタサイタマグンオオトネマチ', '松永新田', 'マツナガシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北埼玉郡大利根町杓子木', '11', '11425', '3491142', '埼玉県', 'サイタマケン', '北埼玉郡大利根町', 'キタサイタマグンオオトネマチ', '杓子木', 'シャクシギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北埼玉郡大利根町生出', '11', '11425', '3491143', '埼玉県', 'サイタマケン', '北埼玉郡大利根町', 'キタサイタマグンオオトネマチ', '生出', 'オイデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北埼玉郡大利根町阿佐間', '11', '11425', '3491144', '埼玉県', 'サイタマケン', '北埼玉郡大利根町', 'キタサイタマグンオオトネマチ', '阿佐間', 'アザマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北埼玉郡大利根町間口', '11', '11425', '3491145', '埼玉県', 'サイタマケン', '北埼玉郡大利根町', 'キタサイタマグンオオトネマチ', '間口', 'マクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北埼玉郡大利根町新井新田', '11', '11425', '3491146', '埼玉県', 'サイタマケン', '北埼玉郡大利根町', 'キタサイタマグンオオトネマチ', '新井新田', 'アライシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北埼玉郡大利根町北大桑', '11', '11425', '3491147', '埼玉県', 'サイタマケン', '北埼玉郡大利根町', 'キタサイタマグンオオトネマチ', '北大桑', 'キタオオクワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北埼玉郡大利根町豊野台', '11', '11425', '3491148', '埼玉県', 'サイタマケン', '北埼玉郡大利根町', 'キタサイタマグンオオトネマチ', '豊野台', 'トヨノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北埼玉郡大利根町佐波', '11', '11425', '3491151', '埼玉県', 'サイタマケン', '北埼玉郡大利根町', 'キタサイタマグンオオトネマチ', '佐波', 'ザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北埼玉郡大利根町弥兵衛', '11', '11425', '3491152', '埼玉県', 'サイタマケン', '北埼玉郡大利根町', 'キタサイタマグンオオトネマチ', '弥兵衛', 'ヤヘエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北埼玉郡大利根町新川通', '11', '11425', '3491153', '埼玉県', 'サイタマケン', '北埼玉郡大利根町', 'キタサイタマグンオオトネマチ', '新川通', 'シンカワドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北埼玉郡大利根町外記新田', '11', '11425', '3491154', '埼玉県', 'サイタマケン', '北埼玉郡大利根町', 'キタサイタマグンオオトネマチ', '外記新田', 'ゲキシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北埼玉郡大利根町砂原', '11', '11425', '3491155', '埼玉県', 'サイタマケン', '北埼玉郡大利根町', 'キタサイタマグンオオトネマチ', '砂原', 'スナハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北埼玉郡大利根町細間', '11', '11425', '3491156', '埼玉県', 'サイタマケン', '北埼玉郡大利根町', 'キタサイタマグンオオトネマチ', '細間', 'ホソマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北埼玉郡大利根町道目', '11', '11425', '3491157', '埼玉県', 'サイタマケン', '北埼玉郡大利根町', 'キタサイタマグンオオトネマチ', '道目', 'ドウメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北埼玉郡大利根町新利根', '11', '11425', '3491158', '埼玉県', 'サイタマケン', '北埼玉郡大利根町', 'キタサイタマグンオオトネマチ', '新利根', 'シントネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北埼玉郡北川辺町', '11', '11424', '3491200', '埼玉県', 'サイタマケン', '北埼玉郡北川辺町', 'キタサイタマグンキタカワベマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('27318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北埼玉郡北川辺町柳生', '11', '11424', '3491201', '埼玉県', 'サイタマケン', '北埼玉郡北川辺町', 'キタサイタマグンキタカワベマチ', '柳生', 'ヤギュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北埼玉郡北川辺町小野袋', '11', '11424', '3491202', '埼玉県', 'サイタマケン', '北埼玉郡北川辺町', 'キタサイタマグンキタカワベマチ', '小野袋', 'オノフクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北埼玉郡北川辺町柏戸', '11', '11424', '3491203', '埼玉県', 'サイタマケン', '北埼玉郡北川辺町', 'キタサイタマグンキタカワベマチ', '柏戸', 'カシワド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北埼玉郡北川辺町陽光台', '11', '11424', '3491204', '埼玉県', 'サイタマケン', '北埼玉郡北川辺町', 'キタサイタマグンキタカワベマチ', '陽光台', 'ヨウコウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北埼玉郡北川辺町向古河', '11', '11424', '3491205', '埼玉県', 'サイタマケン', '北埼玉郡北川辺町', 'キタサイタマグンキタカワベマチ', '向古河', 'ムカイコガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北埼玉郡北川辺町飯積', '11', '11424', '3491211', '埼玉県', 'サイタマケン', '北埼玉郡北川辺町', 'キタサイタマグンキタカワベマチ', '飯積', 'イイヅミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北埼玉郡北川辺町麦倉', '11', '11424', '3491212', '埼玉県', 'サイタマケン', '北埼玉郡北川辺町', 'キタサイタマグンキタカワベマチ', '麦倉', 'ムギクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北埼玉郡北川辺町栄', '11', '11424', '3491213', '埼玉県', 'サイタマケン', '北埼玉郡北川辺町', 'キタサイタマグンキタカワベマチ', '栄', 'サカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北埼玉郡北川辺町駒場', '11', '11424', '3491214', '埼玉県', 'サイタマケン', '北埼玉郡北川辺町', 'キタサイタマグンキタカワベマチ', '駒場', 'コマバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北埼玉郡北川辺町伊賀袋', '11', '11424', '3491215', '埼玉県', 'サイタマケン', '北埼玉郡北川辺町', 'キタサイタマグンキタカワベマチ', '伊賀袋', 'イガフクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北埼玉郡北川辺町本郷', '11', '11424', '3491216', '埼玉県', 'サイタマケン', '北埼玉郡北川辺町', 'キタサイタマグンキタカワベマチ', '本郷', 'ホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '栃木県下都賀郡藤岡町下宮', '09', '09366', '3491221', '栃木県', 'トチギケン', '下都賀郡藤岡町', 'シモツガグンフジオカマチ', '下宮', 'シタミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県むつ市', '02', '02208', '0350000', '青森県', 'アオモリケン', 'むつ市', 'ムツシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('27333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県下北郡東通村', '02', '02424', '0350000', '青森県', 'アオモリケン', '下北郡東通村', 'シモキタグンヒガシドオリムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('27334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市古谷上', '11', '11201', '3500001', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '古谷上', 'フルヤカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市古谷本郷', '11', '11201', '3500002', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '古谷本郷', 'フルヤホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市八ツ島', '11', '11201', '3500003', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '八ツ島', 'ヤツシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市高島', '11', '11201', '3500004', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '高島', 'タカシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県下北郡東通村大利', '02', '02424', '0350001', '青森県', 'アオモリケン', '下北郡東通村', 'シモキタグンヒガシドオリムラ', '大利', 'オオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市久下戸', '11', '11201', '3500011', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '久下戸', 'クゲド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市萱沼', '11', '11201', '3500012', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '萱沼', 'カイヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市渋井', '11', '11201', '3500013', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '渋井', 'シブイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市古市場', '11', '11201', '3500014', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '古市場', 'フルイチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市今泉', '11', '11201', '3500015', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '今泉', 'イマイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市木野目', '11', '11201', '3500016', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '木野目', 'キノメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市牛子', '11', '11201', '3500017', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '牛子', 'ウシコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市藤木町', '11', '11201', '3500018', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '藤木町', 'フジキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県下北郡東通村目名', '02', '02424', '0350002', '青森県', 'アオモリケン', '下北郡東通村', 'シモキタグンヒガシドオリムラ', '目名', 'メナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市大中居', '11', '11201', '3500021', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '大中居', 'オオナカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市小中居', '11', '11201', '3500022', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '小中居', 'コナカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市並木', '11', '11201', '3500023', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '並木', 'ナミキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市並木新町', '11', '11201', '3500024', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '並木新町', 'ナミキシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市並木西町', '11', '11201', '3500025', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '並木西町', 'ナミキニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市泉町', '11', '11201', '3500026', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '泉町', 'イズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市南田島', '11', '11201', '3500027', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '南田島', 'ミナミタジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県下北郡東通村野牛', '02', '02424', '0350003', '青森県', 'アオモリケン', '下北郡東通村', 'シモキタグンヒガシドオリムラ', '野牛', 'ノウシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県下北郡東通村野牛トクサ沢', '02', '02424', '0350003', '青森県', 'アオモリケン', '下北郡東通村', 'シモキタグンヒガシドオリムラ', '野牛', 'ノウシ', null, null, 'トクサ沢', 'トクサザワ');
INSERT INTO `ms_addresses` VALUES ('27357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市小仙波', '11', '11201', '3500031', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '小仙波', 'コセンバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市大仙波', '11', '11201', '3500032', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '大仙波', 'オオセンバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市富士見町', '11', '11201', '3500033', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '富士見町', 'フジミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市仙波町', '11', '11201', '3500034', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '仙波町', 'センバマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市西小仙波町', '11', '11201', '3500035', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '西小仙波町', 'ニシコセンバマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市小仙波町', '11', '11201', '3500036', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '小仙波町', 'コセンバマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県下北郡東通村蒲野沢', '02', '02424', '0350004', '青森県', 'アオモリケン', '下北郡東通村', 'シモキタグンヒガシドオリムラ', '蒲野沢', 'ガマノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市六軒町', '11', '11201', '3500041', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '六軒町', 'ロッケンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市中原町', '11', '11201', '3500042', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '中原町', 'ナカハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市新富町', '11', '11201', '3500043', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '新富町', 'シントミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市通町', '11', '11201', '3500044', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '通町', 'トオリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市南通町', '11', '11201', '3500045', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '南通町', 'ミナミトオリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市菅原町', '11', '11201', '3500046', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '菅原町', 'スガワラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県下北郡東通村田屋', '02', '02424', '0350005', '青森県', 'アオモリケン', '下北郡東通村', 'シモキタグンヒガシドオリムラ', '田屋', 'タヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市志多町', '11', '11201', '3500051', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '志多町', 'シタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市宮下町', '11', '11201', '3500052', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '宮下町', 'ミヤシタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市郭町', '11', '11201', '3500053', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '郭町', 'クルワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市三久保町', '11', '11201', '3500054', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '三久保町', 'サンクボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市久保町', '11', '11201', '3500055', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '久保町', 'クボマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市松江町', '11', '11201', '3500056', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '松江町', 'マツエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市大手町', '11', '11201', '3500057', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '大手町', 'オオテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市喜多町', '11', '11201', '3500061', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '喜多町', 'キタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市元町', '11', '11201', '3500062', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '元町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市幸町', '11', '11201', '3500063', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市末広町', '11', '11201', '3500064', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '末広町', 'スエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市仲町', '11', '11201', '3500065', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '仲町', 'ナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市連雀町', '11', '11201', '3500066', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '連雀町', 'レンジャクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市三光町', '11', '11201', '3500067', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '三光町', 'サンコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡川島町', '11', '11346', '3500100', '埼玉県', 'サイタマケン', '比企郡川島町', 'ヒキグンカワジママチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('27386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡川島町梅ノ木', '11', '11346', '3500101', '埼玉県', 'サイタマケン', '比企郡川島町', 'ヒキグンカワジママチ', '梅ノ木', 'ウメノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡川島町下小見野', '11', '11346', '3500102', '埼玉県', 'サイタマケン', '比企郡川島町', 'ヒキグンカワジママチ', '下小見野', 'シモオミノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡川島町松永', '11', '11346', '3500103', '埼玉県', 'サイタマケン', '比企郡川島町', 'ヒキグンカワジママチ', '松永', 'マツナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡川島町芝沼', '11', '11346', '3500104', '埼玉県', 'サイタマケン', '比企郡川島町', 'ヒキグンカワジママチ', '芝沼', 'シバヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡川島町小見野', '11', '11346', '3500105', '埼玉県', 'サイタマケン', '比企郡川島町', 'ヒキグンカワジママチ', '小見野', 'オミノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡川島町上小見野', '11', '11346', '3500106', '埼玉県', 'サイタマケン', '比企郡川島町', 'ヒキグンカワジママチ', '上小見野', 'カミオミノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡川島町加胡', '11', '11346', '3500107', '埼玉県', 'サイタマケン', '比企郡川島町', 'ヒキグンカワジママチ', '加胡', 'カゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県むつ市奥内', '02', '02208', '0350011', '青森県', 'アオモリケン', 'むつ市', 'ムツシ', '奥内', 'オクナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡川島町谷中', '11', '11346', '3500111', '埼玉県', 'サイタマケン', '比企郡川島町', 'ヒキグンカワジママチ', '谷中', 'ヤナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡川島町鳥羽井新田', '11', '11346', '3500112', '埼玉県', 'サイタマケン', '比企郡川島町', 'ヒキグンカワジママチ', '鳥羽井新田', 'トバイシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡川島町東部', '11', '11346', '3500113', '埼玉県', 'サイタマケン', '比企郡川島町', 'ヒキグンカワジママチ', '東部', 'トウブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡川島町東大塚', '11', '11346', '3500114', '埼玉県', 'サイタマケン', '比企郡川島町', 'ヒキグンカワジママチ', '東大塚', 'ヒガシオオヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡川島町一本木', '11', '11346', '3500115', '埼玉県', 'サイタマケン', '比企郡川島町', 'ヒキグンカワジママチ', '一本木', 'イッポンギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡川島町虫塚', '11', '11346', '3500116', '埼玉県', 'サイタマケン', '比企郡川島町', 'ヒキグンカワジママチ', '虫塚', 'ムシヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡川島町鳥羽井', '11', '11346', '3500117', '埼玉県', 'サイタマケン', '比企郡川島町', 'ヒキグンカワジママチ', '鳥羽井', 'トバイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県むつ市中野沢', '02', '02208', '0350012', '青森県', 'アオモリケン', 'むつ市', 'ムツシ', '中野沢', 'ナカノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡川島町上八ツ林', '11', '11346', '3500121', '埼玉県', 'サイタマケン', '比企郡川島町', 'ヒキグンカワジママチ', '上八ツ林', 'カミヤツバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡川島町下八ツ林', '11', '11346', '3500122', '埼玉県', 'サイタマケン', '比企郡川島町', 'ヒキグンカワジママチ', '下八ツ林', 'シモヤツバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡川島町畑中', '11', '11346', '3500123', '埼玉県', 'サイタマケン', '比企郡川島町', 'ヒキグンカワジママチ', '畑中', 'ハタナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡川島町三保谷宿', '11', '11346', '3500124', '埼玉県', 'サイタマケン', '比企郡川島町', 'ヒキグンカワジママチ', '三保谷宿', 'ミホヤジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡川島町東野', '11', '11346', '3500125', '埼玉県', 'サイタマケン', '比企郡川島町', 'ヒキグンカワジママチ', '東野', 'ヒガシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡川島町山ケ谷戸', '11', '11346', '3500126', '埼玉県', 'サイタマケン', '比企郡川島町', 'ヒキグンカワジママチ', '山ケ谷戸', 'ヤマガヤト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡川島町牛ケ谷戸', '11', '11346', '3500127', '埼玉県', 'サイタマケン', '比企郡川島町', 'ヒキグンカワジママチ', '牛ケ谷戸', 'ウシガヤト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡川島町白井沼', '11', '11346', '3500128', '埼玉県', 'サイタマケン', '比企郡川島町', 'ヒキグンカワジママチ', '白井沼', 'シロイヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡川島町平沼', '11', '11346', '3500131', '埼玉県', 'サイタマケン', '比企郡川島町', 'ヒキグンカワジママチ', '平沼', 'ヒラヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡川島町紫竹', '11', '11346', '3500132', '埼玉県', 'サイタマケン', '比企郡川島町', 'ヒキグンカワジママチ', '紫竹', 'シチク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡川島町表', '11', '11346', '3500133', '埼玉県', 'サイタマケン', '比企郡川島町', 'ヒキグンカワジママチ', '表', 'オモテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡川島町新堀', '11', '11346', '3500134', '埼玉県', 'サイタマケン', '比企郡川島町', 'ヒキグンカワジママチ', '新堀', 'ニイボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡川島町下狢', '11', '11346', '3500135', '埼玉県', 'サイタマケン', '比企郡川島町', 'ヒキグンカワジママチ', '下狢', 'シモムジナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡川島町上狢', '11', '11346', '3500136', '埼玉県', 'サイタマケン', '比企郡川島町', 'ヒキグンカワジママチ', '上狢', 'カミムジナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡川島町宮前', '11', '11346', '3500137', '埼玉県', 'サイタマケン', '比企郡川島町', 'ヒキグンカワジママチ', '宮前', 'ミヤマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡川島町吉原', '11', '11346', '3500138', '埼玉県', 'サイタマケン', '比企郡川島町', 'ヒキグンカワジママチ', '吉原', 'ヨシワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡川島町出丸下郷', '11', '11346', '3500141', '埼玉県', 'サイタマケン', '比企郡川島町', 'ヒキグンカワジママチ', '出丸下郷', 'デマルシモゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡川島町上大屋敷', '11', '11346', '3500142', '埼玉県', 'サイタマケン', '比企郡川島町', 'ヒキグンカワジママチ', '上大屋敷', 'カミオオヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡川島町出丸中郷', '11', '11346', '3500143', '埼玉県', 'サイタマケン', '比企郡川島町', 'ヒキグンカワジママチ', '出丸中郷', 'デマルナカゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡川島町下大屋敷', '11', '11346', '3500144', '埼玉県', 'サイタマケン', '比企郡川島町', 'ヒキグンカワジママチ', '下大屋敷', 'シモオオヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡川島町出丸本', '11', '11346', '3500145', '埼玉県', 'サイタマケン', '比企郡川島町', 'ヒキグンカワジママチ', '出丸本', 'デマルホン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡川島町曲師', '11', '11346', '3500146', '埼玉県', 'サイタマケン', '比企郡川島町', 'ヒキグンカワジママチ', '曲師', 'マゲシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡川島町西谷', '11', '11346', '3500147', '埼玉県', 'サイタマケン', '比企郡川島町', 'ヒキグンカワジママチ', '西谷', 'ニシヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡川島町八幡', '11', '11346', '3500151', '埼玉県', 'サイタマケン', '比企郡川島町', 'ヒキグンカワジママチ', '八幡', 'ハチマン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡川島町上伊草', '11', '11346', '3500152', '埼玉県', 'サイタマケン', '比企郡川島町', 'ヒキグンカワジママチ', '上伊草', 'カミイグサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡川島町飯島', '11', '11346', '3500153', '埼玉県', 'サイタマケン', '比企郡川島町', 'ヒキグンカワジママチ', '飯島', 'イイジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡川島町安塚', '11', '11346', '3500154', '埼玉県', 'サイタマケン', '比企郡川島町', 'ヒキグンカワジママチ', '安塚', 'ヤスヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡川島町釘無', '11', '11346', '3500155', '埼玉県', 'サイタマケン', '比企郡川島町', 'ヒキグンカワジママチ', '釘無', 'クギナシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡川島町角泉', '11', '11346', '3500156', '埼玉県', 'サイタマケン', '比企郡川島町', 'ヒキグンカワジママチ', '角泉', 'カクセン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡川島町下伊草', '11', '11346', '3500157', '埼玉県', 'サイタマケン', '比企郡川島町', 'ヒキグンカワジママチ', '下伊草', 'シモイグサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡川島町伊草', '11', '11346', '3500158', '埼玉県', 'サイタマケン', '比企郡川島町', 'ヒキグンカワジママチ', '伊草', 'イグサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡川島町長楽', '11', '11346', '3500161', '埼玉県', 'サイタマケン', '比企郡川島町', 'ヒキグンカワジママチ', '長楽', 'ナガラク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡川島町正直', '11', '11346', '3500162', '埼玉県', 'サイタマケン', '比企郡川島町', 'ヒキグンカワジママチ', '正直', 'ショウジキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡川島町北園部', '11', '11346', '3500163', '埼玉県', 'サイタマケン', '比企郡川島町', 'ヒキグンカワジママチ', '北園部', 'キタソノベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡川島町吹塚', '11', '11346', '3500164', '埼玉県', 'サイタマケン', '比企郡川島町', 'ヒキグンカワジママチ', '吹塚', 'フキヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡川島町中山', '11', '11346', '3500165', '埼玉県', 'サイタマケン', '比企郡川島町', 'ヒキグンカワジママチ', '中山', 'ナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡川島町戸守', '11', '11346', '3500166', '埼玉県', 'サイタマケン', '比企郡川島町', 'ヒキグンカワジママチ', '戸守', 'トモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡川島町南園部', '11', '11346', '3500167', '埼玉県', 'サイタマケン', '比企郡川島町', 'ヒキグンカワジママチ', '南園部', 'ミナミソノベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県坂戸市', '11', '11239', '3500200', '埼玉県', 'サイタマケン', '坂戸市', 'サカドシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('27444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県坂戸市赤尾', '11', '11239', '3500201', '埼玉県', 'サイタマケン', '坂戸市', 'サカドシ', '赤尾', 'アカオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県坂戸市小沼', '11', '11239', '3500202', '埼玉県', 'サイタマケン', '坂戸市', 'サカドシ', '小沼', 'コヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県坂戸市横沼', '11', '11239', '3500203', '埼玉県', 'サイタマケン', '坂戸市', 'サカドシ', '横沼', 'ヨコヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県坂戸市紺屋', '11', '11239', '3500204', '埼玉県', 'サイタマケン', '坂戸市', 'サカドシ', '紺屋', 'コウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県坂戸市東坂戸', '11', '11239', '3500205', '埼玉県', 'サイタマケン', '坂戸市', 'サカドシ', '東坂戸', 'ヒガシサカド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県坂戸市中小坂', '11', '11239', '3500206', '埼玉県', 'サイタマケン', '坂戸市', 'サカドシ', '中小坂', 'ナカオサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県坂戸市青木', '11', '11239', '3500207', '埼玉県', 'サイタマケン', '坂戸市', 'サカドシ', '青木', 'アオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県坂戸市戸宮', '11', '11239', '3500208', '埼玉県', 'サイタマケン', '坂戸市', 'サカドシ', '戸宮', 'トミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県坂戸市塚越', '11', '11239', '3500209', '埼玉県', 'サイタマケン', '坂戸市', 'サカドシ', '塚越', 'ツカゴシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県むつ市田名部', '02', '02208', '0350021', '青森県', 'アオモリケン', 'むつ市', 'ムツシ', '田名部', 'タナブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県坂戸市島田', '11', '11239', '3500211', '埼玉県', 'サイタマケン', '坂戸市', 'サカドシ', '島田', 'シマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県坂戸市石井', '11', '11239', '3500212', '埼玉県', 'サイタマケン', '坂戸市', 'サカドシ', '石井', 'イシイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県坂戸市栄', '11', '11239', '3500213', '埼玉県', 'サイタマケン', '坂戸市', 'サカドシ', '栄', 'サカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県坂戸市千代田', '11', '11239', '3500214', '埼玉県', 'サイタマケン', '坂戸市', 'サカドシ', '千代田', 'チヨダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県坂戸市関間', '11', '11239', '3500215', '埼玉県', 'サイタマケン', '坂戸市', 'サカドシ', '関間', 'セキマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県坂戸市柳町', '11', '11239', '3500216', '埼玉県', 'サイタマケン', '坂戸市', 'サカドシ', '柳町', 'ヤナギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県坂戸市坂戸', '11', '11239', '3500217', '埼玉県', 'サイタマケン', '坂戸市', 'サカドシ', '坂戸', 'サカド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県坂戸市片柳新田', '11', '11239', '3500218', '埼玉県', 'サイタマケン', '坂戸市', 'サカドシ', '片柳新田', 'カタヤナギシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県坂戸市片柳', '11', '11239', '3500219', '埼玉県', 'サイタマケン', '坂戸市', 'サカドシ', '片柳', 'カタヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県むつ市関根', '02', '02208', '0350022', '青森県', 'アオモリケン', 'むつ市', 'ムツシ', '関根', 'セキネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県坂戸市鎌倉町', '11', '11239', '3500221', '埼玉県', 'サイタマケン', '坂戸市', 'サカドシ', '鎌倉町', 'カマクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県坂戸市清水町', '11', '11239', '3500222', '埼玉県', 'サイタマケン', '坂戸市', 'サカドシ', '清水町', 'シミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県坂戸市八幡', '11', '11239', '3500223', '埼玉県', 'サイタマケン', '坂戸市', 'サカドシ', '八幡', 'ヤハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県坂戸市山田町', '11', '11239', '3500224', '埼玉県', 'サイタマケン', '坂戸市', 'サカドシ', '山田町', 'ヤマタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県坂戸市日の出町', '11', '11239', '3500225', '埼玉県', 'サイタマケン', '坂戸市', 'サカドシ', '日の出町', 'ヒノデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県坂戸市本町', '11', '11239', '3500226', '埼玉県', 'サイタマケン', '坂戸市', 'サカドシ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県坂戸市仲町', '11', '11239', '3500227', '埼玉県', 'サイタマケン', '坂戸市', 'サカドシ', '仲町', 'ナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県坂戸市元町', '11', '11239', '3500228', '埼玉県', 'サイタマケン', '坂戸市', 'サカドシ', '元町', 'モトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県坂戸市薬師町', '11', '11239', '3500229', '埼玉県', 'サイタマケン', '坂戸市', 'サカドシ', '薬師町', 'ヤクシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県坂戸市泉町', '11', '11239', '3500231', '埼玉県', 'サイタマケン', '坂戸市', 'サカドシ', '泉町', 'イズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県坂戸市中富町', '11', '11239', '3500232', '埼玉県', 'サイタマケン', '坂戸市', 'サカドシ', '中富町', 'ナカトミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県坂戸市南町', '11', '11239', '3500233', '埼玉県', 'サイタマケン', '坂戸市', 'サカドシ', '南町', 'ミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県坂戸市緑町', '11', '11239', '3500234', '埼玉県', 'サイタマケン', '坂戸市', 'サカドシ', '緑町', 'ミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県坂戸市三光町', '11', '11239', '3500235', '埼玉県', 'サイタマケン', '坂戸市', 'サカドシ', '三光町', 'サンコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県坂戸市花影町', '11', '11239', '3500236', '埼玉県', 'サイタマケン', '坂戸市', 'サカドシ', '花影町', 'ハナカゲチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県坂戸市浅羽野', '11', '11239', '3500237', '埼玉県', 'サイタマケン', '坂戸市', 'サカドシ', '浅羽野', 'アサバノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県坂戸市浅羽', '11', '11239', '3500238', '埼玉県', 'サイタマケン', '坂戸市', 'サカドシ', '浅羽', 'アサバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県坂戸市粟生田', '11', '11239', '3500239', '埼玉県', 'サイタマケン', '坂戸市', 'サカドシ', '粟生田', 'アオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県坂戸市鶴舞', '11', '11239', '3500241', '埼玉県', 'サイタマケン', '坂戸市', 'サカドシ', '鶴舞', 'ツルマイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県坂戸市厚川', '11', '11239', '3500242', '埼玉県', 'サイタマケン', '坂戸市', 'サカドシ', '厚川', 'アツガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県坂戸市萱方', '11', '11239', '3500243', '埼玉県', 'サイタマケン', '坂戸市', 'サカドシ', '萱方', 'カヤガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県坂戸市森戸', '11', '11239', '3500244', '埼玉県', 'サイタマケン', '坂戸市', 'サカドシ', '森戸', 'モリド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県坂戸市四日市場', '11', '11239', '3500245', '埼玉県', 'サイタマケン', '坂戸市', 'サカドシ', '四日市場', 'ヨッカイチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県坂戸市多和目', '11', '11239', '3500246', '埼玉県', 'サイタマケン', '坂戸市', 'サカドシ', '多和目', 'タワメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県坂戸市西坂戸', '11', '11239', '3500247', '埼玉県', 'サイタマケン', '坂戸市', 'サカドシ', '西坂戸', 'ニシサカド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県坂戸市けやき台', '11', '11239', '3500248', '埼玉県', 'サイタマケン', '坂戸市', 'サカドシ', 'けやき台', 'ケヤキダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県坂戸市塚崎', '11', '11239', '3500251', '埼玉県', 'サイタマケン', '坂戸市', 'サカドシ', '塚崎', 'ツカサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県坂戸市中里', '11', '11239', '3500252', '埼玉県', 'サイタマケン', '坂戸市', 'サカドシ', '中里', 'ナカザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県坂戸市北大塚', '11', '11239', '3500253', '埼玉県', 'サイタマケン', '坂戸市', 'サカドシ', '北大塚', 'キタオオツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県坂戸市欠ノ上', '11', '11239', '3500254', '埼玉県', 'サイタマケン', '坂戸市', 'サカドシ', '欠ノ上', 'カケノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県坂戸市成願寺', '11', '11239', '3500255', '埼玉県', 'サイタマケン', '坂戸市', 'サカドシ', '成願寺', 'ジョウガンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県坂戸市善能寺', '11', '11239', '3500256', '埼玉県', 'サイタマケン', '坂戸市', 'サカドシ', '善能寺', 'ゼンノウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県坂戸市小山', '11', '11239', '3500257', '埼玉県', 'サイタマケン', '坂戸市', 'サカドシ', '小山', 'コヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県坂戸市北峰', '11', '11239', '3500258', '埼玉県', 'サイタマケン', '坂戸市', 'サカドシ', '北峰', 'キタミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県坂戸市沢木', '11', '11239', '3500261', '埼玉県', 'サイタマケン', '坂戸市', 'サカドシ', '沢木', 'サワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県坂戸市新堀', '11', '11239', '3500262', '埼玉県', 'サイタマケン', '坂戸市', 'サカドシ', '新堀', 'ニイホリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県坂戸市堀込', '11', '11239', '3500263', '埼玉県', 'サイタマケン', '坂戸市', 'サカドシ', '堀込', 'ホリゴメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県坂戸市竹之内', '11', '11239', '3500264', '埼玉県', 'サイタマケン', '坂戸市', 'サカドシ', '竹之内', 'タケノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県坂戸市長岡', '11', '11239', '3500265', '埼玉県', 'サイタマケン', '坂戸市', 'サカドシ', '長岡', 'ナガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県坂戸市北浅羽', '11', '11239', '3500266', '埼玉県', 'サイタマケン', '坂戸市', 'サカドシ', '北浅羽', 'キタアサバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県坂戸市今西', '11', '11239', '3500267', '埼玉県', 'サイタマケン', '坂戸市', 'サカドシ', '今西', 'イマニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県坂戸市金田', '11', '11239', '3500268', '埼玉県', 'サイタマケン', '坂戸市', 'サカドシ', '金田', 'カネダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県坂戸市にっさい花みず木', '11', '11239', '3500269', '埼玉県', 'サイタマケン', '坂戸市', 'サカドシ', 'にっさい花みず木', 'ニッサイハナミズキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県坂戸市上吉田', '11', '11239', '3500271', '埼玉県', 'サイタマケン', '坂戸市', 'サカドシ', '上吉田', 'カミヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県坂戸市末広町', '11', '11239', '3500272', '埼玉県', 'サイタマケン', '坂戸市', 'サカドシ', '末広町', 'スエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県坂戸市芦山町', '11', '11239', '3500273', '埼玉県', 'サイタマケン', '坂戸市', 'サカドシ', '芦山町', 'アシヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県坂戸市溝端町', '11', '11239', '3500274', '埼玉県', 'サイタマケン', '坂戸市', 'サカドシ', '溝端町', 'ミゾハタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県坂戸市伊豆の山町', '11', '11239', '3500275', '埼玉県', 'サイタマケン', '坂戸市', 'サカドシ', '伊豆の山町', 'イズノヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県坂戸市戸口', '11', '11239', '3500276', '埼玉県', 'サイタマケン', '坂戸市', 'サカドシ', '戸口', 'トグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県坂戸市東和田', '11', '11239', '3500277', '埼玉県', 'サイタマケン', '坂戸市', 'サカドシ', '東和田', 'ヒガシワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県坂戸市新ケ谷', '11', '11239', '3500278', '埼玉県', 'サイタマケン', '坂戸市', 'サカドシ', '新ケ谷', 'シンガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡鳩山町', '11', '11348', '3500300', '埼玉県', 'サイタマケン', '比企郡鳩山町', 'ヒキグンハトヤママチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('27527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡鳩山町奥田', '11', '11348', '3500301', '埼玉県', 'サイタマケン', '比企郡鳩山町', 'ヒキグンハトヤママチ', '奥田', 'オクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡鳩山町大橋', '11', '11348', '3500302', '埼玉県', 'サイタマケン', '比企郡鳩山町', 'ヒキグンハトヤママチ', '大橋', 'オオハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡鳩山町熊井', '11', '11348', '3500303', '埼玉県', 'サイタマケン', '比企郡鳩山町', 'ヒキグンハトヤママチ', '熊井', 'クマイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡鳩山町高野倉', '11', '11348', '3500304', '埼玉県', 'サイタマケン', '比企郡鳩山町', 'ヒキグンハトヤママチ', '高野倉', 'タカノクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡鳩山町泉井', '11', '11348', '3500305', '埼玉県', 'サイタマケン', '比企郡鳩山町', 'ヒキグンハトヤママチ', '泉井', 'イズイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡鳩山町竹本', '11', '11348', '3500306', '埼玉県', 'サイタマケン', '比企郡鳩山町', 'ヒキグンハトヤママチ', '竹本', 'タケモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡鳩山町須江', '11', '11348', '3500307', '埼玉県', 'サイタマケン', '比企郡鳩山町', 'ヒキグンハトヤママチ', '須江', 'スエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県むつ市柳町', '02', '02208', '0350031', '青森県', 'アオモリケン', 'むつ市', 'ムツシ', '柳町', 'ヤナギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡鳩山町石坂', '11', '11348', '3500311', '埼玉県', 'サイタマケン', '比企郡鳩山町', 'ヒキグンハトヤママチ', '石坂', 'イシザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡鳩山町鳩ケ丘', '11', '11348', '3500312', '埼玉県', 'サイタマケン', '比企郡鳩山町', 'ヒキグンハトヤママチ', '鳩ケ丘', 'ハトガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡鳩山町松ケ丘', '11', '11348', '3500313', '埼玉県', 'サイタマケン', '比企郡鳩山町', 'ヒキグンハトヤママチ', '松ケ丘', 'マツガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡鳩山町楓ケ丘', '11', '11348', '3500314', '埼玉県', 'サイタマケン', '比企郡鳩山町', 'ヒキグンハトヤママチ', '楓ケ丘', 'カエデガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県むつ市上川町', '02', '02208', '0350032', '青森県', 'アオモリケン', 'むつ市', 'ムツシ', '上川町', 'カミカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡鳩山町赤沼', '11', '11348', '3500321', '埼玉県', 'サイタマケン', '比企郡鳩山町', 'ヒキグンハトヤママチ', '赤沼', 'アカヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡鳩山町今宿', '11', '11348', '3500322', '埼玉県', 'サイタマケン', '比企郡鳩山町', 'ヒキグンハトヤママチ', '今宿', 'イマジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡鳩山町小用', '11', '11348', '3500323', '埼玉県', 'サイタマケン', '比企郡鳩山町', 'ヒキグンハトヤママチ', '小用', 'コヨウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡鳩山町大豆戸', '11', '11348', '3500324', '埼玉県', 'サイタマケン', '比企郡鳩山町', 'ヒキグンハトヤママチ', '大豆戸', 'マメド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県むつ市横迎町', '02', '02208', '0350033', '青森県', 'アオモリケン', 'むつ市', 'ムツシ', '横迎町', 'ヨコムカイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県むつ市田名部町', '02', '02208', '0350034', '青森県', 'アオモリケン', 'むつ市', 'ムツシ', '田名部町', 'タナブチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県むつ市本町', '02', '02208', '0350035', '青森県', 'アオモリケン', 'むつ市', 'ムツシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県むつ市栗山町', '02', '02208', '0350036', '青森県', 'アオモリケン', 'むつ市', 'ムツシ', '栗山町', 'クリヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県入間郡毛呂山町', '11', '11326', '3500400', '埼玉県', 'サイタマケン', '入間郡毛呂山町', 'イルマグンモロヤママチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('27554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県入間郡越生町', '11', '11327', '3500400', '埼玉県', 'サイタマケン', '入間郡越生町', 'イルマグンオゴセマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('27555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県入間郡越生町古池', '11', '11327', '3500401', '埼玉県', 'サイタマケン', '入間郡越生町', 'イルマグンオゴセマチ', '古池', 'フルイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県入間郡越生町鹿下', '11', '11327', '3500402', '埼玉県', 'サイタマケン', '入間郡越生町', 'イルマグンオゴセマチ', '鹿下', 'カノシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県入間郡越生町大谷', '11', '11327', '3500403', '埼玉県', 'サイタマケン', '入間郡越生町', 'イルマグンオゴセマチ', '大谷', 'オオヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県入間郡越生町成瀬', '11', '11327', '3500404', '埼玉県', 'サイタマケン', '入間郡越生町', 'イルマグンオゴセマチ', '成瀬', 'ナルセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県入間郡越生町津久根', '11', '11327', '3500405', '埼玉県', 'サイタマケン', '入間郡越生町', 'イルマグンオゴセマチ', '津久根', 'ツクネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県入間郡越生町堂山', '11', '11327', '3500406', '埼玉県', 'サイタマケン', '入間郡越生町', 'イルマグンオゴセマチ', '堂山', 'ドウヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県入間郡越生町上谷', '11', '11327', '3500407', '埼玉県', 'サイタマケン', '入間郡越生町', 'イルマグンオゴセマチ', '上谷', 'カミヤツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県むつ市金曲', '02', '02208', '0350041', '青森県', 'アオモリケン', 'むつ市', 'ムツシ', '金曲', 'カナマガリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県入間郡越生町黒岩', '11', '11327', '3500411', '埼玉県', 'サイタマケン', '入間郡越生町', 'イルマグンオゴセマチ', '黒岩', 'クロイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県入間郡越生町西和田', '11', '11327', '3500412', '埼玉県', 'サイタマケン', '入間郡越生町', 'イルマグンオゴセマチ', '西和田', 'ニシワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県入間郡越生町如意', '11', '11327', '3500413', '埼玉県', 'サイタマケン', '入間郡越生町', 'イルマグンオゴセマチ', '如意', 'ネオイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県入間郡越生町越生東', '11', '11327', '3500414', '埼玉県', 'サイタマケン', '入間郡越生町', 'イルマグンオゴセマチ', '越生東', 'オゴセヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県入間郡越生町上野', '11', '11327', '3500415', '埼玉県', 'サイタマケン', '入間郡越生町', 'イルマグンオゴセマチ', '上野', 'ウエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県入間郡越生町越生', '11', '11327', '3500416', '埼玉県', 'サイタマケン', '入間郡越生町', 'イルマグンオゴセマチ', '越生', 'オゴセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県入間郡越生町上野東', '11', '11327', '3500417', '埼玉県', 'サイタマケン', '入間郡越生町', 'イルマグンオゴセマチ', '上野東', 'ウエノヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県むつ市大曲', '02', '02208', '0350042', '青森県', 'アオモリケン', 'むつ市', 'ムツシ', '大曲', 'オオマガリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県入間郡越生町麦原', '11', '11327', '3500421', '埼玉県', 'サイタマケン', '入間郡越生町', 'イルマグンオゴセマチ', '麦原', 'ムギハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県入間郡越生町小杉', '11', '11327', '3500422', '埼玉県', 'サイタマケン', '入間郡越生町', 'イルマグンオゴセマチ', '小杉', 'コスギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県入間郡越生町大満', '11', '11327', '3500423', '埼玉県', 'サイタマケン', '入間郡越生町', 'イルマグンオゴセマチ', '大満', 'ダイマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県入間郡越生町黒山', '11', '11327', '3500424', '埼玉県', 'サイタマケン', '入間郡越生町', 'イルマグンオゴセマチ', '黒山', 'クロヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県入間郡越生町龍ケ谷', '11', '11327', '3500425', '埼玉県', 'サイタマケン', '入間郡越生町', 'イルマグンオゴセマチ', '龍ケ谷', 'タツガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県むつ市南赤川町', '02', '02208', '0350043', '青森県', 'アオモリケン', 'むつ市', 'ムツシ', '南赤川町', 'ミナミアカガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県入間郡毛呂山町苦林', '11', '11326', '3500431', '埼玉県', 'サイタマケン', '入間郡毛呂山町', 'イルマグンモロヤママチ', '苦林', 'ニガバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県入間郡毛呂山町大類', '11', '11326', '3500432', '埼玉県', 'サイタマケン', '入間郡毛呂山町', 'イルマグンモロヤママチ', '大類', 'オオルイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県入間郡毛呂山町西大久保', '11', '11326', '3500433', '埼玉県', 'サイタマケン', '入間郡毛呂山町', 'イルマグンモロヤママチ', '西大久保', 'ニシオオクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県入間郡毛呂山町市場', '11', '11326', '3500434', '埼玉県', 'サイタマケン', '入間郡毛呂山町', 'イルマグンモロヤママチ', '市場', 'イチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県入間郡毛呂山町下川原', '11', '11326', '3500435', '埼玉県', 'サイタマケン', '入間郡毛呂山町', 'イルマグンモロヤママチ', '下川原', 'シモガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県入間郡毛呂山町川角', '11', '11326', '3500436', '埼玉県', 'サイタマケン', '入間郡毛呂山町', 'イルマグンモロヤママチ', '川角', 'カワカド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県入間郡毛呂山町箕和田', '11', '11326', '3500437', '埼玉県', 'サイタマケン', '入間郡毛呂山町', 'イルマグンモロヤママチ', '箕和田', 'ミノワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県入間郡毛呂山町西戸', '11', '11326', '3500438', '埼玉県', 'サイタマケン', '入間郡毛呂山町', 'イルマグンモロヤママチ', '西戸', 'サイド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県入間郡毛呂山町目白台', '11', '11326', '3500439', '埼玉県', 'サイタマケン', '入間郡毛呂山町', 'イルマグンモロヤママチ', '目白台', 'メジロダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県むつ市赤川町', '02', '02208', '0350044', '青森県', 'アオモリケン', 'むつ市', 'ムツシ', '赤川町', 'アカガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県入間郡毛呂山町岩井', '11', '11326', '3500441', '埼玉県', 'サイタマケン', '入間郡毛呂山町', 'イルマグンモロヤママチ', '岩井', 'イワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県入間郡毛呂山町前久保', '11', '11326', '3500442', '埼玉県', 'サイタマケン', '入間郡毛呂山町', 'イルマグンモロヤママチ', '前久保', 'マエクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県入間郡毛呂山町長瀬', '11', '11326', '3500443', '埼玉県', 'サイタマケン', '入間郡毛呂山町', 'イルマグンモロヤママチ', '長瀬', 'ナガセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県入間郡毛呂山町旭台', '11', '11326', '3500444', '埼玉県', 'サイタマケン', '入間郡毛呂山町', 'イルマグンモロヤママチ', '旭台', 'アサヒダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県入間郡毛呂山町葛貫', '11', '11326', '3500445', '埼玉県', 'サイタマケン', '入間郡毛呂山町', 'イルマグンモロヤママチ', '葛貫', 'ツヅラヌキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県入間郡毛呂山町小田谷', '11', '11326', '3500446', '埼玉県', 'サイタマケン', '入間郡毛呂山町', 'イルマグンモロヤママチ', '小田谷', 'コダヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県むつ市松原町', '02', '02208', '0350045', '青森県', 'アオモリケン', 'むつ市', 'ムツシ', '松原町', 'マツバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県入間郡毛呂山町毛呂本郷', '11', '11326', '3500451', '埼玉県', 'サイタマケン', '入間郡毛呂山町', 'イルマグンモロヤママチ', '毛呂本郷', 'モロホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県入間郡毛呂山町大谷木', '11', '11326', '3500452', '埼玉県', 'サイタマケン', '入間郡毛呂山町', 'イルマグンモロヤママチ', '大谷木', 'オオヤギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県入間郡毛呂山町宿谷', '11', '11326', '3500453', '埼玉県', 'サイタマケン', '入間郡毛呂山町', 'イルマグンモロヤママチ', '宿谷', 'シュクヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県入間郡毛呂山町権現堂', '11', '11326', '3500454', '埼玉県', 'サイタマケン', '入間郡毛呂山町', 'イルマグンモロヤママチ', '権現堂', 'ゴンゲンドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県入間郡毛呂山町阿諏訪', '11', '11326', '3500455', '埼玉県', 'サイタマケン', '入間郡毛呂山町', 'イルマグンモロヤママチ', '阿諏訪', 'アスワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県入間郡毛呂山町滝ノ入', '11', '11326', '3500456', '埼玉県', 'サイタマケン', '入間郡毛呂山町', 'イルマグンモロヤママチ', '滝ノ入', 'タキノイリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県むつ市南町', '02', '02208', '0350046', '青森県', 'アオモリケン', 'むつ市', 'ムツシ', '南町', 'ミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県入間郡毛呂山町中央', '11', '11326', '3500461', '埼玉県', 'サイタマケン', '入間郡毛呂山町', 'イルマグンモロヤママチ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県入間郡毛呂山町若山', '11', '11326', '3500462', '埼玉県', 'サイタマケン', '入間郡毛呂山町', 'イルマグンモロヤママチ', '若山', 'ワカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県入間郡毛呂山町前久保南', '11', '11326', '3500463', '埼玉県', 'サイタマケン', '入間郡毛呂山町', 'イルマグンモロヤママチ', '前久保南', 'マエクボミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県入間郡毛呂山町南台', '11', '11326', '3500464', '埼玉県', 'サイタマケン', '入間郡毛呂山町', 'イルマグンモロヤママチ', '南台', 'ミナミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県入間郡毛呂山町岩井西', '11', '11326', '3500465', '埼玉県', 'サイタマケン', '入間郡毛呂山町', 'イルマグンモロヤママチ', '岩井西', 'イワイニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県むつ市新町', '02', '02208', '0350051', '青森県', 'アオモリケン', 'むつ市', 'ムツシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県むつ市昭和町', '02', '02208', '0350052', '青森県', 'アオモリケン', 'むつ市', 'ムツシ', '昭和町', 'ショウワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県むつ市緑町', '02', '02208', '0350053', '青森県', 'アオモリケン', 'むつ市', 'ムツシ', '緑町', 'ミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県むつ市海老川町', '02', '02208', '0350054', '青森県', 'アオモリケン', 'むつ市', 'ムツシ', '海老川町', 'エビカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県むつ市苫生町', '02', '02208', '0350055', '青森県', 'アオモリケン', 'むつ市', 'ムツシ', '苫生町', 'トマブチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県むつ市下北町', '02', '02208', '0350061', '青森県', 'アオモリケン', 'むつ市', 'ムツシ', '下北町', 'シモキタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県むつ市仲町', '02', '02208', '0350062', '青森県', 'アオモリケン', 'むつ市', 'ムツシ', '仲町', 'ナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県むつ市若松町', '02', '02208', '0350063', '青森県', 'アオモリケン', 'むつ市', 'ムツシ', '若松町', 'ワカマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県むつ市港町', '02', '02208', '0350064', '青森県', 'アオモリケン', 'むつ市', 'ムツシ', '港町', 'ミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県むつ市松山町', '02', '02208', '0350065', '青森県', 'アオモリケン', 'むつ市', 'ムツシ', '松山町', 'マツヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県むつ市緑ヶ丘', '02', '02208', '0350066', '青森県', 'アオモリケン', 'むつ市', 'ムツシ', '緑ヶ丘', 'ミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県むつ市十二林', '02', '02208', '0350067', '青森県', 'アオモリケン', 'むつ市', 'ムツシ', '十二林', 'ジュウニバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県むつ市美里町', '02', '02208', '0350068', '青森県', 'アオモリケン', 'むつ市', 'ムツシ', '美里町', 'ミサトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県むつ市小川町', '02', '02208', '0350071', '青森県', 'アオモリケン', 'むつ市', 'ムツシ', '小川町', 'コガワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県むつ市金谷', '02', '02208', '0350072', '青森県', 'アオモリケン', 'むつ市', 'ムツシ', '金谷', 'カナヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県むつ市中央', '02', '02208', '0350073', '青森県', 'アオモリケン', 'むつ市', 'ムツシ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県むつ市大平', '02', '02208', '0350074', '青森県', 'アオモリケン', 'むつ市', 'ムツシ', '大平', 'オオダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県むつ市真砂町', '02', '02208', '0350075', '青森県', 'アオモリケン', 'むつ市', 'ムツシ', '真砂町', 'マサゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県むつ市旭町', '02', '02208', '0350076', '青森県', 'アオモリケン', 'むつ市', 'ムツシ', '旭町', 'アサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県むつ市山田町', '02', '02208', '0350077', '青森県', 'アオモリケン', 'むつ市', 'ムツシ', '山田町', 'ヤマダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県むつ市松森町', '02', '02208', '0350078', '青森県', 'アオモリケン', 'むつ市', 'ムツシ', '松森町', 'マツモリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県むつ市荒川町', '02', '02208', '0350079', '青森県', 'アオモリケン', 'むつ市', 'ムツシ', '荒川町', 'アラカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市竹野', '11', '11201', '3500801', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '竹野', 'タケノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市富士見', '11', '11201', '3500802', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '富士見', 'フジミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市栄', '11', '11201', '3500803', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '栄', 'サカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市下広谷', '11', '11201', '3500804', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '下広谷', 'シモヒロヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市広谷新町', '11', '11201', '3500805', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '広谷新町', 'ヒロヤシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市天沼新田', '11', '11201', '3500806', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '天沼新田', 'アマヌマシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市吉田', '11', '11201', '3500807', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '吉田', 'ヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市吉田新町', '11', '11201', '3500808', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '吉田新町', 'ヨシダシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市鯨井新田', '11', '11201', '3500809', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '鯨井新田', 'クジライシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県むつ市並川町', '02', '02208', '0350081', '青森県', 'アオモリケン', 'むつ市', 'ムツシ', '並川町', 'ナミカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市小堤', '11', '11201', '3500811', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '小堤', 'コヅツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市下小坂', '11', '11201', '3500812', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '下小坂', 'シモオサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市平塚新田', '11', '11201', '3500813', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '平塚新田', 'ヒラツカシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市平塚', '11', '11201', '3500814', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '平塚', 'ヒラツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市鯨井', '11', '11201', '3500815', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '鯨井', 'クジライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市上戸', '11', '11201', '3500816', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '上戸', 'ウワド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市上戸新町', '11', '11201', '3500817', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '上戸新町', 'ウワドシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県むつ市文京町', '02', '02208', '0350082', '青森県', 'アオモリケン', 'むつ市', 'ムツシ', '文京町', 'ブンキョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市福田', '11', '11201', '3500821', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '福田', 'フクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市山田', '11', '11201', '3500822', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '山田', 'ヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市神明町', '11', '11201', '3500823', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '神明町', 'シンメイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市石原町', '11', '11201', '3500824', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '石原町', 'イシワラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市月吉町', '11', '11201', '3500825', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '月吉町', 'ツキヨシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市上寺山', '11', '11201', '3500826', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '上寺山', 'カミテラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市寺山', '11', '11201', '3500827', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '寺山', 'テラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県むつ市大平町', '02', '02208', '0350083', '青森県', 'アオモリケン', 'むつ市', 'ムツシ', '大平町', 'オオダイラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市府川', '11', '11201', '3500831', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '府川', 'フカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市菅間', '11', '11201', '3500832', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '菅間', 'スガマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市芳野台', '11', '11201', '3500833', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '芳野台', 'ヨシノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市鹿飼', '11', '11201', '3500834', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '鹿飼', 'シシカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市石田本郷', '11', '11201', '3500835', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '石田本郷', 'イシダホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市谷中', '11', '11201', '3500836', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '谷中', 'ヤナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市石田', '11', '11201', '3500837', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '石田', 'イシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市宮元町', '11', '11201', '3500838', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '宮元町', 'ミヤモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県むつ市大湊新町', '02', '02208', '0350084', '青森県', 'アオモリケン', 'むつ市', 'ムツシ', '大湊新町', 'オオミナトシンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市御成町', '11', '11201', '3500841', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '御成町', 'オナリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市北田島', '11', '11201', '3500842', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '北田島', 'キタタジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市東明寺', '11', '11201', '3500843', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '東明寺', 'トウミョウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市鴨田', '11', '11201', '3500844', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '鴨田', 'カモダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市上老袋', '11', '11201', '3500845', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '上老袋', 'カミオイブクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市中老袋', '11', '11201', '3500846', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '中老袋', 'ナカオイブクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市東本宿', '11', '11201', '3500847', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '東本宿', 'ヒガシホンジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市下老袋', '11', '11201', '3500848', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '下老袋', 'シモオイブクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県むつ市大湊浜町', '02', '02208', '0350085', '青森県', 'アオモリケン', 'むつ市', 'ムツシ', '大湊浜町', 'オオミナトハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市氷川町', '11', '11201', '3500851', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '氷川町', 'ヒカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市川越', '11', '11201', '3500852', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '川越', 'カワゴエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市城下町', '11', '11201', '3500853', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '城下町', 'シロシタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市寺井', '11', '11201', '3500854', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '寺井', 'テライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市伊佐沼', '11', '11201', '3500855', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '伊佐沼', 'イサヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市問屋町', '11', '11201', '3500856', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '問屋町', 'トンヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市松郷', '11', '11201', '3500857', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '松郷', 'マツゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県むつ市大湊上町', '02', '02208', '0350086', '青森県', 'アオモリケン', 'むつ市', 'ムツシ', '大湊上町', 'オオミナトカミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県むつ市川守町', '02', '02208', '0350091', '青森県', 'アオモリケン', 'むつ市', 'ムツシ', '川守町', 'カワモリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県むつ市宇田町', '02', '02208', '0350092', '青森県', 'アオモリケン', 'むつ市', 'ムツシ', '宇田町', 'ウダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県むつ市大湊町', '02', '02208', '0350093', '青森県', 'アオモリケン', 'むつ市', 'ムツシ', '大湊町', 'オオミナトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県むつ市桜木町', '02', '02208', '0350094', '青森県', 'アオモリケン', 'むつ市', 'ムツシ', '桜木町', 'サクラギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県むつ市城ケ沢', '02', '02208', '0350095', '青森県', 'アオモリケン', 'むつ市', 'ムツシ', '城ケ沢', 'ジョウガサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県むつ市大湊', '02', '02208', '0350096', '青森県', 'アオモリケン', 'むつ市', 'ムツシ', '大湊', 'オオミナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県下北郡東通村野牛', '02', '02424', '0350103', '青森県', 'アオモリケン', '下北郡東通村', 'シモキタグンヒガシドオリムラ', '野牛', 'ノウシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県下北郡東通村蒲野沢稲崎', '02', '02424', '0350104', '青森県', 'アオモリケン', '下北郡東通村', 'シモキタグンヒガシドオリムラ', '蒲野沢', 'ガマノサワ', null, null, '稲崎', 'イナザキ');
INSERT INTO `ms_addresses` VALUES ('27690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県下北郡東通村蒲野沢浜の平', '02', '02424', '0350104', '青森県', 'アオモリケン', '下北郡東通村', 'シモキタグンヒガシドオリムラ', '蒲野沢', 'ガマノサワ', null, null, '浜の平', 'ハマノタイ');
INSERT INTO `ms_addresses` VALUES ('27691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市', '11', '11201', '3501100', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('27692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市的場', '11', '11201', '3501101', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '的場', 'マトバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市的場北', '11', '11201', '3501102', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '的場北', 'マトバキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市霞ケ関東', '11', '11201', '3501103', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '霞ケ関東', 'カスミガセキヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市小ケ谷', '11', '11201', '3501104', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '小ケ谷', 'オガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市今成', '11', '11201', '3501105', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '今成', 'イマナリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市小室', '11', '11201', '3501106', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '小室', 'コムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市的場新町', '11', '11201', '3501107', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '的場新町', 'マトバシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市伊勢原町', '11', '11201', '3501108', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '伊勢原町', 'イセハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市霞ケ関北', '11', '11201', '3501109', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '霞ケ関北', 'カスミガセキキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県下北郡東通村尻屋', '02', '02424', '0350111', '青森県', 'アオモリケン', '下北郡東通村', 'シモキタグンヒガシドオリムラ', '尻屋', 'シリヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市豊田町', '11', '11201', '3501110', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '豊田町', 'トヨダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市野田', '11', '11201', '3501111', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '野田', 'ノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市上野田町', '11', '11201', '3501112', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '上野田町', 'カミノダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市田町', '11', '11201', '3501113', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '田町', 'タマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市東田町', '11', '11201', '3501114', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '東田町', 'ヒガシタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市野田町', '11', '11201', '3501115', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '野田町', 'ノダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市寿町', '11', '11201', '3501116', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '寿町', 'コトブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市広栄町', '11', '11201', '3501117', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '広栄町', 'コウエイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市豊田本', '11', '11201', '3501118', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '豊田本', 'トヨダホン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市豊田新田', '11', '11201', '3501119', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '豊田新田', 'トヨダシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県下北郡東通村尻労', '02', '02424', '0350112', '青森県', 'アオモリケン', '下北郡東通村', 'シモキタグンヒガシドオリムラ', '尻労', 'シツカリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市脇田新町', '11', '11201', '3501121', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '脇田新町', 'ワキタシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市脇田町', '11', '11201', '3501122', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '脇田町', 'ワキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市脇田本町', '11', '11201', '3501123', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '脇田本町', 'ワキタホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市新宿町', '11', '11201', '3501124', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '新宿町', 'アラジュクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市新宿', '11', '11201', '3501125', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '新宿', 'アラジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市旭町', '11', '11201', '3501126', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '旭町', 'アサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市大仙波新田', '11', '11201', '3501128', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '大仙波新田', 'オオセンバシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県下北郡東通村岩屋', '02', '02424', '0350113', '青森県', 'アオモリケン', '下北郡東通村', 'シモキタグンヒガシドオリムラ', '岩屋', 'イワヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市岸町', '11', '11201', '3501131', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '岸町', 'キシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市岸', '11', '11201', '3501132', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '岸', 'キシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市砂', '11', '11201', '3501133', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '砂', 'スナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市扇河岸', '11', '11201', '3501134', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '扇河岸', 'オウギガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市上新河岸', '11', '11201', '3501135', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '上新河岸', 'カミシンガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市下新河岸', '11', '11201', '3501136', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '下新河岸', 'シモシンガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市砂新田', '11', '11201', '3501137', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '砂新田', 'スナシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市寺尾', '11', '11201', '3501141', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '寺尾', 'テラオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市藤間', '11', '11201', '3501142', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '藤間', 'フジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市藤原町', '11', '11201', '3501143', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '藤原町', 'フジワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市稲荷町', '11', '11201', '3501144', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '稲荷町', 'イナリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市清水町', '11', '11201', '3501145', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '清水町', 'シミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市熊野町', '11', '11201', '3501146', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '熊野町', 'クマノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市諏訪町', '11', '11201', '3501147', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '諏訪町', 'スワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市今福', '11', '11201', '3501151', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '今福', 'イマフク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市砂久保', '11', '11201', '3501152', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '砂久保', 'スナクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市下松原', '11', '11201', '3501153', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '下松原', 'シモマツバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市上松原', '11', '11201', '3501154', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '上松原', 'カミマツバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市下赤坂', '11', '11201', '3501155', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '下赤坂', 'シモアカサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市中福', '11', '11201', '3501156', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '中福', 'ナカフク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市中福東', '11', '11201', '3501157', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '中福東', 'ナカフクヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市日東町', '11', '11201', '3501160', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '日東町', 'ニットウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市大塚新田', '11', '11201', '3501161', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '大塚新田', 'オオツカシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市南大塚', '11', '11201', '3501162', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '南大塚', 'ミナミオオツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市四都野台', '11', '11201', '3501163', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '四都野台', 'ヨツヤダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市青柳', '11', '11201', '3501164', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '青柳', 'アオヤギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市南台', '11', '11201', '3501165', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '南台', 'ミナミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市藤倉', '11', '11201', '3501166', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '藤倉', 'フジクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市大袋新田', '11', '11201', '3501167', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '大袋新田', 'オオフクロシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市大袋', '11', '11201', '3501168', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '大袋', 'オオフクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市山城', '11', '11201', '3501169', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '山城', 'ヤマシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市むさし野', '11', '11201', '3501170', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', 'むさし野', 'ムサシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市池辺', '11', '11201', '3501171', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '池辺', 'イケノベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市増形', '11', '11201', '3501172', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '増形', 'マスカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市安比奈新田', '11', '11201', '3501173', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '安比奈新田', 'アイナシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市かすみ野', '11', '11201', '3501174', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', 'かすみ野', 'カスミノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市笠幡', '11', '11201', '3501175', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '笠幡', 'カサハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市川鶴', '11', '11201', '3501176', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '川鶴', 'カワツル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市かわつる三芳野', '11', '11201', '3501177', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', 'かわつる三芳野', 'カワツルミヨシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県川越市大塚新町', '11', '11201', '3501178', '埼玉県', 'サイタマケン', '川越市', 'カワゴエシ', '大塚新町', 'オオツカシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県日高市', '11', '11242', '3501200', '埼玉県', 'サイタマケン', '日高市', 'ヒダカシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('27766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県日高市田波目', '11', '11242', '3501201', '埼玉県', 'サイタマケン', '日高市', 'ヒダカシ', '田波目', 'タバメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県日高市駒寺野新田', '11', '11242', '3501202', '埼玉県', 'サイタマケン', '日高市', 'ヒダカシ', '駒寺野新田', 'コマデラノシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県日高市旭ケ丘', '11', '11242', '3501203', '埼玉県', 'サイタマケン', '日高市', 'ヒダカシ', '旭ケ丘', 'アサヒガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県日高市新堀新田', '11', '11242', '3501204', '埼玉県', 'サイタマケン', '日高市', 'ヒダカシ', '新堀新田', 'ニイホリシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県日高市原宿', '11', '11242', '3501205', '埼玉県', 'サイタマケン', '日高市', 'ヒダカシ', '原宿', 'ハラジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県日高市南平沢', '11', '11242', '3501206', '埼玉県', 'サイタマケン', '日高市', 'ヒダカシ', '南平沢', 'ミナミヒラサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県日高市森戸新田', '11', '11242', '3501211', '埼玉県', 'サイタマケン', '日高市', 'ヒダカシ', '森戸新田', 'モリドシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県日高市下高萩新田', '11', '11242', '3501212', '埼玉県', 'サイタマケン', '日高市', 'ヒダカシ', '下高萩新田', 'シモタカハギシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県日高市高萩', '11', '11242', '3501213', '埼玉県', 'サイタマケン', '日高市', 'ヒダカシ', '高萩', 'タカハギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県日高市女影新田', '11', '11242', '3501214', '埼玉県', 'サイタマケン', '日高市', 'ヒダカシ', '女影新田', 'オナカゲシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県日高市高萩東', '11', '11242', '3501215', '埼玉県', 'サイタマケン', '日高市', 'ヒダカシ', '高萩東', 'タカハギヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県日高市下大谷沢', '11', '11242', '3501221', '埼玉県', 'サイタマケン', '日高市', 'ヒダカシ', '下大谷沢', 'シモオオヤザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県日高市大谷沢', '11', '11242', '3501222', '埼玉県', 'サイタマケン', '日高市', 'ヒダカシ', '大谷沢', 'オオヤザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県日高市高富', '11', '11242', '3501223', '埼玉県', 'サイタマケン', '日高市', 'ヒダカシ', '高富', 'タカトミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県日高市田木', '11', '11242', '3501224', '埼玉県', 'サイタマケン', '日高市', 'ヒダカシ', '田木', 'タギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県日高市馬引沢', '11', '11242', '3501225', '埼玉県', 'サイタマケン', '日高市', 'ヒダカシ', '馬引沢', 'ウマヒキザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県日高市中沢', '11', '11242', '3501226', '埼玉県', 'サイタマケン', '日高市', 'ヒダカシ', '中沢', 'ナカザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県日高市女影', '11', '11242', '3501227', '埼玉県', 'サイタマケン', '日高市', 'ヒダカシ', '女影', 'オナカゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県日高市鹿山', '11', '11242', '3501231', '埼玉県', 'サイタマケン', '日高市', 'ヒダカシ', '鹿山', 'カヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県日高市中鹿山', '11', '11242', '3501232', '埼玉県', 'サイタマケン', '日高市', 'ヒダカシ', '中鹿山', 'ナカカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県日高市下鹿山', '11', '11242', '3501233', '埼玉県', 'サイタマケン', '日高市', 'ヒダカシ', '下鹿山', 'シモカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県日高市上鹿山', '11', '11242', '3501234', '埼玉県', 'サイタマケン', '日高市', 'ヒダカシ', '上鹿山', 'カミカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県日高市楡木', '11', '11242', '3501235', '埼玉県', 'サイタマケン', '日高市', 'ヒダカシ', '楡木', 'ニレギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県日高市猿田', '11', '11242', '3501236', '埼玉県', 'サイタマケン', '日高市', 'ヒダカシ', '猿田', 'ヤエンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県日高市山根', '11', '11242', '3501241', '埼玉県', 'サイタマケン', '日高市', 'ヒダカシ', '山根', 'ヤマネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県日高市北平沢', '11', '11242', '3501242', '埼玉県', 'サイタマケン', '日高市', 'ヒダカシ', '北平沢', 'キタヒラサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県日高市新堀', '11', '11242', '3501243', '埼玉県', 'サイタマケン', '日高市', 'ヒダカシ', '新堀', 'ニイホリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県日高市野々宮', '11', '11242', '3501244', '埼玉県', 'サイタマケン', '日高市', 'ヒダカシ', '野々宮', 'ノノミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県日高市栗坪', '11', '11242', '3501245', '埼玉県', 'サイタマケン', '日高市', 'ヒダカシ', '栗坪', 'クリツボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県日高市梅原', '11', '11242', '3501246', '埼玉県', 'サイタマケン', '日高市', 'ヒダカシ', '梅原', 'ウメハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県日高市高岡', '11', '11242', '3501247', '埼玉県', 'サイタマケン', '日高市', 'ヒダカシ', '高岡', 'タカオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県日高市高麗本郷', '11', '11242', '3501251', '埼玉県', 'サイタマケン', '日高市', 'ヒダカシ', '高麗本郷', 'コマホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県日高市清流', '11', '11242', '3501252', '埼玉県', 'サイタマケン', '日高市', 'ヒダカシ', '清流', 'セイリュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県日高市台', '11', '11242', '3501253', '埼玉県', 'サイタマケン', '日高市', 'ヒダカシ', '台', 'ダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県日高市久保', '11', '11242', '3501254', '埼玉県', 'サイタマケン', '日高市', 'ヒダカシ', '久保', 'クボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県日高市武蔵台', '11', '11242', '3501255', '埼玉県', 'サイタマケン', '日高市', 'ヒダカシ', '武蔵台', 'ムサシダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県日高市横手', '11', '11242', '3501257', '埼玉県', 'サイタマケン', '日高市', 'ヒダカシ', '横手', 'ヨコテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県狭山市', '11', '11215', '3501300', '埼玉県', 'サイタマケン', '狭山市', 'サヤマシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('27809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県狭山市青柳', '11', '11215', '3501301', '埼玉県', 'サイタマケン', '狭山市', 'サヤマシ', '青柳', 'アオヤギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県狭山市東三ツ木', '11', '11215', '3501302', '埼玉県', 'サイタマケン', '狭山市', 'サヤマシ', '東三ツ木', 'ヒガシミツギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県狭山市沢', '11', '11215', '3501303', '埼玉県', 'サイタマケン', '狭山市', 'サヤマシ', '沢', 'サワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県狭山市狭山台', '11', '11215', '3501304', '埼玉県', 'サイタマケン', '狭山市', 'サヤマシ', '狭山台', 'サヤマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県狭山市入間川', '11', '11215', '3501305', '埼玉県', 'サイタマケン', '狭山市', 'サヤマシ', '入間川', 'イルマガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県狭山市富士見', '11', '11215', '3501306', '埼玉県', 'サイタマケン', '狭山市', 'サヤマシ', '富士見', 'フジミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県狭山市祇園', '11', '11215', '3501307', '埼玉県', 'サイタマケン', '狭山市', 'サヤマシ', '祇園', 'ギオン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県狭山市中央', '11', '11215', '3501308', '埼玉県', 'サイタマケン', '狭山市', 'サヤマシ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県狭山市中新田', '11', '11215', '3501311', '埼玉県', 'サイタマケン', '狭山市', 'サヤマシ', '中新田', 'ナカシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県狭山市堀兼', '11', '11215', '3501312', '埼玉県', 'サイタマケン', '狭山市', 'サヤマシ', '堀兼', 'ホリガネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県狭山市上赤坂', '11', '11215', '3501313', '埼玉県', 'サイタマケン', '狭山市', 'サヤマシ', '上赤坂', 'カミアカサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県狭山市加佐志', '11', '11215', '3501314', '埼玉県', 'サイタマケン', '狭山市', 'サヤマシ', '加佐志', 'カザシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県狭山市北入曽', '11', '11215', '3501315', '埼玉県', 'サイタマケン', '狭山市', 'サヤマシ', '北入曽', 'キタイリソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県狭山市南入曽', '11', '11215', '3501316', '埼玉県', 'サイタマケン', '狭山市', 'サヤマシ', '南入曽', 'ミナミイリソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県狭山市水野', '11', '11215', '3501317', '埼玉県', 'サイタマケン', '狭山市', 'サヤマシ', '水野', 'ミズノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県狭山市広瀬', '11', '11215', '3501319', '埼玉県', 'サイタマケン', '狭山市', 'サヤマシ', '広瀬', 'ヒロセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県狭山市広瀬東', '11', '11215', '3501320', '埼玉県', 'サイタマケン', '狭山市', 'サヤマシ', '広瀬東', 'ヒロセヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県狭山市上広瀬', '11', '11215', '3501321', '埼玉県', 'サイタマケン', '狭山市', 'サヤマシ', '上広瀬', 'カミヒロセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県狭山市下広瀬', '11', '11215', '3501322', '埼玉県', 'サイタマケン', '狭山市', 'サヤマシ', '下広瀬', 'シモヒロセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県狭山市鵜ノ木', '11', '11215', '3501323', '埼玉県', 'サイタマケン', '狭山市', 'サヤマシ', '鵜ノ木', 'ウノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県狭山市稲荷山', '11', '11215', '3501324', '埼玉県', 'サイタマケン', '狭山市', 'サヤマシ', '稲荷山', 'イナリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県狭山市根岸', '11', '11215', '3501325', '埼玉県', 'サイタマケン', '狭山市', 'サヤマシ', '根岸', 'ネギシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県狭山市つつじ野', '11', '11215', '3501326', '埼玉県', 'サイタマケン', '狭山市', 'サヤマシ', 'つつじ野', 'ツツジノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県狭山市笹井', '11', '11215', '3501327', '埼玉県', 'サイタマケン', '狭山市', 'サヤマシ', '笹井', 'ササイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県狭山市広瀬台', '11', '11215', '3501328', '埼玉県', 'サイタマケン', '狭山市', 'サヤマシ', '広瀬台', 'ヒロセダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県狭山市新狭山', '11', '11215', '3501331', '埼玉県', 'サイタマケン', '狭山市', 'サヤマシ', '新狭山', 'シンサヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県狭山市下奥富', '11', '11215', '3501332', '埼玉県', 'サイタマケン', '狭山市', 'サヤマシ', '下奥富', 'シモオクドミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県狭山市上奥富', '11', '11215', '3501333', '埼玉県', 'サイタマケン', '狭山市', 'サヤマシ', '上奥富', 'カミオクドミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県狭山市狭山', '11', '11215', '3501334', '埼玉県', 'サイタマケン', '狭山市', 'サヤマシ', '狭山', 'サヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県狭山市柏原', '11', '11215', '3501335', '埼玉県', 'サイタマケン', '狭山市', 'サヤマシ', '柏原', 'カシワバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県狭山市柏原新田', '11', '11215', '3501336', '埼玉県', 'サイタマケン', '狭山市', 'サヤマシ', '柏原新田', 'カシワバラシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鶴ヶ島市', '11', '11241', '3502200', '埼玉県', 'サイタマケン', '鶴ヶ島市', 'ツルガシマシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('27844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鶴ヶ島市富士見', '11', '11241', '3502201', '埼玉県', 'サイタマケン', '鶴ヶ島市', 'ツルガシマシ', '富士見', 'フジミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鶴ヶ島市五味ヶ谷', '11', '11241', '3502202', '埼玉県', 'サイタマケン', '鶴ヶ島市', 'ツルガシマシ', '五味ヶ谷', 'ゴミガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鶴ヶ島市上広谷', '11', '11241', '3502203', '埼玉県', 'サイタマケン', '鶴ヶ島市', 'ツルガシマシ', '上広谷', 'カミヒロヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鶴ヶ島市鶴ヶ丘', '11', '11241', '3502204', '埼玉県', 'サイタマケン', '鶴ヶ島市', 'ツルガシマシ', '鶴ヶ丘', 'ツルガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鶴ヶ島市松ヶ丘', '11', '11241', '3502205', '埼玉県', 'サイタマケン', '鶴ヶ島市', 'ツルガシマシ', '松ヶ丘', 'マツガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鶴ヶ島市藤金', '11', '11241', '3502206', '埼玉県', 'サイタマケン', '鶴ヶ島市', 'ツルガシマシ', '藤金', 'フジガネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鶴ヶ島市脚折町', '11', '11241', '3502211', '埼玉県', 'サイタマケン', '鶴ヶ島市', 'ツルガシマシ', '脚折町', 'スネオリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鶴ヶ島市共栄町', '11', '11241', '3502212', '埼玉県', 'サイタマケン', '鶴ヶ島市', 'ツルガシマシ', '共栄町', 'キョウエイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鶴ヶ島市脚折', '11', '11241', '3502213', '埼玉県', 'サイタマケン', '鶴ヶ島市', 'ツルガシマシ', '脚折', 'スネオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鶴ヶ島市太田ヶ谷', '11', '11241', '3502214', '埼玉県', 'サイタマケン', '鶴ヶ島市', 'ツルガシマシ', '太田ヶ谷', 'オオタガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鶴ヶ島市南町', '11', '11241', '3502215', '埼玉県', 'サイタマケン', '鶴ヶ島市', 'ツルガシマシ', '南町', 'ミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鶴ヶ島市三ツ木新田', '11', '11241', '3502216', '埼玉県', 'サイタマケン', '鶴ヶ島市', 'ツルガシマシ', '三ツ木新田', 'ミツギシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鶴ヶ島市三ツ木', '11', '11241', '3502217', '埼玉県', 'サイタマケン', '鶴ヶ島市', 'ツルガシマシ', '三ツ木', 'ミツギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鶴ヶ島市柳戸町', '11', '11241', '3502218', '埼玉県', 'サイタマケン', '鶴ヶ島市', 'ツルガシマシ', '柳戸町', 'ヤナギドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鶴ヶ島市三ツ木新町', '11', '11241', '3502219', '埼玉県', 'サイタマケン', '鶴ヶ島市', 'ツルガシマシ', '三ツ木新町', 'ミツギシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鶴ヶ島市羽折町', '11', '11241', '3502221', '埼玉県', 'サイタマケン', '鶴ヶ島市', 'ツルガシマシ', '羽折町', 'ハネオリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鶴ヶ島市下新田', '11', '11241', '3502222', '埼玉県', 'サイタマケン', '鶴ヶ島市', 'ツルガシマシ', '下新田', 'シモシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鶴ヶ島市高倉', '11', '11241', '3502223', '埼玉県', 'サイタマケン', '鶴ヶ島市', 'ツルガシマシ', '高倉', 'タカクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鶴ヶ島市町屋', '11', '11241', '3502224', '埼玉県', 'サイタマケン', '鶴ヶ島市', 'ツルガシマシ', '町屋', 'マチヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鶴ヶ島市上新田', '11', '11241', '3502225', '埼玉県', 'サイタマケン', '鶴ヶ島市', 'ツルガシマシ', '上新田', 'カミシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鶴ヶ島市中新田', '11', '11241', '3502226', '埼玉県', 'サイタマケン', '鶴ヶ島市', 'ツルガシマシ', '中新田', 'ナカシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鶴ヶ島市新町', '11', '11241', '3502227', '埼玉県', 'サイタマケン', '鶴ヶ島市', 'ツルガシマシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県朝霞市', '11', '11227', '3510000', '埼玉県', 'サイタマケン', '朝霞市', 'アサカシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('27882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県朝霞市上内間木', '11', '11227', '3510001', '埼玉県', 'サイタマケン', '朝霞市', 'アサカシ', '上内間木', 'カミウチマギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県朝霞市下内間木', '11', '11227', '3510002', '埼玉県', 'サイタマケン', '朝霞市', 'アサカシ', '下内間木', 'シモウチマギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県朝霞市台', '11', '11227', '3510003', '埼玉県', 'サイタマケン', '朝霞市', 'アサカシ', '台', 'ダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県朝霞市根岸', '11', '11227', '3510004', '埼玉県', 'サイタマケン', '朝霞市', 'アサカシ', '根岸', 'ネギシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県朝霞市根岸台', '11', '11227', '3510005', '埼玉県', 'サイタマケン', '朝霞市', 'アサカシ', '根岸台', 'ネギシダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県朝霞市仲町', '11', '11227', '3510006', '埼玉県', 'サイタマケン', '朝霞市', 'アサカシ', '仲町', 'ナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県朝霞市岡', '11', '11227', '3510007', '埼玉県', 'サイタマケン', '朝霞市', 'アサカシ', '岡', 'オカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県朝霞市本町', '11', '11227', '3510011', '埼玉県', 'サイタマケン', '朝霞市', 'アサカシ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県朝霞市栄町', '11', '11227', '3510012', '埼玉県', 'サイタマケン', '朝霞市', 'アサカシ', '栄町', 'サカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県朝霞市膝折', '11', '11227', '3510013', '埼玉県', 'サイタマケン', '朝霞市', 'アサカシ', '膝折', 'ヒザオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県朝霞市膝折町', '11', '11227', '3510014', '埼玉県', 'サイタマケン', '朝霞市', 'アサカシ', '膝折町', 'ヒザオリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県朝霞市幸町', '11', '11227', '3510015', '埼玉県', 'サイタマケン', '朝霞市', 'アサカシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県朝霞市青葉台', '11', '11227', '3510016', '埼玉県', 'サイタマケン', '朝霞市', 'アサカシ', '青葉台', 'アオバダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県朝霞市西弁財', '11', '11227', '3510021', '埼玉県', 'サイタマケン', '朝霞市', 'アサカシ', '西弁財', 'ニシベンザイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県朝霞市東弁財', '11', '11227', '3510022', '埼玉県', 'サイタマケン', '朝霞市', 'アサカシ', '東弁財', 'ヒガシベンザイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県朝霞市溝沼', '11', '11227', '3510023', '埼玉県', 'サイタマケン', '朝霞市', 'アサカシ', '溝沼', 'ミゾヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県朝霞市泉水', '11', '11227', '3510024', '埼玉県', 'サイタマケン', '朝霞市', 'アサカシ', '泉水', 'センズイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県朝霞市三原', '11', '11227', '3510025', '埼玉県', 'サイタマケン', '朝霞市', 'アサカシ', '三原', 'ミハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県朝霞市宮戸', '11', '11227', '3510031', '埼玉県', 'サイタマケン', '朝霞市', 'アサカシ', '宮戸', 'ミヤド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県朝霞市田島', '11', '11227', '3510032', '埼玉県', 'サイタマケン', '朝霞市', 'アサカシ', '田島', 'タジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県朝霞市浜崎', '11', '11227', '3510033', '埼玉県', 'サイタマケン', '朝霞市', 'アサカシ', '浜崎', 'ハマサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県朝霞市西原', '11', '11227', '3510034', '埼玉県', 'サイタマケン', '朝霞市', 'アサカシ', '西原', 'ニシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県朝霞市朝志ケ丘', '11', '11227', '3510035', '埼玉県', 'サイタマケン', '朝霞市', 'アサカシ', '朝志ケ丘', 'アサシガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県朝霞市北原', '11', '11227', '3510036', '埼玉県', 'サイタマケン', '朝霞市', 'アサカシ', '北原', 'キタハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県和光市', '11', '11229', '3510100', '埼玉県', 'サイタマケン', '和光市', 'ワコウシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('27907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県和光市白子', '11', '11229', '3510101', '埼玉県', 'サイタマケン', '和光市', 'ワコウシ', '白子', 'シラコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県和光市諏訪', '11', '11229', '3510102', '埼玉県', 'サイタマケン', '和光市', 'ワコウシ', '諏訪', 'スワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県和光市諏訪原団地', '11', '11229', '3510103', '埼玉県', 'サイタマケン', '和光市', 'ワコウシ', '諏訪原団地', 'スワハラダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県和光市南', '11', '11229', '3510104', '埼玉県', 'サイタマケン', '和光市', 'ワコウシ', '南', 'ミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県和光市西大和団地', '11', '11229', '3510105', '埼玉県', 'サイタマケン', '和光市', 'ワコウシ', '西大和団地', 'ニシヤマトダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県和光市広沢', '11', '11229', '3510106', '埼玉県', 'サイタマケン', '和光市', 'ワコウシ', '広沢', 'ヒロサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県和光市下新倉', '11', '11229', '3510111', '埼玉県', 'サイタマケン', '和光市', 'ワコウシ', '下新倉', 'シモニイクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県和光市丸山台', '11', '11229', '3510112', '埼玉県', 'サイタマケン', '和光市', 'ワコウシ', '丸山台', 'マルヤマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県和光市中央', '11', '11229', '3510113', '埼玉県', 'サイタマケン', '和光市', 'ワコウシ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県和光市本町', '11', '11229', '3510114', '埼玉県', 'サイタマケン', '和光市', 'ワコウシ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県和光市新倉', '11', '11229', '3510115', '埼玉県', 'サイタマケン', '和光市', 'ワコウシ', '新倉', 'ニイクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県和光市松ノ木島町', '11', '11229', '3510116', '埼玉県', 'サイタマケン', '和光市', 'ワコウシ', '松ノ木島町', 'マツノキジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県新座市', '11', '11230', '3520000', '埼玉県', 'サイタマケン', '新座市', 'ニイザシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('27937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県新座市東北', '11', '11230', '3520001', '埼玉県', 'サイタマケン', '新座市', 'ニイザシ', '東北', 'トウホク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県新座市東', '11', '11230', '3520002', '埼玉県', 'サイタマケン', '新座市', 'ニイザシ', '東', 'ヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県新座市北野', '11', '11230', '3520003', '埼玉県', 'サイタマケン', '新座市', 'ニイザシ', '北野', 'キタノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県新座市大和田', '11', '11230', '3520004', '埼玉県', 'サイタマケン', '新座市', 'ニイザシ', '大和田', 'オオワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県新座市中野', '11', '11230', '3520005', '埼玉県', 'サイタマケン', '新座市', 'ニイザシ', '中野', 'ナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県新座市新座', '11', '11230', '3520006', '埼玉県', 'サイタマケン', '新座市', 'ニイザシ', '新座', 'ニイザ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県新座市野火止', '11', '11230', '3520011', '埼玉県', 'サイタマケン', '新座市', 'ニイザシ', '野火止', 'ノビトメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県新座市畑中', '11', '11230', '3520012', '埼玉県', 'サイタマケン', '新座市', 'ニイザシ', '畑中', 'ハタナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県新座市新塚', '11', '11230', '3520013', '埼玉県', 'サイタマケン', '新座市', 'ニイザシ', '新塚', 'ニイヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県新座市栄', '11', '11230', '3520014', '埼玉県', 'サイタマケン', '新座市', 'ニイザシ', '栄', 'サカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県新座市池田', '11', '11230', '3520015', '埼玉県', 'サイタマケン', '新座市', 'ニイザシ', '池田', 'イケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県新座市馬場', '11', '11230', '3520016', '埼玉県', 'サイタマケン', '新座市', 'ニイザシ', '馬場', 'ババ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県新座市菅沢', '11', '11230', '3520017', '埼玉県', 'サイタマケン', '新座市', 'ニイザシ', '菅沢', 'スガサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県新座市あたご', '11', '11230', '3520021', '埼玉県', 'サイタマケン', '新座市', 'ニイザシ', 'あたご', 'アタゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県新座市本多', '11', '11230', '3520022', '埼玉県', 'サイタマケン', '新座市', 'ニイザシ', '本多', 'ホンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県新座市堀ノ内', '11', '11230', '3520023', '埼玉県', 'サイタマケン', '新座市', 'ニイザシ', '堀ノ内', 'ホリノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県新座市道場', '11', '11230', '3520024', '埼玉県', 'サイタマケン', '新座市', 'ニイザシ', '道場', 'ドウジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県新座市片山', '11', '11230', '3520025', '埼玉県', 'サイタマケン', '新座市', 'ニイザシ', '片山', 'カタヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県新座市西堀', '11', '11230', '3520031', '埼玉県', 'サイタマケン', '新座市', 'ニイザシ', '西堀', 'ニシボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県新座市新堀', '11', '11230', '3520032', '埼玉県', 'サイタマケン', '新座市', 'ニイザシ', '新堀', 'シンボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県新座市石神', '11', '11230', '3520033', '埼玉県', 'サイタマケン', '新座市', 'ニイザシ', '石神', 'イシガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県新座市野寺', '11', '11230', '3520034', '埼玉県', 'サイタマケン', '新座市', 'ニイザシ', '野寺', 'ノデラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県新座市栗原', '11', '11230', '3520035', '埼玉県', 'サイタマケン', '新座市', 'ニイザシ', '栗原', 'クリハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県志木市', '11', '11228', '3530000', '埼玉県', 'サイタマケン', '志木市', 'シキシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('27973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県志木市上宗岡', '11', '11228', '3530001', '埼玉県', 'サイタマケン', '志木市', 'シキシ', '上宗岡', 'カミムネオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県志木市中宗岡', '11', '11228', '3530002', '埼玉県', 'サイタマケン', '志木市', 'シキシ', '中宗岡', 'ナカムネオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県志木市下宗岡', '11', '11228', '3530003', '埼玉県', 'サイタマケン', '志木市', 'シキシ', '下宗岡', 'シモムネオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県志木市本町', '11', '11228', '3530004', '埼玉県', 'サイタマケン', '志木市', 'シキシ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県志木市幸町', '11', '11228', '3530005', '埼玉県', 'サイタマケン', '志木市', 'シキシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県志木市館', '11', '11228', '3530006', '埼玉県', 'サイタマケン', '志木市', 'シキシ', '館', 'タテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県志木市柏町', '11', '11228', '3530007', '埼玉県', 'サイタマケン', '志木市', 'シキシ', '柏町', 'カシワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県志木市宗岡', '11', '11228', '3530008', '埼玉県', 'サイタマケン', '志木市', 'シキシ', '宗岡', 'ムネオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県富士見市', '11', '11235', '3540000', '埼玉県', 'サイタマケン', '富士見市', 'フジミシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('27984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県入間郡三芳町', '11', '11324', '3540000', '埼玉県', 'サイタマケン', '入間郡三芳町', 'イルマグンミヨシマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('27985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県富士見市東大久保', '11', '11235', '3540001', '埼玉県', 'サイタマケン', '富士見市', 'フジミシ', '東大久保', 'ヒガシオオクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県富士見市上南畑', '11', '11235', '3540002', '埼玉県', 'サイタマケン', '富士見市', 'フジミシ', '上南畑', 'カミナンバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県富士見市南畑新田', '11', '11235', '3540003', '埼玉県', 'サイタマケン', '富士見市', 'フジミシ', '南畑新田', 'ナンバタシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県富士見市下南畑', '11', '11235', '3540004', '埼玉県', 'サイタマケン', '富士見市', 'フジミシ', '下南畑', 'シモナンバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県富士見市みどり野北', '11', '11235', '3540005', '埼玉県', 'サイタマケン', '富士見市', 'フジミシ', 'みどり野北', 'ミドリノキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県富士見市みどり野東', '11', '11235', '3540006', '埼玉県', 'サイタマケン', '富士見市', 'フジミシ', 'みどり野東', 'ミドリノヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県富士見市みどり野南', '11', '11235', '3540007', '埼玉県', 'サイタマケン', '富士見市', 'フジミシ', 'みどり野南', 'ミドリノミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県富士見市みどり野西', '11', '11235', '3540008', '埼玉県', 'サイタマケン', '富士見市', 'フジミシ', 'みどり野西', 'ミドリノニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県富士見市水子', '11', '11235', '3540011', '埼玉県', 'サイタマケン', '富士見市', 'フジミシ', '水子', 'ミズコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県富士見市貝塚', '11', '11235', '3540012', '埼玉県', 'サイタマケン', '富士見市', 'フジミシ', '貝塚', 'カイヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県富士見市水谷東', '11', '11235', '3540013', '埼玉県', 'サイタマケン', '富士見市', 'フジミシ', '水谷東', 'ミズタニヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県富士見市水谷', '11', '11235', '3540014', '埼玉県', 'サイタマケン', '富士見市', 'フジミシ', '水谷', 'ミズタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県富士見市東みずほ台', '11', '11235', '3540015', '埼玉県', 'サイタマケン', '富士見市', 'フジミシ', '東みずほ台', 'ヒガシミズホダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県富士見市榎町', '11', '11235', '3540016', '埼玉県', 'サイタマケン', '富士見市', 'フジミシ', '榎町', 'エノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('27999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県富士見市針ケ谷', '11', '11235', '3540017', '埼玉県', 'サイタマケン', '富士見市', 'フジミシ', '針ケ谷', 'ハリガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県富士見市西みずほ台', '11', '11235', '3540018', '埼玉県', 'サイタマケン', '富士見市', 'フジミシ', '西みずほ台', 'ニシミズホダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県富士見市鶴馬', '11', '11235', '3540021', '埼玉県', 'サイタマケン', '富士見市', 'フジミシ', '鶴馬', 'ツルマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県富士見市山室', '11', '11235', '3540022', '埼玉県', 'サイタマケン', '富士見市', 'フジミシ', '山室', 'ヤマムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県富士見市諏訪', '11', '11235', '3540023', '埼玉県', 'サイタマケン', '富士見市', 'フジミシ', '諏訪', 'スワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県富士見市鶴瀬東', '11', '11235', '3540024', '埼玉県', 'サイタマケン', '富士見市', 'フジミシ', '鶴瀬東', 'ツルセヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県富士見市関沢', '11', '11235', '3540025', '埼玉県', 'サイタマケン', '富士見市', 'フジミシ', '関沢', 'セキザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県富士見市鶴瀬西', '11', '11235', '3540026', '埼玉県', 'サイタマケン', '富士見市', 'フジミシ', '鶴瀬西', 'ツルセニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県富士見市勝瀬', '11', '11235', '3540031', '埼玉県', 'サイタマケン', '富士見市', 'フジミシ', '勝瀬', 'カツセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県富士見市渡戸', '11', '11235', '3540032', '埼玉県', 'サイタマケン', '富士見市', 'フジミシ', '渡戸', 'ワタド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県富士見市羽沢', '11', '11235', '3540033', '埼玉県', 'サイタマケン', '富士見市', 'フジミシ', '羽沢', 'ハネサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県富士見市上沢', '11', '11235', '3540034', '埼玉県', 'サイタマケン', '富士見市', 'フジミシ', '上沢', 'カミサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県入間郡三芳町藤久保', '11', '11324', '3540041', '埼玉県', 'サイタマケン', '入間郡三芳町', 'イルマグンミヨシマチ', '藤久保', 'フジクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県入間郡三芳町みよし台', '11', '11324', '3540042', '埼玉県', 'サイタマケン', '入間郡三芳町', 'イルマグンミヨシマチ', 'みよし台', 'ミヨシダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県入間郡三芳町竹間沢', '11', '11324', '3540043', '埼玉県', 'サイタマケン', '入間郡三芳町', 'イルマグンミヨシマチ', '竹間沢', 'チクマザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県入間郡三芳町北永井', '11', '11324', '3540044', '埼玉県', 'サイタマケン', '入間郡三芳町', 'イルマグンミヨシマチ', '北永井', 'キタナガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県入間郡三芳町上富', '11', '11324', '3540045', '埼玉県', 'サイタマケン', '入間郡三芳町', 'イルマグンミヨシマチ', '上富', 'カミトメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県入間郡三芳町竹間沢東', '11', '11324', '3540046', '埼玉県', 'サイタマケン', '入間郡三芳町', 'イルマグンミヨシマチ', '竹間沢東', 'チクマザワヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県東松山市', '11', '11212', '3550000', '埼玉県', 'サイタマケン', '東松山市', 'ヒガシマツヤマシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('28030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県東松山市岡', '11', '11212', '3550001', '埼玉県', 'サイタマケン', '東松山市', 'ヒガシマツヤマシ', '岡', 'オカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県東松山市東平', '11', '11212', '3550002', '埼玉県', 'サイタマケン', '東松山市', 'ヒガシマツヤマシ', '東平', 'ヒガシダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県東松山市殿山町', '11', '11212', '3550003', '埼玉県', 'サイタマケン', '東松山市', 'ヒガシマツヤマシ', '殿山町', 'トノヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県東松山市沢口町', '11', '11212', '3550004', '埼玉県', 'サイタマケン', '東松山市', 'ヒガシマツヤマシ', '沢口町', 'サワグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県東松山市松山', '11', '11212', '3550005', '埼玉県', 'サイタマケン', '東松山市', 'ヒガシマツヤマシ', '松山', 'マツヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県東松山市市ノ川', '11', '11212', '3550006', '埼玉県', 'サイタマケン', '東松山市', 'ヒガシマツヤマシ', '市ノ川', 'イチノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県東松山市野田', '11', '11212', '3550007', '埼玉県', 'サイタマケン', '東松山市', 'ヒガシマツヤマシ', '野田', 'ノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県東松山市大谷', '11', '11212', '3550008', '埼玉県', 'サイタマケン', '東松山市', 'ヒガシマツヤマシ', '大谷', 'オオヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県東松山市加美町', '11', '11212', '3550011', '埼玉県', 'サイタマケン', '東松山市', 'ヒガシマツヤマシ', '加美町', 'カミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県東松山市日吉町', '11', '11212', '3550012', '埼玉県', 'サイタマケン', '東松山市', 'ヒガシマツヤマシ', '日吉町', 'ヒヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県東松山市小松原町', '11', '11212', '3550013', '埼玉県', 'サイタマケン', '東松山市', 'ヒガシマツヤマシ', '小松原町', 'コマツバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県東松山市松本町', '11', '11212', '3550014', '埼玉県', 'サイタマケン', '東松山市', 'ヒガシマツヤマシ', '松本町', 'マツモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県東松山市本町', '11', '11212', '3550015', '埼玉県', 'サイタマケン', '東松山市', 'ヒガシマツヤマシ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県東松山市材木町', '11', '11212', '3550016', '埼玉県', 'サイタマケン', '東松山市', 'ヒガシマツヤマシ', '材木町', 'ザイモクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県東松山市松葉町', '11', '11212', '3550017', '埼玉県', 'サイタマケン', '東松山市', 'ヒガシマツヤマシ', '松葉町', 'マツバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県東松山市松山町', '11', '11212', '3550018', '埼玉県', 'サイタマケン', '東松山市', 'ヒガシマツヤマシ', '松山町', 'マツヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県東松山市砂田町', '11', '11212', '3550019', '埼玉県', 'サイタマケン', '東松山市', 'ヒガシマツヤマシ', '砂田町', 'スナダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県東松山市神明町', '11', '11212', '3550021', '埼玉県', 'サイタマケン', '東松山市', 'ヒガシマツヤマシ', '神明町', 'シンメイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県東松山市御茶山町', '11', '11212', '3550022', '埼玉県', 'サイタマケン', '東松山市', 'ヒガシマツヤマシ', '御茶山町', 'オチャヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県東松山市六反町', '11', '11212', '3550023', '埼玉県', 'サイタマケン', '東松山市', 'ヒガシマツヤマシ', '六反町', 'ロクタンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県東松山市六軒町', '11', '11212', '3550024', '埼玉県', 'サイタマケン', '東松山市', 'ヒガシマツヤマシ', '六軒町', 'ロッケンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県東松山市幸町', '11', '11212', '3550025', '埼玉県', 'サイタマケン', '東松山市', 'ヒガシマツヤマシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県東松山市和泉町', '11', '11212', '3550026', '埼玉県', 'サイタマケン', '東松山市', 'ヒガシマツヤマシ', '和泉町', 'イズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県東松山市美土里町', '11', '11212', '3550027', '埼玉県', 'サイタマケン', '東松山市', 'ヒガシマツヤマシ', '美土里町', 'ミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県東松山市箭弓町', '11', '11212', '3550028', '埼玉県', 'サイタマケン', '東松山市', 'ヒガシマツヤマシ', '箭弓町', 'ヤキュウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県東松山市五領町', '11', '11212', '3550031', '埼玉県', 'サイタマケン', '東松山市', 'ヒガシマツヤマシ', '五領町', 'ゴリョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県東松山市新宿町', '11', '11212', '3550032', '埼玉県', 'サイタマケン', '東松山市', 'ヒガシマツヤマシ', '新宿町', 'シンジュクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県東松山市山崎町', '11', '11212', '3550033', '埼玉県', 'サイタマケン', '東松山市', 'ヒガシマツヤマシ', '山崎町', 'ヤマザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県東松山市柏崎', '11', '11212', '3550034', '埼玉県', 'サイタマケン', '東松山市', 'ヒガシマツヤマシ', '柏崎', 'カシワザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県東松山市古凍', '11', '11212', '3550035', '埼玉県', 'サイタマケン', '東松山市', 'ヒガシマツヤマシ', '古凍', 'フルコオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県東松山市下野本', '11', '11212', '3550036', '埼玉県', 'サイタマケン', '東松山市', 'ヒガシマツヤマシ', '下野本', 'シモノモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県東松山市若松町', '11', '11212', '3550037', '埼玉県', 'サイタマケン', '東松山市', 'ヒガシマツヤマシ', '若松町', 'ワカマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県東松山市下押垂', '11', '11212', '3550041', '埼玉県', 'サイタマケン', '東松山市', 'ヒガシマツヤマシ', '下押垂', 'シモオシダリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県東松山市今泉', '11', '11212', '3550042', '埼玉県', 'サイタマケン', '東松山市', 'ヒガシマツヤマシ', '今泉', 'イマイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県東松山市早俣', '11', '11212', '3550043', '埼玉県', 'サイタマケン', '東松山市', 'ヒガシマツヤマシ', '早俣', 'ハヤマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県東松山市正代', '11', '11212', '3550044', '埼玉県', 'サイタマケン', '東松山市', 'ヒガシマツヤマシ', '正代', 'ショウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県東松山市宮鼻', '11', '11212', '3550045', '埼玉県', 'サイタマケン', '東松山市', 'ヒガシマツヤマシ', '宮鼻', 'ミヤハナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県東松山市大黒部', '11', '11212', '3550046', '埼玉県', 'サイタマケン', '東松山市', 'ヒガシマツヤマシ', '大黒部', 'オオクロベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県東松山市高坂', '11', '11212', '3550047', '埼玉県', 'サイタマケン', '東松山市', 'ヒガシマツヤマシ', '高坂', 'タカサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県東松山市白山台', '11', '11212', '3550051', '埼玉県', 'サイタマケン', '東松山市', 'ヒガシマツヤマシ', '白山台', 'ハクサンダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県東松山市桜山台', '11', '11212', '3550052', '埼玉県', 'サイタマケン', '東松山市', 'ヒガシマツヤマシ', '桜山台', 'サクラヤマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県東松山市田木', '11', '11212', '3550053', '埼玉県', 'サイタマケン', '東松山市', 'ヒガシマツヤマシ', '田木', 'タギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県東松山市旗立台', '11', '11212', '3550054', '埼玉県', 'サイタマケン', '東松山市', 'ヒガシマツヤマシ', '旗立台', 'ハタタテダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県東松山市松風台', '11', '11212', '3550055', '埼玉県', 'サイタマケン', '東松山市', 'ヒガシマツヤマシ', '松風台', 'マツカゼダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県東松山市葛袋', '11', '11212', '3550061', '埼玉県', 'サイタマケン', '東松山市', 'ヒガシマツヤマシ', '葛袋', 'クズブクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県東松山市西本宿', '11', '11212', '3550062', '埼玉県', 'サイタマケン', '東松山市', 'ヒガシマツヤマシ', '西本宿', 'ニシモトジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県東松山市元宿', '11', '11212', '3550063', '埼玉県', 'サイタマケン', '東松山市', 'ヒガシマツヤマシ', '元宿', 'モトジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県東松山市毛塚', '11', '11212', '3550064', '埼玉県', 'サイタマケン', '東松山市', 'ヒガシマツヤマシ', '毛塚', 'ケツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県東松山市岩殿', '11', '11212', '3550065', '埼玉県', 'サイタマケン', '東松山市', 'ヒガシマツヤマシ', '岩殿', 'イワドノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県東松山市神戸', '11', '11212', '3550066', '埼玉県', 'サイタマケン', '東松山市', 'ヒガシマツヤマシ', '神戸', 'ゴウド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県東松山市新郷', '11', '11212', '3550071', '埼玉県', 'サイタマケン', '東松山市', 'ヒガシマツヤマシ', '新郷', 'シンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県東松山市石橋', '11', '11212', '3550072', '埼玉県', 'サイタマケン', '東松山市', 'ヒガシマツヤマシ', '石橋', 'イシバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県東松山市上野本', '11', '11212', '3550073', '埼玉県', 'サイタマケン', '東松山市', 'ヒガシマツヤマシ', '上野本', 'カミノモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県東松山市上押垂', '11', '11212', '3550074', '埼玉県', 'サイタマケン', '東松山市', 'ヒガシマツヤマシ', '上押垂', 'カミオシダリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県東松山市下青鳥', '11', '11212', '3550075', '埼玉県', 'サイタマケン', '東松山市', 'ヒガシマツヤマシ', '下青鳥', 'シモオオドリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県東松山市下唐子', '11', '11212', '3550076', '埼玉県', 'サイタマケン', '東松山市', 'ヒガシマツヤマシ', '下唐子', 'シモガラコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県東松山市上唐子', '11', '11212', '3550077', '埼玉県', 'サイタマケン', '東松山市', 'ヒガシマツヤマシ', '上唐子', 'カミガラコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡吉見町', '11', '11347', '3550100', '埼玉県', 'サイタマケン', '比企郡吉見町', 'ヒキグンヨシミマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('28088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡吉見町一ツ木', '11', '11347', '3550101', '埼玉県', 'サイタマケン', '比企郡吉見町', 'ヒキグンヨシミマチ', '一ツ木', 'ヒトツギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡吉見町明秋', '11', '11347', '3550102', '埼玉県', 'サイタマケン', '比企郡吉見町', 'ヒキグンヨシミマチ', '明秋', 'メイシュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡吉見町今泉', '11', '11347', '3550103', '埼玉県', 'サイタマケン', '比企郡吉見町', 'ヒキグンヨシミマチ', '今泉', 'イマイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡吉見町地頭方', '11', '11347', '3550104', '埼玉県', 'サイタマケン', '比企郡吉見町', 'ヒキグンヨシミマチ', '地頭方', 'ジトウホウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡吉見町上砂', '11', '11347', '3550105', '埼玉県', 'サイタマケン', '比企郡吉見町', 'ヒキグンヨシミマチ', '上砂', 'カミズナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡吉見町中曽根', '11', '11347', '3550106', '埼玉県', 'サイタマケン', '比企郡吉見町', 'ヒキグンヨシミマチ', '中曽根', 'ナカゾネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡吉見町東野', '11', '11347', '3550110', '埼玉県', 'サイタマケン', '比企郡吉見町', 'ヒキグンヨシミマチ', '東野', 'ヒガシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡吉見町北下砂', '11', '11347', '3550111', '埼玉県', 'サイタマケン', '比企郡吉見町', 'ヒキグンヨシミマチ', '北下砂', 'キタシモズナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡吉見町丸貫', '11', '11347', '3550112', '埼玉県', 'サイタマケン', '比企郡吉見町', 'ヒキグンヨシミマチ', '丸貫', 'マルヌキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡吉見町古名新田', '11', '11347', '3550113', '埼玉県', 'サイタマケン', '比企郡吉見町', 'ヒキグンヨシミマチ', '古名新田', 'コミョウシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡吉見町古名', '11', '11347', '3550114', '埼玉県', 'サイタマケン', '比企郡吉見町', 'ヒキグンヨシミマチ', '古名', 'コミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡吉見町上銀谷', '11', '11347', '3550115', '埼玉県', 'サイタマケン', '比企郡吉見町', 'ヒキグンヨシミマチ', '上銀谷', 'カミギンヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡吉見町下銀谷', '11', '11347', '3550116', '埼玉県', 'サイタマケン', '比企郡吉見町', 'ヒキグンヨシミマチ', '下銀谷', 'シモギンヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡吉見町谷口', '11', '11347', '3550117', '埼玉県', 'サイタマケン', '比企郡吉見町', 'ヒキグンヨシミマチ', '谷口', 'ヤグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡吉見町下細谷', '11', '11347', '3550118', '埼玉県', 'サイタマケン', '比企郡吉見町', 'ヒキグンヨシミマチ', '下細谷', 'シモホソヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡吉見町中新井', '11', '11347', '3550119', '埼玉県', 'サイタマケン', '比企郡吉見町', 'ヒキグンヨシミマチ', '中新井', 'ナカアライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡吉見町蓮沼新田', '11', '11347', '3550121', '埼玉県', 'サイタマケン', '比企郡吉見町', 'ヒキグンヨシミマチ', '蓮沼新田', 'ハスヌマシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡吉見町高尾新田', '11', '11347', '3550122', '埼玉県', 'サイタマケン', '比企郡吉見町', 'ヒキグンヨシミマチ', '高尾新田', 'タカオシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡吉見町須ノ子新田', '11', '11347', '3550123', '埼玉県', 'サイタマケン', '比企郡吉見町', 'ヒキグンヨシミマチ', '須ノ子新田', 'スノコシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡吉見町久保田新田', '11', '11347', '3550124', '埼玉県', 'サイタマケン', '比企郡吉見町', 'ヒキグンヨシミマチ', '久保田新田', 'クボタシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡吉見町蚊斗谷', '11', '11347', '3550125', '埼玉県', 'サイタマケン', '比企郡吉見町', 'ヒキグンヨシミマチ', '蚊斗谷', 'カバカリヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡吉見町万光寺', '11', '11347', '3550126', '埼玉県', 'サイタマケン', '比企郡吉見町', 'ヒキグンヨシミマチ', '万光寺', 'マンコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡吉見町大和田', '11', '11347', '3550127', '埼玉県', 'サイタマケン', '比企郡吉見町', 'ヒキグンヨシミマチ', '大和田', 'オオワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡吉見町荒子', '11', '11347', '3550131', '埼玉県', 'サイタマケン', '比企郡吉見町', 'ヒキグンヨシミマチ', '荒子', 'アラコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡吉見町飯島新田', '11', '11347', '3550132', '埼玉県', 'サイタマケン', '比企郡吉見町', 'ヒキグンヨシミマチ', '飯島新田', 'イイジマシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡吉見町江和井', '11', '11347', '3550133', '埼玉県', 'サイタマケン', '比企郡吉見町', 'ヒキグンヨシミマチ', '江和井', 'エワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡吉見町大串', '11', '11347', '3550134', '埼玉県', 'サイタマケン', '比企郡吉見町', 'ヒキグンヨシミマチ', '大串', 'オオクシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡吉見町前河内', '11', '11347', '3550135', '埼玉県', 'サイタマケン', '比企郡吉見町', 'ヒキグンヨシミマチ', '前河内', 'マエゴウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡吉見町江綱', '11', '11347', '3550136', '埼玉県', 'サイタマケン', '比企郡吉見町', 'ヒキグンヨシミマチ', '江綱', 'エツナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡吉見町久保田', '11', '11347', '3550137', '埼玉県', 'サイタマケン', '比企郡吉見町', 'ヒキグンヨシミマチ', '久保田', 'クボタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡吉見町御所', '11', '11347', '3550151', '埼玉県', 'サイタマケン', '比企郡吉見町', 'ヒキグンヨシミマチ', '御所', 'ゴショ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡吉見町和名', '11', '11347', '3550152', '埼玉県', 'サイタマケン', '比企郡吉見町', 'ヒキグンヨシミマチ', '和名', 'ワナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡吉見町久米田', '11', '11347', '3550153', '埼玉県', 'サイタマケン', '比企郡吉見町', 'ヒキグンヨシミマチ', '久米田', 'クメダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡吉見町南吉見', '11', '11347', '3550154', '埼玉県', 'サイタマケン', '比企郡吉見町', 'ヒキグンヨシミマチ', '南吉見', 'ミナミヨシミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡吉見町北吉見', '11', '11347', '3550155', '埼玉県', 'サイタマケン', '比企郡吉見町', 'ヒキグンヨシミマチ', '北吉見', 'キタヨシミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡吉見町長谷', '11', '11347', '3550156', '埼玉県', 'サイタマケン', '比企郡吉見町', 'ヒキグンヨシミマチ', '長谷', 'ナガヤツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡吉見町西吉見', '11', '11347', '3550157', '埼玉県', 'サイタマケン', '比企郡吉見町', 'ヒキグンヨシミマチ', '西吉見', 'ニシヨシミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡吉見町山ノ下', '11', '11347', '3550161', '埼玉県', 'サイタマケン', '比企郡吉見町', 'ヒキグンヨシミマチ', '山ノ下', 'ヤマノシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡吉見町松崎', '11', '11347', '3550162', '埼玉県', 'サイタマケン', '比企郡吉見町', 'ヒキグンヨシミマチ', '松崎', 'マツザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡吉見町本沢', '11', '11347', '3550163', '埼玉県', 'サイタマケン', '比企郡吉見町', 'ヒキグンヨシミマチ', '本沢', 'ホンザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡吉見町小新井', '11', '11347', '3550164', '埼玉県', 'サイタマケン', '比企郡吉見町', 'ヒキグンヨシミマチ', '小新井', 'コアライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡吉見町上細谷', '11', '11347', '3550165', '埼玉県', 'サイタマケン', '比企郡吉見町', 'ヒキグンヨシミマチ', '上細谷', 'カミホソヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡吉見町黒岩', '11', '11347', '3550166', '埼玉県', 'サイタマケン', '比企郡吉見町', 'ヒキグンヨシミマチ', '黒岩', 'クロイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡吉見町田甲', '11', '11347', '3550167', '埼玉県', 'サイタマケン', '比企郡吉見町', 'ヒキグンヨシミマチ', '田甲', 'タコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡嵐山町', '11', '11342', '3550200', '埼玉県', 'サイタマケン', '比企郡嵐山町', 'ヒキグンランザンマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('28136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡嵐山町古里', '11', '11342', '3550201', '埼玉県', 'サイタマケン', '比企郡嵐山町', 'ヒキグンランザンマチ', '古里', 'フルサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡嵐山町吉田', '11', '11342', '3550202', '埼玉県', 'サイタマケン', '比企郡嵐山町', 'ヒキグンランザンマチ', '吉田', 'ヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡嵐山町勝田', '11', '11342', '3550203', '埼玉県', 'サイタマケン', '比企郡嵐山町', 'ヒキグンランザンマチ', '勝田', 'カチダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡嵐山町花見台', '11', '11342', '3550204', '埼玉県', 'サイタマケン', '比企郡嵐山町', 'ヒキグンランザンマチ', '花見台', 'ハナミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡嵐山町広野', '11', '11342', '3550205', '埼玉県', 'サイタマケン', '比企郡嵐山町', 'ヒキグンランザンマチ', '広野', 'ヒロノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡嵐山町越畑', '11', '11342', '3550206', '埼玉県', 'サイタマケン', '比企郡嵐山町', 'ヒキグンランザンマチ', '越畑', 'オツバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡嵐山町杉山', '11', '11342', '3550211', '埼玉県', 'サイタマケン', '比企郡嵐山町', 'ヒキグンランザンマチ', '杉山', 'スギヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡嵐山町太郎丸', '11', '11342', '3550212', '埼玉県', 'サイタマケン', '比企郡嵐山町', 'ヒキグンランザンマチ', '太郎丸', 'タロウマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡嵐山町川島', '11', '11342', '3550213', '埼玉県', 'サイタマケン', '比企郡嵐山町', 'ヒキグンランザンマチ', '川島', 'カワシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡嵐山町志賀', '11', '11342', '3550214', '埼玉県', 'サイタマケン', '比企郡嵐山町', 'ヒキグンランザンマチ', '志賀', 'シガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡嵐山町平沢', '11', '11342', '3550215', '埼玉県', 'サイタマケン', '比企郡嵐山町', 'ヒキグンランザンマチ', '平沢', 'ヒラサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡嵐山町むさし台', '11', '11342', '3550216', '埼玉県', 'サイタマケン', '比企郡嵐山町', 'ヒキグンランザンマチ', 'むさし台', 'ムサシダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡嵐山町菅谷', '11', '11342', '3550221', '埼玉県', 'サイタマケン', '比企郡嵐山町', 'ヒキグンランザンマチ', '菅谷', 'スガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡嵐山町大蔵', '11', '11342', '3550222', '埼玉県', 'サイタマケン', '比企郡嵐山町', 'ヒキグンランザンマチ', '大蔵', 'オオクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡嵐山町根岸', '11', '11342', '3550223', '埼玉県', 'サイタマケン', '比企郡嵐山町', 'ヒキグンランザンマチ', '根岸', 'ネギシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡嵐山町将軍沢', '11', '11342', '3550224', '埼玉県', 'サイタマケン', '比企郡嵐山町', 'ヒキグンランザンマチ', '将軍沢', 'ショウグンサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡嵐山町鎌形', '11', '11342', '3550225', '埼玉県', 'サイタマケン', '比企郡嵐山町', 'ヒキグンランザンマチ', '鎌形', 'カマガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡嵐山町遠山', '11', '11342', '3550226', '埼玉県', 'サイタマケン', '比企郡嵐山町', 'ヒキグンランザンマチ', '遠山', 'トオヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡嵐山町千手堂', '11', '11342', '3550227', '埼玉県', 'サイタマケン', '比企郡嵐山町', 'ヒキグンランザンマチ', '千手堂', 'センジュドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡小川町', '11', '11343', '3550300', '埼玉県', 'サイタマケン', '比企郡小川町', 'ヒキグンオガワマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('28157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡ときがわ町', '11', '11349', '3550300', '埼玉県', 'サイタマケン', '比企郡ときがわ町', 'ヒキグントキガワマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('28158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父郡東秩父村', '11', '11369', '3550300', '埼玉県', 'サイタマケン', '秩父郡東秩父村', 'チチブグンヒガシチチブムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('28159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡小川町西古里', '11', '11343', '3550301', '埼玉県', 'サイタマケン', '比企郡小川町', 'ヒキグンオガワマチ', '西古里', 'ニシフルサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡小川町鷹巣', '11', '11343', '3550302', '埼玉県', 'サイタマケン', '比企郡小川町', 'ヒキグンオガワマチ', '鷹巣', 'タカノス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡小川町奈良梨', '11', '11343', '3550303', '埼玉県', 'サイタマケン', '比企郡小川町', 'ヒキグンオガワマチ', '奈良梨', 'ナラナシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡小川町伊勢根', '11', '11343', '3550304', '埼玉県', 'サイタマケン', '比企郡小川町', 'ヒキグンオガワマチ', '伊勢根', 'イセネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡小川町能増', '11', '11343', '3550305', '埼玉県', 'サイタマケン', '比企郡小川町', 'ヒキグンオガワマチ', '能増', 'ノウマス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡小川町高見', '11', '11343', '3550306', '埼玉県', 'サイタマケン', '比企郡小川町', 'ヒキグンオガワマチ', '高見', 'タカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡小川町高谷', '11', '11343', '3550311', '埼玉県', 'サイタマケン', '比企郡小川町', 'ヒキグンオガワマチ', '高谷', 'コウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡小川町上横田', '11', '11343', '3550312', '埼玉県', 'サイタマケン', '比企郡小川町', 'ヒキグンオガワマチ', '上横田', 'カミヨコタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡小川町下横田', '11', '11343', '3550313', '埼玉県', 'サイタマケン', '比企郡小川町', 'ヒキグンオガワマチ', '下横田', 'シモヨコタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡小川町中爪', '11', '11343', '3550314', '埼玉県', 'サイタマケン', '比企郡小川町', 'ヒキグンオガワマチ', '中爪', 'ナカツメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡小川町みどりが丘', '11', '11343', '3550315', '埼玉県', 'サイタマケン', '比企郡小川町', 'ヒキグンオガワマチ', 'みどりが丘', 'ミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡小川町角山', '11', '11343', '3550316', '埼玉県', 'サイタマケン', '比企郡小川町', 'ヒキグンオガワマチ', '角山', 'カクヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡小川町原川', '11', '11343', '3550317', '埼玉県', 'サイタマケン', '比企郡小川町', 'ヒキグンオガワマチ', '原川', 'ハラガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡小川町ひばり台', '11', '11343', '3550318', '埼玉県', 'サイタマケン', '比企郡小川町', 'ヒキグンオガワマチ', 'ひばり台', 'ヒバリダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡小川町小川', '11', '11343', '3550321', '埼玉県', 'サイタマケン', '比企郡小川町', 'ヒキグンオガワマチ', '小川', 'オガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡小川町東小川', '11', '11343', '3550322', '埼玉県', 'サイタマケン', '比企郡小川町', 'ヒキグンオガワマチ', '東小川', 'ヒガシオガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡小川町下里', '11', '11343', '3550323', '埼玉県', 'サイタマケン', '比企郡小川町', 'ヒキグンオガワマチ', '下里', 'シモザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡小川町青山', '11', '11343', '3550324', '埼玉県', 'サイタマケン', '比企郡小川町', 'ヒキグンオガワマチ', '青山', 'アオヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡小川町上古寺', '11', '11343', '3550325', '埼玉県', 'サイタマケン', '比企郡小川町', 'ヒキグンオガワマチ', '上古寺', 'カミフルテラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡小川町下古寺', '11', '11343', '3550326', '埼玉県', 'サイタマケン', '比企郡小川町', 'ヒキグンオガワマチ', '下古寺', 'シモフルテラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡小川町腰越', '11', '11343', '3550327', '埼玉県', 'サイタマケン', '比企郡小川町', 'ヒキグンオガワマチ', '腰越', 'コシゴエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡小川町大塚', '11', '11343', '3550328', '埼玉県', 'サイタマケン', '比企郡小川町', 'ヒキグンオガワマチ', '大塚', 'オオツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡小川町靱負', '11', '11343', '3550331', '埼玉県', 'サイタマケン', '比企郡小川町', 'ヒキグンオガワマチ', '靱負', 'ユキエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡小川町増尾', '11', '11343', '3550332', '埼玉県', 'サイタマケン', '比企郡小川町', 'ヒキグンオガワマチ', '増尾', 'マスオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡小川町飯田', '11', '11343', '3550333', '埼玉県', 'サイタマケン', '比企郡小川町', 'ヒキグンオガワマチ', '飯田', 'イイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡小川町笠原', '11', '11343', '3550334', '埼玉県', 'サイタマケン', '比企郡小川町', 'ヒキグンオガワマチ', '笠原', 'カサハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡小川町木部', '11', '11343', '3550335', '埼玉県', 'サイタマケン', '比企郡小川町', 'ヒキグンオガワマチ', '木部', 'キベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡小川町勝呂', '11', '11343', '3550336', '埼玉県', 'サイタマケン', '比企郡小川町', 'ヒキグンオガワマチ', '勝呂', 'スグロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡小川町木呂子', '11', '11343', '3550337', '埼玉県', 'サイタマケン', '比企郡小川町', 'ヒキグンオガワマチ', '木呂子', 'キロコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡ときがわ町田黒', '11', '11349', '3550341', '埼玉県', 'サイタマケン', '比企郡ときがわ町', 'ヒキグントキガワマチ', '田黒', 'タグロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡ときがわ町玉川', '11', '11349', '3550342', '埼玉県', 'サイタマケン', '比企郡ときがわ町', 'ヒキグントキガワマチ', '玉川', 'タマガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡ときがわ町五明', '11', '11349', '3550343', '埼玉県', 'サイタマケン', '比企郡ときがわ町', 'ヒキグントキガワマチ', '五明', 'ゴミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡ときがわ町日影', '11', '11349', '3550344', '埼玉県', 'サイタマケン', '比企郡ときがわ町', 'ヒキグントキガワマチ', '日影', 'ヒカゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡ときがわ町雲河原', '11', '11349', '3550351', '埼玉県', 'サイタマケン', '比企郡ときがわ町', 'ヒキグントキガワマチ', '雲河原', 'クモガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡ときがわ町別所', '11', '11349', '3550352', '埼玉県', 'サイタマケン', '比企郡ときがわ町', 'ヒキグントキガワマチ', '別所', 'ベッショ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡ときがわ町本郷', '11', '11349', '3550353', '埼玉県', 'サイタマケン', '比企郡ときがわ町', 'ヒキグントキガワマチ', '本郷', 'ホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡ときがわ町番匠', '11', '11349', '3550354', '埼玉県', 'サイタマケン', '比企郡ときがわ町', 'ヒキグントキガワマチ', '番匠', 'バンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡ときがわ町馬場', '11', '11349', '3550355', '埼玉県', 'サイタマケン', '比企郡ときがわ町', 'ヒキグントキガワマチ', '馬場', 'バンバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡ときがわ町関堀', '11', '11349', '3550356', '埼玉県', 'サイタマケン', '比企郡ときがわ町', 'ヒキグントキガワマチ', '関堀', 'セキボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡ときがわ町田中', '11', '11349', '3550357', '埼玉県', 'サイタマケン', '比企郡ときがわ町', 'ヒキグントキガワマチ', '田中', 'タナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡ときがわ町瀬戸元上', '11', '11349', '3550358', '埼玉県', 'サイタマケン', '比企郡ときがわ町', 'ヒキグントキガワマチ', '瀬戸元上', 'セトモトカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡ときがわ町瀬戸元下', '11', '11349', '3550359', '埼玉県', 'サイタマケン', '比企郡ときがわ町', 'ヒキグントキガワマチ', '瀬戸元下', 'セトモトシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡ときがわ町桃木', '11', '11349', '3550361', '埼玉県', 'サイタマケン', '比企郡ときがわ町', 'ヒキグントキガワマチ', '桃木', 'モモノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡ときがわ町大附', '11', '11349', '3550363', '埼玉県', 'サイタマケン', '比企郡ときがわ町', 'ヒキグントキガワマチ', '大附', 'オオツキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡ときがわ町西平', '11', '11349', '3550364', '埼玉県', 'サイタマケン', '比企郡ときがわ町', 'ヒキグントキガワマチ', '西平', 'ニシダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡ときがわ町椚平', '11', '11349', '3550365', '埼玉県', 'サイタマケン', '比企郡ときがわ町', 'ヒキグントキガワマチ', '椚平', 'クヌギダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡ときがわ町大野', '11', '11349', '3550366', '埼玉県', 'サイタマケン', '比企郡ときがわ町', 'ヒキグントキガワマチ', '大野', 'オオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父郡東秩父村大内沢', '11', '11369', '3550371', '埼玉県', 'サイタマケン', '秩父郡東秩父村', 'チチブグンヒガシチチブムラ', '大内沢', 'オオウチザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父郡東秩父村坂本', '11', '11369', '3550372', '埼玉県', 'サイタマケン', '秩父郡東秩父村', 'チチブグンヒガシチチブムラ', '坂本', 'サカモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父郡東秩父村奥沢', '11', '11369', '3550373', '埼玉県', 'サイタマケン', '秩父郡東秩父村', 'チチブグンヒガシチチブムラ', '奥沢', 'オクサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父郡東秩父村安戸', '11', '11369', '3550374', '埼玉県', 'サイタマケン', '秩父郡東秩父村', 'チチブグンヒガシチチブムラ', '安戸', 'ヤスド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父郡東秩父村御堂', '11', '11369', '3550375', '埼玉県', 'サイタマケン', '秩父郡東秩父村', 'チチブグンヒガシチチブムラ', '御堂', 'ミドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父郡東秩父村皆谷', '11', '11369', '3550376', '埼玉県', 'サイタマケン', '秩父郡東秩父村', 'チチブグンヒガシチチブムラ', '皆谷', 'カイヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父郡東秩父村白石', '11', '11369', '3550377', '埼玉県', 'サイタマケン', '秩父郡東秩父村', 'チチブグンヒガシチチブムラ', '白石', 'シロイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡滑川町', '11', '11341', '3550800', '埼玉県', 'サイタマケン', '比企郡滑川町', 'ヒキグンナメガワマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('28216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡滑川町土塩', '11', '11341', '3550801', '埼玉県', 'サイタマケン', '比企郡滑川町', 'ヒキグンナメガワマチ', '土塩', 'ツチシオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡滑川町山田', '11', '11341', '3550802', '埼玉県', 'サイタマケン', '比企郡滑川町', 'ヒキグンナメガワマチ', '山田', 'ヤマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡滑川町福田', '11', '11341', '3550803', '埼玉県', 'サイタマケン', '比企郡滑川町', 'ヒキグンナメガワマチ', '福田', 'フクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡滑川町中尾', '11', '11341', '3550804', '埼玉県', 'サイタマケン', '比企郡滑川町', 'ヒキグンナメガワマチ', '中尾', 'ナカオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡滑川町水房', '11', '11341', '3550805', '埼玉県', 'サイタマケン', '比企郡滑川町', 'ヒキグンナメガワマチ', '水房', 'ミズフサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡滑川町伊古', '11', '11341', '3550806', '埼玉県', 'サイタマケン', '比企郡滑川町', 'ヒキグンナメガワマチ', '伊古', 'イコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡滑川町和泉', '11', '11341', '3550807', '埼玉県', 'サイタマケン', '比企郡滑川町', 'ヒキグンナメガワマチ', '和泉', 'イズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡滑川町菅田', '11', '11341', '3550808', '埼玉県', 'サイタマケン', '比企郡滑川町', 'ヒキグンナメガワマチ', '菅田', 'スガダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡滑川町羽尾', '11', '11341', '3550811', '埼玉県', 'サイタマケン', '比企郡滑川町', 'ヒキグンナメガワマチ', '羽尾', 'ハネオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡滑川町都', '11', '11341', '3550812', '埼玉県', 'サイタマケン', '比企郡滑川町', 'ヒキグンナメガワマチ', '都', 'ミヤコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡滑川町月輪', '11', '11341', '3550813', '埼玉県', 'サイタマケン', '比企郡滑川町', 'ヒキグンナメガワマチ', '月輪', 'ツキノワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡滑川町みなみ野', '11', '11341', '3550814', '埼玉県', 'サイタマケン', '比企郡滑川町', 'ヒキグンナメガワマチ', 'みなみ野', 'ミナミノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県比企郡滑川町月の輪', '11', '11341', '3550815', '埼玉県', 'サイタマケン', '比企郡滑川町', 'ヒキグンナメガワマチ', '月の輪', 'ツキノワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県ふじみ野市', '11', '11245', '3560000', '埼玉県', 'サイタマケン', 'ふじみ野市', 'フジミノシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('28236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県ふじみ野市川崎', '11', '11245', '3560001', '埼玉県', 'サイタマケン', 'ふじみ野市', 'フジミノシ', '川崎', 'カワサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県ふじみ野市清見', '11', '11245', '3560002', '埼玉県', 'サイタマケン', 'ふじみ野市', 'フジミノシ', '清見', 'キヨミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県ふじみ野市大原', '11', '11245', '3560003', '埼玉県', 'サイタマケン', 'ふじみ野市', 'フジミノシ', '大原', 'オオハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県ふじみ野市上福岡', '11', '11245', '3560004', '埼玉県', 'サイタマケン', 'ふじみ野市', 'フジミノシ', '上福岡', 'カミフクオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県ふじみ野市西', '11', '11245', '3560005', '埼玉県', 'サイタマケン', 'ふじみ野市', 'フジミノシ', '西', 'ニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県ふじみ野市霞ケ丘', '11', '11245', '3560006', '埼玉県', 'サイタマケン', 'ふじみ野市', 'フジミノシ', '霞ケ丘', 'カスミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県ふじみ野市北野', '11', '11245', '3560007', '埼玉県', 'サイタマケン', 'ふじみ野市', 'フジミノシ', '北野', 'キタノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県ふじみ野市元福岡', '11', '11245', '3560008', '埼玉県', 'サイタマケン', 'ふじみ野市', 'フジミノシ', '元福岡', 'モトフクオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県ふじみ野市福岡', '11', '11245', '3560011', '埼玉県', 'サイタマケン', 'ふじみ野市', 'フジミノシ', '福岡', 'フクオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県ふじみ野市滝', '11', '11245', '3560012', '埼玉県', 'サイタマケン', 'ふじみ野市', 'フジミノシ', '滝', 'タキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県ふじみ野市中福岡', '11', '11245', '3560013', '埼玉県', 'サイタマケン', 'ふじみ野市', 'フジミノシ', '中福岡', 'ナカフクオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県ふじみ野市福岡新田', '11', '11245', '3560014', '埼玉県', 'サイタマケン', 'ふじみ野市', 'フジミノシ', '福岡新田', 'フクオカシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県ふじみ野市花ノ木', '11', '11245', '3560015', '埼玉県', 'サイタマケン', 'ふじみ野市', 'フジミノシ', '花ノ木', 'ハナノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県ふじみ野市中丸', '11', '11245', '3560016', '埼玉県', 'サイタマケン', 'ふじみ野市', 'フジミノシ', '中丸', 'ナカマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県ふじみ野市上野台', '11', '11245', '3560017', '埼玉県', 'サイタマケン', 'ふじみ野市', 'フジミノシ', '上野台', 'ウエノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県ふじみ野市本新田', '11', '11245', '3560018', '埼玉県', 'サイタマケン', 'ふじみ野市', 'フジミノシ', '本新田', 'ホンシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県ふじみ野市池上', '11', '11245', '3560019', '埼玉県', 'サイタマケン', 'ふじみ野市', 'フジミノシ', '池上', 'イケガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県ふじみ野市水宮', '11', '11245', '3560020', '埼玉県', 'サイタマケン', 'ふじみ野市', 'フジミノシ', '水宮', 'スイグウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県ふじみ野市上ノ原', '11', '11245', '3560021', '埼玉県', 'サイタマケン', 'ふじみ野市', 'フジミノシ', '上ノ原', 'ウエノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県ふじみ野市長宮', '11', '11245', '3560022', '埼玉県', 'サイタマケン', 'ふじみ野市', 'フジミノシ', '長宮', 'ナガミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県ふじみ野市中ノ島', '11', '11245', '3560023', '埼玉県', 'サイタマケン', 'ふじみ野市', 'フジミノシ', '中ノ島', 'ナカノシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県ふじみ野市谷田', '11', '11245', '3560024', '埼玉県', 'サイタマケン', 'ふじみ野市', 'フジミノシ', '谷田', 'ヤタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県ふじみ野市仲', '11', '11245', '3560025', '埼玉県', 'サイタマケン', 'ふじみ野市', 'フジミノシ', '仲', 'ナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県ふじみ野市築地', '11', '11245', '3560026', '埼玉県', 'サイタマケン', 'ふじみ野市', 'フジミノシ', '築地', 'ツキジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県ふじみ野市松山', '11', '11245', '3560027', '埼玉県', 'サイタマケン', 'ふじみ野市', 'フジミノシ', '松山', 'マツヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県ふじみ野市西原', '11', '11245', '3560028', '埼玉県', 'サイタマケン', 'ふじみ野市', 'フジミノシ', '西原', 'ニシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県ふじみ野市駒西', '11', '11245', '3560029', '埼玉県', 'サイタマケン', 'ふじみ野市', 'フジミノシ', '駒西', 'コマニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県ふじみ野市新駒林', '11', '11245', '3560030', '埼玉県', 'サイタマケン', 'ふじみ野市', 'フジミノシ', '新駒林', 'シンコマバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県ふじみ野市福岡中央', '11', '11245', '3560031', '埼玉県', 'サイタマケン', 'ふじみ野市', 'フジミノシ', '福岡中央', 'フクオカチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県ふじみ野市富士見台', '11', '11245', '3560032', '埼玉県', 'サイタマケン', 'ふじみ野市', 'フジミノシ', '富士見台', 'フジミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県ふじみ野市新田', '11', '11245', '3560033', '埼玉県', 'サイタマケン', 'ふじみ野市', 'フジミノシ', '新田', 'シンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県ふじみ野市駒林', '11', '11245', '3560034', '埼玉県', 'サイタマケン', 'ふじみ野市', 'フジミノシ', '駒林', 'コマハヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県ふじみ野市丸山', '11', '11245', '3560035', '埼玉県', 'サイタマケン', 'ふじみ野市', 'フジミノシ', '丸山', 'マルヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県ふじみ野市南台', '11', '11245', '3560036', '埼玉県', 'サイタマケン', 'ふじみ野市', 'フジミノシ', '南台', 'ミナミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県ふじみ野市福岡武蔵野', '11', '11245', '3560037', '埼玉県', 'サイタマケン', 'ふじみ野市', 'フジミノシ', '福岡武蔵野', 'フクオカムサシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県ふじみ野市鶴ケ舞', '11', '11245', '3560041', '埼玉県', 'サイタマケン', 'ふじみ野市', 'フジミノシ', '鶴ケ舞', 'ツルガマイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県ふじみ野市東久保', '11', '11245', '3560042', '埼玉県', 'サイタマケン', 'ふじみ野市', 'フジミノシ', '東久保', 'ヒガシクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県ふじみ野市緑ケ丘', '11', '11245', '3560043', '埼玉県', 'サイタマケン', 'ふじみ野市', 'フジミノシ', '緑ケ丘', 'ミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県ふじみ野市西鶴ケ岡', '11', '11245', '3560044', '埼玉県', 'サイタマケン', 'ふじみ野市', 'フジミノシ', '西鶴ケ岡', 'ニシツルガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県ふじみ野市鶴ケ岡', '11', '11245', '3560045', '埼玉県', 'サイタマケン', 'ふじみ野市', 'フジミノシ', '鶴ケ岡', 'ツルガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県ふじみ野市ふじみ野', '11', '11245', '3560050', '埼玉県', 'サイタマケン', 'ふじみ野市', 'フジミノシ', 'ふじみ野', 'フジミノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県ふじみ野市亀久保', '11', '11245', '3560051', '埼玉県', 'サイタマケン', 'ふじみ野市', 'フジミノシ', '亀久保', 'カメクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県ふじみ野市苗間', '11', '11245', '3560052', '埼玉県', 'サイタマケン', 'ふじみ野市', 'フジミノシ', '苗間', 'ナエマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県ふじみ野市大井', '11', '11245', '3560053', '埼玉県', 'サイタマケン', 'ふじみ野市', 'フジミノシ', '大井', 'オオイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県ふじみ野市大井武蔵野', '11', '11245', '3560054', '埼玉県', 'サイタマケン', 'ふじみ野市', 'フジミノシ', '大井武蔵野', 'オオイムサシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県ふじみ野市旭', '11', '11245', '3560055', '埼玉県', 'サイタマケン', 'ふじみ野市', 'フジミノシ', '旭', 'アサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県ふじみ野市うれし野', '11', '11245', '3560056', '埼玉県', 'サイタマケン', 'ふじみ野市', 'フジミノシ', 'うれし野', 'ウレシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県ふじみ野市市沢', '11', '11245', '3560057', '埼玉県', 'サイタマケン', 'ふじみ野市', 'フジミノシ', '市沢', 'イチサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県ふじみ野市大井中央', '11', '11245', '3560058', '埼玉県', 'サイタマケン', 'ふじみ野市', 'フジミノシ', '大井中央', 'オオイチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県ふじみ野市桜ケ丘', '11', '11245', '3560059', '埼玉県', 'サイタマケン', 'ふじみ野市', 'フジミノシ', '桜ケ丘', 'サクラガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県飯能市', '11', '11209', '3570000', '埼玉県', 'サイタマケン', '飯能市', 'ハンノウシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('28297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県飯能市宮沢', '11', '11209', '3570001', '埼玉県', 'サイタマケン', '飯能市', 'ハンノウシ', '宮沢', 'ミヤザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県飯能市中居', '11', '11209', '3570002', '埼玉県', 'サイタマケン', '飯能市', 'ハンノウシ', '中居', 'ナカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県飯能市青木', '11', '11209', '3570003', '埼玉県', 'サイタマケン', '飯能市', 'ハンノウシ', '青木', 'アオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県飯能市新町', '11', '11209', '3570004', '埼玉県', 'サイタマケン', '飯能市', 'ハンノウシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県飯能市原町', '11', '11209', '3570005', '埼玉県', 'サイタマケン', '飯能市', 'ハンノウシ', '原町', 'ハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県飯能市中山', '11', '11209', '3570006', '埼玉県', 'サイタマケン', '飯能市', 'ハンノウシ', '中山', 'ナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県飯能市川崎', '11', '11209', '3570011', '埼玉県', 'サイタマケン', '飯能市', 'ハンノウシ', '川崎', 'カワサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県飯能市下川崎', '11', '11209', '3570012', '埼玉県', 'サイタマケン', '飯能市', 'ハンノウシ', '下川崎', 'シモカワサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県飯能市芦苅場', '11', '11209', '3570013', '埼玉県', 'サイタマケン', '飯能市', 'ハンノウシ', '芦苅場', 'アシカリバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県飯能市平松', '11', '11209', '3570014', '埼玉県', 'サイタマケン', '飯能市', 'ハンノウシ', '平松', 'ヒラマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県飯能市小久保', '11', '11209', '3570015', '埼玉県', 'サイタマケン', '飯能市', 'ハンノウシ', '小久保', 'コクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県飯能市下加治', '11', '11209', '3570016', '埼玉県', 'サイタマケン', '飯能市', 'ハンノウシ', '下加治', 'シモカジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県飯能市双柳', '11', '11209', '3570021', '埼玉県', 'サイタマケン', '飯能市', 'ハンノウシ', '双柳', 'ナミヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県飯能市新光', '11', '11209', '3570022', '埼玉県', 'サイタマケン', '飯能市', 'ハンノウシ', '新光', 'シンコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県飯能市岩沢', '11', '11209', '3570023', '埼玉県', 'サイタマケン', '飯能市', 'ハンノウシ', '岩沢', 'イワサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県飯能市緑町', '11', '11209', '3570024', '埼玉県', 'サイタマケン', '飯能市', 'ハンノウシ', '緑町', 'ミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県飯能市栄町', '11', '11209', '3570025', '埼玉県', 'サイタマケン', '飯能市', 'ハンノウシ', '栄町', 'サカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県飯能市山手町', '11', '11209', '3570031', '埼玉県', 'サイタマケン', '飯能市', 'ハンノウシ', '山手町', 'ヤマテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県飯能市本町', '11', '11209', '3570032', '埼玉県', 'サイタマケン', '飯能市', 'ハンノウシ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県飯能市八幡町', '11', '11209', '3570033', '埼玉県', 'サイタマケン', '飯能市', 'ハンノウシ', '八幡町', 'ハチマンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県飯能市東町', '11', '11209', '3570034', '埼玉県', 'サイタマケン', '飯能市', 'ハンノウシ', '東町', 'アズマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県飯能市柳町', '11', '11209', '3570035', '埼玉県', 'サイタマケン', '飯能市', 'ハンノウシ', '柳町', 'ヤナギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県飯能市南町', '11', '11209', '3570036', '埼玉県', 'サイタマケン', '飯能市', 'ハンノウシ', '南町', 'ミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県飯能市稲荷町', '11', '11209', '3570037', '埼玉県', 'サイタマケン', '飯能市', 'ハンノウシ', '稲荷町', 'イナリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県飯能市仲町', '11', '11209', '3570038', '埼玉県', 'サイタマケン', '飯能市', 'ハンノウシ', '仲町', 'ナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県飯能市美杉台', '11', '11209', '3570041', '埼玉県', 'サイタマケン', '飯能市', 'ハンノウシ', '美杉台', 'ミスギダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県飯能市矢颪', '11', '11209', '3570042', '埼玉県', 'サイタマケン', '飯能市', 'ハンノウシ', '矢颪', 'ヤオロシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県飯能市前ケ貫', '11', '11209', '3570043', '埼玉県', 'サイタマケン', '飯能市', 'ハンノウシ', '前ケ貫', 'マエガヌキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県飯能市川寺', '11', '11209', '3570044', '埼玉県', 'サイタマケン', '飯能市', 'ハンノウシ', '川寺', 'カワデラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県飯能市笠縫', '11', '11209', '3570045', '埼玉県', 'サイタマケン', '飯能市', 'ハンノウシ', '笠縫', 'カサヌイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県飯能市阿須', '11', '11209', '3570046', '埼玉県', 'サイタマケン', '飯能市', 'ハンノウシ', '阿須', 'アズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県飯能市落合', '11', '11209', '3570047', '埼玉県', 'サイタマケン', '飯能市', 'ハンノウシ', '落合', 'オチアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県飯能市岩渕', '11', '11209', '3570048', '埼玉県', 'サイタマケン', '飯能市', 'ハンノウシ', '岩渕', 'イワブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県飯能市征矢町', '11', '11209', '3570049', '埼玉県', 'サイタマケン', '飯能市', 'ハンノウシ', '征矢町', 'ソヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県飯能市苅生', '11', '11209', '3570051', '埼玉県', 'サイタマケン', '飯能市', 'ハンノウシ', '苅生', 'カロウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県飯能市下畑', '11', '11209', '3570052', '埼玉県', 'サイタマケン', '飯能市', 'ハンノウシ', '下畑', 'シモハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県飯能市上畑', '11', '11209', '3570053', '埼玉県', 'サイタマケン', '飯能市', 'ハンノウシ', '上畑', 'カミハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県飯能市下直竹', '11', '11209', '3570054', '埼玉県', 'サイタマケン', '飯能市', 'ハンノウシ', '下直竹', 'シモナオタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県飯能市上直竹下分', '11', '11209', '3570055', '埼玉県', 'サイタマケン', '飯能市', 'ハンノウシ', '上直竹下分', 'カミナオタケシモブン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県飯能市上直竹上分', '11', '11209', '3570056', '埼玉県', 'サイタマケン', '飯能市', 'ハンノウシ', '上直竹上分', 'カミナオタケカミブン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県飯能市永田台', '11', '11209', '3570061', '埼玉県', 'サイタマケン', '飯能市', 'ハンノウシ', '永田台', 'ナガタダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県飯能市永田', '11', '11209', '3570062', '埼玉県', 'サイタマケン', '飯能市', 'ハンノウシ', '永田', 'ナガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県飯能市飯能', '11', '11209', '3570063', '埼玉県', 'サイタマケン', '飯能市', 'ハンノウシ', '飯能', 'ハンノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県飯能市久下', '11', '11209', '3570064', '埼玉県', 'サイタマケン', '飯能市', 'ハンノウシ', '久下', 'クゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県飯能市大河原', '11', '11209', '3570065', '埼玉県', 'サイタマケン', '飯能市', 'ハンノウシ', '大河原', 'オオカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県飯能市小岩井', '11', '11209', '3570066', '埼玉県', 'サイタマケン', '飯能市', 'ハンノウシ', '小岩井', 'コイワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県飯能市小瀬戸', '11', '11209', '3570067', '埼玉県', 'サイタマケン', '飯能市', 'ハンノウシ', '小瀬戸', 'コセド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県飯能市久須美', '11', '11209', '3570068', '埼玉県', 'サイタマケン', '飯能市', 'ハンノウシ', '久須美', 'クスミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県飯能市上名栗', '11', '11209', '3570111', '埼玉県', 'サイタマケン', '飯能市', 'ハンノウシ', '上名栗', 'カミナグリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県飯能市下名栗', '11', '11209', '3570112', '埼玉県', 'サイタマケン', '飯能市', 'ハンノウシ', '下名栗', 'シモナグリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県飯能市中藤上郷', '11', '11209', '3570121', '埼玉県', 'サイタマケン', '飯能市', 'ハンノウシ', '中藤上郷', 'ナカトウカミゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県飯能市中藤中郷', '11', '11209', '3570122', '埼玉県', 'サイタマケン', '飯能市', 'ハンノウシ', '中藤中郷', 'ナカトウナカゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県飯能市中藤下郷', '11', '11209', '3570123', '埼玉県', 'サイタマケン', '飯能市', 'ハンノウシ', '中藤下郷', 'ナカトウシモゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県飯能市原市場', '11', '11209', '3570124', '埼玉県', 'サイタマケン', '飯能市', 'ハンノウシ', '原市場', 'ハライチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県飯能市上赤工', '11', '11209', '3570125', '埼玉県', 'サイタマケン', '飯能市', 'ハンノウシ', '上赤工', 'カミアカダクミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県飯能市下赤工', '11', '11209', '3570126', '埼玉県', 'サイタマケン', '飯能市', 'ハンノウシ', '下赤工', 'シモアカダクミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県飯能市唐竹', '11', '11209', '3570127', '埼玉県', 'サイタマケン', '飯能市', 'ハンノウシ', '唐竹', 'カラタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県飯能市赤沢', '11', '11209', '3570128', '埼玉県', 'サイタマケン', '飯能市', 'ハンノウシ', '赤沢', 'アカザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県飯能市北川', '11', '11209', '3570201', '埼玉県', 'サイタマケン', '飯能市', 'ハンノウシ', '北川', 'キタガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県飯能市高山', '11', '11209', '3570202', '埼玉県', 'サイタマケン', '飯能市', 'ハンノウシ', '高山', 'タカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県飯能市長沢', '11', '11209', '3570203', '埼玉県', 'サイタマケン', '飯能市', 'ハンノウシ', '長沢', 'ナガサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県飯能市虎秀', '11', '11209', '3570204', '埼玉県', 'サイタマケン', '飯能市', 'ハンノウシ', '虎秀', 'コシュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県飯能市白子', '11', '11209', '3570205', '埼玉県', 'サイタマケン', '飯能市', 'ハンノウシ', '白子', 'シラコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県飯能市上長沢', '11', '11209', '3570206', '埼玉県', 'サイタマケン', '飯能市', 'ハンノウシ', '上長沢', 'カミナガサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県飯能市平戸', '11', '11209', '3570211', '埼玉県', 'サイタマケン', '飯能市', 'ハンノウシ', '平戸', 'ヒラト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県飯能市井上', '11', '11209', '3570212', '埼玉県', 'サイタマケン', '飯能市', 'ハンノウシ', '井上', 'イノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県飯能市坂石町分', '11', '11209', '3570213', '埼玉県', 'サイタマケン', '飯能市', 'ハンノウシ', '坂石町分', 'サカイシマチブン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県飯能市南', '11', '11209', '3570214', '埼玉県', 'サイタマケン', '飯能市', 'ハンノウシ', '南', 'ミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県飯能市坂石', '11', '11209', '3570215', '埼玉県', 'サイタマケン', '飯能市', 'ハンノウシ', '坂石', 'サカイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県飯能市吾野', '11', '11209', '3570216', '埼玉県', 'サイタマケン', '飯能市', 'ハンノウシ', '吾野', 'アガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県飯能市南川', '11', '11209', '3570217', '埼玉県', 'サイタマケン', '飯能市', 'ハンノウシ', '南川', 'ミナミカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県飯能市坂元', '11', '11209', '3570218', '埼玉県', 'サイタマケン', '飯能市', 'ハンノウシ', '坂元', 'サカモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県入間市', '11', '11225', '3580000', '埼玉県', 'サイタマケン', '入間市', 'イルマシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('28379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県入間市向陽台', '11', '11225', '3580001', '埼玉県', 'サイタマケン', '入間市', 'イルマシ', '向陽台', 'コウヨウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県入間市東町', '11', '11225', '3580002', '埼玉県', 'サイタマケン', '入間市', 'イルマシ', '東町', 'アズマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県入間市豊岡', '11', '11225', '3580003', '埼玉県', 'サイタマケン', '入間市', 'イルマシ', '豊岡', 'トヨオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県入間市鍵山', '11', '11225', '3580004', '埼玉県', 'サイタマケン', '入間市', 'イルマシ', '鍵山', 'カギヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県入間市宮前町', '11', '11225', '3580005', '埼玉県', 'サイタマケン', '入間市', 'イルマシ', '宮前町', 'ミヤマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県入間市春日町', '11', '11225', '3580006', '埼玉県', 'サイタマケン', '入間市', 'イルマシ', '春日町', 'カスガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県入間市黒須', '11', '11225', '3580007', '埼玉県', 'サイタマケン', '入間市', 'イルマシ', '黒須', 'クロス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県入間市河原町', '11', '11225', '3580008', '埼玉県', 'サイタマケン', '入間市', 'イルマシ', '河原町', 'カワラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県入間市下藤沢', '11', '11225', '3580011', '埼玉県', 'サイタマケン', '入間市', 'イルマシ', '下藤沢', 'シモフジサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県入間市東藤沢', '11', '11225', '3580012', '埼玉県', 'サイタマケン', '入間市', 'イルマシ', '東藤沢', 'ヒガシフジサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県入間市上藤沢', '11', '11225', '3580013', '埼玉県', 'サイタマケン', '入間市', 'イルマシ', '上藤沢', 'カミフジサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県入間市宮寺', '11', '11225', '3580014', '埼玉県', 'サイタマケン', '入間市', 'イルマシ', '宮寺', 'ミヤデラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県入間市二本木', '11', '11225', '3580015', '埼玉県', 'サイタマケン', '入間市', 'イルマシ', '二本木', 'ニホンギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県入間市高根', '11', '11225', '3580016', '埼玉県', 'サイタマケン', '入間市', 'イルマシ', '高根', 'タカネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県入間市駒形富士山', '11', '11225', '3580017', '埼玉県', 'サイタマケン', '入間市', 'イルマシ', '駒形富士山', 'コマガタフジヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県入間市高倉', '11', '11225', '3580021', '埼玉県', 'サイタマケン', '入間市', 'イルマシ', '高倉', 'タカクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県入間市扇町屋', '11', '11225', '3580022', '埼玉県', 'サイタマケン', '入間市', 'イルマシ', '扇町屋', 'オウギマチヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県入間市扇台', '11', '11225', '3580023', '埼玉県', 'サイタマケン', '入間市', 'イルマシ', '扇台', 'オウギダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県入間市久保稲荷', '11', '11225', '3580024', '埼玉県', 'サイタマケン', '入間市', 'イルマシ', '久保稲荷', 'クボイナリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県入間市善蔵新田', '11', '11225', '3580025', '埼玉県', 'サイタマケン', '入間市', 'イルマシ', '善蔵新田', 'ゼンゾウシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県入間市小谷田', '11', '11225', '3580026', '埼玉県', 'サイタマケン', '入間市', 'イルマシ', '小谷田', 'コヤタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県入間市上小谷田', '11', '11225', '3580027', '埼玉県', 'サイタマケン', '入間市', 'イルマシ', '上小谷田', 'ウエゴヤタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県入間市新久', '11', '11225', '3580031', '埼玉県', 'サイタマケン', '入間市', 'イルマシ', '新久', 'アラク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県入間市狭山ケ原', '11', '11225', '3580032', '埼玉県', 'サイタマケン', '入間市', 'イルマシ', '狭山ケ原', 'サヤマガハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県入間市狭山台', '11', '11225', '3580033', '埼玉県', 'サイタマケン', '入間市', 'イルマシ', '狭山台', 'サヤマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県入間市根岸', '11', '11225', '3580034', '埼玉県', 'サイタマケン', '入間市', 'イルマシ', '根岸', 'ネギシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県入間市中神', '11', '11225', '3580035', '埼玉県', 'サイタマケン', '入間市', 'イルマシ', '中神', 'ナカガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県入間市花ノ木', '11', '11225', '3580036', '埼玉県', 'サイタマケン', '入間市', 'イルマシ', '花ノ木', 'ハナノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県入間市下谷ケ貫', '11', '11225', '3580041', '埼玉県', 'サイタマケン', '入間市', 'イルマシ', '下谷ケ貫', 'シモヤガヌキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県入間市上谷ケ貫', '11', '11225', '3580042', '埼玉県', 'サイタマケン', '入間市', 'イルマシ', '上谷ケ貫', 'カミヤガヌキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県入間市西三ツ木', '11', '11225', '3580043', '埼玉県', 'サイタマケン', '入間市', 'イルマシ', '西三ツ木', 'ニシミツギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県入間市三ツ木台', '11', '11225', '3580044', '埼玉県', 'サイタマケン', '入間市', 'イルマシ', '三ツ木台', 'ミツギダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県入間市寺竹', '11', '11225', '3580045', '埼玉県', 'サイタマケン', '入間市', 'イルマシ', '寺竹', 'テラダケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県入間市南峯', '11', '11225', '3580046', '埼玉県', 'サイタマケン', '入間市', 'イルマシ', '南峯', 'ミナミミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県入間市木蓮寺', '11', '11225', '3580047', '埼玉県', 'サイタマケン', '入間市', 'イルマシ', '木蓮寺', 'モクレンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県入間市金子中央', '11', '11225', '3580048', '埼玉県', 'サイタマケン', '入間市', 'イルマシ', '金子中央', 'カネコチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県入間市牛沢町', '11', '11225', '3580051', '埼玉県', 'サイタマケン', '入間市', 'イルマシ', '牛沢町', 'ウシザワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県入間市森坂', '11', '11225', '3580052', '埼玉県', 'サイタマケン', '入間市', 'イルマシ', '森坂', 'モリサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県入間市仏子', '11', '11225', '3580053', '埼玉県', 'サイタマケン', '入間市', 'イルマシ', '仏子', 'ブシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県入間市野田', '11', '11225', '3580054', '埼玉県', 'サイタマケン', '入間市', 'イルマシ', '野田', 'ノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県入間市新光', '11', '11225', '3580055', '埼玉県', 'サイタマケン', '入間市', 'イルマシ', '新光', 'シンコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県所沢市', '11', '11208', '3590000', '埼玉県', 'サイタマケン', '所沢市', 'トコロザワシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('28431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県所沢市下富', '11', '11208', '3590001', '埼玉県', 'サイタマケン', '所沢市', 'トコロザワシ', '下富', 'シモトミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県所沢市中富', '11', '11208', '3590002', '埼玉県', 'サイタマケン', '所沢市', 'トコロザワシ', '中富', 'ナカトミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県所沢市中富南', '11', '11208', '3590003', '埼玉県', 'サイタマケン', '所沢市', 'トコロザワシ', '中富南', 'ナカトミミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県所沢市北原町', '11', '11208', '3590004', '埼玉県', 'サイタマケン', '所沢市', 'トコロザワシ', '北原町', 'キタハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県所沢市神米金', '11', '11208', '3590005', '埼玉県', 'サイタマケン', '所沢市', 'トコロザワシ', '神米金', 'カメガネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県所沢市所沢新町', '11', '11208', '3590006', '埼玉県', 'サイタマケン', '所沢市', 'トコロザワシ', '所沢新町', 'トコロザワシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県所沢市北岩岡', '11', '11208', '3590007', '埼玉県', 'サイタマケン', '所沢市', 'トコロザワシ', '北岩岡', 'キタイワオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県所沢市南永井', '11', '11208', '3590011', '埼玉県', 'サイタマケン', '所沢市', 'トコロザワシ', '南永井', 'ミナミナガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県所沢市坂之下', '11', '11208', '3590012', '埼玉県', 'サイタマケン', '所沢市', 'トコロザワシ', '坂之下', 'サカノシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県所沢市城', '11', '11208', '3590013', '埼玉県', 'サイタマケン', '所沢市', 'トコロザワシ', '城', 'シロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県所沢市亀ケ谷', '11', '11208', '3590014', '埼玉県', 'サイタマケン', '所沢市', 'トコロザワシ', '亀ケ谷', 'カメガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県所沢市日比田', '11', '11208', '3590015', '埼玉県', 'サイタマケン', '所沢市', 'トコロザワシ', '日比田', 'ヒビタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県所沢市新郷', '11', '11208', '3590016', '埼玉県', 'サイタマケン', '所沢市', 'トコロザワシ', '新郷', 'シンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県所沢市東所沢', '11', '11208', '3590021', '埼玉県', 'サイタマケン', '所沢市', 'トコロザワシ', '東所沢', 'ヒガシトコロザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県所沢市本郷', '11', '11208', '3590022', '埼玉県', 'サイタマケン', '所沢市', 'トコロザワシ', '本郷', 'ホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県所沢市東所沢和田', '11', '11208', '3590023', '埼玉県', 'サイタマケン', '所沢市', 'トコロザワシ', '東所沢和田', 'ヒガシトコロザワワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県所沢市下安松', '11', '11208', '3590024', '埼玉県', 'サイタマケン', '所沢市', 'トコロザワシ', '下安松', 'シモヤスマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県所沢市上安松', '11', '11208', '3590025', '埼玉県', 'サイタマケン', '所沢市', 'トコロザワシ', '上安松', 'カミヤスマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県所沢市牛沼', '11', '11208', '3590026', '埼玉県', 'サイタマケン', '所沢市', 'トコロザワシ', '牛沼', 'ウシヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県所沢市松郷', '11', '11208', '3590027', '埼玉県', 'サイタマケン', '所沢市', 'トコロザワシ', '松郷', 'マツゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県所沢市下新井', '11', '11208', '3590031', '埼玉県', 'サイタマケン', '所沢市', 'トコロザワシ', '下新井', 'シモアライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県所沢市若松町', '11', '11208', '3590032', '埼玉県', 'サイタマケン', '所沢市', 'トコロザワシ', '若松町', 'ワカマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県所沢市こぶし町', '11', '11208', '3590033', '埼玉県', 'サイタマケン', '所沢市', 'トコロザワシ', 'こぶし町', 'コブシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県所沢市東新井町', '11', '11208', '3590034', '埼玉県', 'サイタマケン', '所沢市', 'トコロザワシ', '東新井町', 'ヒガシアライチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県所沢市西新井町', '11', '11208', '3590035', '埼玉県', 'サイタマケン', '所沢市', 'トコロザワシ', '西新井町', 'ニシアライチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県所沢市旭町', '11', '11208', '3590036', '埼玉県', 'サイタマケン', '所沢市', 'トコロザワシ', '旭町', 'アサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県所沢市くすのき台', '11', '11208', '3590037', '埼玉県', 'サイタマケン', '所沢市', 'トコロザワシ', 'くすのき台', 'クスノキダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県所沢市北秋津', '11', '11208', '3590038', '埼玉県', 'サイタマケン', '所沢市', 'トコロザワシ', '北秋津', 'キタアキツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県所沢市中新井', '11', '11208', '3590041', '埼玉県', 'サイタマケン', '所沢市', 'トコロザワシ', '中新井', 'ナカアライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県所沢市並木', '11', '11208', '3590042', '埼玉県', 'サイタマケン', '所沢市', 'トコロザワシ', '並木', 'ナミキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県所沢市弥生町', '11', '11208', '3590043', '埼玉県', 'サイタマケン', '所沢市', 'トコロザワシ', '弥生町', 'ヤヨイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県所沢市松葉町', '11', '11208', '3590044', '埼玉県', 'サイタマケン', '所沢市', 'トコロザワシ', '松葉町', 'マツバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県所沢市美原町', '11', '11208', '3590045', '埼玉県', 'サイタマケン', '所沢市', 'トコロザワシ', '美原町', 'ミハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県所沢市北所沢町', '11', '11208', '3590046', '埼玉県', 'サイタマケン', '所沢市', 'トコロザワシ', '北所沢町', 'キタトコロザワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県所沢市花園', '11', '11208', '3590047', '埼玉県', 'サイタマケン', '所沢市', 'トコロザワシ', '花園', 'ハナゾノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県所沢市北中', '11', '11208', '3591101', '埼玉県', 'サイタマケン', '所沢市', 'トコロザワシ', '北中', 'キタナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県所沢市岩岡町', '11', '11208', '3591102', '埼玉県', 'サイタマケン', '所沢市', 'トコロザワシ', '岩岡町', 'イワオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県所沢市向陽町', '11', '11208', '3591103', '埼玉県', 'サイタマケン', '所沢市', 'トコロザワシ', '向陽町', 'コウヨウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県所沢市榎町', '11', '11208', '3591104', '埼玉県', 'サイタマケン', '所沢市', 'トコロザワシ', '榎町', 'エノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県所沢市青葉台', '11', '11208', '3591105', '埼玉県', 'サイタマケン', '所沢市', 'トコロザワシ', '青葉台', 'アオバダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県所沢市東狭山ケ丘', '11', '11208', '3591106', '埼玉県', 'サイタマケン', '所沢市', 'トコロザワシ', '東狭山ケ丘', 'ヒガシサヤマガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県所沢市緑町', '11', '11208', '3591111', '埼玉県', 'サイタマケン', '所沢市', 'トコロザワシ', '緑町', 'ミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県所沢市泉町', '11', '11208', '3591112', '埼玉県', 'サイタマケン', '所沢市', 'トコロザワシ', '泉町', 'イズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県所沢市喜多町', '11', '11208', '3591113', '埼玉県', 'サイタマケン', '所沢市', 'トコロザワシ', '喜多町', 'キタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県所沢市北有楽町', '11', '11208', '3591114', '埼玉県', 'サイタマケン', '所沢市', 'トコロザワシ', '北有楽町', 'キタユウラクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県所沢市御幸町', '11', '11208', '3591115', '埼玉県', 'サイタマケン', '所沢市', 'トコロザワシ', '御幸町', 'ミユキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県所沢市東町', '11', '11208', '3591116', '埼玉県', 'サイタマケン', '所沢市', 'トコロザワシ', '東町', 'ヒガシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県所沢市有楽町', '11', '11208', '3591117', '埼玉県', 'サイタマケン', '所沢市', 'トコロザワシ', '有楽町', 'ユウラクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県所沢市けやき台', '11', '11208', '3591118', '埼玉県', 'サイタマケン', '所沢市', 'トコロザワシ', 'けやき台', 'ケヤキダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県所沢市元町', '11', '11208', '3591121', '埼玉県', 'サイタマケン', '所沢市', 'トコロザワシ', '元町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県所沢市寿町', '11', '11208', '3591122', '埼玉県', 'サイタマケン', '所沢市', 'トコロザワシ', '寿町', 'コトブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県所沢市日吉町', '11', '11208', '3591123', '埼玉県', 'サイタマケン', '所沢市', 'トコロザワシ', '日吉町', 'ヒヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県所沢市東住吉', '11', '11208', '3591124', '埼玉県', 'サイタマケン', '所沢市', 'トコロザワシ', '東住吉', 'ヒガシスミヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県所沢市南住吉', '11', '11208', '3591125', '埼玉県', 'サイタマケン', '所沢市', 'トコロザワシ', '南住吉', 'ミナミスミヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県所沢市西住吉', '11', '11208', '3591126', '埼玉県', 'サイタマケン', '所沢市', 'トコロザワシ', '西住吉', 'ニシスミヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県所沢市星の宮', '11', '11208', '3591127', '埼玉県', 'サイタマケン', '所沢市', 'トコロザワシ', '星の宮', 'ホシノミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県所沢市金山町', '11', '11208', '3591128', '埼玉県', 'サイタマケン', '所沢市', 'トコロザワシ', '金山町', 'カナヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県所沢市久米', '11', '11208', '3591131', '埼玉県', 'サイタマケン', '所沢市', 'トコロザワシ', '久米', 'クメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県所沢市松が丘', '11', '11208', '3591132', '埼玉県', 'サイタマケン', '所沢市', 'トコロザワシ', '松が丘', 'マツガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県所沢市荒幡', '11', '11208', '3591133', '埼玉県', 'サイタマケン', '所沢市', 'トコロザワシ', '荒幡', 'アラハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県所沢市小手指町', '11', '11208', '3591141', '埼玉県', 'サイタマケン', '所沢市', 'トコロザワシ', '小手指町', 'コテサシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県所沢市上新井', '11', '11208', '3591142', '埼玉県', 'サイタマケン', '所沢市', 'トコロザワシ', '上新井', 'カミアライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県所沢市宮本町', '11', '11208', '3591143', '埼玉県', 'サイタマケン', '所沢市', 'トコロザワシ', '宮本町', 'ミヤモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県所沢市西所沢', '11', '11208', '3591144', '埼玉県', 'サイタマケン', '所沢市', 'トコロザワシ', '西所沢', 'ニシトコロザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県所沢市山口', '11', '11208', '3591145', '埼玉県', 'サイタマケン', '所沢市', 'トコロザワシ', '山口', 'ヤマグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県所沢市小手指南', '11', '11208', '3591146', '埼玉県', 'サイタマケン', '所沢市', 'トコロザワシ', '小手指南', 'コテサシミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県所沢市小手指元町', '11', '11208', '3591147', '埼玉県', 'サイタマケン', '所沢市', 'トコロザワシ', '小手指元町', 'コテサシモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県所沢市若狭', '11', '11208', '3591151', '埼玉県', 'サイタマケン', '所沢市', 'トコロザワシ', '若狭', 'ワカサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県所沢市北野', '11', '11208', '3591152', '埼玉県', 'サイタマケン', '所沢市', 'トコロザワシ', '北野', 'キタノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県所沢市上山口', '11', '11208', '3591153', '埼玉県', 'サイタマケン', '所沢市', 'トコロザワシ', '上山口', 'カミヤマグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県所沢市勝楽寺', '11', '11208', '3591154', '埼玉県', 'サイタマケン', '所沢市', 'トコロザワシ', '勝楽寺', 'ショウラクジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県所沢市北野新町', '11', '11208', '3591155', '埼玉県', 'サイタマケン', '所沢市', 'トコロザワシ', '北野新町', 'キタノシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県所沢市北野南', '11', '11208', '3591156', '埼玉県', 'サイタマケン', '所沢市', 'トコロザワシ', '北野南', 'キタノミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県所沢市狭山ケ丘', '11', '11208', '3591161', '埼玉県', 'サイタマケン', '所沢市', 'トコロザワシ', '狭山ケ丘', 'サヤマガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県所沢市和ケ原', '11', '11208', '3591162', '埼玉県', 'サイタマケン', '所沢市', 'トコロザワシ', '和ケ原', 'ワガハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県所沢市西狭山ケ丘', '11', '11208', '3591163', '埼玉県', 'サイタマケン', '所沢市', 'トコロザワシ', '西狭山ケ丘', 'ニシサヤマガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県所沢市三ケ島', '11', '11208', '3591164', '埼玉県', 'サイタマケン', '所沢市', 'トコロザワシ', '三ケ島', 'ミカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県所沢市堀之内', '11', '11208', '3591165', '埼玉県', 'サイタマケン', '所沢市', 'トコロザワシ', '堀之内', 'ホリノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県所沢市糀谷', '11', '11208', '3591166', '埼玉県', 'サイタマケン', '所沢市', 'トコロザワシ', '糀谷', 'コウジヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県所沢市林', '11', '11208', '3591167', '埼玉県', 'サイタマケン', '所沢市', 'トコロザワシ', '林', 'ハヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市', '02', '02202', '0360000', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('28535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市', '11', '11202', '3600000', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('28536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市上中条', '11', '11202', '3600001', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '上中条', 'カミチュウジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市大塚', '11', '11202', '3600002', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '大塚', 'オオツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市下川上', '11', '11202', '3600003', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '下川上', 'シモカワカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市上川上', '11', '11202', '3600004', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '上川上', 'カミカワカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市今井', '11', '11202', '3600005', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '今井', 'イマイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市四方寺', '11', '11202', '3600006', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '四方寺', 'シホウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市池上', '11', '11202', '3600011', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '池上', 'イケガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市上之', '11', '11202', '3600012', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '上之', 'カミノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市中西', '11', '11202', '3600013', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '中西', 'ナカニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市箱田', '11', '11202', '3600014', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '箱田', 'ハコダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市肥塚', '11', '11202', '3600015', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '肥塚', 'コイヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市熊谷', '11', '11202', '3600016', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '熊谷', 'クマガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市小曽根', '11', '11202', '3600017', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '小曽根', 'オゾネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市中央', '11', '11202', '3600018', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市平戸', '11', '11202', '3600021', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '平戸', 'ヒラト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市戸出', '11', '11202', '3600022', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '戸出', 'トデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市佐谷田', '11', '11202', '3600023', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '佐谷田', 'サヤダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市問屋町', '11', '11202', '3600024', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '問屋町', 'トンヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市太井', '11', '11202', '3600025', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '太井', 'オオイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市久下', '11', '11202', '3600026', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '久下', 'クゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市新川', '11', '11202', '3600027', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '新川', 'シンカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市末広', '11', '11202', '3600031', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '末広', 'スエヒロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市銀座', '11', '11202', '3600032', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '銀座', 'ギンザ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市曙町', '11', '11202', '3600033', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '曙町', 'アケボノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市万平町', '11', '11202', '3600034', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '万平町', 'マンペイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市河原町', '11', '11202', '3600035', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '河原町', 'カワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市桜木町', '11', '11202', '3600036', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '桜木町', 'サクラギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市筑波', '11', '11202', '3600037', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '筑波', 'ツクバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市宮町', '11', '11202', '3600041', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '宮町', 'ミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市本町', '11', '11202', '3600042', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市星川', '11', '11202', '3600043', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '星川', 'ホシカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市弥生', '11', '11202', '3600044', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '弥生', 'ヤヨイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市宮前町', '11', '11202', '3600045', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '宮前町', 'ミヤマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市鎌倉町', '11', '11202', '3600046', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '鎌倉町', 'カマクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市仲町', '11', '11202', '3600047', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '仲町', 'ナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市野原', '11', '11202', '3600101', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '野原', 'ノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市須賀広', '11', '11202', '3600102', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '須賀広', 'スガヒロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市小江川', '11', '11202', '3600103', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '小江川', 'オエガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市塩', '11', '11202', '3600104', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '塩', 'シオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市板井', '11', '11202', '3600105', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '板井', 'イタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市柴', '11', '11202', '3600106', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '柴', 'シバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市千代', '11', '11202', '3600107', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '千代', 'センダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市押切', '11', '11202', '3600111', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '押切', 'オシキリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市樋春', '11', '11202', '3600112', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '樋春', 'ヒハル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市御正新田', '11', '11202', '3600113', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '御正新田', 'ミショウシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市江南中央', '11', '11202', '3600114', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '江南中央', 'コウナンチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市成沢', '11', '11202', '3600115', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '成沢', 'ナリサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市三本', '11', '11202', '3600116', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '三本', 'ミツモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市上新田', '11', '11202', '3600117', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '上新田', 'カミシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市手島', '11', '11202', '3600121', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '手島', 'テシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市小泉', '11', '11202', '3600122', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '小泉', 'コイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市下恩田', '11', '11202', '3600123', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '下恩田', 'シモオンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市中恩田', '11', '11202', '3600124', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '中恩田', 'ナカオンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市上恩田', '11', '11202', '3600125', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '上恩田', 'カミオンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市屈戸', '11', '11202', '3600131', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '屈戸', 'クット', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市津田新田', '11', '11202', '3600132', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '津田新田', 'ツダシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市中曽根', '11', '11202', '3600133', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '中曽根', 'ナカゾネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市高本', '11', '11202', '3600134', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '高本', 'タカモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市沼黒', '11', '11202', '3600135', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '沼黒', 'ヌマグロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市吉所敷', '11', '11202', '3600136', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '吉所敷', 'キショシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市万吉', '11', '11202', '3600161', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '万吉', 'マゲチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市村岡', '11', '11202', '3600162', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '村岡', 'ムラオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市平塚新田', '11', '11202', '3600163', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '平塚新田', 'ヒラツカシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市楊井', '11', '11202', '3600164', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '楊井', 'ヤギイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市妻沼', '11', '11202', '3600201', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '妻沼', 'メヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市妻沼東', '11', '11202', '3600202', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '妻沼東', 'メヌマヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市弥藤吾', '11', '11202', '3600203', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '弥藤吾', 'ヤトウゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市妻沼中央', '11', '11202', '3600204', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '妻沼中央', 'メヌマチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市善ケ島', '11', '11202', '3600211', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '善ケ島', 'ゼンガシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市江波', '11', '11202', '3600212', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '江波', 'エナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市上須戸', '11', '11202', '3600213', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '上須戸', 'カミスド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市西城', '11', '11202', '3600214', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '西城', 'ニシジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市田島', '11', '11202', '3600215', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '田島', 'タジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市西野', '11', '11202', '3600216', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '西野', 'ニシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市上根', '11', '11202', '3600217', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '上根', 'カミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市八ツ口', '11', '11202', '3600218', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '八ツ口', 'ヤツクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市大野', '11', '11202', '3600221', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '大野', 'オオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市葛和田', '11', '11202', '3600222', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '葛和田', 'クズワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市俵瀬', '11', '11202', '3600223', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '俵瀬', 'タワラセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市日向', '11', '11202', '3600224', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '日向', 'ヒナタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市弁財', '11', '11202', '3600225', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '弁財', 'ベンザイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市飯塚', '11', '11202', '3600231', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '飯塚', 'イイヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市道ケ谷戸', '11', '11202', '3600232', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '道ケ谷戸', 'ドウガヤト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市八木田', '11', '11202', '3600233', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '八木田', 'ヤギタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市上江袋', '11', '11202', '3600234', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '上江袋', 'カミエブクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市原井', '11', '11202', '3600235', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '原井', 'バライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市市ノ坪', '11', '11202', '3600236', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '市ノ坪', 'イチノツボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市永井太田', '11', '11202', '3600237', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '永井太田', 'ナガイオオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市妻沼西', '11', '11202', '3600238', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '妻沼西', 'メヌマニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市妻沼台', '11', '11202', '3600241', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '妻沼台', 'メヌマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市男沼', '11', '11202', '3600242', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '男沼', 'オヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市間々田', '11', '11202', '3600243', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '間々田', 'ママダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市出来島', '11', '11202', '3600244', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '出来島', 'デキジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市妻沼小島', '11', '11202', '3600245', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '妻沼小島', 'メヌマコジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市中奈良', '11', '11202', '3600801', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '中奈良', 'ナカナラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市下奈良', '11', '11202', '3600802', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '下奈良', 'シモナラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市柿沼', '11', '11202', '3600803', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '柿沼', 'カキヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市代', '11', '11202', '3600804', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '代', 'ダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市上奈良', '11', '11202', '3600805', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '上奈良', 'カミナラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市奈良新田', '11', '11202', '3600806', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '奈良新田', 'ナラシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市原島', '11', '11202', '3600811', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '原島', 'ハラジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市大原', '11', '11202', '3600812', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '大原', 'オオハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市円光', '11', '11202', '3600813', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '円光', 'エンコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市桜町', '11', '11202', '3600814', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '桜町', 'サクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市本石', '11', '11202', '3600815', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '本石', 'ホンゴク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市石原', '11', '11202', '3600816', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '石原', 'イシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市新島', '11', '11202', '3600817', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '新島', 'ニイジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市伊勢町', '11', '11202', '3600821', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '伊勢町', 'イセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市宮本町', '11', '11202', '3600822', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '宮本町', 'ミヤモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市榎町', '11', '11202', '3600823', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '榎町', 'エノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市見晴町', '11', '11202', '3600824', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '見晴町', 'ミハラシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市月見町', '11', '11202', '3600825', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '月見町', 'ツキミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市赤城町', '11', '11202', '3600826', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '赤城町', 'アカギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市久保島', '11', '11202', '3600831', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '久保島', 'クボジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市小島', '11', '11202', '3600832', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '小島', 'コジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市広瀬', '11', '11202', '3600833', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '広瀬', 'ヒロセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市瀬南', '11', '11202', '3600834', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '瀬南', 'セナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市大麻生', '11', '11202', '3600835', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '大麻生', 'オオアソウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市武体', '11', '11202', '3600836', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '武体', 'ブタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市川原明戸', '11', '11202', '3600837', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '川原明戸', 'カワハラアケト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市新堀', '11', '11202', '3600841', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '新堀', 'ニイボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市新堀新田', '11', '11202', '3600842', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '新堀新田', 'ニイボリシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市三ケ尻', '11', '11202', '3600843', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '三ケ尻', 'ミカジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市御稜威ケ原', '11', '11202', '3600844', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '御稜威ケ原', 'ミイズガハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市美土里町', '11', '11202', '3600845', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '美土里町', 'ミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市拾六間', '11', '11202', '3600846', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '拾六間', 'ジュウロッケン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市籠原南', '11', '11202', '3600847', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '籠原南', 'カゴハラミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市下増田', '11', '11202', '3600851', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '下増田', 'シモマスダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市東別府', '11', '11202', '3600852', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '東別府', 'ヒガシベップ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市玉井', '11', '11202', '3600853', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '玉井', 'タマイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市玉井南', '11', '11202', '3600854', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '玉井南', 'タマイミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市高柳', '11', '11202', '3600855', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '高柳', 'タカヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市別府', '11', '11202', '3600856', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '別府', 'ベップ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市西別府', '11', '11202', '3600857', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '西別府', 'ニシベップ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市', '02', '02210', '0360100', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('28676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市大光寺一滝本', '02', '02210', '0360101', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '大光寺一滝本', 'ダイコウジイチタキモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市大光寺一村井', '02', '02210', '0360101', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '大光寺一村井', 'ダイコウジイチムライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市大光寺一早稲田', '02', '02210', '0360101', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '大光寺一早稲田', 'ダイコウジイチワセダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市大光寺稲田', '02', '02210', '0360101', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '大光寺稲田', 'ダイコウジイナダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市大光寺稲村', '02', '02210', '0360101', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '大光寺稲村', 'ダイコウジイナムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市大光寺川原田', '02', '02210', '0360101', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '大光寺川原田', 'ダイコウジカワラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市大光寺三滝本', '02', '02210', '0360101', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '大光寺三滝本', 'ダイコウジサンタキモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市大光寺三村井', '02', '02210', '0360101', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '大光寺三村井', 'ダイコウジサンムライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市大光寺三早稲田', '02', '02210', '0360101', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '大光寺三早稲田', 'ダイコウジサンワセダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市大光寺釈迦口', '02', '02210', '0360101', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '大光寺釈迦口', 'ダイコウジシャカグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市大光寺白山', '02', '02210', '0360101', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '大光寺白山', 'ダイコウジシロヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市大光寺種元', '02', '02210', '0360101', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '大光寺種元', 'ダイコウジタネモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市大光寺西稲村', '02', '02210', '0360101', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '大光寺西稲村', 'ダイコウジニシイナムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市大光寺二滝本', '02', '02210', '0360101', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '大光寺二滝本', 'ダイコウジニタキモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市大光寺二村井', '02', '02210', '0360101', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '大光寺二村井', 'ダイコウジニムライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市大光寺二早稲田', '02', '02210', '0360101', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '大光寺二早稲田', 'ダイコウジニワセダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市大光寺四滝本', '02', '02210', '0360101', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '大光寺四滝本', 'ダイコウジヨンタキモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市光城', '02', '02210', '0360102', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '光城', 'コウジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市本町北柳田', '02', '02210', '0360103', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '本町北柳田', 'モトマチキタヤナギダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市本町富岡', '02', '02210', '0360103', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '本町富岡', 'モトマチトミオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市本町西宮', '02', '02210', '0360103', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '本町西宮', 'モトマチニシノミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市本町平野', '02', '02210', '0360103', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '本町平野', 'モトマチヒラノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市本町南柳田', '02', '02210', '0360103', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '本町南柳田', 'モトマチミナミヤナギダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市本町村元', '02', '02210', '0360103', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '本町村元', 'モトマチムラモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市柏木町東田', '02', '02210', '0360104', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '柏木町東田', 'カシワギマチヒガシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市柏木町広田', '02', '02210', '0360104', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '柏木町広田', 'カシワギマチヒロダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市柏木町藤山', '02', '02210', '0360104', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '柏木町藤山', 'カシワギマチフジヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市柏木町柳田', '02', '02210', '0360104', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '柏木町柳田', 'カシワギマチヤナギダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市小和森上田川', '02', '02210', '0360111', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '小和森上田川', 'コワモリカミタガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市小和森上平田', '02', '02210', '0360111', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '小和森上平田', 'コワモリカミヒラタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市小和森上松岡', '02', '02210', '0360111', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '小和森上松岡', 'コワモリカミマツオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市小和森下田川', '02', '02210', '0360111', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '小和森下田川', 'コワモリシモタガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市小和森下平田', '02', '02210', '0360111', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '小和森下平田', 'コワモリシモヒラタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市小和森下松岡', '02', '02210', '0360111', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '小和森下松岡', 'コワモリシモマツオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市小和森種取', '02', '02210', '0360111', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '小和森種取', 'コワモリタネトリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市小和森中松岡', '02', '02210', '0360111', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '小和森中松岡', 'コワモリナカマツオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市小和森福田', '02', '02210', '0360111', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '小和森福田', 'コワモリフクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市小和森松川', '02', '02210', '0360111', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '小和森松川', 'コワモリマツカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市小和森松村', '02', '02210', '0360111', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '小和森松村', 'コワモリマツムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市荒田上駒田', '02', '02210', '0360112', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '荒田上駒田', 'アラタカミコマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市荒田北稲村', '02', '02210', '0360112', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '荒田北稲村', 'アラタキタイナムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市荒田北岡部', '02', '02210', '0360112', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '荒田北岡部', 'アラタキタオカベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市荒田下駒田', '02', '02210', '0360112', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '荒田下駒田', 'アラタシモコマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市荒田南稲村', '02', '02210', '0360112', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '荒田南稲村', 'アラタミナミイナムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市荒田南岡部', '02', '02210', '0360112', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '荒田南岡部', 'アラタミナミオカベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市平田森稲村', '02', '02210', '0360113', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '平田森稲村', 'ヒラタモリイナムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市平田森上宮本', '02', '02210', '0360113', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '平田森上宮本', 'ヒラタモリカミミヤモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市平田森下宮本', '02', '02210', '0360113', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '平田森下宮本', 'ヒラタモリシモミヤモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市平田森前田', '02', '02210', '0360113', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '平田森前田', 'ヒラタモリマエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市平田森若松', '02', '02210', '0360113', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '平田森若松', 'ヒラタモリワカマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市町居稲村', '02', '02210', '0360114', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '町居稲村', 'マチイイナムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市町居稲元', '02', '02210', '0360114', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '町居稲元', 'マチイイナモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市町居西田', '02', '02210', '0360114', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '町居西田', 'マチイニシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市町居南田', '02', '02210', '0360114', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '町居南田', 'マチイミナミタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市町居山下', '02', '02210', '0360114', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '町居山下', 'マチイヤマシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市町居山元', '02', '02210', '0360114', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '町居山元', 'マチイヤマモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市町居横山', '02', '02210', '0360114', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '町居横山', 'マチイヨコヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市新館後野', '02', '02210', '0360115', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '新館後野', 'ニイダテウシロノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市新館柏崎', '02', '02210', '0360115', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '新館柏崎', 'ニイダテカシワザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市新館駒泊', '02', '02210', '0360115', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '新館駒泊', 'ニイダテコマドマリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市新館島村', '02', '02210', '0360115', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '新館島村', 'ニイダテシマムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市新館野木和', '02', '02210', '0360115', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '新館野木和', 'ニイダテノギワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市新館東山', '02', '02210', '0360115', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '新館東山', 'ニイダテヒガシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市新館藤巻', '02', '02210', '0360115', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '新館藤巻', 'ニイダテフジマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市新館藤山', '02', '02210', '0360115', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '新館藤山', 'ニイダテフジヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市新屋稲村', '02', '02210', '0360121', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '新屋稲村', 'アラヤイナムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市新屋長田', '02', '02210', '0360121', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '新屋長田', 'アラヤオサダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市新屋栄館', '02', '02210', '0360121', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '新屋栄館', 'アラヤサカエダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市新屋滝の沢', '02', '02210', '0360121', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '新屋滝の沢', 'アラヤタキノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市新屋富山', '02', '02210', '0360121', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '新屋富山', 'アラヤトミヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市新屋平岡', '02', '02210', '0360121', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '新屋平岡', 'アラヤヒラオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市新屋平野', '02', '02210', '0360121', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '新屋平野', 'アラヤヒラノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市新屋福嶋', '02', '02210', '0360121', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '新屋福嶋', 'アラヤフクシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市新屋山下', '02', '02210', '0360121', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '新屋山下', 'アラヤヤマシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市尾崎浅井', '02', '02210', '0360122', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '尾崎浅井', 'オサキアサイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市尾崎稲元', '02', '02210', '0360122', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '尾崎稲元', 'オサキイナモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市尾崎岡田', '02', '02210', '0360122', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '尾崎岡田', 'オサキオカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市尾崎川合', '02', '02210', '0360122', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '尾崎川合', 'オサキカワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市尾崎木戸口', '02', '02210', '0360122', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '尾崎木戸口', 'オサキキドグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市尾崎里見', '02', '02210', '0360122', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '尾崎里見', 'オサキサトミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市尾崎沢部', '02', '02210', '0360122', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '尾崎沢部', 'オサキサワベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市尾崎平山', '02', '02210', '0360122', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '尾崎平山', 'オサキヒラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市尾崎安田', '02', '02210', '0360122', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '尾崎安田', 'オサキヤスタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市広船広沢', '02', '02210', '0360131', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '広船広沢', 'ヒロフネヒロサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市広船福田', '02', '02210', '0360131', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '広船福田', 'ヒロフネフクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市広船山下', '02', '02210', '0360131', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '広船山下', 'ヒロフネヤマシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市唐竹芦毛沢', '02', '02210', '0360132', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '唐竹芦毛沢', 'カラタケアシゲサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市唐竹阿蘇獄', '02', '02210', '0360132', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '唐竹阿蘇獄', 'カラタケアソダケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市唐竹井沢', '02', '02210', '0360132', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '唐竹井沢', 'カラタケイザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市唐竹苺原', '02', '02210', '0360132', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '唐竹苺原', 'カラタケイチゴハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市唐竹川原田', '02', '02210', '0360132', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '唐竹川原田', 'カラタケカワラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市唐竹小金森', '02', '02210', '0360132', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '唐竹小金森', 'カラタケコガネモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市唐竹小松原', '02', '02210', '0360132', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '唐竹小松原', 'カラタケコマツハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市唐竹高田', '02', '02210', '0360132', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '唐竹高田', 'カラタケタカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市唐竹平山', '02', '02210', '0360132', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '唐竹平山', 'カラタケヒラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市唐竹堀合', '02', '02210', '0360132', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '唐竹堀合', 'カラタケホリアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市唐竹水上', '02', '02210', '0360132', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '唐竹水上', 'カラタケミズカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市唐竹向川原田', '02', '02210', '0360132', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '唐竹向川原田', 'カラタケムカイカワラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市唐竹薬師沢', '02', '02210', '0360132', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '唐竹薬師沢', 'カラタケヤクシザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市沖館長田', '02', '02210', '0360141', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '沖館長田', 'オキダテオサダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市沖館沢田', '02', '02210', '0360141', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '沖館沢田', 'オキダテサワタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市沖館高田', '02', '02210', '0360141', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '沖館高田', 'オキダテタカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市沖館永田', '02', '02210', '0360141', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '沖館永田', 'オキダテナガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市沖館西田', '02', '02210', '0360141', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '沖館西田', 'オキダテニシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市沖館比山館', '02', '02210', '0360141', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '沖館比山館', 'オキダテヒヤマダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市沖館宮崎', '02', '02210', '0360141', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '沖館宮崎', 'オキダテミヤザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市沖館向野', '02', '02210', '0360141', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '沖館向野', 'オキダテムカイノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市沖館和田', '02', '02210', '0360141', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '沖館和田', 'オキダテワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市高畑熊沢', '02', '02210', '0360142', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '高畑熊沢', 'タカハタケクマザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市高畑高田', '02', '02210', '0360142', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '高畑高田', 'タカハタケタカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市高畑前田', '02', '02210', '0360142', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '高畑前田', 'タカハタケマエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市吹上高田', '02', '02210', '0360143', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '吹上高田', 'フキアゲタカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市吹上平岡', '02', '02210', '0360143', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '吹上平岡', 'フキアゲヒラオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市吹上安田', '02', '02210', '0360143', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '吹上安田', 'フキアゲヤスタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市原田稲元', '02', '02210', '0360144', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '原田稲元', 'ハラタイナモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市原田今井', '02', '02210', '0360144', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '原田今井', 'ハラタイマイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市原田沢田', '02', '02210', '0360144', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '原田沢田', 'ハラタサワタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市原田村元', '02', '02210', '0360144', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '原田村元', 'ハラタムラモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市岩館長田', '02', '02210', '0360145', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '岩館長田', 'イワダテオサダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市岩館下り松', '02', '02210', '0360145', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '岩館下り松', 'イワダテサガリマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市岩館藤巻', '02', '02210', '0360145', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '岩館藤巻', 'イワダテフジマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市岩館村元', '02', '02210', '0360145', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '岩館村元', 'イワダテムラモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市岩館山の井', '02', '02210', '0360145', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '岩館山の井', 'イワダテヤマノイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市大坊竹内', '02', '02210', '0360146', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '大坊竹内', 'ダイボウタケウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市大坊竹原', '02', '02210', '0360146', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '大坊竹原', 'ダイボウタケハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市大坊福田', '02', '02210', '0360146', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '大坊福田', 'ダイボウフクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市大坊前田', '02', '02210', '0360146', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '大坊前田', 'ダイボウマエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市石郷沖中', '02', '02210', '0360151', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '石郷沖中', 'イシゴウオキナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市石郷村元', '02', '02210', '0360151', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '石郷村元', 'イシゴウムラモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市石郷柳田', '02', '02210', '0360151', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '石郷柳田', 'イシゴウヤナギダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市石畑岡元', '02', '02210', '0360152', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '石畑岡元', 'イシハタケオカモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市小杉稲村', '02', '02210', '0360153', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '小杉稲村', 'コスギイナムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市小杉扇田', '02', '02210', '0360153', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '小杉扇田', 'コスギオウギダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市小杉川崎', '02', '02210', '0360153', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '小杉川崎', 'コスギカワサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市小杉竹内', '02', '02210', '0360153', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '小杉竹内', 'コスギタケウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市小杉西田', '02', '02210', '0360153', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '小杉西田', 'コスギニシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市四ツ屋亀田', '02', '02210', '0360154', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '四ツ屋亀田', 'ヨツヤカメタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市館田稲村', '02', '02210', '0360155', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '館田稲村', 'タチタイナムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市館田中前田', '02', '02210', '0360155', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '館田中前田', 'タチタナカマエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市館田西川原田', '02', '02210', '0360155', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '館田西川原田', 'タチタニシカワラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市館田西和田', '02', '02210', '0360155', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '館田西和田', 'タチタニシワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市館田東稲村', '02', '02210', '0360155', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '館田東稲村', 'タチタヒガシイナムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市館田東前田', '02', '02210', '0360155', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '館田東前田', 'タチタヒガシマエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市館田東和田', '02', '02210', '0360155', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '館田東和田', 'タチタヒガシワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市館田前田', '02', '02210', '0360155', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '館田前田', 'タチタマエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市館田南川原田', '02', '02210', '0360155', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '館田南川原田', 'タチタミナミカワラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市館田元川原田', '02', '02210', '0360155', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '館田元川原田', 'タチタモトカワラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市館田柳原', '02', '02210', '0360155', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '館田柳原', 'タチタヤナギハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市杉館滝元', '02', '02210', '0360161', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '杉館滝元', 'スギダテタキモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市杉館松橋', '02', '02210', '0360161', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '杉館松橋', 'スギダテマツハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市杉館宮元', '02', '02210', '0360161', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '杉館宮元', 'スギダテミヤモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市館山板橋', '02', '02210', '0360162', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '館山板橋', 'タテヤマイタバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市館山上扇田', '02', '02210', '0360162', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '館山上扇田', 'タテヤマカミオウギダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市館山上亀岡', '02', '02210', '0360162', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '館山上亀岡', 'タテヤマカミカメオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市館山川合', '02', '02210', '0360162', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '館山川合', 'タテヤマカワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市館山下扇田', '02', '02210', '0360162', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '館山下扇田', 'タテヤマシモオウギダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市館山下亀岡', '02', '02210', '0360162', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '館山下亀岡', 'タテヤマシモカメオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市館山前田', '02', '02210', '0360162', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '館山前田', 'タテヤママエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市苗生松一本柳', '02', '02210', '0360163', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '苗生松一本柳', 'ナンバイマツイッポンヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市苗生松上東田', '02', '02210', '0360163', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '苗生松上東田', 'ナンバイマツカミヒガシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市苗生松川崎', '02', '02210', '0360163', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '苗生松川崎', 'ナンバイマツカワサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市苗生松川原田', '02', '02210', '0360163', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '苗生松川原田', 'ナンバイマツカワラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市苗生松下東田', '02', '02210', '0360163', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '苗生松下東田', 'ナンバイマツシモヒガシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市苗生松元東田', '02', '02210', '0360163', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '苗生松元東田', 'ナンバイマツモトヒガシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市松崎亀井', '02', '02210', '0360164', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '松崎亀井', 'マツザキカメイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市松崎西田', '02', '02210', '0360164', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '松崎西田', 'マツザキニシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市松館浅井', '02', '02210', '0360165', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '松館浅井', 'マツダテアサイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市松館井ノ上', '02', '02210', '0360165', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '松館井ノ上', 'マツダテイノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市松館西稲村', '02', '02210', '0360165', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '松館西稲村', 'マツダテニシイナムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市松館西川原田', '02', '02210', '0360165', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '松館西川原田', 'マツダテニシカワラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市松館東稲村', '02', '02210', '0360165', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '松館東稲村', 'マツダテヒガシイナムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市松館東川原田', '02', '02210', '0360165', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '松館東川原田', 'マツダテヒガシカワラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市松館松元', '02', '02210', '0360165', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '松館松元', 'マツダテマツモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市小国浅瀬石山', '02', '02210', '0360171', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '小国浅瀬石山', 'オグニアセイシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市小国川辺', '02', '02210', '0360171', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '小国川辺', 'オグニカワベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市小国川原田', '02', '02210', '0360171', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '小国川原田', 'オグニカワラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市小国深沢', '02', '02210', '0360171', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '小国深沢', 'オグニフカサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市小国山下', '02', '02210', '0360171', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '小国山下', 'オグニヤマシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市葛川浅瀬石山', '02', '02210', '0360172', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '葛川浅瀬石山', 'クズカワアセイシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市葛川一本木平', '02', '02210', '0360172', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '葛川一本木平', 'クズカワイッポンギタイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市葛川大川添', '02', '02210', '0360172', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '葛川大川添', 'クズカワオオカワゾエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市葛川折戸', '02', '02210', '0360172', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '葛川折戸', 'クズカワオリト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市葛川上の平', '02', '02210', '0360172', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '葛川上の平', 'クズカワカミノタイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市葛川唐川平', '02', '02210', '0360172', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '葛川唐川平', 'クズカワカラカワタイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市葛川葛川沢', '02', '02210', '0360172', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '葛川葛川沢', 'クズカワクズカワサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市葛川葛川平', '02', '02210', '0360172', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '葛川葛川平', 'クズカワクズカワタイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市葛川葛川出口', '02', '02210', '0360172', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '葛川葛川出口', 'クズカワクズカワデグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市葛川毛無森', '02', '02210', '0360172', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '葛川毛無森', 'クズカワケナシモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市葛川砂子沢', '02', '02210', '0360172', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '葛川砂子沢', 'クズカワスナコザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市葛川田の沢口', '02', '02210', '0360172', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '葛川田の沢口', 'クズカワタノサワグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市葛川長小股', '02', '02210', '0360172', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '葛川長小股', 'クズカワナガコマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市葛川平六沢上', '02', '02210', '0360172', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '葛川平六沢上', 'クズカワヘイロクサワカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市葛川平六村下', '02', '02210', '0360172', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '葛川平六村下', 'クズカワヘイロクムラシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市葛川家岸', '02', '02210', '0360172', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '葛川家岸', 'クズカワヤギシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市切明浅瀬石山', '02', '02210', '0360173', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '切明浅瀬石山', 'キリアケアセイシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市切明上井戸', '02', '02210', '0360173', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '切明上井戸', 'キリアケカミイド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市切明誉田邸', '02', '02210', '0360173', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '切明誉田邸', 'キリアケコンタヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市切明坂本', '02', '02210', '0360173', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '切明坂本', 'キリアケサカモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市切明滝の森', '02', '02210', '0360173', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '切明滝の森', 'キリアケタキノモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市切明滝候沢', '02', '02210', '0360173', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '切明滝候沢', 'キリアケタッコウサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市切明津根川森', '02', '02210', '0360173', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '切明津根川森', 'キリアケツネカワモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市切明温川沢', '02', '02210', '0360173', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '切明温川沢', 'キリアケヌルカワサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市切明温川森', '02', '02210', '0360173', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '切明温川森', 'キリアケヌルカワモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市切明螢沢', '02', '02210', '0360173', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '切明螢沢', 'キリアケホタルサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市切明山下', '02', '02210', '0360173', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '切明山下', 'キリアケヤマシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市李平上安原', '02', '02210', '0360201', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '李平上安原', 'スモモダイカミヤスハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市李平上山崎', '02', '02210', '0360201', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '李平上山崎', 'スモモダイカミヤマザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市李平北豊田', '02', '02210', '0360201', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '李平北豊田', 'スモモダイキタトヨダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市李平下安原', '02', '02210', '0360201', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '李平下安原', 'スモモダイシモヤスハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市李平西豊田', '02', '02210', '0360201', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '李平西豊田', 'スモモダイニシトヨダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市李平西山崎', '02', '02210', '0360201', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '李平西山崎', 'スモモダイニシヤマザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市李平西和田', '02', '02210', '0360201', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '李平西和田', 'スモモダイニシワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市李平東豊田', '02', '02210', '0360201', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '李平東豊田', 'スモモダイヒガシトヨダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市李平東和田', '02', '02210', '0360201', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '李平東和田', 'スモモダイヒガシワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市李平南豊田', '02', '02210', '0360201', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '李平南豊田', 'スモモダイミナミトヨダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市金屋上松元', '02', '02210', '0360202', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '金屋上松元', 'カナヤカミマツモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市金屋上早稲田', '02', '02210', '0360202', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '金屋上早稲田', 'カナヤカミワセダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市金屋下松元', '02', '02210', '0360202', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '金屋下松元', 'カナヤシモマツモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市金屋下早稲田', '02', '02210', '0360202', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '金屋下早稲田', 'カナヤシモワセダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市金屋中松元', '02', '02210', '0360202', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '金屋中松元', 'カナヤナカマツモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市金屋中早稲田', '02', '02210', '0360202', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '金屋中早稲田', 'カナヤナカワセダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市金屋西松元', '02', '02210', '0360202', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '金屋西松元', 'カナヤニシマツモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市南田中北林元', '02', '02210', '0360203', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '南田中北林元', 'ミナミタナカキタハヤシモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市南田中北原', '02', '02210', '0360203', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '南田中北原', 'ミナミタナカキタハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市南田中北細田', '02', '02210', '0360203', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '南田中北細田', 'ミナミタナカキタホソダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市南田中北村井', '02', '02210', '0360203', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '南田中北村井', 'ミナミタナカキタムライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市南田中中村井', '02', '02210', '0360203', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '南田中中村井', 'ミナミタナカナカムライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市南田中西林元', '02', '02210', '0360203', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '南田中西林元', 'ミナミタナカニシハヤシモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市南田中西原', '02', '02210', '0360203', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '南田中西原', 'ミナミタナカニシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市南田中東林元', '02', '02210', '0360203', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '南田中東林元', 'ミナミタナカヒガシハヤシモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市南田中南林元', '02', '02210', '0360203', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '南田中南林元', 'ミナミタナカミナミハヤシモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市南田中村内', '02', '02210', '0360203', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '南田中村内', 'ミナミタナカムラウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市高木岡崎', '02', '02210', '0360211', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '高木岡崎', 'タカキオカザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市高木岡田', '02', '02210', '0360211', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '高木岡田', 'タカキオカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市高木岡部', '02', '02210', '0360211', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '高木岡部', 'タカキオカベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市高木豊岡', '02', '02210', '0360211', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '高木豊岡', 'タカキトヨオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市高木豊田', '02', '02210', '0360211', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '高木豊田', 'タカキトヨダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市高木原田', '02', '02210', '0360211', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '高木原田', 'タカキハラタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市高木原富', '02', '02210', '0360211', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '高木原富', 'タカキハラトミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市高木松元', '02', '02210', '0360211', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '高木松元', 'タカキマツモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市尾上栄松', '02', '02210', '0360212', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '尾上栄松', 'オノエサカエマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市新屋町上沢田', '02', '02210', '0360213', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '新屋町上沢田', 'アラヤマチカミサワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市新屋町北鶉野', '02', '02210', '0360213', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '新屋町北鶉野', 'アラヤマチキタウズラノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市新屋町下沢田', '02', '02210', '0360213', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '新屋町下沢田', 'アラヤマチシモサワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市新屋町田川', '02', '02210', '0360213', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '新屋町田川', 'アラヤマチタガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市新屋町松居', '02', '02210', '0360213', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '新屋町松居', 'アラヤマチマツイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市新屋町松下', '02', '02210', '0360213', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '新屋町松下', 'アラヤマチマツシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市新屋町松久', '02', '02210', '0360213', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '新屋町松久', 'アラヤマチマツヒサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市新屋町道ノ下', '02', '02210', '0360213', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '新屋町道ノ下', 'アラヤマチミチノシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市新屋町南鶉野', '02', '02210', '0360213', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '新屋町南鶉野', 'アラヤマチミナミウズラノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市新屋町村元', '02', '02210', '0360213', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '新屋町村元', 'アラヤマチムラモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市中佐渡石田', '02', '02210', '0360221', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '中佐渡石田', 'ナカサドイシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市中佐渡鎌田', '02', '02210', '0360221', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '中佐渡鎌田', 'ナカサドカマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市中佐渡前田', '02', '02210', '0360221', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '中佐渡前田', 'ナカサドマエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市中佐渡南田', '02', '02210', '0360221', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '中佐渡南田', 'ナカサドミナミダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市中佐渡村元', '02', '02210', '0360221', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '中佐渡村元', 'ナカサドムラモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市長田沼田', '02', '02210', '0360222', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '長田沼田', 'オサダヌマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市長田野田', '02', '02210', '0360222', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '長田野田', 'オサダノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市長田村下', '02', '02210', '0360222', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '長田村下', 'オサダムラシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市長田元村', '02', '02210', '0360222', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '長田元村', 'オサダモトムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市西野曽江川崎', '02', '02210', '0360223', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '西野曽江川崎', 'ニシノゾエカワサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市西野曽江橋元', '02', '02210', '0360223', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '西野曽江橋元', 'ニシノゾエハシモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市西野曽江広田', '02', '02210', '0360223', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '西野曽江広田', 'ニシノゾエヒロタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市新山岡部', '02', '02210', '0360231', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '新山岡部', 'ニヤマオカベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市新山松橋', '02', '02210', '0360231', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '新山松橋', 'ニヤママツハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市新山村元', '02', '02210', '0360231', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '新山村元', 'ニヤマムラモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市新山柳田', '02', '02210', '0360231', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '新山柳田', 'ニヤマヤナギダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市新山早稲田', '02', '02210', '0360231', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '新山早稲田', 'ニヤマワセダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市蒲田一本松', '02', '02210', '0360232', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '蒲田一本松', 'ガマタイッポンマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市蒲田玉田', '02', '02210', '0360232', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '蒲田玉田', 'ガマタタマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市蒲田豊田', '02', '02210', '0360232', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '蒲田豊田', 'ガマタトヨタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市蒲田豊富', '02', '02210', '0360232', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '蒲田豊富', 'ガマタトヨトミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市蒲田三原', '02', '02210', '0360232', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '蒲田三原', 'ガマタミハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市蒲田元宮', '02', '02210', '0360232', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '蒲田元宮', 'ガマタモトミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市日沼一本柳', '02', '02210', '0360233', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '日沼一本柳', 'ヒヌマイッポンヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市日沼河原田', '02', '02210', '0360233', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '日沼河原田', 'ヒヌマカワラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市日沼下川原', '02', '02210', '0360233', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '日沼下川原', 'ヒヌマシモカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市日沼下袋', '02', '02210', '0360233', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '日沼下袋', 'ヒヌマシモフクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市日沼李田', '02', '02210', '0360233', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '日沼李田', 'ヒヌマスモモダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市日沼高田', '02', '02210', '0360233', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '日沼高田', 'ヒヌマタカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市日沼塚越', '02', '02210', '0360233', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '日沼塚越', 'ヒヌマツカゴシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市日沼樋田', '02', '02210', '0360233', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '日沼樋田', 'ヒヌマトイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市日沼富田', '02', '02210', '0360233', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '日沼富田', 'ヒヌマトミタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市日沼富岳', '02', '02210', '0360233', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '日沼富岳', 'ヒヌマトミタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市八幡崎高野', '02', '02210', '0360241', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '八幡崎高野', 'ヤワタサキタカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市八幡崎高原', '02', '02210', '0360241', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '八幡崎高原', 'ヤワタサキタカハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市八幡崎本林', '02', '02210', '0360241', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '八幡崎本林', 'ヤワタサキホンバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市八幡崎松枝', '02', '02210', '0360241', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '八幡崎松枝', 'ヤワタサキマツエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市八幡崎松橋', '02', '02210', '0360241', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '八幡崎松橋', 'ヤワタサキマツハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市八幡崎宮田', '02', '02210', '0360241', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '八幡崎宮田', 'ヤワタサキミヤタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市八幡崎宮本', '02', '02210', '0360241', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '八幡崎宮本', 'ヤワタサキミヤモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市八幡崎本宮', '02', '02210', '0360241', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '八幡崎本宮', 'ヤワタサキモトミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市猿賀浅井', '02', '02210', '0360242', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '猿賀浅井', 'サルカアサイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市猿賀浅田', '02', '02210', '0360242', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '猿賀浅田', 'サルカアサダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市猿賀池上', '02', '02210', '0360242', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '猿賀池上', 'サルカイケガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市猿賀池田', '02', '02210', '0360242', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '猿賀池田', 'サルカイケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市猿賀石林', '02', '02210', '0360242', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '猿賀石林', 'サルカイシバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市猿賀上岡', '02', '02210', '0360242', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '猿賀上岡', 'サルカカミオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市猿賀上川', '02', '02210', '0360242', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '猿賀上川', 'サルカカミカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市猿賀下岡', '02', '02210', '0360242', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '猿賀下岡', 'サルカシモオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市猿賀下川', '02', '02210', '0360242', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '猿賀下川', 'サルカシモカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市猿賀下野', '02', '02210', '0360242', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '猿賀下野', 'サルカシモノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市猿賀遠林', '02', '02210', '0360242', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '猿賀遠林', 'サルカトオバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市猿賀富岡', '02', '02210', '0360242', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '猿賀富岡', 'サルカトミオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市猿賀平塚', '02', '02210', '0360242', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '猿賀平塚', 'サルカヒラツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市猿賀松枝', '02', '02210', '0360242', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '猿賀松枝', 'サルカマツエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市猿賀南田', '02', '02210', '0360242', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '猿賀南田', 'サルカミナミタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市猿賀南野', '02', '02210', '0360242', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '猿賀南野', 'サルカミナミノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市猿賀明堂', '02', '02210', '0360242', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '猿賀明堂', 'サルカミョウドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市猿賀安岡', '02', '02210', '0360242', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '猿賀安岡', 'サルカヤスオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市猿賀安田', '02', '02210', '0360242', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '猿賀安田', 'サルカヤスタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市原大野', '02', '02210', '0360243', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '原大野', 'ハラオオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市原上原', '02', '02210', '0360243', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '原上原', 'ハラカミハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市原北原', '02', '02210', '0360243', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '原北原', 'ハラキタハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市', '02', '02204', '0360300', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('28991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市一番町', '02', '02204', '0360301', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', '一番町', 'イチバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市油横丁', '02', '02204', '0360302', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', '油横丁', 'アブラヨコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市株梗木横丁', '02', '02204', '0360303', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', '株梗木横丁', 'グミノキヨコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市甲徳兵衛町', '02', '02204', '0360304', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', '甲徳兵衛町', 'コウトクベエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市乙徳兵衛町', '02', '02204', '0360305', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', '乙徳兵衛町', 'オツトクベエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市内町', '02', '02204', '0360306', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', '内町', 'ウチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市市ノ町', '02', '02204', '0360307', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', '市ノ町', 'イチノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市寺小路', '02', '02204', '0360308', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', '寺小路', 'テラコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('28999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市吉乃町', '02', '02204', '0360311', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', '吉乃町', 'ヨシノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市昭和町', '02', '02204', '0360312', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', '昭和町', 'ショウワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市松葉町', '02', '02204', '0360313', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', '松葉町', 'マツバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市道北町', '02', '02204', '0360314', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', '道北町', 'ミチキタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市寿町', '02', '02204', '0360315', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', '寿町', 'コトブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市ぐみの木', '02', '02204', '0360316', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', 'ぐみの木', 'グミノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市住吉町', '02', '02204', '0360317', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', '住吉町', 'スミヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市岩木町', '02', '02204', '0360318', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', '岩木町', 'イワキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市あけぼの町', '02', '02204', '0360321', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', 'あけぼの町', 'アケボノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市竹田町', '02', '02204', '0360322', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', '竹田町', 'タケダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市上十川', '02', '02204', '0360323', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', '上十川', 'カミトガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市東野添', '02', '02204', '0360324', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', '東野添', 'ヒガシノゾエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市青山', '02', '02204', '0360325', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', '青山', 'アオヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市野添町', '02', '02204', '0360326', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', '野添町', 'ノゾエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市八甲', '02', '02204', '0360331', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', '八甲', 'ハッコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市牡丹平', '02', '02204', '0360332', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', '牡丹平', 'ボタンダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市柵ノ木', '02', '02204', '0360333', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', '柵ノ木', 'サクノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市東新町', '02', '02204', '0360334', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', '東新町', 'ヒガシシンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市幸町', '02', '02204', '0360335', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市桜木町', '02', '02204', '0360336', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', '桜木町', 'サクラギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市角田', '02', '02204', '0360337', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', '角田', 'カクタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市春日町', '02', '02204', '0360338', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', '春日町', 'カスガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市美原町', '02', '02204', '0360339', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', '美原町', 'ミハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市豊岡', '02', '02204', '0360341', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', '豊岡', 'トヨオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市石名坂', '02', '02204', '0360342', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', '石名坂', 'イシナザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市浅瀬石', '02', '02204', '0360343', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', '浅瀬石', 'アセイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市高賀野', '02', '02204', '0360344', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', '高賀野', 'コガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市中川', '02', '02204', '0360345', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', '中川', 'ナカガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市黒石', '02', '02204', '0360351', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', '黒石', 'クロイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市甲大工町', '02', '02204', '0360352', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', '甲大工町', 'コウダイクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市乙大工町', '02', '02204', '0360353', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', '乙大工町', 'オツダイクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市後大工町', '02', '02204', '0360354', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', '後大工町', 'ウシロダイクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市袋井', '02', '02204', '0360355', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', '袋井', 'フクロイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市ちとせ', '02', '02204', '0360356', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', 'ちとせ', 'チトセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市追子野木', '02', '02204', '0360357', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', '追子野木', 'オッコノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市弥生町', '02', '02204', '0360361', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', '弥生町', 'ヤヨイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市京町', '02', '02204', '0360362', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', '京町', 'キョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市鍛治町', '02', '02204', '0360363', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', '鍛治町', 'カジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市山形町', '02', '02204', '0360364', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', '山形町', 'ヤマガタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市長崎', '02', '02204', '0360365', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', '長崎', 'ナガサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市浦町', '02', '02204', '0360366', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', '浦町', 'ウラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市前町', '02', '02204', '0360367', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', '前町', 'マエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市横町', '02', '02204', '0360368', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', '横町', 'ヨコマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市花園町', '02', '02204', '0360371', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', '花園町', 'ハナゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市錦町', '02', '02204', '0360372', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', '錦町', 'ニシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市東町', '02', '02204', '0360373', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', '東町', 'アズマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市泉町', '02', '02204', '0360374', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', '泉町', 'イズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市若葉町', '02', '02204', '0360375', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', '若葉町', 'ワカバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市旭町', '02', '02204', '0360376', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', '旭町', 'アサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市中町', '02', '02204', '0360377', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', '中町', 'ナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市浜町', '02', '02204', '0360378', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', '浜町', 'ハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市株梗木', '02', '02204', '0360381', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', '株梗木', 'グミノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市作場町', '02', '02204', '0360382', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', '作場町', 'サクバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市緑町', '02', '02204', '0360383', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', '緑町', 'ミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市大町', '02', '02204', '0360384', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', '大町', 'オオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市大板町', '02', '02204', '0360385', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', '大板町', 'オオイタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市上町', '02', '02204', '0360386', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', '上町', 'カンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市元町', '02', '02204', '0360387', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', '元町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市西ケ丘', '02', '02204', '0360388', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', '西ケ丘', 'ニシガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市境松', '02', '02204', '0360389', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', '境松', 'サカイマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市大川原', '02', '02204', '0360401', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', '大川原', 'オオカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市沖浦', '02', '02204', '0360402', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', '沖浦', 'オキウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市二庄内', '02', '02204', '0360403', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', '二庄内', 'ニショウナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市板留', '02', '02204', '0360404', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', '板留', 'イタドメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市南中野', '02', '02204', '0360405', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', '南中野', 'ミナミナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市温湯', '02', '02204', '0360411', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', '温湯', 'ヌルユ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市袋', '02', '02204', '0360412', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', '袋', 'フクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市花巻', '02', '02204', '0360413', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', '花巻', 'ハナマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市下山形', '02', '02204', '0360414', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', '下山形', 'シモヤマガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市上山形', '02', '02204', '0360415', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', '上山形', 'カミヤマガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市東馬場尻', '02', '02204', '0360501', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', '東馬場尻', 'ヒガシババシリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市馬場尻北', '02', '02204', '0360502', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', '馬場尻北', 'ババシリキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市馬場尻下', '02', '02204', '0360503', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', '馬場尻下', 'ババシリシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市馬場尻東', '02', '02204', '0360504', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', '馬場尻東', 'ババシリヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市馬場尻南', '02', '02204', '0360505', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', '馬場尻南', 'ババシリミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市馬場尻西', '02', '02204', '0360506', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', '馬場尻西', 'ババシリニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市西馬場尻', '02', '02204', '0360507', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', '西馬場尻', 'ニシババシリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市小屋敷', '02', '02204', '0360511', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', '小屋敷', 'コヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市小屋敷南', '02', '02204', '0360512', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', '小屋敷南', 'コヤシキミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市小屋敷西', '02', '02204', '0360513', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', '小屋敷西', 'コヤシキニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市富田', '02', '02204', '0360514', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', '富田', 'トミタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市富士見', '02', '02204', '0360515', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', '富士見', 'フジミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市相野', '02', '02204', '0360516', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', '相野', 'アイノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市松原', '02', '02204', '0360517', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', '松原', 'マツバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市末広', '02', '02204', '0360521', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', '末広', 'スエヒロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市田中', '02', '02204', '0360522', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', '田中', 'タナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市北田中', '02', '02204', '0360523', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', '北田中', 'キタタナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市緑ケ丘', '02', '02204', '0360524', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', '緑ケ丘', 'ミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市飛内', '02', '02204', '0360531', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', '飛内', 'トビナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市飛内北', '02', '02204', '0360532', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', '飛内北', 'トビナイキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市二双子', '02', '02204', '0360533', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', '二双子', 'ニソウシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市竹鼻', '02', '02204', '0360534', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', '竹鼻', 'タケハナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市高舘', '02', '02204', '0360535', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', '高舘', 'タカダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市三島', '02', '02204', '0360536', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', '三島', 'ミシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市赤坂', '02', '02204', '0360537', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', '赤坂', 'アカサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市上目内澤', '02', '02204', '0360538', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', '上目内澤', 'カミメナイサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市下目内澤', '02', '02204', '0360539', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', '下目内澤', 'シモメナイサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市北美町', '02', '02204', '0360541', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', '北美町', 'キタミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県黒石市野際', '02', '02204', '0360542', '青森県', 'アオモリケン', '黒石市', 'クロイシシ', '野際', 'ノギワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県行田市', '11', '11206', '3610000', '埼玉県', 'サイタマケン', '行田市', 'ギョウダシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('29122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県行田市北河原', '11', '11206', '3610001', '埼玉県', 'サイタマケン', '行田市', 'ギョウダシ', '北河原', 'キタガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県行田市酒巻', '11', '11206', '3610002', '埼玉県', 'サイタマケン', '行田市', 'ギョウダシ', '酒巻', 'サカマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県行田市下中条', '11', '11206', '3610003', '埼玉県', 'サイタマケン', '行田市', 'ギョウダシ', '下中条', 'シモチュウジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県行田市須加', '11', '11206', '3610004', '埼玉県', 'サイタマケン', '行田市', 'ギョウダシ', '須加', 'スカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県行田市斎条', '11', '11206', '3610005', '埼玉県', 'サイタマケン', '行田市', 'ギョウダシ', '斎条', 'サイジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県行田市白川戸', '11', '11206', '3610006', '埼玉県', 'サイタマケン', '行田市', 'ギョウダシ', '白川戸', 'シラカワド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県行田市小見', '11', '11206', '3610007', '埼玉県', 'サイタマケン', '行田市', 'ギョウダシ', '小見', 'オミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県行田市荒木', '11', '11206', '3610011', '埼玉県', 'サイタマケン', '行田市', 'ギョウダシ', '荒木', 'アラキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県行田市下須戸', '11', '11206', '3610012', '埼玉県', 'サイタマケン', '行田市', 'ギョウダシ', '下須戸', 'シモスド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県行田市真名板', '11', '11206', '3610013', '埼玉県', 'サイタマケン', '行田市', 'ギョウダシ', '真名板', 'マナイタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県行田市藤間', '11', '11206', '3610014', '埼玉県', 'サイタマケン', '行田市', 'ギョウダシ', '藤間', 'トウマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県行田市関根', '11', '11206', '3610015', '埼玉県', 'サイタマケン', '行田市', 'ギョウダシ', '関根', 'セキネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県行田市藤原町', '11', '11206', '3610016', '埼玉県', 'サイタマケン', '行田市', 'ギョウダシ', '藤原町', 'フジワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県行田市若小玉', '11', '11206', '3610017', '埼玉県', 'サイタマケン', '行田市', 'ギョウダシ', '若小玉', 'ワカコダマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県行田市富士見町', '11', '11206', '3610021', '埼玉県', 'サイタマケン', '行田市', 'ギョウダシ', '富士見町', 'フジミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県行田市桜町', '11', '11206', '3610022', '埼玉県', 'サイタマケン', '行田市', 'ギョウダシ', '桜町', 'サクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県行田市長野', '11', '11206', '3610023', '埼玉県', 'サイタマケン', '行田市', 'ギョウダシ', '長野', 'ナガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県行田市小針', '11', '11206', '3610024', '埼玉県', 'サイタマケン', '行田市', 'ギョウダシ', '小針', 'コバリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県行田市埼玉', '11', '11206', '3610025', '埼玉県', 'サイタマケン', '行田市', 'ギョウダシ', '埼玉', 'サキタマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県行田市野', '11', '11206', '3610026', '埼玉県', 'サイタマケン', '行田市', 'ギョウダシ', '野', 'ノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県行田市緑町', '11', '11206', '3610031', '埼玉県', 'サイタマケン', '行田市', 'ギョウダシ', '緑町', 'ミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県行田市佐間', '11', '11206', '3610032', '埼玉県', 'サイタマケン', '行田市', 'ギョウダシ', '佐間', 'サマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県行田市渡柳', '11', '11206', '3610033', '埼玉県', 'サイタマケン', '行田市', 'ギョウダシ', '渡柳', 'ワタリヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県行田市利田', '11', '11206', '3610034', '埼玉県', 'サイタマケン', '行田市', 'ギョウダシ', '利田', 'カガダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県行田市堤根', '11', '11206', '3610035', '埼玉県', 'サイタマケン', '行田市', 'ギョウダシ', '堤根', 'ツツミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県行田市樋上', '11', '11206', '3610036', '埼玉県', 'サイタマケン', '行田市', 'ギョウダシ', '樋上', 'ヒノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県行田市下忍', '11', '11206', '3610037', '埼玉県', 'サイタマケン', '行田市', 'ギョウダシ', '下忍', 'シモオシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県行田市前谷', '11', '11206', '3610038', '埼玉県', 'サイタマケン', '行田市', 'ギョウダシ', '前谷', 'マエヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県行田市棚田町', '11', '11206', '3610041', '埼玉県', 'サイタマケン', '行田市', 'ギョウダシ', '棚田町', 'タナダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県行田市西新町', '11', '11206', '3610042', '埼玉県', 'サイタマケン', '行田市', 'ギョウダシ', '西新町', 'ニシシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県行田市深水町', '11', '11206', '3610043', '埼玉県', 'サイタマケン', '行田市', 'ギョウダシ', '深水町', 'フカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県行田市門井町', '11', '11206', '3610044', '埼玉県', 'サイタマケン', '行田市', 'ギョウダシ', '門井町', 'カドイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県行田市押上町', '11', '11206', '3610045', '埼玉県', 'サイタマケン', '行田市', 'ギョウダシ', '押上町', 'オシアゲチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県行田市壱里山町', '11', '11206', '3610046', '埼玉県', 'サイタマケン', '行田市', 'ギョウダシ', '壱里山町', 'イチリヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県行田市清水町', '11', '11206', '3610047', '埼玉県', 'サイタマケン', '行田市', 'ギョウダシ', '清水町', 'シミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県行田市矢場', '11', '11206', '3610051', '埼玉県', 'サイタマケン', '行田市', 'ギョウダシ', '矢場', 'ヤバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県行田市本丸', '11', '11206', '3610052', '埼玉県', 'サイタマケン', '行田市', 'ギョウダシ', '本丸', 'ホンマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県行田市水城公園', '11', '11206', '3610053', '埼玉県', 'サイタマケン', '行田市', 'ギョウダシ', '水城公園', 'スイジョウコウエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県行田市城南', '11', '11206', '3610054', '埼玉県', 'サイタマケン', '行田市', 'ギョウダシ', '城南', 'ジョウナン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県行田市駒形', '11', '11206', '3610055', '埼玉県', 'サイタマケン', '行田市', 'ギョウダシ', '駒形', 'コマガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県行田市持田', '11', '11206', '3610056', '埼玉県', 'サイタマケン', '行田市', 'ギョウダシ', '持田', 'モチダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県行田市城西', '11', '11206', '3610057', '埼玉県', 'サイタマケン', '行田市', 'ギョウダシ', '城西', 'ジョウサイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県行田市和田', '11', '11206', '3610061', '埼玉県', 'サイタマケン', '行田市', 'ギョウダシ', '和田', 'ワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県行田市谷郷', '11', '11206', '3610062', '埼玉県', 'サイタマケン', '行田市', 'ギョウダシ', '谷郷', 'ヤゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県行田市皿尾', '11', '11206', '3610063', '埼玉県', 'サイタマケン', '行田市', 'ギョウダシ', '皿尾', 'サラオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県行田市中里', '11', '11206', '3610064', '埼玉県', 'サイタマケン', '行田市', 'ギョウダシ', '中里', 'ナカザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県行田市小敷田', '11', '11206', '3610065', '埼玉県', 'サイタマケン', '行田市', 'ギョウダシ', '小敷田', 'コシキダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県行田市上池守', '11', '11206', '3610066', '埼玉県', 'サイタマケン', '行田市', 'ギョウダシ', '上池守', 'カミイケモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県行田市下池守', '11', '11206', '3610067', '埼玉県', 'サイタマケン', '行田市', 'ギョウダシ', '下池守', 'シモイケモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県行田市栄町', '11', '11206', '3610071', '埼玉県', 'サイタマケン', '行田市', 'ギョウダシ', '栄町', 'サカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県行田市宮本', '11', '11206', '3610072', '埼玉県', 'サイタマケン', '行田市', 'ギョウダシ', '宮本', 'ミヤモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県行田市行田', '11', '11206', '3610073', '埼玉県', 'サイタマケン', '行田市', 'ギョウダシ', '行田', 'ギョウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県行田市旭町', '11', '11206', '3610074', '埼玉県', 'サイタマケン', '行田市', 'ギョウダシ', '旭町', 'アサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県行田市向町', '11', '11206', '3610075', '埼玉県', 'サイタマケン', '行田市', 'ギョウダシ', '向町', 'ムカイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県行田市天満', '11', '11206', '3610076', '埼玉県', 'サイタマケン', '行田市', 'ギョウダシ', '天満', 'テンマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県行田市忍', '11', '11206', '3610077', '埼玉県', 'サイタマケン', '行田市', 'ギョウダシ', '忍', 'オシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県行田市中央', '11', '11206', '3610078', '埼玉県', 'サイタマケン', '行田市', 'ギョウダシ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県行田市犬塚', '11', '11206', '3610081', '埼玉県', 'サイタマケン', '行田市', 'ギョウダシ', '犬塚', 'イヌズカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県行田市馬見塚', '11', '11206', '3610082', '埼玉県', 'サイタマケン', '行田市', 'ギョウダシ', '馬見塚', 'マミヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県行田市中江袋', '11', '11206', '3610083', '埼玉県', 'サイタマケン', '行田市', 'ギョウダシ', '中江袋', 'ナカエブクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県行田市南河原', '11', '11206', '3610084', '埼玉県', 'サイタマケン', '行田市', 'ギョウダシ', '南河原', 'ミナミカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市十腰内', '02', '02202', '0361201', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '十腰内', 'トコシナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市十面沢', '02', '02202', '0361202', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '十面沢', 'トツラザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市大森', '02', '02202', '0361203', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '大森', 'オオモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市貝沢', '02', '02202', '0361204', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '貝沢', 'カイザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市鬼沢', '02', '02202', '0361205', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '鬼沢', 'オニザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市楢木', '02', '02202', '0361206', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '楢木', 'ナラノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市鼻和', '02', '02202', '0361301', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '鼻和', 'ハナワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市愛宕', '02', '02202', '0361302', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '愛宕', 'アタゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市葛原', '02', '02202', '0361303', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '葛原', 'クズハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市新岡', '02', '02202', '0361304', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '新岡', 'ニイオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市横町', '02', '02202', '0361311', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '横町', 'ヨコマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市高屋', '02', '02202', '0361312', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '高屋', 'タカヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市賀田', '02', '02202', '0361313', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '賀田', 'ヨシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市八幡', '02', '02202', '0361314', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '八幡', 'ヤワタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市熊嶋', '02', '02202', '0361321', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '熊嶋', 'クマジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市駒越', '02', '02202', '0361322', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '駒越', 'コマゴシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市真土', '02', '02202', '0361323', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '真土', 'マツチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市龍ノ口', '02', '02202', '0361324', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '龍ノ口', 'タツノクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市一町田', '02', '02202', '0361325', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '一町田', 'イッチョウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市五代', '02', '02202', '0361331', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '五代', 'ゴダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市兼平', '02', '02202', '0361332', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '兼平', 'カネヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市鳥井野', '02', '02202', '0361333', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '鳥井野', 'トリイノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市如来瀬', '02', '02202', '0361334', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '如来瀬', 'ニョライセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市宮地', '02', '02202', '0361341', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '宮地', 'ミヤジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市新法師', '02', '02202', '0361342', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '新法師', 'シンボウシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市百沢', '02', '02202', '0361343', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '百沢', 'ヒャクザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市高岡', '02', '02202', '0361344', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '高岡', 'タカオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市常盤野', '02', '02202', '0361345', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '常盤野', 'トキワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市弥生', '02', '02202', '0361361', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '弥生', 'ヤヨイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県中津軽郡西目屋村', '02', '02343', '0361400', '青森県', 'アオモリケン', '中津軽郡西目屋村', 'ナカツガルグンニシメヤムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('29214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県中津軽郡西目屋村田代', '02', '02343', '0361411', '青森県', 'アオモリケン', '中津軽郡西目屋村', 'ナカツガルグンニシメヤムラ', '田代', 'タシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県中津軽郡西目屋村杉ケ沢', '02', '02343', '0361412', '青森県', 'アオモリケン', '中津軽郡西目屋村', 'ナカツガルグンニシメヤムラ', '杉ケ沢', 'スギガサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県中津軽郡西目屋村大秋', '02', '02343', '0361413', '青森県', 'アオモリケン', '中津軽郡西目屋村', 'ナカツガルグンニシメヤムラ', '大秋', 'タイアキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県中津軽郡西目屋村白沢', '02', '02343', '0361414', '青森県', 'アオモリケン', '中津軽郡西目屋村', 'ナカツガルグンニシメヤムラ', '白沢', 'シラサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県中津軽郡西目屋村村市', '02', '02343', '0361415', '青森県', 'アオモリケン', '中津軽郡西目屋村', 'ナカツガルグンニシメヤムラ', '村市', 'ムライチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県中津軽郡西目屋村藤川', '02', '02343', '0361421', '青森県', 'アオモリケン', '中津軽郡西目屋村', 'ナカツガルグンニシメヤムラ', '藤川', 'フジカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県中津軽郡西目屋村居森平', '02', '02343', '0361422', '青森県', 'アオモリケン', '中津軽郡西目屋村', 'ナカツガルグンニシメヤムラ', '居森平', 'イモリタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県中津軽郡西目屋村砂子瀬', '02', '02343', '0361423', '青森県', 'アオモリケン', '中津軽郡西目屋村', 'ナカツガルグンニシメヤムラ', '砂子瀬', 'スナコセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県中津軽郡西目屋村川原平', '02', '02343', '0361424', '青森県', 'アオモリケン', '中津軽郡西目屋村', 'ナカツガルグンニシメヤムラ', '川原平', 'カワラタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市高野', '02', '02202', '0361431', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '高野', 'コウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市館後', '02', '02202', '0361432', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '館後', 'タテウシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市国吉', '02', '02202', '0361433', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '国吉', 'クニヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市黒土', '02', '02202', '0361434', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '黒土', 'クロツチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市吉川', '02', '02202', '0361435', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '吉川', 'ヨシカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市桜庭', '02', '02202', '0361441', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '桜庭', 'サクラバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市平山', '02', '02202', '0361442', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '平山', 'ヒラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市米ケ袋', '02', '02202', '0361443', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '米ケ袋', 'ヨネガフクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市中野', '02', '02202', '0361451', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '中野', 'ナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市中畑', '02', '02202', '0361452', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '中畑', 'ナカハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市番館', '02', '02202', '0361453', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '番館', 'バンダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市湯口', '02', '02202', '0361501', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '湯口', 'ユグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市黒滝', '02', '02202', '0361502', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '黒滝', 'クロタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市五所', '02', '02202', '0361503', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '五所', 'ゴショ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市紙漉沢', '02', '02202', '0361504', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '紙漉沢', 'カミスキサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市水木在家', '02', '02202', '0361505', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '水木在家', 'ミズキザイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市坂市', '02', '02202', '0361511', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '坂市', 'サカイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市藤沢', '02', '02202', '0361512', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '藤沢', 'フジサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市大助', '02', '02202', '0361513', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '大助', 'オオスケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市沢田', '02', '02202', '0361514', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '沢田', 'サワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市相馬', '02', '02202', '0361515', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '相馬', 'ソウマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市藍内', '02', '02202', '0361516', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '藍内', 'アイナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県上尾市', '11', '11219', '3620000', '埼玉県', 'サイタマケン', '上尾市', 'アゲオシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('29267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県上尾市上', '11', '11219', '3620001', '埼玉県', 'サイタマケン', '上尾市', 'アゲオシ', '上', 'カミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県上尾市南', '11', '11219', '3620002', '埼玉県', 'サイタマケン', '上尾市', 'アゲオシ', '南', 'ミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県上尾市菅谷', '11', '11219', '3620003', '埼玉県', 'サイタマケン', '上尾市', 'アゲオシ', '菅谷', 'スガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県上尾市須ケ谷', '11', '11219', '3620004', '埼玉県', 'サイタマケン', '上尾市', 'アゲオシ', '須ケ谷', 'スカヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県上尾市西門前', '11', '11219', '3620005', '埼玉県', 'サイタマケン', '上尾市', 'アゲオシ', '西門前', 'ニシモンゼン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県上尾市錦町', '11', '11219', '3620006', '埼玉県', 'サイタマケン', '上尾市', 'アゲオシ', '錦町', 'ニシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県上尾市久保', '11', '11219', '3620007', '埼玉県', 'サイタマケン', '上尾市', 'アゲオシ', '久保', 'クボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県上尾市平塚', '11', '11219', '3620011', '埼玉県', 'サイタマケン', '上尾市', 'アゲオシ', '平塚', 'ヒラツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県上尾市上尾宿', '11', '11219', '3620012', '埼玉県', 'サイタマケン', '上尾市', 'アゲオシ', '上尾宿', 'アゲオシュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県上尾市上尾村', '11', '11219', '3620013', '埼玉県', 'サイタマケン', '上尾市', 'アゲオシ', '上尾村', 'アゲオムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県上尾市本町', '11', '11219', '3620014', '埼玉県', 'サイタマケン', '上尾市', 'アゲオシ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県上尾市緑丘', '11', '11219', '3620015', '埼玉県', 'サイタマケン', '上尾市', 'アゲオシ', '緑丘', 'ミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県上尾市原新町', '11', '11219', '3620016', '埼玉県', 'サイタマケン', '上尾市', 'アゲオシ', '原新町', 'ハラシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県上尾市二ツ宮', '11', '11219', '3620017', '埼玉県', 'サイタマケン', '上尾市', 'アゲオシ', '二ツ宮', 'フタツミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県上尾市原市', '11', '11219', '3620021', '埼玉県', 'サイタマケン', '上尾市', 'アゲオシ', '原市', 'ハライチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県上尾市瓦葺', '11', '11219', '3620022', '埼玉県', 'サイタマケン', '上尾市', 'アゲオシ', '瓦葺', 'カワラブキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県上尾市原市中', '11', '11219', '3620023', '埼玉県', 'サイタマケン', '上尾市', 'アゲオシ', '原市中', 'ハライチナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県上尾市五番町', '11', '11219', '3620024', '埼玉県', 'サイタマケン', '上尾市', 'アゲオシ', '五番町', 'ゴバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県上尾市上尾下', '11', '11219', '3620025', '埼玉県', 'サイタマケン', '上尾市', 'アゲオシ', '上尾下', 'アゲオシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県上尾市東町', '11', '11219', '3620031', '埼玉県', 'サイタマケン', '上尾市', 'アゲオシ', '東町', 'アズマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県上尾市日の出', '11', '11219', '3620032', '埼玉県', 'サイタマケン', '上尾市', 'アゲオシ', '日の出', 'ヒノデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県上尾市栄町', '11', '11219', '3620033', '埼玉県', 'サイタマケン', '上尾市', 'アゲオシ', '栄町', 'サカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県上尾市愛宕', '11', '11219', '3620034', '埼玉県', 'サイタマケン', '上尾市', 'アゲオシ', '愛宕', 'アタゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県上尾市仲町', '11', '11219', '3620035', '埼玉県', 'サイタマケン', '上尾市', 'アゲオシ', '仲町', 'ナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県上尾市宮本町', '11', '11219', '3620036', '埼玉県', 'サイタマケン', '上尾市', 'アゲオシ', '宮本町', 'ミヤモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県上尾市上町', '11', '11219', '3620037', '埼玉県', 'サイタマケン', '上尾市', 'アゲオシ', '上町', 'カミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県上尾市富士見', '11', '11219', '3620041', '埼玉県', 'サイタマケン', '上尾市', 'アゲオシ', '富士見', 'フジミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県上尾市谷津', '11', '11219', '3620042', '埼玉県', 'サイタマケン', '上尾市', 'アゲオシ', '谷津', 'ヤツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県上尾市西宮下', '11', '11219', '3620043', '埼玉県', 'サイタマケン', '上尾市', 'アゲオシ', '西宮下', 'ニシミヤシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県上尾市大谷本郷', '11', '11219', '3620044', '埼玉県', 'サイタマケン', '上尾市', 'アゲオシ', '大谷本郷', 'オオヤホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県上尾市向山', '11', '11219', '3620045', '埼玉県', 'サイタマケン', '上尾市', 'アゲオシ', '向山', 'ムコウヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県上尾市壱丁目', '11', '11219', '3620046', '埼玉県', 'サイタマケン', '上尾市', 'アゲオシ', '壱丁目', 'イッチョウメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県上尾市今泉', '11', '11219', '3620047', '埼玉県', 'サイタマケン', '上尾市', 'アゲオシ', '今泉', 'イマイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県上尾市川', '11', '11219', '3620048', '埼玉県', 'サイタマケン', '上尾市', 'アゲオシ', '川', 'カワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県上尾市地頭方', '11', '11219', '3620051', '埼玉県', 'サイタマケン', '上尾市', 'アゲオシ', '地頭方', 'ジトウガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県上尾市中新井', '11', '11219', '3620052', '埼玉県', 'サイタマケン', '上尾市', 'アゲオシ', '中新井', 'ナカアライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県上尾市戸崎', '11', '11219', '3620053', '埼玉県', 'サイタマケン', '上尾市', 'アゲオシ', '戸崎', 'トサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県上尾市堤崎', '11', '11219', '3620054', '埼玉県', 'サイタマケン', '上尾市', 'アゲオシ', '堤崎', 'ツツミサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県上尾市平方領領家', '11', '11219', '3620055', '埼玉県', 'サイタマケン', '上尾市', 'アゲオシ', '平方領領家', 'ヒラカタリョウリョウケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県上尾市上野本郷', '11', '11219', '3620056', '埼玉県', 'サイタマケン', '上尾市', 'アゲオシ', '上野本郷', 'ウエノホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県上尾市西貝塚', '11', '11219', '3620057', '埼玉県', 'サイタマケン', '上尾市', 'アゲオシ', '西貝塚', 'ニシカイヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県上尾市上野', '11', '11219', '3620058', '埼玉県', 'サイタマケン', '上尾市', 'アゲオシ', '上野', 'ウエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県上尾市平方', '11', '11219', '3620059', '埼玉県', 'サイタマケン', '上尾市', 'アゲオシ', '平方', 'ヒラカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県上尾市藤波', '11', '11219', '3620061', '埼玉県', 'サイタマケン', '上尾市', 'アゲオシ', '藤波', 'フジナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県上尾市泉台', '11', '11219', '3620062', '埼玉県', 'サイタマケン', '上尾市', 'アゲオシ', '泉台', 'イズミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県上尾市小泉', '11', '11219', '3620063', '埼玉県', 'サイタマケン', '上尾市', 'アゲオシ', '小泉', 'コイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県上尾市小敷谷', '11', '11219', '3620064', '埼玉県', 'サイタマケン', '上尾市', 'アゲオシ', '小敷谷', 'コシキヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県上尾市畔吉', '11', '11219', '3620065', '埼玉県', 'サイタマケン', '上尾市', 'アゲオシ', '畔吉', 'アゼヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県上尾市領家', '11', '11219', '3620066', '埼玉県', 'サイタマケン', '上尾市', 'アゲオシ', '領家', 'リョウケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県上尾市中分', '11', '11219', '3620067', '埼玉県', 'サイタマケン', '上尾市', 'アゲオシ', '中分', 'ナカブン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県上尾市井戸木', '11', '11219', '3620071', '埼玉県', 'サイタマケン', '上尾市', 'アゲオシ', '井戸木', 'イドギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県上尾市中妻', '11', '11219', '3620072', '埼玉県', 'サイタマケン', '上尾市', 'アゲオシ', '中妻', 'ナカヅマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県上尾市浅間台', '11', '11219', '3620073', '埼玉県', 'サイタマケン', '上尾市', 'アゲオシ', '浅間台', 'アサマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県上尾市春日', '11', '11219', '3620074', '埼玉県', 'サイタマケン', '上尾市', 'アゲオシ', '春日', 'カスガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県上尾市柏座', '11', '11219', '3620075', '埼玉県', 'サイタマケン', '上尾市', 'アゲオシ', '柏座', 'カシワザ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県上尾市弁財', '11', '11219', '3620076', '埼玉県', 'サイタマケン', '上尾市', 'アゲオシ', '弁財', 'ベンザイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北足立郡伊奈町', '11', '11301', '3620800', '埼玉県', 'サイタマケン', '北足立郡伊奈町', 'キタアダチグンイナマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('29324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北足立郡伊奈町小針内宿', '11', '11301', '3620801', '埼玉県', 'サイタマケン', '北足立郡伊奈町', 'キタアダチグンイナマチ', '小針内宿', 'コバリウチジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北足立郡伊奈町羽貫', '11', '11301', '3620802', '埼玉県', 'サイタマケン', '北足立郡伊奈町', 'キタアダチグンイナマチ', '羽貫', 'ハヌキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北足立郡伊奈町大針', '11', '11301', '3620803', '埼玉県', 'サイタマケン', '北足立郡伊奈町', 'キタアダチグンイナマチ', '大針', 'オオバリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北足立郡伊奈町本町', '11', '11301', '3620804', '埼玉県', 'サイタマケン', '北足立郡伊奈町', 'キタアダチグンイナマチ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北足立郡伊奈町栄', '11', '11301', '3620805', '埼玉県', 'サイタマケン', '北足立郡伊奈町', 'キタアダチグンイナマチ', '栄', 'サカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北足立郡伊奈町小室', '11', '11301', '3620806', '埼玉県', 'サイタマケン', '北足立郡伊奈町', 'キタアダチグンイナマチ', '小室', 'コムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北足立郡伊奈町寿', '11', '11301', '3620807', '埼玉県', 'サイタマケン', '北足立郡伊奈町', 'キタアダチグンイナマチ', '寿', 'コトブキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北足立郡伊奈町小針新宿', '11', '11301', '3620808', '埼玉県', 'サイタマケン', '北足立郡伊奈町', 'キタアダチグンイナマチ', '小針新宿', 'コバリシンシュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県桶川市', '11', '11231', '3630000', '埼玉県', 'サイタマケン', '桶川市', 'オケガワシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('29351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県桶川市加納', '11', '11231', '3630001', '埼玉県', 'サイタマケン', '桶川市', 'オケガワシ', '加納', 'カノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県桶川市赤堀', '11', '11231', '3630002', '埼玉県', 'サイタマケン', '桶川市', 'オケガワシ', '赤堀', 'アカボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県桶川市篠津', '11', '11231', '3630003', '埼玉県', 'サイタマケン', '桶川市', 'オケガワシ', '篠津', 'シノヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県桶川市五丁台', '11', '11231', '3630004', '埼玉県', 'サイタマケン', '桶川市', 'オケガワシ', '五丁台', 'ゴチョウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県桶川市舎人新田', '11', '11231', '3630005', '埼玉県', 'サイタマケン', '桶川市', 'オケガワシ', '舎人新田', 'トネリシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県桶川市倉田', '11', '11231', '3630006', '埼玉県', 'サイタマケン', '桶川市', 'オケガワシ', '倉田', 'クラタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県桶川市小針領家', '11', '11231', '3630007', '埼玉県', 'サイタマケン', '桶川市', 'オケガワシ', '小針領家', 'コバリリョウケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県桶川市坂田', '11', '11231', '3630008', '埼玉県', 'サイタマケン', '桶川市', 'オケガワシ', '坂田', 'サカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県桶川市北', '11', '11231', '3630011', '埼玉県', 'サイタマケン', '桶川市', 'オケガワシ', '北', 'キタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県桶川市末広', '11', '11231', '3630012', '埼玉県', 'サイタマケン', '桶川市', 'オケガワシ', '末広', 'スエヒロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県桶川市東', '11', '11231', '3630013', '埼玉県', 'サイタマケン', '桶川市', 'オケガワシ', '東', 'ヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県桶川市神明', '11', '11231', '3630014', '埼玉県', 'サイタマケン', '桶川市', 'オケガワシ', '神明', 'シンメイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県桶川市南', '11', '11231', '3630015', '埼玉県', 'サイタマケン', '桶川市', 'オケガワシ', '南', 'ミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県桶川市寿', '11', '11231', '3630016', '埼玉県', 'サイタマケン', '桶川市', 'オケガワシ', '寿', 'コトブキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県桶川市西', '11', '11231', '3630017', '埼玉県', 'サイタマケン', '桶川市', 'オケガワシ', '西', 'ニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県桶川市泉', '11', '11231', '3630021', '埼玉県', 'サイタマケン', '桶川市', 'オケガワシ', '泉', 'イズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県桶川市若宮', '11', '11231', '3630022', '埼玉県', 'サイタマケン', '桶川市', 'オケガワシ', '若宮', 'ワカミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県桶川市朝日', '11', '11231', '3630023', '埼玉県', 'サイタマケン', '桶川市', 'オケガワシ', '朝日', 'アサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県桶川市鴨川', '11', '11231', '3630024', '埼玉県', 'サイタマケン', '桶川市', 'オケガワシ', '鴨川', 'カモガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県桶川市下日出谷', '11', '11231', '3630025', '埼玉県', 'サイタマケン', '桶川市', 'オケガワシ', '下日出谷', 'シモヒデヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県桶川市上日出谷', '11', '11231', '3630026', '埼玉県', 'サイタマケン', '桶川市', 'オケガワシ', '上日出谷', 'カミヒデヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県桶川市川田谷', '11', '11231', '3630027', '埼玉県', 'サイタマケン', '桶川市', 'オケガワシ', '川田谷', 'カワタヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県桶川市下日出谷西', '11', '11231', '3630028', '埼玉県', 'サイタマケン', '桶川市', 'オケガワシ', '下日出谷西', 'シモヒデヤニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北本市', '11', '11233', '3640000', '埼玉県', 'サイタマケン', '北本市', 'キタモトシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('29379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北本市深井', '11', '11233', '3640001', '埼玉県', 'サイタマケン', '北本市', 'キタモトシ', '深井', 'フカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北本市宮内', '11', '11233', '3640002', '埼玉県', 'サイタマケン', '北本市', 'キタモトシ', '宮内', 'ミヤウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北本市古市場', '11', '11233', '3640003', '埼玉県', 'サイタマケン', '北本市', 'キタモトシ', '古市場', 'フルイチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北本市山中', '11', '11233', '3640004', '埼玉県', 'サイタマケン', '北本市', 'キタモトシ', '山中', 'ヤマナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北本市本宿', '11', '11233', '3640005', '埼玉県', 'サイタマケン', '北本市', 'キタモトシ', '本宿', 'モトジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北本市北本', '11', '11233', '3640006', '埼玉県', 'サイタマケン', '北本市', 'キタモトシ', '北本', 'キタモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北本市東間', '11', '11233', '3640007', '埼玉県', 'サイタマケン', '北本市', 'キタモトシ', '東間', 'アズマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北本市朝日', '11', '11233', '3640011', '埼玉県', 'サイタマケン', '北本市', 'キタモトシ', '朝日', 'アサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北本市北中丸', '11', '11233', '3640012', '埼玉県', 'サイタマケン', '北本市', 'キタモトシ', '北中丸', 'キタナカマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北本市中丸', '11', '11233', '3640013', '埼玉県', 'サイタマケン', '北本市', 'キタモトシ', '中丸', 'ナカマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北本市二ツ家', '11', '11233', '3640014', '埼玉県', 'サイタマケン', '北本市', 'キタモトシ', '二ツ家', 'フタツヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北本市北本宿', '11', '11233', '3640021', '埼玉県', 'サイタマケン', '北本市', 'キタモトシ', '北本宿', 'キタモトジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北本市下石戸上', '11', '11233', '3640022', '埼玉県', 'サイタマケン', '北本市', 'キタモトシ', '下石戸上', 'シモイシトカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北本市下石戸下', '11', '11233', '3640023', '埼玉県', 'サイタマケン', '北本市', 'キタモトシ', '下石戸下', 'シモイシトシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北本市石戸', '11', '11233', '3640024', '埼玉県', 'サイタマケン', '北本市', 'キタモトシ', '石戸', 'イシト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北本市石戸宿', '11', '11233', '3640025', '埼玉県', 'サイタマケン', '北本市', 'キタモトシ', '石戸宿', 'イシトジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北本市荒井', '11', '11233', '3640026', '埼玉県', 'サイタマケン', '北本市', 'キタモトシ', '荒井', 'アライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北本市栄', '11', '11233', '3640027', '埼玉県', 'サイタマケン', '北本市', 'キタモトシ', '栄', 'サカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北本市中央', '11', '11233', '3640031', '埼玉県', 'サイタマケン', '北本市', 'キタモトシ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北本市緑', '11', '11233', '3640032', '埼玉県', 'サイタマケン', '北本市', 'キタモトシ', '緑', 'ミドリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北本市本町', '11', '11233', '3640033', '埼玉県', 'サイタマケン', '北本市', 'キタモトシ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北本市高尾', '11', '11233', '3640034', '埼玉県', 'サイタマケン', '北本市', 'キタモトシ', '高尾', 'タカオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県北本市西高尾', '11', '11233', '3640035', '埼玉県', 'サイタマケン', '北本市', 'キタモトシ', '西高尾', 'ニシタカオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鴻巣市', '11', '11217', '3650000', '埼玉県', 'サイタマケン', '鴻巣市', 'コウノスシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('29408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鴻巣市赤城台', '11', '11217', '3650001', '埼玉県', 'サイタマケン', '鴻巣市', 'コウノスシ', '赤城台', 'アカギダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鴻巣市赤城', '11', '11217', '3650002', '埼玉県', 'サイタマケン', '鴻巣市', 'コウノスシ', '赤城', 'アカギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鴻巣市北根', '11', '11217', '3650003', '埼玉県', 'サイタマケン', '鴻巣市', 'コウノスシ', '北根', 'キタネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鴻巣市関新田', '11', '11217', '3650004', '埼玉県', 'サイタマケン', '鴻巣市', 'コウノスシ', '関新田', 'セキシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鴻巣市広田', '11', '11217', '3650005', '埼玉県', 'サイタマケン', '鴻巣市', 'コウノスシ', '広田', 'ヒロダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鴻巣市新井', '11', '11217', '3650011', '埼玉県', 'サイタマケン', '鴻巣市', 'コウノスシ', '新井', 'アライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鴻巣市上会下', '11', '11217', '3650012', '埼玉県', 'サイタマケン', '鴻巣市', 'コウノスシ', '上会下', 'カミエゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鴻巣市境', '11', '11217', '3650013', '埼玉県', 'サイタマケン', '鴻巣市', 'コウノスシ', '境', 'サカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鴻巣市屈巣', '11', '11217', '3650014', '埼玉県', 'サイタマケン', '鴻巣市', 'コウノスシ', '屈巣', 'クス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鴻巣市安養寺', '11', '11217', '3650021', '埼玉県', 'サイタマケン', '鴻巣市', 'コウノスシ', '安養寺', 'アンヨウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鴻巣市郷地', '11', '11217', '3650022', '埼玉県', 'サイタマケン', '鴻巣市', 'コウノスシ', '郷地', 'ゴウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鴻巣市笠原', '11', '11217', '3650023', '埼玉県', 'サイタマケン', '鴻巣市', 'コウノスシ', '笠原', 'カサハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鴻巣市常光', '11', '11217', '3650024', '埼玉県', 'サイタマケン', '鴻巣市', 'コウノスシ', '常光', 'ジョウコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鴻巣市下谷', '11', '11217', '3650025', '埼玉県', 'サイタマケン', '鴻巣市', 'コウノスシ', '下谷', 'シモヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鴻巣市西中曽根', '11', '11217', '3650026', '埼玉県', 'サイタマケン', '鴻巣市', 'コウノスシ', '西中曽根', 'ニシナカゾネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鴻巣市上谷', '11', '11217', '3650027', '埼玉県', 'サイタマケン', '鴻巣市', 'コウノスシ', '上谷', 'カミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鴻巣市鴻巣', '11', '11217', '3650028', '埼玉県', 'サイタマケン', '鴻巣市', 'コウノスシ', '鴻巣', 'コウノス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鴻巣市ひばり野', '11', '11217', '3650031', '埼玉県', 'サイタマケン', '鴻巣市', 'コウノスシ', 'ひばり野', 'ヒバリノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鴻巣市中央', '11', '11217', '3650032', '埼玉県', 'サイタマケン', '鴻巣市', 'コウノスシ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鴻巣市生出塚', '11', '11217', '3650033', '埼玉県', 'サイタマケン', '鴻巣市', 'コウノスシ', '生出塚', 'オイネヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鴻巣市上生出塚', '11', '11217', '3650034', '埼玉県', 'サイタマケン', '鴻巣市', 'コウノスシ', '上生出塚', 'カミオイネヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鴻巣市下生出塚', '11', '11217', '3650035', '埼玉県', 'サイタマケン', '鴻巣市', 'コウノスシ', '下生出塚', 'シモオイネヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鴻巣市天神', '11', '11217', '3650036', '埼玉県', 'サイタマケン', '鴻巣市', 'コウノスシ', '天神', 'テンジン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鴻巣市人形', '11', '11217', '3650037', '埼玉県', 'サイタマケン', '鴻巣市', 'コウノスシ', '人形', 'ニンギョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鴻巣市本町', '11', '11217', '3650038', '埼玉県', 'サイタマケン', '鴻巣市', 'コウノスシ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鴻巣市東', '11', '11217', '3650039', '埼玉県', 'サイタマケン', '鴻巣市', 'コウノスシ', '東', 'ヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鴻巣市小松', '11', '11217', '3650041', '埼玉県', 'サイタマケン', '鴻巣市', 'コウノスシ', '小松', 'コマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鴻巣市松原', '11', '11217', '3650042', '埼玉県', 'サイタマケン', '鴻巣市', 'コウノスシ', '松原', 'マツバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鴻巣市原馬室', '11', '11217', '3650043', '埼玉県', 'サイタマケン', '鴻巣市', 'コウノスシ', '原馬室', 'ハラマムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鴻巣市滝馬室', '11', '11217', '3650044', '埼玉県', 'サイタマケン', '鴻巣市', 'コウノスシ', '滝馬室', 'タキマムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鴻巣市氷川町', '11', '11217', '3650045', '埼玉県', 'サイタマケン', '鴻巣市', 'コウノスシ', '氷川町', 'ヒカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鴻巣市富士見町', '11', '11217', '3650046', '埼玉県', 'サイタマケン', '鴻巣市', 'コウノスシ', '富士見町', 'フジミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鴻巣市逆川', '11', '11217', '3650047', '埼玉県', 'サイタマケン', '鴻巣市', 'コウノスシ', '逆川', 'サカサガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鴻巣市宮前', '11', '11217', '3650051', '埼玉県', 'サイタマケン', '鴻巣市', 'コウノスシ', '宮前', 'ミヤマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鴻巣市登戸', '11', '11217', '3650052', '埼玉県', 'サイタマケン', '鴻巣市', 'コウノスシ', '登戸', 'ノボリト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鴻巣市緑町', '11', '11217', '3650053', '埼玉県', 'サイタマケン', '鴻巣市', 'コウノスシ', '緑町', 'ミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鴻巣市大間', '11', '11217', '3650054', '埼玉県', 'サイタマケン', '鴻巣市', 'コウノスシ', '大間', 'オオマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鴻巣市栄町', '11', '11217', '3650055', '埼玉県', 'サイタマケン', '鴻巣市', 'コウノスシ', '栄町', 'サカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鴻巣市堤町', '11', '11217', '3650056', '埼玉県', 'サイタマケン', '鴻巣市', 'コウノスシ', '堤町', 'ツツミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鴻巣市幸町', '11', '11217', '3650057', '埼玉県', 'サイタマケン', '鴻巣市', 'コウノスシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鴻巣市北中野', '11', '11217', '3650058', '埼玉県', 'サイタマケン', '鴻巣市', 'コウノスシ', '北中野', 'キタナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鴻巣市糠田', '11', '11217', '3650059', '埼玉県', 'サイタマケン', '鴻巣市', 'コウノスシ', '糠田', 'ヌカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鴻巣市川面', '11', '11217', '3650061', '埼玉県', 'サイタマケン', '鴻巣市', 'コウノスシ', '川面', 'カワヅラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鴻巣市箕田', '11', '11217', '3650062', '埼玉県', 'サイタマケン', '鴻巣市', 'コウノスシ', '箕田', 'ミダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鴻巣市稲荷町', '11', '11217', '3650063', '埼玉県', 'サイタマケン', '鴻巣市', 'コウノスシ', '稲荷町', 'イナリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鴻巣市赤見台', '11', '11217', '3650064', '埼玉県', 'サイタマケン', '鴻巣市', 'コウノスシ', '赤見台', 'アカミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鴻巣市中井', '11', '11217', '3650065', '埼玉県', 'サイタマケン', '鴻巣市', 'コウノスシ', '中井', 'ナカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鴻巣市三ツ木', '11', '11217', '3650066', '埼玉県', 'サイタマケン', '鴻巣市', 'コウノスシ', '三ツ木', 'ミツギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鴻巣市寺谷', '11', '11217', '3650071', '埼玉県', 'サイタマケン', '鴻巣市', 'コウノスシ', '寺谷', 'テラヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鴻巣市市ノ縄', '11', '11217', '3650072', '埼玉県', 'サイタマケン', '鴻巣市', 'コウノスシ', '市ノ縄', 'イチノナワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鴻巣市八幡田', '11', '11217', '3650073', '埼玉県', 'サイタマケン', '鴻巣市', 'コウノスシ', '八幡田', 'ハチマンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鴻巣市神明', '11', '11217', '3650074', '埼玉県', 'サイタマケン', '鴻巣市', 'コウノスシ', '神明', 'シンメイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鴻巣市宮地', '11', '11217', '3650075', '埼玉県', 'サイタマケン', '鴻巣市', 'コウノスシ', '宮地', 'ミヤジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鴻巣市本宮町', '11', '11217', '3650076', '埼玉県', 'サイタマケン', '鴻巣市', 'コウノスシ', '本宮町', 'ホンミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鴻巣市雷電', '11', '11217', '3650077', '埼玉県', 'サイタマケン', '鴻巣市', 'コウノスシ', '雷電', 'ライデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鴻巣市加美', '11', '11217', '3650078', '埼玉県', 'サイタマケン', '鴻巣市', 'コウノスシ', '加美', 'カミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県深谷市', '11', '11218', '3660000', '埼玉県', 'サイタマケン', '深谷市', 'フカヤシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('29479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県深谷市中瀬', '11', '11218', '3660001', '埼玉県', 'サイタマケン', '深谷市', 'フカヤシ', '中瀬', 'ナカゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県深谷市下手計', '11', '11218', '3660002', '埼玉県', 'サイタマケン', '深谷市', 'フカヤシ', '下手計', 'シモテバカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県深谷市大塚', '11', '11218', '3660003', '埼玉県', 'サイタマケン', '深谷市', 'フカヤシ', '大塚', 'オオヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県深谷市上手計', '11', '11218', '3660004', '埼玉県', 'サイタマケン', '深谷市', 'フカヤシ', '上手計', 'カミテバカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県深谷市町田', '11', '11218', '3660005', '埼玉県', 'サイタマケン', '深谷市', 'フカヤシ', '町田', 'マチダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県深谷市血洗島', '11', '11218', '3660006', '埼玉県', 'サイタマケン', '深谷市', 'フカヤシ', '血洗島', 'チアライジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県深谷市南阿賀野', '11', '11218', '3660007', '埼玉県', 'サイタマケン', '深谷市', 'フカヤシ', '南阿賀野', 'ミナミアガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県深谷市北阿賀野', '11', '11218', '3660008', '埼玉県', 'サイタマケン', '深谷市', 'フカヤシ', '北阿賀野', 'キタアガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県深谷市横瀬', '11', '11218', '3660009', '埼玉県', 'サイタマケン', '深谷市', 'フカヤシ', '横瀬', 'ヨコゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県深谷市高島', '11', '11218', '3660010', '埼玉県', 'サイタマケン', '深谷市', 'フカヤシ', '高島', 'タカシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県深谷市石塚', '11', '11218', '3660011', '埼玉県', 'サイタマケン', '深谷市', 'フカヤシ', '石塚', 'イシヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県深谷市江原', '11', '11218', '3660012', '埼玉県', 'サイタマケン', '深谷市', 'フカヤシ', '江原', 'エバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県深谷市堀米', '11', '11218', '3660013', '埼玉県', 'サイタマケン', '深谷市', 'フカヤシ', '堀米', 'ホリゴメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県深谷市藤野木', '11', '11218', '3660014', '埼玉県', 'サイタマケン', '深谷市', 'フカヤシ', '藤野木', 'フジノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県深谷市蓮沼', '11', '11218', '3660015', '埼玉県', 'サイタマケン', '深谷市', 'フカヤシ', '蓮沼', 'ハスヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県深谷市新井', '11', '11218', '3660016', '埼玉県', 'サイタマケン', '深谷市', 'フカヤシ', '新井', 'アライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県深谷市沼尻', '11', '11218', '3660017', '埼玉県', 'サイタマケン', '深谷市', 'フカヤシ', '沼尻', 'ヌマジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県深谷市成塚', '11', '11218', '3660018', '埼玉県', 'サイタマケン', '深谷市', 'フカヤシ', '成塚', 'ナリヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県深谷市新戒', '11', '11218', '3660019', '埼玉県', 'サイタマケン', '深谷市', 'フカヤシ', '新戒', 'シンガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県深谷市上増田', '11', '11218', '3660021', '埼玉県', 'サイタマケン', '深谷市', 'フカヤシ', '上増田', 'カミマスダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県深谷市本田ケ谷', '11', '11218', '3660022', '埼玉県', 'サイタマケン', '深谷市', 'フカヤシ', '本田ケ谷', 'ホンダガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県深谷市宮ケ谷戸', '11', '11218', '3660023', '埼玉県', 'サイタマケン', '深谷市', 'フカヤシ', '宮ケ谷戸', 'ミヤガヤト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県深谷市明戸', '11', '11218', '3660024', '埼玉県', 'サイタマケン', '深谷市', 'フカヤシ', '明戸', 'アケト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県深谷市寿町', '11', '11218', '3660025', '埼玉県', 'サイタマケン', '深谷市', 'フカヤシ', '寿町', 'コトブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県深谷市稲荷町', '11', '11218', '3660026', '埼玉県', 'サイタマケン', '深谷市', 'フカヤシ', '稲荷町', 'イナリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県深谷市天神町', '11', '11218', '3660027', '埼玉県', 'サイタマケン', '深谷市', 'フカヤシ', '天神町', 'テンジンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県深谷市稲荷町北', '11', '11218', '3660028', '埼玉県', 'サイタマケン', '深谷市', 'フカヤシ', '稲荷町北', 'イナリチョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県深谷市上敷免', '11', '11218', '3660029', '埼玉県', 'サイタマケン', '深谷市', 'フカヤシ', '上敷免', 'ジョウシキメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県深谷市国済寺町', '11', '11218', '3660031', '埼玉県', 'サイタマケン', '深谷市', 'フカヤシ', '国済寺町', 'コクサイジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県深谷市幡羅町', '11', '11218', '3660032', '埼玉県', 'サイタマケン', '深谷市', 'フカヤシ', '幡羅町', 'ハタラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県深谷市国済寺', '11', '11218', '3660033', '埼玉県', 'サイタマケン', '深谷市', 'フカヤシ', '国済寺', 'コクサイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県深谷市常盤町', '11', '11218', '3660034', '埼玉県', 'サイタマケン', '深谷市', 'フカヤシ', '常盤町', 'トキワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県深谷市原郷', '11', '11218', '3660035', '埼玉県', 'サイタマケン', '深谷市', 'フカヤシ', '原郷', 'ハラゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県深谷市東方', '11', '11218', '3660041', '埼玉県', 'サイタマケン', '深谷市', 'フカヤシ', '東方', 'ヒガシガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県深谷市東方町', '11', '11218', '3660042', '埼玉県', 'サイタマケン', '深谷市', 'フカヤシ', '東方町', 'ヒガシガタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県深谷市上柴町東', '11', '11218', '3660051', '埼玉県', 'サイタマケン', '深谷市', 'フカヤシ', '上柴町東', 'カミシバチョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県深谷市上柴町西', '11', '11218', '3660052', '埼玉県', 'サイタマケン', '深谷市', 'フカヤシ', '上柴町西', 'カミシバチョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県深谷市秋元町', '11', '11218', '3660053', '埼玉県', 'サイタマケン', '深谷市', 'フカヤシ', '秋元町', 'アキモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県深谷市緑ケ丘', '11', '11218', '3660054', '埼玉県', 'サイタマケン', '深谷市', 'フカヤシ', '緑ケ丘', 'ミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県深谷市上野台', '11', '11218', '3660801', '埼玉県', 'サイタマケン', '深谷市', 'フカヤシ', '上野台', 'ウワノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県深谷市桜ケ丘', '11', '11218', '3660802', '埼玉県', 'サイタマケン', '深谷市', 'フカヤシ', '桜ケ丘', 'サクラガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県深谷市宿根', '11', '11218', '3660810', '埼玉県', 'サイタマケン', '深谷市', 'フカヤシ', '宿根', 'シュクネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県深谷市人見', '11', '11218', '3660811', '埼玉県', 'サイタマケン', '深谷市', 'フカヤシ', '人見', 'ヒトミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県深谷市折之口', '11', '11218', '3660812', '埼玉県', 'サイタマケン', '深谷市', 'フカヤシ', '折之口', 'オリノクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県深谷市境', '11', '11218', '3660813', '埼玉県', 'サイタマケン', '深谷市', 'フカヤシ', '境', 'サカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県深谷市大谷', '11', '11218', '3660814', '埼玉県', 'サイタマケン', '深谷市', 'フカヤシ', '大谷', 'オオヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県深谷市櫛引', '11', '11218', '3660815', '埼玉県', 'サイタマケン', '深谷市', 'フカヤシ', '櫛引', 'クシビキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県深谷市樫合', '11', '11218', '3660816', '埼玉県', 'サイタマケン', '深谷市', 'フカヤシ', '樫合', 'カシアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県深谷市柏合', '11', '11218', '3660817', '埼玉県', 'サイタマケン', '深谷市', 'フカヤシ', '柏合', 'カシアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県深谷市萱場', '11', '11218', '3660818', '埼玉県', 'サイタマケン', '深谷市', 'フカヤシ', '萱場', 'カヤバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県深谷市見晴町', '11', '11218', '3660819', '埼玉県', 'サイタマケン', '深谷市', 'フカヤシ', '見晴町', 'ミハラシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県深谷市田谷', '11', '11218', '3660821', '埼玉県', 'サイタマケン', '深谷市', 'フカヤシ', '田谷', 'タヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県深谷市仲町', '11', '11218', '3660822', '埼玉県', 'サイタマケン', '深谷市', 'フカヤシ', '仲町', 'ナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県深谷市本住町', '11', '11218', '3660823', '埼玉県', 'サイタマケン', '深谷市', 'フカヤシ', '本住町', 'モトスミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県深谷市西島町西島', '11', '11218', '3660824', '埼玉県', 'サイタマケン', '深谷市', 'フカヤシ', '西島町', 'ニシジマチョウ', null, null, '西島', 'ニシジマ');
INSERT INTO `ms_addresses` VALUES ('29534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県深谷市深谷町', '11', '11218', '3660825', '埼玉県', 'サイタマケン', '深谷市', 'フカヤシ', '深谷町', 'フカヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県深谷市田所町', '11', '11218', '3660826', '埼玉県', 'サイタマケン', '深谷市', 'フカヤシ', '田所町', 'タドコロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県深谷市栄町', '11', '11218', '3660827', '埼玉県', 'サイタマケン', '深谷市', 'フカヤシ', '栄町', 'サカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県深谷市東大沼', '11', '11218', '3660828', '埼玉県', 'サイタマケン', '深谷市', 'フカヤシ', '東大沼', 'ヒガシオオヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県深谷市西大沼', '11', '11218', '3660829', '埼玉県', 'サイタマケン', '深谷市', 'フカヤシ', '西大沼', 'ニシオオヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県深谷市内ケ島', '11', '11218', '3660831', '埼玉県', 'サイタマケン', '深谷市', 'フカヤシ', '内ケ島', 'ウチガシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県深谷市高畑', '11', '11218', '3660832', '埼玉県', 'サイタマケン', '深谷市', 'フカヤシ', '高畑', 'タカバタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県深谷市戸森', '11', '11218', '3660833', '埼玉県', 'サイタマケン', '深谷市', 'フカヤシ', '戸森', 'トモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県深谷市曲田錦町', '11', '11218', '3660834', '埼玉県', 'サイタマケン', '深谷市', 'フカヤシ', '曲田', 'マガツタ', null, null, '錦町', 'ニシキマチ');
INSERT INTO `ms_addresses` VALUES ('29543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県深谷市谷之', '11', '11218', '3660835', '埼玉県', 'サイタマケン', '深谷市', 'フカヤシ', '谷之', 'ヤノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県深谷市伊勢方', '11', '11218', '3660836', '埼玉県', 'サイタマケン', '深谷市', 'フカヤシ', '伊勢方', 'イセガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県深谷市起会', '11', '11218', '3660837', '埼玉県', 'サイタマケン', '深谷市', 'フカヤシ', '起会', 'オキアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県深谷市大塚島', '11', '11218', '3660838', '埼玉県', 'サイタマケン', '深谷市', 'フカヤシ', '大塚島', 'オオツカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県深谷市矢島', '11', '11218', '3660839', '埼玉県', 'サイタマケン', '深谷市', 'フカヤシ', '矢島', 'ヤジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県本庄市', '11', '11211', '3670000', '埼玉県', 'サイタマケン', '本庄市', 'ホンジョウシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('29556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県本庄市下仁手', '11', '11211', '3670001', '埼玉県', 'サイタマケン', '本庄市', 'ホンジョウシ', '下仁手', 'シモニツテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県本庄市仁手', '11', '11211', '3670002', '埼玉県', 'サイタマケン', '本庄市', 'ホンジョウシ', '仁手', 'ニッテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県本庄市台町', '11', '11211', '3670003', '埼玉県', 'サイタマケン', '本庄市', 'ホンジョウシ', '台町', 'ダイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県本庄市本町', '11', '11211', '3670004', '埼玉県', 'サイタマケン', '本庄市', 'ホンジョウシ', '本町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県本庄市久々宇', '11', '11211', '3670005', '埼玉県', 'サイタマケン', '本庄市', 'ホンジョウシ', '久々宇', 'クグウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県本庄市田中', '11', '11211', '3670006', '埼玉県', 'サイタマケン', '本庄市', 'ホンジョウシ', '田中', 'タナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県本庄市上仁手', '11', '11211', '3670007', '埼玉県', 'サイタマケン', '本庄市', 'ホンジョウシ', '上仁手', 'カミニッテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県本庄市小和瀬', '11', '11211', '3670011', '埼玉県', 'サイタマケン', '本庄市', 'ホンジョウシ', '小和瀬', 'コワゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県本庄市宮戸', '11', '11211', '3670012', '埼玉県', 'サイタマケン', '本庄市', 'ホンジョウシ', '宮戸', 'ミヤド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県本庄市滝瀬', '11', '11211', '3670013', '埼玉県', 'サイタマケン', '本庄市', 'ホンジョウシ', '滝瀬', 'タキセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県本庄市堀田', '11', '11211', '3670014', '埼玉県', 'サイタマケン', '本庄市', 'ホンジョウシ', '堀田', 'ホッタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県本庄市牧西', '11', '11211', '3670015', '埼玉県', 'サイタマケン', '本庄市', 'ホンジョウシ', '牧西', 'モクサイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県本庄市鵜森', '11', '11211', '3670016', '埼玉県', 'サイタマケン', '本庄市', 'ホンジョウシ', '鵜森', 'ウノモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県本庄市傍示堂', '11', '11211', '3670017', '埼玉県', 'サイタマケン', '本庄市', 'ホンジョウシ', '傍示堂', 'ホウジドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県本庄市諏訪町', '11', '11211', '3670018', '埼玉県', 'サイタマケン', '本庄市', 'ホンジョウシ', '諏訪町', 'スワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県本庄市東台', '11', '11211', '3670021', '埼玉県', 'サイタマケン', '本庄市', 'ホンジョウシ', '東台', 'ヒガシダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県本庄市日の出', '11', '11211', '3670022', '埼玉県', 'サイタマケン', '本庄市', 'ホンジョウシ', '日の出', 'ヒノデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県本庄市寿', '11', '11211', '3670023', '埼玉県', 'サイタマケン', '本庄市', 'ホンジョウシ', '寿', 'コトブキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県本庄市東五十子', '11', '11211', '3670024', '埼玉県', 'サイタマケン', '本庄市', 'ホンジョウシ', '東五十子', 'ヒガシイカツコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県本庄市西五十子', '11', '11211', '3670025', '埼玉県', 'サイタマケン', '本庄市', 'ホンジョウシ', '西五十子', 'ニシイカツコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県本庄市朝日町', '11', '11211', '3670026', '埼玉県', 'サイタマケン', '本庄市', 'ホンジョウシ', '朝日町', 'アサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県本庄市五十子', '11', '11211', '3670027', '埼玉県', 'サイタマケン', '本庄市', 'ホンジョウシ', '五十子', 'イカッコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県本庄市北堀', '11', '11211', '3670031', '埼玉県', 'サイタマケン', '本庄市', 'ホンジョウシ', '北堀', 'キタボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県本庄市栗崎', '11', '11211', '3670032', '埼玉県', 'サイタマケン', '本庄市', 'ホンジョウシ', '栗崎', 'クリザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県本庄市東富田', '11', '11211', '3670033', '埼玉県', 'サイタマケン', '本庄市', 'ホンジョウシ', '東富田', 'ヒガシトミダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県本庄市四方田', '11', '11211', '3670034', '埼玉県', 'サイタマケン', '本庄市', 'ホンジョウシ', '四方田', 'シホウデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県本庄市西富田', '11', '11211', '3670035', '埼玉県', 'サイタマケン', '本庄市', 'ホンジョウシ', '西富田', 'ニシトミダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県本庄市今井', '11', '11211', '3670036', '埼玉県', 'サイタマケン', '本庄市', 'ホンジョウシ', '今井', 'イマイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県本庄市共栄', '11', '11211', '3670037', '埼玉県', 'サイタマケン', '本庄市', 'ホンジョウシ', '共栄', 'キョウエイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県本庄市いまい台', '11', '11211', '3670038', '埼玉県', 'サイタマケン', '本庄市', 'ホンジョウシ', 'いまい台', 'イマイダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県本庄市四季の里', '11', '11211', '3670039', '埼玉県', 'サイタマケン', '本庄市', 'ホンジョウシ', '四季の里', 'シキノサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県本庄市駅南', '11', '11211', '3670041', '埼玉県', 'サイタマケン', '本庄市', 'ホンジョウシ', '駅南', 'エキナン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県本庄市けや木', '11', '11211', '3670042', '埼玉県', 'サイタマケン', '本庄市', 'ホンジョウシ', 'けや木', 'ケヤキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県本庄市緑', '11', '11211', '3670043', '埼玉県', 'サイタマケン', '本庄市', 'ホンジョウシ', '緑', 'ミドリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県本庄市見福', '11', '11211', '3670044', '埼玉県', 'サイタマケン', '本庄市', 'ホンジョウシ', '見福', 'ケンプク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県本庄市柏', '11', '11211', '3670045', '埼玉県', 'サイタマケン', '本庄市', 'ホンジョウシ', '柏', 'カシワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県本庄市栄', '11', '11211', '3670046', '埼玉県', 'サイタマケン', '本庄市', 'ホンジョウシ', '栄', 'サカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県本庄市前原', '11', '11211', '3670047', '埼玉県', 'サイタマケン', '本庄市', 'ホンジョウシ', '前原', 'マエハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県本庄市南', '11', '11211', '3670048', '埼玉県', 'サイタマケン', '本庄市', 'ホンジョウシ', '南', 'ミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県本庄市本庄', '11', '11211', '3670051', '埼玉県', 'サイタマケン', '本庄市', 'ホンジョウシ', '本庄', 'ホンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県本庄市銀座', '11', '11211', '3670052', '埼玉県', 'サイタマケン', '本庄市', 'ホンジョウシ', '銀座', 'ギンザ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県本庄市中央', '11', '11211', '3670053', '埼玉県', 'サイタマケン', '本庄市', 'ホンジョウシ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県本庄市千代田', '11', '11211', '3670054', '埼玉県', 'サイタマケン', '本庄市', 'ホンジョウシ', '千代田', 'チヨダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県本庄市若泉', '11', '11211', '3670055', '埼玉県', 'サイタマケン', '本庄市', 'ホンジョウシ', '若泉', 'ワカイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県本庄市照若町', '11', '11211', '3670056', '埼玉県', 'サイタマケン', '本庄市', 'ホンジョウシ', '照若町', 'テルワカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県本庄市小島', '11', '11211', '3670061', '埼玉県', 'サイタマケン', '本庄市', 'ホンジョウシ', '小島', 'オジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県本庄市小島南', '11', '11211', '3670062', '埼玉県', 'サイタマケン', '本庄市', 'ホンジョウシ', '小島南', 'オジマミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県本庄市下野堂', '11', '11211', '3670063', '埼玉県', 'サイタマケン', '本庄市', 'ホンジョウシ', '下野堂', 'シモノドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県本庄市万年寺', '11', '11211', '3670064', '埼玉県', 'サイタマケン', '本庄市', 'ホンジョウシ', '万年寺', 'マンネンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県本庄市山王堂', '11', '11211', '3670071', '埼玉県', 'サイタマケン', '本庄市', 'ホンジョウシ', '山王堂', 'サンノウドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県本庄市沼和田', '11', '11211', '3670072', '埼玉県', 'サイタマケン', '本庄市', 'ホンジョウシ', '沼和田', 'ヌマワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県本庄市都島', '11', '11211', '3670073', '埼玉県', 'サイタマケン', '本庄市', 'ホンジョウシ', '都島', 'ミヤコジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県本庄市杉山', '11', '11211', '3670074', '埼玉県', 'サイタマケン', '本庄市', 'ホンジョウシ', '杉山', 'スギヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県本庄市新井', '11', '11211', '3670075', '埼玉県', 'サイタマケン', '本庄市', 'ホンジョウシ', '新井', 'アライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県児玉郡美里町', '11', '11381', '3670100', '埼玉県', 'サイタマケン', '児玉郡美里町', 'コダマグンミサトマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('29611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県児玉郡美里町小茂田', '11', '11381', '3670101', '埼玉県', 'サイタマケン', '児玉郡美里町', 'コダマグンミサトマチ', '小茂田', 'コモダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県児玉郡美里町関', '11', '11381', '3670102', '埼玉県', 'サイタマケン', '児玉郡美里町', 'コダマグンミサトマチ', '関', 'セキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県児玉郡美里町阿那志', '11', '11381', '3670103', '埼玉県', 'サイタマケン', '児玉郡美里町', 'コダマグンミサトマチ', '阿那志', 'アナシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県児玉郡美里町根木', '11', '11381', '3670104', '埼玉県', 'サイタマケン', '児玉郡美里町', 'コダマグンミサトマチ', '根木', 'ネギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県児玉郡美里町沼上', '11', '11381', '3670105', '埼玉県', 'サイタマケン', '児玉郡美里町', 'コダマグンミサトマチ', '沼上', 'ヌマガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県児玉郡美里町南十条', '11', '11381', '3670106', '埼玉県', 'サイタマケン', '児玉郡美里町', 'コダマグンミサトマチ', '南十条', 'ミナミジュウジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県児玉郡美里町北十条', '11', '11381', '3670107', '埼玉県', 'サイタマケン', '児玉郡美里町', 'コダマグンミサトマチ', '北十条', 'キタジュウジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県児玉郡美里町下児玉', '11', '11381', '3670108', '埼玉県', 'サイタマケン', '児玉郡美里町', 'コダマグンミサトマチ', '下児玉', 'シモコダマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県児玉郡美里町古郡', '11', '11381', '3670111', '埼玉県', 'サイタマケン', '児玉郡美里町', 'コダマグンミサトマチ', '古郡', 'フルコオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県児玉郡美里町木部', '11', '11381', '3670112', '埼玉県', 'サイタマケン', '児玉郡美里町', 'コダマグンミサトマチ', '木部', 'キベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県児玉郡美里町甘粕', '11', '11381', '3670113', '埼玉県', 'サイタマケン', '児玉郡美里町', 'コダマグンミサトマチ', '甘粕', 'アマガス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県児玉郡美里町中里', '11', '11381', '3670114', '埼玉県', 'サイタマケン', '児玉郡美里町', 'コダマグンミサトマチ', '中里', 'ナカザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県児玉郡美里町猪俣', '11', '11381', '3670115', '埼玉県', 'サイタマケン', '児玉郡美里町', 'コダマグンミサトマチ', '猪俣', 'イノマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県児玉郡美里町円良田', '11', '11381', '3670116', '埼玉県', 'サイタマケン', '児玉郡美里町', 'コダマグンミサトマチ', '円良田', 'ツブラタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県児玉郡美里町白石', '11', '11381', '3670117', '埼玉県', 'サイタマケン', '児玉郡美里町', 'コダマグンミサトマチ', '白石', 'シロイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県児玉郡美里町広木', '11', '11381', '3670118', '埼玉県', 'サイタマケン', '児玉郡美里町', 'コダマグンミサトマチ', '広木', 'ヒロキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県児玉郡美里町駒衣', '11', '11381', '3670119', '埼玉県', 'サイタマケン', '児玉郡美里町', 'コダマグンミサトマチ', '駒衣', 'コマギヌ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県児玉郡神川町', '11', '11383', '3670200', '埼玉県', 'サイタマケン', '児玉郡神川町', 'コダマグンカミカワマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('29632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県本庄市児玉町高関', '11', '11211', '3670201', '埼玉県', 'サイタマケン', '本庄市', 'ホンジョウシ', '児玉町高関', 'コダマチョウタカゼキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県本庄市児玉町下浅見', '11', '11211', '3670202', '埼玉県', 'サイタマケン', '本庄市', 'ホンジョウシ', '児玉町下浅見', 'コダマチョウシモアザミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県本庄市児玉町入浅見', '11', '11211', '3670203', '埼玉県', 'サイタマケン', '本庄市', 'ホンジョウシ', '児玉町入浅見', 'コダマチョウイリアザミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県本庄市児玉町蛭川', '11', '11211', '3670204', '埼玉県', 'サイタマケン', '本庄市', 'ホンジョウシ', '児玉町蛭川', 'コダマチョウヒルガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県本庄市児玉町上真下', '11', '11211', '3670205', '埼玉県', 'サイタマケン', '本庄市', 'ホンジョウシ', '児玉町上真下', 'コダマチョウカミマシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県本庄市児玉町共栄', '11', '11211', '3670206', '埼玉県', 'サイタマケン', '本庄市', 'ホンジョウシ', '児玉町共栄', 'コダマチョウキョウエイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県本庄市児玉町下真下', '11', '11211', '3670207', '埼玉県', 'サイタマケン', '本庄市', 'ホンジョウシ', '児玉町下真下', 'コダマチョウシモマシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県本庄市児玉町吉田林', '11', '11211', '3670211', '埼玉県', 'サイタマケン', '本庄市', 'ホンジョウシ', '児玉町吉田林', 'コダマチョウキタバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県本庄市児玉町児玉', '11', '11211', '3670212', '埼玉県', 'サイタマケン', '本庄市', 'ホンジョウシ', '児玉町児玉', 'コダマチョウコダマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県本庄市児玉町秋山', '11', '11211', '3670213', '埼玉県', 'サイタマケン', '本庄市', 'ホンジョウシ', '児玉町秋山', 'コダマチョウアキヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県本庄市児玉町小平', '11', '11211', '3670214', '埼玉県', 'サイタマケン', '本庄市', 'ホンジョウシ', '児玉町小平', 'コダマチョウコダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県本庄市児玉町長沖', '11', '11211', '3670215', '埼玉県', 'サイタマケン', '本庄市', 'ホンジョウシ', '児玉町長沖', 'コダマチョウナガオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県本庄市児玉町金屋', '11', '11211', '3670216', '埼玉県', 'サイタマケン', '本庄市', 'ホンジョウシ', '児玉町金屋', 'コダマチョウカナヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県本庄市児玉町八幡山', '11', '11211', '3670217', '埼玉県', 'サイタマケン', '本庄市', 'ホンジョウシ', '児玉町八幡山', 'コダマチョウハチマンヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県本庄市児玉町保木野', '11', '11211', '3670221', '埼玉県', 'サイタマケン', '本庄市', 'ホンジョウシ', '児玉町保木野', 'コダマチョウホキノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県本庄市児玉町田端', '11', '11211', '3670222', '埼玉県', 'サイタマケン', '本庄市', 'ホンジョウシ', '児玉町田端', 'コダマチョウタバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県本庄市児玉町塩谷', '11', '11211', '3670223', '埼玉県', 'サイタマケン', '本庄市', 'ホンジョウシ', '児玉町塩谷', 'コダマチョウシオヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県本庄市児玉町高柳', '11', '11211', '3670224', '埼玉県', 'サイタマケン', '本庄市', 'ホンジョウシ', '児玉町高柳', 'コダマチョウタカヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県本庄市児玉町飯倉', '11', '11211', '3670225', '埼玉県', 'サイタマケン', '本庄市', 'ホンジョウシ', '児玉町飯倉', 'コダマチョウイイグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県本庄市児玉町宮内', '11', '11211', '3670226', '埼玉県', 'サイタマケン', '本庄市', 'ホンジョウシ', '児玉町宮内', 'コダマチョウミヤウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県児玉郡神川町中新里', '11', '11383', '3670231', '埼玉県', 'サイタマケン', '児玉郡神川町', 'コダマグンカミカワマチ', '中新里', 'ナカニイサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県児玉郡神川町新里', '11', '11383', '3670232', '埼玉県', 'サイタマケン', '児玉郡神川町', 'コダマグンカミカワマチ', '新里', 'ニイサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県児玉郡神川町二ノ宮', '11', '11383', '3670233', '埼玉県', 'サイタマケン', '児玉郡神川町', 'コダマグンカミカワマチ', '二ノ宮', 'ニノミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県児玉郡神川町池田', '11', '11383', '3670234', '埼玉県', 'サイタマケン', '児玉郡神川町', 'コダマグンカミカワマチ', '池田', 'イケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県児玉郡神川町新宿', '11', '11383', '3670235', '埼玉県', 'サイタマケン', '児玉郡神川町', 'コダマグンカミカワマチ', '新宿', 'シンシュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県児玉郡神川町小浜', '11', '11383', '3670236', '埼玉県', 'サイタマケン', '児玉郡神川町', 'コダマグンカミカワマチ', '小浜', 'コバマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県児玉郡神川町貫井', '11', '11383', '3670237', '埼玉県', 'サイタマケン', '児玉郡神川町', 'コダマグンカミカワマチ', '貫井', 'ヌクイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県児玉郡神川町肥土', '11', '11383', '3670238', '埼玉県', 'サイタマケン', '児玉郡神川町', 'コダマグンカミカワマチ', '肥土', 'ヒド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県児玉郡神川町元原', '11', '11383', '3670241', '埼玉県', 'サイタマケン', '児玉郡神川町', 'コダマグンカミカワマチ', '元原', 'モトハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県児玉郡神川町原新田', '11', '11383', '3670242', '埼玉県', 'サイタマケン', '児玉郡神川町', 'コダマグンカミカワマチ', '原新田', 'ハラシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県児玉郡神川町熊野堂', '11', '11383', '3670243', '埼玉県', 'サイタマケン', '児玉郡神川町', 'コダマグンカミカワマチ', '熊野堂', 'クマノドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県児玉郡神川町八日市', '11', '11383', '3670244', '埼玉県', 'サイタマケン', '児玉郡神川町', 'コダマグンカミカワマチ', '八日市', 'ヨウカイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県児玉郡神川町植竹', '11', '11383', '3670245', '埼玉県', 'サイタマケン', '児玉郡神川町', 'コダマグンカミカワマチ', '植竹', 'ウエダケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県児玉郡神川町関口', '11', '11383', '3670246', '埼玉県', 'サイタマケン', '児玉郡神川町', 'コダマグンカミカワマチ', '関口', 'セキグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県児玉郡神川町元阿保', '11', '11383', '3670247', '埼玉県', 'サイタマケン', '児玉郡神川町', 'コダマグンカミカワマチ', '元阿保', 'モトアボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県児玉郡神川町四軒在家', '11', '11383', '3670248', '埼玉県', 'サイタマケン', '児玉郡神川町', 'コダマグンカミカワマチ', '四軒在家', 'シケンザイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県本庄市児玉町稲沢', '11', '11211', '3670251', '埼玉県', 'サイタマケン', '本庄市', 'ホンジョウシ', '児玉町稲沢', 'コダマチョウイナザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県本庄市児玉町元田', '11', '11211', '3670252', '埼玉県', 'サイタマケン', '本庄市', 'ホンジョウシ', '児玉町元田', 'コダマチョウゲンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県本庄市児玉町河内', '11', '11211', '3670253', '埼玉県', 'サイタマケン', '本庄市', 'ホンジョウシ', '児玉町河内', 'コダマチョウコウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県本庄市児玉町太駄', '11', '11211', '3670254', '埼玉県', 'サイタマケン', '本庄市', 'ホンジョウシ', '児玉町太駄', 'コダマチョウオオダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県児玉郡神川町渡瀬', '11', '11383', '3670301', '埼玉県', 'サイタマケン', '児玉郡神川町', 'コダマグンカミカワマチ', '渡瀬', 'ワタルセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県児玉郡神川町下阿久原', '11', '11383', '3670311', '埼玉県', 'サイタマケン', '児玉郡神川町', 'コダマグンカミカワマチ', '下阿久原', 'シモアグハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県児玉郡神川町上阿久原', '11', '11383', '3670312', '埼玉県', 'サイタマケン', '児玉郡神川町', 'コダマグンカミカワマチ', '上阿久原', 'カミアグハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県児玉郡神川町矢納', '11', '11383', '3670313', '埼玉県', 'サイタマケン', '児玉郡神川町', 'コダマグンカミカワマチ', '矢納', 'ヤノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父市', '11', '11207', '3680000', '埼玉県', 'サイタマケン', '秩父市', 'チチブシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('29682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父郡横瀬町', '11', '11361', '3680000', '埼玉県', 'サイタマケン', '秩父郡横瀬町', 'チチブグンヨコゼマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('29683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父市黒谷', '11', '11207', '3680001', '埼玉県', 'サイタマケン', '秩父市', 'チチブシ', '黒谷', 'クロヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父市栃谷', '11', '11207', '3680002', '埼玉県', 'サイタマケン', '秩父市', 'チチブシ', '栃谷', 'トチヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父市定峰', '11', '11207', '3680003', '埼玉県', 'サイタマケン', '秩父市', 'チチブシ', '定峰', 'サダミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父市山田', '11', '11207', '3680004', '埼玉県', 'サイタマケン', '秩父市', 'チチブシ', '山田', 'ヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父市大野原', '11', '11207', '3680005', '埼玉県', 'サイタマケン', '秩父市', 'チチブシ', '大野原', 'オオノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市代官町', '02', '02202', '0368001', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '代官町', 'ダイカンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父市大畑町', '11', '11207', '3680011', '埼玉県', 'サイタマケン', '秩父市', 'チチブシ', '大畑町', 'オオバタケマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父市滝の上町', '11', '11207', '3680012', '埼玉県', 'サイタマケン', '秩父市', 'チチブシ', '滝の上町', 'タキノウエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父市永田町', '11', '11207', '3680013', '埼玉県', 'サイタマケン', '秩父市', 'チチブシ', '永田町', 'ナガタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父市金室町', '11', '11207', '3680014', '埼玉県', 'サイタマケン', '秩父市', 'チチブシ', '金室町', 'カナムロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父市柳田町', '11', '11207', '3680015', '埼玉県', 'サイタマケン', '秩父市', 'チチブシ', '柳田町', 'ヤナギダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父市阿保町', '11', '11207', '3680016', '埼玉県', 'サイタマケン', '秩父市', 'チチブシ', '阿保町', 'アボマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市駅前', '02', '02202', '0368002', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '駅前', 'エキマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父市下宮地町', '11', '11207', '3680021', '埼玉県', 'サイタマケン', '秩父市', 'チチブシ', '下宮地町', 'シモミヤジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父市中宮地町', '11', '11207', '3680022', '埼玉県', 'サイタマケン', '秩父市', 'チチブシ', '中宮地町', 'ナカミヤジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父市大宮', '11', '11207', '3680023', '埼玉県', 'サイタマケン', '秩父市', 'チチブシ', '大宮', 'オオミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父市上宮地町', '11', '11207', '3680024', '埼玉県', 'サイタマケン', '秩父市', 'チチブシ', '上宮地町', 'カミミヤジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父市桜木町', '11', '11207', '3680025', '埼玉県', 'サイタマケン', '秩父市', 'チチブシ', '桜木町', 'サクラギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父市相生町', '11', '11207', '3680026', '埼玉県', 'サイタマケン', '秩父市', 'チチブシ', '相生町', 'アイオイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市駅前町', '02', '02202', '0368003', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '駅前町', 'エキマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父市上野町', '11', '11207', '3680031', '埼玉県', 'サイタマケン', '秩父市', 'チチブシ', '上野町', 'ウエノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父市熊木町', '11', '11207', '3680032', '埼玉県', 'サイタマケン', '秩父市', 'チチブシ', '熊木町', 'クマギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父市野坂町', '11', '11207', '3680033', '埼玉県', 'サイタマケン', '秩父市', 'チチブシ', '野坂町', 'ノサカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父市日野田町', '11', '11207', '3680034', '埼玉県', 'サイタマケン', '秩父市', 'チチブシ', '日野田町', 'ヒノダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父市上町', '11', '11207', '3680035', '埼玉県', 'サイタマケン', '秩父市', 'チチブシ', '上町', 'カミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市大町', '02', '02202', '0368004', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '大町', 'オオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父市番場町', '11', '11207', '3680041', '埼玉県', 'サイタマケン', '秩父市', 'チチブシ', '番場町', 'バンバマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父市東町', '11', '11207', '3680042', '埼玉県', 'サイタマケン', '秩父市', 'チチブシ', '東町', 'ヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父市中町', '11', '11207', '3680043', '埼玉県', 'サイタマケン', '秩父市', 'チチブシ', '中町', 'ナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父市本町', '11', '11207', '3680044', '埼玉県', 'サイタマケン', '秩父市', 'チチブシ', '本町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父市道生町', '11', '11207', '3680045', '埼玉県', 'サイタマケン', '秩父市', 'チチブシ', '道生町', 'ドウジョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父市宮側町', '11', '11207', '3680046', '埼玉県', 'サイタマケン', '秩父市', 'チチブシ', '宮側町', 'ミヤカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市楮町', '02', '02202', '0368005', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '楮町', 'コウジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父市中村町', '11', '11207', '3680051', '埼玉県', 'サイタマケン', '秩父市', 'チチブシ', '中村町', 'ナカムラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父市近戸町', '11', '11207', '3680052', '埼玉県', 'サイタマケン', '秩父市', 'チチブシ', '近戸町', 'チカトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父市久那', '11', '11207', '3680053', '埼玉県', 'サイタマケン', '秩父市', 'チチブシ', '久那', 'クナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父市別所', '11', '11207', '3680054', '埼玉県', 'サイタマケン', '秩父市', 'チチブシ', '別所', 'ベッショ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父市田村', '11', '11207', '3680055', '埼玉県', 'サイタマケン', '秩父市', 'チチブシ', '田村', 'タムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父市寺尾', '11', '11207', '3680056', '埼玉県', 'サイタマケン', '秩父市', 'チチブシ', '寺尾', 'テラオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市南大町', '02', '02202', '0368006', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '南大町', 'ミナミオオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父市小柱', '11', '11207', '3680061', '埼玉県', 'サイタマケン', '秩父市', 'チチブシ', '小柱', 'オバシラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父市蒔田', '11', '11207', '3680062', '埼玉県', 'サイタマケン', '秩父市', 'チチブシ', '蒔田', 'マイタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父市伊古田', '11', '11207', '3680063', '埼玉県', 'サイタマケン', '秩父市', 'チチブシ', '伊古田', 'イコタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父市品沢', '11', '11207', '3680064', '埼玉県', 'サイタマケン', '秩父市', 'チチブシ', '品沢', 'シナザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父市太田', '11', '11207', '3680065', '埼玉県', 'サイタマケン', '秩父市', 'チチブシ', '太田', 'オオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父市堀切', '11', '11207', '3680066', '埼玉県', 'サイタマケン', '秩父市', 'チチブシ', '堀切', 'ホリキリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父市みどりが丘', '11', '11207', '3680067', '埼玉県', 'サイタマケン', '秩父市', 'チチブシ', 'みどりが丘', 'ミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父郡横瀬町芦ケ久保', '11', '11361', '3680071', '埼玉県', 'サイタマケン', '秩父郡横瀬町', 'チチブグンヨコゼマチ', '芦ケ久保', 'アシガクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父郡横瀬町横瀬', '11', '11361', '3680072', '埼玉県', 'サイタマケン', '秩父郡横瀬町', 'チチブグンヨコゼマチ', '横瀬', 'ヨコゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父郡小鹿野町', '11', '11365', '3680100', '埼玉県', 'サイタマケン', '秩父郡小鹿野町', 'チチブグンオガノマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('29733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父郡小鹿野町下小鹿野', '11', '11365', '3680101', '埼玉県', 'サイタマケン', '秩父郡小鹿野町', 'チチブグンオガノマチ', '下小鹿野', 'シモオガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父郡小鹿野町長留', '11', '11365', '3680102', '埼玉県', 'サイタマケン', '秩父郡小鹿野町', 'チチブグンオガノマチ', '長留', 'ナガル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父郡小鹿野町般若', '11', '11365', '3680103', '埼玉県', 'サイタマケン', '秩父郡小鹿野町', 'チチブグンオガノマチ', '般若', 'ハンニャ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父郡小鹿野町伊豆沢', '11', '11365', '3680104', '埼玉県', 'サイタマケン', '秩父郡小鹿野町', 'チチブグンオガノマチ', '伊豆沢', 'イズサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父郡小鹿野町小鹿野', '11', '11365', '3680105', '埼玉県', 'サイタマケン', '秩父郡小鹿野町', 'チチブグンオガノマチ', '小鹿野', 'オガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市山下町', '02', '02202', '0368011', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '山下町', 'ヤマシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父郡小鹿野町飯田', '11', '11365', '3680111', '埼玉県', 'サイタマケン', '秩父郡小鹿野町', 'チチブグンオガノマチ', '飯田', 'イイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父郡小鹿野町三山', '11', '11365', '3680112', '埼玉県', 'サイタマケン', '秩父郡小鹿野町', 'チチブグンオガノマチ', '三山', 'サンヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父郡小鹿野町河原沢', '11', '11365', '3680113', '埼玉県', 'サイタマケン', '秩父郡小鹿野町', 'チチブグンオガノマチ', '河原沢', 'カワラサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父郡小鹿野町藤倉', '11', '11365', '3680114', '埼玉県', 'サイタマケン', '秩父郡小鹿野町', 'チチブグンオガノマチ', '藤倉', 'フジクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父郡小鹿野町日尾', '11', '11365', '3680115', '埼玉県', 'サイタマケン', '秩父郡小鹿野町', 'チチブグンオガノマチ', '日尾', 'ヒオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市北瓦ケ町', '02', '02202', '0368012', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '北瓦ケ町', 'キタカワラケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市上瓦ケ町', '02', '02202', '0368013', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '上瓦ケ町', 'カミカワラケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市南瓦ケ町', '02', '02202', '0368014', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '南瓦ケ町', 'ミナミカワラケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市中瓦ケ町', '02', '02202', '0368015', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '中瓦ケ町', 'ナカカワラケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市坂本町', '02', '02202', '0368016', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '坂本町', 'サカモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市西川岸町', '02', '02202', '0368017', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '西川岸町', 'ニシカワギシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市田代町', '02', '02202', '0368018', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '田代町', 'タシロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父郡小鹿野町両神薄', '11', '11365', '3680201', '埼玉県', 'サイタマケン', '秩父郡小鹿野町', 'チチブグンオガノマチ', '両神薄', 'リョウカミススキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父郡小鹿野町両神小森', '11', '11365', '3680202', '埼玉県', 'サイタマケン', '秩父郡小鹿野町', 'チチブグンオガノマチ', '両神小森', 'リョウカミコモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市和徳町', '02', '02202', '0368021', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '和徳町', 'ワトクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市萱町', '02', '02202', '0368022', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '萱町', 'カヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市植田町', '02', '02202', '0368023', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '植田町', 'ウエダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市緑町', '02', '02202', '0368024', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '緑町', 'ミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市南柳町', '02', '02202', '0368025', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '南柳町', 'ミナミヤナギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市南横町', '02', '02202', '0368026', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '南横町', 'ミナミヨコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市北柳町', '02', '02202', '0368031', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '北柳町', 'キタヤナギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市徳田町', '02', '02202', '0368032', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '徳田町', 'トクダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市徒町川端町', '02', '02202', '0368033', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '徒町川端町', 'オカチマチカワバタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市徒町', '02', '02202', '0368034', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '徒町', 'オカチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市百石町', '02', '02202', '0368035', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '百石町', 'ヒャッコクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市鉄砲町', '02', '02202', '0368036', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '鉄砲町', 'テッポウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市俵元', '02', '02202', '0368041', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '俵元', 'タワラモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市松ケ枝', '02', '02202', '0368042', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '松ケ枝', 'マツガエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市東和徳町', '02', '02202', '0368043', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '東和徳町', 'ヒガシワトクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市茶畑町', '02', '02202', '0368044', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '茶畑町', 'チャバタケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市野田', '02', '02202', '0368045', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '野田', 'ノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市北横町', '02', '02202', '0368046', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '北横町', 'キタヨコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市宮川', '02', '02202', '0368051', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '宮川', 'ミヤカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市堅田', '02', '02202', '0368052', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '堅田', 'カタダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市和泉', '02', '02202', '0368053', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '和泉', 'ワイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市田町', '02', '02202', '0368054', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '田町', 'タマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市田茂木町', '02', '02202', '0368055', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '田茂木町', 'タモギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市禰宜町', '02', '02202', '0368056', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '禰宜町', 'ネギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市八幡町', '02', '02202', '0368057', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '八幡町', 'ハチマンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市神田', '02', '02202', '0368061', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '神田', 'カンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市青山', '02', '02202', '0368062', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '青山', 'アオヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市宮園', '02', '02202', '0368063', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '宮園', 'ミヤゾノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市東城北', '02', '02202', '0368064', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '東城北', 'ヒガシジョウホク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市西城北', '02', '02202', '0368065', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '西城北', 'ニシジョウホク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市向外瀬', '02', '02202', '0368066', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '向外瀬', 'ムカイトノセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市大久保', '02', '02202', '0368071', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '大久保', 'オオクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市清野袋', '02', '02202', '0368072', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '清野袋', 'セイノフクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市岩賀', '02', '02202', '0368073', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '岩賀', 'イワカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市津賀野瀬ノ上', '02', '02202', '0368074', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '津賀野', 'ツカノ', null, null, '瀬ノ上', 'セノウエ');
INSERT INTO `ms_addresses` VALUES ('29792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市撫牛子', '02', '02202', '0368075', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '撫牛子', 'ナイジョウシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市境関', '02', '02202', '0368076', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '境関', 'サカイゼキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市福田', '02', '02202', '0368081', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '福田', 'フクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市福村', '02', '02202', '0368082', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '福村', 'フクムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市新里', '02', '02202', '0368083', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '新里', 'ニサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市高田', '02', '02202', '0368084', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '高田', 'タカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市末広', '02', '02202', '0368085', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '末広', 'スエヒロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市田園', '02', '02202', '0368086', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '田園', 'デンエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市早稲田', '02', '02202', '0368087', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '早稲田', 'ワセダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市高崎', '02', '02202', '0368091', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '高崎', 'タカサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市城東北', '02', '02202', '0368092', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '城東北', 'ジョウトウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市城東中央', '02', '02202', '0368093', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '城東中央', 'ジョウトウチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市外崎', '02', '02202', '0368094', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '外崎', 'トノサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市城東', '02', '02202', '0368095', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '城東', 'ジョウトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市表町', '02', '02202', '0368096', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '表町', 'オモテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市稲田', '02', '02202', '0368097', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '稲田', 'イナダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市豊田', '02', '02202', '0368101', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '豊田', 'トヨダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市小比内', '02', '02202', '0368102', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '小比内', 'サンピナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市川先', '02', '02202', '0368103', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '川先', 'カワサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市扇町', '02', '02202', '0368104', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '扇町', 'オウギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市門外', '02', '02202', '0368111', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '門外', 'カドケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市堀越', '02', '02202', '0368112', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '堀越', 'ホリコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市清水森', '02', '02202', '0368113', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '清水森', 'シミズモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市川合', '02', '02202', '0368114', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '川合', 'カワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市広野', '02', '02202', '0368115', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '広野', 'ヒロノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市薬師堂', '02', '02202', '0368121', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '薬師堂', 'ヤクシドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市乳井', '02', '02202', '0368122', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '乳井', 'ニュウイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市小金崎', '02', '02202', '0368123', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '小金崎', 'コガネザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市石川', '02', '02202', '0368124', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '石川', 'イシカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市大沢', '02', '02202', '0368125', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '大沢', 'オオサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市松木平', '02', '02202', '0368126', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '松木平', 'マツキタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市小栗山', '02', '02202', '0368127', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '小栗山', 'コグリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市千年', '02', '02202', '0368131', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '千年', 'チトセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市狼森', '02', '02202', '0368132', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '狼森', 'オイノモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市大和沢', '02', '02202', '0368133', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '大和沢', 'オオワサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市一野渡', '02', '02202', '0368134', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '一野渡', 'イチノワタリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市松原東', '02', '02202', '0368141', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '松原東', 'マツバラヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市松原西', '02', '02202', '0368142', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '松原西', 'マツバラニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市富士見台', '02', '02202', '0368143', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '富士見台', 'フジミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市原ケ平', '02', '02202', '0368144', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '原ケ平', 'ハラガタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市北園', '02', '02202', '0368151', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '北園', 'キタゾノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市学園町', '02', '02202', '0368152', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '学園町', 'ガクエンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市三岳町', '02', '02202', '0368153', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '三岳町', 'ミタケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市豊原', '02', '02202', '0368154', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '豊原', 'トヨハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市中野', '02', '02202', '0368155', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '中野', 'ナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市大清水', '02', '02202', '0368161', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '大清水', 'オオシミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市安原', '02', '02202', '0368162', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '安原', 'ヤスハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市清原', '02', '02202', '0368163', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '清原', 'キヨハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市泉野', '02', '02202', '0368164', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '泉野', 'イズミノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市取上', '02', '02202', '0368171', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '取上', 'トリアゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市南富田町', '02', '02202', '0368172', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '南富田町', 'ミナミトミタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市富田町', '02', '02202', '0368173', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '富田町', 'トミタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市富野町', '02', '02202', '0368174', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '富野町', 'トミノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市大富町', '02', '02202', '0368175', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '大富町', 'オオトミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市山道町', '02', '02202', '0368181', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '山道町', 'ヤマミチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市土手町', '02', '02202', '0368182', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '土手町', 'ドテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市品川町', '02', '02202', '0368183', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '品川町', 'シナカワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市松森町', '02', '02202', '0368184', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '松森町', 'マツモリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市御幸町', '02', '02202', '0368185', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '御幸町', 'ミユキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市富田', '02', '02202', '0368186', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '富田', 'トミタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市住吉町', '02', '02202', '0368187', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '住吉町', 'スミヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市吉野町', '02', '02202', '0368188', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '吉野町', 'ヨシノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市親方町', '02', '02202', '0368191', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '親方町', 'オヤカタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市鍛冶町', '02', '02202', '0368192', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '鍛冶町', 'カジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市新鍛冶町', '02', '02202', '0368193', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '新鍛冶町', 'シンカジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市北川端町', '02', '02202', '0368194', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '北川端町', 'キタカワバタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市南川端町', '02', '02202', '0368195', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '南川端町', 'ミナミカワバタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市銅屋町', '02', '02202', '0368196', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '銅屋町', 'ドウヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市桶屋町', '02', '02202', '0368197', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '桶屋町', 'オケヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市元長町', '02', '02202', '0368198', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '元長町', 'モトナガマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市一番町', '02', '02202', '0368201', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '一番町', 'イチバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市元大工町', '02', '02202', '0368202', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '元大工町', 'モトダイクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市本町', '02', '02202', '0368203', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市覚仙町', '02', '02202', '0368204', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '覚仙町', 'カクセンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市森町', '02', '02202', '0368205', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '森町', 'モリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市塩分町', '02', '02202', '0368206', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '塩分町', 'シオワケマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市上白銀町', '02', '02202', '0368207', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '上白銀町', 'カミシロガネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市相良町', '02', '02202', '0368211', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '相良町', 'サガラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市南塘町', '02', '02202', '0368212', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '南塘町', 'ナントウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市北新寺町', '02', '02202', '0368213', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '北新寺町', 'キタシンテラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市新寺町', '02', '02202', '0368214', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '新寺町', 'シンテラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市新寺町新割町', '02', '02202', '0368215', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '新寺町新割町', 'シンテラマチシンワリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市在府町', '02', '02202', '0368216', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '在府町', 'ザイフチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市茂森町', '02', '02202', '0368217', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '茂森町', 'シゲモリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市紙漉町', '02', '02202', '0368221', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '紙漉町', 'カミスキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市桜林町', '02', '02202', '0368222', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '桜林町', 'サクラバヤシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市富士見町', '02', '02202', '0368223', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '富士見町', 'フジミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市文京町', '02', '02202', '0368224', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '文京町', 'ブンキョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市西ケ丘町', '02', '02202', '0368225', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '西ケ丘町', 'ニシガオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市寒沢町', '02', '02202', '0368226', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '寒沢町', 'カンザワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市桔梗野', '02', '02202', '0368227', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '桔梗野', 'キキョウノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市樹木', '02', '02202', '0368228', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '樹木', 'ジュモク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市稔町', '02', '02202', '0368231', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '稔町', 'ミノリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市城南', '02', '02202', '0368232', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '城南', 'ジョウナン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市山崎', '02', '02202', '0368233', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '山崎', 'ヤマザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市館野', '02', '02202', '0368234', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '館野', 'タテノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市桜ケ丘', '02', '02202', '0368241', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '桜ケ丘', 'サクラガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市大原', '02', '02202', '0368242', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '大原', 'オオハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市小沢', '02', '02202', '0368243', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '小沢', 'コザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市坂元', '02', '02202', '0368244', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '坂元', 'サカモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市金属町', '02', '02202', '0368245', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '金属町', 'キンゾクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市青樹町', '02', '02202', '0368246', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '青樹町', 'アオキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市大開', '02', '02202', '0368247', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '大開', 'オオビラキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市清富町', '02', '02202', '0368251', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '清富町', 'キヨトミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市旭ケ丘', '02', '02202', '0368252', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '旭ケ丘', 'アサヒガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市緑ケ丘', '02', '02202', '0368253', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '緑ケ丘', 'ミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市清水', '02', '02202', '0368254', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '清水', 'シミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市若葉', '02', '02202', '0368255', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '若葉', 'ワカバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市茂森新町', '02', '02202', '0368261', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '茂森新町', 'シゲモリシンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市清水富田', '02', '02202', '0368262', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '清水富田', 'シミズトミタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市常盤坂', '02', '02202', '0368263', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '常盤坂', 'トキワザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市悪戸', '02', '02202', '0368264', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '悪戸', 'アクド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市下湯口', '02', '02202', '0368265', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '下湯口', 'シモユグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市自由ケ丘', '02', '02202', '0368266', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '自由ケ丘', 'ジユウガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市鷹匠町', '02', '02202', '0368271', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '鷹匠町', 'タカジョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市南袋町', '02', '02202', '0368272', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '南袋町', 'ミナミフクロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市西茂森', '02', '02202', '0368273', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '西茂森', 'ニシシゲモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市南城西', '02', '02202', '0368274', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '南城西', 'ミナミジョウセイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市城西', '02', '02202', '0368275', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '城西', 'ジョウセイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市樋の口町', '02', '02202', '0368276', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '樋の口町', 'ヒノクチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市河原町', '02', '02202', '0368277', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '河原町', 'カワハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市樋の口', '02', '02202', '0368278', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '樋の口', 'ヒノクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市茜町', '02', '02202', '0368279', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '茜町', 'アカネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市糠坪', '02', '02202', '0368301', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '糠坪', 'ヌカツボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市高杉', '02', '02202', '0368302', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '高杉', 'タカスギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市前坂', '02', '02202', '0368303', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '前坂', 'マエザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市大川', '02', '02202', '0368311', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '大川', 'オオカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市三世寺', '02', '02202', '0368312', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '三世寺', 'サンゼジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市中崎', '02', '02202', '0368313', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '中崎', 'ナカザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市町田', '02', '02202', '0368314', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '町田', 'マチダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市船水', '02', '02202', '0368315', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '船水', 'フナミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市石渡', '02', '02202', '0368316', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '石渡', 'イシワタリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市外瀬', '02', '02202', '0368317', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '外瀬', 'トノセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市八代町', '02', '02202', '0368318', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '八代町', 'ヤシロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市藤内町', '02', '02202', '0368319', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '藤内町', 'トウナイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市萢中', '02', '02202', '0368321', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '萢中', 'ヤチナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市浜の町東', '02', '02202', '0368323', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '浜の町東', 'ハマノマチヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市浜の町西', '02', '02202', '0368324', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '浜の町西', 'ハマノマチニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市浜の町北', '02', '02202', '0368325', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '浜の町北', 'ハマノマチキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市藤野', '02', '02202', '0368326', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '藤野', 'フジノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市小人町', '02', '02202', '0368331', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '小人町', 'コビトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市亀甲町', '02', '02202', '0368332', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '亀甲町', 'カメノコウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市若党町', '02', '02202', '0368333', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '若党町', 'ワカドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市馬喰町', '02', '02202', '0368334', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '馬喰町', 'バクロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市春日町', '02', '02202', '0368335', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '春日町', 'カスガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市栄町', '02', '02202', '0368336', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市山王町', '02', '02202', '0368341', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '山王町', 'サンノウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市笹森町', '02', '02202', '0368342', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '笹森町', 'ササモリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市東長町', '02', '02202', '0368343', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '東長町', 'ヒガシナガマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市長坂町', '02', '02202', '0368344', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '長坂町', 'ナガサカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市蔵主町', '02', '02202', '0368345', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '蔵主町', 'クラヌシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市大浦町', '02', '02202', '0368346', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '大浦町', 'オオウラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市百石町小路', '02', '02202', '0368351', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '百石町小路', 'ヒャッコクマチコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市元寺町小路', '02', '02202', '0368352', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '元寺町小路', 'モトテラマチコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市下鞘師町', '02', '02202', '0368353', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '下鞘師町', 'シモサヤシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市上鞘師町', '02', '02202', '0368354', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '上鞘師町', 'カミサヤシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市元寺町', '02', '02202', '0368355', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '元寺町', 'モトテラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市下白銀町', '02', '02202', '0368356', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '下白銀町', 'シモシロガネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市馬屋町', '02', '02202', '0368357', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '馬屋町', 'マヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市紺屋町', '02', '02202', '0368361', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '紺屋町', 'コンヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市五十石町', '02', '02202', '0368362', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '五十石町', 'ゴジツコクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市袋町', '02', '02202', '0368363', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '袋町', 'フクロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市新町', '02', '02202', '0368364', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '新町', 'アラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市西大工町', '02', '02202', '0368365', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '西大工町', 'ニシダイクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市駒越町', '02', '02202', '0368366', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '駒越町', 'コマゴシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市平岡町', '02', '02202', '0368367', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '平岡町', 'ヒラオカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市和田町', '02', '02202', '0368368', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '和田町', 'ワダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市蒔苗', '02', '02202', '0368371', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '蒔苗', 'マカナエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市元薬師堂', '02', '02202', '0368372', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '元薬師堂', 'モトヤクシドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市藤代', '02', '02202', '0368373', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '藤代', 'フジシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市土堂', '02', '02202', '0368374', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '土堂', 'ツチドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市細越', '02', '02202', '0368375', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '細越', 'ホソゴエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市独狐', '02', '02202', '0368381', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '独狐', 'トッコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市富栄', '02', '02202', '0368382', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '富栄', 'トミサカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市折笠', '02', '02202', '0368383', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '折笠', 'オリカサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市宮舘', '02', '02202', '0368384', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '宮舘', 'ミヤダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('29968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市中別所', '02', '02202', '0368385', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '中別所', 'ナカベッシヨ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市津田', '11', '11202', '3690101', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '津田', 'ツダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市玉作', '11', '11202', '3690102', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '玉作', 'タマツクリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市小八林', '11', '11202', '3690103', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '小八林', 'コヤツバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市冑山', '11', '11202', '3690104', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '冑山', 'カブトヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市箕輪', '11', '11202', '3690105', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '箕輪', 'ミノワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市相上', '11', '11202', '3690106', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '相上', 'アイアゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市向谷', '11', '11202', '3690107', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '向谷', 'ムコウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県熊谷市船木台', '11', '11202', '3690108', '埼玉県', 'サイタマケン', '熊谷市', 'クマガヤシ', '船木台', 'フナキダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鴻巣市新宿', '11', '11217', '3690111', '埼玉県', 'サイタマケン', '鴻巣市', 'コウノスシ', '新宿', 'シンシュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鴻巣市鎌塚', '11', '11217', '3690112', '埼玉県', 'サイタマケン', '鴻巣市', 'コウノスシ', '鎌塚', 'カマツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鴻巣市下忍', '11', '11217', '3690113', '埼玉県', 'サイタマケン', '鴻巣市', 'コウノスシ', '下忍', 'シモオシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鴻巣市筑波', '11', '11217', '3690114', '埼玉県', 'サイタマケン', '鴻巣市', 'コウノスシ', '筑波', 'ツクバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鴻巣市吹上本町', '11', '11217', '3690115', '埼玉県', 'サイタマケン', '鴻巣市', 'コウノスシ', '吹上本町', 'フキアゲホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鴻巣市北新宿', '11', '11217', '3690116', '埼玉県', 'サイタマケン', '鴻巣市', 'コウノスシ', '北新宿', 'キタシンシュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鴻巣市吹上富士見', '11', '11217', '3690121', '埼玉県', 'サイタマケン', '鴻巣市', 'コウノスシ', '吹上富士見', 'フキアゲフジミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鴻巣市南', '11', '11217', '3690122', '埼玉県', 'サイタマケン', '鴻巣市', 'コウノスシ', '南', 'ミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鴻巣市榎戸', '11', '11217', '3690123', '埼玉県', 'サイタマケン', '鴻巣市', 'コウノスシ', '榎戸', 'エノキド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鴻巣市荊原', '11', '11217', '3690124', '埼玉県', 'サイタマケン', '鴻巣市', 'コウノスシ', '荊原', 'バラハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鴻巣市袋', '11', '11217', '3690131', '埼玉県', 'サイタマケン', '鴻巣市', 'コウノスシ', '袋', 'フクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鴻巣市前砂', '11', '11217', '3690132', '埼玉県', 'サイタマケン', '鴻巣市', 'コウノスシ', '前砂', 'マエスナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鴻巣市小谷', '11', '11217', '3690133', '埼玉県', 'サイタマケン', '鴻巣市', 'コウノスシ', '小谷', 'コヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鴻巣市三町免', '11', '11217', '3690134', '埼玉県', 'サイタマケン', '鴻巣市', 'コウノスシ', '三町免', 'サンチョウメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鴻巣市明用', '11', '11217', '3690135', '埼玉県', 'サイタマケン', '鴻巣市', 'コウノスシ', '明用', 'ミョウヨウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鴻巣市吹上', '11', '11217', '3690136', '埼玉県', 'サイタマケン', '鴻巣市', 'コウノスシ', '吹上', 'フキアゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県鴻巣市大芦', '11', '11217', '3690137', '埼玉県', 'サイタマケン', '鴻巣市', 'コウノスシ', '大芦', 'オオアシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県深谷市岡', '11', '11218', '3690201', '埼玉県', 'サイタマケン', '深谷市', 'フカヤシ', '岡', 'オカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県深谷市岡里', '11', '11218', '3690202', '埼玉県', 'サイタマケン', '深谷市', 'フカヤシ', '岡里', 'オカザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県深谷市普済寺', '11', '11218', '3690203', '埼玉県', 'サイタマケン', '深谷市', 'フカヤシ', '普済寺', 'フサイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県深谷市岡部', '11', '11218', '3690211', '埼玉県', 'サイタマケン', '深谷市', 'フカヤシ', '岡部', 'オカベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県深谷市櫛挽', '11', '11218', '3690212', '埼玉県', 'サイタマケン', '深谷市', 'フカヤシ', '櫛挽', 'クシビキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県深谷市針ケ谷', '11', '11218', '3690213', '埼玉県', 'サイタマケン', '深谷市', 'フカヤシ', '針ケ谷', 'ハリガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県深谷市本郷', '11', '11218', '3690214', '埼玉県', 'サイタマケン', '深谷市', 'フカヤシ', '本郷', 'ホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県深谷市今泉', '11', '11218', '3690215', '埼玉県', 'サイタマケン', '深谷市', 'フカヤシ', '今泉', 'イマイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県深谷市山崎', '11', '11218', '3690216', '埼玉県', 'サイタマケン', '深谷市', 'フカヤシ', '山崎', 'ヤマザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県深谷市山河', '11', '11218', '3690217', '埼玉県', 'サイタマケン', '深谷市', 'フカヤシ', '山河', 'ヤマガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県深谷市榛沢新田', '11', '11218', '3690221', '埼玉県', 'サイタマケン', '深谷市', 'フカヤシ', '榛沢新田', 'ハンサワシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県深谷市後榛沢', '11', '11218', '3690222', '埼玉県', 'サイタマケン', '深谷市', 'フカヤシ', '後榛沢', 'ウシロハンザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県深谷市榛沢', '11', '11218', '3690223', '埼玉県', 'サイタマケン', '深谷市', 'フカヤシ', '榛沢', 'ハンザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県深谷市西田', '11', '11218', '3690224', '埼玉県', 'サイタマケン', '深谷市', 'フカヤシ', '西田', 'ニシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県深谷市沓掛', '11', '11218', '3690225', '埼玉県', 'サイタマケン', '深谷市', 'フカヤシ', '沓掛', 'クツカケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県児玉郡上里町', '11', '11385', '3690300', '埼玉県', 'サイタマケン', '児玉郡上里町', 'コダマグンカミサトマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('30062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県児玉郡上里町金久保', '11', '11385', '3690301', '埼玉県', 'サイタマケン', '児玉郡上里町', 'コダマグンカミサトマチ', '金久保', 'カナクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県児玉郡上里町黛', '11', '11385', '3690302', '埼玉県', 'サイタマケン', '児玉郡上里町', 'コダマグンカミサトマチ', '黛', 'マユズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県児玉郡上里町忍保', '11', '11385', '3690303', '埼玉県', 'サイタマケン', '児玉郡上里町', 'コダマグンカミサトマチ', '忍保', 'オシボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県児玉郡上里町八町河原', '11', '11385', '3690304', '埼玉県', 'サイタマケン', '児玉郡上里町', 'コダマグンカミサトマチ', '八町河原', 'ハッチョウガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県児玉郡上里町神保原町', '11', '11385', '3690305', '埼玉県', 'サイタマケン', '児玉郡上里町', 'コダマグンカミサトマチ', '神保原町', 'ジンボハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県児玉郡上里町七本木', '11', '11385', '3690306', '埼玉県', 'サイタマケン', '児玉郡上里町', 'コダマグンカミサトマチ', '七本木', 'シチホンギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県児玉郡上里町嘉美', '11', '11385', '3690307', '埼玉県', 'サイタマケン', '児玉郡上里町', 'コダマグンカミサトマチ', '嘉美', 'カミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県児玉郡上里町毘沙吐', '11', '11385', '3690308', '埼玉県', 'サイタマケン', '児玉郡上里町', 'コダマグンカミサトマチ', '毘沙吐', 'ビシャド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県児玉郡上里町勅使河原', '11', '11385', '3690311', '埼玉県', 'サイタマケン', '児玉郡上里町', 'コダマグンカミサトマチ', '勅使河原', 'テシガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県児玉郡上里町帯刀', '11', '11385', '3690312', '埼玉県', 'サイタマケン', '児玉郡上里町', 'コダマグンカミサトマチ', '帯刀', 'タテワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県児玉郡上里町堤', '11', '11385', '3690313', '埼玉県', 'サイタマケン', '児玉郡上里町', 'コダマグンカミサトマチ', '堤', 'ツツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県児玉郡上里町三町', '11', '11385', '3690314', '埼玉県', 'サイタマケン', '児玉郡上里町', 'コダマグンカミサトマチ', '三町', 'ミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県児玉郡上里町大御堂', '11', '11385', '3690315', '埼玉県', 'サイタマケン', '児玉郡上里町', 'コダマグンカミサトマチ', '大御堂', 'オオミドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県児玉郡上里町長浜', '11', '11385', '3690316', '埼玉県', 'サイタマケン', '児玉郡上里町', 'コダマグンカミサトマチ', '長浜', 'ナガハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県児玉郡上里町五明', '11', '11385', '3690317', '埼玉県', 'サイタマケン', '児玉郡上里町', 'コダマグンカミサトマチ', '五明', 'ゴミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県児玉郡上里町藤木戸', '11', '11385', '3690318', '埼玉県', 'サイタマケン', '児玉郡上里町', 'コダマグンカミサトマチ', '藤木戸', 'フジキド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県深谷市長在家', '11', '11218', '3691101', '埼玉県', 'サイタマケン', '深谷市', 'フカヤシ', '長在家', 'ナガザイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県深谷市瀬山', '11', '11218', '3691102', '埼玉県', 'サイタマケン', '深谷市', 'フカヤシ', '瀬山', 'セヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県深谷市川本明戸', '11', '11218', '3691103', '埼玉県', 'サイタマケン', '深谷市', 'フカヤシ', '川本明戸', 'カワモトアケト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県深谷市菅沼', '11', '11218', '3691104', '埼玉県', 'サイタマケン', '深谷市', 'フカヤシ', '菅沼', 'スガヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県深谷市本田', '11', '11218', '3691105', '埼玉県', 'サイタマケン', '深谷市', 'フカヤシ', '本田', 'ホンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県深谷市白草台', '11', '11218', '3691106', '埼玉県', 'サイタマケン', '深谷市', 'フカヤシ', '白草台', 'シラクサダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県深谷市畠山', '11', '11218', '3691107', '埼玉県', 'サイタマケン', '深谷市', 'フカヤシ', '畠山', 'ハタケヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県深谷市田中', '11', '11218', '3691108', '埼玉県', 'サイタマケン', '深谷市', 'フカヤシ', '田中', 'タナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県深谷市上原', '11', '11218', '3691109', '埼玉県', 'サイタマケン', '深谷市', 'フカヤシ', '上原', 'カミハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県大里郡寄居町', '11', '11408', '3691200', '埼玉県', 'サイタマケン', '大里郡寄居町', 'オオサトグンヨリイマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('30093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県大里郡寄居町用土', '11', '11408', '3691201', '埼玉県', 'サイタマケン', '大里郡寄居町', 'オオサトグンヨリイマチ', '用土', 'ヨウド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県大里郡寄居町桜沢', '11', '11408', '3691202', '埼玉県', 'サイタマケン', '大里郡寄居町', 'オオサトグンヨリイマチ', '桜沢', 'サクラザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県大里郡寄居町寄居', '11', '11408', '3691203', '埼玉県', 'サイタマケン', '大里郡寄居町', 'オオサトグンヨリイマチ', '寄居', 'ヨリイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県大里郡寄居町藤田', '11', '11408', '3691204', '埼玉県', 'サイタマケン', '大里郡寄居町', 'オオサトグンヨリイマチ', '藤田', 'フジタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県大里郡寄居町末野', '11', '11408', '3691205', '埼玉県', 'サイタマケン', '大里郡寄居町', 'オオサトグンヨリイマチ', '末野', 'スエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県大里郡寄居町赤浜', '11', '11408', '3691211', '埼玉県', 'サイタマケン', '大里郡寄居町', 'オオサトグンヨリイマチ', '赤浜', 'アカハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県大里郡寄居町西古里', '11', '11408', '3691212', '埼玉県', 'サイタマケン', '大里郡寄居町', 'オオサトグンヨリイマチ', '西古里', 'ニシフルサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県大里郡寄居町鷹巣', '11', '11408', '3691213', '埼玉県', 'サイタマケン', '大里郡寄居町', 'オオサトグンヨリイマチ', '鷹巣', 'タカノス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県大里郡寄居町今市', '11', '11408', '3691214', '埼玉県', 'サイタマケン', '大里郡寄居町', 'オオサトグンヨリイマチ', '今市', 'イマイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県大里郡寄居町牟礼', '11', '11408', '3691215', '埼玉県', 'サイタマケン', '大里郡寄居町', 'オオサトグンヨリイマチ', '牟礼', 'ムレイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県大里郡寄居町富田', '11', '11408', '3691216', '埼玉県', 'サイタマケン', '大里郡寄居町', 'オオサトグンヨリイマチ', '富田', 'トミダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県大里郡寄居町小園', '11', '11408', '3691217', '埼玉県', 'サイタマケン', '大里郡寄居町', 'オオサトグンヨリイマチ', '小園', 'コゾノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県大里郡寄居町保田原', '11', '11408', '3691221', '埼玉県', 'サイタマケン', '大里郡寄居町', 'オオサトグンヨリイマチ', '保田原', 'ホダワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県大里郡寄居町露梨子', '11', '11408', '3691222', '埼玉県', 'サイタマケン', '大里郡寄居町', 'オオサトグンヨリイマチ', '露梨子', 'ツユナシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県大里郡寄居町三ケ山', '11', '11408', '3691223', '埼玉県', 'サイタマケン', '大里郡寄居町', 'オオサトグンヨリイマチ', '三ケ山', 'ミカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県大里郡寄居町鉢形', '11', '11408', '3691224', '埼玉県', 'サイタマケン', '大里郡寄居町', 'オオサトグンヨリイマチ', '鉢形', 'ハチガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県大里郡寄居町西ノ入', '11', '11408', '3691225', '埼玉県', 'サイタマケン', '大里郡寄居町', 'オオサトグンヨリイマチ', '西ノ入', 'ニシノイリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県大里郡寄居町立原', '11', '11408', '3691231', '埼玉県', 'サイタマケン', '大里郡寄居町', 'オオサトグンヨリイマチ', '立原', 'タテハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県大里郡寄居町三品', '11', '11408', '3691232', '埼玉県', 'サイタマケン', '大里郡寄居町', 'オオサトグンヨリイマチ', '三品', 'ミシナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県大里郡寄居町秋山', '11', '11408', '3691233', '埼玉県', 'サイタマケン', '大里郡寄居町', 'オオサトグンヨリイマチ', '秋山', 'アキヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県大里郡寄居町折原', '11', '11408', '3691234', '埼玉県', 'サイタマケン', '大里郡寄居町', 'オオサトグンヨリイマチ', '折原', 'オリハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県大里郡寄居町風布', '11', '11408', '3691235', '埼玉県', 'サイタマケン', '大里郡寄居町', 'オオサトグンヨリイマチ', '風布', 'フウプ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県大里郡寄居町金尾', '11', '11408', '3691236', '埼玉県', 'サイタマケン', '大里郡寄居町', 'オオサトグンヨリイマチ', '金尾', 'カナオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県深谷市武蔵野', '11', '11218', '3691241', '埼玉県', 'サイタマケン', '深谷市', 'フカヤシ', '武蔵野', 'ムサシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県深谷市北根', '11', '11218', '3691242', '埼玉県', 'サイタマケン', '深谷市', 'フカヤシ', '北根', 'キタネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県深谷市永田', '11', '11218', '3691243', '埼玉県', 'サイタマケン', '深谷市', 'フカヤシ', '永田', 'ナガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県深谷市黒田', '11', '11218', '3691244', '埼玉県', 'サイタマケン', '深谷市', 'フカヤシ', '黒田', 'クロダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県深谷市荒川', '11', '11218', '3691245', '埼玉県', 'サイタマケン', '深谷市', 'フカヤシ', '荒川', 'アラカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県深谷市小前田', '11', '11218', '3691246', '埼玉県', 'サイタマケン', '深谷市', 'フカヤシ', '小前田', 'オマエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父郡長瀞町', '11', '11363', '3691300', '埼玉県', 'サイタマケン', '秩父郡長瀞町', 'チチブグンナガトロマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('30127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父郡長瀞町矢那瀬', '11', '11363', '3691301', '埼玉県', 'サイタマケン', '秩父郡長瀞町', 'チチブグンナガトロマチ', '矢那瀬', 'ヤナセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父郡長瀞町野上下郷', '11', '11363', '3691302', '埼玉県', 'サイタマケン', '秩父郡長瀞町', 'チチブグンナガトロマチ', '野上下郷', 'ノガミシモゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父郡長瀞町中野上', '11', '11363', '3691303', '埼玉県', 'サイタマケン', '秩父郡長瀞町', 'チチブグンナガトロマチ', '中野上', 'ナカノガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父郡長瀞町本野上', '11', '11363', '3691304', '埼玉県', 'サイタマケン', '秩父郡長瀞町', 'チチブグンナガトロマチ', '本野上', 'ホンノガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父郡長瀞町長瀞', '11', '11363', '3691305', '埼玉県', 'サイタマケン', '秩父郡長瀞町', 'チチブグンナガトロマチ', '長瀞', 'ナガトロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父郡長瀞町岩田', '11', '11363', '3691311', '埼玉県', 'サイタマケン', '秩父郡長瀞町', 'チチブグンナガトロマチ', '岩田', 'イワタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父郡長瀞町井戸', '11', '11363', '3691312', '埼玉県', 'サイタマケン', '秩父郡長瀞町', 'チチブグンナガトロマチ', '井戸', 'イド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父郡長瀞町風布', '11', '11363', '3691313', '埼玉県', 'サイタマケン', '秩父郡長瀞町', 'チチブグンナガトロマチ', '風布', 'フウプ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父郡皆野町', '11', '11362', '3691400', '埼玉県', 'サイタマケン', '秩父郡皆野町', 'チチブグンミナノマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('30137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父郡皆野町三沢', '11', '11362', '3691411', '埼玉県', 'サイタマケン', '秩父郡皆野町', 'チチブグンミナノマチ', '三沢', 'ミサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父郡皆野町皆野', '11', '11362', '3691412', '埼玉県', 'サイタマケン', '秩父郡皆野町', 'チチブグンミナノマチ', '皆野', 'ミナノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父郡皆野町下田野', '11', '11362', '3691413', '埼玉県', 'サイタマケン', '秩父郡皆野町', 'チチブグンミナノマチ', '下田野', 'シモタノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父市吉田久長', '11', '11207', '3691501', '埼玉県', 'サイタマケン', '秩父市', 'チチブシ', '吉田久長', 'ヨシダヒサナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父市吉田阿熊', '11', '11207', '3691502', '埼玉県', 'サイタマケン', '秩父市', 'チチブシ', '吉田阿熊', 'ヨシダアグマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父市下吉田', '11', '11207', '3691503', '埼玉県', 'サイタマケン', '秩父市', 'チチブシ', '下吉田', 'シモヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父市吉田石間', '11', '11207', '3691504', '埼玉県', 'サイタマケン', '秩父市', 'チチブシ', '吉田石間', 'ヨシダイサマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父市上吉田', '11', '11207', '3691505', '埼玉県', 'サイタマケン', '秩父市', 'チチブシ', '上吉田', 'カミヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父市吉田太田部', '11', '11207', '3691506', '埼玉県', 'サイタマケン', '秩父市', 'チチブシ', '吉田太田部', 'ヨシダオオタブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父郡皆野町金沢', '11', '11362', '3691601', '埼玉県', 'サイタマケン', '秩父郡皆野町', 'チチブグンミナノマチ', '金沢', 'カネザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父郡皆野町金崎', '11', '11362', '3691621', '埼玉県', 'サイタマケン', '秩父郡皆野町', 'チチブグンミナノマチ', '金崎', 'カナサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父郡皆野町国神', '11', '11362', '3691622', '埼玉県', 'サイタマケン', '秩父郡皆野町', 'チチブグンミナノマチ', '国神', 'クニカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父郡皆野町大淵', '11', '11362', '3691623', '埼玉県', 'サイタマケン', '秩父郡皆野町', 'チチブグンミナノマチ', '大淵', 'オオフチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父郡皆野町野巻', '11', '11362', '3691624', '埼玉県', 'サイタマケン', '秩父郡皆野町', 'チチブグンミナノマチ', '野巻', 'ノマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父郡皆野町下日野沢', '11', '11362', '3691625', '埼玉県', 'サイタマケン', '秩父郡皆野町', 'チチブグンミナノマチ', '下日野沢', 'シモヒノザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父郡皆野町上日野沢', '11', '11362', '3691626', '埼玉県', 'サイタマケン', '秩父郡皆野町', 'チチブグンミナノマチ', '上日野沢', 'カミヒノザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父市荒川久那', '11', '11207', '3691801', '埼玉県', 'サイタマケン', '秩父市', 'チチブシ', '荒川久那', 'アラカワクナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父市荒川上田野', '11', '11207', '3691802', '埼玉県', 'サイタマケン', '秩父市', 'チチブシ', '荒川上田野', 'アラカワカミタノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父市荒川日野', '11', '11207', '3691803', '埼玉県', 'サイタマケン', '秩父市', 'チチブシ', '荒川日野', 'アラカワヒノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父市荒川小野原', '11', '11207', '3691804', '埼玉県', 'サイタマケン', '秩父市', 'チチブシ', '荒川小野原', 'アラカワオノバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父市下影森', '11', '11207', '3691871', '埼玉県', 'サイタマケン', '秩父市', 'チチブシ', '下影森', 'シモカゲモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父市上影森', '11', '11207', '3691872', '埼玉県', 'サイタマケン', '秩父市', 'チチブシ', '上影森', 'カミカゲモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父市浦山', '11', '11207', '3691873', '埼玉県', 'サイタマケン', '秩父市', 'チチブシ', '浦山', 'ウラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父市和泉町', '11', '11207', '3691874', '埼玉県', 'サイタマケン', '秩父市', 'チチブシ', '和泉町', 'イズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父市大滝', '11', '11207', '3691901', '埼玉県', 'サイタマケン', '秩父市', 'チチブシ', '大滝', 'オオタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父市三峰', '11', '11207', '3691902', '埼玉県', 'サイタマケン', '秩父市', 'チチブシ', '三峰', 'ミツミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父市中津川', '11', '11207', '3691903', '埼玉県', 'サイタマケン', '秩父市', 'チチブシ', '中津川', 'ナカツガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父市荒川贄川', '11', '11207', '3691911', '埼玉県', 'サイタマケン', '秩父市', 'チチブシ', '荒川贄川', 'アラカワニエガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '埼玉県秩父市荒川白久', '11', '11207', '3691912', '埼玉県', 'サイタマケン', '秩父市', 'チチブシ', '荒川白久', 'アラカワシロク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県五所川原市', '02', '02205', '0370000', '青森県', 'アオモリケン', '五所川原市', 'ゴショガワラシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('30176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市', '10', '10202', '3700000', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('30177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市中尾町', '10', '10202', '3700001', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '中尾町', 'ナカオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市日高町', '10', '10202', '3700002', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '日高町', 'ヒダカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市新保田中町', '10', '10202', '3700003', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '新保田中町', 'シンボタナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市井野町', '10', '10202', '3700004', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '井野町', 'イノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市浜尻町', '10', '10202', '3700005', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '浜尻町', 'ハマジリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市問屋町', '10', '10202', '3700006', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '問屋町', 'トンヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市問屋町西', '10', '10202', '3700007', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '問屋町西', 'トンヤマチニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市正観寺町', '10', '10202', '3700008', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '正観寺町', 'ショウカンジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県五所川原市下岩崎', '02', '02205', '0370001', '青森県', 'アオモリケン', '五所川原市', 'ゴショガワラシ', '下岩崎', 'シモイワサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市京目町', '10', '10202', '3700011', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '京目町', 'キョウメマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市大沢町', '10', '10202', '3700012', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '大沢町', 'オオサワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市萩原町', '10', '10202', '3700013', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '萩原町', 'ハギワラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市元島名町', '10', '10202', '3700014', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '元島名町', 'モトシマナマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市島野町', '10', '10202', '3700015', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '島野町', 'シマノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市矢島町', '10', '10202', '3700016', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '矢島町', 'ヤジママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市西島町', '10', '10202', '3700017', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '西島町', 'ニシジママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市新保町', '10', '10202', '3700018', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '新保町', 'シンボマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県五所川原市飯詰', '02', '02205', '0370002', '青森県', 'アオモリケン', '五所川原市', 'ゴショガワラシ', '飯詰', 'イイヅメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市西横手町', '10', '10202', '3700021', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '西横手町', 'ニシヨコテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市宿横手町', '10', '10202', '3700022', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '宿横手町', 'シュクヨコテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市中島町', '10', '10202', '3700023', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '中島町', 'ナカジママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市八幡原町', '10', '10202', '3700024', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '八幡原町', 'ヤハタバラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市下斉田町', '10', '10202', '3700025', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '下斉田町', 'シモサイダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市下滝町', '10', '10202', '3700026', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '下滝町', 'シモタキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市上滝町', '10', '10202', '3700027', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '上滝町', 'カミタキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県五所川原市吹畑', '02', '02205', '0370003', '青森県', 'アオモリケン', '五所川原市', 'ゴショガワラシ', '吹畑', 'フキハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市上大類町', '10', '10202', '3700031', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '上大類町', 'カミオオルイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市宿大類町', '10', '10202', '3700032', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '宿大類町', 'シュクオオルイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市中大類町', '10', '10202', '3700033', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '中大類町', 'ナカオオルイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市下大類町', '10', '10202', '3700034', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '下大類町', 'シモオオルイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市柴崎町', '10', '10202', '3700035', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '柴崎町', 'シバサキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市南大類町', '10', '10202', '3700036', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '南大類町', 'ミナミオオルイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県五所川原市唐笠柳', '02', '02205', '0370004', '青森県', 'アオモリケン', '五所川原市', 'ゴショガワラシ', '唐笠柳', 'カラカサヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市東貝沢町', '10', '10202', '3700041', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '東貝沢町', 'ヒガシカイザワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市貝沢町', '10', '10202', '3700042', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '貝沢町', 'カイザワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市高関町', '10', '10202', '3700043', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '高関町', 'タカゼキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市岩押町', '10', '10202', '3700044', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '岩押町', 'イワオシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市東町', '10', '10202', '3700045', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '東町', 'アズマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市江木町', '10', '10202', '3700046', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '江木町', 'エギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市高砂町', '10', '10202', '3700047', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '高砂町', 'タカサゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市日光町', '10', '10202', '3700048', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '日光町', 'ニッコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県五所川原市石岡', '02', '02205', '0370005', '青森県', 'アオモリケン', '五所川原市', 'ゴショガワラシ', '石岡', 'イシオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市弓町', '10', '10202', '3700051', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '弓町', 'ユミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市旭町', '10', '10202', '3700052', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '旭町', 'アサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市通町', '10', '10202', '3700053', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '通町', 'トオリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市真町', '10', '10202', '3700054', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '真町', 'シンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市羅漢町', '10', '10202', '3700055', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '羅漢町', 'ラカンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市北通町', '10', '10202', '3700056', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '北通町', 'キタトオリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市元紺屋町', '10', '10202', '3700057', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '元紺屋町', 'モトコンヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市九蔵町', '10', '10202', '3700058', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '九蔵町', 'クゾウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市椿町', '10', '10202', '3700059', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '椿町', 'ツバキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県五所川原市松島町', '02', '02205', '0370006', '青森県', 'アオモリケン', '五所川原市', 'ゴショガワラシ', '松島町', 'マツシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市天神町', '10', '10202', '3700061', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '天神町', 'テンジンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市稲荷町', '10', '10202', '3700062', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '稲荷町', 'イナリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市飯玉町', '10', '10202', '3700063', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '飯玉町', 'イイダママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市芝塚町', '10', '10202', '3700064', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '芝塚町', 'シバヅカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市末広町', '10', '10202', '3700065', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '末広町', 'スエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市山田町', '10', '10202', '3700066', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '山田町', 'ヤマダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市請地町', '10', '10202', '3700067', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '請地町', 'ウケチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市昭和町', '10', '10202', '3700068', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '昭和町', 'ショウワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市飯塚町', '10', '10202', '3700069', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '飯塚町', 'イイヅカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市小八木町', '10', '10202', '3700071', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '小八木町', 'コヤギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市大八木町', '10', '10202', '3700072', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '大八木町', 'オオヤギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市緑町', '10', '10202', '3700073', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '緑町', 'ミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市下小鳥町', '10', '10202', '3700074', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '下小鳥町', 'シモコトリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市筑縄町', '10', '10202', '3700075', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '筑縄町', 'ツクナワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市下小塙町', '10', '10202', '3700076', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '下小塙町', 'シモコバナマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市上小塙町', '10', '10202', '3700077', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '上小塙町', 'カミコバナマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市上小鳥町', '10', '10202', '3700078', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '上小鳥町', 'カミコトリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市浜川町', '10', '10202', '3700081', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '浜川町', 'ハマガワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市北新波町', '10', '10202', '3700082', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '北新波町', 'キタアラナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市南新波町', '10', '10202', '3700083', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '南新波町', 'ミナミアラナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市菊地町', '10', '10202', '3700084', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '菊地町', 'キクジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市我峰町', '10', '10202', '3700085', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '我峰町', 'ワガミネマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市沖町', '10', '10202', '3700086', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '沖町', 'オキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市楽間町', '10', '10202', '3700087', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '楽間町', 'ラクママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市行力町', '10', '10202', '3700088', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '行力町', 'ギョウリキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市境東新井', '10', '10204', '3700101', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '境東新井', 'サカイヒガシアライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市境上渕名', '10', '10204', '3700102', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '境上渕名', 'サカイカミフチナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市境下渕名', '10', '10204', '3700103', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '境下渕名', 'サカイシモフチナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市境木島', '10', '10204', '3700104', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '境木島', 'サカイキジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市境伊与久', '10', '10204', '3700105', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '境伊与久', 'サカイイヨク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県五所川原市金山', '02', '02205', '0370011', '青森県', 'アオモリケン', '五所川原市', 'ゴショガワラシ', '金山', 'カネヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市境上矢島', '10', '10204', '3700111', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '境上矢島', 'サカイカミヤジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市境西今井', '10', '10204', '3700112', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '境西今井', 'サカイニシイマイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市境三ツ木', '10', '10204', '3700113', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '境三ツ木', 'サカイミツギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市境新栄', '10', '10204', '3700114', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '境新栄', 'サカイシンエイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市境美原', '10', '10204', '3700115', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '境美原', 'サカイミハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市境百々東', '10', '10204', '3700116', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '境百々東', 'サカイドウドウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市境百々', '10', '10204', '3700117', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '境百々', 'サカイドウドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県五所川原市水野尾', '02', '02205', '0370012', '青森県', 'アオモリケン', '五所川原市', 'ゴショガワラシ', '水野尾', 'ミズノオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市境女塚', '10', '10204', '3700121', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '境女塚', 'サカイオナヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市境栄', '10', '10204', '3700122', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '境栄', 'サカイサカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市境東', '10', '10204', '3700123', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '境東', 'サカイアズマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市境', '10', '10204', '3700124', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '境', 'サカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市境萩原', '10', '10204', '3700125', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '境萩原', 'サカイハギワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市境下武士', '10', '10204', '3700126', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '境下武士', 'サカイシモタケシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市境上武士', '10', '10204', '3700127', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '境上武士', 'サカイカミタケシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市境保泉', '10', '10204', '3700128', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '境保泉', 'サカイホズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県五所川原市米田', '02', '02205', '0370013', '青森県', 'アオモリケン', '五所川原市', 'ゴショガワラシ', '米田', 'ヨネタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市境米岡', '10', '10204', '3700131', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '境米岡', 'サカイヨネオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市境平塚', '10', '10204', '3700132', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '境平塚', 'サカイヒラヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市境中島', '10', '10204', '3700133', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '境中島', 'サカイナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市境島村', '10', '10204', '3700134', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '境島村', 'サカイシマムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市境小此木', '10', '10204', '3700135', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '境小此木', 'サカイオコノギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県五所川原市稲実', '02', '02205', '0370014', '青森県', 'アオモリケン', '五所川原市', 'ゴショガワラシ', '稲実', 'イナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県五所川原市姥萢', '02', '02205', '0370015', '青森県', 'アオモリケン', '五所川原市', 'ゴショガワラシ', '姥萢', 'ウバヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県五所川原市一ツ谷', '02', '02205', '0370016', '青森県', 'アオモリケン', '五所川原市', 'ゴショガワラシ', '一ツ谷', 'ヒトツヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県五所川原市漆川', '02', '02205', '0370017', '青森県', 'アオモリケン', '五所川原市', 'ゴショガワラシ', '漆川', 'ウルシカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県五所川原市中泉', '02', '02205', '0370021', '青森県', 'アオモリケン', '五所川原市', 'ゴショガワラシ', '中泉', 'ナカイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県五所川原市梅田', '02', '02205', '0370022', '青森県', 'アオモリケン', '五所川原市', 'ゴショガワラシ', '梅田', 'ウメタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県五所川原市広田', '02', '02205', '0370023', '青森県', 'アオモリケン', '五所川原市', 'ゴショガワラシ', '広田', 'ヒロタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県五所川原市みどり町', '02', '02205', '0370024', '青森県', 'アオモリケン', '五所川原市', 'ゴショガワラシ', 'みどり町', 'ミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県五所川原市七ツ館', '02', '02205', '0370025', '青森県', 'アオモリケン', '五所川原市', 'ゴショガワラシ', '七ツ館', 'ナナツダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市新田天良町', '10', '10205', '3700301', '群馬県', 'グンマケン', '太田市', 'オオタシ', '新田天良町', 'ニッタテンラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市新田小金町', '10', '10205', '3700302', '群馬県', 'グンマケン', '太田市', 'オオタシ', '新田小金町', 'ニッタコキンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市新田小金井町', '10', '10205', '3700303', '群馬県', 'グンマケン', '太田市', 'オオタシ', '新田小金井町', 'ニッタコガナイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市新田市町', '10', '10205', '3700304', '群馬県', 'グンマケン', '太田市', 'オオタシ', '新田市町', 'ニッタイチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市新田多村新田町', '10', '10205', '3700305', '群馬県', 'グンマケン', '太田市', 'オオタシ', '新田多村新田町', 'ニッタタムラシンデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市新田市野倉町', '10', '10205', '3700306', '群馬県', 'グンマケン', '太田市', 'オオタシ', '新田市野倉町', 'ニッタイチノクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県五所川原市下り枝', '02', '02205', '0370031', '青森県', 'アオモリケン', '五所川原市', 'ゴショガワラシ', '下り枝', 'サガリエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市新田瑞木町', '10', '10205', '3700311', '群馬県', 'グンマケン', '太田市', 'オオタシ', '新田瑞木町', 'ニッタミズキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市新田村田町', '10', '10205', '3700312', '群馬県', 'グンマケン', '太田市', 'オオタシ', '新田村田町', 'ニッタムラタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市新田反町町', '10', '10205', '3700313', '群馬県', 'グンマケン', '太田市', 'オオタシ', '新田反町町', 'ニッタソリマチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市新田市野井町', '10', '10205', '3700314', '群馬県', 'グンマケン', '太田市', 'オオタシ', '新田市野井町', 'ニッタイチノイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県五所川原市烏森', '02', '02205', '0370032', '青森県', 'アオモリケン', '五所川原市', 'ゴショガワラシ', '烏森', 'カラスモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市新田木崎町', '10', '10205', '3700321', '群馬県', 'グンマケン', '太田市', 'オオタシ', '新田木崎町', 'ニッタキザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県五所川原市鎌谷町', '02', '02205', '0370033', '青森県', 'アオモリケン', '五所川原市', 'ゴショガワラシ', '鎌谷町', 'カマヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市新田赤堀町', '10', '10205', '3700331', '群馬県', 'グンマケン', '太田市', 'オオタシ', '新田赤堀町', 'ニッタアカボリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市新田中江田町', '10', '10205', '3700332', '群馬県', 'グンマケン', '太田市', 'オオタシ', '新田中江田町', 'ニッタナカエダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市新田下江田町', '10', '10205', '3700333', '群馬県', 'グンマケン', '太田市', 'オオタシ', '新田下江田町', 'ニッタシモエダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市新田高尾町', '10', '10205', '3700334', '群馬県', 'グンマケン', '太田市', 'オオタシ', '新田高尾町', 'ニッタタカオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県五所川原市八重菊', '02', '02205', '0370034', '青森県', 'アオモリケン', '五所川原市', 'ゴショガワラシ', '八重菊', 'ヤエギク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市新田金井町', '10', '10205', '3700341', '群馬県', 'グンマケン', '太田市', 'オオタシ', '新田金井町', 'ニッタカナイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市新田上江田町', '10', '10205', '3700342', '群馬県', 'グンマケン', '太田市', 'オオタシ', '新田上江田町', 'ニッタカミエダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市新田下田中町', '10', '10205', '3700343', '群馬県', 'グンマケン', '太田市', 'オオタシ', '新田下田中町', 'ニッタシモダナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市新田早川町', '10', '10205', '3700344', '群馬県', 'グンマケン', '太田市', 'オオタシ', '新田早川町', 'ニッタハヤカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市新田花香塚町', '10', '10205', '3700345', '群馬県', 'グンマケン', '太田市', 'オオタシ', '新田花香塚町', 'ニッタハナカヅカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市新田上田中町', '10', '10205', '3700346', '群馬県', 'グンマケン', '太田市', 'オオタシ', '新田上田中町', 'ニッタカミダナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市新田大根町', '10', '10205', '3700347', '群馬県', 'グンマケン', '太田市', 'オオタシ', '新田大根町', 'ニッタオオネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県五所川原市湊', '02', '02205', '0370035', '青森県', 'アオモリケン', '五所川原市', 'ゴショガワラシ', '湊', 'ミナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市新田大町', '10', '10205', '3700351', '群馬県', 'グンマケン', '太田市', 'オオタシ', '新田大町', 'ニッタオオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市新田嘉祢町', '10', '10205', '3700352', '群馬県', 'グンマケン', '太田市', 'オオタシ', '新田嘉祢町', 'ニッタカネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市新田上中町', '10', '10205', '3700353', '群馬県', 'グンマケン', '太田市', 'オオタシ', '新田上中町', 'ニッタカミナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市新田溜池町', '10', '10205', '3700354', '群馬県', 'グンマケン', '太田市', 'オオタシ', '新田溜池町', 'ニッタタメイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市新田権右衛門町', '10', '10205', '3700355', '群馬県', 'グンマケン', '太田市', 'オオタシ', '新田権右衛門町', 'ニッタゴンウエモンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市新田萩町', '10', '10205', '3700356', '群馬県', 'グンマケン', '太田市', 'オオタシ', '新田萩町', 'ニッタハギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市尾島町', '10', '10205', '3700401', '群馬県', 'グンマケン', '太田市', 'オオタシ', '尾島町', 'オジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市阿久津町', '10', '10205', '3700402', '群馬県', 'グンマケン', '太田市', 'オオタシ', '阿久津町', 'アクツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市岩松町', '10', '10205', '3700403', '群馬県', 'グンマケン', '太田市', 'オオタシ', '岩松町', 'イワマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市備前島町', '10', '10205', '3700404', '群馬県', 'グンマケン', '太田市', 'オオタシ', '備前島町', 'ビゼンジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市押切町', '10', '10205', '3700405', '群馬県', 'グンマケン', '太田市', 'オオタシ', '押切町', 'オシキリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市前小屋町', '10', '10205', '3700406', '群馬県', 'グンマケン', '太田市', 'オオタシ', '前小屋町', 'マエゴヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県五所川原市田町', '02', '02205', '0370041', '青森県', 'アオモリケン', '五所川原市', 'ゴショガワラシ', '田町', 'タマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市亀岡町', '10', '10205', '3700411', '群馬県', 'グンマケン', '太田市', 'オオタシ', '亀岡町', 'カメオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市太子町', '10', '10205', '3700412', '群馬県', 'グンマケン', '太田市', 'オオタシ', '太子町', 'タイシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市すずかけ町', '10', '10205', '3700413', '群馬県', 'グンマケン', '太田市', 'オオタシ', 'すずかけ町', 'スズカケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市堀口町', '10', '10205', '3700414', '群馬県', 'グンマケン', '太田市', 'オオタシ', '堀口町', 'ホリグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市南ケ丘町', '10', '10205', '3700415', '群馬県', 'グンマケン', '太田市', 'オオタシ', '南ケ丘町', 'ミナミガオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市前島町', '10', '10205', '3700416', '群馬県', 'グンマケン', '太田市', 'オオタシ', '前島町', 'マエジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市二ツ小屋町', '10', '10205', '3700417', '群馬県', 'グンマケン', '太田市', 'オオタシ', '二ツ小屋町', 'フタツゴヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市武蔵島町', '10', '10205', '3700418', '群馬県', 'グンマケン', '太田市', 'オオタシ', '武蔵島町', 'ムサシジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県五所川原市不魚住', '02', '02205', '0370042', '青森県', 'アオモリケン', '五所川原市', 'ゴショガワラシ', '不魚住', 'ウオスマズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市粕川町', '10', '10205', '3700421', '群馬県', 'グンマケン', '太田市', 'オオタシ', '粕川町', 'カスカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市安養寺町', '10', '10205', '3700422', '群馬県', 'グンマケン', '太田市', 'オオタシ', '安養寺町', 'アンヨウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市大舘町', '10', '10205', '3700423', '群馬県', 'グンマケン', '太田市', 'オオタシ', '大舘町', 'オオタチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市出塚町', '10', '10205', '3700424', '群馬県', 'グンマケン', '太田市', 'オオタシ', '出塚町', 'イデヅカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市徳川町', '10', '10205', '3700425', '群馬県', 'グンマケン', '太田市', 'オオタシ', '徳川町', 'トクガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市世良田町', '10', '10205', '3700426', '群馬県', 'グンマケン', '太田市', 'オオタシ', '世良田町', 'セラダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市小角田町', '10', '10205', '3700427', '群馬県', 'グンマケン', '太田市', 'オオタシ', '小角田町', 'コズミダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県五所川原市蓮沼', '02', '02205', '0370043', '青森県', 'アオモリケン', '五所川原市', 'ゴショガワラシ', '蓮沼', 'ハスヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県五所川原市元町', '02', '02205', '0370044', '青森県', 'アオモリケン', '五所川原市', 'ゴショガワラシ', '元町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県五所川原市新町', '02', '02205', '0370045', '青森県', 'アオモリケン', '五所川原市', 'ゴショガワラシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県五所川原市栄町', '02', '02205', '0370046', '青森県', 'アオモリケン', '五所川原市', 'ゴショガワラシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県邑楽郡千代田町', '10', '10523', '3700500', '群馬県', 'グンマケン', '邑楽郡千代田町', 'オウラグンチヨダマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('30355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県邑楽郡大泉町', '10', '10524', '3700500', '群馬県', 'グンマケン', '邑楽郡大泉町', 'オウラグンオオイズミマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('30356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県邑楽郡千代田町福島', '10', '10523', '3700501', '群馬県', 'グンマケン', '邑楽郡千代田町', 'オウラグンチヨダマチ', '福島', 'フクジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県邑楽郡千代田町鍋谷', '10', '10523', '3700502', '群馬県', 'グンマケン', '邑楽郡千代田町', 'オウラグンチヨダマチ', '鍋谷', 'ナベヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県邑楽郡千代田町赤岩', '10', '10523', '3700503', '群馬県', 'グンマケン', '邑楽郡千代田町', 'オウラグンチヨダマチ', '赤岩', 'アカイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県邑楽郡千代田町舞木', '10', '10523', '3700504', '群馬県', 'グンマケン', '邑楽郡千代田町', 'オウラグンチヨダマチ', '舞木', 'マイギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県邑楽郡千代田町新福寺', '10', '10523', '3700505', '群馬県', 'グンマケン', '邑楽郡千代田町', 'オウラグンチヨダマチ', '新福寺', 'シンプクジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県五所川原市弥生町', '02', '02205', '0370051', '青森県', 'アオモリケン', '五所川原市', 'ゴショガワラシ', '弥生町', 'ヤヨイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県邑楽郡大泉町北小泉', '10', '10524', '3700511', '群馬県', 'グンマケン', '邑楽郡大泉町', 'オウラグンオオイズミマチ', '北小泉', 'キタコイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県邑楽郡大泉町上小泉', '10', '10524', '3700512', '群馬県', 'グンマケン', '邑楽郡大泉町', 'オウラグンオオイズミマチ', '上小泉', 'カミコイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県邑楽郡大泉町東小泉', '10', '10524', '3700513', '群馬県', 'グンマケン', '邑楽郡大泉町', 'オウラグンオオイズミマチ', '東小泉', 'ヒガシコイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県邑楽郡大泉町朝日', '10', '10524', '3700514', '群馬県', 'グンマケン', '邑楽郡大泉町', 'オウラグンオオイズミマチ', '朝日', 'アサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県邑楽郡大泉町下小泉', '10', '10524', '3700515', '群馬県', 'グンマケン', '邑楽郡大泉町', 'オウラグンオオイズミマチ', '下小泉', 'シモコイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県邑楽郡大泉町中央', '10', '10524', '3700516', '群馬県', 'グンマケン', '邑楽郡大泉町', 'オウラグンオオイズミマチ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県邑楽郡大泉町西小泉', '10', '10524', '3700517', '群馬県', 'グンマケン', '邑楽郡大泉町', 'オウラグンオオイズミマチ', '西小泉', 'ニシコイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県邑楽郡大泉町城之内', '10', '10524', '3700518', '群馬県', 'グンマケン', '邑楽郡大泉町', 'オウラグンオオイズミマチ', '城之内', 'シロノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県五所川原市東町', '02', '02205', '0370052', '青森県', 'アオモリケン', '五所川原市', 'ゴショガワラシ', '東町', 'アズマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県邑楽郡大泉町住吉', '10', '10524', '3700521', '群馬県', 'グンマケン', '邑楽郡大泉町', 'オウラグンオオイズミマチ', '住吉', 'スミヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県邑楽郡大泉町富士', '10', '10524', '3700522', '群馬県', 'グンマケン', '邑楽郡大泉町', 'オウラグンオオイズミマチ', '富士', 'フジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県邑楽郡大泉町吉田', '10', '10524', '3700523', '群馬県', 'グンマケン', '邑楽郡大泉町', 'オウラグンオオイズミマチ', '吉田', 'ヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県邑楽郡大泉町古海', '10', '10524', '3700524', '群馬県', 'グンマケン', '邑楽郡大泉町', 'オウラグンオオイズミマチ', '古海', 'コカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県邑楽郡大泉町日の出', '10', '10524', '3700525', '群馬県', 'グンマケン', '邑楽郡大泉町', 'オウラグンオオイズミマチ', '日の出', 'ヒノデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県五所川原市布屋町', '02', '02205', '0370053', '青森県', 'アオモリケン', '五所川原市', 'ゴショガワラシ', '布屋町', 'ヌノヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県邑楽郡大泉町いずみ', '10', '10524', '3700531', '群馬県', 'グンマケン', '邑楽郡大泉町', 'オウラグンオオイズミマチ', 'いずみ', 'イズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県邑楽郡大泉町坂田', '10', '10524', '3700532', '群馬県', 'グンマケン', '邑楽郡大泉町', 'オウラグンオオイズミマチ', '坂田', 'サカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県邑楽郡大泉町仙石', '10', '10524', '3700533', '群馬県', 'グンマケン', '邑楽郡大泉町', 'オウラグンオオイズミマチ', '仙石', 'センゴク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県邑楽郡大泉町丘山', '10', '10524', '3700534', '群馬県', 'グンマケン', '邑楽郡大泉町', 'オウラグンオオイズミマチ', '丘山', 'オカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県邑楽郡大泉町寄木戸', '10', '10524', '3700535', '群馬県', 'グンマケン', '邑楽郡大泉町', 'オウラグンオオイズミマチ', '寄木戸', 'ヨリキド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県邑楽郡大泉町古氷', '10', '10524', '3700536', '群馬県', 'グンマケン', '邑楽郡大泉町', 'オウラグンオオイズミマチ', '古氷', 'フルコオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県五所川原市上平井町', '02', '02205', '0370054', '青森県', 'アオモリケン', '五所川原市', 'ゴショガワラシ', '上平井町', 'カミヒライマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県五所川原市柏原町', '02', '02205', '0370055', '青森県', 'アオモリケン', '五所川原市', 'ゴショガワラシ', '柏原町', 'カシワバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県五所川原市末広町', '02', '02205', '0370056', '青森県', 'アオモリケン', '五所川原市', 'ゴショガワラシ', '末広町', 'スエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県五所川原市幾島町', '02', '02205', '0370057', '青森県', 'アオモリケン', '五所川原市', 'ゴショガワラシ', '幾島町', 'イクシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県五所川原市錦町', '02', '02205', '0370058', '青森県', 'アオモリケン', '五所川原市', 'ゴショガワラシ', '錦町', 'ニシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県邑楽郡邑楽町', '10', '10525', '3700600', '群馬県', 'グンマケン', '邑楽郡邑楽町', 'オウラグンオウラマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('30392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県邑楽郡邑楽町鶉', '10', '10525', '3700601', '群馬県', 'グンマケン', '邑楽郡邑楽町', 'オウラグンオウラマチ', '鶉', 'ウズラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県邑楽郡邑楽町明野', '10', '10525', '3700602', '群馬県', 'グンマケン', '邑楽郡邑楽町', 'オウラグンオウラマチ', '明野', 'アケノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県邑楽郡邑楽町中野', '10', '10525', '3700603', '群馬県', 'グンマケン', '邑楽郡邑楽町', 'オウラグンオウラマチ', '中野', 'ナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県邑楽郡邑楽町石打', '10', '10525', '3700604', '群馬県', 'グンマケン', '邑楽郡邑楽町', 'オウラグンオウラマチ', '石打', 'イシウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県邑楽郡邑楽町藤川', '10', '10525', '3700605', '群馬県', 'グンマケン', '邑楽郡邑楽町', 'オウラグンオウラマチ', '藤川', 'フジカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県邑楽郡邑楽町秋妻', '10', '10525', '3700606', '群馬県', 'グンマケン', '邑楽郡邑楽町', 'オウラグンオウラマチ', '秋妻', 'アキヅマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県五所川原市雛田', '02', '02205', '0370061', '青森県', 'アオモリケン', '五所川原市', 'ゴショガワラシ', '雛田', 'ヒナタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県邑楽郡邑楽町鶉新田', '10', '10525', '3700611', '群馬県', 'グンマケン', '邑楽郡邑楽町', 'オウラグンオウラマチ', '鶉新田', 'ウズラシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県邑楽郡邑楽町新中野', '10', '10525', '3700612', '群馬県', 'グンマケン', '邑楽郡邑楽町', 'オウラグンオウラマチ', '新中野', 'シンナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県邑楽郡邑楽町狸塚', '10', '10525', '3700613', '群馬県', 'グンマケン', '邑楽郡邑楽町', 'オウラグンオウラマチ', '狸塚', 'ムジナヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県邑楽郡邑楽町赤堀', '10', '10525', '3700614', '群馬県', 'グンマケン', '邑楽郡邑楽町', 'オウラグンオウラマチ', '赤堀', 'アカホリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県邑楽郡邑楽町篠塚', '10', '10525', '3700615', '群馬県', 'グンマケン', '邑楽郡邑楽町', 'オウラグンオウラマチ', '篠塚', 'シノヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県邑楽郡邑楽町光善寺', '10', '10525', '3700616', '群馬県', 'グンマケン', '邑楽郡邑楽町', 'オウラグンオウラマチ', '光善寺', 'コウゼンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県五所川原市旭町', '02', '02205', '0370062', '青森県', 'アオモリケン', '五所川原市', 'ゴショガワラシ', '旭町', 'アサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県五所川原市大町', '02', '02205', '0370063', '青森県', 'アオモリケン', '五所川原市', 'ゴショガワラシ', '大町', 'オオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県五所川原市下平井町', '02', '02205', '0370064', '青森県', 'アオモリケン', '五所川原市', 'ゴショガワラシ', '下平井町', 'シモヒライマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県五所川原市幾世森', '02', '02205', '0370065', '青森県', 'アオモリケン', '五所川原市', 'ゴショガワラシ', '幾世森', 'イクセモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県五所川原市中平井町', '02', '02205', '0370066', '青森県', 'アオモリケン', '五所川原市', 'ゴショガワラシ', '中平井町', 'ナカヒライマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県五所川原市敷島町', '02', '02205', '0370067', '青森県', 'アオモリケン', '五所川原市', 'ゴショガワラシ', '敷島町', 'シキシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県五所川原市長橋', '02', '02205', '0370068', '青森県', 'アオモリケン', '五所川原市', 'ゴショガワラシ', '長橋', 'ナガハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県五所川原市若葉', '02', '02205', '0370069', '青森県', 'アオモリケン', '五所川原市', 'ゴショガワラシ', '若葉', 'ワカバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県邑楽郡明和町', '10', '10522', '3700700', '群馬県', 'グンマケン', '邑楽郡明和町', 'オウラグンメイワマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('30415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県邑楽郡明和町南大島', '10', '10522', '3700701', '群馬県', 'グンマケン', '邑楽郡明和町', 'オウラグンメイワマチ', '南大島', 'ミナミオオシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県邑楽郡明和町上江黒', '10', '10522', '3700702', '群馬県', 'グンマケン', '邑楽郡明和町', 'オウラグンメイワマチ', '上江黒', 'カミエグロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県邑楽郡明和町下江黒', '10', '10522', '3700703', '群馬県', 'グンマケン', '邑楽郡明和町', 'オウラグンメイワマチ', '下江黒', 'シモエグロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県邑楽郡明和町斗合田', '10', '10522', '3700704', '群馬県', 'グンマケン', '邑楽郡明和町', 'オウラグンメイワマチ', '斗合田', 'トゴウタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県邑楽郡明和町千津井', '10', '10522', '3700705', '群馬県', 'グンマケン', '邑楽郡明和町', 'オウラグンメイワマチ', '千津井', 'センヅイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県邑楽郡明和町江口', '10', '10522', '3700706', '群馬県', 'グンマケン', '邑楽郡明和町', 'オウラグンメイワマチ', '江口', 'エグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県邑楽郡明和町田島', '10', '10522', '3700707', '群馬県', 'グンマケン', '邑楽郡明和町', 'オウラグンメイワマチ', '田島', 'タジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県邑楽郡明和町新里', '10', '10522', '3700708', '群馬県', 'グンマケン', '邑楽郡明和町', 'オウラグンメイワマチ', '新里', 'ニッサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県五所川原市本町', '02', '02205', '0370071', '青森県', 'アオモリケン', '五所川原市', 'ゴショガワラシ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県邑楽郡明和町入ケ谷', '10', '10522', '3700711', '群馬県', 'グンマケン', '邑楽郡明和町', 'オウラグンメイワマチ', '入ケ谷', 'イリカヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県邑楽郡明和町矢島', '10', '10522', '3700712', '群馬県', 'グンマケン', '邑楽郡明和町', 'オウラグンメイワマチ', '矢島', 'ヤジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県邑楽郡明和町中谷', '10', '10522', '3700713', '群馬県', 'グンマケン', '邑楽郡明和町', 'オウラグンメイワマチ', '中谷', 'ナカヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県邑楽郡明和町梅原', '10', '10522', '3700714', '群馬県', 'グンマケン', '邑楽郡明和町', 'オウラグンメイワマチ', '梅原', 'ウメバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県邑楽郡明和町大佐貫', '10', '10522', '3700715', '群馬県', 'グンマケン', '邑楽郡明和町', 'オウラグンメイワマチ', '大佐貫', 'オオザヌキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県邑楽郡明和町川俣', '10', '10522', '3700716', '群馬県', 'グンマケン', '邑楽郡明和町', 'オウラグンメイワマチ', '川俣', 'カワマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県邑楽郡明和町須賀', '10', '10522', '3700717', '群馬県', 'グンマケン', '邑楽郡明和町', 'オウラグンメイワマチ', '須賀', 'スカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県邑楽郡明和町大輪', '10', '10522', '3700718', '群馬県', 'グンマケン', '邑楽郡明和町', 'オウラグンメイワマチ', '大輪', 'オオワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県五所川原市川端町', '02', '02205', '0370072', '青森県', 'アオモリケン', '五所川原市', 'ゴショガワラシ', '川端町', 'カワバタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県邑楽郡千代田町木崎', '10', '10523', '3700721', '群馬県', 'グンマケン', '邑楽郡千代田町', 'オウラグンチヨダマチ', '木崎', 'キザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県邑楽郡千代田町萱野', '10', '10523', '3700722', '群馬県', 'グンマケン', '邑楽郡千代田町', 'オウラグンチヨダマチ', '萱野', 'カヤノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県邑楽郡千代田町昭和', '10', '10523', '3700723', '群馬県', 'グンマケン', '邑楽郡千代田町', 'オウラグンチヨダマチ', '昭和', 'ショウワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県邑楽郡千代田町下中森', '10', '10523', '3700724', '群馬県', 'グンマケン', '邑楽郡千代田町', 'オウラグンチヨダマチ', '下中森', 'シモナカモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県邑楽郡千代田町上中森', '10', '10523', '3700725', '群馬県', 'グンマケン', '邑楽郡千代田町', 'オウラグンチヨダマチ', '上中森', 'カミナカモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県邑楽郡千代田町上五箇', '10', '10523', '3700726', '群馬県', 'グンマケン', '邑楽郡千代田町', 'オウラグンチヨダマチ', '上五箇', 'カミゴカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県邑楽郡千代田町瀬戸井', '10', '10523', '3700727', '群馬県', 'グンマケン', '邑楽郡千代田町', 'オウラグンチヨダマチ', '瀬戸井', 'セドイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県五所川原市柳町', '02', '02205', '0370073', '青森県', 'アオモリケン', '五所川原市', 'ゴショガワラシ', '柳町', 'ヤナギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県五所川原市岩木町', '02', '02205', '0370074', '青森県', 'アオモリケン', '五所川原市', 'ゴショガワラシ', '岩木町', 'イワキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県五所川原市寺町', '02', '02205', '0370075', '青森県', 'アオモリケン', '五所川原市', 'ゴショガワラシ', '寺町', 'テラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県五所川原市小曲', '02', '02205', '0370076', '青森県', 'アオモリケン', '五所川原市', 'ゴショガワラシ', '小曲', 'コマガリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市上並榎町', '10', '10202', '3700801', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '上並榎町', 'カミナミエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市並榎町', '10', '10202', '3700802', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '並榎町', 'ナミエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市大橋町', '10', '10202', '3700803', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '大橋町', 'オオハシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市住吉町', '10', '10202', '3700804', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '住吉町', 'スミヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市台町', '10', '10202', '3700805', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '台町', 'ダイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市上和田町', '10', '10202', '3700806', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '上和田町', 'カミワダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市歌川町', '10', '10202', '3700807', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '歌川町', 'ウタガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県五所川原市新宮', '02', '02205', '0370081', '青森県', 'アオモリケン', '五所川原市', 'ゴショガワラシ', '新宮', 'シンミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市相生町', '10', '10202', '3700811', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '相生町', 'アイオイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市成田町', '10', '10202', '3700812', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '成田町', 'ナリタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市本町', '10', '10202', '3700813', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '本町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市嘉多町', '10', '10202', '3700814', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '嘉多町', 'カタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市柳川町', '10', '10202', '3700815', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '柳川町', 'ヤナガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市常盤町', '10', '10202', '3700816', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '常盤町', 'トキワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市堰代町', '10', '10202', '3700817', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '堰代町', 'セキシロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市赤坂町', '10', '10202', '3700818', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '赤坂町', 'アカサカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市四ツ屋町', '10', '10202', '3700819', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '四ツ屋町', 'ヨツヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県五所川原市種井', '02', '02205', '0370082', '青森県', 'アオモリケン', '五所川原市', 'ゴショガワラシ', '種井', 'タネイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市新紺屋町', '10', '10202', '3700821', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '新紺屋町', 'シンコンヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市寄合町', '10', '10202', '3700822', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '寄合町', 'ヨリアイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市中紺屋町', '10', '10202', '3700823', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '中紺屋町', 'ナカコンヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市田町', '10', '10202', '3700824', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '田町', 'タマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市白銀町', '10', '10202', '3700825', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '白銀町', 'シロガネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市連雀町', '10', '10202', '3700826', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '連雀町', 'レンジャクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市鞘町', '10', '10202', '3700827', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '鞘町', 'サヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市宮元町', '10', '10202', '3700828', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '宮元町', 'ミヤモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市高松町', '10', '10202', '3700829', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '高松町', 'タカマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県五所川原市新宮町', '02', '02205', '0370083', '青森県', 'アオモリケン', '五所川原市', 'ゴショガワラシ', '新宮町', 'シンミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市あら町', '10', '10202', '3700831', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', 'あら町', 'アラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市砂賀町', '10', '10202', '3700832', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '砂賀町', 'スナガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市新田町', '10', '10202', '3700833', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '新田町', 'シンデンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市南町', '10', '10202', '3700834', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '南町', 'ミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市竜見町', '10', '10202', '3700835', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '竜見町', 'タツミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市若松町', '10', '10202', '3700836', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '若松町', 'ワカマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市下横町', '10', '10202', '3700837', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '下横町', 'シモヨコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市鍛冶町', '10', '10202', '3700838', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '鍛冶町', 'カジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市檜物町', '10', '10202', '3700839', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '檜物町', 'ヒモノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県五所川原市蘇鉄', '02', '02205', '0370084', '青森県', 'アオモリケン', '五所川原市', 'ゴショガワラシ', '蘇鉄', 'ソテツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市栄町', '10', '10202', '3700841', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '栄町', 'サカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市北双葉町', '10', '10202', '3700842', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '北双葉町', 'キタフタバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市双葉町', '10', '10202', '3700843', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '双葉町', 'フタバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市和田多中町', '10', '10202', '3700844', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '和田多中町', 'ワダタナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市新後閑町', '10', '10202', '3700845', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '新後閑町', 'シゴカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市下和田町', '10', '10202', '3700846', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '下和田町', 'シモワダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市和田町', '10', '10202', '3700847', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '和田町', 'ワダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市鶴見町', '10', '10202', '3700848', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '鶴見町', 'ツルミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市八島町', '10', '10202', '3700849', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '八島町', 'ヤシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県五所川原市芭蕉', '02', '02205', '0370085', '青森県', 'アオモリケン', '五所川原市', 'ゴショガワラシ', '芭蕉', 'バショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市上中居町', '10', '10202', '3700851', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '上中居町', 'カミナカイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市中居町', '10', '10202', '3700852', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '中居町', 'ナカイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市下中居町', '10', '10202', '3700853', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '下中居町', 'シモナカイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市下之城町', '10', '10202', '3700854', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '下之城町', 'シモノジョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市下佐野町', '10', '10202', '3700855', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '下佐野町', 'シモサノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市佐野窪町', '10', '10202', '3700856', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '佐野窪町', 'サノクボマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市上佐野町', '10', '10202', '3700857', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '上佐野町', 'カミサノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県五所川原市田川', '02', '02205', '0370086', '青森県', 'アオモリケン', '五所川原市', 'ゴショガワラシ', '田川', 'タガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市八千代町', '10', '10202', '3700861', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '八千代町', 'ヤチヨマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市片岡町', '10', '10202', '3700862', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '片岡町', 'カタオカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市聖石町', '10', '10202', '3700863', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '聖石町', 'ヒジリイシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市石原町', '10', '10202', '3700864', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '石原町', 'イシハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市寺尾町', '10', '10202', '3700865', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '寺尾町', 'テラオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市城山町', '10', '10202', '3700866', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '城山町', 'シロヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市乗附町', '10', '10202', '3700867', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '乗附町', 'ノツケマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市鼻高町', '10', '10202', '3700868', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '鼻高町', 'ハナダカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県五所川原市高瀬', '02', '02205', '0370087', '青森県', 'アオモリケン', '五所川原市', 'ゴショガワラシ', '高瀬', 'タカセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市上豊岡町', '10', '10202', '3700871', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '上豊岡町', 'カミトヨオカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市北久保町', '10', '10202', '3700872', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '北久保町', 'キタクボマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市下豊岡町', '10', '10202', '3700873', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '下豊岡町', 'シモトヨオカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市中豊岡町', '10', '10202', '3700874', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '中豊岡町', 'ナカトヨオカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市藤塚町', '10', '10202', '3700875', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '藤塚町', 'フジツカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県五所川原市鶴ケ岡', '02', '02205', '0370088', '青森県', 'アオモリケン', '五所川原市', 'ゴショガワラシ', '鶴ケ岡', 'ツルガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市町屋町', '10', '10202', '3700881', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '町屋町', 'マチヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市金井淵町', '10', '10202', '3700882', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '金井淵町', 'カナイブチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市剣崎町', '10', '10202', '3700883', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '剣崎町', 'ケンザキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市八幡町', '10', '10202', '3700884', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '八幡町', 'ヤワタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市若田町', '10', '10202', '3700885', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '若田町', 'ワカタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市下大島町', '10', '10202', '3700886', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '下大島町', 'シモオオシママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県五所川原市藻川', '02', '02205', '0370089', '青森県', 'アオモリケン', '五所川原市', 'ゴショガワラシ', '藻川', 'モガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県五所川原市太刀打', '02', '02205', '0370091', '青森県', 'アオモリケン', '五所川原市', 'ゴショガワラシ', '太刀打', 'タチウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県五所川原市沖飯詰', '02', '02205', '0370092', '青森県', 'アオモリケン', '五所川原市', 'ゴショガワラシ', '沖飯詰', 'オキイイヅメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県五所川原市一野坪', '02', '02205', '0370093', '青森県', 'アオモリケン', '五所川原市', 'ゴショガワラシ', '一野坪', 'イチノツボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県五所川原市川山', '02', '02205', '0370094', '青森県', 'アオモリケン', '五所川原市', 'ゴショガワラシ', '川山', 'カワヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県五所川原市桜田', '02', '02205', '0370095', '青森県', 'アオモリケン', '五所川原市', 'ゴショガワラシ', '桜田', 'サクラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県五所川原市毘沙門', '02', '02205', '0370096', '青森県', 'アオモリケン', '五所川原市', 'ゴショガワラシ', '毘沙門', 'ビシャモン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県五所川原市長富', '02', '02205', '0370097', '青森県', 'アオモリケン', '五所川原市', 'ゴショガワラシ', '長富', 'ナガトミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県つがる市稲垣町下繁田', '02', '02209', '0370101', '青森県', 'アオモリケン', 'つがる市', 'ツガルシ', '稲垣町下繁田', 'イナガキチョウシモシゲタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県つがる市稲垣町繁田', '02', '02209', '0370102', '青森県', 'アオモリケン', 'つがる市', 'ツガルシ', '稲垣町繁田', 'イナガキチョウシゲタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県つがる市稲垣町穂積', '02', '02209', '0370103', '青森県', 'アオモリケン', 'つがる市', 'ツガルシ', '稲垣町穂積', 'イナガキチョウホヅミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県つがる市稲垣町豊川', '02', '02209', '0370104', '青森県', 'アオモリケン', 'つがる市', 'ツガルシ', '稲垣町豊川', 'イナガキチョウトヨカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県つがる市稲垣町福富', '02', '02209', '0370105', '青森県', 'アオモリケン', 'つがる市', 'ツガルシ', '稲垣町福富', 'イナガキチョウフクトミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県つがる市稲垣町沼崎', '02', '02209', '0370106', '青森県', 'アオモリケン', 'つがる市', 'ツガルシ', '稲垣町沼崎', 'イナガキチョウヌマザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県つがる市稲垣町沼舘', '02', '02209', '0370107', '青森県', 'アオモリケン', 'つがる市', 'ツガルシ', '稲垣町沼舘', 'イナガキチョウヌマダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県つがる市稲垣町吉出', '02', '02209', '0370108', '青森県', 'アオモリケン', 'つがる市', 'ツガルシ', '稲垣町吉出', 'イナガキチョウヨシデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県つがる市稲垣町千年', '02', '02209', '0370109', '青森県', 'アオモリケン', 'つがる市', 'ツガルシ', '稲垣町千年', 'イナガキチョウチトセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県佐波郡玉村町', '10', '10464', '3701100', '群馬県', 'グンマケン', '佐波郡玉村町', 'サワグンタマムラマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('30540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県佐波郡玉村町藤川', '10', '10464', '3701101', '群馬県', 'グンマケン', '佐波郡玉村町', 'サワグンタマムラマチ', '藤川', 'フジカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県佐波郡玉村町飯塚', '10', '10464', '3701102', '群馬県', 'グンマケン', '佐波郡玉村町', 'サワグンタマムラマチ', '飯塚', 'イイヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県佐波郡玉村町樋越', '10', '10464', '3701103', '群馬県', 'グンマケン', '佐波郡玉村町', 'サワグンタマムラマチ', '樋越', 'ヒゴシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県佐波郡玉村町上福島', '10', '10464', '3701104', '群馬県', 'グンマケン', '佐波郡玉村町', 'サワグンタマムラマチ', '上福島', 'カミフクシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県佐波郡玉村町福島', '10', '10464', '3701105', '群馬県', 'グンマケン', '佐波郡玉村町', 'サワグンタマムラマチ', '福島', 'フクジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県佐波郡玉村町南玉', '10', '10464', '3701111', '群馬県', 'グンマケン', '佐波郡玉村町', 'サワグンタマムラマチ', '南玉', 'ナンギョク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県佐波郡玉村町下之宮', '10', '10464', '3701112', '群馬県', 'グンマケン', '佐波郡玉村町', 'サワグンタマムラマチ', '下之宮', 'シモノミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県佐波郡玉村町箱石', '10', '10464', '3701113', '群馬県', 'グンマケン', '佐波郡玉村町', 'サワグンタマムラマチ', '箱石', 'ハコイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県佐波郡玉村町小泉', '10', '10464', '3701114', '群馬県', 'グンマケン', '佐波郡玉村町', 'サワグンタマムラマチ', '小泉', 'コイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県佐波郡玉村町五料', '10', '10464', '3701115', '群馬県', 'グンマケン', '佐波郡玉村町', 'サワグンタマムラマチ', '五料', 'ゴリョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県佐波郡玉村町飯倉', '10', '10464', '3701116', '群馬県', 'グンマケン', '佐波郡玉村町', 'サワグンタマムラマチ', '飯倉', 'イイグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県佐波郡玉村町川井', '10', '10464', '3701117', '群馬県', 'グンマケン', '佐波郡玉村町', 'サワグンタマムラマチ', '川井', 'カワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県佐波郡玉村町上飯島', '10', '10464', '3701121', '群馬県', 'グンマケン', '佐波郡玉村町', 'サワグンタマムラマチ', '上飯島', 'カミイイジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県佐波郡玉村町上茂木', '10', '10464', '3701122', '群馬県', 'グンマケン', '佐波郡玉村町', 'サワグンタマムラマチ', '上茂木', 'カミモギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県佐波郡玉村町下茂木', '10', '10464', '3701123', '群馬県', 'グンマケン', '佐波郡玉村町', 'サワグンタマムラマチ', '下茂木', 'シモモギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県佐波郡玉村町角淵', '10', '10464', '3701124', '群馬県', 'グンマケン', '佐波郡玉村町', 'サワグンタマムラマチ', '角淵', 'ツノブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県佐波郡玉村町八幡原', '10', '10464', '3701125', '群馬県', 'グンマケン', '佐波郡玉村町', 'サワグンタマムラマチ', '八幡原', 'ヤワタバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県佐波郡玉村町宇貫', '10', '10464', '3701126', '群馬県', 'グンマケン', '佐波郡玉村町', 'サワグンタマムラマチ', '宇貫', 'ウヌキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県佐波郡玉村町上之手', '10', '10464', '3701127', '群馬県', 'グンマケン', '佐波郡玉村町', 'サワグンタマムラマチ', '上之手', 'カミノテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県佐波郡玉村町後箇', '10', '10464', '3701128', '群馬県', 'グンマケン', '佐波郡玉村町', 'サワグンタマムラマチ', '後箇', 'ゴカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県佐波郡玉村町斉田', '10', '10464', '3701131', '群馬県', 'グンマケン', '佐波郡玉村町', 'サワグンタマムラマチ', '斉田', 'サイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県佐波郡玉村町下新田', '10', '10464', '3701132', '群馬県', 'グンマケン', '佐波郡玉村町', 'サワグンタマムラマチ', '下新田', 'シモシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県佐波郡玉村町上新田', '10', '10464', '3701133', '群馬県', 'グンマケン', '佐波郡玉村町', 'サワグンタマムラマチ', '上新田', 'カミシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県佐波郡玉村町与六分', '10', '10464', '3701134', '群馬県', 'グンマケン', '佐波郡玉村町', 'サワグンタマムラマチ', '与六分', 'ヨロクブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県佐波郡玉村町板井', '10', '10464', '3701135', '群馬県', 'グンマケン', '佐波郡玉村町', 'サワグンタマムラマチ', '板井', 'イタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市倉賀野町', '10', '10202', '3701201', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '倉賀野町', 'クラガノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市宮原町', '10', '10202', '3701202', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '宮原町', 'ミヤハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市矢中町', '10', '10202', '3701203', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '矢中町', 'ヤナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市東中里町', '10', '10202', '3701204', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '東中里町', 'ヒガシナカサトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市栗崎町', '10', '10202', '3701205', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '栗崎町', 'クリザキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市台新田町', '10', '10202', '3701206', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '台新田町', 'ダイシンデンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市綿貫町', '10', '10202', '3701207', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '綿貫町', 'ワタヌキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市岩鼻町', '10', '10202', '3701208', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '岩鼻町', 'イワハナマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市阿久津町', '10', '10202', '3701211', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '阿久津町', 'アクツマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市木部町', '10', '10202', '3701212', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '木部町', 'キベマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市山名町', '10', '10202', '3701213', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '山名町', 'ヤマナマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市根小屋町', '10', '10202', '3701214', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '根小屋町', 'ネゴヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市新町', '10', '10202', '3701301', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県藤岡市鬼石', '10', '10209', '3701401', '群馬県', 'グンマケン', '藤岡市', 'フジオカシ', '鬼石', 'オニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県藤岡市譲原', '10', '10209', '3701402', '群馬県', 'グンマケン', '藤岡市', 'フジオカシ', '譲原', 'ユズリハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県藤岡市保美濃山', '10', '10209', '3701403', '群馬県', 'グンマケン', '藤岡市', 'フジオカシ', '保美濃山', 'ホミノヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県藤岡市坂原', '10', '10209', '3701404', '群馬県', 'グンマケン', '藤岡市', 'フジオカシ', '坂原', 'サカハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県藤岡市三波川', '10', '10209', '3701405', '群馬県', 'グンマケン', '藤岡市', 'フジオカシ', '三波川', 'サンバガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県藤岡市浄法寺', '10', '10209', '3701406', '群馬県', 'グンマケン', '藤岡市', 'フジオカシ', '浄法寺', 'ジョウボウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県多野郡神流町柏木', '10', '10367', '3701501', '群馬県', 'グンマケン', '多野郡神流町', 'タノグンカンナマチ', '柏木', 'カシワギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県多野郡神流町麻生', '10', '10367', '3701502', '群馬県', 'グンマケン', '多野郡神流町', 'タノグンカンナマチ', '麻生', 'アソウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県多野郡神流町生利', '10', '10367', '3701503', '群馬県', 'グンマケン', '多野郡神流町', 'タノグンカンナマチ', '生利', 'ショウリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県多野郡神流町万場', '10', '10367', '3701504', '群馬県', 'グンマケン', '多野郡神流町', 'タノグンカンナマチ', '万場', 'マンバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県多野郡神流町森戸', '10', '10367', '3701505', '群馬県', 'グンマケン', '多野郡神流町', 'タノグンカンナマチ', '森戸', 'モリド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県多野郡神流町黒田', '10', '10367', '3701506', '群馬県', 'グンマケン', '多野郡神流町', 'タノグンカンナマチ', '黒田', 'クロダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県多野郡神流町相原', '10', '10367', '3701511', '群馬県', 'グンマケン', '多野郡神流町', 'タノグンカンナマチ', '相原', 'アイバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県多野郡神流町青梨', '10', '10367', '3701512', '群馬県', 'グンマケン', '多野郡神流町', 'タノグンカンナマチ', '青梨', 'アオナシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県多野郡神流町小平', '10', '10367', '3701513', '群馬県', 'グンマケン', '多野郡神流町', 'タノグンカンナマチ', '小平', 'コダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県多野郡神流町塩沢', '10', '10367', '3701514', '群馬県', 'グンマケン', '多野郡神流町', 'タノグンカンナマチ', '塩沢', 'シオザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県多野郡神流町船子', '10', '10367', '3701515', '群馬県', 'グンマケン', '多野郡神流町', 'タノグンカンナマチ', '船子', 'フナコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県多野郡上野村', '10', '10366', '3701600', '群馬県', 'グンマケン', '多野郡上野村', 'タノグンウエノムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('30609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県多野郡神流町', '10', '10367', '3701600', '群馬県', 'グンマケン', '多野郡神流町', 'タノグンカンナマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('30610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県多野郡神流町魚尾', '10', '10367', '3701601', '群馬県', 'グンマケン', '多野郡神流町', 'タノグンカンナマチ', '魚尾', 'ヨノオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県多野郡神流町神ケ原', '10', '10367', '3701602', '群馬県', 'グンマケン', '多野郡神流町', 'タノグンカンナマチ', '神ケ原', 'カガハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県多野郡神流町平原', '10', '10367', '3701603', '群馬県', 'グンマケン', '多野郡神流町', 'タノグンカンナマチ', '平原', 'ヘバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県多野郡神流町尾附', '10', '10367', '3701604', '群馬県', 'グンマケン', '多野郡神流町', 'タノグンカンナマチ', '尾附', 'オヅク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県多野郡上野村新羽', '10', '10366', '3701611', '群馬県', 'グンマケン', '多野郡上野村', 'タノグンウエノムラ', '新羽', 'ニッパ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県多野郡上野村野栗沢', '10', '10366', '3701612', '群馬県', 'グンマケン', '多野郡上野村', 'タノグンウエノムラ', '野栗沢', 'ノグリサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県多野郡上野村勝山', '10', '10366', '3701613', '群馬県', 'グンマケン', '多野郡上野村', 'タノグンウエノムラ', '勝山', 'カツヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県多野郡上野村川和', '10', '10366', '3701614', '群馬県', 'グンマケン', '多野郡上野村', 'タノグンウエノムラ', '川和', 'カワワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県多野郡上野村乙母', '10', '10366', '3701615', '群馬県', 'グンマケン', '多野郡上野村', 'タノグンウエノムラ', '乙母', 'オトモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県多野郡上野村乙父', '10', '10366', '3701616', '群馬県', 'グンマケン', '多野郡上野村', 'タノグンウエノムラ', '乙父', 'オッチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県多野郡上野村楢原', '10', '10366', '3701617', '群馬県', 'グンマケン', '多野郡上野村', 'タノグンウエノムラ', '楢原', 'ナラハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県五所川原市金木町川倉', '02', '02205', '0370201', '青森県', 'アオモリケン', '五所川原市', 'ゴショガワラシ', '金木町川倉', 'カナギチョウカワクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県五所川原市金木町', '02', '02205', '0370202', '青森県', 'アオモリケン', '五所川原市', 'ゴショガワラシ', '金木町', 'カナギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県五所川原市金木町喜良市', '02', '02205', '0370203', '青森県', 'アオモリケン', '五所川原市', 'ゴショガワラシ', '金木町喜良市', 'カナギチョウキライチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県五所川原市金木町嘉瀬', '02', '02205', '0370204', '青森県', 'アオモリケン', '五所川原市', 'ゴショガワラシ', '金木町嘉瀬', 'カナギチョウカセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県五所川原市金木町中柏木', '02', '02205', '0370205', '青森県', 'アオモリケン', '五所川原市', 'ゴショガワラシ', '金木町中柏木', 'カナギチョウナカカシワギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県五所川原市金木町神原', '02', '02205', '0370206', '青森県', 'アオモリケン', '五所川原市', 'ゴショガワラシ', '金木町神原', 'カナギチョウカンバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県五所川原市金木町蒔田', '02', '02205', '0370207', '青森県', 'アオモリケン', '五所川原市', 'ゴショガワラシ', '金木町蒔田', 'カナギチョウマキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県五所川原市金木町藤枝', '02', '02205', '0370208', '青森県', 'アオモリケン', '五所川原市', 'ゴショガワラシ', '金木町藤枝', 'カナギチョウフジエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県多野郡吉井町', '10', '10363', '3702100', '群馬県', 'グンマケン', '多野郡吉井町', 'タノグンヨシイマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('30630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県多野郡吉井町南陽台', '10', '10363', '3702101', '群馬県', 'グンマケン', '多野郡吉井町', 'タノグンヨシイマチ', '南陽台', 'ナンヨウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県多野郡吉井町小暮', '10', '10363', '3702102', '群馬県', 'グンマケン', '多野郡吉井町', 'タノグンヨシイマチ', '小暮', 'コグレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県多野郡吉井町岩井', '10', '10363', '3702103', '群馬県', 'グンマケン', '多野郡吉井町', 'タノグンヨシイマチ', '岩井', 'イワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県多野郡吉井町馬庭', '10', '10363', '3702104', '群馬県', 'グンマケン', '多野郡吉井町', 'タノグンヨシイマチ', '馬庭', 'マニワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県多野郡吉井町中島', '10', '10363', '3702105', '群馬県', 'グンマケン', '多野郡吉井町', 'タノグンヨシイマチ', '中島', 'ナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県多野郡吉井町矢田', '10', '10363', '3702106', '群馬県', 'グンマケン', '多野郡吉井町', 'タノグンヨシイマチ', '矢田', 'ヤタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県多野郡吉井町池', '10', '10363', '3702107', '群馬県', 'グンマケン', '多野郡吉井町', 'タノグンヨシイマチ', '池', 'イケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県多野郡吉井町小串', '10', '10363', '3702111', '群馬県', 'グンマケン', '多野郡吉井町', 'タノグンヨシイマチ', '小串', 'オグシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県多野郡吉井町黒熊', '10', '10363', '3702112', '群馬県', 'グンマケン', '多野郡吉井町', 'タノグンヨシイマチ', '黒熊', 'クロクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県多野郡吉井町深沢', '10', '10363', '3702113', '群馬県', 'グンマケン', '多野郡吉井町', 'タノグンヨシイマチ', '深沢', 'フカサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県多野郡吉井町石神', '10', '10363', '3702114', '群馬県', 'グンマケン', '多野郡吉井町', 'タノグンヨシイマチ', '石神', 'イシガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県多野郡吉井町多比良', '10', '10363', '3702115', '群馬県', 'グンマケン', '多野郡吉井町', 'タノグンヨシイマチ', '多比良', 'タイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県多野郡吉井町多胡', '10', '10363', '3702116', '群馬県', 'グンマケン', '多野郡吉井町', 'タノグンヨシイマチ', '多胡', 'タゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県多野郡吉井町下長根', '10', '10363', '3702121', '群馬県', 'グンマケン', '多野郡吉井町', 'タノグンヨシイマチ', '下長根', 'シモナガネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県多野郡吉井町高', '10', '10363', '3702122', '群馬県', 'グンマケン', '多野郡吉井町', 'タノグンヨシイマチ', '高', 'タカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県多野郡吉井町神保', '10', '10363', '3702123', '群馬県', 'グンマケン', '多野郡吉井町', 'タノグンヨシイマチ', '神保', 'ジンボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県多野郡吉井町塩', '10', '10363', '3702124', '群馬県', 'グンマケン', '多野郡吉井町', 'タノグンヨシイマチ', '塩', 'シオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県多野郡吉井町大沢', '10', '10363', '3702125', '群馬県', 'グンマケン', '多野郡吉井町', 'タノグンヨシイマチ', '大沢', 'オオサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県多野郡吉井町東谷', '10', '10363', '3702126', '群馬県', 'グンマケン', '多野郡吉井町', 'タノグンヨシイマチ', '東谷', 'ヒガシヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県多野郡吉井町長根', '10', '10363', '3702127', '群馬県', 'グンマケン', '多野郡吉井町', 'タノグンヨシイマチ', '長根', 'ナガネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県多野郡吉井町本郷', '10', '10363', '3702128', '群馬県', 'グンマケン', '多野郡吉井町', 'タノグンヨシイマチ', '本郷', 'ホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県多野郡吉井町岩崎', '10', '10363', '3702131', '群馬県', 'グンマケン', '多野郡吉井町', 'タノグンヨシイマチ', '岩崎', 'イワザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県多野郡吉井町吉井', '10', '10363', '3702132', '群馬県', 'グンマケン', '多野郡吉井町', 'タノグンヨシイマチ', '吉井', 'ヨシイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県多野郡吉井町吉井川', '10', '10363', '3702133', '群馬県', 'グンマケン', '多野郡吉井町', 'タノグンヨシイマチ', '吉井川', 'ヨシイカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県多野郡吉井町塩川', '10', '10363', '3702134', '群馬県', 'グンマケン', '多野郡吉井町', 'タノグンヨシイマチ', '塩川', 'シオガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県多野郡吉井町片山', '10', '10363', '3702135', '群馬県', 'グンマケン', '多野郡吉井町', 'タノグンヨシイマチ', '片山', 'カタヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県多野郡吉井町小棚', '10', '10363', '3702136', '群馬県', 'グンマケン', '多野郡吉井町', 'タノグンヨシイマチ', '小棚', 'コタナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県多野郡吉井町坂口', '10', '10363', '3702137', '群馬県', 'グンマケン', '多野郡吉井町', 'タノグンヨシイマチ', '坂口', 'サカグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県多野郡吉井町下奥平', '10', '10363', '3702138', '群馬県', 'グンマケン', '多野郡吉井町', 'タノグンヨシイマチ', '下奥平', 'シモオクダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県多野郡吉井町上奥平', '10', '10363', '3702139', '群馬県', 'グンマケン', '多野郡吉井町', 'タノグンヨシイマチ', '上奥平', 'カミオクダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県甘楽郡甘楽町', '10', '10384', '3702200', '群馬県', 'グンマケン', '甘楽郡甘楽町', 'カンラグンカンラマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('30662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県甘楽郡甘楽町上野', '10', '10384', '3702201', '群馬県', 'グンマケン', '甘楽郡甘楽町', 'カンラグンカンラマチ', '上野', 'ウエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県甘楽郡甘楽町小幡', '10', '10384', '3702202', '群馬県', 'グンマケン', '甘楽郡甘楽町', 'カンラグンカンラマチ', '小幡', 'オバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県甘楽郡甘楽町轟', '10', '10384', '3702203', '群馬県', 'グンマケン', '甘楽郡甘楽町', 'カンラグンカンラマチ', '轟', 'トドロク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県甘楽郡甘楽町秋畑', '10', '10384', '3702204', '群馬県', 'グンマケン', '甘楽郡甘楽町', 'カンラグンカンラマチ', '秋畑', 'アキハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県甘楽郡甘楽町国峰', '10', '10384', '3702205', '群馬県', 'グンマケン', '甘楽郡甘楽町', 'カンラグンカンラマチ', '国峰', 'クニミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県甘楽郡甘楽町善慶寺', '10', '10384', '3702206', '群馬県', 'グンマケン', '甘楽郡甘楽町', 'カンラグンカンラマチ', '善慶寺', 'ゼンケイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県甘楽郡甘楽町小川', '10', '10384', '3702211', '群馬県', 'グンマケン', '甘楽郡甘楽町', 'カンラグンカンラマチ', '小川', 'オガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県甘楽郡甘楽町福島', '10', '10384', '3702212', '群馬県', 'グンマケン', '甘楽郡甘楽町', 'カンラグンカンラマチ', '福島', 'フクシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県甘楽郡甘楽町白倉', '10', '10384', '3702213', '群馬県', 'グンマケン', '甘楽郡甘楽町', 'カンラグンカンラマチ', '白倉', 'シラクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県甘楽郡甘楽町庭谷', '10', '10384', '3702214', '群馬県', 'グンマケン', '甘楽郡甘楽町', 'カンラグンカンラマチ', '庭谷', 'ニワヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県甘楽郡甘楽町造石', '10', '10384', '3702215', '群馬県', 'グンマケン', '甘楽郡甘楽町', 'カンラグンカンラマチ', '造石', 'ツクリイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県甘楽郡甘楽町金井', '10', '10384', '3702216', '群馬県', 'グンマケン', '甘楽郡甘楽町', 'カンラグンカンラマチ', '金井', 'カナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県甘楽郡甘楽町天引', '10', '10384', '3702217', '群馬県', 'グンマケン', '甘楽郡甘楽町', 'カンラグンカンラマチ', '天引', 'アマビキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県富岡市', '10', '10210', '3702300', '群馬県', 'グンマケン', '富岡市', 'トミオカシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('30677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県富岡市桑原', '10', '10210', '3702301', '群馬県', 'グンマケン', '富岡市', 'トミオカシ', '桑原', 'クワハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県富岡市小桑原', '10', '10210', '3702302', '群馬県', 'グンマケン', '富岡市', 'トミオカシ', '小桑原', 'コクワハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県富岡市蕨', '10', '10210', '3702303', '群馬県', 'グンマケン', '富岡市', 'トミオカシ', '蕨', 'ワラビ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県富岡市後賀', '10', '10210', '3702304', '群馬県', 'グンマケン', '富岡市', 'トミオカシ', '後賀', 'ゴカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県富岡市白岩', '10', '10210', '3702305', '群馬県', 'グンマケン', '富岡市', 'トミオカシ', '白岩', 'シライワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県富岡市相野田', '10', '10210', '3702306', '群馬県', 'グンマケン', '富岡市', 'トミオカシ', '相野田', 'アイノタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県富岡市藤木', '10', '10210', '3702307', '群馬県', 'グンマケン', '富岡市', 'トミオカシ', '藤木', 'フジキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県富岡市下高尾', '10', '10210', '3702311', '群馬県', 'グンマケン', '富岡市', 'トミオカシ', '下高尾', 'シモタカオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県富岡市星田', '10', '10210', '3702312', '群馬県', 'グンマケン', '富岡市', 'トミオカシ', '星田', 'ホシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県富岡市君川', '10', '10210', '3702313', '群馬県', 'グンマケン', '富岡市', 'トミオカシ', '君川', 'キミカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県富岡市田篠', '10', '10210', '3702314', '群馬県', 'グンマケン', '富岡市', 'トミオカシ', '田篠', 'タジノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県富岡市曾木', '10', '10210', '3702315', '群馬県', 'グンマケン', '富岡市', 'トミオカシ', '曾木', 'ソギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県富岡市富岡', '10', '10210', '3702316', '群馬県', 'グンマケン', '富岡市', 'トミオカシ', '富岡', 'トミオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県富岡市上高尾', '10', '10210', '3702317', '群馬県', 'グンマケン', '富岡市', 'トミオカシ', '上高尾', 'カミタカオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県富岡市岡本', '10', '10210', '3702321', '群馬県', 'グンマケン', '富岡市', 'トミオカシ', '岡本', 'オカモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県富岡市岩染', '10', '10210', '3702322', '群馬県', 'グンマケン', '富岡市', 'トミオカシ', '岩染', 'イワソメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県富岡市野上', '10', '10210', '3702323', '群馬県', 'グンマケン', '富岡市', 'トミオカシ', '野上', 'ノガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県富岡市南後箇', '10', '10210', '3702324', '群馬県', 'グンマケン', '富岡市', 'トミオカシ', '南後箇', 'ミナミゴカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県富岡市内匠', '10', '10210', '3702331', '群馬県', 'グンマケン', '富岡市', 'トミオカシ', '内匠', 'タクミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県富岡市下高瀬', '10', '10210', '3702332', '群馬県', 'グンマケン', '富岡市', 'トミオカシ', '下高瀬', 'シモダカセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県富岡市中高瀬', '10', '10210', '3702333', '群馬県', 'グンマケン', '富岡市', 'トミオカシ', '中高瀬', 'ナカダカセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県富岡市上高瀬', '10', '10210', '3702334', '群馬県', 'グンマケン', '富岡市', 'トミオカシ', '上高瀬', 'カミダカセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県富岡市大島', '10', '10210', '3702335', '群馬県', 'グンマケン', '富岡市', 'トミオカシ', '大島', 'オオシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県富岡市下黒岩', '10', '10210', '3702341', '群馬県', 'グンマケン', '富岡市', 'トミオカシ', '下黒岩', 'シモクロイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県富岡市別保', '10', '10210', '3702342', '群馬県', 'グンマケン', '富岡市', 'トミオカシ', '別保', 'ベツポ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県富岡市七日市', '10', '10210', '3702343', '群馬県', 'グンマケン', '富岡市', 'トミオカシ', '七日市', 'ナノカイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県富岡市黒川', '10', '10210', '3702344', '群馬県', 'グンマケン', '富岡市', 'トミオカシ', '黒川', 'クロカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県富岡市上黒岩', '10', '10210', '3702345', '群馬県', 'グンマケン', '富岡市', 'トミオカシ', '上黒岩', 'カミクロイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県富岡市妙義町上高田', '10', '10210', '3702411', '群馬県', 'グンマケン', '富岡市', 'トミオカシ', '妙義町上高田', 'ミョウギマチカミタカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県富岡市妙義町下高田', '10', '10210', '3702412', '群馬県', 'グンマケン', '富岡市', 'トミオカシ', '妙義町下高田', 'ミョウギマチシモタカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県富岡市妙義町八木連', '10', '10210', '3702413', '群馬県', 'グンマケン', '富岡市', 'トミオカシ', '妙義町八木連', 'ミョウギマチヤギツレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県富岡市宇田', '10', '10210', '3702451', '群馬県', 'グンマケン', '富岡市', 'トミオカシ', '宇田', 'ウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県富岡市一ノ宮', '10', '10210', '3702452', '群馬県', 'グンマケン', '富岡市', 'トミオカシ', '一ノ宮', 'イチノミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県富岡市宮崎', '10', '10210', '3702453', '群馬県', 'グンマケン', '富岡市', 'トミオカシ', '宮崎', 'ミヤザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県富岡市田島', '10', '10210', '3702454', '群馬県', 'グンマケン', '富岡市', 'トミオカシ', '田島', 'タジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県富岡市神農原', '10', '10210', '3702455', '群馬県', 'グンマケン', '富岡市', 'トミオカシ', '神農原', 'カノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県富岡市上小林', '10', '10210', '3702456', '群馬県', 'グンマケン', '富岡市', 'トミオカシ', '上小林', 'カミコバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県富岡市上丹生', '10', '10210', '3702461', '群馬県', 'グンマケン', '富岡市', 'トミオカシ', '上丹生', 'カミニュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県富岡市下丹生', '10', '10210', '3702462', '群馬県', 'グンマケン', '富岡市', 'トミオカシ', '下丹生', 'シモニュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県富岡市神成', '10', '10210', '3702463', '群馬県', 'グンマケン', '富岡市', 'トミオカシ', '神成', 'カンナリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県富岡市南蛇井', '10', '10210', '3702464', '群馬県', 'グンマケン', '富岡市', 'トミオカシ', '南蛇井', 'ナンジャイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県富岡市中沢', '10', '10210', '3702465', '群馬県', 'グンマケン', '富岡市', 'トミオカシ', '中沢', 'ナカザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県富岡市蚊沼', '10', '10210', '3702466', '群馬県', 'グンマケン', '富岡市', 'トミオカシ', '蚊沼', 'カヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県富岡市原', '10', '10210', '3702467', '群馬県', 'グンマケン', '富岡市', 'トミオカシ', '原', 'ハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県甘楽郡下仁田町', '10', '10382', '3702600', '群馬県', 'グンマケン', '甘楽郡下仁田町', 'カンラグンシモニタマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('30730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県甘楽郡下仁田町下仁田', '10', '10382', '3702601', '群馬県', 'グンマケン', '甘楽郡下仁田町', 'カンラグンシモニタマチ', '下仁田', 'シモニタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県甘楽郡下仁田町白山', '10', '10382', '3702602', '群馬県', 'グンマケン', '甘楽郡下仁田町', 'カンラグンシモニタマチ', '白山', 'ハクサン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県甘楽郡下仁田町馬山', '10', '10382', '3702603', '群馬県', 'グンマケン', '甘楽郡下仁田町', 'カンラグンシモニタマチ', '馬山', 'マヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県甘楽郡下仁田町吉崎', '10', '10382', '3702604', '群馬県', 'グンマケン', '甘楽郡下仁田町', 'カンラグンシモニタマチ', '吉崎', 'ヨシザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県甘楽郡下仁田町栗山', '10', '10382', '3702605', '群馬県', 'グンマケン', '甘楽郡下仁田町', 'カンラグンシモニタマチ', '栗山', 'クリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県甘楽郡下仁田町川井', '10', '10382', '3702606', '群馬県', 'グンマケン', '甘楽郡下仁田町', 'カンラグンシモニタマチ', '川井', 'カワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県甘楽郡下仁田町青倉', '10', '10382', '3702611', '群馬県', 'グンマケン', '甘楽郡下仁田町', 'カンラグンシモニタマチ', '青倉', 'アオクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県甘楽郡下仁田町平原', '10', '10382', '3702612', '群馬県', 'グンマケン', '甘楽郡下仁田町', 'カンラグンシモニタマチ', '平原', 'ヘバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県甘楽郡下仁田町大桑原', '10', '10382', '3702613', '群馬県', 'グンマケン', '甘楽郡下仁田町', 'カンラグンシモニタマチ', '大桑原', 'オオクワハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県甘楽郡下仁田町風口', '10', '10382', '3702614', '群馬県', 'グンマケン', '甘楽郡下仁田町', 'カンラグンシモニタマチ', '風口', 'カザクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県甘楽郡下仁田町宮室', '10', '10382', '3702615', '群馬県', 'グンマケン', '甘楽郡下仁田町', 'カンラグンシモニタマチ', '宮室', 'ミヤムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県甘楽郡下仁田町下郷', '10', '10382', '3702616', '群馬県', 'グンマケン', '甘楽郡下仁田町', 'カンラグンシモニタマチ', '下郷', 'シモゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県甘楽郡下仁田町上小坂', '10', '10382', '3702621', '群馬県', 'グンマケン', '甘楽郡下仁田町', 'カンラグンシモニタマチ', '上小坂', 'カミオサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県甘楽郡下仁田町中小坂', '10', '10382', '3702622', '群馬県', 'グンマケン', '甘楽郡下仁田町', 'カンラグンシモニタマチ', '中小坂', 'ナカオサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県甘楽郡下仁田町下小坂', '10', '10382', '3702623', '群馬県', 'グンマケン', '甘楽郡下仁田町', 'カンラグンシモニタマチ', '下小坂', 'シモオサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県甘楽郡下仁田町東野牧', '10', '10382', '3702624', '群馬県', 'グンマケン', '甘楽郡下仁田町', 'カンラグンシモニタマチ', '東野牧', 'ヒガシノマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県甘楽郡下仁田町本宿', '10', '10382', '3702625', '群馬県', 'グンマケン', '甘楽郡下仁田町', 'カンラグンシモニタマチ', '本宿', 'モトジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県甘楽郡下仁田町南野牧', '10', '10382', '3702626', '群馬県', 'グンマケン', '甘楽郡下仁田町', 'カンラグンシモニタマチ', '南野牧', 'ミナミノマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県甘楽郡下仁田町西野牧', '10', '10382', '3702627', '群馬県', 'グンマケン', '甘楽郡下仁田町', 'カンラグンシモニタマチ', '西野牧', 'ニシノマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県甘楽郡南牧村', '10', '10383', '3702800', '群馬県', 'グンマケン', '甘楽郡南牧村', 'カンラグンナンモクムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('30750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県甘楽郡南牧村大塩沢', '10', '10383', '3702801', '群馬県', 'グンマケン', '甘楽郡南牧村', 'カンラグンナンモクムラ', '大塩沢', 'オオシオザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県甘楽郡南牧村小沢', '10', '10383', '3702802', '群馬県', 'グンマケン', '甘楽郡南牧村', 'カンラグンナンモクムラ', '小沢', 'オザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県甘楽郡南牧村千原', '10', '10383', '3702803', '群馬県', 'グンマケン', '甘楽郡南牧村', 'カンラグンナンモクムラ', '千原', 'チハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県甘楽郡南牧村磐戸', '10', '10383', '3702804', '群馬県', 'グンマケン', '甘楽郡南牧村', 'カンラグンナンモクムラ', '磐戸', 'イワド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県甘楽郡南牧村檜沢', '10', '10383', '3702805', '群馬県', 'グンマケン', '甘楽郡南牧村', 'カンラグンナンモクムラ', '檜沢', 'ヒサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県甘楽郡南牧村大日向', '10', '10383', '3702806', '群馬県', 'グンマケン', '甘楽郡南牧村', 'カンラグンナンモクムラ', '大日向', 'オオヒナタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県甘楽郡南牧村六車', '10', '10383', '3702811', '群馬県', 'グンマケン', '甘楽郡南牧村', 'カンラグンナンモクムラ', '六車', 'ムクルマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県甘楽郡南牧村大仁田', '10', '10383', '3702812', '群馬県', 'グンマケン', '甘楽郡南牧村', 'カンラグンナンモクムラ', '大仁田', 'オオニタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県甘楽郡南牧村砥沢', '10', '10383', '3702813', '群馬県', 'グンマケン', '甘楽郡南牧村', 'カンラグンナンモクムラ', '砥沢', 'トザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県甘楽郡南牧村羽沢', '10', '10383', '3702814', '群馬県', 'グンマケン', '甘楽郡南牧村', 'カンラグンナンモクムラ', '羽沢', 'ハザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県甘楽郡南牧村熊倉', '10', '10383', '3702815', '群馬県', 'グンマケン', '甘楽郡南牧村', 'カンラグンナンモクムラ', '熊倉', 'クマクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県甘楽郡南牧村星尾', '10', '10383', '3702816', '群馬県', 'グンマケン', '甘楽郡南牧村', 'カンラグンナンモクムラ', '星尾', 'ホシオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県北津軽郡中泊町', '02', '02387', '0370300', '青森県', 'アオモリケン', '北津軽郡中泊町', 'キタツガルグンナカドマリマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('30763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県北津軽郡中泊町今泉', '02', '02387', '0370301', '青森県', 'アオモリケン', '北津軽郡中泊町', 'キタツガルグンナカドマリマチ', '今泉', 'イマイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県北津軽郡中泊町薄市', '02', '02387', '0370302', '青森県', 'アオモリケン', '北津軽郡中泊町', 'キタツガルグンナカドマリマチ', '薄市', 'ウスイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県北津軽郡中泊町高根', '02', '02387', '0370303', '青森県', 'アオモリケン', '北津軽郡中泊町', 'キタツガルグンナカドマリマチ', '高根', 'タカネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県北津軽郡中泊町尾別', '02', '02387', '0370304', '青森県', 'アオモリケン', '北津軽郡中泊町', 'キタツガルグンナカドマリマチ', '尾別', 'オッペツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県北津軽郡中泊町中里', '02', '02387', '0370305', '青森県', 'アオモリケン', '北津軽郡中泊町', 'キタツガルグンナカドマリマチ', '中里', 'ナカサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県北津軽郡中泊町宮川', '02', '02387', '0370306', '青森県', 'アオモリケン', '北津軽郡中泊町', 'キタツガルグンナカドマリマチ', '宮川', 'ミヤカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県北津軽郡中泊町宮野沢', '02', '02387', '0370307', '青森県', 'アオモリケン', '北津軽郡中泊町', 'キタツガルグンナカドマリマチ', '宮野沢', 'ミヤノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県北津軽郡中泊町深郷田', '02', '02387', '0370308', '青森県', 'アオモリケン', '北津軽郡中泊町', 'キタツガルグンナカドマリマチ', '深郷田', 'フコウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県北津軽郡中泊町八幡', '02', '02387', '0370309', '青森県', 'アオモリケン', '北津軽郡中泊町', 'キタツガルグンナカドマリマチ', '八幡', 'ハチマン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市箕郷町柏木沢', '10', '10202', '3703101', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '箕郷町柏木沢', 'ミサトマチカシワギザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市箕郷町生原', '10', '10202', '3703102', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '箕郷町生原', 'ミサトマチオイバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市箕郷町下芝', '10', '10202', '3703103', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '箕郷町下芝', 'ミサトマチシモシバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市箕郷町上芝', '10', '10202', '3703104', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '箕郷町上芝', 'ミサトマチカミシバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市箕郷町西明屋', '10', '10202', '3703105', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '箕郷町西明屋', 'ミサトマチニシアキヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市箕郷町東明屋', '10', '10202', '3703106', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '箕郷町東明屋', 'ミサトマチヒガシアキヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市箕郷町矢原', '10', '10202', '3703107', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '箕郷町矢原', 'ミサトマチヤバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県北津軽郡中泊町大沢内', '02', '02387', '0370311', '青森県', 'アオモリケン', '北津軽郡中泊町', 'キタツガルグンナカドマリマチ', '大沢内', 'オオサワナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市箕郷町中野', '10', '10202', '3703111', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '箕郷町中野', 'ミサトマチナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市箕郷町善地', '10', '10202', '3703112', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '箕郷町善地', 'ミサトマチゼンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市箕郷町松之沢', '10', '10202', '3703113', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '箕郷町松之沢', 'ミサトマチマツノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市箕郷町金敷平', '10', '10202', '3703114', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '箕郷町金敷平', 'ミサトマチカナシキダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市箕郷町富岡', '10', '10202', '3703115', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '箕郷町富岡', 'ミサトマチトミオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市箕郷町和田山', '10', '10202', '3703116', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '箕郷町和田山', 'ミサトマチワダヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市箕郷町白川', '10', '10202', '3703117', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '箕郷町白川', 'ミサトマチシラカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県北津軽郡中泊町豊島', '02', '02387', '0370312', '青森県', 'アオモリケン', '北津軽郡中泊町', 'キタツガルグンナカドマリマチ', '豊島', 'トヨシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県北津軽郡中泊町富野', '02', '02387', '0370313', '青森県', 'アオモリケン', '北津軽郡中泊町', 'キタツガルグンナカドマリマチ', '富野', 'トミノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県北津軽郡中泊町福浦', '02', '02387', '0370314', '青森県', 'アオモリケン', '北津軽郡中泊町', 'キタツガルグンナカドマリマチ', '福浦', 'フクウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県北津軽郡中泊町豊岡', '02', '02387', '0370315', '青森県', 'アオモリケン', '北津軽郡中泊町', 'キタツガルグンナカドマリマチ', '豊岡', 'トヨオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県北津軽郡中泊町芦野', '02', '02387', '0370316', '青森県', 'アオモリケン', '北津軽郡中泊町', 'キタツガルグンナカドマリマチ', '芦野', 'アシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県北津軽郡中泊町長泥', '02', '02387', '0370317', '青森県', 'アオモリケン', '北津軽郡中泊町', 'キタツガルグンナカドマリマチ', '長泥', 'ナガドロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県北津軽郡中泊町田茂木', '02', '02387', '0370318', '青森県', 'アオモリケン', '北津軽郡中泊町', 'キタツガルグンナカドマリマチ', '田茂木', 'タモギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県吾妻郡東吾妻町岡崎烏帽子「榛名湖畔」', '10', '10429', '3703311', '群馬県', 'グンマケン', '吾妻郡東吾妻町', 'アガツマグンヒガシアガツママチ', '岡崎', 'オカザキ', null, null, '烏帽子「榛名湖畔」', 'エボシ＜ハルナコハン＞');
INSERT INTO `ms_addresses` VALUES ('30796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県吾妻郡東吾妻町泉沢烏帽子「榛名湖畔」', '10', '10429', '3703321', '群馬県', 'グンマケン', '吾妻郡東吾妻町', 'アガツマグンヒガシアガツママチ', '泉沢', 'イズミサワ', null, null, '烏帽子「榛名湖畔」', '（エボシ（ハルナコハン）');
INSERT INTO `ms_addresses` VALUES ('30797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県吾妻郡東吾妻町泉沢烏帽子国有林77林班', '10', '10429', '3703321', '群馬県', 'グンマケン', '吾妻郡東吾妻町', 'アガツマグンヒガシアガツママチ', '泉沢', 'イズミサワ', null, null, '烏帽子国有林77林班', 'エボシコクユウリン77リンハン）');
INSERT INTO `ms_addresses` VALUES ('30798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県吾妻郡東吾妻町川戸烏帽子「榛名湖畔」', '10', '10429', '3703322', '群馬県', 'グンマケン', '吾妻郡東吾妻町', 'アガツマグンヒガシアガツママチ', '川戸', 'カワド', null, null, '烏帽子「榛名湖畔」', 'エボシ＜ハルナコハン＞');
INSERT INTO `ms_addresses` VALUES ('30799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市十文字町', '10', '10202', '3703331', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '十文字町', 'ジュウモンジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市白岩町', '10', '10202', '3703332', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '白岩町', 'シライワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市高浜町', '10', '10202', '3703333', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '高浜町', 'タカハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市本郷町', '10', '10202', '3703334', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '本郷町', 'ホンゴウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市上大島町', '10', '10202', '3703335', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '上大島町', 'カミオオシママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市神戸町', '10', '10202', '3703336', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '神戸町', 'ゴウドマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市三ツ子沢町', '10', '10202', '3703337', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '三ツ子沢町', 'ミツゴサワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市宮沢町', '10', '10202', '3703338', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '宮沢町', 'ミヤザワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市榛名山町', '10', '10202', '3703341', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '榛名山町', 'ハルナサンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市下室田町', '10', '10202', '3703342', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '下室田町', 'シモムロダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市下里見町', '10', '10202', '3703343', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '下里見町', 'シモサトミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市中里見町', '10', '10202', '3703344', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '中里見町', 'ナカサトミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市上里見町', '10', '10202', '3703345', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '上里見町', 'カミサトミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市上室田町', '10', '10202', '3703346', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '上室田町', 'カミムロダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市中室田町', '10', '10202', '3703347', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '中室田町', 'ナカムロダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市榛名湖町', '10', '10202', '3703348', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '榛名湖町', 'ハルナコマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市倉渕町権田', '10', '10202', '3703401', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '倉渕町権田', 'クラブチマチゴンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市倉渕町三ノ倉', '10', '10202', '3703402', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '倉渕町三ノ倉', 'クラブチマチサンノクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市倉渕町水沼', '10', '10202', '3703403', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '倉渕町水沼', 'クラブチマチミズヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市倉渕町岩氷', '10', '10202', '3703404', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '倉渕町岩氷', 'クラブチマチイワコオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市倉渕町川浦', '10', '10202', '3703405', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '倉渕町川浦', 'クラブチマチカワウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県北群馬郡榛東村', '10', '10344', '3703500', '群馬県', 'グンマケン', '北群馬郡榛東村', 'キタグンマグンシントウムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('30824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県北群馬郡榛東村長岡', '10', '10344', '3703501', '群馬県', 'グンマケン', '北群馬郡榛東村', 'キタグンマグンシントウムラ', '長岡', 'ナガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県北群馬郡榛東村山子田', '10', '10344', '3703502', '群馬県', 'グンマケン', '北群馬郡榛東村', 'キタグンマグンシントウムラ', '山子田', 'ヤマコダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県北群馬郡榛東村新井', '10', '10344', '3703503', '群馬県', 'グンマケン', '北群馬郡榛東村', 'キタグンマグンシントウムラ', '新井', 'アライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県北群馬郡榛東村広馬場', '10', '10344', '3703504', '群馬県', 'グンマケン', '北群馬郡榛東村', 'キタグンマグンシントウムラ', '広馬場', 'ヒロババ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県北群馬郡榛東村上野原', '10', '10344', '3703505', '群馬県', 'グンマケン', '北群馬郡榛東村', 'キタグンマグンシントウムラ', '上野原', 'ウエノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市金古町', '10', '10202', '3703511', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '金古町', 'カネコマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市西国分町', '10', '10202', '3703512', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '西国分町', 'ニシコクブマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市北原町', '10', '10202', '3703513', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '北原町', 'キタハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市東国分町', '10', '10202', '3703514', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '東国分町', 'ヒガシコクブマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市塚田町', '10', '10202', '3703515', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '塚田町', 'ツカダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市稲荷台町', '10', '10202', '3703516', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '稲荷台町', 'トウカダイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市引間町', '10', '10202', '3703517', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '引間町', 'ヒキママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市後疋間町', '10', '10202', '3703518', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '後疋間町', 'ウシロヒキママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市冷水町', '10', '10202', '3703519', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '冷水町', 'ヒヤミズマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市棟高町', '10', '10202', '3703521', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '棟高町', 'ムナダカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市菅谷町', '10', '10202', '3703522', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '菅谷町', 'スガヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市福島町', '10', '10202', '3703523', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '福島町', 'フクシママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市中泉町', '10', '10202', '3703524', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '中泉町', 'ナカイズミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市三ツ寺町', '10', '10202', '3703525', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '三ツ寺町', 'ミツデラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市足門町', '10', '10202', '3703531', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '足門町', 'アシカドマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市中里町', '10', '10202', '3703532', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '中里町', 'ナカザトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市保渡田町', '10', '10202', '3703533', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '保渡田町', 'ホドタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県高崎市井出町', '10', '10202', '3703534', '群馬県', 'グンマケン', '高崎市', 'タカサキシ', '井出町', 'イデマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市池端町', '10', '10201', '3703571', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '池端町', 'イケハタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市上青梨子町', '10', '10201', '3703572', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '上青梨子町', 'カミアオナシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市青梨子町', '10', '10201', '3703573', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '青梨子町', 'アオナシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市清野町', '10', '10201', '3703574', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '清野町', 'キヨノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県北群馬郡吉岡町', '10', '10345', '3703600', '群馬県', 'グンマケン', '北群馬郡吉岡町', 'キタグンマグンヨシオカマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('30855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県北群馬郡吉岡町漆原', '10', '10345', '3703601', '群馬県', 'グンマケン', '北群馬郡吉岡町', 'キタグンマグンヨシオカマチ', '漆原', 'ウルシバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県北群馬郡吉岡町大久保', '10', '10345', '3703602', '群馬県', 'グンマケン', '北群馬郡吉岡町', 'キタグンマグンヨシオカマチ', '大久保', 'オオクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県北群馬郡吉岡町陣場', '10', '10345', '3703603', '群馬県', 'グンマケン', '北群馬郡吉岡町', 'キタグンマグンヨシオカマチ', '陣場', 'ジンバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県北群馬郡吉岡町南下', '10', '10345', '3703604', '群馬県', 'グンマケン', '北群馬郡吉岡町', 'キタグンマグンヨシオカマチ', '南下', 'ミナミシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県北群馬郡吉岡町北下', '10', '10345', '3703605', '群馬県', 'グンマケン', '北群馬郡吉岡町', 'キタグンマグンヨシオカマチ', '北下', 'キタシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県北群馬郡吉岡町上野田', '10', '10345', '3703606', '群馬県', 'グンマケン', '北群馬郡吉岡町', 'キタグンマグンヨシオカマチ', '上野田', 'カミノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県北群馬郡吉岡町小倉', '10', '10345', '3703607', '群馬県', 'グンマケン', '北群馬郡吉岡町', 'キタグンマグンヨシオカマチ', '小倉', 'オグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県北群馬郡吉岡町下野田', '10', '10345', '3703608', '群馬県', 'グンマケン', '北群馬郡吉岡町', 'キタグンマグンヨシオカマチ', '下野田', 'シモノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県五所川原市相内', '02', '02205', '0370401', '青森県', 'アオモリケン', '五所川原市', 'ゴショガワラシ', '相内', 'アイウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県五所川原市太田', '02', '02205', '0370402', '青森県', 'アオモリケン', '五所川原市', 'ゴショガワラシ', '太田', 'オオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県五所川原市十三', '02', '02205', '0370403', '青森県', 'アオモリケン', '五所川原市', 'ゴショガワラシ', '十三', 'ジュウサン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県五所川原市磯松', '02', '02205', '0370404', '青森県', 'アオモリケン', '五所川原市', 'ゴショガワラシ', '磯松', 'イソマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県五所川原市脇元', '02', '02205', '0370405', '青森県', 'アオモリケン', '五所川原市', 'ゴショガワラシ', '脇元', 'ワキモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県北津軽郡中泊町小泊砂山', '02', '02387', '0370511', '青森県', 'アオモリケン', '北津軽郡中泊町', 'キタツガルグンナカドマリマチ', '小泊砂山', 'コドマリスナヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県北津軽郡中泊町小泊朝間', '02', '02387', '0370512', '青森県', 'アオモリケン', '北津軽郡中泊町', 'キタツガルグンナカドマリマチ', '小泊朝間', 'コドマリアサマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県北津軽郡中泊町小泊割長根', '02', '02387', '0370513', '青森県', 'アオモリケン', '北津軽郡中泊町', 'キタツガルグンナカドマリマチ', '小泊割長根', 'コドマリワリナガネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県北津軽郡中泊町小泊浜野', '02', '02387', '0370514', '青森県', 'アオモリケン', '北津軽郡中泊町', 'キタツガルグンナカドマリマチ', '小泊浜野', 'コドマリハマノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県北津軽郡中泊町小泊折戸', '02', '02387', '0370521', '青森県', 'アオモリケン', '北津軽郡中泊町', 'キタツガルグンナカドマリマチ', '小泊折戸', 'コドマリオリト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県北津軽郡中泊町小泊小泊', '02', '02387', '0370522', '青森県', 'アオモリケン', '北津軽郡中泊町', 'キタツガルグンナカドマリマチ', '小泊小泊', 'コドマリコドマリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県北津軽郡中泊町小泊稲荷', '02', '02387', '0370523', '青森県', 'アオモリケン', '北津軽郡中泊町', 'キタツガルグンナカドマリマチ', '小泊稲荷', 'コドマリイナリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県北津軽郡中泊町小泊水澗', '02', '02387', '0370524', '青森県', 'アオモリケン', '北津軽郡中泊町', 'キタツガルグンナカドマリマチ', '小泊水澗', 'コドマリミズノマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県北津軽郡中泊町小泊鮫貝', '02', '02387', '0370525', '青森県', 'アオモリケン', '北津軽郡中泊町', 'キタツガルグンナカドマリマチ', '小泊鮫貝', 'コドマリサメガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県北津軽郡中泊町小泊長坂', '02', '02387', '0370531', '青森県', 'アオモリケン', '北津軽郡中泊町', 'キタツガルグンナカドマリマチ', '小泊長坂', 'コドマリナガサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県北津軽郡中泊町小泊梨子木平', '02', '02387', '0370532', '青森県', 'アオモリケン', '北津軽郡中泊町', 'キタツガルグンナカドマリマチ', '小泊梨子木平', 'コドマリナシキタイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県北津軽郡中泊町小泊白倉', '02', '02387', '0370533', '青森県', 'アオモリケン', '北津軽郡中泊町', 'キタツガルグンナカドマリマチ', '小泊白倉', 'コドマリシロクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県北津軽郡中泊町小泊漆流', '02', '02387', '0370534', '青森県', 'アオモリケン', '北津軽郡中泊町', 'キタツガルグンナカドマリマチ', '小泊漆流', 'コドマリウルシナガレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県北津軽郡中泊町小泊尾崎道', '02', '02387', '0370535', '青森県', 'アオモリケン', '北津軽郡中泊町', 'キタツガルグンナカドマリマチ', '小泊尾崎道', 'コドマリオサキミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県北津軽郡中泊町小泊中間', '02', '02387', '0370536', '青森県', 'アオモリケン', '北津軽郡中泊町', 'キタツガルグンナカドマリマチ', '小泊中間', 'コドマリナカマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県北津軽郡中泊町小泊渕岩', '02', '02387', '0370537', '青森県', 'アオモリケン', '北津軽郡中泊町', 'キタツガルグンナカドマリマチ', '小泊渕岩', 'コドマリフチイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県北津軽郡中泊町小泊下前', '02', '02387', '0370538', '青森県', 'アオモリケン', '北津軽郡中泊町', 'キタツガルグンナカドマリマチ', '小泊下前', 'コドマリシタマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県北津軽郡中泊町小泊嗽沢', '02', '02387', '0370541', '青森県', 'アオモリケン', '北津軽郡中泊町', 'キタツガルグンナカドマリマチ', '小泊嗽沢', 'コドマリウガイサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県北津軽郡中泊町小泊大山長根', '02', '02387', '0370542', '青森県', 'アオモリケン', '北津軽郡中泊町', 'キタツガルグンナカドマリマチ', '小泊大山長根', 'コドマリオオヤマナガネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県北津軽郡中泊町小泊坊主沢', '02', '02387', '0370543', '青森県', 'アオモリケン', '北津軽郡中泊町', 'キタツガルグンナカドマリマチ', '小泊坊主沢', 'コドマリボウズサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県五所川原市戸沢', '02', '02205', '0370601', '青森県', 'アオモリケン', '五所川原市', 'ゴショガワラシ', '戸沢', 'トザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県五所川原市松野木', '02', '02205', '0370602', '青森県', 'アオモリケン', '五所川原市', 'ゴショガワラシ', '松野木', 'マツノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県五所川原市神山', '02', '02205', '0370611', '青森県', 'アオモリケン', '五所川原市', 'ゴショガワラシ', '神山', 'カミヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県五所川原市福山', '02', '02205', '0370612', '青森県', 'アオモリケン', '五所川原市', 'ゴショガワラシ', '福山', 'フクヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県五所川原市浅井', '02', '02205', '0370613', '青森県', 'アオモリケン', '五所川原市', 'ゴショガワラシ', '浅井', 'アサイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県五所川原市野里', '02', '02205', '0370614', '青森県', 'アオモリケン', '五所川原市', 'ゴショガワラシ', '野里', 'ノザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県五所川原市豊成', '02', '02205', '0370621', '青森県', 'アオモリケン', '五所川原市', 'ゴショガワラシ', '豊成', 'トヨナリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県五所川原市原子', '02', '02205', '0370622', '青森県', 'アオモリケン', '五所川原市', 'ゴショガワラシ', '原子', 'ハラコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県五所川原市俵元', '02', '02205', '0370623', '青森県', 'アオモリケン', '五所川原市', 'ゴショガワラシ', '俵元', 'タワラモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県五所川原市前田野目', '02', '02205', '0370631', '青森県', 'アオモリケン', '五所川原市', 'ゴショガワラシ', '前田野目', 'マエダノメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県五所川原市高野', '02', '02205', '0370632', '青森県', 'アオモリケン', '五所川原市', 'ゴショガワラシ', '高野', 'コウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県五所川原市羽野木沢', '02', '02205', '0370641', '青森県', 'アオモリケン', '五所川原市', 'ゴショガワラシ', '羽野木沢', 'ハノキザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県五所川原市持子沢', '02', '02205', '0370642', '青森県', 'アオモリケン', '五所川原市', 'ゴショガワラシ', '持子沢', 'モッコザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市', '10', '10201', '3710000', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('30922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市荻窪町', '10', '10201', '3710001', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '荻窪町', 'オギクボマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市江木町', '10', '10201', '3710002', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '江木町', 'エギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市堤町', '10', '10201', '3710003', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '堤町', 'ツツミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市亀泉町', '10', '10201', '3710004', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '亀泉町', 'カメイズミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市堀之下町', '10', '10201', '3710005', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '堀之下町', 'ホリノシタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市石関町', '10', '10201', '3710006', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '石関町', 'イシゼキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市上泉町', '10', '10201', '3710007', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '上泉町', 'カミイズミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市下沖町', '10', '10201', '3710011', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '下沖町', 'シモオキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市東片貝町', '10', '10201', '3710012', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '東片貝町', 'ヒガシカタカイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市西片貝町', '10', '10201', '3710013', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '西片貝町', 'ニシカタカイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市朝日町', '10', '10201', '3710014', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '朝日町', 'アサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市三河町', '10', '10201', '3710015', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '三河町', 'ミカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市城東町', '10', '10201', '3710016', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '城東町', 'ジョウトウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市日吉町', '10', '10201', '3710017', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '日吉町', 'ヒヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市三俣町', '10', '10201', '3710018', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '三俣町', 'ミツマタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市住吉町', '10', '10201', '3710021', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '住吉町', 'スミヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市千代田町', '10', '10201', '3710022', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '千代田町', 'チヨダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市本町', '10', '10201', '3710023', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市表町', '10', '10201', '3710024', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '表町', 'オモテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市紅雲町', '10', '10201', '3710025', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '紅雲町', 'コウウンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市大手町', '10', '10201', '3710026', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '大手町', 'オオテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市平和町', '10', '10201', '3710027', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '平和町', 'ヘイワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市下小出町', '10', '10201', '3710031', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '下小出町', 'シモコイデマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市若宮町', '10', '10201', '3710032', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '若宮町', 'ワカミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市国領町', '10', '10201', '3710033', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '国領町', 'コクリョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市昭和町', '10', '10201', '3710034', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '昭和町', 'ショウワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市岩神町', '10', '10201', '3710035', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '岩神町', 'イワガミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市敷島町', '10', '10201', '3710036', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '敷島町', 'シキシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市上小出町', '10', '10201', '3710037', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '上小出町', 'カミコイデマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市川端町', '10', '10201', '3710041', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '川端町', 'カワバタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市日輪寺町', '10', '10201', '3710042', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '日輪寺町', 'ニチリンジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市南橘町', '10', '10201', '3710043', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '南橘町', 'ナンキツマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市荒牧町', '10', '10201', '3710044', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '荒牧町', 'アラマキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市緑が丘町', '10', '10201', '3710045', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '緑が丘町', 'ミドリガオカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市川原町', '10', '10201', '3710046', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '川原町', 'カワハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市関根町', '10', '10201', '3710047', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '関根町', 'セキネマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市田口町', '10', '10201', '3710048', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '田口町', 'タグチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市上細井町', '10', '10201', '3710051', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '上細井町', 'カミホソイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市上沖町', '10', '10201', '3710052', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '上沖町', 'カミオキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市幸塚町', '10', '10201', '3710053', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '幸塚町', 'コウヅカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市下細井町', '10', '10201', '3710054', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '下細井町', 'シモホソイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市北代田町', '10', '10201', '3710055', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '北代田町', 'キタシロタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市青柳町', '10', '10201', '3710056', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '青柳町', 'アオヤギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市竜蔵寺町', '10', '10201', '3710057', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '竜蔵寺町', 'リュウゾウジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県勢多郡富士見村', '10', '10303', '3710100', '群馬県', 'グンマケン', '勢多郡富士見村', 'セタグンフジミムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('30967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県勢多郡富士見村赤城山', '10', '10303', '3710101', '群馬県', 'グンマケン', '勢多郡富士見村', 'セタグンフジミムラ', '赤城山', 'アカギサン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県勢多郡富士見村皆沢', '10', '10303', '3710102', '群馬県', 'グンマケン', '勢多郡富士見村', 'セタグンフジミムラ', '皆沢', 'ミナザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県勢多郡富士見村小暮', '10', '10303', '3710103', '群馬県', 'グンマケン', '勢多郡富士見村', 'セタグンフジミムラ', '小暮', 'コグレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県勢多郡富士見村時沢', '10', '10303', '3710104', '群馬県', 'グンマケン', '勢多郡富士見村', 'セタグンフジミムラ', '時沢', 'トキザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県勢多郡富士見村石井', '10', '10303', '3710105', '群馬県', 'グンマケン', '勢多郡富士見村', 'セタグンフジミムラ', '石井', 'イシイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県勢多郡富士見村市之木場', '10', '10303', '3710106', '群馬県', 'グンマケン', '勢多郡富士見村', 'セタグンフジミムラ', '市之木場', 'イチノキバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県勢多郡富士見村山口', '10', '10303', '3710107', '群馬県', 'グンマケン', '勢多郡富士見村', 'セタグンフジミムラ', '山口', 'ヤマグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県勢多郡富士見村米野', '10', '10303', '3710111', '群馬県', 'グンマケン', '勢多郡富士見村', 'セタグンフジミムラ', '米野', 'コメノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県勢多郡富士見村引田', '10', '10303', '3710112', '群馬県', 'グンマケン', '勢多郡富士見村', 'セタグンフジミムラ', '引田', 'ヒキダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県勢多郡富士見村漆窪', '10', '10303', '3710113', '群馬県', 'グンマケン', '勢多郡富士見村', 'セタグンフジミムラ', '漆窪', 'ウルクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県勢多郡富士見村田島', '10', '10303', '3710114', '群馬県', 'グンマケン', '勢多郡富士見村', 'セタグンフジミムラ', '田島', 'タジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県勢多郡富士見村小沢', '10', '10303', '3710115', '群馬県', 'グンマケン', '勢多郡富士見村', 'セタグンフジミムラ', '小沢', 'オザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県勢多郡富士見村原之郷', '10', '10303', '3710116', '群馬県', 'グンマケン', '勢多郡富士見村', 'セタグンフジミムラ', '原之郷', 'ハラノゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県勢多郡富士見村横室', '10', '10303', '3710117', '群馬県', 'グンマケン', '勢多郡富士見村', 'セタグンフジミムラ', '横室', 'ヨコムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市金丸町', '10', '10201', '3710121', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '金丸町', 'カナマルマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市小坂子町', '10', '10201', '3710122', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '小坂子町', 'コザカシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市高花台', '10', '10201', '3710123', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '高花台', 'タカハナダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市勝沢町', '10', '10201', '3710124', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '勝沢町', 'カツサワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市嶺町', '10', '10201', '3710125', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '嶺町', 'ミネマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市鳥取町', '10', '10201', '3710131', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '鳥取町', 'トットリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市五代町', '10', '10201', '3710132', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '五代町', 'ゴダイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市端気町', '10', '10201', '3710133', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '端気町', 'ハケマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市小神明町', '10', '10201', '3710134', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '小神明町', 'コジンメイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市粕川町中之沢', '10', '10201', '3710201', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '粕川町中之沢', 'カスカワマチナカノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市粕川町室沢', '10', '10201', '3710202', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '粕川町室沢', 'カスカワマチムロサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市粕川町月田', '10', '10201', '3710203', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '粕川町月田', 'カスカワマチツキダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市粕川町膳', '10', '10201', '3710204', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '粕川町膳', 'カスカワマチゼン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市粕川町中', '10', '10201', '3710205', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '粕川町中', 'カスカワマチナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市粕川町新屋', '10', '10201', '3710206', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '粕川町新屋', 'カスカワマチアラヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市粕川町稲里', '10', '10201', '3710207', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '粕川町稲里', 'カスカワマチイナサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市粕川町上東田面', '10', '10201', '3710211', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '粕川町上東田面', 'カスカワマチカミヒガシタナボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('30999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市粕川町下東田面', '10', '10201', '3710212', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '粕川町下東田面', 'カスカワマチシモヒガシタナボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市粕川町一日市', '10', '10201', '3710213', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '粕川町一日市', 'カスカワマチヒトイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市粕川町女渕', '10', '10201', '3710214', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '粕川町女渕', 'カスカワマチオナブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市粕川町深津', '10', '10201', '3710215', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '粕川町深津', 'カスカワマチフカヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市粕川町込皆戸', '10', '10201', '3710216', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '粕川町込皆戸', 'カスカワマチコミガイト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市粕川町西田面', '10', '10201', '3710217', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '粕川町西田面', 'カスカワマチニシタナボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市粕川町前皆戸', '10', '10201', '3710218', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '粕川町前皆戸', 'カスカワマチマエガイト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市樋越町', '10', '10201', '3710221', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '樋越町', 'ヒゴシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市上大屋町', '10', '10201', '3710222', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '上大屋町', 'カミオオヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市大胡町', '10', '10201', '3710223', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '大胡町', 'オオゴマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市河原浜町', '10', '10201', '3710224', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '河原浜町', 'カワラハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市堀越町', '10', '10201', '3710231', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '堀越町', 'ホリコシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市茂木町', '10', '10201', '3710232', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '茂木町', 'モトギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市横沢町', '10', '10201', '3710233', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '横沢町', 'ヨコザワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市東金丸町', '10', '10201', '3710234', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '東金丸町', 'ヒガシカナマルマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市滝窪町', '10', '10201', '3710235', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '滝窪町', 'タキクボマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市苗ケ島町', '10', '10201', '3710241', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '苗ケ島町', 'ナエガシママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市馬場町', '10', '10201', '3710242', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '馬場町', 'ババマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市大前田町', '10', '10201', '3710243', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '大前田町', 'オオマエタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市鼻毛石町', '10', '10201', '3710244', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '鼻毛石町', 'ハナゲイシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市市之関町', '10', '10201', '3710245', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '市之関町', 'イチノセキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市柏倉町', '10', '10201', '3710246', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '柏倉町', 'カシワグラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市三夜沢町', '10', '10201', '3710247', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '三夜沢町', 'ミヨサワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市文京町', '10', '10201', '3710801', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '文京町', 'ブンキョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市天川町', '10', '10201', '3710802', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '天川町', 'アマガワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市天川原町', '10', '10201', '3710803', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '天川原町', 'アマガワバラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市六供町', '10', '10201', '3710804', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '六供町', 'ロックマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市南町', '10', '10201', '3710805', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '南町', 'ミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市朝倉町', '10', '10201', '3710811', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '朝倉町', 'アサクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市広瀬町', '10', '10201', '3710812', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '広瀬町', 'ヒロセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市後閑町', '10', '10201', '3710813', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '後閑町', 'ゴカンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市宮地町', '10', '10201', '3710814', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '宮地町', 'ミヤジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市下佐鳥町', '10', '10201', '3710815', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '下佐鳥町', 'シモサドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市上佐鳥町', '10', '10201', '3710816', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '上佐鳥町', 'カミサドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市ぬで島町', '10', '10201', '3710817', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', 'ぬで島町', 'ヌデジママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市上新田町', '10', '10201', '3710821', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '上新田町', 'カミシンデンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市下新田町', '10', '10201', '3710822', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '下新田町', 'シモシンデンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市川曲町', '10', '10201', '3710823', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '川曲町', 'カワマガリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市稲荷新田町', '10', '10201', '3710824', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '稲荷新田町', 'トウカシンデンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市大利根町', '10', '10201', '3710825', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '大利根町', 'オオトネマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市青葉町', '10', '10201', '3710826', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '青葉町', 'アオバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市小相木町', '10', '10201', '3710831', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '小相木町', 'コアイギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市朝日が丘町', '10', '10201', '3710832', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '朝日が丘町', 'アサヒガオカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市光が丘町', '10', '10201', '3710833', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '光が丘町', 'ヒカリガオカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市後家町', '10', '10201', '3710834', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '後家町', 'ゴケマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市前箱田町', '10', '10201', '3710835', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '前箱田町', 'マエハコダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市江田町', '10', '10201', '3710836', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '江田町', 'エダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市箱田町', '10', '10201', '3710837', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '箱田町', 'ハコダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市石倉町', '10', '10201', '3710841', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '石倉町', 'イシクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市下石倉町', '10', '10201', '3710842', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '下石倉町', 'シモイシクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市新前橋町', '10', '10201', '3710843', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '新前橋町', 'シンマエバシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市古市町', '10', '10201', '3710844', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '古市町', 'フルイチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市鳥羽町', '10', '10201', '3710845', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '鳥羽町', 'トリバマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市元総社町', '10', '10201', '3710846', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '元総社町', 'モトソウジャマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市大友町', '10', '10201', '3710847', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '大友町', 'オオドモマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市総社町植野', '10', '10201', '3710851', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '総社町植野', 'ソウジャマチウエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市総社町総社', '10', '10201', '3710852', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '総社町総社', 'ソウジャマチソウジャ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市総社町', '10', '10201', '3710853', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '総社町', 'ソウジャマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市大渡町', '10', '10201', '3710854', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '大渡町', 'オオワタリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市問屋町', '10', '10201', '3710855', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '問屋町', 'トンヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市総社町高井', '10', '10201', '3710856', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '総社町高井', 'ソウジャマチタカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市高井町', '10', '10201', '3710857', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '高井町', 'タカイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市総社町桜が丘', '10', '10201', '3710858', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '総社町桜が丘', 'ソウジャマチサクラガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市', '10', '10204', '3720000', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('31089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市波志江町', '10', '10204', '3720001', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '波志江町', 'ハシエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市堤西町', '10', '10204', '3720002', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '堤西町', 'ツツミニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市華蔵寺町', '10', '10204', '3720003', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '華蔵寺町', 'ケゾウジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市堤下町', '10', '10204', '3720004', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '堤下町', 'ツツミシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市乾町', '10', '10204', '3720005', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '乾町', 'イヌイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市太田町', '10', '10204', '3720006', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '太田町', 'オオタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市安堀町', '10', '10204', '3720007', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '安堀町', 'アンボリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市三和町', '10', '10204', '3720011', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '三和町', 'サンワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市豊城町', '10', '10204', '3720012', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '豊城町', 'トヨシロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市上植木本町', '10', '10204', '3720013', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '上植木本町', 'カミウエキホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市昭和町', '10', '10204', '3720014', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '昭和町', 'ショウワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市鹿島町', '10', '10204', '3720015', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '鹿島町', 'カシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市本関町', '10', '10204', '3720016', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '本関町', 'ホンセキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市上諏訪町', '10', '10204', '3720021', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '上諏訪町', 'カミスワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市日乃出町', '10', '10204', '3720022', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '日乃出町', 'ヒノデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市粕川町', '10', '10204', '3720023', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '粕川町', 'カスカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市下植木町', '10', '10204', '3720024', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '下植木町', 'シモウエキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市東本町', '10', '10204', '3720025', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '東本町', 'ヒガシホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市宮前町', '10', '10204', '3720026', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '宮前町', 'ミヤマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市今泉町', '10', '10204', '3720031', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '今泉町', 'イマイズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市北千木町', '10', '10204', '3720032', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '北千木町', 'キタセンギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市南千木町', '10', '10204', '3720033', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '南千木町', 'ミナミセンギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市茂呂町', '10', '10204', '3720034', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '茂呂町', 'モロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市茂呂南町', '10', '10204', '3720036', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '茂呂南町', 'モロミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市美茂呂町', '10', '10204', '3720037', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '美茂呂町', 'ミモロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市新栄町', '10', '10204', '3720038', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '新栄町', 'シンエイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市ひろせ町', '10', '10204', '3720039', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', 'ひろせ町', 'ヒロセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市平和町', '10', '10204', '3720041', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '平和町', 'ヘイワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市中央町', '10', '10204', '3720042', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '中央町', 'チュウオウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市緑町', '10', '10204', '3720043', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '緑町', 'ミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市八坂町', '10', '10204', '3720044', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '八坂町', 'ヤサカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市上泉町', '10', '10204', '3720045', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '上泉町', 'カミイズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市三光町', '10', '10204', '3720046', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '三光町', 'サンコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市本町', '10', '10204', '3720047', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市大手町', '10', '10204', '3720048', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '大手町', 'オオテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市八幡町', '10', '10204', '3720051', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '八幡町', 'ヤハタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市寿町', '10', '10204', '3720052', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '寿町', 'コトブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市宗高町', '10', '10204', '3720053', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '宗高町', 'ムネタカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市柳原町', '10', '10204', '3720054', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '柳原町', 'ヤナギハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市曲輪町', '10', '10204', '3720055', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '曲輪町', 'クルワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市喜多町', '10', '10204', '3720056', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '喜多町', 'キタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市末広町', '10', '10204', '3720057', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '末広町', 'スエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市西田町', '10', '10204', '3720058', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '西田町', 'ニシダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市宮子町', '10', '10204', '3720801', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '宮子町', 'ミヤコマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市田中島町', '10', '10204', '3720802', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '田中島町', 'タナカジママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市宮古町', '10', '10204', '3720803', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '宮古町', 'ミヤフルマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市稲荷町', '10', '10204', '3720804', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '稲荷町', 'イナリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市若葉町', '10', '10204', '3720811', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '若葉町', 'ワカバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市連取町', '10', '10204', '3720812', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '連取町', 'ツナトリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市韮塚町', '10', '10204', '3720813', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '韮塚町', 'ニラヅカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市田中町', '10', '10204', '3720814', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '田中町', 'タナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市東上之宮町', '10', '10204', '3720815', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '東上之宮町', 'ヒガシカミノミヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市西上之宮町', '10', '10204', '3720816', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '西上之宮町', 'ニシカミノミヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市連取本町', '10', '10204', '3720817', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '連取本町', 'ツナトリホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市連取元町', '10', '10204', '3720818', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '連取元町', 'ツナトリモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市阿弥大寺町', '10', '10204', '3720821', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '阿弥大寺町', 'アミダイジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市中町', '10', '10204', '3720822', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '中町', 'ナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市今井町', '10', '10204', '3720823', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '今井町', 'イマイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市柴町', '10', '10204', '3720824', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '柴町', 'シバマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市戸谷塚町', '10', '10204', '3720825', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '戸谷塚町', 'トヤツカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市福島町', '10', '10204', '3720826', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '福島町', 'フクジママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市八斗島町', '10', '10204', '3720827', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '八斗島町', 'ヤッタジママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市山王町', '10', '10204', '3720831', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '山王町', 'サンオウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市除ケ町', '10', '10204', '3720832', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '除ケ町', 'ヨゲチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市富塚町', '10', '10204', '3720833', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '富塚町', 'トミヅカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市堀口町', '10', '10204', '3720834', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '堀口町', 'ホリグチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市大正寺町', '10', '10204', '3720841', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '大正寺町', 'ダイショウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市馬見塚町', '10', '10204', '3720842', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '馬見塚町', 'マミヅカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市下道寺町', '10', '10204', '3720843', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '下道寺町', 'ゲドウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市羽黒町', '10', '10204', '3720844', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '羽黒町', 'ハグロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市上蓮町', '10', '10204', '3720851', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '上蓮町', 'カミハスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市下蓮町', '10', '10204', '3720852', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '下蓮町', 'シモハスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市国領町', '10', '10204', '3720853', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '国領町', 'コクリョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市飯島町', '10', '10204', '3720854', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '飯島町', 'イイジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市長沼町', '10', '10204', '3720855', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '長沼町', 'ナガヌママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市', '10', '10205', '3730000', '群馬県', 'グンマケン', '太田市', 'オオタシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('31174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市西長岡町', '10', '10205', '3730001', '群馬県', 'グンマケン', '太田市', 'オオタシ', '西長岡町', 'ニシナガオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市菅塩町', '10', '10205', '3730002', '群馬県', 'グンマケン', '太田市', 'オオタシ', '菅塩町', 'スガシオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市北金井町', '10', '10205', '3730003', '群馬県', 'グンマケン', '太田市', 'オオタシ', '北金井町', 'キタカナイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市強戸町', '10', '10205', '3730004', '群馬県', 'グンマケン', '太田市', 'オオタシ', '強戸町', 'ゴウドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市成塚町', '10', '10205', '3730006', '群馬県', 'グンマケン', '太田市', 'オオタシ', '成塚町', 'ナリヅカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市石橋町', '10', '10205', '3730007', '群馬県', 'グンマケン', '太田市', 'オオタシ', '石橋町', 'イシバシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市鶴生田町', '10', '10205', '3730008', '群馬県', 'グンマケン', '太田市', 'オオタシ', '鶴生田町', 'ツルウダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市只上町', '10', '10205', '3730011', '群馬県', 'グンマケン', '太田市', 'オオタシ', '只上町', 'タダカリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市清原町', '10', '10205', '3730012', '群馬県', 'グンマケン', '太田市', 'オオタシ', '清原町', 'キヨハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市市場町', '10', '10205', '3730013', '群馬県', 'グンマケン', '太田市', 'オオタシ', '市場町', 'イチバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市植木野町', '10', '10205', '3730014', '群馬県', 'グンマケン', '太田市', 'オオタシ', '植木野町', 'ウエキノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市東新町', '10', '10205', '3730015', '群馬県', 'グンマケン', '太田市', 'オオタシ', '東新町', 'ヒガシシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市矢田堀町', '10', '10205', '3730016', '群馬県', 'グンマケン', '太田市', 'オオタシ', '矢田堀町', 'ヤタボリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市丸山町', '10', '10205', '3730018', '群馬県', 'グンマケン', '太田市', 'オオタシ', '丸山町', 'マルヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市吉沢町', '10', '10205', '3730019', '群馬県', 'グンマケン', '太田市', 'オオタシ', '吉沢町', 'ヨシザワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市東今泉町', '10', '10205', '3730021', '群馬県', 'グンマケン', '太田市', 'オオタシ', '東今泉町', 'ヒガシイマイズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市東金井町', '10', '10205', '3730022', '群馬県', 'グンマケン', '太田市', 'オオタシ', '東金井町', 'ヒガシカナイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市富若町', '10', '10205', '3730023', '群馬県', 'グンマケン', '太田市', 'オオタシ', '富若町', 'トミワカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市上小林町', '10', '10205', '3730024', '群馬県', 'グンマケン', '太田市', 'オオタシ', '上小林町', 'カミコバヤシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市熊野町', '10', '10205', '3730025', '群馬県', 'グンマケン', '太田市', 'オオタシ', '熊野町', 'クマノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市東本町', '10', '10205', '3730026', '群馬県', 'グンマケン', '太田市', 'オオタシ', '東本町', 'ヒガシホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市金山町', '10', '10205', '3730027', '群馬県', 'グンマケン', '太田市', 'オオタシ', '金山町', 'カナヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市スバル町', '10', '10205', '3730028', '群馬県', 'グンマケン', '太田市', 'オオタシ', 'スバル町', 'スバルチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市韮川町', '10', '10205', '3730029', '群馬県', 'グンマケン', '太田市', 'オオタシ', '韮川町', 'ニラガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市脇屋町', '10', '10205', '3730031', '群馬県', 'グンマケン', '太田市', 'オオタシ', '脇屋町', 'ワキヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市新野町', '10', '10205', '3730032', '群馬県', 'グンマケン', '太田市', 'オオタシ', '新野町', 'ニイノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市西本町', '10', '10205', '3730033', '群馬県', 'グンマケン', '太田市', 'オオタシ', '西本町', 'ニシホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市藤阿久町', '10', '10205', '3730034', '群馬県', 'グンマケン', '太田市', 'オオタシ', '藤阿久町', 'フジアグチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市藤久良町', '10', '10205', '3730035', '群馬県', 'グンマケン', '太田市', 'オオタシ', '藤久良町', 'フジクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市由良町', '10', '10205', '3730036', '群馬県', 'グンマケン', '太田市', 'オオタシ', '由良町', 'ユラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市新道町', '10', '10205', '3730037', '群馬県', 'グンマケン', '太田市', 'オオタシ', '新道町', 'シンドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市城西町', '10', '10205', '3730038', '群馬県', 'グンマケン', '太田市', 'オオタシ', '城西町', 'ジョウサイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市別所町', '10', '10205', '3730041', '群馬県', 'グンマケン', '太田市', 'オオタシ', '別所町', 'ベッショチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市宝町', '10', '10205', '3730042', '群馬県', 'グンマケン', '太田市', 'オオタシ', '宝町', 'タカラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市西野谷町', '10', '10205', '3730043', '群馬県', 'グンマケン', '太田市', 'オオタシ', '西野谷町', 'ニシノヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市上田島町', '10', '10205', '3730044', '群馬県', 'グンマケン', '太田市', 'オオタシ', '上田島町', 'カミタジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市沖野町', '10', '10205', '3730045', '群馬県', 'グンマケン', '太田市', 'オオタシ', '沖野町', 'オキノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市天良町', '10', '10205', '3730051', '群馬県', 'グンマケン', '太田市', 'オオタシ', '天良町', 'テンラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市寺井町', '10', '10205', '3730052', '群馬県', 'グンマケン', '太田市', 'オオタシ', '寺井町', 'テライチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市鳥山町', '10', '10205', '3730053', '群馬県', 'グンマケン', '太田市', 'オオタシ', '鳥山町', 'トリヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市長手町', '10', '10205', '3730054', '群馬県', 'グンマケン', '太田市', 'オオタシ', '長手町', 'ナガテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市大島町', '10', '10205', '3730055', '群馬県', 'グンマケン', '太田市', 'オオタシ', '大島町', 'オオシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市八幡町', '10', '10205', '3730056', '群馬県', 'グンマケン', '太田市', 'オオタシ', '八幡町', 'ハチマンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市本町', '10', '10205', '3730057', '群馬県', 'グンマケン', '太田市', 'オオタシ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市鳥山上町', '10', '10205', '3730061', '群馬県', 'グンマケン', '太田市', 'オオタシ', '鳥山上町', 'トリヤマカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市鳥山中町', '10', '10205', '3730062', '群馬県', 'グンマケン', '太田市', 'オオタシ', '鳥山中町', 'トリヤマナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市鳥山下町', '10', '10205', '3730063', '群馬県', 'グンマケン', '太田市', 'オオタシ', '鳥山下町', 'トリヤマシモチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市原宿町', '10', '10205', '3730071', '群馬県', 'グンマケン', '太田市', 'オオタシ', '原宿町', 'ハラジュクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市高瀬町', '10', '10205', '3730072', '群馬県', 'グンマケン', '太田市', 'オオタシ', '高瀬町', 'タカゼチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市緑町', '10', '10205', '3730073', '群馬県', 'グンマケン', '太田市', 'オオタシ', '緑町', 'ミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市上強戸町', '10', '10205', '3730074', '群馬県', 'グンマケン', '太田市', 'オオタシ', '上強戸町', 'カミゴウドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市大鷲町', '10', '10205', '3730075', '群馬県', 'グンマケン', '太田市', 'オオタシ', '大鷲町', 'オオワシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市台之郷町', '10', '10205', '3730801', '群馬県', 'グンマケン', '太田市', 'オオタシ', '台之郷町', 'ダイノゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市矢場新町', '10', '10205', '3730802', '群馬県', 'グンマケン', '太田市', 'オオタシ', '矢場新町', 'ヤバシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市矢場町', '10', '10205', '3730803', '群馬県', 'グンマケン', '太田市', 'オオタシ', '矢場町', 'ヤバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市沖之郷町', '10', '10205', '3730804', '群馬県', 'グンマケン', '太田市', 'オオタシ', '沖之郷町', 'オキノゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市八重笠町', '10', '10205', '3730805', '群馬県', 'グンマケン', '太田市', 'オオタシ', '八重笠町', 'ヤエガサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市龍舞町', '10', '10205', '3730806', '群馬県', 'グンマケン', '太田市', 'オオタシ', '龍舞町', 'リュウマイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市下小林町', '10', '10205', '3730807', '群馬県', 'グンマケン', '太田市', 'オオタシ', '下小林町', 'シモコバヤシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市石原町', '10', '10205', '3730808', '群馬県', 'グンマケン', '太田市', 'オオタシ', '石原町', 'イシハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市茂木町', '10', '10205', '3730809', '群馬県', 'グンマケン', '太田市', 'オオタシ', '茂木町', 'モテギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市安良岡町', '10', '10205', '3730811', '群馬県', 'グンマケン', '太田市', 'オオタシ', '安良岡町', 'ヤスラオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市東長岡町', '10', '10205', '3730812', '群馬県', 'グンマケン', '太田市', 'オオタシ', '東長岡町', 'ヒガシナガオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市内ケ島町', '10', '10205', '3730813', '群馬県', 'グンマケン', '太田市', 'オオタシ', '内ケ島町', 'ウチガシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市朝日町', '10', '10205', '3730814', '群馬県', 'グンマケン', '太田市', 'オオタシ', '朝日町', 'アサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市東別所町', '10', '10205', '3730815', '群馬県', 'グンマケン', '太田市', 'オオタシ', '東別所町', 'ヒガシベッショチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市東矢島町', '10', '10205', '3730816', '群馬県', 'グンマケン', '太田市', 'オオタシ', '東矢島町', 'ヒガシヤジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市飯塚町', '10', '10205', '3730817', '群馬県', 'グンマケン', '太田市', 'オオタシ', '飯塚町', 'イイヅカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市小舞木町', '10', '10205', '3730818', '群馬県', 'グンマケン', '太田市', 'オオタシ', '小舞木町', 'コマイギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市新島町', '10', '10205', '3730819', '群馬県', 'グンマケン', '太田市', 'オオタシ', '新島町', 'ニイジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市下浜田町', '10', '10205', '3730821', '群馬県', 'グンマケン', '太田市', 'オオタシ', '下浜田町', 'シモハマダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市庄屋町', '10', '10205', '3730822', '群馬県', 'グンマケン', '太田市', 'オオタシ', '庄屋町', 'ショウヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市西矢島町', '10', '10205', '3730823', '群馬県', 'グンマケン', '太田市', 'オオタシ', '西矢島町', 'ニシヤジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市高林寿町', '10', '10205', '3730824', '群馬県', 'グンマケン', '太田市', 'オオタシ', '高林寿町', 'タカハヤシコトブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市高林東町', '10', '10205', '3730825', '群馬県', 'グンマケン', '太田市', 'オオタシ', '高林東町', 'タカハヤシヒガシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市古戸町', '10', '10205', '3730826', '群馬県', 'グンマケン', '太田市', 'オオタシ', '古戸町', 'フルトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市高林南町', '10', '10205', '3730827', '群馬県', 'グンマケン', '太田市', 'オオタシ', '高林南町', 'タカハヤシミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市高林西町', '10', '10205', '3730828', '群馬県', 'グンマケン', '太田市', 'オオタシ', '高林西町', 'タカハヤシニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市高林北町', '10', '10205', '3730829', '群馬県', 'グンマケン', '太田市', 'オオタシ', '高林北町', 'タカハヤシキタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市福沢町', '10', '10205', '3730831', '群馬県', 'グンマケン', '太田市', 'オオタシ', '福沢町', 'フクザワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市富沢町', '10', '10205', '3730832', '群馬県', 'グンマケン', '太田市', 'オオタシ', '富沢町', 'トミザワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市牛沢町', '10', '10205', '3730833', '群馬県', 'グンマケン', '太田市', 'オオタシ', '牛沢町', 'ウシザワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市岩瀬川町', '10', '10205', '3730841', '群馬県', 'グンマケン', '太田市', 'オオタシ', '岩瀬川町', 'イワセガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市細谷町', '10', '10205', '3730842', '群馬県', 'グンマケン', '太田市', 'オオタシ', '細谷町', 'ホソヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市米沢町', '10', '10205', '3730843', '群馬県', 'グンマケン', '太田市', 'オオタシ', '米沢町', 'ヨネザワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市下田島町', '10', '10205', '3730844', '群馬県', 'グンマケン', '太田市', 'オオタシ', '下田島町', 'シモタジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市泉町', '10', '10205', '3730845', '群馬県', 'グンマケン', '太田市', 'オオタシ', '泉町', 'イズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市中根町', '10', '10205', '3730846', '群馬県', 'グンマケン', '太田市', 'オオタシ', '中根町', 'ナカネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市西新町', '10', '10205', '3730847', '群馬県', 'グンマケン', '太田市', 'オオタシ', '西新町', 'ニシシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市飯田町', '10', '10205', '3730851', '群馬県', 'グンマケン', '太田市', 'オオタシ', '飯田町', 'イイダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市新井町', '10', '10205', '3730852', '群馬県', 'グンマケン', '太田市', 'オオタシ', '新井町', 'アライチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市浜町', '10', '10205', '3730853', '群馬県', 'グンマケン', '太田市', 'オオタシ', '浜町', 'ハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市南矢島町', '10', '10205', '3730861', '群馬県', 'グンマケン', '太田市', 'オオタシ', '南矢島町', 'ミナミヤジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市末広町', '10', '10205', '3730862', '群馬県', 'グンマケン', '太田市', 'オオタシ', '末広町', 'スエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県館林市', '10', '10207', '3740000', '群馬県', 'グンマケン', '館林市', 'タテバヤシシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('31302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県館林市大島町', '10', '10207', '3740001', '群馬県', 'グンマケン', '館林市', 'タテバヤシシ', '大島町', 'オオシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県館林市田谷町', '10', '10207', '3740002', '群馬県', 'グンマケン', '館林市', 'タテバヤシシ', '田谷町', 'タヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県館林市四ツ谷町', '10', '10207', '3740003', '群馬県', 'グンマケン', '館林市', 'タテバヤシシ', '四ツ谷町', 'ヨツヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県館林市楠町', '10', '10207', '3740004', '群馬県', 'グンマケン', '館林市', 'タテバヤシシ', '楠町', 'クスノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県館林市花山町', '10', '10207', '3740005', '群馬県', 'グンマケン', '館林市', 'タテバヤシシ', '花山町', 'ハナヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県館林市当郷町', '10', '10207', '3740006', '群馬県', 'グンマケン', '館林市', 'タテバヤシシ', '当郷町', 'トウゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県館林市若宮町', '10', '10207', '3740007', '群馬県', 'グンマケン', '館林市', 'タテバヤシシ', '若宮町', 'ワカミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県館林市細内町', '10', '10207', '3740008', '群馬県', 'グンマケン', '館林市', 'タテバヤシシ', '細内町', 'ホソウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県館林市千塚町', '10', '10207', '3740009', '群馬県', 'グンマケン', '館林市', 'タテバヤシシ', '千塚町', 'チヅカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県館林市羽附町', '10', '10207', '3740011', '群馬県', 'グンマケン', '館林市', 'タテバヤシシ', '羽附町', 'ハネツクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県館林市羽附旭町', '10', '10207', '3740012', '群馬県', 'グンマケン', '館林市', 'タテバヤシシ', '羽附旭町', 'ハネツクアサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県館林市赤生田町', '10', '10207', '3740013', '群馬県', 'グンマケン', '館林市', 'タテバヤシシ', '赤生田町', 'アコウダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県館林市赤生田本町', '10', '10207', '3740014', '群馬県', 'グンマケン', '館林市', 'タテバヤシシ', '赤生田本町', 'アコウダホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県館林市上赤生田町', '10', '10207', '3740015', '群馬県', 'グンマケン', '館林市', 'タテバヤシシ', '上赤生田町', 'カミアコウダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県館林市松原', '10', '10207', '3740016', '群馬県', 'グンマケン', '館林市', 'タテバヤシシ', '松原', 'マツバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県館林市つつじ町', '10', '10207', '3740017', '群馬県', 'グンマケン', '館林市', 'タテバヤシシ', 'つつじ町', 'ツツジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県館林市城町', '10', '10207', '3740018', '群馬県', 'グンマケン', '館林市', 'タテバヤシシ', '城町', 'シロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県館林市尾曳町', '10', '10207', '3740019', '群馬県', 'グンマケン', '館林市', 'タテバヤシシ', '尾曳町', 'オビキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県館林市瀬戸谷町', '10', '10207', '3740021', '群馬県', 'グンマケン', '館林市', 'タテバヤシシ', '瀬戸谷町', 'セドヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県館林市加法師町', '10', '10207', '3740022', '群馬県', 'グンマケン', '館林市', 'タテバヤシシ', '加法師町', 'カボウシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県館林市大手町', '10', '10207', '3740023', '群馬県', 'グンマケン', '館林市', 'タテバヤシシ', '大手町', 'オオテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県館林市本町', '10', '10207', '3740024', '群馬県', 'グンマケン', '館林市', 'タテバヤシシ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県館林市緑町', '10', '10207', '3740025', '群馬県', 'グンマケン', '館林市', 'タテバヤシシ', '緑町', 'ミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県館林市新宿', '10', '10207', '3740026', '群馬県', 'グンマケン', '館林市', 'タテバヤシシ', '新宿', 'シンジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県館林市富士見町', '10', '10207', '3740027', '群馬県', 'グンマケン', '館林市', 'タテバヤシシ', '富士見町', 'フジミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県館林市千代田町', '10', '10207', '3740028', '群馬県', 'グンマケン', '館林市', 'タテバヤシシ', '千代田町', 'チヨダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県館林市仲町', '10', '10207', '3740029', '群馬県', 'グンマケン', '館林市', 'タテバヤシシ', '仲町', 'ナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県館林市東美園町', '10', '10207', '3740031', '群馬県', 'グンマケン', '館林市', 'タテバヤシシ', '東美園町', 'ヒガシミソノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県館林市南美園町', '10', '10207', '3740032', '群馬県', 'グンマケン', '館林市', 'タテバヤシシ', '南美園町', 'ミナミミソノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県館林市堀工町', '10', '10207', '3740033', '群馬県', 'グンマケン', '館林市', 'タテバヤシシ', '堀工町', 'ホリクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県館林市分福町', '10', '10207', '3740034', '群馬県', 'グンマケン', '館林市', 'タテバヤシシ', '分福町', 'ブンブクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県館林市青柳町', '10', '10207', '3740035', '群馬県', 'グンマケン', '館林市', 'タテバヤシシ', '青柳町', 'アオヤギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県館林市諏訪町', '10', '10207', '3740036', '群馬県', 'グンマケン', '館林市', 'タテバヤシシ', '諏訪町', 'スワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県館林市小桑原町', '10', '10207', '3740037', '群馬県', 'グンマケン', '館林市', 'タテバヤシシ', '小桑原町', 'コクワバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県館林市西美園町', '10', '10207', '3740038', '群馬県', 'グンマケン', '館林市', 'タテバヤシシ', '西美園町', 'ニシミソノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県館林市美園町', '10', '10207', '3740039', '群馬県', 'グンマケン', '館林市', 'タテバヤシシ', '美園町', 'ミソノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県館林市富士原町', '10', '10207', '3740041', '群馬県', 'グンマケン', '館林市', 'タテバヤシシ', '富士原町', 'フジハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県館林市近藤町', '10', '10207', '3740042', '群馬県', 'グンマケン', '館林市', 'タテバヤシシ', '近藤町', 'コンドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県館林市苗木町', '10', '10207', '3740043', '群馬県', 'グンマケン', '館林市', 'タテバヤシシ', '苗木町', 'ナエギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県館林市下三林町', '10', '10207', '3740044', '群馬県', 'グンマケン', '館林市', 'タテバヤシシ', '下三林町', 'シモミバヤシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県館林市入ケ谷町', '10', '10207', '3740045', '群馬県', 'グンマケン', '館林市', 'タテバヤシシ', '入ケ谷町', 'イリカヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県館林市上三林町', '10', '10207', '3740046', '群馬県', 'グンマケン', '館林市', 'タテバヤシシ', '上三林町', 'カミミバヤシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県館林市野辺町', '10', '10207', '3740047', '群馬県', 'グンマケン', '館林市', 'タテバヤシシ', '野辺町', 'ノベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県館林市新栄町', '10', '10207', '3740051', '群馬県', 'グンマケン', '館林市', 'タテバヤシシ', '新栄町', 'シンサカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県館林市栄町', '10', '10207', '3740052', '群馬県', 'グンマケン', '館林市', 'タテバヤシシ', '栄町', 'サカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県館林市赤土町', '10', '10207', '3740053', '群馬県', 'グンマケン', '館林市', 'タテバヤシシ', '赤土町', 'アカツチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県館林市大谷町', '10', '10207', '3740054', '群馬県', 'グンマケン', '館林市', 'タテバヤシシ', '大谷町', 'オオヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県館林市成島町', '10', '10207', '3740055', '群馬県', 'グンマケン', '館林市', 'タテバヤシシ', '成島町', 'ナルシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県館林市松沼町', '10', '10207', '3740056', '群馬県', 'グンマケン', '館林市', 'タテバヤシシ', '松沼町', 'マツヌマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県館林市北成島町', '10', '10207', '3740057', '群馬県', 'グンマケン', '館林市', 'タテバヤシシ', '北成島町', 'キタナルシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県館林市東広内町', '10', '10207', '3740061', '群馬県', 'グンマケン', '館林市', 'タテバヤシシ', '東広内町', 'ヒガシヒロウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県館林市広内町', '10', '10207', '3740062', '群馬県', 'グンマケン', '館林市', 'タテバヤシシ', '広内町', 'ヒロウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県館林市朝日町', '10', '10207', '3740063', '群馬県', 'グンマケン', '館林市', 'タテバヤシシ', '朝日町', 'アサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県館林市代官町', '10', '10207', '3740064', '群馬県', 'グンマケン', '館林市', 'タテバヤシシ', '代官町', 'ダイカンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県館林市西本町', '10', '10207', '3740065', '群馬県', 'グンマケン', '館林市', 'タテバヤシシ', '西本町', 'ニシホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県館林市大街道', '10', '10207', '3740066', '群馬県', 'グンマケン', '館林市', 'タテバヤシシ', '大街道', 'オオカイドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県館林市岡野町', '10', '10207', '3740067', '群馬県', 'グンマケン', '館林市', 'タテバヤシシ', '岡野町', 'オカノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県館林市台宿町', '10', '10207', '3740068', '群馬県', 'グンマケン', '館林市', 'タテバヤシシ', '台宿町', 'ダイジュクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県館林市坂下町', '10', '10207', '3740069', '群馬県', 'グンマケン', '館林市', 'タテバヤシシ', '坂下町', 'サカシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県館林市下早川田町', '10', '10207', '3740071', '群馬県', 'グンマケン', '館林市', 'タテバヤシシ', '下早川田町', 'シモサガワダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県館林市大新田町', '10', '10207', '3740072', '群馬県', 'グンマケン', '館林市', 'タテバヤシシ', '大新田町', 'オオシンデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県館林市足次町', '10', '10207', '3740073', '群馬県', 'グンマケン', '館林市', 'タテバヤシシ', '足次町', 'アシツギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県館林市高根町', '10', '10207', '3740074', '群馬県', 'グンマケン', '館林市', 'タテバヤシシ', '高根町', 'タカネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県館林市西高根町', '10', '10207', '3740075', '群馬県', 'グンマケン', '館林市', 'タテバヤシシ', '西高根町', 'ニシタカネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県館林市日向町', '10', '10207', '3740076', '群馬県', 'グンマケン', '館林市', 'タテバヤシシ', '日向町', 'ヒナタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県館林市木戸町', '10', '10207', '3740077', '群馬県', 'グンマケン', '館林市', 'タテバヤシシ', '木戸町', 'キドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県館林市傍示塚町', '10', '10207', '3740078', '群馬県', 'グンマケン', '館林市', 'タテバヤシシ', '傍示塚町', 'ホウジツカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県館林市上早川田町', '10', '10207', '3740079', '群馬県', 'グンマケン', '館林市', 'タテバヤシシ', '上早川田町', 'カミサガワダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県邑楽郡板倉町', '10', '10521', '3740100', '群馬県', 'グンマケン', '邑楽郡板倉町', 'オウラグンイタクラマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('31371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県邑楽郡板倉町除川', '10', '10521', '3740101', '群馬県', 'グンマケン', '邑楽郡板倉町', 'オウラグンイタクラマチ', '除川', 'ヨケガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県邑楽郡板倉町離', '10', '10521', '3740102', '群馬県', 'グンマケン', '邑楽郡板倉町', 'オウラグンイタクラマチ', '離', 'ハナレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県邑楽郡板倉町細谷', '10', '10521', '3740103', '群馬県', 'グンマケン', '邑楽郡板倉町', 'オウラグンイタクラマチ', '細谷', 'ホソヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県邑楽郡板倉町大荷場', '10', '10521', '3740104', '群馬県', 'グンマケン', '邑楽郡板倉町', 'オウラグンイタクラマチ', '大荷場', 'オオニンバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県邑楽郡板倉町大曲', '10', '10521', '3740105', '群馬県', 'グンマケン', '邑楽郡板倉町', 'オウラグンイタクラマチ', '大曲', 'オオマガリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県邑楽郡板倉町西岡新田', '10', '10521', '3740106', '群馬県', 'グンマケン', '邑楽郡板倉町', 'オウラグンイタクラマチ', '西岡新田', 'ニシオカシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県邑楽郡板倉町西岡', '10', '10521', '3740107', '群馬県', 'グンマケン', '邑楽郡板倉町', 'オウラグンイタクラマチ', '西岡', 'ニシオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県邑楽郡板倉町海老瀬', '10', '10521', '3740111', '群馬県', 'グンマケン', '邑楽郡板倉町', 'オウラグンイタクラマチ', '海老瀬', 'エビセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県邑楽郡板倉町朝日野', '10', '10521', '3740112', '群馬県', 'グンマケン', '邑楽郡板倉町', 'オウラグンイタクラマチ', '朝日野', 'アサヒノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県邑楽郡板倉町泉野', '10', '10521', '3740113', '群馬県', 'グンマケン', '邑楽郡板倉町', 'オウラグンイタクラマチ', '泉野', 'イズミノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県邑楽郡板倉町下五箇', '10', '10521', '3740121', '群馬県', 'グンマケン', '邑楽郡板倉町', 'オウラグンイタクラマチ', '下五箇', 'シモゴカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県邑楽郡板倉町大高嶋', '10', '10521', '3740122', '群馬県', 'グンマケン', '邑楽郡板倉町', 'オウラグンイタクラマチ', '大高嶋', 'オオタカシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県邑楽郡板倉町飯野', '10', '10521', '3740123', '群馬県', 'グンマケン', '邑楽郡板倉町', 'オウラグンイタクラマチ', '飯野', 'イイノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県邑楽郡板倉町大蔵', '10', '10521', '3740131', '群馬県', 'グンマケン', '邑楽郡板倉町', 'オウラグンイタクラマチ', '大蔵', 'オオクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県邑楽郡板倉町板倉', '10', '10521', '3740132', '群馬県', 'グンマケン', '邑楽郡板倉町', 'オウラグンイタクラマチ', '板倉', 'イタクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県邑楽郡板倉町岩田', '10', '10521', '3740133', '群馬県', 'グンマケン', '邑楽郡板倉町', 'オウラグンイタクラマチ', '岩田', 'イワタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県邑楽郡板倉町籾谷', '10', '10521', '3740134', '群馬県', 'グンマケン', '邑楽郡板倉町', 'オウラグンイタクラマチ', '籾谷', 'モミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県邑楽郡板倉町内蔵新田', '10', '10521', '3740135', '群馬県', 'グンマケン', '邑楽郡板倉町', 'オウラグンイタクラマチ', '内蔵新田', 'ウチクラシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県藤岡市', '10', '10209', '3750000', '群馬県', 'グンマケン', '藤岡市', 'フジオカシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('31409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県藤岡市中島', '10', '10209', '3750001', '群馬県', 'グンマケン', '藤岡市', 'フジオカシ', '中島', 'ナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県藤岡市立石', '10', '10209', '3750002', '群馬県', 'グンマケン', '藤岡市', 'フジオカシ', '立石', 'タツイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県藤岡市立石新田', '10', '10209', '3750003', '群馬県', 'グンマケン', '藤岡市', 'フジオカシ', '立石新田', 'タツイシシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県藤岡市森', '10', '10209', '3750004', '群馬県', 'グンマケン', '藤岡市', 'フジオカシ', '森', 'モリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県藤岡市中', '10', '10209', '3750005', '群馬県', 'グンマケン', '藤岡市', 'フジオカシ', '中', 'ナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県藤岡市森新田', '10', '10209', '3750006', '群馬県', 'グンマケン', '藤岡市', 'フジオカシ', '森新田', 'モリシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県藤岡市岡之郷', '10', '10209', '3750011', '群馬県', 'グンマケン', '藤岡市', 'フジオカシ', '岡之郷', 'オカノゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県藤岡市下戸塚', '10', '10209', '3750012', '群馬県', 'グンマケン', '藤岡市', 'フジオカシ', '下戸塚', 'シモトヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県藤岡市上戸塚', '10', '10209', '3750013', '群馬県', 'グンマケン', '藤岡市', 'フジオカシ', '上戸塚', 'カミトヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県藤岡市下栗須', '10', '10209', '3750014', '群馬県', 'グンマケン', '藤岡市', 'フジオカシ', '下栗須', 'シモクリス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県藤岡市中栗須', '10', '10209', '3750015', '群馬県', 'グンマケン', '藤岡市', 'フジオカシ', '中栗須', 'ナカクリス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県藤岡市上栗須', '10', '10209', '3750016', '群馬県', 'グンマケン', '藤岡市', 'フジオカシ', '上栗須', 'カミクリス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県藤岡市篠塚', '10', '10209', '3750017', '群馬県', 'グンマケン', '藤岡市', 'フジオカシ', '篠塚', 'シノヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県藤岡市小林', '10', '10209', '3750021', '群馬県', 'グンマケン', '藤岡市', 'フジオカシ', '小林', 'コバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県藤岡市根岸', '10', '10209', '3750022', '群馬県', 'グンマケン', '藤岡市', 'フジオカシ', '根岸', 'ネギシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県藤岡市本郷', '10', '10209', '3750023', '群馬県', 'グンマケン', '藤岡市', 'フジオカシ', '本郷', 'ホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県藤岡市藤岡', '10', '10209', '3750024', '群馬県', 'グンマケン', '藤岡市', 'フジオカシ', '藤岡', 'フジオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県藤岡市矢場', '10', '10209', '3750031', '群馬県', 'グンマケン', '藤岡市', 'フジオカシ', '矢場', 'ヤバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県藤岡市神田', '10', '10209', '3750032', '群馬県', 'グンマケン', '藤岡市', 'フジオカシ', '神田', 'ジンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県藤岡市川除', '10', '10209', '3750033', '群馬県', 'グンマケン', '藤岡市', 'フジオカシ', '川除', 'カワヨケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県藤岡市牛田', '10', '10209', '3750034', '群馬県', 'グンマケン', '藤岡市', 'フジオカシ', '牛田', 'ウシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県藤岡市保美', '10', '10209', '3750035', '群馬県', 'グンマケン', '藤岡市', 'フジオカシ', '保美', 'ホミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県藤岡市高山', '10', '10209', '3750036', '群馬県', 'グンマケン', '藤岡市', 'フジオカシ', '高山', 'タカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県藤岡市三本木', '10', '10209', '3750037', '群馬県', 'グンマケン', '藤岡市', 'フジオカシ', '三本木', 'サンボギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県藤岡市緑埜', '10', '10209', '3750041', '群馬県', 'グンマケン', '藤岡市', 'フジオカシ', '緑埜', 'ミドノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県藤岡市鮎川', '10', '10209', '3750042', '群馬県', 'グンマケン', '藤岡市', 'フジオカシ', '鮎川', 'アユガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県藤岡市東平井', '10', '10209', '3750043', '群馬県', 'グンマケン', '藤岡市', 'フジオカシ', '東平井', 'ヒガシヒライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県藤岡市西平井', '10', '10209', '3750044', '群馬県', 'グンマケン', '藤岡市', 'フジオカシ', '西平井', 'ニシヒライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県藤岡市金井', '10', '10209', '3750045', '群馬県', 'グンマケン', '藤岡市', 'フジオカシ', '金井', 'カナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県藤岡市下日野', '10', '10209', '3750046', '群馬県', 'グンマケン', '藤岡市', 'フジオカシ', '下日野', 'シモヒノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県藤岡市上日野', '10', '10209', '3750047', '群馬県', 'グンマケン', '藤岡市', 'フジオカシ', '上日野', 'カミヒノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県藤岡市本動堂', '10', '10209', '3750051', '群馬県', 'グンマケン', '藤岡市', 'フジオカシ', '本動堂', 'モトユルギドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県藤岡市下大塚', '10', '10209', '3750052', '群馬県', 'グンマケン', '藤岡市', 'フジオカシ', '下大塚', 'シモオオヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県藤岡市中大塚', '10', '10209', '3750053', '群馬県', 'グンマケン', '藤岡市', 'フジオカシ', '中大塚', 'ナカオオヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県藤岡市上大塚', '10', '10209', '3750054', '群馬県', 'グンマケン', '藤岡市', 'フジオカシ', '上大塚', 'カミオオヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県藤岡市白石', '10', '10209', '3750055', '群馬県', 'グンマケン', '藤岡市', 'フジオカシ', '白石', 'シロイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県藤岡市三ツ木', '10', '10209', '3750056', '群馬県', 'グンマケン', '藤岡市', 'フジオカシ', '三ツ木', 'ミツギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県藤岡市上落合', '10', '10209', '3750057', '群馬県', 'グンマケン', '藤岡市', 'フジオカシ', '上落合', 'カミオチアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県桐生市', '10', '10203', '3760000', '群馬県', 'グンマケン', '桐生市', 'キリュウシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('31458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県桐生市菱町', '10', '10203', '3760001', '群馬県', 'グンマケン', '桐生市', 'キリュウシ', '菱町', 'ヒシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県桐生市境野町', '10', '10203', '3760002', '群馬県', 'グンマケン', '桐生市', 'キリュウシ', '境野町', 'サカイノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県桐生市琴平町', '10', '10203', '3760003', '群馬県', 'グンマケン', '桐生市', 'キリュウシ', '琴平町', 'コトヒラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県桐生市小梅町', '10', '10203', '3760004', '群馬県', 'グンマケン', '桐生市', 'キリュウシ', '小梅町', 'コウメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県桐生市三吉町', '10', '10203', '3760005', '群馬県', 'グンマケン', '桐生市', 'キリュウシ', '三吉町', 'ミヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県桐生市新宿', '10', '10203', '3760006', '群馬県', 'グンマケン', '桐生市', 'キリュウシ', '新宿', 'シンシュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県桐生市浜松町', '10', '10203', '3760007', '群馬県', 'グンマケン', '桐生市', 'キリュウシ', '浜松町', 'ハママツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県桐生市相生町', '10', '10203', '3760011', '群馬県', 'グンマケン', '桐生市', 'キリュウシ', '相生町', 'アイオイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県桐生市桜木町', '10', '10203', '3760012', '群馬県', 'グンマケン', '桐生市', 'キリュウシ', '桜木町', 'サクラギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県桐生市広沢町', '10', '10203', '3760013', '群馬県', 'グンマケン', '桐生市', 'キリュウシ', '広沢町', 'ヒロサワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県桐生市広沢町間ノ島', '10', '10203', '3760014', '群馬県', 'グンマケン', '桐生市', 'キリュウシ', '広沢町間ノ島', 'ヒロサワチョウアイノシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県桐生市巴町', '10', '10203', '3760021', '群馬県', 'グンマケン', '桐生市', 'キリュウシ', '巴町', 'トモエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県桐生市稲荷町', '10', '10203', '3760022', '群馬県', 'グンマケン', '桐生市', 'キリュウシ', '稲荷町', 'イナリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県桐生市錦町', '10', '10203', '3760023', '群馬県', 'グンマケン', '桐生市', 'キリュウシ', '錦町', 'ニシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県桐生市織姫町', '10', '10203', '3760024', '群馬県', 'グンマケン', '桐生市', 'キリュウシ', '織姫町', 'オリヒメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県桐生市美原町', '10', '10203', '3760025', '群馬県', 'グンマケン', '桐生市', 'キリュウシ', '美原町', 'ミハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県桐生市清瀬町', '10', '10203', '3760026', '群馬県', 'グンマケン', '桐生市', 'キリュウシ', '清瀬町', 'キヨセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県桐生市元宿町', '10', '10203', '3760027', '群馬県', 'グンマケン', '桐生市', 'キリュウシ', '元宿町', 'モトジュクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県桐生市本町', '10', '10203', '3760031', '群馬県', 'グンマケン', '桐生市', 'キリュウシ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県桐生市東町', '10', '10203', '3760032', '群馬県', 'グンマケン', '桐生市', 'キリュウシ', '東町', 'アズマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県桐生市泉町', '10', '10203', '3760033', '群馬県', 'グンマケン', '桐生市', 'キリュウシ', '泉町', 'イズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県桐生市東', '10', '10203', '3760034', '群馬県', 'グンマケン', '桐生市', 'キリュウシ', '東', 'ヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県桐生市仲町', '10', '10203', '3760035', '群馬県', 'グンマケン', '桐生市', 'キリュウシ', '仲町', 'ナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県桐生市川岸町', '10', '10203', '3760036', '群馬県', 'グンマケン', '桐生市', 'キリュウシ', '川岸町', 'カワギシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県桐生市旭町', '10', '10203', '3760037', '群馬県', 'グンマケン', '桐生市', 'キリュウシ', '旭町', 'アサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県桐生市高砂町', '10', '10203', '3760038', '群馬県', 'グンマケン', '桐生市', 'キリュウシ', '高砂町', 'タカサゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県桐生市川内町', '10', '10203', '3760041', '群馬県', 'グンマケン', '桐生市', 'キリュウシ', '川内町', 'カワウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県桐生市堤町', '10', '10203', '3760042', '群馬県', 'グンマケン', '桐生市', 'キリュウシ', '堤町', 'ツツミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県桐生市小曾根町', '10', '10203', '3760043', '群馬県', 'グンマケン', '桐生市', 'キリュウシ', '小曾根町', 'コソネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県桐生市永楽町', '10', '10203', '3760044', '群馬県', 'グンマケン', '桐生市', 'キリュウシ', '永楽町', 'エイラクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県桐生市末広町', '10', '10203', '3760045', '群馬県', 'グンマケン', '桐生市', 'キリュウシ', '末広町', 'スエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県桐生市宮前町', '10', '10203', '3760046', '群馬県', 'グンマケン', '桐生市', 'キリュウシ', '宮前町', 'ミヤマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県桐生市平井町', '10', '10203', '3760051', '群馬県', 'グンマケン', '桐生市', 'キリュウシ', '平井町', 'ヒライチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県桐生市天神町', '10', '10203', '3760052', '群馬県', 'グンマケン', '桐生市', 'キリュウシ', '天神町', 'テンジンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県桐生市東久方町', '10', '10203', '3760053', '群馬県', 'グンマケン', '桐生市', 'キリュウシ', '東久方町', 'ヒガシヒサカタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県桐生市西久方町', '10', '10203', '3760054', '群馬県', 'グンマケン', '桐生市', 'キリュウシ', '西久方町', 'ニシヒサカタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県桐生市横山町', '10', '10203', '3760055', '群馬県', 'グンマケン', '桐生市', 'キリュウシ', '横山町', 'ヨコヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県桐生市宮本町', '10', '10203', '3760056', '群馬県', 'グンマケン', '桐生市', 'キリュウシ', '宮本町', 'ミヤモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県みどり市', '10', '10212', '3760100', '群馬県', 'グンマケン', 'みどり市', 'ミドリシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('31497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県みどり市大間々町大間々', '10', '10212', '3760101', '群馬県', 'グンマケン', 'みどり市', 'ミドリシ', '大間々町大間々', 'オオママチョウオオママ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県みどり市大間々町桐原', '10', '10212', '3760102', '群馬県', 'グンマケン', 'みどり市', 'ミドリシ', '大間々町桐原', 'オオママチョウキリバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県みどり市大間々町下神梅', '10', '10212', '3760103', '群馬県', 'グンマケン', 'みどり市', 'ミドリシ', '大間々町下神梅', 'オオママチョウシモカンバイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県みどり市大間々町上神梅', '10', '10212', '3760104', '群馬県', 'グンマケン', 'みどり市', 'ミドリシ', '大間々町上神梅', 'オオママチョウカミカンバイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県みどり市大間々町小平', '10', '10212', '3760111', '群馬県', 'グンマケン', 'みどり市', 'ミドリシ', '大間々町小平', 'オオママチョウオダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県みどり市大間々町長尾根', '10', '10212', '3760112', '群馬県', 'グンマケン', 'みどり市', 'ミドリシ', '大間々町長尾根', 'オオママチョウナガオネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県みどり市大間々町高津戸', '10', '10212', '3760113', '群馬県', 'グンマケン', 'みどり市', 'ミドリシ', '大間々町高津戸', 'オオママチョウタカツド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県みどり市大間々町浅原', '10', '10212', '3760114', '群馬県', 'グンマケン', 'みどり市', 'ミドリシ', '大間々町浅原', 'オオママチョウアサバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県みどり市大間々町塩原', '10', '10212', '3760115', '群馬県', 'グンマケン', 'みどり市', 'ミドリシ', '大間々町塩原', 'オオママチョウシオバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県みどり市大間々町塩沢', '10', '10212', '3760116', '群馬県', 'グンマケン', 'みどり市', 'ミドリシ', '大間々町塩沢', 'オオママチョウシオザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県桐生市新里町新川', '10', '10203', '3760121', '群馬県', 'グンマケン', '桐生市', 'キリュウシ', '新里町新川', 'ニイサトチョウニッカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県桐生市新里町野', '10', '10203', '3760122', '群馬県', 'グンマケン', '桐生市', 'キリュウシ', '新里町野', 'ニイサトチョウノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県桐生市新里町武井', '10', '10203', '3760123', '群馬県', 'グンマケン', '桐生市', 'キリュウシ', '新里町武井', 'ニイサトチョウタケイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県桐生市新里町小林', '10', '10203', '3760124', '群馬県', 'グンマケン', '桐生市', 'キリュウシ', '新里町小林', 'ニイサトチョウコバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県桐生市新里町山上', '10', '10203', '3760125', '群馬県', 'グンマケン', '桐生市', 'キリュウシ', '新里町山上', 'ニイサトチョウヤマカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県桐生市新里町奥沢', '10', '10203', '3760131', '群馬県', 'グンマケン', '桐生市', 'キリュウシ', '新里町奥沢', 'ニイサトチョウオクザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県桐生市新里町鶴ケ谷', '10', '10203', '3760132', '群馬県', 'グンマケン', '桐生市', 'キリュウシ', '新里町鶴ケ谷', 'ニイサトチョウツルガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県桐生市新里町大久保', '10', '10203', '3760133', '群馬県', 'グンマケン', '桐生市', 'キリュウシ', '新里町大久保', 'ニイサトチョウオオクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県桐生市新里町関', '10', '10203', '3760134', '群馬県', 'グンマケン', '桐生市', 'キリュウシ', '新里町関', 'ニイサトチョウセキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県桐生市新里町高泉', '10', '10203', '3760135', '群馬県', 'グンマケン', '桐生市', 'キリュウシ', '新里町高泉', 'ニイサトチョウタカイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県桐生市新里町板橋', '10', '10203', '3760136', '群馬県', 'グンマケン', '桐生市', 'キリュウシ', '新里町板橋', 'ニイサトチョウイタバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県桐生市新里町赤城山', '10', '10203', '3760137', '群馬県', 'グンマケン', '桐生市', 'キリュウシ', '新里町赤城山', 'ニイサトチョウアカギサン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県桐生市黒保根町水沼', '10', '10203', '3760141', '群馬県', 'グンマケン', '桐生市', 'キリュウシ', '黒保根町水沼', 'クロホネチョウミズヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県桐生市黒保根町八木原', '10', '10203', '3760142', '群馬県', 'グンマケン', '桐生市', 'キリュウシ', '黒保根町八木原', 'クロホネチョウヤギハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県桐生市黒保根町宿廻', '10', '10203', '3760143', '群馬県', 'グンマケン', '桐生市', 'キリュウシ', '黒保根町宿廻', 'クロホネチョウシュクメグリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県桐生市黒保根町下田沢', '10', '10203', '3760144', '群馬県', 'グンマケン', '桐生市', 'キリュウシ', '黒保根町下田沢', 'クロホネチョウシモタザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県桐生市黒保根町上田沢', '10', '10203', '3760145', '群馬県', 'グンマケン', '桐生市', 'キリュウシ', '黒保根町上田沢', 'クロホネチョウカミタザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県みどり市東町沢入', '10', '10212', '3760301', '群馬県', 'グンマケン', 'みどり市', 'ミドリシ', '東町沢入', 'アズマチョウソウリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県みどり市東町草木', '10', '10212', '3760302', '群馬県', 'グンマケン', 'みどり市', 'ミドリシ', '東町草木', 'アズマチョウクサギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県みどり市東町座間', '10', '10212', '3760303', '群馬県', 'グンマケン', 'みどり市', 'ミドリシ', '東町座間', 'アズマチョウザマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県みどり市東町神戸', '10', '10212', '3760304', '群馬県', 'グンマケン', 'みどり市', 'ミドリシ', '東町神戸', 'アズマチョウゴウド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県みどり市東町小夜戸', '10', '10212', '3760305', '群馬県', 'グンマケン', 'みどり市', 'ミドリシ', '東町小夜戸', 'アズマチョウサヤド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県みどり市東町荻原', '10', '10212', '3760306', '群馬県', 'グンマケン', 'みどり市', 'ミドリシ', '東町荻原', 'アズマチョウオギハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県みどり市東町花輪', '10', '10212', '3760307', '群馬県', 'グンマケン', 'みどり市', 'ミドリシ', '東町花輪', 'アズマチョウハナワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県みどり市東町小中', '10', '10212', '3760308', '群馬県', 'グンマケン', 'みどり市', 'ミドリシ', '東町小中', 'アズマチョウコナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県桐生市梅田町', '10', '10203', '3760601', '群馬県', 'グンマケン', '桐生市', 'キリュウシ', '梅田町', 'ウメダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県渋川市', '10', '10208', '3770000', '群馬県', 'グンマケン', '渋川市', 'シブカワシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('31555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県渋川市中村', '10', '10208', '3770002', '群馬県', 'グンマケン', '渋川市', 'シブカワシ', '中村', 'ナカムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県渋川市八木原', '10', '10208', '3770003', '群馬県', 'グンマケン', '渋川市', 'シブカワシ', '八木原', 'ヤギハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県渋川市半田', '10', '10208', '3770004', '群馬県', 'グンマケン', '渋川市', 'シブカワシ', '半田', 'ハンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県渋川市有馬', '10', '10208', '3770005', '群馬県', 'グンマケン', '渋川市', 'シブカワシ', '有馬', 'アリマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県渋川市行幸田', '10', '10208', '3770006', '群馬県', 'グンマケン', '渋川市', 'シブカワシ', '行幸田', 'ミユキダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県渋川市石原', '10', '10208', '3770007', '群馬県', 'グンマケン', '渋川市', 'シブカワシ', '石原', 'イシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県渋川市渋川', '10', '10208', '3770008', '群馬県', 'グンマケン', '渋川市', 'シブカワシ', '渋川', 'シブカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県渋川市祖母島', '10', '10208', '3770024', '群馬県', 'グンマケン', '渋川市', 'シブカワシ', '祖母島', 'ウバシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県渋川市川島', '10', '10208', '3770025', '群馬県', 'グンマケン', '渋川市', 'シブカワシ', '川島', 'カワシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県渋川市南牧', '10', '10208', '3770026', '群馬県', 'グンマケン', '渋川市', 'シブカワシ', '南牧', 'ナンモク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県渋川市金井', '10', '10208', '3770027', '群馬県', 'グンマケン', '渋川市', 'シブカワシ', '金井', 'カナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県渋川市阿久津', '10', '10208', '3770031', '群馬県', 'グンマケン', '渋川市', 'シブカワシ', '阿久津', 'アクツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県渋川市北橘町赤城山', '10', '10208', '3770051', '群馬県', 'グンマケン', '渋川市', 'シブカワシ', '北橘町赤城山', 'ホッキツマチアカギサン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県渋川市北橘町上箱田', '10', '10208', '3770052', '群馬県', 'グンマケン', '渋川市', 'シブカワシ', '北橘町上箱田', 'ホッキツマチカミハコダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県渋川市北橘町箱田', '10', '10208', '3770053', '群馬県', 'グンマケン', '渋川市', 'シブカワシ', '北橘町箱田', 'ホッキツマチハコダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県渋川市北橘町下南室', '10', '10208', '3770054', '群馬県', 'グンマケン', '渋川市', 'シブカワシ', '北橘町下南室', 'ホッキツマチシモナムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県渋川市北橘町上南室', '10', '10208', '3770055', '群馬県', 'グンマケン', '渋川市', 'シブカワシ', '北橘町上南室', 'ホッキツマチカミナムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県渋川市北橘町下箱田', '10', '10208', '3770061', '群馬県', 'グンマケン', '渋川市', 'シブカワシ', '北橘町下箱田', 'ホッキツマチシモハコダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県渋川市北橘町真壁', '10', '10208', '3770062', '群馬県', 'グンマケン', '渋川市', 'シブカワシ', '北橘町真壁', 'ホッキツマチマカベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県渋川市北橘町分郷八崎', '10', '10208', '3770063', '群馬県', 'グンマケン', '渋川市', 'シブカワシ', '北橘町分郷八崎', 'ホッキツマチブンゴウハッサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県渋川市北橘町八崎', '10', '10208', '3770064', '群馬県', 'グンマケン', '渋川市', 'シブカワシ', '北橘町八崎', 'ホッキツマチハッサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県渋川市北橘町小室', '10', '10208', '3770065', '群馬県', 'グンマケン', '渋川市', 'シブカワシ', '北橘町小室', 'ホッキツマチコムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県渋川市伊香保町湯中子', '10', '10208', '3770101', '群馬県', 'グンマケン', '渋川市', 'シブカワシ', '伊香保町湯中子', 'イカホマチユナカゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県渋川市伊香保町伊香保', '10', '10208', '3770102', '群馬県', 'グンマケン', '渋川市', 'シブカワシ', '伊香保町伊香保', 'イカホマチイカホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県渋川市伊香保町水沢', '10', '10208', '3770103', '群馬県', 'グンマケン', '渋川市', 'シブカワシ', '伊香保町水沢', 'イカホマチミズサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県渋川市上白井', '10', '10208', '3770201', '群馬県', 'グンマケン', '渋川市', 'シブカワシ', '上白井', 'カミシロイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県渋川市中郷', '10', '10208', '3770202', '群馬県', 'グンマケン', '渋川市', 'シブカワシ', '中郷', 'ナカゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県渋川市吹屋', '10', '10208', '3770203', '群馬県', 'グンマケン', '渋川市', 'シブカワシ', '吹屋', 'フキヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県渋川市白井', '10', '10208', '3770204', '群馬県', 'グンマケン', '渋川市', 'シブカワシ', '白井', 'シロイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県渋川市北牧', '10', '10208', '3770205', '群馬県', 'グンマケン', '渋川市', 'シブカワシ', '北牧', 'キタモク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県渋川市横堀', '10', '10208', '3770206', '群馬県', 'グンマケン', '渋川市', 'シブカワシ', '横堀', 'ヨコボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県吾妻郡東吾妻町箱島', '10', '10429', '3770301', '群馬県', 'グンマケン', '吾妻郡東吾妻町', 'アガツマグンヒガシアガツママチ', '箱島', 'ハコジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県吾妻郡東吾妻町岡崎', '10', '10429', '3770302', '群馬県', 'グンマケン', '吾妻郡東吾妻町', 'アガツマグンヒガシアガツママチ', '岡崎', 'オカザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県吾妻郡東吾妻町新巻', '10', '10429', '3770303', '群馬県', 'グンマケン', '吾妻郡東吾妻町', 'アガツマグンヒガシアガツママチ', '新巻', 'アラマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県吾妻郡東吾妻町奥田', '10', '10429', '3770304', '群馬県', 'グンマケン', '吾妻郡東吾妻町', 'アガツマグンヒガシアガツママチ', '奥田', 'オクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県吾妻郡東吾妻町五町田', '10', '10429', '3770305', '群馬県', 'グンマケン', '吾妻郡東吾妻町', 'アガツマグンヒガシアガツママチ', '五町田', 'ゴチョウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県渋川市村上', '10', '10208', '3770311', '群馬県', 'グンマケン', '渋川市', 'シブカワシ', '村上', 'ムラカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県渋川市小野子', '10', '10208', '3770312', '群馬県', 'グンマケン', '渋川市', 'シブカワシ', '小野子', 'オノコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県吾妻郡中之条町', '10', '10421', '3770400', '群馬県', 'グンマケン', '吾妻郡中之条町', 'アガツマグンナカノジョウマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('31602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県吾妻郡中之条町大道', '10', '10421', '3770411', '群馬県', 'グンマケン', '吾妻郡中之条町', 'アガツマグンナカノジョウマチ', '大道', 'ダイドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県吾妻郡中之条町栃窪', '10', '10421', '3770412', '群馬県', 'グンマケン', '吾妻郡中之条町', 'アガツマグンナカノジョウマチ', '栃窪', 'トチクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県吾妻郡中之条町大塚', '10', '10421', '3770413', '群馬県', 'グンマケン', '吾妻郡中之条町', 'アガツマグンナカノジョウマチ', '大塚', 'オオヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県吾妻郡中之条町平', '10', '10421', '3770414', '群馬県', 'グンマケン', '吾妻郡中之条町', 'アガツマグンナカノジョウマチ', '平', 'タイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県吾妻郡中之条町横尾', '10', '10421', '3770415', '群馬県', 'グンマケン', '吾妻郡中之条町', 'アガツマグンナカノジョウマチ', '横尾', 'ヨコオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県吾妻郡中之条町蟻川', '10', '10421', '3770416', '群馬県', 'グンマケン', '吾妻郡中之条町', 'アガツマグンナカノジョウマチ', '蟻川', 'アリガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県吾妻郡中之条町赤坂', '10', '10421', '3770417', '群馬県', 'グンマケン', '吾妻郡中之条町', 'アガツマグンナカノジョウマチ', '赤坂', 'アカサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県吾妻郡中之条町市城', '10', '10421', '3770421', '群馬県', 'グンマケン', '吾妻郡中之条町', 'アガツマグンナカノジョウマチ', '市城', 'イチシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県吾妻郡中之条町青山', '10', '10421', '3770422', '群馬県', 'グンマケン', '吾妻郡中之条町', 'アガツマグンナカノジョウマチ', '青山', 'アオヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県吾妻郡中之条町伊勢町', '10', '10421', '3770423', '群馬県', 'グンマケン', '吾妻郡中之条町', 'アガツマグンナカノジョウマチ', '伊勢町', 'イセマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県吾妻郡中之条町中之条町', '10', '10421', '3770424', '群馬県', 'グンマケン', '吾妻郡中之条町', 'アガツマグンナカノジョウマチ', '中之条町', 'ナカノジョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県吾妻郡中之条町西中之条', '10', '10421', '3770425', '群馬県', 'グンマケン', '吾妻郡中之条町', 'アガツマグンナカノジョウマチ', '西中之条', 'ニシナカノジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県吾妻郡中之条町岩本', '10', '10421', '3770431', '群馬県', 'グンマケン', '吾妻郡中之条町', 'アガツマグンナカノジョウマチ', '岩本', 'イワモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県吾妻郡中之条町五反田', '10', '10421', '3770432', '群馬県', 'グンマケン', '吾妻郡中之条町', 'アガツマグンナカノジョウマチ', '五反田', 'ゴタンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県吾妻郡中之条町折田', '10', '10421', '3770433', '群馬県', 'グンマケン', '吾妻郡中之条町', 'アガツマグンナカノジョウマチ', '折田', 'オリダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県吾妻郡中之条町山田', '10', '10421', '3770434', '群馬県', 'グンマケン', '吾妻郡中之条町', 'アガツマグンナカノジョウマチ', '山田', 'ヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県吾妻郡中之条町上沢渡', '10', '10421', '3770541', '群馬県', 'グンマケン', '吾妻郡中之条町', 'アガツマグンナカノジョウマチ', '上沢渡', 'カミサワタリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県吾妻郡中之条町下沢渡', '10', '10421', '3770542', '群馬県', 'グンマケン', '吾妻郡中之条町', 'アガツマグンナカノジョウマチ', '下沢渡', 'シモサワタリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県吾妻郡中之条町山田寺社原', '10', '10421', '3770543', '群馬県', 'グンマケン', '吾妻郡中之条町', 'アガツマグンナカノジョウマチ', '山田', 'ヤマダ', null, null, '寺社原', 'ジシャバラ');
INSERT INTO `ms_addresses` VALUES ('31623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県吾妻郡中之条町山田細尾', '10', '10421', '3770543', '群馬県', 'グンマケン', '吾妻郡中之条町', 'アガツマグンナカノジョウマチ', '山田', 'ヤマダ', null, null, '細尾', 'ホソオ');
INSERT INTO `ms_addresses` VALUES ('31624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県吾妻郡中之条町折田戦道', '10', '10421', '3770544', '群馬県', 'グンマケン', '吾妻郡中之条町', 'アガツマグンナカノジョウマチ', '折田', 'オリダ', null, null, '戦道', 'センドウ');
INSERT INTO `ms_addresses` VALUES ('31625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県吾妻郡中之条町四万', '10', '10421', '3770601', '群馬県', 'グンマケン', '吾妻郡中之条町', 'アガツマグンナカノジョウマチ', '四万', 'シマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県吾妻郡高山村', '10', '10428', '3770700', '群馬県', 'グンマケン', '吾妻郡高山村', 'アガツマグンタカヤマムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('31627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県吾妻郡高山村尻高', '10', '10428', '3770701', '群馬県', 'グンマケン', '吾妻郡高山村', 'アガツマグンタカヤマムラ', '尻高', 'シッタカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県吾妻郡高山村中山', '10', '10428', '3770702', '群馬県', 'グンマケン', '吾妻郡高山村', 'アガツマグンタカヤマムラ', '中山', 'ナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県吾妻郡東吾妻町', '10', '10429', '3770800', '群馬県', 'グンマケン', '吾妻郡東吾妻町', 'アガツマグンヒガシアガツママチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('31631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県吾妻郡東吾妻町原町', '10', '10429', '3770801', '群馬県', 'グンマケン', '吾妻郡東吾妻町', 'アガツマグンヒガシアガツママチ', '原町', 'ハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県吾妻郡東吾妻町川戸', '10', '10429', '3770802', '群馬県', 'グンマケン', '吾妻郡東吾妻町', 'アガツマグンヒガシアガツママチ', '川戸', 'カワド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県吾妻郡東吾妻町金井', '10', '10429', '3770803', '群馬県', 'グンマケン', '吾妻郡東吾妻町', 'アガツマグンヒガシアガツママチ', '金井', 'カナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県吾妻郡東吾妻町岩井', '10', '10429', '3770804', '群馬県', 'グンマケン', '吾妻郡東吾妻町', 'アガツマグンヒガシアガツママチ', '岩井', 'イワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県吾妻郡東吾妻町植栗', '10', '10429', '3770805', '群馬県', 'グンマケン', '吾妻郡東吾妻町', 'アガツマグンヒガシアガツママチ', '植栗', 'ウエグリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県吾妻郡東吾妻町小泉', '10', '10429', '3770806', '群馬県', 'グンマケン', '吾妻郡東吾妻町', 'アガツマグンヒガシアガツママチ', '小泉', 'コイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県吾妻郡東吾妻町泉沢', '10', '10429', '3770807', '群馬県', 'グンマケン', '吾妻郡東吾妻町', 'アガツマグンヒガシアガツママチ', '泉沢', 'イズミサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県吾妻郡東吾妻町郷原', '10', '10429', '3770811', '群馬県', 'グンマケン', '吾妻郡東吾妻町', 'アガツマグンヒガシアガツママチ', '郷原', 'ゴウバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県吾妻郡東吾妻町厚田', '10', '10429', '3770812', '群馬県', 'グンマケン', '吾妻郡東吾妻町', 'アガツマグンヒガシアガツママチ', '厚田', 'アツダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県吾妻郡東吾妻町三島', '10', '10429', '3770813', '群馬県', 'グンマケン', '吾妻郡東吾妻町', 'アガツマグンヒガシアガツママチ', '三島', 'ミシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県吾妻郡東吾妻町松谷', '10', '10429', '3770814', '群馬県', 'グンマケン', '吾妻郡東吾妻町', 'アガツマグンヒガシアガツママチ', '松谷', 'マツヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県吾妻郡東吾妻町岩下', '10', '10429', '3770815', '群馬県', 'グンマケン', '吾妻郡東吾妻町', 'アガツマグンヒガシアガツママチ', '岩下', 'イワシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県吾妻郡東吾妻町矢倉', '10', '10429', '3770816', '群馬県', 'グンマケン', '吾妻郡東吾妻町', 'アガツマグンヒガシアガツママチ', '矢倉', 'ヤグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県吾妻郡東吾妻町大戸', '10', '10429', '3770931', '群馬県', 'グンマケン', '吾妻郡東吾妻町', 'アガツマグンヒガシアガツママチ', '大戸', 'オオド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県吾妻郡東吾妻町萩生', '10', '10429', '3770932', '群馬県', 'グンマケン', '吾妻郡東吾妻町', 'アガツマグンヒガシアガツママチ', '萩生', 'ハギュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県吾妻郡東吾妻町本宿', '10', '10429', '3770933', '群馬県', 'グンマケン', '吾妻郡東吾妻町', 'アガツマグンヒガシアガツママチ', '本宿', 'モトジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県吾妻郡東吾妻町須賀尾', '10', '10429', '3770934', '群馬県', 'グンマケン', '吾妻郡東吾妻町', 'アガツマグンヒガシアガツママチ', '須賀尾', 'スガオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県吾妻郡東吾妻町大柏木', '10', '10429', '3770935', '群馬県', 'グンマケン', '吾妻郡東吾妻町', 'アガツマグンヒガシアガツママチ', '大柏木', 'オオカシワギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県吾妻郡長野原町', '10', '10424', '3771300', '群馬県', 'グンマケン', '吾妻郡長野原町', 'アガツマグンナガノハラマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('31658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県吾妻郡長野原町川原畑', '10', '10424', '3771301', '群馬県', 'グンマケン', '吾妻郡長野原町', 'アガツマグンナガノハラマチ', '川原畑', 'カワラハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県吾妻郡長野原町川原湯', '10', '10424', '3771302', '群馬県', 'グンマケン', '吾妻郡長野原町', 'アガツマグンナガノハラマチ', '川原湯', 'カワラユ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県吾妻郡長野原町横壁', '10', '10424', '3771303', '群馬県', 'グンマケン', '吾妻郡長野原町', 'アガツマグンナガノハラマチ', '横壁', 'ヨコカベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県吾妻郡長野原町長野原', '10', '10424', '3771304', '群馬県', 'グンマケン', '吾妻郡長野原町', 'アガツマグンナガノハラマチ', '長野原', 'ナガノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県吾妻郡長野原町与喜屋', '10', '10424', '3771305', '群馬県', 'グンマケン', '吾妻郡長野原町', 'アガツマグンナガノハラマチ', '与喜屋', 'ヨキヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県吾妻郡長野原町古森', '10', '10424', '3771306', '群馬県', 'グンマケン', '吾妻郡長野原町', 'アガツマグンナガノハラマチ', '古森', 'フルモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県吾妻郡長野原町羽根尾', '10', '10424', '3771307', '群馬県', 'グンマケン', '吾妻郡長野原町', 'アガツマグンナガノハラマチ', '羽根尾', 'ハネオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県吾妻郡長野原町大津', '10', '10424', '3771308', '群馬県', 'グンマケン', '吾妻郡長野原町', 'アガツマグンナガノハラマチ', '大津', 'オオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県吾妻郡長野原町林', '10', '10424', '3771309', '群馬県', 'グンマケン', '吾妻郡長野原町', 'アガツマグンナガノハラマチ', '林', 'ハヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県吾妻郡長野原町応桑堂光原', '10', '10424', '3771310', '群馬県', 'グンマケン', '吾妻郡長野原町', 'アガツマグンナガノハラマチ', '応桑', 'オオクワ', null, null, '堂光原', 'ドウコウハラ');
INSERT INTO `ms_addresses` VALUES ('31668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県吾妻郡六合村赤岩', '10', '10427', '3771311', '群馬県', 'グンマケン', '吾妻郡六合村', 'アガツマグンクニムラ', '赤岩', 'アカイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県吾妻郡六合村日影', '10', '10427', '3771312', '群馬県', 'グンマケン', '吾妻郡六合村', 'アガツマグンクニムラ', '日影', 'ヒカゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県吾妻郡嬬恋村鎌原奥軽井沢', '10', '10425', '3771401', '群馬県', 'グンマケン', '吾妻郡嬬恋村', 'アガツマグンツマゴイムラ', '鎌原', 'カンバラ', null, null, '奥軽井沢', 'オクカルイザワ');
INSERT INTO `ms_addresses` VALUES ('31674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県吾妻郡嬬恋村鎌原鬼の泉水', '10', '10425', '3771402', '群馬県', 'グンマケン', '吾妻郡嬬恋村', 'アガツマグンツマゴイムラ', '鎌原', 'カンバラ', null, null, '鬼の泉水', 'オニノセンスイ');
INSERT INTO `ms_addresses` VALUES ('31675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県吾妻郡嬬恋村鎌原あやめケ原', '10', '10425', '3771403', '群馬県', 'グンマケン', '吾妻郡嬬恋村', 'アガツマグンツマゴイムラ', '鎌原', 'カンバラ', null, null, 'あやめケ原', 'アヤメガハラ');
INSERT INTO `ms_addresses` VALUES ('31676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県吾妻郡嬬恋村鎌原大カイシコ', '10', '10425', '3771404', '群馬県', 'グンマケン', '吾妻郡嬬恋村', 'アガツマグンツマゴイムラ', '鎌原', 'カンバラ', null, null, '大カイシコ', 'オオカイシコ');
INSERT INTO `ms_addresses` VALUES ('31677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県吾妻郡嬬恋村鎌原モロシコ「浅間園」', '10', '10425', '3771405', '群馬県', 'グンマケン', '吾妻郡嬬恋村', 'アガツマグンツマゴイムラ', '鎌原', 'カンバラ', null, null, 'モロシコ「浅間園」', 'モロシコ＜アサマエン＞');
INSERT INTO `ms_addresses` VALUES ('31678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県吾妻郡長野原町応桑', '10', '10424', '3771411', '群馬県', 'グンマケン', '吾妻郡長野原町', 'アガツマグンナガノハラマチ', '応桑', 'オオクワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県吾妻郡長野原町北軽井沢', '10', '10424', '3771412', '群馬県', 'グンマケン', '吾妻郡長野原町', 'アガツマグンナガノハラマチ', '北軽井沢', 'キタカルイザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県吾妻郡嬬恋村', '10', '10425', '3771500', '群馬県', 'グンマケン', '吾妻郡嬬恋村', 'アガツマグンツマゴイムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('31681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県吾妻郡嬬恋村大前', '10', '10425', '3771512', '群馬県', 'グンマケン', '吾妻郡嬬恋村', 'アガツマグンツマゴイムラ', '大前', 'オオマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県吾妻郡嬬恋村今井', '10', '10425', '3771521', '群馬県', 'グンマケン', '吾妻郡嬬恋村', 'アガツマグンツマゴイムラ', '今井', 'イマイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県吾妻郡嬬恋村袋倉', '10', '10425', '3771522', '群馬県', 'グンマケン', '吾妻郡嬬恋村', 'アガツマグンツマゴイムラ', '袋倉', 'フクログラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県吾妻郡嬬恋村芦生田', '10', '10425', '3771523', '群馬県', 'グンマケン', '吾妻郡嬬恋村', 'アガツマグンツマゴイムラ', '芦生田', 'アシウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県吾妻郡嬬恋村鎌原', '10', '10425', '3771524', '群馬県', 'グンマケン', '吾妻郡嬬恋村', 'アガツマグンツマゴイムラ', '鎌原', 'カンバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県吾妻郡嬬恋村西窪', '10', '10425', '3771525', '群馬県', 'グンマケン', '吾妻郡嬬恋村', 'アガツマグンツマゴイムラ', '西窪', 'サイクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県吾妻郡嬬恋村三原', '10', '10425', '3771526', '群馬県', 'グンマケン', '吾妻郡嬬恋村', 'アガツマグンツマゴイムラ', '三原', 'ミハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県吾妻郡嬬恋村門貝', '10', '10425', '3771527', '群馬県', 'グンマケン', '吾妻郡嬬恋村', 'アガツマグンツマゴイムラ', '門貝', 'カドガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県吾妻郡嬬恋村干俣吾妻鉱山', '10', '10425', '3771528', '群馬県', 'グンマケン', '吾妻郡嬬恋村', 'アガツマグンツマゴイムラ', '干俣', 'ホシマタ', null, null, '吾妻鉱山', 'アガツマコウザン');
INSERT INTO `ms_addresses` VALUES ('31690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県吾妻郡嬬恋村干俣万座温泉', '10', '10425', '3771528', '群馬県', 'グンマケン', '吾妻郡嬬恋村', 'アガツマグンツマゴイムラ', '干俣', 'ホシマタ', null, null, '万座温泉', 'マンザオンセン');
INSERT INTO `ms_addresses` VALUES ('31694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県吾妻郡嬬恋村干俣', '10', '10425', '3771611', '群馬県', 'グンマケン', '吾妻郡嬬恋村', 'アガツマグンツマゴイムラ', '干俣', 'ホシマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県吾妻郡嬬恋村大前', '10', '10425', '3771612', '群馬県', 'グンマケン', '吾妻郡嬬恋村', 'アガツマグンツマゴイムラ', '大前', 'オオマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県吾妻郡嬬恋村大笹', '10', '10425', '3771613', '群馬県', 'グンマケン', '吾妻郡嬬恋村', 'アガツマグンツマゴイムラ', '大笹', 'オオザサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県吾妻郡嬬恋村田代', '10', '10425', '3771614', '群馬県', 'グンマケン', '吾妻郡嬬恋村', 'アガツマグンツマゴイムラ', '田代', 'タシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県吾妻郡嬬恋村鎌原藤原', '10', '10425', '3771615', '群馬県', 'グンマケン', '吾妻郡嬬恋村', 'アガツマグンツマゴイムラ', '鎌原', 'カンバラ', null, null, '藤原', 'フジワラ');
INSERT INTO `ms_addresses` VALUES ('31699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県吾妻郡嬬恋村鎌原柏木塚', '10', '10425', '3771616', '群馬県', 'グンマケン', '吾妻郡嬬恋村', 'アガツマグンツマゴイムラ', '鎌原', 'カンバラ', null, null, '柏木塚', 'カシワギヅカ');
INSERT INTO `ms_addresses` VALUES ('31700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県吾妻郡嬬恋村鎌原群馬坂', '10', '10425', '3771617', '群馬県', 'グンマケン', '吾妻郡嬬恋村', 'アガツマグンツマゴイムラ', '鎌原', 'カンバラ', null, null, '群馬坂', 'グンマザカ');
INSERT INTO `ms_addresses` VALUES ('31704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県吾妻郡草津町', '10', '10426', '3771700', '群馬県', 'グンマケン', '吾妻郡草津町', 'アガツマグンクサツマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('31705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県吾妻郡六合村', '10', '10427', '3771700', '群馬県', 'グンマケン', '吾妻郡六合村', 'アガツマグンクニムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('31706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県吾妻郡六合村入山', '10', '10427', '3771701', '群馬県', 'グンマケン', '吾妻郡六合村', 'アガツマグンクニムラ', '入山', 'イリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県吾妻郡六合村生須', '10', '10427', '3771702', '群馬県', 'グンマケン', '吾妻郡六合村', 'アガツマグンクニムラ', '生須', 'ナマス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県吾妻郡六合村太子', '10', '10427', '3771703', '群馬県', 'グンマケン', '吾妻郡六合村', 'アガツマグンクニムラ', '太子', 'オオシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県吾妻郡六合村小雨', '10', '10427', '3771704', '群馬県', 'グンマケン', '吾妻郡六合村', 'アガツマグンクニムラ', '小雨', 'コサメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県吾妻郡草津町草津', '10', '10426', '3771711', '群馬県', 'グンマケン', '吾妻郡草津町', 'アガツマグンクサツマチ', '草津', 'クサツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県吾妻郡草津町前口', '10', '10426', '3771712', '群馬県', 'グンマケン', '吾妻郡草津町', 'アガツマグンクサツマチ', '前口', 'マエグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県沼田市', '10', '10206', '3780000', '群馬県', 'グンマケン', '沼田市', 'ヌマタシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('31735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県沼田市戸神町', '10', '10206', '3780001', '群馬県', 'グンマケン', '沼田市', 'ヌマタシ', '戸神町', 'トカミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県沼田市横塚町', '10', '10206', '3780002', '群馬県', 'グンマケン', '沼田市', 'ヌマタシ', '横塚町', 'ヨコヅカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県沼田市上久屋町', '10', '10206', '3780003', '群馬県', 'グンマケン', '沼田市', 'ヌマタシ', '上久屋町', 'カミクヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県沼田市下久屋町', '10', '10206', '3780004', '群馬県', 'グンマケン', '沼田市', 'ヌマタシ', '下久屋町', 'シモクヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県沼田市久屋原町', '10', '10206', '3780005', '群馬県', 'グンマケン', '沼田市', 'ヌマタシ', '久屋原町', 'クヤハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県沼田市上沼須町', '10', '10206', '3780011', '群馬県', 'グンマケン', '沼田市', 'ヌマタシ', '上沼須町', 'カミヌマスマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県沼田市沼須町', '10', '10206', '3780012', '群馬県', 'グンマケン', '沼田市', 'ヌマタシ', '沼須町', 'ヌマスマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県沼田市新町', '10', '10206', '3780013', '群馬県', 'グンマケン', '沼田市', 'ヌマタシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県沼田市栄町', '10', '10206', '3780014', '群馬県', 'グンマケン', '沼田市', 'ヌマタシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県沼田市戸鹿野町', '10', '10206', '3780015', '群馬県', 'グンマケン', '沼田市', 'ヌマタシ', '戸鹿野町', 'トガノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県沼田市清水町', '10', '10206', '3780016', '群馬県', 'グンマケン', '沼田市', 'ヌマタシ', '清水町', 'シミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県沼田市坊新田町', '10', '10206', '3780017', '群馬県', 'グンマケン', '沼田市', 'ヌマタシ', '坊新田町', 'ボウシンデンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県沼田市鍛冶町', '10', '10206', '3780018', '群馬県', 'グンマケン', '沼田市', 'ヌマタシ', '鍛冶町', 'カジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県沼田市岩本町', '10', '10206', '3780021', '群馬県', 'グンマケン', '沼田市', 'ヌマタシ', '岩本町', 'イワモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県沼田市屋形原町', '10', '10206', '3780022', '群馬県', 'グンマケン', '沼田市', 'ヌマタシ', '屋形原町', 'ヤカタバラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県沼田市篠尾町', '10', '10206', '3780023', '群馬県', 'グンマケン', '沼田市', 'ヌマタシ', '篠尾町', 'ササオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県沼田市下川田町', '10', '10206', '3780024', '群馬県', 'グンマケン', '沼田市', 'ヌマタシ', '下川田町', 'シモカワダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県沼田市今井町', '10', '10206', '3780025', '群馬県', 'グンマケン', '沼田市', 'ヌマタシ', '今井町', 'イマイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県沼田市上川田町', '10', '10206', '3780026', '群馬県', 'グンマケン', '沼田市', 'ヌマタシ', '上川田町', 'カミカワダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県沼田市薄根町', '10', '10206', '3780031', '群馬県', 'グンマケン', '沼田市', 'ヌマタシ', '薄根町', 'ウスネマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県沼田市硯田町', '10', '10206', '3780032', '群馬県', 'グンマケン', '沼田市', 'ヌマタシ', '硯田町', 'スズリダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県沼田市白岩町', '10', '10206', '3780033', '群馬県', 'グンマケン', '沼田市', 'ヌマタシ', '白岩町', 'シライワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県沼田市恩田町', '10', '10206', '3780034', '群馬県', 'グンマケン', '沼田市', 'ヌマタシ', '恩田町', 'オンダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県沼田市井土上町', '10', '10206', '3780035', '群馬県', 'グンマケン', '沼田市', 'ヌマタシ', '井土上町', 'イドノウエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県沼田市榛名町', '10', '10206', '3780041', '群馬県', 'グンマケン', '沼田市', 'ヌマタシ', '榛名町', 'ハルナマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県沼田市西倉内町', '10', '10206', '3780042', '群馬県', 'グンマケン', '沼田市', 'ヌマタシ', '西倉内町', 'ニシクラウチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県沼田市東倉内町', '10', '10206', '3780043', '群馬県', 'グンマケン', '沼田市', 'ヌマタシ', '東倉内町', 'ヒガシクラウチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県沼田市下之町', '10', '10206', '3780044', '群馬県', 'グンマケン', '沼田市', 'ヌマタシ', '下之町', 'シモノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県沼田市材木町', '10', '10206', '3780045', '群馬県', 'グンマケン', '沼田市', 'ヌマタシ', '材木町', 'ザイモクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県沼田市馬喰町', '10', '10206', '3780046', '群馬県', 'グンマケン', '沼田市', 'ヌマタシ', '馬喰町', 'バクロウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県沼田市上之町', '10', '10206', '3780047', '群馬県', 'グンマケン', '沼田市', 'ヌマタシ', '上之町', 'カミノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県沼田市中町', '10', '10206', '3780048', '群馬県', 'グンマケン', '沼田市', 'ヌマタシ', '中町', 'ナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県沼田市上原町', '10', '10206', '3780051', '群馬県', 'グンマケン', '沼田市', 'ヌマタシ', '上原町', 'カミハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県沼田市桜町', '10', '10206', '3780052', '群馬県', 'グンマケン', '沼田市', 'ヌマタシ', '桜町', 'サクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県沼田市東原新町', '10', '10206', '3780053', '群馬県', 'グンマケン', '沼田市', 'ヌマタシ', '東原新町', 'ヒガシハラシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県沼田市西原新町', '10', '10206', '3780054', '群馬県', 'グンマケン', '沼田市', 'ヌマタシ', '西原新町', 'ニシハラシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県沼田市柳町', '10', '10206', '3780055', '群馬県', 'グンマケン', '沼田市', 'ヌマタシ', '柳町', 'ヤナギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県沼田市高橋場町', '10', '10206', '3780056', '群馬県', 'グンマケン', '沼田市', 'ヌマタシ', '高橋場町', 'タカハシバマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県沼田市岡谷町', '10', '10206', '3780061', '群馬県', 'グンマケン', '沼田市', 'ヌマタシ', '岡谷町', 'オカヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県沼田市町田町', '10', '10206', '3780062', '群馬県', 'グンマケン', '沼田市', 'ヌマタシ', '町田町', 'マチダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県沼田市下沼田町', '10', '10206', '3780063', '群馬県', 'グンマケン', '沼田市', 'ヌマタシ', '下沼田町', 'シモヌマタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県沼田市善桂寺町', '10', '10206', '3780064', '群馬県', 'グンマケン', '沼田市', 'ヌマタシ', '善桂寺町', 'ゼンケイジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県沼田市堀廻町', '10', '10206', '3780065', '群馬県', 'グンマケン', '沼田市', 'ヌマタシ', '堀廻町', 'ホリメグリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県沼田市原町', '10', '10206', '3780066', '群馬県', 'グンマケン', '沼田市', 'ヌマタシ', '原町', 'ハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県沼田市大釜町', '10', '10206', '3780067', '群馬県', 'グンマケン', '沼田市', 'ヌマタシ', '大釜町', 'オオガママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県沼田市宇楚井町', '10', '10206', '3780068', '群馬県', 'グンマケン', '沼田市', 'ヌマタシ', '宇楚井町', 'ウソイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県沼田市上発知町', '10', '10206', '3780071', '群馬県', 'グンマケン', '沼田市', 'ヌマタシ', '上発知町', 'カミホッチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県沼田市中発知町', '10', '10206', '3780072', '群馬県', 'グンマケン', '沼田市', 'ヌマタシ', '中発知町', 'ナカホッチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県沼田市発知新田町', '10', '10206', '3780073', '群馬県', 'グンマケン', '沼田市', 'ヌマタシ', '発知新田町', 'ホッチシンデンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県沼田市下発知町', '10', '10206', '3780074', '群馬県', 'グンマケン', '沼田市', 'ヌマタシ', '下発知町', 'シモホッチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県沼田市奈良町', '10', '10206', '3780075', '群馬県', 'グンマケン', '沼田市', 'ヌマタシ', '奈良町', 'ナラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県沼田市秋塚町', '10', '10206', '3780076', '群馬県', 'グンマケン', '沼田市', 'ヌマタシ', '秋塚町', 'アキヅカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県沼田市石墨町', '10', '10206', '3780077', '群馬県', 'グンマケン', '沼田市', 'ヌマタシ', '石墨町', 'イシズミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県沼田市佐山町', '10', '10206', '3780078', '群馬県', 'グンマケン', '沼田市', 'ヌマタシ', '佐山町', 'サヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県利根郡川場村', '10', '10444', '3780100', '群馬県', 'グンマケン', '利根郡川場村', 'トネグンカワバムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('31790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県利根郡川場村谷地', '10', '10444', '3780101', '群馬県', 'グンマケン', '利根郡川場村', 'トネグンカワバムラ', '谷地', 'ヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県利根郡川場村川場湯原', '10', '10444', '3780102', '群馬県', 'グンマケン', '利根郡川場村', 'トネグンカワバムラ', '川場湯原', 'カワバユバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県利根郡川場村中野', '10', '10444', '3780103', '群馬県', 'グンマケン', '利根郡川場村', 'トネグンカワバムラ', '中野', 'ナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県利根郡川場村太田川', '10', '10444', '3780104', '群馬県', 'グンマケン', '利根郡川場村', 'トネグンカワバムラ', '太田川', 'オオタガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県利根郡川場村小田川', '10', '10444', '3780105', '群馬県', 'グンマケン', '利根郡川場村', 'トネグンカワバムラ', '小田川', 'コタガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県利根郡川場村萩室', '10', '10444', '3780111', '群馬県', 'グンマケン', '利根郡川場村', 'トネグンカワバムラ', '萩室', 'ハギムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県利根郡川場村立岩', '10', '10444', '3780112', '群馬県', 'グンマケン', '利根郡川場村', 'トネグンカワバムラ', '立岩', 'タツイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県利根郡川場村生品', '10', '10444', '3780113', '群馬県', 'グンマケン', '利根郡川場村', 'トネグンカワバムラ', '生品', 'ナマシナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県利根郡川場村天神', '10', '10444', '3780114', '群馬県', 'グンマケン', '利根郡川場村', 'トネグンカワバムラ', '天神', 'テンジン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県利根郡川場村門前', '10', '10444', '3780115', '群馬県', 'グンマケン', '利根郡川場村', 'トネグンカワバムラ', '門前', 'モンゼン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県沼田市白沢町高平', '10', '10206', '3780121', '群馬県', 'グンマケン', '沼田市', 'ヌマタシ', '白沢町高平', 'シラサワマチタカヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県沼田市白沢町生枝', '10', '10206', '3780122', '群馬県', 'グンマケン', '沼田市', 'ヌマタシ', '白沢町生枝', 'シラサワマチナマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県沼田市白沢町岩室', '10', '10206', '3780123', '群馬県', 'グンマケン', '沼田市', 'ヌマタシ', '白沢町岩室', 'シラサワマチイワムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県沼田市白沢町尾合', '10', '10206', '3780124', '群馬県', 'グンマケン', '沼田市', 'ヌマタシ', '白沢町尾合', 'シラサワマチオアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県沼田市白沢町平出', '10', '10206', '3780125', '群馬県', 'グンマケン', '沼田市', 'ヌマタシ', '白沢町平出', 'シラサワマチヒライデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県沼田市白沢町上古語父', '10', '10206', '3780126', '群馬県', 'グンマケン', '沼田市', 'ヌマタシ', '白沢町上古語父', 'シラサワマチカミココブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県沼田市白沢町下古語父', '10', '10206', '3780127', '群馬県', 'グンマケン', '沼田市', 'ヌマタシ', '白沢町下古語父', 'シラサワマチシモココブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県沼田市利根町平川', '10', '10206', '3780301', '群馬県', 'グンマケン', '沼田市', 'ヌマタシ', '利根町平川', 'トネマチヒラガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県沼田市利根町千鳥', '10', '10206', '3780302', '群馬県', 'グンマケン', '沼田市', 'ヌマタシ', '利根町千鳥', 'トネマチチドリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県沼田市利根町追貝', '10', '10206', '3780303', '群馬県', 'グンマケン', '沼田市', 'ヌマタシ', '利根町追貝', 'トネマチオッカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県沼田市利根町大楊', '10', '10206', '3780304', '群馬県', 'グンマケン', '沼田市', 'ヌマタシ', '利根町大楊', 'トネマチオオヨウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県沼田市利根町穴原', '10', '10206', '3780305', '群馬県', 'グンマケン', '沼田市', 'ヌマタシ', '利根町穴原', 'トネマチアナバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県沼田市利根町日向南郷', '10', '10206', '3780306', '群馬県', 'グンマケン', '沼田市', 'ヌマタシ', '利根町日向南郷', 'トネマチヒナタナンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県沼田市利根町柿平', '10', '10206', '3780307', '群馬県', 'グンマケン', '沼田市', 'ヌマタシ', '利根町柿平', 'トネマチカキダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県沼田市利根町小松', '10', '10206', '3780311', '群馬県', 'グンマケン', '沼田市', 'ヌマタシ', '利根町小松', 'トネマチコマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県沼田市利根町根利', '10', '10206', '3780312', '群馬県', 'グンマケン', '沼田市', 'ヌマタシ', '利根町根利', 'トネマチネリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県沼田市利根町日影南郷', '10', '10206', '3780313', '群馬県', 'グンマケン', '沼田市', 'ヌマタシ', '利根町日影南郷', 'トネマチヒカゲナンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県沼田市利根町青木', '10', '10206', '3780314', '群馬県', 'グンマケン', '沼田市', 'ヌマタシ', '利根町青木', 'トネマチアオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県沼田市利根町砂川', '10', '10206', '3780315', '群馬県', 'グンマケン', '沼田市', 'ヌマタシ', '利根町砂川', 'トネマチスナガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県沼田市利根町二本松', '10', '10206', '3780316', '群馬県', 'グンマケン', '沼田市', 'ヌマタシ', '利根町二本松', 'トネマチニホンマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県沼田市利根町多那', '10', '10206', '3780317', '群馬県', 'グンマケン', '沼田市', 'ヌマタシ', '利根町多那', 'トネマチタナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県沼田市利根町高戸谷', '10', '10206', '3780321', '群馬県', 'グンマケン', '沼田市', 'ヌマタシ', '利根町高戸谷', 'トネマチタカトヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県沼田市利根町老神', '10', '10206', '3780322', '群馬県', 'グンマケン', '沼田市', 'ヌマタシ', '利根町老神', 'トネマチオイガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県沼田市利根町大原', '10', '10206', '3780323', '群馬県', 'グンマケン', '沼田市', 'ヌマタシ', '利根町大原', 'トネマチオオハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県沼田市利根町園原', '10', '10206', '3780324', '群馬県', 'グンマケン', '沼田市', 'ヌマタシ', '利根町園原', 'トネマチソノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県沼田市利根町輪組', '10', '10206', '3780325', '群馬県', 'グンマケン', '沼田市', 'ヌマタシ', '利根町輪組', 'トネマチワクミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県沼田市利根町石戸新田', '10', '10206', '3780326', '群馬県', 'グンマケン', '沼田市', 'ヌマタシ', '利根町石戸新田', 'トネマチイシドシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県利根郡片品村', '10', '10443', '3780400', '群馬県', 'グンマケン', '利根郡片品村', 'トネグンカタシナムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('31828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県利根郡片品村須賀川', '10', '10443', '3780401', '群馬県', 'グンマケン', '利根郡片品村', 'トネグンカタシナムラ', '須賀川', 'スカガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県利根郡片品村御座入', '10', '10443', '3780402', '群馬県', 'グンマケン', '利根郡片品村', 'トネグンカタシナムラ', '御座入', 'ゴザイリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県利根郡片品村菅沼', '10', '10443', '3780403', '群馬県', 'グンマケン', '利根郡片品村', 'トネグンカタシナムラ', '菅沼', 'スガヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県利根郡片品村築地', '10', '10443', '3780404', '群馬県', 'グンマケン', '利根郡片品村', 'トネグンカタシナムラ', '築地', 'ツイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県利根郡片品村下平', '10', '10443', '3780405', '群馬県', 'グンマケン', '利根郡片品村', 'トネグンカタシナムラ', '下平', 'シモダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県利根郡片品村摺淵', '10', '10443', '3780406', '群馬県', 'グンマケン', '利根郡片品村', 'トネグンカタシナムラ', '摺淵', 'スルブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県利根郡片品村幡谷', '10', '10443', '3780407', '群馬県', 'グンマケン', '利根郡片品村', 'トネグンカタシナムラ', '幡谷', 'ハタヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県利根郡片品村花咲', '10', '10443', '3780408', '群馬県', 'グンマケン', '利根郡片品村', 'トネグンカタシナムラ', '花咲', 'ハナサク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県利根郡片品村針山', '10', '10443', '3780409', '群馬県', 'グンマケン', '利根郡片品村', 'トネグンカタシナムラ', '針山', 'ハリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県利根郡片品村戸倉', '10', '10443', '3780411', '群馬県', 'グンマケン', '利根郡片品村', 'トネグンカタシナムラ', '戸倉', 'トクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県利根郡片品村土出', '10', '10443', '3780412', '群馬県', 'グンマケン', '利根郡片品村', 'トネグンカタシナムラ', '土出', 'ツチイデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県利根郡片品村越本', '10', '10443', '3780413', '群馬県', 'グンマケン', '利根郡片品村', 'トネグンカタシナムラ', '越本', 'コシモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県利根郡片品村東小川', '10', '10443', '3780414', '群馬県', 'グンマケン', '利根郡片品村', 'トネグンカタシナムラ', '東小川', 'ヒガシオガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県利根郡片品村鎌田', '10', '10443', '3780415', '群馬県', 'グンマケン', '利根郡片品村', 'トネグンカタシナムラ', '鎌田', 'カマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県安中市', '10', '10211', '3790100', '群馬県', 'グンマケン', '安中市', 'アンナカシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('31847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県安中市西上秋間', '10', '10211', '3790101', '群馬県', 'グンマケン', '安中市', 'アンナカシ', '西上秋間', 'ニシカミアキマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県安中市東上秋間', '10', '10211', '3790102', '群馬県', 'グンマケン', '安中市', 'アンナカシ', '東上秋間', 'ヒガシカミアキマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県安中市中秋間', '10', '10211', '3790103', '群馬県', 'グンマケン', '安中市', 'アンナカシ', '中秋間', 'ナカアキマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県安中市下秋間', '10', '10211', '3790104', '群馬県', 'グンマケン', '安中市', 'アンナカシ', '下秋間', 'シモアキマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県安中市小俣', '10', '10211', '3790105', '群馬県', 'グンマケン', '安中市', 'アンナカシ', '小俣', 'オマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県安中市下後閑', '10', '10211', '3790106', '群馬県', 'グンマケン', '安中市', 'アンナカシ', '下後閑', 'シモゴカン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県安中市中後閑', '10', '10211', '3790107', '群馬県', 'グンマケン', '安中市', 'アンナカシ', '中後閑', 'ナカゴカン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県安中市上後閑', '10', '10211', '3790108', '群馬県', 'グンマケン', '安中市', 'アンナカシ', '上後閑', 'カミゴカン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県安中市秋間みのりが丘', '10', '10211', '3790109', '群馬県', 'グンマケン', '安中市', 'アンナカシ', '秋間みのりが丘', 'アキマミノリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県安中市板鼻', '10', '10211', '3790111', '群馬県', 'グンマケン', '安中市', 'アンナカシ', '板鼻', 'イタハナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県安中市岩井', '10', '10211', '3790112', '群馬県', 'グンマケン', '安中市', 'アンナカシ', '岩井', 'イワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県安中市大谷', '10', '10211', '3790113', '群馬県', 'グンマケン', '安中市', 'アンナカシ', '大谷', 'オオヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県安中市野殿', '10', '10211', '3790114', '群馬県', 'グンマケン', '安中市', 'アンナカシ', '野殿', 'ノドノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県安中市中宿', '10', '10211', '3790115', '群馬県', 'グンマケン', '安中市', 'アンナカシ', '中宿', 'ナカジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県安中市安中', '10', '10211', '3790116', '群馬県', 'グンマケン', '安中市', 'アンナカシ', '安中', 'アンナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県安中市大竹', '10', '10211', '3790121', '群馬県', 'グンマケン', '安中市', 'アンナカシ', '大竹', 'オオタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県安中市下間仁田', '10', '10211', '3790122', '群馬県', 'グンマケン', '安中市', 'アンナカシ', '下間仁田', 'シモマニタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県安中市上間仁田', '10', '10211', '3790123', '群馬県', 'グンマケン', '安中市', 'アンナカシ', '上間仁田', 'カミマニタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県安中市鷺宮', '10', '10211', '3790124', '群馬県', 'グンマケン', '安中市', 'アンナカシ', '鷺宮', 'サギノミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県安中市中野谷', '10', '10211', '3790125', '群馬県', 'グンマケン', '安中市', 'アンナカシ', '中野谷', 'ナカノヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県安中市西上磯部', '10', '10211', '3790126', '群馬県', 'グンマケン', '安中市', 'アンナカシ', '西上磯部', 'ニシカミイソベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県安中市磯部', '10', '10211', '3790127', '群馬県', 'グンマケン', '安中市', 'アンナカシ', '磯部', 'イソベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県安中市東上磯部', '10', '10211', '3790128', '群馬県', 'グンマケン', '安中市', 'アンナカシ', '東上磯部', 'ヒガシカミイソベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県安中市下磯部', '10', '10211', '3790129', '群馬県', 'グンマケン', '安中市', 'アンナカシ', '下磯部', 'シモイソベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県安中市古屋', '10', '10211', '3790131', '群馬県', 'グンマケン', '安中市', 'アンナカシ', '古屋', 'フルヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県安中市高別当', '10', '10211', '3790132', '群馬県', 'グンマケン', '安中市', 'アンナカシ', '高別当', 'コウベツトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県安中市原市', '10', '10211', '3790133', '群馬県', 'グンマケン', '安中市', 'アンナカシ', '原市', 'ハライチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県安中市簗瀬', '10', '10211', '3790134', '群馬県', 'グンマケン', '安中市', 'アンナカシ', '簗瀬', 'ヤナセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県安中市郷原', '10', '10211', '3790135', '群馬県', 'グンマケン', '安中市', 'アンナカシ', '郷原', 'ゴウバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県安中市嶺', '10', '10211', '3790136', '群馬県', 'グンマケン', '安中市', 'アンナカシ', '嶺', 'ミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県富岡市妙義町妙義', '10', '10210', '3790201', '群馬県', 'グンマケン', '富岡市', 'トミオカシ', '妙義町妙義', 'ミョウギマチミョウギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県富岡市妙義町大牛', '10', '10210', '3790202', '群馬県', 'グンマケン', '富岡市', 'トミオカシ', '妙義町大牛', 'ミョウギマチオオウシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県富岡市妙義町岳', '10', '10210', '3790203', '群馬県', 'グンマケン', '富岡市', 'トミオカシ', '妙義町岳', 'ミョウギマチタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県富岡市妙義町行沢', '10', '10210', '3790204', '群馬県', 'グンマケン', '富岡市', 'トミオカシ', '妙義町行沢', 'ミョウギマチナメザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県富岡市妙義町北山', '10', '10210', '3790205', '群馬県', 'グンマケン', '富岡市', 'トミオカシ', '妙義町北山', 'ミョウギマチキタヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県富岡市妙義町中里', '10', '10210', '3790206', '群馬県', 'グンマケン', '富岡市', 'トミオカシ', '妙義町中里', 'ミョウギマチナカザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県富岡市妙義町古立', '10', '10210', '3790207', '群馬県', 'グンマケン', '富岡市', 'トミオカシ', '妙義町古立', 'ミョウギマチフルタチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県富岡市妙義町菅原', '10', '10210', '3790208', '群馬県', 'グンマケン', '富岡市', 'トミオカシ', '妙義町菅原', 'ミョウギマチスガハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県富岡市妙義町諸戸', '10', '10210', '3790209', '群馬県', 'グンマケン', '富岡市', 'トミオカシ', '妙義町諸戸', 'ミョウギマチモロト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県安中市松井田町上増田', '10', '10211', '3790211', '群馬県', 'グンマケン', '安中市', 'アンナカシ', '松井田町上増田', 'マツイダマチカミマスダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県安中市松井田町下増田', '10', '10211', '3790212', '群馬県', 'グンマケン', '安中市', 'アンナカシ', '松井田町下増田', 'マツイダマチシモマスダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県安中市松井田町小日向', '10', '10211', '3790213', '群馬県', 'グンマケン', '安中市', 'アンナカシ', '松井田町小日向', 'マツイダマチオビナタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県安中市松井田町国衙', '10', '10211', '3790214', '群馬県', 'グンマケン', '安中市', 'アンナカシ', '松井田町国衙', 'マツイダマチコクガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県安中市松井田町高梨子', '10', '10211', '3790215', '群馬県', 'グンマケン', '安中市', 'アンナカシ', '松井田町高梨子', 'マツイダマチタカナシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県安中市松井田町新井', '10', '10211', '3790216', '群馬県', 'グンマケン', '安中市', 'アンナカシ', '松井田町新井', 'マツイダマチアライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県安中市松井田町土塩', '10', '10211', '3790217', '群馬県', 'グンマケン', '安中市', 'アンナカシ', '松井田町土塩', 'マツイダマチヒジシオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県安中市松井田町新堀', '10', '10211', '3790221', '群馬県', 'グンマケン', '安中市', 'アンナカシ', '松井田町新堀', 'マツイダマチニイボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県安中市松井田町松井田', '10', '10211', '3790222', '群馬県', 'グンマケン', '安中市', 'アンナカシ', '松井田町松井田', 'マツイダマチマツイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県安中市松井田町二軒在家', '10', '10211', '3790223', '群馬県', 'グンマケン', '安中市', 'アンナカシ', '松井田町二軒在家', 'マツイダマチニケンザイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県安中市松井田町人見', '10', '10211', '3790224', '群馬県', 'グンマケン', '安中市', 'アンナカシ', '松井田町人見', 'マツイダマチヒトミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県安中市松井田町八城', '10', '10211', '3790225', '群馬県', 'グンマケン', '安中市', 'アンナカシ', '松井田町八城', 'マツイダマチヤシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県安中市松井田町行田', '10', '10211', '3790226', '群馬県', 'グンマケン', '安中市', 'アンナカシ', '松井田町行田', 'マツイダマチオクナダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県安中市松井田町横川', '10', '10211', '3790301', '群馬県', 'グンマケン', '安中市', 'アンナカシ', '松井田町横川', 'マツイダマチヨコカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県安中市松井田町五料', '10', '10211', '3790302', '群馬県', 'グンマケン', '安中市', 'アンナカシ', '松井田町五料', 'マツイダマチゴリョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県安中市松井田町西野牧', '10', '10211', '3790303', '群馬県', 'グンマケン', '安中市', 'アンナカシ', '松井田町西野牧', 'マツイダマチニシノマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県安中市松井田町北野牧', '10', '10211', '3790304', '群馬県', 'グンマケン', '安中市', 'アンナカシ', '松井田町北野牧', 'マツイダマチキタノマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県安中市松井田町入山', '10', '10211', '3790305', '群馬県', 'グンマケン', '安中市', 'アンナカシ', '松井田町入山', 'マツイダマチイリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県安中市松井田町原', '10', '10211', '3790306', '群馬県', 'グンマケン', '安中市', 'アンナカシ', '松井田町原', 'マツイダマチハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県安中市松井田町坂本', '10', '10211', '3790307', '群馬県', 'グンマケン', '安中市', 'アンナカシ', '松井田町坂本', 'マツイダマチサカモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県渋川市赤城町棚下', '10', '10208', '3791101', '群馬県', 'グンマケン', '渋川市', 'シブカワシ', '赤城町棚下', 'アカギマチタナシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県渋川市赤城町長井小川田', '10', '10208', '3791102', '群馬県', 'グンマケン', '渋川市', 'シブカワシ', '赤城町長井小川田', 'アカギマチナガイオガワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県渋川市赤城町津久田', '10', '10208', '3791103', '群馬県', 'グンマケン', '渋川市', 'シブカワシ', '赤城町津久田', 'アカギマチツクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県渋川市赤城町敷島', '10', '10208', '3791104', '群馬県', 'グンマケン', '渋川市', 'シブカワシ', '赤城町敷島', 'アカギマチシキシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県渋川市赤城町北上野', '10', '10208', '3791105', '群馬県', 'グンマケン', '渋川市', 'シブカワシ', '赤城町北上野', 'アカギマチキタウエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県渋川市赤城町北赤城山', '10', '10208', '3791111', '群馬県', 'グンマケン', '渋川市', 'シブカワシ', '赤城町北赤城山', 'アカギマチキタアカギサン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県渋川市赤城町深山', '10', '10208', '3791112', '群馬県', 'グンマケン', '渋川市', 'シブカワシ', '赤城町深山', 'アカギマチミヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県渋川市赤城町南赤城山', '10', '10208', '3791113', '群馬県', 'グンマケン', '渋川市', 'シブカワシ', '赤城町南赤城山', 'アカギマチミナミアカギサン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県渋川市赤城町栄', '10', '10208', '3791114', '群馬県', 'グンマケン', '渋川市', 'シブカワシ', '赤城町栄', 'アカギマチサカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県渋川市赤城町溝呂木', '10', '10208', '3791115', '群馬県', 'グンマケン', '渋川市', 'シブカワシ', '赤城町溝呂木', 'アカギマチミゾロキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県渋川市赤城町持柏木', '10', '10208', '3791116', '群馬県', 'グンマケン', '渋川市', 'シブカワシ', '赤城町持柏木', 'アカギマチモチカシワギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県渋川市赤城町宮田', '10', '10208', '3791121', '群馬県', 'グンマケン', '渋川市', 'シブカワシ', '赤城町宮田', 'アカギマチミヤダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県渋川市赤城町勝保沢', '10', '10208', '3791122', '群馬県', 'グンマケン', '渋川市', 'シブカワシ', '赤城町勝保沢', 'アカギマチカツホザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県渋川市赤城町見立', '10', '10208', '3791123', '群馬県', 'グンマケン', '渋川市', 'シブカワシ', '赤城町見立', 'アカギマチミタチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県渋川市赤城町滝沢', '10', '10208', '3791124', '群馬県', 'グンマケン', '渋川市', 'シブカワシ', '赤城町滝沢', 'アカギマチタキザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県渋川市赤城町上三原田', '10', '10208', '3791125', '群馬県', 'グンマケン', '渋川市', 'シブカワシ', '赤城町上三原田', 'アカギマチカミミハラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県渋川市赤城町三原田', '10', '10208', '3791126', '群馬県', 'グンマケン', '渋川市', 'シブカワシ', '赤城町三原田', 'アカギマチミハラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県渋川市赤城町樽', '10', '10208', '3791127', '群馬県', 'グンマケン', '渋川市', 'シブカワシ', '赤城町樽', 'アカギマチタル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県利根郡昭和村', '10', '10448', '3791200', '群馬県', 'グンマケン', '利根郡昭和村', 'トネグンショウワムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('31931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県利根郡昭和村生越', '10', '10448', '3791201', '群馬県', 'グンマケン', '利根郡昭和村', 'トネグンショウワムラ', '生越', 'オゴセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県利根郡昭和村貝野瀬', '10', '10448', '3791202', '群馬県', 'グンマケン', '利根郡昭和村', 'トネグンショウワムラ', '貝野瀬', 'カイノセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県利根郡昭和村糸井', '10', '10448', '3791203', '群馬県', 'グンマケン', '利根郡昭和村', 'トネグンショウワムラ', '糸井', 'イトイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県利根郡昭和村森下', '10', '10448', '3791204', '群馬県', 'グンマケン', '利根郡昭和村', 'トネグンショウワムラ', '森下', 'モリシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県利根郡昭和村川額', '10', '10448', '3791205', '群馬県', 'グンマケン', '利根郡昭和村', 'トネグンショウワムラ', '川額', 'カワハケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県利根郡昭和村橡久保', '10', '10448', '3791206', '群馬県', 'グンマケン', '利根郡昭和村', 'トネグンショウワムラ', '橡久保', 'トチクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県利根郡昭和村赤城原', '10', '10448', '3791207', '群馬県', 'グンマケン', '利根郡昭和村', 'トネグンショウワムラ', '赤城原', 'アカギハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県利根郡みなかみ町', '10', '10449', '3791300', '群馬県', 'グンマケン', '利根郡みなかみ町', 'トネグンミナカミマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('31940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県利根郡みなかみ町奈女沢', '10', '10449', '3791301', '群馬県', 'グンマケン', '利根郡みなかみ町', 'トネグンミナカミマチ', '奈女沢', 'ナメザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県利根郡みなかみ町大沼', '10', '10449', '3791302', '群馬県', 'グンマケン', '利根郡みなかみ町', 'トネグンミナカミマチ', '大沼', 'オオヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県利根郡みなかみ町上牧', '10', '10449', '3791303', '群馬県', 'グンマケン', '利根郡みなかみ町', 'トネグンミナカミマチ', '上牧', 'カミモク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県利根郡みなかみ町下牧', '10', '10449', '3791304', '群馬県', 'グンマケン', '利根郡みなかみ町', 'トネグンミナカミマチ', '下牧', 'シモモク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県利根郡みなかみ町後閑', '10', '10449', '3791305', '群馬県', 'グンマケン', '利根郡みなかみ町', 'トネグンミナカミマチ', '後閑', 'ゴカン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県利根郡みなかみ町師', '10', '10449', '3791306', '群馬県', 'グンマケン', '利根郡みなかみ町', 'トネグンミナカミマチ', '師', 'モロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県利根郡みなかみ町政所', '10', '10449', '3791307', '群馬県', 'グンマケン', '利根郡みなかみ町', 'トネグンミナカミマチ', '政所', 'マンドコロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県利根郡みなかみ町真庭', '10', '10449', '3791308', '群馬県', 'グンマケン', '利根郡みなかみ町', 'トネグンミナカミマチ', '真庭', 'マニワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県利根郡みなかみ町石倉', '10', '10449', '3791311', '群馬県', 'グンマケン', '利根郡みなかみ町', 'トネグンミナカミマチ', '石倉', 'イシクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県利根郡みなかみ町小川', '10', '10449', '3791312', '群馬県', 'グンマケン', '利根郡みなかみ町', 'トネグンミナカミマチ', '小川', 'オガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県利根郡みなかみ町月夜野', '10', '10449', '3791313', '群馬県', 'グンマケン', '利根郡みなかみ町', 'トネグンミナカミマチ', '月夜野', 'ツキヨノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県利根郡みなかみ町下津', '10', '10449', '3791314', '群馬県', 'グンマケン', '利根郡みなかみ町', 'トネグンミナカミマチ', '下津', 'シモヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県利根郡みなかみ町上津', '10', '10449', '3791315', '群馬県', 'グンマケン', '利根郡みなかみ町', 'トネグンミナカミマチ', '上津', 'カミヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県利根郡みなかみ町永井', '10', '10449', '3791401', '群馬県', 'グンマケン', '利根郡みなかみ町', 'トネグンミナカミマチ', '永井', 'ナガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県利根郡みなかみ町吹路', '10', '10449', '3791402', '群馬県', 'グンマケン', '利根郡みなかみ町', 'トネグンミナカミマチ', '吹路', 'フクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県利根郡みなかみ町猿ケ京温泉', '10', '10449', '3791403', '群馬県', 'グンマケン', '利根郡みなかみ町', 'トネグンミナカミマチ', '猿ケ京温泉', 'サルガキョウオンセン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県利根郡みなかみ町相俣', '10', '10449', '3791404', '群馬県', 'グンマケン', '利根郡みなかみ町', 'トネグンミナカミマチ', '相俣', 'アイマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県利根郡みなかみ町湯宿温泉', '10', '10449', '3791409', '群馬県', 'グンマケン', '利根郡みなかみ町', 'トネグンミナカミマチ', '湯宿温泉', 'ユジュクオンセン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県利根郡みなかみ町新巻', '10', '10449', '3791411', '群馬県', 'グンマケン', '利根郡みなかみ町', 'トネグンミナカミマチ', '新巻', 'アラマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県利根郡みなかみ町羽場', '10', '10449', '3791412', '群馬県', 'グンマケン', '利根郡みなかみ町', 'トネグンミナカミマチ', '羽場', 'ハバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県利根郡みなかみ町師田', '10', '10449', '3791413', '群馬県', 'グンマケン', '利根郡みなかみ町', 'トネグンミナカミマチ', '師田', 'モロダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県利根郡みなかみ町布施', '10', '10449', '3791414', '群馬県', 'グンマケン', '利根郡みなかみ町', 'トネグンミナカミマチ', '布施', 'フセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県利根郡みなかみ町西峰須川', '10', '10449', '3791415', '群馬県', 'グンマケン', '利根郡みなかみ町', 'トネグンミナカミマチ', '西峰須川', 'ニシミネスカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県利根郡みなかみ町入須川', '10', '10449', '3791416', '群馬県', 'グンマケン', '利根郡みなかみ町', 'トネグンミナカミマチ', '入須川', 'イリスカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県利根郡みなかみ町東峰', '10', '10449', '3791417', '群馬県', 'グンマケン', '利根郡みなかみ町', 'トネグンミナカミマチ', '東峰', 'ヒガシミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県利根郡みなかみ町須川', '10', '10449', '3791418', '群馬県', 'グンマケン', '利根郡みなかみ町', 'トネグンミナカミマチ', '須川', 'スカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県利根郡みなかみ町吉本', '10', '10449', '3791601', '群馬県', 'グンマケン', '利根郡みなかみ町', 'トネグンミナカミマチ', '吉本', 'ヨシモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県利根郡みなかみ町鹿野沢', '10', '10449', '3791611', '群馬県', 'グンマケン', '利根郡みなかみ町', 'トネグンミナカミマチ', '鹿野沢', 'カノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県利根郡みなかみ町小日向', '10', '10449', '3791612', '群馬県', 'グンマケン', '利根郡みなかみ町', 'トネグンミナカミマチ', '小日向', 'オビナタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県利根郡みなかみ町高日向', '10', '10449', '3791613', '群馬県', 'グンマケン', '利根郡みなかみ町', 'トネグンミナカミマチ', '高日向', 'タカヒナタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県利根郡みなかみ町寺間', '10', '10449', '3791614', '群馬県', 'グンマケン', '利根郡みなかみ町', 'トネグンミナカミマチ', '寺間', 'テラマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県利根郡みなかみ町小仁田', '10', '10449', '3791615', '群馬県', 'グンマケン', '利根郡みなかみ町', 'トネグンミナカミマチ', '小仁田', 'コニタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県利根郡みなかみ町川上', '10', '10449', '3791616', '群馬県', 'グンマケン', '利根郡みなかみ町', 'トネグンミナカミマチ', '川上', 'カワカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県利根郡みなかみ町湯原', '10', '10449', '3791617', '群馬県', 'グンマケン', '利根郡みなかみ町', 'トネグンミナカミマチ', '湯原', 'ユバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県利根郡みなかみ町阿能川', '10', '10449', '3791618', '群馬県', 'グンマケン', '利根郡みなかみ町', 'トネグンミナカミマチ', '阿能川', 'アノウガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県利根郡みなかみ町谷川', '10', '10449', '3791619', '群馬県', 'グンマケン', '利根郡みなかみ町', 'トネグンミナカミマチ', '谷川', 'タニガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県利根郡みなかみ町藤原', '10', '10449', '3791721', '群馬県', 'グンマケン', '利根郡みなかみ町', 'トネグンミナカミマチ', '藤原', 'フジワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県利根郡みなかみ町夜後', '10', '10449', '3791722', '群馬県', 'グンマケン', '利根郡みなかみ町', 'トネグンミナカミマチ', '夜後', 'ヨゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県利根郡みなかみ町粟沢', '10', '10449', '3791723', '群馬県', 'グンマケン', '利根郡みなかみ町', 'トネグンミナカミマチ', '粟沢', 'アワザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県利根郡みなかみ町向山', '10', '10449', '3791724', '群馬県', 'グンマケン', '利根郡みなかみ町', 'トネグンミナカミマチ', '向山', 'ムコウヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県利根郡みなかみ町綱子', '10', '10449', '3791725', '群馬県', 'グンマケン', '利根郡みなかみ町', 'トネグンミナカミマチ', '綱子', 'ツナゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県利根郡みなかみ町幸知', '10', '10449', '3791726', '群馬県', 'グンマケン', '利根郡みなかみ町', 'トネグンミナカミマチ', '幸知', 'コウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県利根郡みなかみ町大穴', '10', '10449', '3791727', '群馬県', 'グンマケン', '利根郡みなかみ町', 'トネグンミナカミマチ', '大穴', 'オオアナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県利根郡みなかみ町湯桧曽', '10', '10449', '3791728', '群馬県', 'グンマケン', '利根郡みなかみ町', 'トネグンミナカミマチ', '湯桧曽', 'ユビソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市泉沢町', '10', '10201', '3792101', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '泉沢町', 'イズミサワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市下大屋町', '10', '10201', '3792102', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '下大屋町', 'シモオオヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市神沢の森', '10', '10201', '3792103', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '神沢の森', 'カンザワノモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市西大室町', '10', '10201', '3792104', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '西大室町', 'ニシオオムロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市東大室町', '10', '10201', '3792105', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '東大室町', 'ヒガシオオムロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市荒子町', '10', '10201', '3792106', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '荒子町', 'アラコマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市荒口町', '10', '10201', '3792107', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '荒口町', 'アラクチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市鶴が谷町', '10', '10201', '3792108', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '鶴が谷町', 'ツルガヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市飯土井町', '10', '10201', '3792111', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '飯土井町', 'イイドイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市新井町', '10', '10201', '3792112', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '新井町', 'アライマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市下増田町', '10', '10201', '3792113', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '下増田町', 'シモマスダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市上増田町', '10', '10201', '3792114', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '上増田町', 'カミマスダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('31999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市笂井町', '10', '10201', '3792115', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '笂井町', 'ウツボイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市今井町', '10', '10201', '3792116', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '今井町', 'イマイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市二之宮町', '10', '10201', '3792117', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '二之宮町', 'ニノミヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市小屋原町', '10', '10201', '3792121', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '小屋原町', 'コヤハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市駒形町', '10', '10201', '3792122', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '駒形町', 'コマガタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市山王町', '10', '10201', '3792123', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '山王町', 'サンノウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市西善町', '10', '10201', '3792131', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '西善町', 'ニシゼンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市東善町', '10', '10201', '3792132', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '東善町', 'ヒガシゼンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市中内町', '10', '10201', '3792133', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '中内町', 'ナカウチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市力丸町', '10', '10201', '3792134', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '力丸町', 'リキマルマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市徳丸町', '10', '10201', '3792135', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '徳丸町', 'トクマルマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市房丸町', '10', '10201', '3792136', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '房丸町', 'ボウマルマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市鶴光路町', '10', '10201', '3792141', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '鶴光路町', 'ツルコウジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市下阿内町', '10', '10201', '3792142', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '下阿内町', 'シモアウチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市新堀町', '10', '10201', '3792143', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '新堀町', 'ニイボリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市下川町', '10', '10201', '3792144', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '下川町', 'シモカワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市横手町', '10', '10201', '3792145', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '横手町', 'ヨコテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市公田町', '10', '10201', '3792146', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '公田町', 'クデンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市亀里町', '10', '10201', '3792147', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '亀里町', 'カメサトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市下長磯町', '10', '10201', '3792151', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '下長磯町', 'シモナガイソマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市下大島町', '10', '10201', '3792152', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '下大島町', 'シモオオシママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市上大島町', '10', '10201', '3792153', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '上大島町', 'カミオオシママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市天川大島町', '10', '10201', '3792154', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '天川大島町', 'アマガワオオシママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市富田町', '10', '10201', '3792161', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '富田町', 'トミダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市小島田町', '10', '10201', '3792162', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '小島田町', 'コジマタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市女屋町', '10', '10201', '3792163', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '女屋町', 'オナヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市東上野町', '10', '10201', '3792164', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '東上野町', 'ヒガシウエノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市上長磯町', '10', '10201', '3792165', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '上長磯町', 'カミナガイソマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県前橋市野中町', '10', '10201', '3792166', '群馬県', 'グンマケン', '前橋市', 'マエバシシ', '野中町', 'ノナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市間野谷町', '10', '10204', '3792201', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '間野谷町', 'アイノヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市赤堀鹿島町', '10', '10204', '3792202', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '赤堀鹿島町', 'アカボリカシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市曲沢町', '10', '10204', '3792203', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '曲沢町', 'マガリサワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市西久保町', '10', '10204', '3792204', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '西久保町', 'ニシクボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市野町', '10', '10204', '3792205', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '野町', 'ノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市香林町', '10', '10204', '3792206', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '香林町', 'コウバヤシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市市場町', '10', '10204', '3792211', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '市場町', 'イチバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市堀下町', '10', '10204', '3792212', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '堀下町', 'ホリシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市五目牛町', '10', '10204', '3792213', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '五目牛町', 'ゴメウシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市下触町', '10', '10204', '3792214', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '下触町', 'シモフレイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市赤堀今井町', '10', '10204', '3792215', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '赤堀今井町', 'アカボリイマイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市西野町', '10', '10204', '3792216', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '西野町', 'ニシノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市磯町', '10', '10204', '3792217', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '磯町', 'イソチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市国定町', '10', '10204', '3792221', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '国定町', 'クニサダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市田部井町', '10', '10204', '3792222', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '田部井町', 'タベイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市西小保方町', '10', '10204', '3792224', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '西小保方町', 'ニシオボカタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市上田町', '10', '10204', '3792225', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '上田町', 'カミダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市東町', '10', '10204', '3792231', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '東町', 'アズマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市小泉町', '10', '10204', '3792232', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '小泉町', 'コイズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市平井町', '10', '10204', '3792233', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '平井町', 'ヒライチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市東小保方町', '10', '10204', '3792234', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '東小保方町', 'ヒガシオボカタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市三室町', '10', '10204', '3792235', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '三室町', 'ミムロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県伊勢崎市八寸町', '10', '10204', '3792236', '群馬県', 'グンマケン', '伊勢崎市', 'イセサキシ', '八寸町', 'ハチスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市藪塚町', '10', '10205', '3792301', '群馬県', 'グンマケン', '太田市', 'オオタシ', '藪塚町', 'ヤブヅカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市山之神町', '10', '10205', '3792302', '群馬県', 'グンマケン', '太田市', 'オオタシ', '山之神町', 'ヤマノカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市寄合町', '10', '10205', '3792303', '群馬県', 'グンマケン', '太田市', 'オオタシ', '寄合町', 'ヨリアイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市大原町', '10', '10205', '3792304', '群馬県', 'グンマケン', '太田市', 'オオタシ', '大原町', 'オオバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市六千石町', '10', '10205', '3792305', '群馬県', 'グンマケン', '太田市', 'オオタシ', '六千石町', 'ロクセンゴクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県太田市大久保町', '10', '10205', '3792306', '群馬県', 'グンマケン', '太田市', 'オオタシ', '大久保町', 'オオクボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県みどり市笠懸町阿左美', '10', '10212', '3792311', '群馬県', 'グンマケン', 'みどり市', 'ミドリシ', '笠懸町阿左美', 'カサカケチョウアザミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県みどり市笠懸町久宮', '10', '10212', '3792312', '群馬県', 'グンマケン', 'みどり市', 'ミドリシ', '笠懸町久宮', 'カサカケチョウクグウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県みどり市笠懸町鹿', '10', '10212', '3792313', '群馬県', 'グンマケン', 'みどり市', 'ミドリシ', '笠懸町鹿', 'カサカケチョウシカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県みどり市笠懸町西鹿田', '10', '10212', '3792314', '群馬県', 'グンマケン', 'みどり市', 'ミドリシ', '笠懸町西鹿田', 'カサカケチョウサイシカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市', '02', '02201', '0380000', '青森県', 'アオモリケン', '青森市', 'アオモリシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('32079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市新田', '02', '02201', '0380001', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '新田', 'ニッタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市沖館', '02', '02201', '0380002', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '沖館', 'オキダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市石江', '02', '02201', '0380003', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '石江', 'イシエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市富田', '02', '02201', '0380004', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '富田', 'トミタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市三好', '02', '02201', '0380006', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '三好', 'ミヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市篠田', '02', '02201', '0380011', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '篠田', 'シノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市柳川', '02', '02201', '0380012', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '柳川', 'ヤナカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市久須志', '02', '02201', '0380013', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '久須志', 'クスシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市西滝', '02', '02201', '0380014', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '西滝', 'ニシタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市千刈', '02', '02201', '0380015', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '千刈', 'センガリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市安田', '02', '02201', '0380021', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '安田', 'ヤスタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市浪館', '02', '02201', '0380022', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '浪館', 'ナミダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市細越', '02', '02201', '0380023', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '細越', 'ホソゴエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市浪館前田', '02', '02201', '0380024', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '浪館前田', 'ナミダテマエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市三内', '02', '02201', '0380031', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '三内', 'サンナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市里見', '02', '02201', '0380032', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '里見', 'サトミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市岡町', '02', '02201', '0380041', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '岡町', 'オカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市新城', '02', '02201', '0380042', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '新城', 'シンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市岩渡', '02', '02201', '0380043', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '岩渡', 'イワタリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市孫内', '02', '02201', '0380044', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '孫内', 'マゴナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市鶴ケ坂', '02', '02201', '0380045', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '鶴ケ坂', 'ツルガサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市戸門', '02', '02201', '0380046', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '戸門', 'トカド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市内真部', '02', '02201', '0380051', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '内真部', 'ウチマンペ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市清水', '02', '02201', '0380052', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '清水', 'シミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市前田', '02', '02201', '0380053', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '前田', 'マエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市奥内', '02', '02201', '0380054', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '奥内', 'オクナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市瀬戸子', '02', '02201', '0380055', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '瀬戸子', 'セトシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市飛鳥', '02', '02201', '0380056', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '飛鳥', 'アスカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市西田沢', '02', '02201', '0380057', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '西田沢', 'ニシタザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市羽白', '02', '02201', '0380058', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '羽白', 'ハジロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市油川', '02', '02201', '0380059', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '油川', 'アブラカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市箱清水', '20', '20201', '3800801', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '箱清水', 'ハコシミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市上松', '20', '20201', '3800802', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '上松', 'ウエマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市三輪', '20', '20201', '3800803', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '三輪', 'ミワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市荒屋', '20', '20201', '3800804', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '荒屋', 'アラヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市柳町', '20', '20201', '3800805', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '柳町', 'ヤナギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市淀ケ橋', '20', '20201', '3800806', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '淀ケ橋', 'ヨドガバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市横山', '20', '20201', '3800807', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '横山', 'ヨコヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市鶴賀東鶴賀町', '20', '20201', '3800811', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '鶴賀', 'ツルガ', null, null, '東鶴賀町', 'ヒガシツルガマチ');
INSERT INTO `ms_addresses` VALUES ('32118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市東鶴賀町', '20', '20201', '3800811', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '東鶴賀町', 'ヒガシツルガマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市早苗町', '20', '20201', '3800812', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '早苗町', 'サナエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市鶴賀早苗町', '20', '20201', '3800812', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '鶴賀', 'ツルガ', null, null, '早苗町', 'サナエチョウ');
INSERT INTO `ms_addresses` VALUES ('32121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市鶴賀緑町', '20', '20201', '3800813', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '鶴賀', 'ツルガ', null, null, '緑町', 'ミドリチョウ');
INSERT INTO `ms_addresses` VALUES ('32122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市緑町', '20', '20201', '3800813', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '緑町', 'ミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市鶴賀西鶴賀町', '20', '20201', '3800814', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '鶴賀', 'ツルガ', null, null, '西鶴賀町', 'ニシツルガマチ');
INSERT INTO `ms_addresses` VALUES ('32124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市西鶴賀町', '20', '20201', '3800814', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '西鶴賀町', 'ニシツルガマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市田町', '20', '20201', '3800815', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '田町', 'タマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市鶴賀田町', '20', '20201', '3800815', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '鶴賀', 'ツルガ', null, null, '田町', 'タマチ');
INSERT INTO `ms_addresses` VALUES ('32127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市三輪田町', '20', '20201', '3800816', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '三輪田町', 'ミワタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市上千歳町', '20', '20201', '3800821', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '上千歳町', 'カミチトセマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市鶴賀上千歳町', '20', '20201', '3800821', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '鶴賀', 'ツルガ', null, null, '上千歳町', 'カミチトセマチ');
INSERT INTO `ms_addresses` VALUES ('32130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市鶴賀南千歳町', '20', '20201', '3800822', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '鶴賀', 'ツルガ', null, null, '南千歳町', 'ミナミチトセマチ');
INSERT INTO `ms_addresses` VALUES ('32131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市南千歳町', '20', '20201', '3800822', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '南千歳町', 'ミナミチトセマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市南千歳', '20', '20201', '3800823', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '南千歳', 'ミナミチトセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市南石堂町', '20', '20201', '3800824', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '南石堂町', 'ミナミイシドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市末広町', '20', '20201', '3800825', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '末広町', 'スエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市北石堂町', '20', '20201', '3800826', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '北石堂町', 'キタイシドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市東町', '20', '20201', '3800831', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '東町', 'ヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市東後町', '20', '20201', '3800832', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '東後町', 'ヒガシゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市権堂町', '20', '20201', '3800833', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '権堂町', 'ゴンドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市鶴賀権堂町', '20', '20201', '3800833', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '鶴賀', 'ツルガ', null, null, '権堂町', 'ゴンドウチョウ');
INSERT INTO `ms_addresses` VALUES ('32140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市鶴賀問御所町', '20', '20201', '3800834', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '鶴賀', 'ツルガ', null, null, '問御所町', 'トイゴショマチ');
INSERT INTO `ms_addresses` VALUES ('32141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市問御所町', '20', '20201', '3800834', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '問御所町', 'トイゴショマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市新田町', '20', '20201', '3800835', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '新田町', 'シンデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市南県町', '20', '20201', '3800836', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '南県町', 'ミナミアガタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市南長野幅下', '20', '20201', '3800837', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '南長野', 'ミナミナガノ', null, null, '幅下', 'ハバシタ');
INSERT INTO `ms_addresses` VALUES ('32145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市県町', '20', '20201', '3800838', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '県町', 'アガタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市大門町', '20', '20201', '3800841', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '大門町', 'ダイモンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市西町', '20', '20201', '3800842', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '西町', 'ニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市長門町', '20', '20201', '3800843', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '長門町', 'ナガトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市諏訪町', '20', '20201', '3800844', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '諏訪町', 'スワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市西後町', '20', '20201', '3800845', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '西後町', 'ニシゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市旭町', '20', '20201', '3800846', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '旭町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市若松町', '20', '20201', '3800847', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '若松町', 'ワカマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市元善町', '20', '20201', '3800851', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '元善町', 'モトヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市東之門町', '20', '20201', '3800852', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '東之門町', 'ヒガシノモンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市新町', '20', '20201', '3800853', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市伊勢町', '20', '20201', '3800854', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '伊勢町', 'イセマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市岩石町', '20', '20201', '3800855', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '岩石町', 'ガンゼキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市横町', '20', '20201', '3800856', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '横町', 'ヨコマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市西之門町', '20', '20201', '3800857', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '西之門町', 'ニシノモンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市上西之門町', '20', '20201', '3800858', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '上西之門町', 'カミニシノモンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市横沢町', '20', '20201', '3800861', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '横沢町', 'ヨコサワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市桜枝町', '20', '20201', '3800862', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '桜枝町', 'サクラエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市栄町', '20', '20201', '3800863', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '栄町', 'サカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市立町', '20', '20201', '3800864', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '立町', 'タツマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市花咲町', '20', '20201', '3800865', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '花咲町', 'ハナサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市狐池', '20', '20201', '3800866', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '狐池', 'キツネイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市往生地', '20', '20201', '3800867', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '往生地', 'オウショウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市西長野町', '20', '20201', '3800871', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '西長野町', 'ニシナガノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市妻科', '20', '20201', '3800872', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '妻科', 'ツマシナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市新諏訪町', '20', '20201', '3800873', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '新諏訪町', 'シンズワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市茂菅', '20', '20201', '3800874', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '茂菅', 'モスゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市小鍋', '20', '20201', '3800875', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '小鍋', 'コナベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市山田中', '20', '20201', '3800876', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '山田中', 'ヤマダナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市塩生', '20', '20201', '3800877', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '塩生', 'ショウブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市門沢', '20', '20201', '3800881', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '門沢', 'カドサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市富田', '20', '20201', '3800882', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '富田', 'トミダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市泉平', '20', '20201', '3800883', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '泉平', 'イズミダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市鑪', '20', '20201', '3800884', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '鑪', 'タタラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市桜', '20', '20201', '3800885', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '桜', 'サクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市広瀬', '20', '20201', '3800886', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '広瀬', 'ヒロセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市入山', '20', '20201', '3800887', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '入山', 'イリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市上ケ屋', '20', '20201', '3800888', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '上ケ屋', 'アゲヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市居町', '20', '20201', '3800901', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '居町', 'イマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市鶴賀居町', '20', '20201', '3800901', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '鶴賀', 'ツルガ', null, null, '居町', 'イマチ');
INSERT INTO `ms_addresses` VALUES ('32185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市鶴賀中堰', '20', '20201', '3800902', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '鶴賀', 'ツルガ', null, null, '中堰', 'ナカゼキ');
INSERT INTO `ms_addresses` VALUES ('32186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市鶴賀峰村', '20', '20201', '3800903', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '鶴賀', 'ツルガ', null, null, '峰村', 'ミネムラ');
INSERT INTO `ms_addresses` VALUES ('32187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市鶴賀七瀬中町', '20', '20201', '3800904', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '鶴賀', 'ツルガ', null, null, '七瀬中町', 'ナナセナカマチ');
INSERT INTO `ms_addresses` VALUES ('32188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市七瀬中町', '20', '20201', '3800904', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '七瀬中町', 'ナナセナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市鶴賀七瀬南部', '20', '20201', '3800905', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '鶴賀', 'ツルガ', null, null, '七瀬南部', 'ナナセナンブ');
INSERT INTO `ms_addresses` VALUES ('32190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市七瀬南部', '20', '20201', '3800905', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '七瀬南部', 'ナナセナンブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市鶴賀七瀬', '20', '20201', '3800906', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '鶴賀', 'ツルガ', null, null, '七瀬', 'ナナセ');
INSERT INTO `ms_addresses` VALUES ('32192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市七瀬', '20', '20201', '3800906', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '七瀬', 'ナナセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市稲葉', '20', '20201', '3800911', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '稲葉', 'イナバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市稲葉日詰', '20', '20201', '3800912', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '稲葉日詰', 'イナバヒヅメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市川合新田', '20', '20201', '3800913', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '川合新田', 'カワイシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市稲葉母袋', '20', '20201', '3800914', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '稲葉母袋', 'イナバモタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市稲葉上千田', '20', '20201', '3800915', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '稲葉上千田', 'イナバカミセンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市稲葉中千田', '20', '20201', '3800916', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '稲葉中千田', 'イナバナカセンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市稲葉南俣', '20', '20201', '3800917', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '稲葉南俣', 'イナバミナミマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市アークス', '20', '20201', '3800918', '長野県', 'ナガノケン', '長野市', 'ナガノシ', 'アークス', 'アークス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市栗田', '20', '20201', '3800921', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '栗田', 'クリタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市栗田北中', '20', '20201', '3800927', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '栗田北中', 'クリタキタナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市若里', '20', '20201', '3800928', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '若里', 'ワカサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市中御所町', '20', '20201', '3800934', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '中御所町', 'ナカゴショマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市中御所', '20', '20201', '3800935', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '中御所', 'ナカゴショ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市岡田町', '20', '20201', '3800936', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '岡田町', 'オカダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市安茂里', '20', '20201', '3800941', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '安茂里', 'アモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市小柴見', '20', '20201', '3800942', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '小柴見', 'コシバミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市安茂里差出', '20', '20201', '3800943', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '安茂里差出', 'アモリサシデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市安茂里米村', '20', '20201', '3800944', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '安茂里米村', 'アモリコメムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市安茂里杏花台', '20', '20201', '3800945', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '安茂里杏花台', 'アモリキョウカダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市平柴台', '20', '20201', '3800946', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '平柴台', 'ヒラシバダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市平柴', '20', '20201', '3800947', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '平柴', 'ヒラシバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市差出南', '20', '20201', '3800948', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '差出南', 'サシデミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市宮沖', '20', '20201', '3800952', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '宮沖', 'ミヤオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市安茂里犀北', '20', '20201', '3800953', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '安茂里犀北', 'アモリサイホク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市安茂里犀北団地', '20', '20201', '3800954', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '安茂里犀北団地', 'アモリサイホクダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市安茂里西河原', '20', '20201', '3800955', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '安茂里西河原', 'アモリニシガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市安茂里小路', '20', '20201', '3800956', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '安茂里小路', 'アモリコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市安茂里大門', '20', '20201', '3800957', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '安茂里大門', 'アモリダイモン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市伊勢宮', '20', '20201', '3800958', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '伊勢宮', 'イセミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市安茂里小市', '20', '20201', '3800961', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '安茂里小市', 'アモリコイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市碇ケ関', '02', '02210', '0380101', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '碇ケ関', 'イカリガセキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市碇ケ関相沢', '02', '02210', '0380101', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '碇ケ関相沢', 'イカリガセキアイザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市碇ケ関阿原', '02', '02210', '0380101', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '碇ケ関阿原', 'イカリガセキアバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市碇ケ関雷林', '02', '02210', '0380101', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '碇ケ関雷林', 'イカリガセキイカズチバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市碇ケ関碇石', '02', '02210', '0380101', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '碇ケ関碇石', 'イカリガセキイカリイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市碇ケ関岩井', '02', '02210', '0380101', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '碇ケ関岩井', 'イカリガセキイワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市碇ケ関大葉平', '02', '02210', '0380101', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '碇ケ関大葉平', 'イカリガセキオオバダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市碇ケ関大落前', '02', '02210', '0380101', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '碇ケ関大落前', 'イカリガセキオオラクマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市碇ケ関折橋', '02', '02210', '0380101', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '碇ケ関折橋', 'イカリガセキオリハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市碇ケ関鯨森', '02', '02210', '0380101', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '碇ケ関鯨森', 'イカリガセキクジラモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市碇ケ関小落前', '02', '02210', '0380101', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '碇ケ関小落前', 'イカリガセキコラクマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市碇ケ関山神堂', '02', '02210', '0380101', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '碇ケ関山神堂', 'イカリガセキサンジンドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市碇ケ関白沢', '02', '02210', '0380101', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '碇ケ関白沢', 'イカリガセキシラサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市碇ケ関諏訪平', '02', '02210', '0380101', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '碇ケ関諏訪平', 'イカリガセキスワダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市碇ケ関外白沢', '02', '02210', '0380101', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '碇ケ関外白沢', 'イカリガセキソトシラサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市碇ケ関高田', '02', '02210', '0380101', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '碇ケ関高田', 'イカリガセキタカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市碇ケ関樋ケ沢', '02', '02210', '0380101', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '碇ケ関樋ケ沢', 'イカリガセキトイガサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市碇ケ関西碇ケ関山', '02', '02210', '0380101', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '碇ケ関西碇ケ関山', 'イカリガセキニシイカリガセキヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市碇ケ関東碇ケ関山', '02', '02210', '0380101', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '碇ケ関東碇ケ関山', 'イカリガセキヒガシイカリガセキヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市碇ケ関樋ノ口', '02', '02210', '0380101', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '碇ケ関樋ノ口', 'イカリガセキヒノクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市碇ケ関船岡', '02', '02210', '0380101', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '碇ケ関船岡', 'イカリガセキフナオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市碇ケ関踏田切', '02', '02210', '0380101', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '碇ケ関踏田切', 'イカリガセキフミタギリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市碇ケ関三笠山', '02', '02210', '0380101', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '碇ケ関三笠山', 'イカリガセキミカサヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市碇ケ関水溜', '02', '02210', '0380101', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '碇ケ関水溜', 'イカリガセキミズタメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市碇ケ関湯向川添', '02', '02210', '0380101', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '碇ケ関湯向川添', 'イカリガセキユムカイカワゾエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市碇ケ関横町', '02', '02210', '0380101', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '碇ケ関横町', 'イカリガセキヨコマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市碇ケ関古懸上程森', '02', '02210', '0380102', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '碇ケ関古懸上程森', 'イカリガセキコガケカミホドモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市碇ケ関古懸沢田', '02', '02210', '0380102', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '碇ケ関古懸沢田', 'イカリガセキコガケサワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市碇ケ関古懸樋ケ沢', '02', '02210', '0380102', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '碇ケ関古懸樋ケ沢', 'イカリガセキコガケトイガサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市碇ケ関古懸堂ノ上', '02', '02210', '0380102', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '碇ケ関古懸堂ノ上', 'イカリガセキコガケドウノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市碇ケ関古懸鳥井', '02', '02210', '0380102', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '碇ケ関古懸鳥井', 'イカリガセキコガケトリイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市碇ケ関古懸西不動野', '02', '02210', '0380102', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '碇ケ関古懸西不動野', 'イカリガセキコガケニシフドウノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市碇ケ関古懸東不動野', '02', '02210', '0380102', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '碇ケ関古懸東不動野', 'イカリガセキコガケヒガシフドウノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市碇ケ関古懸不動沢大石', '02', '02210', '0380102', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '碇ケ関古懸不動沢大石', 'イカリガセキコガケフドウサワオオイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市碇ケ関古懸不動野', '02', '02210', '0380102', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '碇ケ関古懸不動野', 'イカリガセキコガケフドウノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市碇ケ関古懸南不動野', '02', '02210', '0380102', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '碇ケ関古懸南不動野', 'イカリガセキコガケミナミフドウノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市碇ケ関古懸向安田', '02', '02210', '0380102', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '碇ケ関古懸向安田', 'イカリガセキコガケムカイヤスダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市碇ケ関古懸門前', '02', '02210', '0380102', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '碇ケ関古懸門前', 'イカリガセキコガケモンゼン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市碇ケ関古懸門前屋岸', '02', '02210', '0380102', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '碇ケ関古懸門前屋岸', 'イカリガセキコガケモンゼンヤギシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市碇ケ関古懸安田', '02', '02210', '0380102', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '碇ケ関古懸安田', 'イカリガセキコガケヤスタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市碇ケ関久吉蕷ケ平', '02', '02210', '0380103', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '碇ケ関久吉蕷ケ平', 'イカリガセキヒサヨシイモガタイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市碇ケ関久吉二ノ渡', '02', '02210', '0380103', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '碇ケ関久吉二ノ渡', 'イカリガセキヒサヨシニノワタリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県平川市碇ケ関久吉山岸', '02', '02210', '0380103', '青森県', 'アオモリケン', '平川市', 'ヒラカワシ', '碇ケ関久吉山岸', 'イカリガセキヒサヨシヤマギシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県南津軽郡大鰐町', '02', '02362', '0380200', '青森県', 'アオモリケン', '南津軽郡大鰐町', 'ミナミツガルグンオオワニマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('32269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県南津軽郡大鰐町苦木', '02', '02362', '0380201', '青森県', 'アオモリケン', '南津軽郡大鰐町', 'ミナミツガルグンオオワニマチ', '苦木', 'ニガキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県南津軽郡大鰐町長峰', '02', '02362', '0380202', '青森県', 'アオモリケン', '南津軽郡大鰐町', 'ミナミツガルグンオオワニマチ', '長峰', 'ナガミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県南津軽郡大鰐町駒木', '02', '02362', '0380203', '青森県', 'アオモリケン', '南津軽郡大鰐町', 'ミナミツガルグンオオワニマチ', '駒木', 'コマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県南津軽郡大鰐町唐牛', '02', '02362', '0380204', '青森県', 'アオモリケン', '南津軽郡大鰐町', 'ミナミツガルグンオオワニマチ', '唐牛', 'カロウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県南津軽郡大鰐町大鰐', '02', '02362', '0380211', '青森県', 'アオモリケン', '南津軽郡大鰐町', 'ミナミツガルグンオオワニマチ', '大鰐', 'オオワニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県南津軽郡大鰐町蔵館', '02', '02362', '0380212', '青森県', 'アオモリケン', '南津軽郡大鰐町', 'ミナミツガルグンオオワニマチ', '蔵館', 'クラダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県南津軽郡大鰐町虹貝', '02', '02362', '0380221', '青森県', 'アオモリケン', '南津軽郡大鰐町', 'ミナミツガルグンオオワニマチ', '虹貝', 'ニジカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県南津軽郡大鰐町早瀬野', '02', '02362', '0380222', '青森県', 'アオモリケン', '南津軽郡大鰐町', 'ミナミツガルグンオオワニマチ', '早瀬野', 'ハヤセノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県南津軽郡大鰐町島田', '02', '02362', '0380223', '青森県', 'アオモリケン', '南津軽郡大鰐町', 'ミナミツガルグンオオワニマチ', '島田', 'シマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県南津軽郡大鰐町宿川原', '02', '02362', '0380231', '青森県', 'アオモリケン', '南津軽郡大鰐町', 'ミナミツガルグンオオワニマチ', '宿川原', 'シュクガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県南津軽郡大鰐町三ツ目内', '02', '02362', '0380232', '青森県', 'アオモリケン', '南津軽郡大鰐町', 'ミナミツガルグンオオワニマチ', '三ツ目内', 'ミツメナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県南津軽郡大鰐町居土', '02', '02362', '0380233', '青森県', 'アオモリケン', '南津軽郡大鰐町', 'ミナミツガルグンオオワニマチ', '居土', 'イヅチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県南津軽郡大鰐町鯖石', '02', '02362', '0380241', '青森県', 'アオモリケン', '南津軽郡大鰐町', 'ミナミツガルグンオオワニマチ', '鯖石', 'サバイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県南津軽郡大鰐町森山', '02', '02362', '0380242', '青森県', 'アオモリケン', '南津軽郡大鰐町', 'ミナミツガルグンオオワニマチ', '森山', 'モリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県南津軽郡大鰐町八幡館', '02', '02362', '0380243', '青森県', 'アオモリケン', '南津軽郡大鰐町', 'ミナミツガルグンオオワニマチ', '八幡館', 'ハチマンダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市', '20', '20201', '3810000', '長野県', 'ナガノケン', '長野市', 'ナガノシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('32372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市赤沼', '20', '20201', '3810001', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '赤沼', 'アカヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市津野', '20', '20201', '3810002', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '津野', 'ツノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市穂保', '20', '20201', '3810003', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '穂保', 'ホヤス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市大町', '20', '20201', '3810004', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '大町', 'オオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市北堀', '20', '20201', '3810005', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '北堀', 'キタホリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市富竹', '20', '20201', '3810006', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '富竹', 'トミタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市金箱', '20', '20201', '3810007', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '金箱', 'カネバコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市下駒沢', '20', '20201', '3810008', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '下駒沢', 'シモコマザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市村山', '20', '20201', '3810011', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '村山', 'ムラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市柳原', '20', '20201', '3810012', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '柳原', 'ヤナギハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市桜新町', '20', '20201', '3810013', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '桜新町', 'サクラシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市北尾張部', '20', '20201', '3810014', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '北尾張部', 'キタオワリベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市石渡', '20', '20201', '3810015', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '石渡', 'イシワタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市南堀', '20', '20201', '3810016', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '南堀', 'ミナミホリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市小島', '20', '20201', '3810017', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '小島', 'コジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市屋島', '20', '20201', '3810021', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '屋島', 'ヤシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市大豆島', '20', '20201', '3810022', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '大豆島', 'マメジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市風間', '20', '20201', '3810023', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '風間', 'カザマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市南長池', '20', '20201', '3810024', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '南長池', 'ミナミナガイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市北長池', '20', '20201', '3810025', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '北長池', 'キタナガイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市松岡', '20', '20201', '3810026', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '松岡', 'マツオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市西尾張部', '20', '20201', '3810031', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '西尾張部', 'ニシオワリベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市若宮', '20', '20201', '3810032', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '若宮', 'ワカミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市南高田', '20', '20201', '3810033', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '南高田', 'ミナミタカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市高田', '20', '20201', '3810034', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '高田', 'タカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市北条町', '20', '20201', '3810035', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '北条町', 'キタジョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市平林', '20', '20201', '3810036', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '平林', 'ヒラバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市西和田', '20', '20201', '3810037', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '西和田', 'ニシワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市東和田', '20', '20201', '3810038', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '東和田', 'ヒガシワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市徳間', '20', '20201', '3810041', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '徳間', 'トクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市稲田', '20', '20201', '3810042', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '稲田', 'イナダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市吉田', '20', '20201', '3810043', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '吉田', 'ヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市中越', '20', '20201', '3810044', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '中越', 'ナカゴエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市桐原', '20', '20201', '3810045', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '桐原', 'キリハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市若槻団地', '20', '20201', '3810051', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '若槻団地', 'ワカツキダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市檀田', '20', '20201', '3810052', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '檀田', 'マユミダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市神楽橋', '20', '20201', '3810053', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '神楽橋', 'カグラバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市浅川', '20', '20201', '3810054', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '浅川', 'アサカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市屋敷田', '20', '20201', '3810055', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '屋敷田', 'ヤシキダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市浅川押田', '20', '20201', '3810056', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '浅川押田', 'アサカワオシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市浅川西条', '20', '20201', '3810057', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '浅川西条', 'アサカワニシジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市坂中', '20', '20201', '3810061', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '坂中', 'サカナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市浅川福岡', '20', '20201', '3810062', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '浅川福岡', 'アサカワフクオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市伺去', '20', '20201', '3810063', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '伺去', 'シャリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市浅川東条', '20', '20201', '3810064', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '浅川東条', 'アサカワヒガシジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市真光寺', '20', '20201', '3810065', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '真光寺', 'シンコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市浅川西平', '20', '20201', '3810066', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '浅川西平', 'アサカワニシヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市台ケ窪', '20', '20201', '3810071', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '台ケ窪', 'ダイガクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市浅川清水', '20', '20201', '3810072', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '浅川清水', 'アサカワキヨミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市浅川畑山', '20', '20201', '3810073', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '浅川畑山', 'アサカワハタヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市中曽根', '20', '20201', '3810074', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '中曽根', 'ナカゾネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市北郷', '20', '20201', '3810075', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '北郷', 'キタゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市三ツ出', '20', '20201', '3810076', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '三ツ出', 'ミツデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市三才', '20', '20201', '3810081', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '三才', 'サンサイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市上駒沢', '20', '20201', '3810082', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '上駒沢', 'カミコマザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市西三才', '20', '20201', '3810083', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '西三才', 'ニシサンサイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市若槻東条', '20', '20201', '3810084', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '若槻東条', 'ワカツキヒガシジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市上野', '20', '20201', '3810085', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '上野', 'ウワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市田中', '20', '20201', '3810086', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '田中', 'タナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市田子', '20', '20201', '3810087', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '田子', 'タコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市吉', '20', '20201', '3810088', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '吉', 'ヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市若槻西条', '20', '20201', '3810089', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '若槻西条', 'ワカツキニシジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市若穂綿内', '20', '20201', '3810101', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '若穂綿内', 'ワカホワタウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市若穂保科', '20', '20201', '3810102', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '若穂保科', 'ワカホホシナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市若穂川田', '20', '20201', '3810103', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '若穂川田', 'ワカホカワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市若穂牛島', '20', '20201', '3810104', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '若穂牛島', 'ワカホウシジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上高井郡小布施町', '20', '20541', '3810200', '長野県', 'ナガノケン', '上高井郡小布施町', 'カミタカイグンオブセマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('32441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上高井郡小布施町小布施', '20', '20541', '3810201', '長野県', 'ナガノケン', '上高井郡小布施町', 'カミタカイグンオブセマチ', '小布施', 'オブセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上高井郡小布施町福原', '20', '20541', '3810202', '長野県', 'ナガノケン', '上高井郡小布施町', 'カミタカイグンオブセマチ', '福原', 'フクハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上高井郡小布施町大島', '20', '20541', '3810203', '長野県', 'ナガノケン', '上高井郡小布施町', 'カミタカイグンオブセマチ', '大島', 'オオジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上高井郡小布施町飯田', '20', '20541', '3810204', '長野県', 'ナガノケン', '上高井郡小布施町', 'カミタカイグンオブセマチ', '飯田', 'イイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上高井郡小布施町山王島', '20', '20541', '3810205', '長野県', 'ナガノケン', '上高井郡小布施町', 'カミタカイグンオブセマチ', '山王島', 'サンノウジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上高井郡小布施町北岡', '20', '20541', '3810206', '長野県', 'ナガノケン', '上高井郡小布施町', 'カミタカイグンオブセマチ', '北岡', 'キタオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上高井郡小布施町押羽', '20', '20541', '3810207', '長野県', 'ナガノケン', '上高井郡小布施町', 'カミタカイグンオブセマチ', '押羽', 'オシハ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上高井郡小布施町都住', '20', '20541', '3810208', '長野県', 'ナガノケン', '上高井郡小布施町', 'カミタカイグンオブセマチ', '都住', 'ツスミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上高井郡小布施町中松', '20', '20541', '3810209', '長野県', 'ナガノケン', '上高井郡小布施町', 'カミタカイグンオブセマチ', '中松', 'ナカマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上高井郡小布施町雁田', '20', '20541', '3810211', '長野県', 'ナガノケン', '上高井郡小布施町', 'カミタカイグンオブセマチ', '雁田', 'カリダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上高井郡小布施町吉島', '20', '20541', '3810212', '長野県', 'ナガノケン', '上高井郡小布施町', 'カミタカイグンオブセマチ', '吉島', 'ヨシジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県下高井郡山ノ内町', '20', '20561', '3810400', '長野県', 'ナガノケン', '下高井郡山ノ内町', 'シモタカイグンヤマノウチマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('32458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県下高井郡山ノ内町平穏', '20', '20561', '3810401', '長野県', 'ナガノケン', '下高井郡山ノ内町', 'シモタカイグンヤマノウチマチ', '平穏', 'ヒラオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県下高井郡山ノ内町佐野', '20', '20561', '3810402', '長野県', 'ナガノケン', '下高井郡山ノ内町', 'シモタカイグンヤマノウチマチ', '佐野', 'サノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県下高井郡山ノ内町寒沢', '20', '20561', '3810403', '長野県', 'ナガノケン', '下高井郡山ノ内町', 'シモタカイグンヤマノウチマチ', '寒沢', 'サムサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県下高井郡山ノ内町戸狩', '20', '20561', '3810404', '長野県', 'ナガノケン', '下高井郡山ノ内町', 'シモタカイグンヤマノウチマチ', '戸狩', 'トガリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県下高井郡山ノ内町夜間瀬', '20', '20561', '3810405', '長野県', 'ナガノケン', '下高井郡山ノ内町', 'シモタカイグンヤマノウチマチ', '夜間瀬', 'ヨマセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県南津軽郡田舎館村', '02', '02367', '0381100', '青森県', 'アオモリケン', '南津軽郡田舎館村', 'ミナミツガルグンイナカダテムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('32466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県南津軽郡田舎館村東光寺', '02', '02367', '0381101', '青森県', 'アオモリケン', '南津軽郡田舎館村', 'ミナミツガルグンイナカダテムラ', '東光寺', 'トウコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県南津軽郡田舎館村堂野前', '02', '02367', '0381102', '青森県', 'アオモリケン', '南津軽郡田舎館村', 'ミナミツガルグンイナカダテムラ', '堂野前', 'ドウノマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県南津軽郡田舎館村十二川原', '02', '02367', '0381103', '青森県', 'アオモリケン', '南津軽郡田舎館村', 'ミナミツガルグンイナカダテムラ', '十二川原', 'ジュウニカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県南津軽郡田舎館村枝川', '02', '02367', '0381104', '青森県', 'アオモリケン', '南津軽郡田舎館村', 'ミナミツガルグンイナカダテムラ', '枝川', 'エダガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県南津軽郡田舎館村高樋', '02', '02367', '0381111', '青森県', 'アオモリケン', '南津軽郡田舎館村', 'ミナミツガルグンイナカダテムラ', '高樋', 'タカヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県南津軽郡田舎館村垂柳', '02', '02367', '0381112', '青森県', 'アオモリケン', '南津軽郡田舎館村', 'ミナミツガルグンイナカダテムラ', '垂柳', 'タレヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県南津軽郡田舎館村田舎舘', '02', '02367', '0381113', '青森県', 'アオモリケン', '南津軽郡田舎館村', 'ミナミツガルグンイナカダテムラ', '田舎舘', 'イナカダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県南津軽郡田舎館村畑中', '02', '02367', '0381121', '青森県', 'アオモリケン', '南津軽郡田舎館村', 'ミナミツガルグンイナカダテムラ', '畑中', 'ハタケナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市松代町大室', '20', '20201', '3811211', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '松代町大室', 'マツシロマチオオムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市松代町牧島', '20', '20201', '3811212', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '松代町牧島', 'マツシロマチマキシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市松代町小島田', '20', '20201', '3811213', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '松代町小島田', 'マツシロマチオシマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市松代町柴', '20', '20201', '3811214', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '松代町柴', 'マツシロマチシバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市松代町西寺尾', '20', '20201', '3811215', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '松代町西寺尾', 'マツシロマチニシテラオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県南津軽郡田舎館村八反田', '02', '02367', '0381122', '青森県', 'アオモリケン', '南津軽郡田舎館村', 'ミナミツガルグンイナカダテムラ', '八反田', 'ハッタンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市松代町東条', '20', '20201', '3811221', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '松代町東条', 'マツシロマチヒガシジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市松代町豊栄', '20', '20201', '3811222', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '松代町豊栄', 'マツシロマチトヨサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市皆神台', '20', '20201', '3811223', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '皆神台', 'ミナカミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市松代町城東', '20', '20201', '3811224', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '松代町城東', 'マツシロマチジョウトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市松代町東寺尾', '20', '20201', '3811225', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '松代町東寺尾', 'マツシロマチヒガシテラオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市松代温泉', '20', '20201', '3811226', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '松代温泉', 'マツシロオンセン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県南津軽郡田舎館村大曲', '02', '02367', '0381123', '青森県', 'アオモリケン', '南津軽郡田舎館村', 'ミナミツガルグンイナカダテムラ', '大曲', 'オオマガリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市松代町松代', '20', '20201', '3811231', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '松代町松代', 'マツシロマチマツシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市松代町西条', '20', '20201', '3811232', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '松代町西条', 'マツシロマチニシジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市松代町清野', '20', '20201', '3811233', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '松代町清野', 'マツシロマチキヨノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市松代町岩野', '20', '20201', '3811234', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '松代町岩野', 'マツシロマチイワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市松代町城北', '20', '20201', '3811235', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '松代町城北', 'マツシロマチジョウホク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県南津軽郡田舎館村大袋', '02', '02367', '0381131', '青森県', 'アオモリケン', '南津軽郡田舎館村', 'ミナミツガルグンイナカダテムラ', '大袋', 'オオフクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県南津軽郡田舎館村諏訪堂', '02', '02367', '0381132', '青森県', 'アオモリケン', '南津軽郡田舎館村', 'ミナミツガルグンイナカダテムラ', '諏訪堂', 'スワドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県南津軽郡田舎館村大根子', '02', '02367', '0381133', '青森県', 'アオモリケン', '南津軽郡田舎館村', 'ミナミツガルグンイナカダテムラ', '大根子', 'オオネコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県南津軽郡田舎館村豊蒔', '02', '02367', '0381134', '青森県', 'アオモリケン', '南津軽郡田舎館村', 'ミナミツガルグンイナカダテムラ', '豊蒔', 'トヨマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県南津軽郡田舎館村川部', '02', '02367', '0381141', '青森県', 'アオモリケン', '南津軽郡田舎館村', 'ミナミツガルグンイナカダテムラ', '川部', 'カワベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県南津軽郡田舎館村和泉', '02', '02367', '0381142', '青森県', 'アオモリケン', '南津軽郡田舎館村', 'ミナミツガルグンイナカダテムラ', '和泉', 'イズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県南津軽郡田舎館村境森', '02', '02367', '0381143', '青森県', 'アオモリケン', '南津軽郡田舎館村', 'ミナミツガルグンイナカダテムラ', '境森', 'サカイモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県南津軽郡田舎館村前田屋敷', '02', '02367', '0381144', '青森県', 'アオモリケン', '南津軽郡田舎館村', 'ミナミツガルグンイナカダテムラ', '前田屋敷', 'マエダヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県南津軽郡田舎館村土矢倉', '02', '02367', '0381145', '青森県', 'アオモリケン', '南津軽郡田舎館村', 'ミナミツガルグンイナカダテムラ', '土矢倉', 'ツチヤグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県南津軽郡藤崎町福舘', '02', '02361', '0381201', '青森県', 'アオモリケン', '南津軽郡藤崎町', 'ミナミツガルグンフジサキマチ', '福舘', 'フクダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県南津軽郡藤崎町富柳', '02', '02361', '0381202', '青森県', 'アオモリケン', '南津軽郡藤崎町', 'ミナミツガルグンフジサキマチ', '富柳', 'トミヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県南津軽郡藤崎町久井名舘', '02', '02361', '0381203', '青森県', 'アオモリケン', '南津軽郡藤崎町', 'ミナミツガルグンフジサキマチ', '久井名舘', 'グイナダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県南津軽郡藤崎町水木', '02', '02361', '0381204', '青森県', 'アオモリケン', '南津軽郡藤崎町', 'ミナミツガルグンフジサキマチ', '水木', 'ミズキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県南津軽郡藤崎町吉野田', '02', '02361', '0381205', '青森県', 'アオモリケン', '南津軽郡藤崎町', 'ミナミツガルグンフジサキマチ', '吉野田', 'ヨシノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県南津軽郡藤崎町郷山前', '02', '02361', '0381206', '青森県', 'アオモリケン', '南津軽郡藤崎町', 'ミナミツガルグンフジサキマチ', '郷山前', 'ゴウサンマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県南津軽郡藤崎町増館', '02', '02361', '0381207', '青森県', 'アオモリケン', '南津軽郡藤崎町', 'ミナミツガルグンフジサキマチ', '増館', 'マスダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県南津軽郡藤崎町福島', '02', '02361', '0381211', '青森県', 'アオモリケン', '南津軽郡藤崎町', 'ミナミツガルグンフジサキマチ', '福島', 'フクシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県南津軽郡藤崎町三ツ屋', '02', '02361', '0381212', '青森県', 'アオモリケン', '南津軽郡藤崎町', 'ミナミツガルグンフジサキマチ', '三ツ屋', 'ミツヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県南津軽郡藤崎町徳下', '02', '02361', '0381213', '青森県', 'アオモリケン', '南津軽郡藤崎町', 'ミナミツガルグンフジサキマチ', '徳下', 'トクゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県南津軽郡藤崎町常盤', '02', '02361', '0381214', '青森県', 'アオモリケン', '南津軽郡藤崎町', 'ミナミツガルグンフジサキマチ', '常盤', 'トキワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県南津軽郡藤崎町若松', '02', '02361', '0381215', '青森県', 'アオモリケン', '南津軽郡藤崎町', 'ミナミツガルグンフジサキマチ', '若松', 'ワカマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県南津軽郡藤崎町榊', '02', '02361', '0381216', '青森県', 'アオモリケン', '南津軽郡藤崎町', 'ミナミツガルグンフジサキマチ', '榊', 'サカキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市若穂牛島', '20', '20201', '3812201', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '若穂牛島', 'ワカホウシジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市市場', '20', '20201', '3812202', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '市場', 'イチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市真島町川合', '20', '20201', '3812203', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '真島町川合', 'マシママチカワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市真島町真島', '20', '20201', '3812204', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '真島町真島', 'マシママチマシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市青木島町大塚', '20', '20201', '3812205', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '青木島町大塚', 'アオキジママチオオツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市青木島町綱島', '20', '20201', '3812206', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '青木島町綱島', 'アオキジママチツナシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市大橋南', '20', '20201', '3812207', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '大橋南', 'オオハシミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市稲里町下氷鉋', '20', '20201', '3812211', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '稲里町下氷鉋', 'イナサトマチシモヒガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市小島田町', '20', '20201', '3812212', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '小島田町', 'オシマダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市広田', '20', '20201', '3812213', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '広田', 'ヒロタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市稲里町田牧', '20', '20201', '3812214', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '稲里町田牧', 'イナサトマチタマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市稲里町中氷鉋', '20', '20201', '3812215', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '稲里町中氷鉋', 'イナサトマチナカヒガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市下氷鉋', '20', '20201', '3812216', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '下氷鉋', 'シモヒガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市稲里町中央', '20', '20201', '3812217', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '稲里町中央', 'イナサトマチチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市川中島町御厨', '20', '20201', '3812221', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '川中島町御厨', 'カワナカジママチミクリヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市金井田', '20', '20201', '3812222', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '金井田', 'カナイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市里島', '20', '20201', '3812223', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '里島', 'サトジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市川中島町原', '20', '20201', '3812224', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '川中島町原', 'カワナカジママチハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市篠ノ井岡田', '20', '20201', '3812225', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '篠ノ井岡田', 'シノノイオカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市川中島町今井', '20', '20201', '3812226', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '川中島町今井', 'カワナカジママチイマイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市川中島町今井原', '20', '20201', '3812227', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '川中島町今井原', 'カワナカジママチイマイハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市川中島町四ツ屋', '20', '20201', '3812231', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '川中島町四ツ屋', 'カワナカジママチヨツヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市川中島町若葉町', '20', '20201', '3812232', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '川中島町若葉町', 'カワナカジマチョウワカバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市川中島町上氷鉋', '20', '20201', '3812233', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '川中島町上氷鉋', 'カワナカジママチカミヒガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市川中島町今里', '20', '20201', '3812234', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '川中島町今里', 'カワナカジママチイマザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市篠ノ井小松原', '20', '20201', '3812235', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '篠ノ井小松原', 'シノノイコマツバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市青木島町青木島乙', '20', '20201', '3812241', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '青木島町青木島乙', 'アオキジママチアオキジマオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市青木島町青木島', '20', '20201', '3812242', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '青木島町青木島', 'アオキジママチアオキジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市稲里', '20', '20201', '3812243', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '稲里', 'イナサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市三本柳西', '20', '20201', '3812244', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '三本柳西', 'サンボンヤナギニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市三本柳東', '20', '20201', '3812245', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '三本柳東', 'サンボンヤナギヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市丹波島', '20', '20201', '3812246', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '丹波島', 'タンバジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市青木島', '20', '20201', '3812247', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '青木島', 'アオキジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市信更町下平', '20', '20201', '3812341', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '信更町下平', 'シンコウマチシモダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市信更町宮平', '20', '20201', '3812342', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '信更町宮平', 'シンコウマチミヤダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市信更町桜井', '20', '20201', '3812343', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '信更町桜井', 'シンコウマチサクライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市信更町上尾', '20', '20201', '3812344', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '信更町上尾', 'シンコウマチアゲオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市信更町涌池', '20', '20201', '3812345', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '信更町涌池', 'シンコウマチワクイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市信更町安庭', '20', '20201', '3812346', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '信更町安庭', 'シンコウマチヤスニワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市信更町古藤', '20', '20201', '3812347', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '信更町古藤', 'シンコウマチフルフジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市信更町氷ノ田', '20', '20201', '3812351', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '信更町氷ノ田', 'シンコウマチヒノタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市信更町赤田', '20', '20201', '3812352', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '信更町赤田', 'シンコウマチアカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市信更町田野口', '20', '20201', '3812353', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '信更町田野口', 'シンコウマチタノクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市信更町田沢', '20', '20201', '3812354', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '信更町田沢', 'シンコウマチタザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市信更町高野', '20', '20201', '3812355', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '信更町高野', 'シンコウマチタカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市信更町吉原', '20', '20201', '3812356', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '信更町吉原', 'シンコウマチヨシワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市信更町灰原', '20', '20201', '3812357', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '信更町灰原', 'シンコウマチハイバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市信更町今泉', '20', '20201', '3812358', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '信更町今泉', 'シンコウマチイマイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市信更町三水', '20', '20201', '3812359', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '信更町三水', 'シンコウマチサミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上水内郡信州新町', '20', '20581', '3812400', '長野県', 'ナガノケン', '上水内郡信州新町', 'カミミノチグンシンシュウシンマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('32574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上水内郡信州新町越道', '20', '20581', '3812401', '長野県', 'ナガノケン', '上水内郡信州新町', 'カミミノチグンシンシュウシンマチ', '越道', 'コエドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上水内郡信州新町山上条', '20', '20581', '3812402', '長野県', 'ナガノケン', '上水内郡信州新町', 'カミミノチグンシンシュウシンマチ', '山上条', 'ヤマカミジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上水内郡信州新町水内', '20', '20581', '3812403', '長野県', 'ナガノケン', '上水内郡信州新町', 'カミミノチグンシンシュウシンマチ', '水内', 'ミノチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上水内郡信州新町上条', '20', '20581', '3812404', '長野県', 'ナガノケン', '上水内郡信州新町', 'カミミノチグンシンシュウシンマチ', '上条', 'カミジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上水内郡信州新町新町', '20', '20581', '3812405', '長野県', 'ナガノケン', '上水内郡信州新町', 'カミミノチグンシンシュウシンマチ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上水内郡信州新町里穂刈', '20', '20581', '3812406', '長野県', 'ナガノケン', '上水内郡信州新町', 'カミミノチグンシンシュウシンマチ', '里穂刈', 'サトホカリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上水内郡信州新町山穂刈', '20', '20581', '3812407', '長野県', 'ナガノケン', '上水内郡信州新町', 'カミミノチグンシンシュウシンマチ', '山穂刈', 'ヤマホカリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上水内郡信州新町竹房', '20', '20581', '3812411', '長野県', 'ナガノケン', '上水内郡信州新町', 'カミミノチグンシンシュウシンマチ', '竹房', 'タケブサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上水内郡信州新町牧野島', '20', '20581', '3812412', '長野県', 'ナガノケン', '上水内郡信州新町', 'カミミノチグンシンシュウシンマチ', '牧野島', 'マキノシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上水内郡信州新町下市場', '20', '20581', '3812413', '長野県', 'ナガノケン', '上水内郡信州新町', 'カミミノチグンシンシュウシンマチ', '下市場', 'シモイチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上水内郡信州新町牧田中', '20', '20581', '3812414', '長野県', 'ナガノケン', '上水内郡信州新町', 'カミミノチグンシンシュウシンマチ', '牧田中', 'マキダナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上水内郡信州新町中牧', '20', '20581', '3812415', '長野県', 'ナガノケン', '上水内郡信州新町', 'カミミノチグンシンシュウシンマチ', '中牧', 'ナカマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上水内郡信州新町弘崎', '20', '20581', '3812416', '長野県', 'ナガノケン', '上水内郡信州新町', 'カミミノチグンシンシュウシンマチ', '弘崎', 'ヒロサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上水内郡信州新町信級', '20', '20581', '3812421', '長野県', 'ナガノケン', '上水内郡信州新町', 'カミミノチグンシンシュウシンマチ', '信級', 'ノブシナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上水内郡信州新町日原東', '20', '20581', '3812422', '長野県', 'ナガノケン', '上水内郡信州新町', 'カミミノチグンシンシュウシンマチ', '日原東', 'ヒハラヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上水内郡信州新町日原西', '20', '20581', '3812423', '長野県', 'ナガノケン', '上水内郡信州新町', 'カミミノチグンシンシュウシンマチ', '日原西', 'ヒハラニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上水内郡信州新町左右', '20', '20581', '3812424', '長野県', 'ナガノケン', '上水内郡信州新町', 'カミミノチグンシンシュウシンマチ', '左右', 'ソウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市大岡中牧', '20', '20201', '3812701', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '大岡中牧', 'オオオカナカマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市大岡丙', '20', '20201', '3812702', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '大岡丙', 'オオオカヘイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市大岡乙', '20', '20201', '3812703', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '大岡乙', 'オオオカオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市大岡甲', '20', '20201', '3812704', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '大岡甲', 'オオオカコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市大岡弘崎', '20', '20201', '3812705', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '大岡弘崎', 'オオオカヒロサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市浪岡大釈迦', '02', '02201', '0381301', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '浪岡大釈迦', 'ナミオカダイシャカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市浪岡長沼', '02', '02201', '0381302', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '浪岡長沼', 'ナミオカナガヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市浪岡徳才子', '02', '02201', '0381303', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '浪岡徳才子', 'ナミオカトクサイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市浪岡高屋敷', '02', '02201', '0381304', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '浪岡高屋敷', 'ナミオカタカヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市浪岡杉沢', '02', '02201', '0381305', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '浪岡杉沢', 'ナミオカスギサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市浪岡福田', '02', '02201', '0381306', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '浪岡福田', 'ナミオカフクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市浪岡浪岡', '02', '02201', '0381311', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '浪岡浪岡', 'ナミオカナミオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市浪岡五本松', '02', '02201', '0381312', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '浪岡五本松', 'ナミオカゴホンマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市浪岡王余魚沢', '02', '02201', '0381313', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '浪岡王余魚沢', 'ナミオカカレイザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市七二会丁', '20', '20201', '3813161', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '七二会丁', 'ナニアイテイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市七二会戊', '20', '20201', '3813162', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '七二会戊', 'ナニアイボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市七二会己', '20', '20201', '3813163', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '七二会己', 'ナニアイキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市七二会乙', '20', '20201', '3813164', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '七二会乙', 'ナニアイオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市七二会甲', '20', '20201', '3813165', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '七二会甲', 'ナニアイコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市七二会丙', '20', '20201', '3813166', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '七二会丙', 'ナニアイヘイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上水内郡中条村', '20', '20589', '3813200', '長野県', 'ナガノケン', '上水内郡中条村', 'カミミノチグンナカジョウムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('32612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上水内郡中条村日高', '20', '20589', '3813201', '長野県', 'ナガノケン', '上水内郡中条村', 'カミミノチグンナカジョウムラ', '日高', 'ヒダカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上水内郡中条村日下野', '20', '20589', '3813202', '長野県', 'ナガノケン', '上水内郡中条村', 'カミミノチグンナカジョウムラ', '日下野', 'クサガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上水内郡中条村中条', '20', '20589', '3813203', '長野県', 'ナガノケン', '上水内郡中条村', 'カミミノチグンナカジョウムラ', '中条', 'ナカジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上水内郡中条村御山里', '20', '20589', '3813204', '長野県', 'ナガノケン', '上水内郡中条村', 'カミミノチグンナカジョウムラ', '御山里', 'ミヤマサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上水内郡中条村住良木', '20', '20589', '3813205', '長野県', 'ナガノケン', '上水内郡中条村', 'カミミノチグンナカジョウムラ', '住良木', 'スメラギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市浪岡相沢', '02', '02201', '0381321', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '浪岡相沢', 'ナミオカアイザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市浪岡細野', '02', '02201', '0381322', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '浪岡細野', 'ナミオカホソノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市浪岡本郷', '02', '02201', '0381323', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '浪岡本郷', 'ナミオカホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市浪岡吉内', '02', '02201', '0381324', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '浪岡吉内', 'ナミオカキチナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市浪岡北中野', '02', '02201', '0381325', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '浪岡北中野', 'ナミオカキタナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上水内郡小川村', '20', '20588', '3813300', '長野県', 'ナガノケン', '上水内郡小川村', 'カミミノチグンオガワムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('32623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上水内郡小川村稲丘', '20', '20588', '3813301', '長野県', 'ナガノケン', '上水内郡小川村', 'カミミノチグンオガワムラ', '稲丘', 'イナオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上水内郡小川村高府', '20', '20588', '3813302', '長野県', 'ナガノケン', '上水内郡小川村', 'カミミノチグンオガワムラ', '高府', 'タカフ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上水内郡小川村小根山', '20', '20588', '3813303', '長野県', 'ナガノケン', '上水内郡小川村', 'カミミノチグンオガワムラ', '小根山', 'オネヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上水内郡小川村瀬戸川', '20', '20588', '3813304', '長野県', 'ナガノケン', '上水内郡小川村', 'カミミノチグンオガワムラ', '瀬戸川', 'セトガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市浪岡女鹿沢', '02', '02201', '0381331', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '浪岡女鹿沢', 'ナミオカメガサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市浪岡下十川', '02', '02201', '0381332', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '浪岡下十川', 'ナミオカシモトガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市浪岡増館', '02', '02201', '0381333', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '浪岡増館', 'ナミオカマスダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市浪岡銀', '02', '02201', '0381341', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '浪岡銀', 'ナミオカシロガネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市浪岡樽沢', '02', '02201', '0381342', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '浪岡樽沢', 'ナミオカタルサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市浪岡郷山前', '02', '02201', '0381343', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '浪岡郷山前', 'ナミオカゴウサンマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市浪岡吉野田', '02', '02201', '0381344', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '浪岡吉野田', 'ナミオカヨシノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市浪岡下石川', '02', '02201', '0381345', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '浪岡下石川', 'ナミオカシモイシカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市戸隠', '20', '20201', '3814101', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '戸隠', 'トガクシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市戸隠豊岡', '20', '20201', '3814102', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '戸隠豊岡', 'トガクシトヨオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市戸隠祖山', '20', '20201', '3814103', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '戸隠祖山', 'トガクシソヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市戸隠栃原', '20', '20201', '3814104', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '戸隠栃原', 'トガクシトチワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市鬼無里', '20', '20201', '3814301', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '鬼無里', 'キナサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市鬼無里日影', '20', '20201', '3814302', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '鬼無里日影', 'キナサヒカゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市鬼無里日下野', '20', '20201', '3814303', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '鬼無里日下野', 'キナサクサガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県須坂市', '20', '20207', '3820000', '長野県', 'ナガノケン', '須坂市', 'スザカシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('32670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県須坂市松川町', '20', '20207', '3820001', '長野県', 'ナガノケン', '須坂市', 'スザカシ', '松川町', 'マツカワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県須坂市北旭ケ丘町', '20', '20207', '3820002', '長野県', 'ナガノケン', '須坂市', 'スザカシ', '北旭ケ丘町', 'キタアサヒガオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県須坂市旭ケ丘', '20', '20207', '3820003', '長野県', 'ナガノケン', '須坂市', 'スザカシ', '旭ケ丘', 'アサヒガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県須坂市高畑町', '20', '20207', '3820004', '長野県', 'ナガノケン', '須坂市', 'スザカシ', '高畑町', 'タカバタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県須坂市新田町', '20', '20207', '3820005', '長野県', 'ナガノケン', '須坂市', 'スザカシ', '新田町', 'シンデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県須坂市光ケ丘ニュータウン', '20', '20207', '3820006', '長野県', 'ナガノケン', '須坂市', 'スザカシ', '光ケ丘ニュータウン', 'ヒカリガオカニュータウン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県須坂市本郷町', '20', '20207', '3820011', '長野県', 'ナガノケン', '須坂市', 'スザカシ', '本郷町', 'ホンゴウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県須坂市大谷町', '20', '20207', '3820012', '長野県', 'ナガノケン', '須坂市', 'スザカシ', '大谷町', 'オオヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県須坂市常盤町', '20', '20207', '3820013', '長野県', 'ナガノケン', '須坂市', 'スザカシ', '常盤町', 'トキワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県須坂市新町', '20', '20207', '3820014', '長野県', 'ナガノケン', '須坂市', 'スザカシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県須坂市太子町', '20', '20207', '3820015', '長野県', 'ナガノケン', '須坂市', 'スザカシ', '太子町', 'タイシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県須坂市高橋町', '20', '20207', '3820016', '長野県', 'ナガノケン', '須坂市', 'スザカシ', '高橋町', 'タカハシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県須坂市相森町', '20', '20207', '3820017', '長野県', 'ナガノケン', '須坂市', 'スザカシ', '相森町', 'オオモリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県須坂市豊丘町', '20', '20207', '3820021', '長野県', 'ナガノケン', '須坂市', 'スザカシ', '豊丘町', 'トヨオカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県須坂市豊丘上町', '20', '20207', '3820022', '長野県', 'ナガノケン', '須坂市', 'スザカシ', '豊丘上町', 'トヨオカカミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県須坂市米子町', '20', '20207', '3820023', '長野県', 'ナガノケン', '須坂市', 'スザカシ', '米子町', 'ヨナコマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県須坂市塩野町', '20', '20207', '3820024', '長野県', 'ナガノケン', '須坂市', 'スザカシ', '塩野町', 'シオノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県須坂市大日向町', '20', '20207', '3820025', '長野県', 'ナガノケン', '須坂市', 'スザカシ', '大日向町', 'オビナタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県須坂市坂田町', '20', '20207', '3820026', '長野県', 'ナガノケン', '須坂市', 'スザカシ', '坂田町', 'サカダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県須坂市南原町', '20', '20207', '3820027', '長野県', 'ナガノケン', '須坂市', 'スザカシ', '南原町', 'ミナミハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県須坂市臥竜', '20', '20207', '3820028', '長野県', 'ナガノケン', '須坂市', 'スザカシ', '臥竜', 'ガリュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県須坂市村石町', '20', '20207', '3820031', '長野県', 'ナガノケン', '須坂市', 'スザカシ', '村石町', 'ムライシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県須坂市夏端町', '20', '20207', '3820032', '長野県', 'ナガノケン', '須坂市', 'スザカシ', '夏端町', 'ナツバタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県須坂市亀倉町', '20', '20207', '3820033', '長野県', 'ナガノケン', '須坂市', 'スザカシ', '亀倉町', 'カメクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県須坂市仁礼町', '20', '20207', '3820034', '長野県', 'ナガノケン', '須坂市', 'スザカシ', '仁礼町', 'ニレイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県須坂市明徳町', '20', '20207', '3820036', '長野県', 'ナガノケン', '須坂市', 'スザカシ', '明徳町', 'ミョウトクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県須坂市野辺町', '20', '20207', '3820037', '長野県', 'ナガノケン', '須坂市', 'スザカシ', '野辺町', 'ノベマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県須坂市米持町', '20', '20207', '3820041', '長野県', 'ナガノケン', '須坂市', 'スザカシ', '米持町', 'ヨナモチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県須坂市望岳台', '20', '20207', '3820042', '長野県', 'ナガノケン', '須坂市', 'スザカシ', '望岳台', 'ボウガクダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県須坂市下八町', '20', '20207', '3820043', '長野県', 'ナガノケン', '須坂市', 'スザカシ', '下八町', 'シモハッチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県須坂市上八町', '20', '20207', '3820044', '長野県', 'ナガノケン', '須坂市', 'スザカシ', '上八町', 'カミハッチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県須坂市井上', '20', '20207', '3820045', '長野県', 'ナガノケン', '須坂市', 'スザカシ', '井上', 'イノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県須坂市二睦町', '20', '20207', '3820046', '長野県', 'ナガノケン', '須坂市', 'スザカシ', '二睦町', 'ニボクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県須坂市幸高町', '20', '20207', '3820047', '長野県', 'ナガノケン', '須坂市', 'スザカシ', '幸高町', 'コウタカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県須坂市九反田町', '20', '20207', '3820048', '長野県', 'ナガノケン', '須坂市', 'スザカシ', '九反田町', 'クタンダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県須坂市八重森町', '20', '20207', '3820051', '長野県', 'ナガノケン', '須坂市', 'スザカシ', '八重森町', 'ヤエモリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県須坂市塩川町', '20', '20207', '3820052', '長野県', 'ナガノケン', '須坂市', 'スザカシ', '塩川町', 'シオガワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県須坂市五閑町', '20', '20207', '3820053', '長野県', 'ナガノケン', '須坂市', 'スザカシ', '五閑町', 'ゴカンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県須坂市高梨町', '20', '20207', '3820054', '長野県', 'ナガノケン', '須坂市', 'スザカシ', '高梨町', 'タカナシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県須坂市中島町', '20', '20207', '3820055', '長野県', 'ナガノケン', '須坂市', 'スザカシ', '中島町', 'ナカジママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県須坂市福島町', '20', '20207', '3820056', '長野県', 'ナガノケン', '須坂市', 'スザカシ', '福島町', 'フクジママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県須坂市村山町', '20', '20207', '3820057', '長野県', 'ナガノケン', '須坂市', 'スザカシ', '村山町', 'ムラヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県須坂市北相之島町', '20', '20207', '3820061', '長野県', 'ナガノケン', '須坂市', 'スザカシ', '北相之島町', 'キタアイノシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県須坂市小島町', '20', '20207', '3820062', '長野県', 'ナガノケン', '須坂市', 'スザカシ', '小島町', 'コジママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県須坂市西町', '20', '20207', '3820063', '長野県', 'ナガノケン', '須坂市', 'スザカシ', '西町', 'ニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県須坂市沼目町', '20', '20207', '3820064', '長野県', 'ナガノケン', '須坂市', 'スザカシ', '沼目町', 'ヌマメマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県須坂市相之島', '20', '20207', '3820065', '長野県', 'ナガノケン', '須坂市', 'スザカシ', '相之島', 'アイノシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県須坂市豊島町', '20', '20207', '3820066', '長野県', 'ナガノケン', '須坂市', 'スザカシ', '豊島町', 'トヨシママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県須坂市小河原町', '20', '20207', '3820071', '長野県', 'ナガノケン', '須坂市', 'スザカシ', '小河原町', 'オガワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県須坂市南小河原町', '20', '20207', '3820072', '長野県', 'ナガノケン', '須坂市', 'スザカシ', '南小河原町', 'ミナミオガワラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県須坂市田の神町', '20', '20207', '3820073', '長野県', 'ナガノケン', '須坂市', 'スザカシ', '田の神町', 'タノカミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県須坂市春木町', '20', '20207', '3820074', '長野県', 'ナガノケン', '須坂市', 'スザカシ', '春木町', 'ハルキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県須坂市須坂ハイランド町', '20', '20207', '3820075', '長野県', 'ナガノケン', '須坂市', 'スザカシ', '須坂ハイランド町', 'スザカハイランドマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県須坂市馬場町', '20', '20207', '3820076', '長野県', 'ナガノケン', '須坂市', 'スザカシ', '馬場町', 'ババチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県須坂市北横町', '20', '20207', '3820077', '長野県', 'ナガノケン', '須坂市', 'スザカシ', '北横町', 'キタヨコマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県須坂市横町', '20', '20207', '3820081', '長野県', 'ナガノケン', '須坂市', 'スザカシ', '横町', 'ヨコマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県須坂市中町', '20', '20207', '3820082', '長野県', 'ナガノケン', '須坂市', 'スザカシ', '中町', 'ナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県須坂市上中町', '20', '20207', '3820083', '長野県', 'ナガノケン', '須坂市', 'スザカシ', '上中町', 'カミナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県須坂市上町', '20', '20207', '3820084', '長野県', 'ナガノケン', '須坂市', 'スザカシ', '上町', 'カンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県須坂市穀町', '20', '20207', '3820085', '長野県', 'ナガノケン', '須坂市', 'スザカシ', '穀町', 'コクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県須坂市本上町', '20', '20207', '3820086', '長野県', 'ナガノケン', '須坂市', 'スザカシ', '本上町', 'ホンカンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県須坂市東横町', '20', '20207', '3820087', '長野県', 'ナガノケン', '須坂市', 'スザカシ', '東横町', 'ヒガシヨコマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県須坂市立町', '20', '20207', '3820091', '長野県', 'ナガノケン', '須坂市', 'スザカシ', '立町', 'タツマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県須坂市北原町', '20', '20207', '3820092', '長野県', 'ナガノケン', '須坂市', 'スザカシ', '北原町', 'キタハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県須坂市屋部町', '20', '20207', '3820094', '長野県', 'ナガノケン', '須坂市', 'スザカシ', '屋部町', 'ヤブマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県須坂市南横町', '20', '20207', '3820097', '長野県', 'ナガノケン', '須坂市', 'スザカシ', '南横町', 'ミナミヨコマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県須坂市墨坂南', '20', '20207', '3820098', '長野県', 'ナガノケン', '須坂市', 'スザカシ', '墨坂南', 'スミサカミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県須坂市墨坂', '20', '20207', '3820099', '長野県', 'ナガノケン', '須坂市', 'スザカシ', '墨坂', 'スミサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上高井郡高山村', '20', '20543', '3820800', '長野県', 'ナガノケン', '上高井郡高山村', 'カミタカイグンタカヤマムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('32739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上高井郡高山村駒場', '20', '20543', '3820801', '長野県', 'ナガノケン', '上高井郡高山村', 'カミタカイグンタカヤマムラ', '駒場', 'コマバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上高井郡高山村松原', '20', '20543', '3820802', '長野県', 'ナガノケン', '上高井郡高山村', 'カミタカイグンタカヤマムラ', '松原', 'マツハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上高井郡高山村桝形', '20', '20543', '3820803', '長野県', 'ナガノケン', '上高井郡高山村', 'カミタカイグンタカヤマムラ', '桝形', 'マスガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上高井郡高山村中原', '20', '20543', '3820804', '長野県', 'ナガノケン', '上高井郡高山村', 'カミタカイグンタカヤマムラ', '中原', 'ナカハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上高井郡高山村三郷', '20', '20543', '3820805', '長野県', 'ナガノケン', '上高井郡高山村', 'カミタカイグンタカヤマムラ', '三郷', 'ミサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上高井郡高山村なかひら', '20', '20543', '3820806', '長野県', 'ナガノケン', '上高井郡高山村', 'カミタカイグンタカヤマムラ', 'なかひら', 'ナカヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上高井郡高山村宮関', '20', '20543', '3820811', '長野県', 'ナガノケン', '上高井郡高山村', 'カミタカイグンタカヤマムラ', '宮関', 'ミヤセキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上高井郡高山村蕨平', '20', '20543', '3820813', '長野県', 'ナガノケン', '上高井郡高山村', 'カミタカイグンタカヤマムラ', '蕨平', 'ワラビタイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上高井郡高山村天神原', '20', '20543', '3820814', '長野県', 'ナガノケン', '上高井郡高山村', 'カミタカイグンタカヤマムラ', '天神原', 'テンジンバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上高井郡高山村荻久保', '20', '20543', '3820815', '長野県', 'ナガノケン', '上高井郡高山村', 'カミタカイグンタカヤマムラ', '荻久保', 'オギクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上高井郡高山村山田温泉', '20', '20543', '3820816', '長野県', 'ナガノケン', '上高井郡高山村', 'カミタカイグンタカヤマムラ', '山田温泉', 'ヤマダオンセン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上高井郡高山村山田牧場', '20', '20543', '3820817', '長野県', 'ナガノケン', '上高井郡高山村', 'カミタカイグンタカヤマムラ', '山田牧場', 'ヤマダボクジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上高井郡高山村牧', '20', '20543', '3820821', '長野県', 'ナガノケン', '上高井郡高山村', 'カミタカイグンタカヤマムラ', '牧', 'マキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上高井郡高山村福井原', '20', '20543', '3820822', '長野県', 'ナガノケン', '上高井郡高山村', 'カミタカイグンタカヤマムラ', '福井原', 'フクイハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上高井郡高山村黒部', '20', '20543', '3820823', '長野県', 'ナガノケン', '上高井郡高山村', 'カミタカイグンタカヤマムラ', '黒部', 'クロベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上高井郡高山村緑ケ丘', '20', '20543', '3820824', '長野県', 'ナガノケン', '上高井郡高山村', 'カミタカイグンタカヤマムラ', '緑ケ丘', 'ミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上高井郡高山村紫', '20', '20543', '3820825', '長野県', 'ナガノケン', '上高井郡高山村', 'カミタカイグンタカヤマムラ', '紫', 'ムラサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上高井郡高山村二ツ石', '20', '20543', '3820826', '長野県', 'ナガノケン', '上高井郡高山村', 'カミタカイグンタカヤマムラ', '二ツ石', 'フタツイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上高井郡高山村松南', '20', '20543', '3820827', '長野県', 'ナガノケン', '上高井郡高山村', 'カミタカイグンタカヤマムラ', '松南', 'マツナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上高井郡高山村荒井原', '20', '20543', '3820831', '長野県', 'ナガノケン', '上高井郡高山村', 'カミタカイグンタカヤマムラ', '荒井原', 'アライハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上高井郡高山村赤和', '20', '20543', '3820832', '長野県', 'ナガノケン', '上高井郡高山村', 'カミタカイグンタカヤマムラ', '赤和', 'アカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上高井郡高山村久保', '20', '20543', '3820833', '長野県', 'ナガノケン', '上高井郡高山村', 'カミタカイグンタカヤマムラ', '久保', 'クボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上高井郡高山村水中', '20', '20543', '3820834', '長野県', 'ナガノケン', '上高井郡高山村', 'カミタカイグンタカヤマムラ', '水中', 'ミズナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上高井郡高山村千本松', '20', '20543', '3820835', '長野県', 'ナガノケン', '上高井郡高山村', 'カミタカイグンタカヤマムラ', '千本松', 'センボンマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上高井郡高山村新堀', '20', '20543', '3820836', '長野県', 'ナガノケン', '上高井郡高山村', 'カミタカイグンタカヤマムラ', '新堀', 'シンボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上高井郡高山村堀之内', '20', '20543', '3820837', '長野県', 'ナガノケン', '上高井郡高山村', 'カミタカイグンタカヤマムラ', '堀之内', 'ホリノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県西津軽郡深浦町沢辺', '02', '02323', '0382201', '青森県', 'アオモリケン', '西津軽郡深浦町', 'ニシツガルグンフカウラマチ', '沢辺', 'サワベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県西津軽郡深浦町岩崎', '02', '02323', '0382202', '青森県', 'アオモリケン', '西津軽郡深浦町', 'ニシツガルグンフカウラマチ', '岩崎', 'イワサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県西津軽郡深浦町正道尻', '02', '02323', '0382203', '青森県', 'アオモリケン', '西津軽郡深浦町', 'ニシツガルグンフカウラマチ', '正道尻', 'ショウドウジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県西津軽郡深浦町久田', '02', '02323', '0382204', '青森県', 'アオモリケン', '西津軽郡深浦町', 'ニシツガルグンフカウラマチ', '久田', 'ヒサダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県西津軽郡深浦町森山', '02', '02323', '0382205', '青森県', 'アオモリケン', '西津軽郡深浦町', 'ニシツガルグンフカウラマチ', '森山', 'モリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県西津軽郡深浦町松神', '02', '02323', '0382206', '青森県', 'アオモリケン', '西津軽郡深浦町', 'ニシツガルグンフカウラマチ', '松神', 'マツカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県西津軽郡深浦町黒崎', '02', '02323', '0382207', '青森県', 'アオモリケン', '西津軽郡深浦町', 'ニシツガルグンフカウラマチ', '黒崎', 'クロサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県西津軽郡深浦町大間越', '02', '02323', '0382208', '青森県', 'アオモリケン', '西津軽郡深浦町', 'ニシツガルグンフカウラマチ', '大間越', 'オオマゴシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県西津軽郡深浦町', '02', '02323', '0382300', '青森県', 'アオモリケン', '西津軽郡深浦町', 'ニシツガルグンフカウラマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('32774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県西津軽郡深浦町広戸', '02', '02323', '0382321', '青森県', 'アオモリケン', '西津軽郡深浦町', 'ニシツガルグンフカウラマチ', '広戸', 'ヒロト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県西津軽郡深浦町長慶平', '02', '02323', '0382322', '青森県', 'アオモリケン', '西津軽郡深浦町', 'ニシツガルグンフカウラマチ', '長慶平', 'チョウケイダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県西津軽郡深浦町上長慶平', '02', '02323', '0382323', '青森県', 'アオモリケン', '西津軽郡深浦町', 'ニシツガルグンフカウラマチ', '上長慶平', 'カミチョウケイダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県西津軽郡深浦町深浦', '02', '02323', '0382324', '青森県', 'アオモリケン', '西津軽郡深浦町', 'ニシツガルグンフカウラマチ', '深浦', 'フカウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県西津軽郡深浦町横磯', '02', '02323', '0382325', '青森県', 'アオモリケン', '西津軽郡深浦町', 'ニシツガルグンフカウラマチ', '横磯', 'ヨコイソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県西津軽郡深浦町月屋', '02', '02323', '0382326', '青森県', 'アオモリケン', '西津軽郡深浦町', 'ニシツガルグンフカウラマチ', '月屋', 'ツキヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県西津軽郡深浦町舮作', '02', '02323', '0382327', '青森県', 'アオモリケン', '西津軽郡深浦町', 'ニシツガルグンフカウラマチ', '舮作', 'ヘナシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県西津軽郡深浦町風合瀬', '02', '02323', '0382411', '青森県', 'アオモリケン', '西津軽郡深浦町', 'ニシツガルグンフカウラマチ', '風合瀬', 'カソセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県西津軽郡深浦町驫木', '02', '02323', '0382412', '青森県', 'アオモリケン', '西津軽郡深浦町', 'ニシツガルグンフカウラマチ', '驫木', 'トドロキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県西津軽郡深浦町追良瀬', '02', '02323', '0382413', '青森県', 'アオモリケン', '西津軽郡深浦町', 'ニシツガルグンフカウラマチ', '追良瀬', 'オイラセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県西津軽郡深浦町柳田', '02', '02323', '0382501', '青森県', 'アオモリケン', '西津軽郡深浦町', 'ニシツガルグンフカウラマチ', '柳田', 'ヤナギタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県西津軽郡深浦町岩坂', '02', '02323', '0382502', '青森県', 'アオモリケン', '西津軽郡深浦町', 'ニシツガルグンフカウラマチ', '岩坂', 'イワサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県西津軽郡深浦町関', '02', '02323', '0382503', '青森県', 'アオモリケン', '西津軽郡深浦町', 'ニシツガルグンフカウラマチ', '関', 'セキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県西津軽郡深浦町北金ケ沢', '02', '02323', '0382504', '青森県', 'アオモリケン', '西津軽郡深浦町', 'ニシツガルグンフカウラマチ', '北金ケ沢', 'キタカネガサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県西津軽郡深浦町田野沢', '02', '02323', '0382505', '青森県', 'アオモリケン', '西津軽郡深浦町', 'ニシツガルグンフカウラマチ', '田野沢', 'タノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県西津軽郡鰺ヶ沢町', '02', '02321', '0382700', '青森県', 'アオモリケン', '西津軽郡鰺ヶ沢町', 'ニシツガルグンアジガサワマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('32790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県西津軽郡鰺ヶ沢町北浮田町', '02', '02321', '0382701', '青森県', 'アオモリケン', '西津軽郡鰺ヶ沢町', 'ニシツガルグンアジガサワマチ', '北浮田町', 'キタウキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県西津軽郡鰺ヶ沢町建石町', '02', '02321', '0382702', '青森県', 'アオモリケン', '西津軽郡鰺ヶ沢町', 'ニシツガルグンアジガサワマチ', '建石町', 'タテイシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県西津軽郡鰺ヶ沢町小屋敷町', '02', '02321', '0382703', '青森県', 'アオモリケン', '西津軽郡鰺ヶ沢町', 'ニシツガルグンアジガサワマチ', '小屋敷町', 'コヤシキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県西津軽郡鰺ヶ沢町湯舟町', '02', '02321', '0382704', '青森県', 'アオモリケン', '西津軽郡鰺ヶ沢町', 'ニシツガルグンアジガサワマチ', '湯舟町', 'ユブネマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県西津軽郡鰺ヶ沢町南浮田町', '02', '02321', '0382705', '青森県', 'アオモリケン', '西津軽郡鰺ヶ沢町', 'ニシツガルグンアジガサワマチ', '南浮田町', 'ミナミウキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県西津軽郡鰺ヶ沢町中村町', '02', '02321', '0382711', '青森県', 'アオモリケン', '西津軽郡鰺ヶ沢町', 'ニシツガルグンアジガサワマチ', '中村町', 'ナカムラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県西津軽郡鰺ヶ沢町長平町', '02', '02321', '0382712', '青森県', 'アオモリケン', '西津軽郡鰺ヶ沢町', 'ニシツガルグンアジガサワマチ', '長平町', 'ナガダイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県西津軽郡鰺ヶ沢町松代町', '02', '02321', '0382713', '青森県', 'アオモリケン', '西津軽郡鰺ヶ沢町', 'ニシツガルグンアジガサワマチ', '松代町', 'マツダイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県西津軽郡鰺ヶ沢町芦萢町', '02', '02321', '0382714', '青森県', 'アオモリケン', '西津軽郡鰺ヶ沢町', 'ニシツガルグンアジガサワマチ', '芦萢町', 'アシヤチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県西津軽郡鰺ヶ沢町浜横沢町', '02', '02321', '0382715', '青森県', 'アオモリケン', '西津軽郡鰺ヶ沢町', 'ニシツガルグンアジガサワマチ', '浜横沢町', 'ハマヨコサワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県西津軽郡鰺ヶ沢町深谷町', '02', '02321', '0382721', '青森県', 'アオモリケン', '西津軽郡鰺ヶ沢町', 'ニシツガルグンアジガサワマチ', '深谷町', 'フカヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県西津軽郡鰺ヶ沢町小森町', '02', '02321', '0382722', '青森県', 'アオモリケン', '西津軽郡鰺ヶ沢町', 'ニシツガルグンアジガサワマチ', '小森町', 'コモリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県西津軽郡鰺ヶ沢町一ツ森町', '02', '02321', '0382723', '青森県', 'アオモリケン', '西津軽郡鰺ヶ沢町', 'ニシツガルグンアジガサワマチ', '一ツ森町', 'ヒトツモリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県西津軽郡鰺ヶ沢町鬼袋町', '02', '02321', '0382724', '青森県', 'アオモリケン', '西津軽郡鰺ヶ沢町', 'ニシツガルグンアジガサワマチ', '鬼袋町', 'オニフクロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県西津軽郡鰺ヶ沢町種里町', '02', '02321', '0382725', '青森県', 'アオモリケン', '西津軽郡鰺ヶ沢町', 'ニシツガルグンアジガサワマチ', '種里町', 'タネサトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県西津軽郡鰺ヶ沢町赤石町', '02', '02321', '0382731', '青森県', 'アオモリケン', '西津軽郡鰺ヶ沢町', 'ニシツガルグンアジガサワマチ', '赤石町', 'アカイシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県西津軽郡鰺ヶ沢町日照田町', '02', '02321', '0382732', '青森県', 'アオモリケン', '西津軽郡鰺ヶ沢町', 'ニシツガルグンアジガサワマチ', '日照田町', 'ヒデリタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県西津軽郡鰺ヶ沢町館前町', '02', '02321', '0382733', '青森県', 'アオモリケン', '西津軽郡鰺ヶ沢町', 'ニシツガルグンアジガサワマチ', '館前町', 'タテマエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県西津軽郡鰺ヶ沢町南金沢町', '02', '02321', '0382734', '青森県', 'アオモリケン', '西津軽郡鰺ヶ沢町', 'ニシツガルグンアジガサワマチ', '南金沢町', 'ミナミカナザワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県西津軽郡鰺ヶ沢町姥袋町', '02', '02321', '0382735', '青森県', 'アオモリケン', '西津軽郡鰺ヶ沢町', 'ニシツガルグンアジガサワマチ', '姥袋町', 'ウバフクロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県西津軽郡鰺ヶ沢町浜町', '02', '02321', '0382741', '青森県', 'アオモリケン', '西津軽郡鰺ヶ沢町', 'ニシツガルグンアジガサワマチ', '浜町', 'ハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県西津軽郡鰺ヶ沢町新町', '02', '02321', '0382742', '青森県', 'アオモリケン', '西津軽郡鰺ヶ沢町', 'ニシツガルグンアジガサワマチ', '新町', 'アラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県西津軽郡鰺ヶ沢町釣町', '02', '02321', '0382743', '青森県', 'アオモリケン', '西津軽郡鰺ヶ沢町', 'ニシツガルグンアジガサワマチ', '釣町', 'ツリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県西津軽郡鰺ヶ沢町漁師町', '02', '02321', '0382744', '青森県', 'アオモリケン', '西津軽郡鰺ヶ沢町', 'ニシツガルグンアジガサワマチ', '漁師町', 'リョウシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県西津軽郡鰺ヶ沢町新地町', '02', '02321', '0382745', '青森県', 'アオモリケン', '西津軽郡鰺ヶ沢町', 'ニシツガルグンアジガサワマチ', '新地町', 'シンチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県西津軽郡鰺ヶ沢町富根町', '02', '02321', '0382746', '青森県', 'アオモリケン', '西津軽郡鰺ヶ沢町', 'ニシツガルグンアジガサワマチ', '富根町', 'フネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県西津軽郡鰺ヶ沢町淀町', '02', '02321', '0382747', '青森県', 'アオモリケン', '西津軽郡鰺ヶ沢町', 'ニシツガルグンアジガサワマチ', '淀町', 'ヨドマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県西津軽郡鰺ヶ沢町田中町', '02', '02321', '0382751', '青森県', 'アオモリケン', '西津軽郡鰺ヶ沢町', 'ニシツガルグンアジガサワマチ', '田中町', 'タナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県西津軽郡鰺ヶ沢町七ツ石町', '02', '02321', '0382752', '青森県', 'アオモリケン', '西津軽郡鰺ヶ沢町', 'ニシツガルグンアジガサワマチ', '七ツ石町', 'ナナツイシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県西津軽郡鰺ヶ沢町本町', '02', '02321', '0382753', '青森県', 'アオモリケン', '西津軽郡鰺ヶ沢町', 'ニシツガルグンアジガサワマチ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県西津軽郡鰺ヶ沢町米町', '02', '02321', '0382754', '青森県', 'アオモリケン', '西津軽郡鰺ヶ沢町', 'ニシツガルグンアジガサワマチ', '米町', 'コメマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県西津軽郡鰺ヶ沢町舞戸町', '02', '02321', '0382761', '青森県', 'アオモリケン', '西津軽郡鰺ヶ沢町', 'ニシツガルグンアジガサワマチ', '舞戸町', 'マイドマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県つがる市木造丸山', '02', '02209', '0382801', '青森県', 'アオモリケン', 'つがる市', 'ツガルシ', '木造丸山', 'キヅクリマルヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県つがる市木造下福原', '02', '02209', '0382803', '青森県', 'アオモリケン', 'つがる市', 'ツガルシ', '木造下福原', 'キヅクリシモフクハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県つがる市木造三ツ館', '02', '02209', '0382804', '青森県', 'アオモリケン', 'つがる市', 'ツガルシ', '木造三ツ館', 'キヅクリミツタテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県つがる市木造広岡', '02', '02209', '0382805', '青森県', 'アオモリケン', 'つがる市', 'ツガルシ', '木造広岡', 'キヅクリヒロオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県つがる市木造越水', '02', '02209', '0382806', '青森県', 'アオモリケン', 'つがる市', 'ツガルシ', '木造越水', 'キヅクリコシミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県つがる市木造駒田', '02', '02209', '0382807', '青森県', 'アオモリケン', 'つがる市', 'ツガルシ', '木造駒田', 'キヅクリコマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県つがる市木造吹原', '02', '02209', '0382808', '青森県', 'アオモリケン', 'つがる市', 'ツガルシ', '木造吹原', 'キヅクリフキハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県つがる市森田町上相野', '02', '02209', '0382811', '青森県', 'アオモリケン', 'つがる市', 'ツガルシ', '森田町上相野', 'モリタチョウカミアイノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県つがる市森田町下相野', '02', '02209', '0382812', '青森県', 'アオモリケン', 'つがる市', 'ツガルシ', '森田町下相野', 'モリタチョウシモアイノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県つがる市森田町妙堂崎', '02', '02209', '0382813', '青森県', 'アオモリケン', 'つがる市', 'ツガルシ', '森田町妙堂崎', 'モリタチョウミョウドウザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県つがる市森田町中田', '02', '02209', '0382814', '青森県', 'アオモリケン', 'つがる市', 'ツガルシ', '森田町中田', 'モリタチョウナカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県つがる市森田町山田', '02', '02209', '0382815', '青森県', 'アオモリケン', 'つがる市', 'ツガルシ', '森田町山田', 'モリタチョウヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県つがる市森田町森田', '02', '02209', '0382816', '青森県', 'アオモリケン', 'つがる市', 'ツガルシ', '森田町森田', 'モリタチョウモリタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県つがる市森田町床舞', '02', '02209', '0382817', '青森県', 'アオモリケン', 'つがる市', 'ツガルシ', '森田町床舞', 'モリタチョウトコマイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県つがる市森田町大館', '02', '02209', '0382818', '青森県', 'アオモリケン', 'つがる市', 'ツガルシ', '森田町大館', 'モリタチョウオオダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県中野市', '20', '20211', '3830000', '長野県', 'ナガノケン', '中野市', 'ナカノシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('32852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県中野市岩井', '20', '20211', '3830001', '長野県', 'ナガノケン', '中野市', 'ナカノシ', '岩井', 'イワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県中野市田上', '20', '20211', '3830002', '長野県', 'ナガノケン', '中野市', 'ナカノシ', '田上', 'タガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県中野市柳沢', '20', '20211', '3830003', '長野県', 'ナガノケン', '中野市', 'ナカノシ', '柳沢', 'ヤナギサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県中野市赤岩', '20', '20211', '3830004', '長野県', 'ナガノケン', '中野市', 'ナカノシ', '赤岩', 'アカイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県中野市越', '20', '20211', '3830005', '長野県', 'ナガノケン', '中野市', 'ナカノシ', '越', 'コシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県中野市深沢', '20', '20211', '3830006', '長野県', 'ナガノケン', '中野市', 'ナカノシ', '深沢', 'フカサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県中野市竹原', '20', '20211', '3830007', '長野県', 'ナガノケン', '中野市', 'ナカノシ', '竹原', 'タケハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県中野市金井', '20', '20211', '3830008', '長野県', 'ナガノケン', '中野市', 'ナカノシ', '金井', 'カナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県中野市若宮', '20', '20211', '3830011', '長野県', 'ナガノケン', '中野市', 'ナカノシ', '若宮', 'ワカミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県中野市一本木', '20', '20211', '3830012', '長野県', 'ナガノケン', '中野市', 'ナカノシ', '一本木', 'イッポンギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県中野市中野', '20', '20211', '3830013', '長野県', 'ナガノケン', '中野市', 'ナカノシ', '中野', 'ナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県中野市諏訪町', '20', '20211', '3830014', '長野県', 'ナガノケン', '中野市', 'ナカノシ', '諏訪町', 'スワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県中野市吉田', '20', '20211', '3830015', '長野県', 'ナガノケン', '中野市', 'ナカノシ', '吉田', 'ヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県中野市西', '20', '20211', '3830021', '長野県', 'ナガノケン', '中野市', 'ナカノシ', '西', 'ニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県中野市中央', '20', '20211', '3830022', '長野県', 'ナガノケン', '中野市', 'ナカノシ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県中野市小館', '20', '20211', '3830023', '長野県', 'ナガノケン', '中野市', 'ナカノシ', '小館', 'オタテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県中野市東山', '20', '20211', '3830024', '長野県', 'ナガノケン', '中野市', 'ナカノシ', '東山', 'ヒガシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県中野市三好町', '20', '20211', '3830025', '長野県', 'ナガノケン', '中野市', 'ナカノシ', '三好町', 'ミヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県中野市南宮', '20', '20211', '3830031', '長野県', 'ナガノケン', '中野市', 'ナカノシ', '南宮', 'ナングウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県中野市更科', '20', '20211', '3830032', '長野県', 'ナガノケン', '中野市', 'ナカノシ', '更科', 'サラシナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県中野市間山', '20', '20211', '3830033', '長野県', 'ナガノケン', '中野市', 'ナカノシ', '間山', 'マヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県中野市新野', '20', '20211', '3830034', '長野県', 'ナガノケン', '中野市', 'ナカノシ', '新野', 'シンノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県中野市篠井', '20', '20211', '3830035', '長野県', 'ナガノケン', '中野市', 'ナカノシ', '篠井', 'シノイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県中野市新保', '20', '20211', '3830036', '長野県', 'ナガノケン', '中野市', 'ナカノシ', '新保', 'シンボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県中野市小田中', '20', '20211', '3830037', '長野県', 'ナガノケン', '中野市', 'ナカノシ', '小田中', 'コダナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県中野市岩船', '20', '20211', '3830041', '長野県', 'ナガノケン', '中野市', 'ナカノシ', '岩船', 'イワフネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県中野市西条', '20', '20211', '3830042', '長野県', 'ナガノケン', '中野市', 'ナカノシ', '西条', 'ニシジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県中野市三ツ和', '20', '20211', '3830043', '長野県', 'ナガノケン', '中野市', 'ナカノシ', '三ツ和', 'ミツワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県中野市桜沢', '20', '20211', '3830044', '長野県', 'ナガノケン', '中野市', 'ナカノシ', '桜沢', 'サクラサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県中野市江部', '20', '20211', '3830045', '長野県', 'ナガノケン', '中野市', 'ナカノシ', '江部', 'エベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県中野市片塩', '20', '20211', '3830046', '長野県', 'ナガノケン', '中野市', 'ナカノシ', '片塩', 'カタシオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県中野市七瀬', '20', '20211', '3830051', '長野県', 'ナガノケン', '中野市', 'ナカノシ', '七瀬', 'ナナセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県中野市安源寺', '20', '20211', '3830052', '長野県', 'ナガノケン', '中野市', 'ナカノシ', '安源寺', 'アンゲンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県中野市草間', '20', '20211', '3830053', '長野県', 'ナガノケン', '中野市', 'ナカノシ', '草間', 'クサマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県中野市立ケ花', '20', '20211', '3830054', '長野県', 'ナガノケン', '中野市', 'ナカノシ', '立ケ花', 'タテガハナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県中野市牛出', '20', '20211', '3830055', '長野県', 'ナガノケン', '中野市', 'ナカノシ', '牛出', 'ウシイデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県中野市栗林', '20', '20211', '3830056', '長野県', 'ナガノケン', '中野市', 'ナカノシ', '栗林', 'クリバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県中野市大俣', '20', '20211', '3830057', '長野県', 'ナガノケン', '中野市', 'ナカノシ', '大俣', 'オオマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県中野市壁田', '20', '20211', '3830061', '長野県', 'ナガノケン', '中野市', 'ナカノシ', '壁田', 'ヘキダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県中野市笠原', '20', '20211', '3830062', '長野県', 'ナガノケン', '中野市', 'ナカノシ', '笠原', 'カサハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県中野市間長瀬', '20', '20211', '3830063', '長野県', 'ナガノケン', '中野市', 'ナカノシ', '間長瀬', 'マナガセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県中野市新井', '20', '20211', '3830064', '長野県', 'ナガノケン', '中野市', 'ナカノシ', '新井', 'アライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県中野市田麦', '20', '20211', '3830065', '長野県', 'ナガノケン', '中野市', 'ナカノシ', '田麦', 'タムギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県中野市厚貝', '20', '20211', '3830066', '長野県', 'ナガノケン', '中野市', 'ナカノシ', '厚貝', 'アッカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県つがる市', '02', '02209', '0383100', '青森県', 'アオモリケン', 'つがる市', 'ツガルシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('32897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県つがる市柏鷺坂', '02', '02209', '0383101', '青森県', 'アオモリケン', 'つがる市', 'ツガルシ', '柏鷺坂', 'カシワサギサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県つがる市柏下古川', '02', '02209', '0383102', '青森県', 'アオモリケン', 'つがる市', 'ツガルシ', '柏下古川', 'カシワシモコガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県つがる市柏上古川', '02', '02209', '0383103', '青森県', 'アオモリケン', 'つがる市', 'ツガルシ', '柏上古川', 'カシワカミコガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県つがる市柏桑野木田', '02', '02209', '0383104', '青森県', 'アオモリケン', 'つがる市', 'ツガルシ', '柏桑野木田', 'カシワクワノキダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県つがる市柏広須', '02', '02209', '0383105', '青森県', 'アオモリケン', 'つがる市', 'ツガルシ', '柏広須', 'カシワヒロス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県つがる市柏玉水', '02', '02209', '0383106', '青森県', 'アオモリケン', 'つがる市', 'ツガルシ', '柏玉水', 'カシワタマミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県つがる市柏稲盛', '02', '02209', '0383107', '青森県', 'アオモリケン', 'つがる市', 'ツガルシ', '柏稲盛', 'カシワイセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県つがる市木造豊田', '02', '02209', '0383111', '青森県', 'アオモリケン', 'つがる市', 'ツガルシ', '木造豊田', 'キヅクリトヨダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県つがる市木造川除', '02', '02209', '0383112', '青森県', 'アオモリケン', 'つがる市', 'ツガルシ', '木造川除', 'キヅクリカワヨケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県つがる市木造芦沼', '02', '02209', '0383113', '青森県', 'アオモリケン', 'つがる市', 'ツガルシ', '木造芦沼', 'キヅクリアシヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県つがる市木造成田', '02', '02209', '0383114', '青森県', 'アオモリケン', 'つがる市', 'ツガルシ', '木造成田', 'キヅクリナリタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県つがる市木造蓮川', '02', '02209', '0383115', '青森県', 'アオモリケン', 'つがる市', 'ツガルシ', '木造蓮川', 'キヅクリハスカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県つがる市木造早田', '02', '02209', '0383121', '青森県', 'アオモリケン', 'つがる市', 'ツガルシ', '木造早田', 'キヅクリハヤタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県つがる市木造追広', '02', '02209', '0383122', '青森県', 'アオモリケン', 'つがる市', 'ツガルシ', '木造追広', 'キヅクリオイヒロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県つがる市木造藤田', '02', '02209', '0383123', '青森県', 'アオモリケン', 'つがる市', 'ツガルシ', '木造藤田', 'キヅクリフジタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県つがる市木造朝日', '02', '02209', '0383124', '青森県', 'アオモリケン', 'つがる市', 'ツガルシ', '木造朝日', 'キヅクリアサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県つがる市木造鶴泊', '02', '02209', '0383125', '青森県', 'アオモリケン', 'つがる市', 'ツガルシ', '木造鶴泊', 'キヅクリツルドマリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県つがる市木造森内', '02', '02209', '0383126', '青森県', 'アオモリケン', 'つがる市', 'ツガルシ', '木造森内', 'キヅクリモリウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県つがる市木造森山', '02', '02209', '0383127', '青森県', 'アオモリケン', 'つがる市', 'ツガルシ', '木造森山', 'キヅクリモリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県つがる市木造森本', '02', '02209', '0383128', '青森県', 'アオモリケン', 'つがる市', 'ツガルシ', '木造森本', 'キヅクリモリモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県つがる市木造千年', '02', '02209', '0383131', '青森県', 'アオモリケン', 'つがる市', 'ツガルシ', '木造千年', 'キヅクリチトセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県つがる市木造清水', '02', '02209', '0383132', '青森県', 'アオモリケン', 'つがる市', 'ツガルシ', '木造清水', 'キヅクリシミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県つがる市木造末広', '02', '02209', '0383133', '青森県', 'アオモリケン', 'つがる市', 'ツガルシ', '木造末広', 'キヅクリスエヒロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県つがる市木造種取', '02', '02209', '0383134', '青森県', 'アオモリケン', 'つがる市', 'ツガルシ', '木造種取', 'キヅクリタネトリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県つがる市木造有楽町', '02', '02209', '0383135', '青森県', 'アオモリケン', 'つがる市', 'ツガルシ', '木造有楽町', 'キヅクリウラクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県つがる市木造萩野', '02', '02209', '0383136', '青森県', 'アオモリケン', 'つがる市', 'ツガルシ', '木造萩野', 'キヅクリハギノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県つがる市木造若宮', '02', '02209', '0383137', '青森県', 'アオモリケン', 'つがる市', 'ツガルシ', '木造若宮', 'キヅクリワカミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県つがる市木造若緑', '02', '02209', '0383138', '青森県', 'アオモリケン', 'つがる市', 'ツガルシ', '木造若緑', 'キヅクリワカミドリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県つがる市木造萩流', '02', '02209', '0383139', '青森県', 'アオモリケン', 'つがる市', 'ツガルシ', '木造萩流', 'キヅクリハギナガレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県つがる市木造浮巣', '02', '02209', '0383141', '青森県', 'アオモリケン', 'つがる市', 'ツガルシ', '木造浮巣', 'キヅクリウキス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県つがる市木造赤根', '02', '02209', '0383142', '青森県', 'アオモリケン', 'つがる市', 'ツガルシ', '木造赤根', 'キヅクリアカネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県つがる市木造日向', '02', '02209', '0383143', '青森県', 'アオモリケン', 'つがる市', 'ツガルシ', '木造日向', 'キヅクリヒナタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県つがる市木造曙', '02', '02209', '0383144', '青森県', 'アオモリケン', 'つがる市', 'ツガルシ', '木造曙', 'キヅクリアケボノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県つがる市木造千代町', '02', '02209', '0383145', '青森県', 'アオモリケン', 'つがる市', 'ツガルシ', '木造千代町', 'キヅクリチヨマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県つがる市木造桜木', '02', '02209', '0383146', '青森県', 'アオモリケン', 'つがる市', 'ツガルシ', '木造桜木', 'キヅクリサクラギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県つがる市木造若竹', '02', '02209', '0383151', '青森県', 'アオモリケン', 'つがる市', 'ツガルシ', '木造若竹', 'キヅクリワカタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県つがる市木造藤岡', '02', '02209', '0383152', '青森県', 'アオモリケン', 'つがる市', 'ツガルシ', '木造藤岡', 'キヅクリフジオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県つがる市木造野宮', '02', '02209', '0383153', '青森県', 'アオモリケン', 'つがる市', 'ツガルシ', '木造野宮', 'キヅクリノミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県つがる市木造照日', '02', '02209', '0383154', '青森県', 'アオモリケン', 'つがる市', 'ツガルシ', '木造照日', 'キヅクリテルヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県つがる市木造増田', '02', '02209', '0383155', '青森県', 'アオモリケン', 'つがる市', 'ツガルシ', '木造増田', 'キヅクリマスタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県つがる市木造宮井', '02', '02209', '0383156', '青森県', 'アオモリケン', 'つがる市', 'ツガルシ', '木造宮井', 'キヅクリミヤイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県つがる市木造宮崎', '02', '02209', '0383157', '青森県', 'アオモリケン', 'つがる市', 'ツガルシ', '木造宮崎', 'キヅクリミヤザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県つがる市木造房松', '02', '02209', '0383158', '青森県', 'アオモリケン', 'つがる市', 'ツガルシ', '木造房松', 'キヅクリフサマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県つがる市木造桜川', '02', '02209', '0383159', '青森県', 'アオモリケン', 'つがる市', 'ツガルシ', '木造桜川', 'キヅクリサクラガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県つがる市木造濁川', '02', '02209', '0383161', '青森県', 'アオモリケン', 'つがる市', 'ツガルシ', '木造濁川', 'キヅクリニゴリガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県つがる市木造浦船', '02', '02209', '0383162', '青森県', 'アオモリケン', 'つがる市', 'ツガルシ', '木造浦船', 'キヅクリウラフネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県つがる市木造中館', '02', '02209', '0383163', '青森県', 'アオモリケン', 'つがる市', 'ツガルシ', '木造中館', 'キヅクリナカダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県つがる市木造柴田', '02', '02209', '0383164', '青森県', 'アオモリケン', 'つがる市', 'ツガルシ', '木造柴田', 'キヅクリシバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県つがる市木造菊川', '02', '02209', '0383165', '青森県', 'アオモリケン', 'つがる市', 'ツガルシ', '木造菊川', 'キヅクリキクカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県つがる市木造福原', '02', '02209', '0383166', '青森県', 'アオモリケン', 'つがる市', 'ツガルシ', '木造福原', 'キヅクリフクハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県つがる市木造千代田', '02', '02209', '0383167', '青森県', 'アオモリケン', 'つがる市', 'ツガルシ', '木造千代田', 'キヅクリチヨダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県つがる市木造善積', '02', '02209', '0383271', '青森県', 'アオモリケン', 'つがる市', 'ツガルシ', '木造善積', 'キヅクリヨシヅミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県つがる市木造兼館', '02', '02209', '0383272', '青森県', 'アオモリケン', 'つがる市', 'ツガルシ', '木造兼館', 'キヅクリカネダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県つがる市木造出野里', '02', '02209', '0383273', '青森県', 'アオモリケン', 'つがる市', 'ツガルシ', '木造出野里', 'キヅクリイデノサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県つがる市木造蓮花田', '02', '02209', '0383274', '青森県', 'アオモリケン', 'つがる市', 'ツガルシ', '木造蓮花田', 'キヅクリレンゲタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県つがる市木造永田', '02', '02209', '0383275', '青森県', 'アオモリケン', 'つがる市', 'ツガルシ', '木造永田', 'キヅクリナガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県つがる市木造林', '02', '02209', '0383276', '青森県', 'アオモリケン', 'つがる市', 'ツガルシ', '木造林', 'キヅクリハヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県つがる市木造大畑', '02', '02209', '0383277', '青森県', 'アオモリケン', 'つがる市', 'ツガルシ', '木造大畑', 'キヅクリオオバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県つがる市木造土滝', '02', '02209', '0383278', '青森県', 'アオモリケン', 'つがる市', 'ツガルシ', '木造土滝', 'キヅクリツチタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県つがる市木造平滝', '02', '02209', '0383281', '青森県', 'アオモリケン', 'つがる市', 'ツガルシ', '木造平滝', 'キヅクリヒラタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県つがる市木造筒木坂', '02', '02209', '0383282', '青森県', 'アオモリケン', 'つがる市', 'ツガルシ', '木造筒木坂', 'キヅクリドウキザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県つがる市木造館岡', '02', '02209', '0383283', '青森県', 'アオモリケン', 'つがる市', 'ツガルシ', '木造館岡', 'キヅクリタテオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県つがる市木造亀ケ岡', '02', '02209', '0383284', '青森県', 'アオモリケン', 'つがる市', 'ツガルシ', '木造亀ケ岡', 'キヅクリカメガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県つがる市木造大湯町', '02', '02209', '0383285', '青森県', 'アオモリケン', 'つがる市', 'ツガルシ', '木造大湯町', 'キヅクリオオユマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県つがる市木造菰槌', '02', '02209', '0383286', '青森県', 'アオモリケン', 'つがる市', 'ツガルシ', '木造菰槌', 'キヅクリコモツチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県つがる市木造下遠山里', '02', '02209', '0383287', '青森県', 'アオモリケン', 'つがる市', 'ツガルシ', '木造下遠山里', 'キヅクリシモトオヤマサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県つがる市木造出来島', '02', '02209', '0383288', '青森県', 'アオモリケン', 'つがる市', 'ツガルシ', '木造出来島', 'キヅクリデキシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県つがる市富萢町', '02', '02209', '0383301', '青森県', 'アオモリケン', 'つがる市', 'ツガルシ', '富萢町', 'トミヤチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県つがる市豊富町', '02', '02209', '0383302', '青森県', 'アオモリケン', 'つがる市', 'ツガルシ', '豊富町', 'トヨトミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県つがる市車力町', '02', '02209', '0383303', '青森県', 'アオモリケン', 'つがる市', 'ツガルシ', '車力町', 'シャリキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県つがる市下車力町', '02', '02209', '0383304', '青森県', 'アオモリケン', 'つがる市', 'ツガルシ', '下車力町', 'シタシャリキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県つがる市牛潟町', '02', '02209', '0383305', '青森県', 'アオモリケン', 'つがる市', 'ツガルシ', '牛潟町', 'ウシガタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県つがる市下牛潟町', '02', '02209', '0383306', '青森県', 'アオモリケン', 'つがる市', 'ツガルシ', '下牛潟町', 'シモウシガタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県北津軽郡鶴田町', '02', '02384', '0383500', '青森県', 'アオモリケン', '北津軽郡鶴田町', 'キタツガルグンツルタマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('32979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県北津軽郡鶴田町大巻', '02', '02384', '0383501', '青森県', 'アオモリケン', '北津軽郡鶴田町', 'キタツガルグンツルタマチ', '大巻', 'オオマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県北津軽郡鶴田町強巻', '02', '02384', '0383502', '青森県', 'アオモリケン', '北津軽郡鶴田町', 'キタツガルグンツルタマチ', '強巻', 'コワマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県北津軽郡鶴田町鶴田', '02', '02384', '0383503', '青森県', 'アオモリケン', '北津軽郡鶴田町', 'キタツガルグンツルタマチ', '鶴田', 'ツルタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県北津軽郡鶴田町横萢', '02', '02384', '0383511', '青森県', 'アオモリケン', '北津軽郡鶴田町', 'キタツガルグンツルタマチ', '横萢', 'ヨコヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県北津軽郡鶴田町瀬良沢', '02', '02384', '0383512', '青森県', 'アオモリケン', '北津軽郡鶴田町', 'キタツガルグンツルタマチ', '瀬良沢', 'セラザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県北津軽郡鶴田町沖', '02', '02384', '0383513', '青森県', 'アオモリケン', '北津軽郡鶴田町', 'キタツガルグンツルタマチ', '沖', 'オキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県北津軽郡鶴田町中野', '02', '02384', '0383514', '青森県', 'アオモリケン', '北津軽郡鶴田町', 'キタツガルグンツルタマチ', '中野', 'ナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県北津軽郡鶴田町山道', '02', '02384', '0383515', '青森県', 'アオモリケン', '北津軽郡鶴田町', 'キタツガルグンツルタマチ', '山道', 'ヤマミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県北津軽郡鶴田町菖蒲川', '02', '02384', '0383521', '青森県', 'アオモリケン', '北津軽郡鶴田町', 'キタツガルグンツルタマチ', '菖蒲川', 'ショウブカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県北津軽郡鶴田町鶴泊', '02', '02384', '0383522', '青森県', 'アオモリケン', '北津軽郡鶴田町', 'キタツガルグンツルタマチ', '鶴泊', 'ツルドマリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県北津軽郡鶴田町胡桃舘', '02', '02384', '0383523', '青森県', 'アオモリケン', '北津軽郡鶴田町', 'キタツガルグンツルタマチ', '胡桃舘', 'クルミダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県北津軽郡鶴田町境', '02', '02384', '0383524', '青森県', 'アオモリケン', '北津軽郡鶴田町', 'キタツガルグンツルタマチ', '境', 'サカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県北津軽郡鶴田町大性', '02', '02384', '0383525', '青森県', 'アオモリケン', '北津軽郡鶴田町', 'キタツガルグンツルタマチ', '大性', 'ダイショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県北津軽郡鶴田町木筒', '02', '02384', '0383531', '青森県', 'アオモリケン', '北津軽郡鶴田町', 'キタツガルグンツルタマチ', '木筒', 'キヅツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県北津軽郡鶴田町野木', '02', '02384', '0383532', '青森県', 'アオモリケン', '北津軽郡鶴田町', 'キタツガルグンツルタマチ', '野木', 'ノギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県北津軽郡鶴田町尾原', '02', '02384', '0383541', '青森県', 'アオモリケン', '北津軽郡鶴田町', 'キタツガルグンツルタマチ', '尾原', 'オハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県北津軽郡鶴田町廻堰', '02', '02384', '0383542', '青森県', 'アオモリケン', '北津軽郡鶴田町', 'キタツガルグンツルタマチ', '廻堰', 'マワリゼキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県北津軽郡鶴田町妙堂崎', '02', '02384', '0383543', '青森県', 'アオモリケン', '北津軽郡鶴田町', 'キタツガルグンツルタマチ', '妙堂崎', 'ミョウドウザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('32998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県北津軽郡板柳町', '02', '02381', '0383600', '青森県', 'アオモリケン', '北津軽郡板柳町', 'キタツガルグンイタヤナギマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('32999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市三和', '02', '02202', '0383611', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '三和', 'ミワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市笹舘', '02', '02202', '0383612', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '笹舘', 'ササダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市小友', '02', '02202', '0383613', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '小友', 'オトモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市種市', '02', '02202', '0383614', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '種市', 'タネイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市青女子', '02', '02202', '0383615', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '青女子', 'アオナゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県北津軽郡板柳町五林平', '02', '02381', '0383621', '青森県', 'アオモリケン', '北津軽郡板柳町', 'キタツガルグンイタヤナギマチ', '五林平', 'ゴリンタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県北津軽郡板柳町夕顔関', '02', '02381', '0383622', '青森県', 'アオモリケン', '北津軽郡板柳町', 'キタツガルグンイタヤナギマチ', '夕顔関', 'ユウガオゼキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県北津軽郡板柳町常海橋', '02', '02381', '0383623', '青森県', 'アオモリケン', '北津軽郡板柳町', 'キタツガルグンイタヤナギマチ', '常海橋', 'ジョウカイバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県北津軽郡板柳町滝井', '02', '02381', '0383624', '青森県', 'アオモリケン', '北津軽郡板柳町', 'キタツガルグンイタヤナギマチ', '滝井', 'タキイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県北津軽郡板柳町舘野越', '02', '02381', '0383625', '青森県', 'アオモリケン', '北津軽郡板柳町', 'キタツガルグンイタヤナギマチ', '舘野越', 'タテノコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県北津軽郡板柳町牡丹森', '02', '02381', '0383631', '青森県', 'アオモリケン', '北津軽郡板柳町', 'キタツガルグンイタヤナギマチ', '牡丹森', 'ボタンモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県北津軽郡板柳町柏木', '02', '02381', '0383632', '青森県', 'アオモリケン', '北津軽郡板柳町', 'キタツガルグンイタヤナギマチ', '柏木', 'カシワギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県北津軽郡板柳町狐森', '02', '02381', '0383633', '青森県', 'アオモリケン', '北津軽郡板柳町', 'キタツガルグンイタヤナギマチ', '狐森', 'キツネモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県北津軽郡板柳町高増', '02', '02381', '0383634', '青森県', 'アオモリケン', '北津軽郡板柳町', 'キタツガルグンイタヤナギマチ', '高増', 'タカマス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県北津軽郡板柳町大俵', '02', '02381', '0383635', '青森県', 'アオモリケン', '北津軽郡板柳町', 'キタツガルグンイタヤナギマチ', '大俵', 'オオタワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県北津軽郡板柳町五幾形', '02', '02381', '0383636', '青森県', 'アオモリケン', '北津軽郡板柳町', 'キタツガルグンイタヤナギマチ', '五幾形', 'ゴキガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県北津軽郡板柳町深味', '02', '02381', '0383641', '青森県', 'アオモリケン', '北津軽郡板柳町', 'キタツガルグンイタヤナギマチ', '深味', 'フカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県北津軽郡板柳町太田', '02', '02381', '0383642', '青森県', 'アオモリケン', '北津軽郡板柳町', 'キタツガルグンイタヤナギマチ', '太田', 'オオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県北津軽郡板柳町長野', '02', '02381', '0383643', '青森県', 'アオモリケン', '北津軽郡板柳町', 'キタツガルグンイタヤナギマチ', '長野', 'ナガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県北津軽郡板柳町横沢', '02', '02381', '0383644', '青森県', 'アオモリケン', '北津軽郡板柳町', 'キタツガルグンイタヤナギマチ', '横沢', 'ヨコサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県北津軽郡板柳町辻', '02', '02381', '0383645', '青森県', 'アオモリケン', '北津軽郡板柳町', 'キタツガルグンイタヤナギマチ', '辻', 'ツジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県北津軽郡板柳町飯田', '02', '02381', '0383651', '青森県', 'アオモリケン', '北津軽郡板柳町', 'キタツガルグンイタヤナギマチ', '飯田', 'イイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県北津軽郡板柳町福野田', '02', '02381', '0383661', '青森県', 'アオモリケン', '北津軽郡板柳町', 'キタツガルグンイタヤナギマチ', '福野田', 'フクノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県北津軽郡板柳町板柳', '02', '02381', '0383662', '青森県', 'アオモリケン', '北津軽郡板柳町', 'キタツガルグンイタヤナギマチ', '板柳', 'イタヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県北津軽郡板柳町掛落林', '02', '02381', '0383671', '青森県', 'アオモリケン', '北津軽郡板柳町', 'キタツガルグンイタヤナギマチ', '掛落林', 'カケオチバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県北津軽郡板柳町灰沼', '02', '02381', '0383672', '青森県', 'アオモリケン', '北津軽郡板柳町', 'キタツガルグンイタヤナギマチ', '灰沼', 'ハイヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県北津軽郡板柳町小幡', '02', '02381', '0383673', '青森県', 'アオモリケン', '北津軽郡板柳町', 'キタツガルグンイタヤナギマチ', '小幡', 'コハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県北津軽郡板柳町野中', '02', '02381', '0383681', '青森県', 'アオモリケン', '北津軽郡板柳町', 'キタツガルグンイタヤナギマチ', '野中', 'ノナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県北津軽郡板柳町石野', '02', '02381', '0383682', '青森県', 'アオモリケン', '北津軽郡板柳町', 'キタツガルグンイタヤナギマチ', '石野', 'イシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県北津軽郡板柳町赤田', '02', '02381', '0383683', '青森県', 'アオモリケン', '北津軽郡板柳町', 'キタツガルグンイタヤナギマチ', '赤田', 'アカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県北津軽郡板柳町三千石', '02', '02381', '0383684', '青森県', 'アオモリケン', '北津軽郡板柳町', 'キタツガルグンイタヤナギマチ', '三千石', 'サンゼンゴク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県北津軽郡板柳町いたや町', '02', '02381', '0383685', '青森県', 'アオモリケン', '北津軽郡板柳町', 'キタツガルグンイタヤナギマチ', 'いたや町', 'イタヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県南津軽郡藤崎町', '02', '02361', '0383800', '青森県', 'アオモリケン', '南津軽郡藤崎町', 'ミナミツガルグンフジサキマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('33033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県南津軽郡藤崎町藤越', '02', '02361', '0383801', '青森県', 'アオモリケン', '南津軽郡藤崎町', 'ミナミツガルグンフジサキマチ', '藤越', 'フジコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県南津軽郡藤崎町藤崎', '02', '02361', '0383802', '青森県', 'アオモリケン', '南津軽郡藤崎町', 'ミナミツガルグンフジサキマチ', '藤崎', 'フジサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県南津軽郡藤崎町西豊田', '02', '02361', '0383803', '青森県', 'アオモリケン', '南津軽郡藤崎町', 'ミナミツガルグンフジサキマチ', '西豊田', 'ニシトヨダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県南津軽郡藤崎町葛野', '02', '02361', '0383804', '青森県', 'アオモリケン', '南津軽郡藤崎町', 'ミナミツガルグンフジサキマチ', '葛野', 'クズノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県南津軽郡藤崎町五林', '02', '02361', '0383805', '青森県', 'アオモリケン', '南津軽郡藤崎町', 'ミナミツガルグンフジサキマチ', '五林', 'ゴリン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県南津軽郡藤崎町林崎', '02', '02361', '0383806', '青森県', 'アオモリケン', '南津軽郡藤崎町', 'ミナミツガルグンフジサキマチ', '林崎', 'ハヤシザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県南津軽郡藤崎町中島', '02', '02361', '0383811', '青森県', 'アオモリケン', '南津軽郡藤崎町', 'ミナミツガルグンフジサキマチ', '中島', 'ナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県南津軽郡藤崎町小畑', '02', '02361', '0383812', '青森県', 'アオモリケン', '南津軽郡藤崎町', 'ミナミツガルグンフジサキマチ', '小畑', 'コバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県南津軽郡藤崎町矢沢', '02', '02361', '0383813', '青森県', 'アオモリケン', '南津軽郡藤崎町', 'ミナミツガルグンフジサキマチ', '矢沢', 'ヤザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県南津軽郡藤崎町水沼', '02', '02361', '0383814', '青森県', 'アオモリケン', '南津軽郡藤崎町', 'ミナミツガルグンフジサキマチ', '水沼', 'ミズヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市百田', '02', '02202', '0383821', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '百田', 'モモタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県南津軽郡藤崎町中野目', '02', '02361', '0383831', '青森県', 'アオモリケン', '南津軽郡藤崎町', 'ミナミツガルグンフジサキマチ', '中野目', 'ナカノメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県南津軽郡藤崎町吉向', '02', '02361', '0383832', '青森県', 'アオモリケン', '南津軽郡藤崎町', 'ミナミツガルグンフジサキマチ', '吉向', 'ヨシムカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県南津軽郡藤崎町亀岡', '02', '02361', '0383833', '青森県', 'アオモリケン', '南津軽郡藤崎町', 'ミナミツガルグンフジサキマチ', '亀岡', 'カメオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県南津軽郡藤崎町西中野目', '02', '02361', '0383834', '青森県', 'アオモリケン', '南津軽郡藤崎町', 'ミナミツガルグンフジサキマチ', '西中野目', 'ニシナカノメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県南津軽郡藤崎町俵舛', '02', '02361', '0383835', '青森県', 'アオモリケン', '南津軽郡藤崎町', 'ミナミツガルグンフジサキマチ', '俵舛', 'タワラマス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県南津軽郡藤崎町下俵舛', '02', '02361', '0383836', '青森県', 'アオモリケン', '南津軽郡藤崎町', 'ミナミツガルグンフジサキマチ', '下俵舛', 'シモタワラマス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県南津軽郡藤崎町柏木堰', '02', '02361', '0383837', '青森県', 'アオモリケン', '南津軽郡藤崎町', 'ミナミツガルグンフジサキマチ', '柏木堰', 'カシワギゼキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県弘前市津賀野', '02', '02202', '0383874', '青森県', 'アオモリケン', '弘前市', 'ヒロサキシ', '津賀野', 'ツカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県小諸市', '20', '20208', '3840000', '長野県', 'ナガノケン', '小諸市', 'コモロシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('33066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県小諸市小原', '20', '20208', '3840001', '長野県', 'ナガノケン', '小諸市', 'コモロシ', '小原', 'コバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県小諸市唐松', '20', '20208', '3840002', '長野県', 'ナガノケン', '小諸市', 'コモロシ', '唐松', 'カラマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県小諸市東山', '20', '20208', '3840003', '長野県', 'ナガノケン', '小諸市', 'コモロシ', '東山', 'ヒガシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県小諸市乙女', '20', '20208', '3840004', '長野県', 'ナガノケン', '小諸市', 'コモロシ', '乙女', 'オトメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県小諸市御幸町', '20', '20208', '3840005', '長野県', 'ナガノケン', '小諸市', 'コモロシ', '御幸町', 'ミユキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県小諸市与良町', '20', '20208', '3840006', '長野県', 'ナガノケン', '小諸市', 'コモロシ', '与良町', 'ヨラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県小諸市鶴巻', '20', '20208', '3840007', '長野県', 'ナガノケン', '小諸市', 'コモロシ', '鶴巻', 'ツルマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県小諸市東小諸', '20', '20208', '3840008', '長野県', 'ナガノケン', '小諸市', 'コモロシ', '東小諸', 'ヒガシコモロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県小諸市赤坂', '20', '20208', '3840011', '長野県', 'ナガノケン', '小諸市', 'コモロシ', '赤坂', 'アカサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県小諸市南町', '20', '20208', '3840012', '長野県', 'ナガノケン', '小諸市', 'コモロシ', '南町', 'ミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県小諸市緑ケ丘', '20', '20208', '3840013', '長野県', 'ナガノケン', '小諸市', 'コモロシ', '緑ケ丘', 'ミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県小諸市荒町', '20', '20208', '3840014', '長野県', 'ナガノケン', '小諸市', 'コモロシ', '荒町', 'アラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県小諸市紺屋町', '20', '20208', '3840015', '長野県', 'ナガノケン', '小諸市', 'コモロシ', '紺屋町', 'コンヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県小諸市八幡町', '20', '20208', '3840016', '長野県', 'ナガノケン', '小諸市', 'コモロシ', '八幡町', 'ハチマンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県小諸市三和', '20', '20208', '3840017', '長野県', 'ナガノケン', '小諸市', 'コモロシ', '三和', 'ミツワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県小諸市坂ノ上', '20', '20208', '3840018', '長野県', 'ナガノケン', '小諸市', 'コモロシ', '坂ノ上', 'サカノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県小諸市天池', '20', '20208', '3840021', '長野県', 'ナガノケン', '小諸市', 'コモロシ', '天池', 'アマイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県小諸市松井', '20', '20208', '3840022', '長野県', 'ナガノケン', '小諸市', 'コモロシ', '松井', 'マツイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県小諸市東雲', '20', '20208', '3840023', '長野県', 'ナガノケン', '小諸市', 'コモロシ', '東雲', 'シノノメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県小諸市熊ノ堂', '20', '20208', '3840024', '長野県', 'ナガノケン', '小諸市', 'コモロシ', '熊ノ堂', 'クマノドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県小諸市相生町', '20', '20208', '3840025', '長野県', 'ナガノケン', '小諸市', 'コモロシ', '相生町', 'アイオイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県小諸市本町', '20', '20208', '3840026', '長野県', 'ナガノケン', '小諸市', 'コモロシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県小諸市六供', '20', '20208', '3840027', '長野県', 'ナガノケン', '小諸市', 'コモロシ', '六供', 'ロック', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県小諸市田町', '20', '20208', '3840028', '長野県', 'ナガノケン', '小諸市', 'コモロシ', '田町', 'タマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県小諸市大手', '20', '20208', '3840031', '長野県', 'ナガノケン', '小諸市', 'コモロシ', '大手', 'オオテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県小諸市古城', '20', '20208', '3840032', '長野県', 'ナガノケン', '小諸市', 'コモロシ', '古城', 'コジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県小諸市市町', '20', '20208', '3840033', '長野県', 'ナガノケン', '小諸市', 'コモロシ', '市町', 'イチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県小諸市新町', '20', '20208', '3840034', '長野県', 'ナガノケン', '小諸市', 'コモロシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県小諸市両神', '20', '20208', '3840035', '長野県', 'ナガノケン', '小諸市', 'コモロシ', '両神', 'リョウジン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県小諸市富士見平', '20', '20208', '3840036', '長野県', 'ナガノケン', '小諸市', 'コモロシ', '富士見平', 'フジミダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県小諸市押出', '20', '20208', '3840037', '長野県', 'ナガノケン', '小諸市', 'コモロシ', '押出', 'オシダシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県小諸市栃木', '20', '20208', '3840038', '長野県', 'ナガノケン', '小諸市', 'コモロシ', '栃木', 'トチギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県小諸市菱平', '20', '20208', '3840041', '長野県', 'ナガノケン', '小諸市', 'コモロシ', '菱平', 'ヒシダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県小諸市後平', '20', '20208', '3840042', '長野県', 'ナガノケン', '小諸市', 'コモロシ', '後平', 'ウシロダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県小諸市諸', '20', '20208', '3840043', '長野県', 'ナガノケン', '小諸市', 'コモロシ', '諸', 'モロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県小諸市西原', '20', '20208', '3840044', '長野県', 'ナガノケン', '小諸市', 'コモロシ', '西原', 'ニシバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県小諸市滝原', '20', '20208', '3840045', '長野県', 'ナガノケン', '小諸市', 'コモロシ', '滝原', 'タキバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県小諸市芝生田', '20', '20208', '3840046', '長野県', 'ナガノケン', '小諸市', 'コモロシ', '芝生田', 'シボウタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県小諸市井子', '20', '20208', '3840047', '長野県', 'ナガノケン', '小諸市', 'コモロシ', '井子', 'イコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県小諸市糠地', '20', '20208', '3840048', '長野県', 'ナガノケン', '小諸市', 'コモロシ', '糠地', 'ヌカチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県小諸市八満', '20', '20208', '3840051', '長野県', 'ナガノケン', '小諸市', 'コモロシ', '八満', 'ハチマン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県小諸市東区', '20', '20208', '3840052', '長野県', 'ナガノケン', '小諸市', 'コモロシ', '東区', 'ヒガシク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県小諸市藤塚', '20', '20208', '3840053', '長野県', 'ナガノケン', '小諸市', 'コモロシ', '藤塚', 'フジツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県小諸市石峠', '20', '20208', '3840054', '長野県', 'ナガノケン', '小諸市', 'コモロシ', '石峠', 'イシトウゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県小諸市柏木', '20', '20208', '3840055', '長野県', 'ナガノケン', '小諸市', 'コモロシ', '柏木', 'カシワギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県小諸市四ツ谷', '20', '20208', '3840056', '長野県', 'ナガノケン', '小諸市', 'コモロシ', '四ツ谷', 'ヨツヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県小諸市加増', '20', '20208', '3840061', '長野県', 'ナガノケン', '小諸市', 'コモロシ', '加増', 'カマス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県小諸市荒堀', '20', '20208', '3840062', '長野県', 'ナガノケン', '小諸市', 'コモロシ', '荒堀', 'アラホリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県小諸市南ケ原', '20', '20208', '3840063', '長野県', 'ナガノケン', '小諸市', 'コモロシ', '南ケ原', 'ミナミガハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県小諸市乗瀬', '20', '20208', '3840064', '長野県', 'ナガノケン', '小諸市', 'コモロシ', '乗瀬', 'ノリセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県小諸市ひばりケ丘', '20', '20208', '3840065', '長野県', 'ナガノケン', '小諸市', 'コモロシ', 'ひばりケ丘', 'ヒバリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県小諸市大久保', '20', '20208', '3840071', '長野県', 'ナガノケン', '小諸市', 'コモロシ', '大久保', 'オオクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県小諸市鴇久保', '20', '20208', '3840072', '長野県', 'ナガノケン', '小諸市', 'コモロシ', '鴇久保', 'トキクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県小諸市西浦', '20', '20208', '3840074', '長野県', 'ナガノケン', '小諸市', 'コモロシ', '西浦', 'ニシウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県小諸市上ノ平', '20', '20208', '3840075', '長野県', 'ナガノケン', '小諸市', 'コモロシ', '上ノ平', 'ウエノダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県小諸市久保', '20', '20208', '3840076', '長野県', 'ナガノケン', '小諸市', 'コモロシ', '久保', 'クボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県小諸市大杭', '20', '20208', '3840077', '長野県', 'ナガノケン', '小諸市', 'コモロシ', '大杭', 'オオクイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県小諸市宮沢', '20', '20208', '3840078', '長野県', 'ナガノケン', '小諸市', 'コモロシ', '宮沢', 'ミヤザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県小諸市御牧ケ原', '20', '20208', '3840081', '長野県', 'ナガノケン', '小諸市', 'コモロシ', '御牧ケ原', 'ミマキガハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県小諸市諏訪山', '20', '20208', '3840082', '長野県', 'ナガノケン', '小諸市', 'コモロシ', '諏訪山', 'スワヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県小諸市市', '20', '20208', '3840083', '長野県', 'ナガノケン', '小諸市', 'コモロシ', '市', 'イチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県小諸市耳取', '20', '20208', '3840084', '長野県', 'ナガノケン', '小諸市', 'コモロシ', '耳取', 'ミミトリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県小諸市森山', '20', '20208', '3840085', '長野県', 'ナガノケン', '小諸市', 'コモロシ', '森山', 'モリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県小諸市御影', '20', '20208', '3840091', '長野県', 'ナガノケン', '小諸市', 'コモロシ', '御影', 'ミカゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県小諸市平原', '20', '20208', '3840092', '長野県', 'ナガノケン', '小諸市', 'コモロシ', '平原', 'ヒラハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県小諸市和田', '20', '20208', '3840093', '長野県', 'ナガノケン', '小諸市', 'コモロシ', '和田', 'ワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県小諸市一ツ谷', '20', '20208', '3840094', '長野県', 'ナガノケン', '小諸市', 'コモロシ', '一ツ谷', 'ヒトツヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県小諸市谷地原', '20', '20208', '3840095', '長野県', 'ナガノケン', '小諸市', 'コモロシ', '谷地原', 'ヤチハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県小諸市池ノ前', '20', '20208', '3840096', '長野県', 'ナガノケン', '小諸市', 'コモロシ', '池ノ前', 'イケノマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県吾妻郡嬬恋村鎌原高峰高原', '10', '10425', '3840097', '群馬県', 'グンマケン', '吾妻郡嬬恋村', 'アガツマグンツマゴイムラ', '鎌原', 'カンバラ', null, null, '高峰高原', 'タカミネコウゲン');
INSERT INTO `ms_addresses` VALUES ('33136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県佐久市臼田', '20', '20217', '3840301', '長野県', 'ナガノケン', '佐久市', 'サクシ', '臼田', 'ウスダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県佐久市勝間', '20', '20217', '3840302', '長野県', 'ナガノケン', '佐久市', 'サクシ', '勝間', 'カツマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県佐久市下小田切', '20', '20217', '3840303', '長野県', 'ナガノケン', '佐久市', 'サクシ', '下小田切', 'シモオタギリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県佐久市北川', '20', '20217', '3840304', '長野県', 'ナガノケン', '佐久市', 'サクシ', '北川', 'キタガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県佐久市中小田切', '20', '20217', '3840305', '長野県', 'ナガノケン', '佐久市', 'サクシ', '中小田切', 'ナカオタギリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県佐久市上小田切', '20', '20217', '3840306', '長野県', 'ナガノケン', '佐久市', 'サクシ', '上小田切', 'カミオタギリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県佐久市湯原', '20', '20217', '3840307', '長野県', 'ナガノケン', '佐久市', 'サクシ', '湯原', 'ユハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県佐久市清川', '20', '20217', '3840411', '長野県', 'ナガノケン', '佐久市', 'サクシ', '清川', 'キヨカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県佐久市田口', '20', '20217', '3840412', '長野県', 'ナガノケン', '佐久市', 'サクシ', '田口', 'タグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県佐久市三分', '20', '20217', '3840413', '長野県', 'ナガノケン', '佐久市', 'サクシ', '三分', 'ミブン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県佐久市下越', '20', '20217', '3840414', '長野県', 'ナガノケン', '佐久市', 'サクシ', '下越', 'シモゴエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県南佐久郡佐久穂町余地', '20', '20309', '3840501', '長野県', 'ナガノケン', '南佐久郡佐久穂町', 'ミナミサクグンサクホマチ', '余地', 'ヨジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県南佐久郡佐久穂町大日向', '20', '20309', '3840502', '長野県', 'ナガノケン', '南佐久郡佐久穂町', 'ミナミサクグンサクホマチ', '大日向', 'オオヒナタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県南佐久郡佐久穂町海瀬', '20', '20309', '3840503', '長野県', 'ナガノケン', '南佐久郡佐久穂町', 'ミナミサクグンサクホマチ', '海瀬', 'カイゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県南佐久郡佐久穂町', '20', '20309', '3840600', '長野県', 'ナガノケン', '南佐久郡佐久穂町', 'ミナミサクグンサクホマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('33151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県南佐久郡佐久穂町平林', '20', '20309', '3840611', '長野県', 'ナガノケン', '南佐久郡佐久穂町', 'ミナミサクグンサクホマチ', '平林', 'ヒラバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県南佐久郡佐久穂町宿岩', '20', '20309', '3840612', '長野県', 'ナガノケン', '南佐久郡佐久穂町', 'ミナミサクグンサクホマチ', '宿岩', 'ヤドイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県南佐久郡佐久穂町高野町', '20', '20309', '3840613', '長野県', 'ナガノケン', '南佐久郡佐久穂町', 'ミナミサクグンサクホマチ', '高野町', 'タカノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県南佐久郡佐久穂町上', '20', '20309', '3840614', '長野県', 'ナガノケン', '南佐久郡佐久穂町', 'ミナミサクグンサクホマチ', '上', 'カミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県佐久市入沢', '20', '20217', '3840621', '長野県', 'ナガノケン', '佐久市', 'サクシ', '入沢', 'イリサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県佐久市平林', '20', '20217', '3840622', '長野県', 'ナガノケン', '佐久市', 'サクシ', '平林', 'ヒラバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県南佐久郡佐久穂町畑', '20', '20309', '3840701', '長野県', 'ナガノケン', '南佐久郡佐久穂町', 'ミナミサクグンサクホマチ', '畑', 'ハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県南佐久郡佐久穂町穂積', '20', '20309', '3840702', '長野県', 'ナガノケン', '南佐久郡佐久穂町', 'ミナミサクグンサクホマチ', '穂積', 'ホヅミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県南佐久郡佐久穂町千代里', '20', '20309', '3840703', '長野県', 'ナガノケン', '南佐久郡佐久穂町', 'ミナミサクグンサクホマチ', '千代里', 'チヨサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県南佐久郡佐久穂町八郡', '20', '20309', '3840704', '長野県', 'ナガノケン', '南佐久郡佐久穂町', 'ミナミサクグンサクホマチ', '八郡', 'ヤコオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県小諸市甲', '20', '20208', '3840801', '長野県', 'ナガノケン', '小諸市', 'コモロシ', '甲', 'コウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県小諸市乙', '20', '20208', '3840802', '長野県', 'ナガノケン', '小諸市', 'コモロシ', '乙', 'オツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県小諸市丙', '20', '20208', '3840803', '長野県', 'ナガノケン', '小諸市', 'コモロシ', '丙', 'ヘイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県小諸市丁', '20', '20208', '3840804', '長野県', 'ナガノケン', '小諸市', 'コモロシ', '丁', 'テイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県小諸市己', '20', '20208', '3840805', '長野県', 'ナガノケン', '小諸市', 'コモロシ', '己', 'キ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県小諸市塩野', '20', '20208', '3840806', '長野県', 'ナガノケン', '小諸市', 'コモロシ', '塩野', 'シオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県小諸市山浦', '20', '20208', '3840807', '長野県', 'ナガノケン', '小諸市', 'コモロシ', '山浦', 'ヤマウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県小諸市御影新田', '20', '20208', '3840808', '長野県', 'ナガノケン', '小諸市', 'コモロシ', '御影新田', 'ミカゲシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県小諸市滋野甲', '20', '20208', '3840809', '長野県', 'ナガノケン', '小諸市', 'コモロシ', '滋野甲', 'シゲノコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県南佐久郡小海町', '20', '20303', '3841100', '長野県', 'ナガノケン', '南佐久郡小海町', 'ミナミサクグンコウミマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('33176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県南佐久郡小海町東馬流', '20', '20303', '3841101', '長野県', 'ナガノケン', '南佐久郡小海町', 'ミナミサクグンコウミマチ', '東馬流', 'ヒガシマナガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県南佐久郡小海町小海', '20', '20303', '3841102', '長野県', 'ナガノケン', '南佐久郡小海町', 'ミナミサクグンコウミマチ', '小海', 'コウミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県南佐久郡小海町豊里', '20', '20303', '3841103', '長野県', 'ナガノケン', '南佐久郡小海町', 'ミナミサクグンコウミマチ', '豊里', 'トヨサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県南佐久郡小海町稲子', '20', '20303', '3841104', '長野県', 'ナガノケン', '南佐久郡小海町', 'ミナミサクグンコウミマチ', '稲子', 'イナコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県南佐久郡小海町千代里', '20', '20303', '3841105', '長野県', 'ナガノケン', '南佐久郡小海町', 'ミナミサクグンコウミマチ', '千代里', 'チヨサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県南佐久郡北相木村', '20', '20307', '3841201', '長野県', 'ナガノケン', '南佐久郡北相木村', 'ミナミサクグンキタアイキムラ', null, '　', '（全域）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('33183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県南佐久郡南相木村', '20', '20306', '3841211', '長野県', 'ナガノケン', '南佐久郡南相木村', 'ミナミサクグンミナミアイキムラ', null, '　', '（全域）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('33184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県南佐久郡南牧村', '20', '20305', '3841300', '長野県', 'ナガノケン', '南佐久郡南牧村', 'ミナミサクグンミナミマキムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('33185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県南佐久郡南牧村海尻', '20', '20305', '3841301', '長野県', 'ナガノケン', '南佐久郡南牧村', 'ミナミサクグンミナミマキムラ', '海尻', 'ウミジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県南佐久郡南牧村海ノ口', '20', '20305', '3841302', '長野県', 'ナガノケン', '南佐久郡南牧村', 'ミナミサクグンミナミマキムラ', '海ノ口', 'ウミノクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県南佐久郡南牧村広瀬', '20', '20305', '3841303', '長野県', 'ナガノケン', '南佐久郡南牧村', 'ミナミサクグンミナミマキムラ', '広瀬', 'ヒロセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県南佐久郡南牧村板橋', '20', '20305', '3841304', '長野県', 'ナガノケン', '南佐久郡南牧村', 'ミナミサクグンミナミマキムラ', '板橋', 'イタバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県南佐久郡南牧村野辺山', '20', '20305', '3841305', '長野県', 'ナガノケン', '南佐久郡南牧村', 'ミナミサクグンミナミマキムラ', '野辺山', 'ノベヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県南佐久郡南牧村平沢', '20', '20305', '3841306', '長野県', 'ナガノケン', '南佐久郡南牧村', 'ミナミサクグンミナミマキムラ', '平沢', 'ヒラサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県南佐久郡川上村', '20', '20304', '3841400', '長野県', 'ナガノケン', '南佐久郡川上村', 'ミナミサクグンカワカミムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('33192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県南佐久郡川上村川端下', '20', '20304', '3841401', '長野県', 'ナガノケン', '南佐久郡川上村', 'ミナミサクグンカワカミムラ', '川端下', 'カワハケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県南佐久郡川上村梓山', '20', '20304', '3841402', '長野県', 'ナガノケン', '南佐久郡川上村', 'ミナミサクグンカワカミムラ', '梓山', 'アズサヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県南佐久郡川上村秋山', '20', '20304', '3841403', '長野県', 'ナガノケン', '南佐久郡川上村', 'ミナミサクグンカワカミムラ', '秋山', 'アキヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県南佐久郡川上村居倉', '20', '20304', '3841404', '長野県', 'ナガノケン', '南佐久郡川上村', 'ミナミサクグンカワカミムラ', '居倉', 'イグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県南佐久郡川上村大深山', '20', '20304', '3841405', '長野県', 'ナガノケン', '南佐久郡川上村', 'ミナミサクグンカワカミムラ', '大深山', 'オオミヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県南佐久郡川上村原', '20', '20304', '3841406', '長野県', 'ナガノケン', '南佐久郡川上村', 'ミナミサクグンカワカミムラ', '原', 'ハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県南佐久郡川上村御所平', '20', '20304', '3841407', '長野県', 'ナガノケン', '南佐久郡川上村', 'ミナミサクグンカワカミムラ', '御所平', 'ゴショダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県南佐久郡川上村樋沢', '20', '20304', '3841408', '長野県', 'ナガノケン', '南佐久郡川上村', 'ミナミサクグンカワカミムラ', '樋沢', 'ヒサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県佐久市桑山', '20', '20217', '3842101', '長野県', 'ナガノケン', '佐久市', 'サクシ', '桑山', 'クワヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県佐久市塩名田', '20', '20217', '3842102', '長野県', 'ナガノケン', '佐久市', 'サクシ', '塩名田', 'シオナダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県佐久市御馬寄', '20', '20217', '3842103', '長野県', 'ナガノケン', '佐久市', 'サクシ', '御馬寄', 'ミマヨセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県佐久市甲', '20', '20217', '3842104', '長野県', 'ナガノケン', '佐久市', 'サクシ', '甲', 'コウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県佐久市矢島', '20', '20217', '3842105', '長野県', 'ナガノケン', '佐久市', 'サクシ', '矢島', 'ヤシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県佐久市八幡', '20', '20217', '3842106', '長野県', 'ナガノケン', '佐久市', 'サクシ', '八幡', 'ヤワタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県佐久市蓬田', '20', '20217', '3842107', '長野県', 'ナガノケン', '佐久市', 'サクシ', '蓬田', 'ヨモギダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県佐久市印内', '20', '20217', '3842201', '長野県', 'ナガノケン', '佐久市', 'サクシ', '印内', 'インナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県佐久市望月', '20', '20217', '3842202', '長野県', 'ナガノケン', '佐久市', 'サクシ', '望月', 'モチヅキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県佐久市布施', '20', '20217', '3842203', '長野県', 'ナガノケン', '佐久市', 'サクシ', '布施', 'フセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県佐久市協和', '20', '20217', '3842204', '長野県', 'ナガノケン', '佐久市', 'サクシ', '協和', 'キョウワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県佐久市春日', '20', '20217', '3842205', '長野県', 'ナガノケン', '佐久市', 'サクシ', '春日', 'カスガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県佐久市茂田井', '20', '20217', '3842206', '長野県', 'ナガノケン', '佐久市', 'サクシ', '茂田井', 'モタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県北佐久郡立科町茂田井', '20', '20324', '3842211', '長野県', 'ナガノケン', '北佐久郡立科町', 'キタサクグンタテシナマチ', '茂田井', 'モタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県北佐久郡立科町', '20', '20324', '3842300', '長野県', 'ナガノケン', '北佐久郡立科町', 'キタサクグンタテシナマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('33216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県北佐久郡立科町桐原', '20', '20324', '3842301', '長野県', 'ナガノケン', '北佐久郡立科町', 'キタサクグンタテシナマチ', '桐原', 'キリハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県北佐久郡立科町藤沢', '20', '20324', '3842302', '長野県', 'ナガノケン', '北佐久郡立科町', 'キタサクグンタテシナマチ', '藤沢', 'フジサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県北佐久郡立科町塩沢', '20', '20324', '3842303', '長野県', 'ナガノケン', '北佐久郡立科町', 'キタサクグンタテシナマチ', '塩沢', 'シオサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県北佐久郡立科町茂田井', '20', '20324', '3842304', '長野県', 'ナガノケン', '北佐久郡立科町', 'キタサクグンタテシナマチ', '茂田井', 'モタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県北佐久郡立科町芦田', '20', '20324', '3842305', '長野県', 'ナガノケン', '北佐久郡立科町', 'キタサクグンタテシナマチ', '芦田', 'アシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県北佐久郡立科町宇山', '20', '20324', '3842306', '長野県', 'ナガノケン', '北佐久郡立科町', 'キタサクグンタテシナマチ', '宇山', 'ウヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県北佐久郡立科町山部', '20', '20324', '3842307', '長野県', 'ナガノケン', '北佐久郡立科町', 'キタサクグンタテシナマチ', '山部', 'ヤマベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県北佐久郡立科町牛鹿', '20', '20324', '3842308', '長野県', 'ナガノケン', '北佐久郡立科町', 'キタサクグンタテシナマチ', '牛鹿', 'ウシロク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県北佐久郡立科町芦田八ケ野', '20', '20324', '3842309', '長野県', 'ナガノケン', '北佐久郡立科町', 'キタサクグンタテシナマチ', '芦田八ケ野', 'アシダハッカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県佐久市', '20', '20217', '3850000', '長野県', 'ナガノケン', '佐久市', 'サクシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('33231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県佐久市横根', '20', '20217', '3850001', '長野県', 'ナガノケン', '佐久市', 'サクシ', '横根', 'ヨコネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県佐久市上平尾', '20', '20217', '3850002', '長野県', 'ナガノケン', '佐久市', 'サクシ', '上平尾', 'カミヒラオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県佐久市下平尾', '20', '20217', '3850003', '長野県', 'ナガノケン', '佐久市', 'サクシ', '下平尾', 'シモヒラオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県佐久市安原', '20', '20217', '3850004', '長野県', 'ナガノケン', '佐久市', 'サクシ', '安原', 'ヤスハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県佐久市香坂', '20', '20217', '3850005', '長野県', 'ナガノケン', '佐久市', 'サクシ', '香坂', 'コウサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県佐久市志賀', '20', '20217', '3850006', '長野県', 'ナガノケン', '佐久市', 'サクシ', '志賀', 'シガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県佐久市新子田', '20', '20217', '3850007', '長野県', 'ナガノケン', '佐久市', 'サクシ', '新子田', 'アラコダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県佐久市小田井', '20', '20217', '3850009', '長野県', 'ナガノケン', '佐久市', 'サクシ', '小田井', 'オタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県佐久市猿久保', '20', '20217', '3850011', '長野県', 'ナガノケン', '佐久市', 'サクシ', '猿久保', 'サルクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県佐久市根々井', '20', '20217', '3850012', '長野県', 'ナガノケン', '佐久市', 'サクシ', '根々井', 'ネネイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県佐久市横和', '20', '20217', '3850013', '長野県', 'ナガノケン', '佐久市', 'サクシ', '横和', 'ヨコワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県佐久市三河田', '20', '20217', '3850014', '長野県', 'ナガノケン', '佐久市', 'サクシ', '三河田', 'ミカワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県佐久市今井', '20', '20217', '3850015', '長野県', 'ナガノケン', '佐久市', 'サクシ', '今井', 'イマイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県佐久市鳴瀬', '20', '20217', '3850016', '長野県', 'ナガノケン', '佐久市', 'サクシ', '鳴瀬', 'ナルセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県佐久市長土呂', '20', '20217', '3850021', '長野県', 'ナガノケン', '佐久市', 'サクシ', '長土呂', 'ナガトロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県佐久市岩村田', '20', '20217', '3850022', '長野県', 'ナガノケン', '佐久市', 'サクシ', '岩村田', 'イワムラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県佐久市岩村田北', '20', '20217', '3850023', '長野県', 'ナガノケン', '佐久市', 'サクシ', '岩村田北', 'イワムラダキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県佐久市平塚', '20', '20217', '3850024', '長野県', 'ナガノケン', '佐久市', 'サクシ', '平塚', 'ヒラツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県佐久市塚原', '20', '20217', '3850025', '長野県', 'ナガノケン', '佐久市', 'サクシ', '塚原', 'ツカバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県佐久市常田', '20', '20217', '3850026', '長野県', 'ナガノケン', '佐久市', 'サクシ', '常田', 'トキダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県佐久市佐久平駅北', '20', '20217', '3850027', '長野県', 'ナガノケン', '佐久市', 'サクシ', '佐久平駅北', 'サクダイラエキキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県佐久市佐久平駅東', '20', '20217', '3850028', '長野県', 'ナガノケン', '佐久市', 'サクシ', '佐久平駅東', 'サクダイラエキヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県佐久市佐久平駅南', '20', '20217', '3850029', '長野県', 'ナガノケン', '佐久市', 'サクシ', '佐久平駅南', 'サクダイラエキミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県佐久市内山', '20', '20217', '3850031', '長野県', 'ナガノケン', '佐久市', 'サクシ', '内山', 'ウチヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県佐久市常和', '20', '20217', '3850032', '長野県', 'ナガノケン', '佐久市', 'サクシ', '常和', 'トキワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県佐久市太田部', '20', '20217', '3850033', '長野県', 'ナガノケン', '佐久市', 'サクシ', '太田部', 'オオタベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県佐久市平賀', '20', '20217', '3850034', '長野県', 'ナガノケン', '佐久市', 'サクシ', '平賀', 'ヒラカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県佐久市瀬戸', '20', '20217', '3850035', '長野県', 'ナガノケン', '佐久市', 'サクシ', '瀬戸', 'セト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県佐久市鍛冶屋', '20', '20217', '3850041', '長野県', 'ナガノケン', '佐久市', 'サクシ', '鍛冶屋', 'カジヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県佐久市高柳', '20', '20217', '3850042', '長野県', 'ナガノケン', '佐久市', 'サクシ', '高柳', 'タカヤギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県佐久市取出町', '20', '20217', '3850043', '長野県', 'ナガノケン', '佐久市', 'サクシ', '取出町', 'トリデマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県佐久市本新町', '20', '20217', '3850044', '長野県', 'ナガノケン', '佐久市', 'サクシ', '本新町', 'ホンシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県佐久市大沢', '20', '20217', '3850045', '長野県', 'ナガノケン', '佐久市', 'サクシ', '大沢', 'オオサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県佐久市前山', '20', '20217', '3850046', '長野県', 'ナガノケン', '佐久市', 'サクシ', '前山', 'マエヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県佐久市小宮山', '20', '20217', '3850047', '長野県', 'ナガノケン', '佐久市', 'サクシ', '小宮山', 'コミヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県佐久市中込', '20', '20217', '3850051', '長野県', 'ナガノケン', '佐久市', 'サクシ', '中込', 'ナカゴミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県佐久市原', '20', '20217', '3850052', '長野県', 'ナガノケン', '佐久市', 'サクシ', '原', 'ハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県佐久市野沢', '20', '20217', '3850053', '長野県', 'ナガノケン', '佐久市', 'サクシ', '野沢', 'ノザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県佐久市跡部', '20', '20217', '3850054', '長野県', 'ナガノケン', '佐久市', 'サクシ', '跡部', 'アトベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県佐久市三塚', '20', '20217', '3850055', '長野県', 'ナガノケン', '佐久市', 'サクシ', '三塚', 'ミチヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県佐久市桜井', '20', '20217', '3850056', '長野県', 'ナガノケン', '佐久市', 'サクシ', '桜井', 'サクライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県佐久市伴野', '20', '20217', '3850061', '長野県', 'ナガノケン', '佐久市', 'サクシ', '伴野', 'トモノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県佐久市根岸', '20', '20217', '3850062', '長野県', 'ナガノケン', '佐久市', 'サクシ', '根岸', 'ネギシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県佐久市東立科', '20', '20217', '3850063', '長野県', 'ナガノケン', '佐久市', 'サクシ', '東立科', 'ヒガシタテシナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上田市', '20', '20203', '3860000', '長野県', 'ナガノケン', '上田市', 'ウエダシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('33305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上田市上田', '20', '20203', '3860001', '長野県', 'ナガノケン', '上田市', 'ウエダシ', '上田', 'ウエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上田市住吉', '20', '20203', '3860002', '長野県', 'ナガノケン', '上田市', 'ウエダシ', '住吉', 'スミヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上田市上野', '20', '20203', '3860003', '長野県', 'ナガノケン', '上田市', 'ウエダシ', '上野', 'ウエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上田市殿城', '20', '20203', '3860004', '長野県', 'ナガノケン', '上田市', 'ウエダシ', '殿城', 'トノシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上田市古里', '20', '20203', '3860005', '長野県', 'ナガノケン', '上田市', 'ウエダシ', '古里', 'コサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上田市漆戸', '20', '20203', '3860006', '長野県', 'ナガノケン', '上田市', 'ウエダシ', '漆戸', 'ウルシド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上田市中央北', '20', '20203', '3860011', '長野県', 'ナガノケン', '上田市', 'ウエダシ', '中央北', 'チュウオウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上田市中央', '20', '20203', '3860012', '長野県', 'ナガノケン', '上田市', 'ウエダシ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上田市中央東', '20', '20203', '3860013', '長野県', 'ナガノケン', '上田市', 'ウエダシ', '中央東', 'チュウオウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上田市材木町', '20', '20203', '3860014', '長野県', 'ナガノケン', '上田市', 'ウエダシ', '材木町', 'ザイモクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上田市常入', '20', '20203', '3860015', '長野県', 'ナガノケン', '上田市', 'ウエダシ', '常入', 'トキイリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上田市国分', '20', '20203', '3860016', '長野県', 'ナガノケン', '上田市', 'ウエダシ', '国分', 'コクブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上田市踏入', '20', '20203', '3860017', '長野県', 'ナガノケン', '上田市', 'ウエダシ', '踏入', 'フミイリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上田市常田', '20', '20203', '3860018', '長野県', 'ナガノケン', '上田市', 'ウエダシ', '常田', 'トキダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上田市緑が丘', '20', '20203', '3860022', '長野県', 'ナガノケン', '上田市', 'ウエダシ', '緑が丘', 'ミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上田市中央西', '20', '20203', '3860023', '長野県', 'ナガノケン', '上田市', 'ウエダシ', '中央西', 'チュウオウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上田市大手', '20', '20203', '3860024', '長野県', 'ナガノケン', '上田市', 'ウエダシ', '大手', 'オオテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上田市天神', '20', '20203', '3860025', '長野県', 'ナガノケン', '上田市', 'ウエダシ', '天神', 'テンジン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上田市二の丸', '20', '20203', '3860026', '長野県', 'ナガノケン', '上田市', 'ウエダシ', '二の丸', 'ニノマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上田市常磐城', '20', '20203', '3860027', '長野県', 'ナガノケン', '上田市', 'ウエダシ', '常磐城', 'トキワギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上田市小牧', '20', '20203', '3860031', '長野県', 'ナガノケン', '上田市', 'ウエダシ', '小牧', 'コマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上田市諏訪形', '20', '20203', '3860032', '長野県', 'ナガノケン', '上田市', 'ウエダシ', '諏訪形', 'スワガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上田市御所', '20', '20203', '3860033', '長野県', 'ナガノケン', '上田市', 'ウエダシ', '御所', 'ゴショ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上田市中之条', '20', '20203', '3860034', '長野県', 'ナガノケン', '上田市', 'ウエダシ', '中之条', 'ナカノジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上田市秋和', '20', '20203', '3860041', '長野県', 'ナガノケン', '上田市', 'ウエダシ', '秋和', 'アキワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上田市上塩尻', '20', '20203', '3860042', '長野県', 'ナガノケン', '上田市', 'ウエダシ', '上塩尻', 'カミシオジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上田市下塩尻', '20', '20203', '3860043', '長野県', 'ナガノケン', '上田市', 'ウエダシ', '下塩尻', 'シモシオジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上田市芳田', '20', '20203', '3860151', '長野県', 'ナガノケン', '上田市', 'ウエダシ', '芳田', 'ヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上田市大屋', '20', '20203', '3860152', '長野県', 'ナガノケン', '上田市', 'ウエダシ', '大屋', 'オオヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上田市岩下', '20', '20203', '3860153', '長野県', 'ナガノケン', '上田市', 'ウエダシ', '岩下', 'イワシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上田市蒼久保', '20', '20203', '3860155', '長野県', 'ナガノケン', '上田市', 'ウエダシ', '蒼久保', 'アオクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上田市林之郷', '20', '20203', '3860156', '長野県', 'ナガノケン', '上田市', 'ウエダシ', '林之郷', 'ハヤシノゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上田市平井', '20', '20203', '3860321', '長野県', 'ナガノケン', '上田市', 'ウエダシ', '平井', 'ヒライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上田市西内', '20', '20203', '3860322', '長野県', 'ナガノケン', '上田市', 'ウエダシ', '西内', 'ニシウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上田市鹿教湯温泉', '20', '20203', '3860323', '長野県', 'ナガノケン', '上田市', 'ウエダシ', '鹿教湯温泉', 'カケユオンセン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上田市塩川', '20', '20203', '3860401', '長野県', 'ナガノケン', '上田市', 'ウエダシ', '塩川', 'シオカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上田市藤原田', '20', '20203', '3860402', '長野県', 'ナガノケン', '上田市', 'ウエダシ', '藤原田', 'フジワラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上田市腰越', '20', '20203', '3860403', '長野県', 'ナガノケン', '上田市', 'ウエダシ', '腰越', 'コシゴエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上田市上丸子', '20', '20203', '3860404', '長野県', 'ナガノケン', '上田市', 'ウエダシ', '上丸子', 'カミマルコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上田市中丸子', '20', '20203', '3860405', '長野県', 'ナガノケン', '上田市', 'ウエダシ', '中丸子', 'ナカマルコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上田市下丸子', '20', '20203', '3860406', '長野県', 'ナガノケン', '上田市', 'ウエダシ', '下丸子', 'シモマルコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上田市長瀬', '20', '20203', '3860407', '長野県', 'ナガノケン', '上田市', 'ウエダシ', '長瀬', 'ナガセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上田市本海野', '20', '20203', '3860408', '長野県', 'ナガノケン', '上田市', 'ウエダシ', '本海野', 'モトウンノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上田市生田', '20', '20203', '3860411', '長野県', 'ナガノケン', '上田市', 'ウエダシ', '生田', 'イクタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上田市御嶽堂', '20', '20203', '3860412', '長野県', 'ナガノケン', '上田市', 'ウエダシ', '御嶽堂', 'ミタケドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上田市東内', '20', '20203', '3860413', '長野県', 'ナガノケン', '上田市', 'ウエダシ', '東内', 'ヒガシウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上田市武石鳥屋', '20', '20203', '3860501', '長野県', 'ナガノケン', '上田市', 'ウエダシ', '武石鳥屋', 'タケシトヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上田市武石沖', '20', '20203', '3860502', '長野県', 'ナガノケン', '上田市', 'ウエダシ', '武石沖', 'タケシオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上田市下武石', '20', '20203', '3860503', '長野県', 'ナガノケン', '上田市', 'ウエダシ', '下武石', 'シモタケシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上田市武石小沢根', '20', '20203', '3860504', '長野県', 'ナガノケン', '上田市', 'ウエダシ', '武石小沢根', 'タケシオザワネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上田市武石余里', '20', '20203', '3860505', '長野県', 'ナガノケン', '上田市', 'ウエダシ', '武石余里', 'タケシヨリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上田市武石下本入', '20', '20203', '3860506', '長野県', 'ナガノケン', '上田市', 'ウエダシ', '武石下本入', 'タケシシモホンイリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上田市武石上本入', '20', '20203', '3860507', '長野県', 'ナガノケン', '上田市', 'ウエダシ', '武石上本入', 'タケシカミホンイリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上田市上武石', '20', '20203', '3860508', '長野県', 'ナガノケン', '上田市', 'ウエダシ', '上武石', 'カミタケシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県小県郡長和町', '20', '20350', '3860600', '長野県', 'ナガノケン', '小県郡長和町', 'チイサガタグンナガワマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('33369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県小県郡長和町大門', '20', '20350', '3860601', '長野県', 'ナガノケン', '小県郡長和町', 'チイサガタグンナガワマチ', '大門', 'ダイモン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県小県郡長和町長久保', '20', '20350', '3860602', '長野県', 'ナガノケン', '小県郡長和町', 'チイサガタグンナガワマチ', '長久保', 'ナガクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県小県郡長和町古町', '20', '20350', '3860603', '長野県', 'ナガノケン', '小県郡長和町', 'チイサガタグンナガワマチ', '古町', 'フルマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県小県郡長和町和田', '20', '20350', '3860701', '長野県', 'ナガノケン', '小県郡長和町', 'チイサガタグンナガワマチ', '和田', 'ワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上田市下之条', '20', '20203', '3861101', '長野県', 'ナガノケン', '上田市', 'ウエダシ', '下之条', 'シモノジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上田市上田原', '20', '20203', '3861102', '長野県', 'ナガノケン', '上田市', 'ウエダシ', '上田原', 'ウエダハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上田市神畑', '20', '20203', '3861103', '長野県', 'ナガノケン', '上田市', 'ウエダシ', '神畑', 'カバタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上田市福田', '20', '20203', '3861104', '長野県', 'ナガノケン', '上田市', 'ウエダシ', '福田', 'フクタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上田市吉田', '20', '20203', '3861105', '長野県', 'ナガノケン', '上田市', 'ウエダシ', '吉田', 'ヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上田市小泉', '20', '20203', '3861106', '長野県', 'ナガノケン', '上田市', 'ウエダシ', '小泉', 'コイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上田市築地', '20', '20203', '3861107', '長野県', 'ナガノケン', '上田市', 'ウエダシ', '築地', 'ツイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上田市神畑乙', '20', '20203', '3861108', '長野県', 'ナガノケン', '上田市', 'ウエダシ', '神畑乙', 'カバタケオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上田市下之郷', '20', '20203', '3861211', '長野県', 'ナガノケン', '上田市', 'ウエダシ', '下之郷', 'シモノゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上田市富士山', '20', '20203', '3861212', '長野県', 'ナガノケン', '上田市', 'ウエダシ', '富士山', 'フジヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上田市古安曽', '20', '20203', '3861213', '長野県', 'ナガノケン', '上田市', 'ウエダシ', '古安曽', 'コアソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上田市下之郷乙', '20', '20203', '3861214', '長野県', 'ナガノケン', '上田市', 'ウエダシ', '下之郷乙', 'シモノゴウオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上田市保野', '20', '20203', '3861321', '長野県', 'ナガノケン', '上田市', 'ウエダシ', '保野', 'ホヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上田市小島', '20', '20203', '3861322', '長野県', 'ナガノケン', '上田市', 'ウエダシ', '小島', 'コジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上田市本郷', '20', '20203', '3861323', '長野県', 'ナガノケン', '上田市', 'ウエダシ', '本郷', 'ホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上田市五加', '20', '20203', '3861324', '長野県', 'ナガノケン', '上田市', 'ウエダシ', '五加', 'ゴカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上田市中野', '20', '20203', '3861325', '長野県', 'ナガノケン', '上田市', 'ウエダシ', '中野', 'ナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上田市舞田', '20', '20203', '3861326', '長野県', 'ナガノケン', '上田市', 'ウエダシ', '舞田', 'マイタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上田市八木沢', '20', '20203', '3861327', '長野県', 'ナガノケン', '上田市', 'ウエダシ', '八木沢', 'ヤギサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上田市別所温泉', '20', '20203', '3861431', '長野県', 'ナガノケン', '上田市', 'ウエダシ', '別所温泉', 'ベッショオンセン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上田市山田', '20', '20203', '3861432', '長野県', 'ナガノケン', '上田市', 'ウエダシ', '山田', 'ヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上田市手塚', '20', '20203', '3861433', '長野県', 'ナガノケン', '上田市', 'ウエダシ', '手塚', 'テヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上田市新町', '20', '20203', '3861434', '長野県', 'ナガノケン', '上田市', 'ウエダシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上田市十人', '20', '20203', '3861435', '長野県', 'ナガノケン', '上田市', 'ウエダシ', '十人', 'ジュウニン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上田市前山', '20', '20203', '3861436', '長野県', 'ナガノケン', '上田市', 'ウエダシ', '前山', 'マエヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上田市野倉', '20', '20203', '3861437', '長野県', 'ナガノケン', '上田市', 'ウエダシ', '野倉', 'ノグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上田市上室賀', '20', '20203', '3861541', '長野県', 'ナガノケン', '上田市', 'ウエダシ', '上室賀', 'カミムロガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上田市下室賀', '20', '20203', '3861542', '長野県', 'ナガノケン', '上田市', 'ウエダシ', '下室賀', 'シモムロガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上田市岡', '20', '20203', '3861543', '長野県', 'ナガノケン', '上田市', 'ウエダシ', '岡', 'オカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上田市仁古田', '20', '20203', '3861544', '長野県', 'ナガノケン', '上田市', 'ウエダシ', '仁古田', 'ニコダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上田市越戸', '20', '20203', '3861545', '長野県', 'ナガノケン', '上田市', 'ウエダシ', '越戸', 'コウド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上田市浦野', '20', '20203', '3861546', '長野県', 'ナガノケン', '上田市', 'ウエダシ', '浦野', 'ウラノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県小県郡青木村', '20', '20349', '3861600', '長野県', 'ナガノケン', '小県郡青木村', 'チイサガタグンアオキムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('33411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県小県郡青木村田沢', '20', '20349', '3861601', '長野県', 'ナガノケン', '小県郡青木村', 'チイサガタグンアオキムラ', '田沢', 'タザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県小県郡青木村村松', '20', '20349', '3861602', '長野県', 'ナガノケン', '小県郡青木村', 'チイサガタグンアオキムラ', '村松', 'ムラマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県小県郡青木村当郷', '20', '20349', '3861603', '長野県', 'ナガノケン', '小県郡青木村', 'チイサガタグンアオキムラ', '当郷', 'トウゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県小県郡青木村殿戸', '20', '20349', '3861604', '長野県', 'ナガノケン', '小県郡青木村', 'チイサガタグンアオキムラ', '殿戸', 'トノド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県小県郡青木村夫神', '20', '20349', '3861605', '長野県', 'ナガノケン', '小県郡青木村', 'チイサガタグンアオキムラ', '夫神', 'オカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県小県郡青木村沓掛', '20', '20349', '3861606', '長野県', 'ナガノケン', '小県郡青木村', 'チイサガタグンアオキムラ', '沓掛', 'クツカケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県小県郡青木村奈良本', '20', '20349', '3861607', '長野県', 'ナガノケン', '小県郡青木村', 'チイサガタグンアオキムラ', '奈良本', 'ナラモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上田市真田町長', '20', '20203', '3862201', '長野県', 'ナガノケン', '上田市', 'ウエダシ', '真田町長', 'サナダマチオサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上田市真田町本原', '20', '20203', '3862202', '長野県', 'ナガノケン', '上田市', 'ウエダシ', '真田町本原', 'サナダマチモトハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上田市真田町傍陽', '20', '20203', '3862203', '長野県', 'ナガノケン', '上田市', 'ウエダシ', '真田町傍陽', 'サナダマチソエヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上田市菅平高原', '20', '20203', '3862204', '長野県', 'ナガノケン', '上田市', 'ウエダシ', '菅平高原', 'スガダイラコウゲン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県須坂市仁礼町仙仁山', '20', '20207', '3862211', '長野県', 'ナガノケン', '須坂市', 'スザカシ', '仁礼町', 'ニレイチョウ', null, null, '仙仁山', 'ニレイヤマ');
INSERT INTO `ms_addresses` VALUES ('33423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県須坂市仁礼町峰の原', '20', '20207', '3862211', '長野県', 'ナガノケン', '須坂市', 'スザカシ', '仁礼町', 'ニレイチョウ', null, null, '峰の原', 'ミネノハラ');
INSERT INTO `ms_addresses` VALUES ('33465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県千曲市', '20', '20218', '3870000', '長野県', 'ナガノケン', '千曲市', 'チクマシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('33466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県千曲市雨宮', '20', '20218', '3870001', '長野県', 'ナガノケン', '千曲市', 'チクマシ', '雨宮', 'アメノミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県千曲市土口', '20', '20218', '3870002', '長野県', 'ナガノケン', '千曲市', 'チクマシ', '土口', 'ドグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県千曲市生萱', '20', '20218', '3870003', '長野県', 'ナガノケン', '千曲市', 'チクマシ', '生萱', 'イキガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県千曲市倉科', '20', '20218', '3870004', '長野県', 'ナガノケン', '千曲市', 'チクマシ', '倉科', 'クラシナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県千曲市森', '20', '20218', '3870005', '長野県', 'ナガノケン', '千曲市', 'チクマシ', '森', 'モリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県千曲市粟佐', '20', '20218', '3870006', '長野県', 'ナガノケン', '千曲市', 'チクマシ', '粟佐', 'アワサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県千曲市屋代', '20', '20218', '3870007', '長野県', 'ナガノケン', '千曲市', 'チクマシ', '屋代', 'ヤシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県千曲市杭瀬下', '20', '20218', '3870011', '長野県', 'ナガノケン', '千曲市', 'チクマシ', '杭瀬下', 'クイセケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県千曲市桜堂', '20', '20218', '3870012', '長野県', 'ナガノケン', '千曲市', 'チクマシ', '桜堂', 'サクラドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県千曲市小島', '20', '20218', '3870013', '長野県', 'ナガノケン', '千曲市', 'チクマシ', '小島', 'オジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県千曲市打沢', '20', '20218', '3870014', '長野県', 'ナガノケン', '千曲市', 'チクマシ', '打沢', 'ウッサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県千曲市鋳物師屋', '20', '20218', '3870015', '長野県', 'ナガノケン', '千曲市', 'チクマシ', '鋳物師屋', 'イモジヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県千曲市寂蒔', '20', '20218', '3870016', '長野県', 'ナガノケン', '千曲市', 'チクマシ', '寂蒔', 'ジャクマク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県千曲市中', '20', '20218', '3870017', '長野県', 'ナガノケン', '千曲市', 'チクマシ', '中', 'ナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県千曲市新田', '20', '20218', '3870018', '長野県', 'ナガノケン', '千曲市', 'チクマシ', '新田', 'シンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県千曲市稲荷山', '20', '20218', '3870021', '長野県', 'ナガノケン', '千曲市', 'チクマシ', '稲荷山', 'イナリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県千曲市野高場', '20', '20218', '3870022', '長野県', 'ナガノケン', '千曲市', 'チクマシ', '野高場', 'ノタカバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県千曲市八幡', '20', '20218', '3870023', '長野県', 'ナガノケン', '千曲市', 'チクマシ', '八幡', 'ヤワタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県千曲市桑原', '20', '20218', '3870024', '長野県', 'ナガノケン', '千曲市', 'チクマシ', '桑原', 'クワバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市東犀南', '20', '20201', '3888001', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '東犀南', 'ヒガシサイナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市篠ノ井東福寺', '20', '20201', '3888002', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '篠ノ井東福寺', 'シノノイトウフクジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市篠ノ井小森', '20', '20201', '3888003', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '篠ノ井小森', 'シノノイコモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市篠ノ井会', '20', '20201', '3888004', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '篠ノ井会', 'シノノイアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市篠ノ井横田', '20', '20201', '3888005', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '篠ノ井横田', 'シノノイヨコタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市篠ノ井御幣川', '20', '20201', '3888006', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '篠ノ井御幣川', 'シノノイオンベガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市篠ノ井布施高田', '20', '20201', '3888007', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '篠ノ井布施高田', 'シノノイフセタカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市合戦場', '20', '20201', '3888008', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '合戦場', 'カッセンバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市篠ノ井布施五明', '20', '20201', '3888011', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '篠ノ井布施五明', 'シノノイフセゴミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市篠ノ井二ツ柳', '20', '20201', '3888012', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '篠ノ井二ツ柳', 'シノノイフタツヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市みこと川', '20', '20201', '3888013', '長野県', 'ナガノケン', '長野市', 'ナガノシ', 'みこと川', 'ミコトガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市篠ノ井塩崎', '20', '20201', '3888014', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '篠ノ井塩崎', 'シノノイシオザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市篠ノ井石川', '20', '20201', '3888015', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '篠ノ井石川', 'シノノイイシカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市篠ノ井有旅', '20', '20201', '3888016', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '篠ノ井有旅', 'シノノイウタビ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市篠ノ井山布施', '20', '20201', '3888017', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '篠ノ井山布施', 'シノノイヤマブセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市篠ノ井西寺尾', '20', '20201', '3888018', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '篠ノ井西寺尾', 'シノノイニシデラオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市篠ノ井杵淵', '20', '20201', '3888019', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '篠ノ井杵淵', 'シノノイキネブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市神明', '20', '20201', '3888020', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '神明', 'シンメイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県北佐久郡軽井沢町', '20', '20321', '3890100', '長野県', 'ナガノケン', '北佐久郡軽井沢町', 'キタサクグンカルイザワマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('33525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県北佐久郡軽井沢町峠町', '20', '20321', '3890101', '長野県', 'ナガノケン', '北佐久郡軽井沢町', 'キタサクグンカルイザワマチ', '峠町', 'トウゲマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県北佐久郡軽井沢町軽井沢', '20', '20321', '3890102', '長野県', 'ナガノケン', '北佐久郡軽井沢町', 'キタサクグンカルイザワマチ', '軽井沢', 'カルイザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県北佐久郡軽井沢町軽井沢', '20', '20321', '3890103', '長野県', 'ナガノケン', '北佐久郡軽井沢町', 'キタサクグンカルイザワマチ', '軽井沢', 'カルイザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県北佐久郡軽井沢町軽井沢東', '20', '20321', '3890104', '長野県', 'ナガノケン', '北佐久郡軽井沢町', 'キタサクグンカルイザワマチ', '軽井沢東', 'カルイザワヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県北佐久郡軽井沢町長倉', '20', '20321', '3890111', '長野県', 'ナガノケン', '北佐久郡軽井沢町', 'キタサクグンカルイザワマチ', '長倉', 'ナガクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県北佐久郡軽井沢町中軽井沢', '20', '20321', '3890112', '長野県', 'ナガノケン', '北佐久郡軽井沢町', 'キタサクグンカルイザワマチ', '中軽井沢', 'ナカカルイザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県北佐久郡軽井沢町発地', '20', '20321', '3890113', '長野県', 'ナガノケン', '北佐久郡軽井沢町', 'キタサクグンカルイザワマチ', '発地', 'ホッチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県北佐久郡軽井沢町茂沢', '20', '20321', '3890114', '長野県', 'ナガノケン', '北佐久郡軽井沢町', 'キタサクグンカルイザワマチ', '茂沢', 'モザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県北佐久郡軽井沢町追分', '20', '20321', '3890115', '長野県', 'ナガノケン', '北佐久郡軽井沢町', 'キタサクグンカルイザワマチ', '追分', 'オイワケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '群馬県安中市松井田町峠', '10', '10211', '3890121', '群馬県', 'グンマケン', '安中市', 'アンナカシ', '松井田町峠', 'マツイダマチトウゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県北佐久郡御代田町', '20', '20323', '3890200', '長野県', 'ナガノケン', '北佐久郡御代田町', 'キタサクグンミヨタマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('33543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県北佐久郡御代田町塩野', '20', '20323', '3890201', '長野県', 'ナガノケン', '北佐久郡御代田町', 'キタサクグンミヨタマチ', '塩野', 'シオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県北佐久郡御代田町草越', '20', '20323', '3890202', '長野県', 'ナガノケン', '北佐久郡御代田町', 'キタサクグンミヨタマチ', '草越', 'クサゴエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県北佐久郡御代田町広戸', '20', '20323', '3890203', '長野県', 'ナガノケン', '北佐久郡御代田町', 'キタサクグンミヨタマチ', '広戸', 'ヒロト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県北佐久郡御代田町豊昇', '20', '20323', '3890204', '長野県', 'ナガノケン', '北佐久郡御代田町', 'キタサクグンミヨタマチ', '豊昇', 'ホウショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県北佐久郡御代田町面替', '20', '20323', '3890205', '長野県', 'ナガノケン', '北佐久郡御代田町', 'キタサクグンミヨタマチ', '面替', 'オモガエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県北佐久郡御代田町御代田', '20', '20323', '3890206', '長野県', 'ナガノケン', '北佐久郡御代田町', 'キタサクグンミヨタマチ', '御代田', 'ミヨタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県北佐久郡御代田町馬瀬口', '20', '20323', '3890207', '長野県', 'ナガノケン', '北佐久郡御代田町', 'キタサクグンミヨタマチ', '馬瀬口', 'マセグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県北佐久郡御代田町茂沢', '20', '20323', '3890208', '長野県', 'ナガノケン', '北佐久郡御代田町', 'キタサクグンミヨタマチ', '茂沢', 'モサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県東御市島川原', '20', '20219', '3890401', '長野県', 'ナガノケン', '東御市', 'トウミシ', '島川原', 'シマガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県東御市布下', '20', '20219', '3890402', '長野県', 'ナガノケン', '東御市', 'トウミシ', '布下', 'ヌノシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県東御市御牧原', '20', '20219', '3890403', '長野県', 'ナガノケン', '東御市', 'トウミシ', '御牧原', 'ミマキハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県東御市大日向', '20', '20219', '3890404', '長野県', 'ナガノケン', '東御市', 'トウミシ', '大日向', 'オオヒナタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県東御市下之城', '20', '20219', '3890405', '長野県', 'ナガノケン', '東御市', 'トウミシ', '下之城', 'シモノジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県東御市八重原', '20', '20219', '3890406', '長野県', 'ナガノケン', '東御市', 'トウミシ', '八重原', 'ヤエハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県東御市羽毛山', '20', '20219', '3890407', '長野県', 'ナガノケン', '東御市', 'トウミシ', '羽毛山', 'ハケヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県東御市', '20', '20219', '3890500', '長野県', 'ナガノケン', '東御市', 'トウミシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('33564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県東御市新張', '20', '20219', '3890501', '長野県', 'ナガノケン', '東御市', 'トウミシ', '新張', 'ミハリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県東御市鞍掛', '20', '20219', '3890502', '長野県', 'ナガノケン', '東御市', 'トウミシ', '鞍掛', 'クラカケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県東御市新屋', '20', '20219', '3890503', '長野県', 'ナガノケン', '東御市', 'トウミシ', '新屋', 'アラヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県東御市海善寺', '20', '20219', '3890504', '長野県', 'ナガノケン', '東御市', 'トウミシ', '海善寺', 'カイゼンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県東御市和', '20', '20219', '3890505', '長野県', 'ナガノケン', '東御市', 'トウミシ', '和', 'カノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県東御市祢津', '20', '20219', '3890506', '長野県', 'ナガノケン', '東御市', 'トウミシ', '祢津', 'ネツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県東御市滋野甲', '20', '20219', '3890511', '長野県', 'ナガノケン', '東御市', 'トウミシ', '滋野', 'シゲノ', null, null, '甲', 'コウ');
INSERT INTO `ms_addresses` VALUES ('33571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県東御市滋野乙', '20', '20219', '3890512', '長野県', 'ナガノケン', '東御市', 'トウミシ', '滋野', 'シゲノ', null, null, '乙', 'オツ');
INSERT INTO `ms_addresses` VALUES ('33572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県東御市滋野', '20', '20219', '3890513', '長野県', 'ナガノケン', '東御市', 'トウミシ', '滋野', 'シゲノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県東御市加沢', '20', '20219', '3890514', '長野県', 'ナガノケン', '東御市', 'トウミシ', '加沢', 'カザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県東御市常田', '20', '20219', '3890515', '長野県', 'ナガノケン', '東御市', 'トウミシ', '常田', 'トキダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県東御市田中', '20', '20219', '3890516', '長野県', 'ナガノケン', '東御市', 'トウミシ', '田中', 'タナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県東御市県', '20', '20219', '3890517', '長野県', 'ナガノケン', '東御市', 'トウミシ', '県', 'アガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県東御市本海野', '20', '20219', '3890518', '長野県', 'ナガノケン', '東御市', 'トウミシ', '本海野', 'モトウンノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県東御市塩川', '20', '20219', '3890519', '長野県', 'ナガノケン', '東御市', 'トウミシ', '塩川', 'シオカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県埴科郡坂城町', '20', '20521', '3890600', '長野県', 'ナガノケン', '埴科郡坂城町', 'ハニシナグンサカキマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('33584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県埴科郡坂城町坂城', '20', '20521', '3890601', '長野県', 'ナガノケン', '埴科郡坂城町', 'ハニシナグンサカキマチ', '坂城', 'サカキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県埴科郡坂城町中之条', '20', '20521', '3890602', '長野県', 'ナガノケン', '埴科郡坂城町', 'ハニシナグンサカキマチ', '中之条', 'ナカノジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県埴科郡坂城町南条', '20', '20521', '3890603', '長野県', 'ナガノケン', '埴科郡坂城町', 'ハニシナグンサカキマチ', '南条', 'ミナミジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県埴科郡坂城町網掛', '20', '20521', '3890604', '長野県', 'ナガノケン', '埴科郡坂城町', 'ハニシナグンサカキマチ', '網掛', 'アミカケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県埴科郡坂城町上平', '20', '20521', '3890605', '長野県', 'ナガノケン', '埴科郡坂城町', 'ハニシナグンサカキマチ', '上平', 'ウワダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県埴科郡坂城町上五明', '20', '20521', '3890606', '長野県', 'ナガノケン', '埴科郡坂城町', 'ハニシナグンサカキマチ', '上五明', 'カミゴミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県千曲市小船山', '20', '20218', '3890801', '長野県', 'ナガノケン', '千曲市', 'チクマシ', '小船山', 'コブネヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県千曲市内川', '20', '20218', '3890802', '長野県', 'ナガノケン', '千曲市', 'チクマシ', '内川', 'ウチカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県千曲市千本柳', '20', '20218', '3890803', '長野県', 'ナガノケン', '千曲市', 'チクマシ', '千本柳', 'センボンヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県千曲市戸倉', '20', '20218', '3890804', '長野県', 'ナガノケン', '千曲市', 'チクマシ', '戸倉', 'トグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県千曲市上徳間', '20', '20218', '3890805', '長野県', 'ナガノケン', '千曲市', 'チクマシ', '上徳間', 'カミトクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県千曲市磯部', '20', '20218', '3890806', '長野県', 'ナガノケン', '千曲市', 'チクマシ', '磯部', 'イソベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県千曲市戸倉温泉', '20', '20218', '3890807', '長野県', 'ナガノケン', '千曲市', 'チクマシ', '戸倉温泉', 'トグラオンセン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県千曲市須坂', '20', '20218', '3890811', '長野県', 'ナガノケン', '千曲市', 'チクマシ', '須坂', 'スザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県千曲市羽尾', '20', '20218', '3890812', '長野県', 'ナガノケン', '千曲市', 'チクマシ', '羽尾', 'ハネオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県千曲市若宮', '20', '20218', '3890813', '長野県', 'ナガノケン', '千曲市', 'チクマシ', '若宮', 'ワカミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県千曲市上山田温泉', '20', '20218', '3890821', '長野県', 'ナガノケン', '千曲市', 'チクマシ', '上山田温泉', 'カミヤマダオンセン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県千曲市上山田', '20', '20218', '3890822', '長野県', 'ナガノケン', '千曲市', 'チクマシ', '上山田', 'カミヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県千曲市新山', '20', '20218', '3890823', '長野県', 'ナガノケン', '千曲市', 'チクマシ', '新山', 'アラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県千曲市力石', '20', '20218', '3890824', '長野県', 'ナガノケン', '千曲市', 'チクマシ', '力石', 'チカライシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市豊野町川谷', '20', '20201', '3891101', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '豊野町川谷', 'トヨノマチカワタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市豊野町大倉', '20', '20201', '3891102', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '豊野町大倉', 'トヨノマチオオクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市豊野町蟹沢', '20', '20201', '3891103', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '豊野町蟹沢', 'トヨノマチカニサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市豊野町浅野', '20', '20201', '3891104', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '豊野町浅野', 'トヨノマチアサノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市豊野町豊野', '20', '20201', '3891105', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '豊野町豊野', 'トヨノマチトヨノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市豊野町石', '20', '20201', '3891106', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '豊野町石', 'トヨノマチイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県長野市豊野町南郷', '20', '20201', '3891107', '長野県', 'ナガノケン', '長野市', 'ナガノシ', '豊野町南郷', 'トヨノマチミナミゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上水内郡飯綱町', '20', '20590', '3891200', '長野県', 'ナガノケン', '上水内郡飯綱町', 'カミミノチグンイイヅナマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('33628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上水内郡飯綱町芋川', '20', '20590', '3891201', '長野県', 'ナガノケン', '上水内郡飯綱町', 'カミミノチグンイイヅナマチ', '芋川', 'イモガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上水内郡飯綱町東柏原', '20', '20590', '3891202', '長野県', 'ナガノケン', '上水内郡飯綱町', 'カミミノチグンイイヅナマチ', '東柏原', 'ヒガシカシワバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上水内郡飯綱町赤塩', '20', '20590', '3891203', '長野県', 'ナガノケン', '上水内郡飯綱町', 'カミミノチグンイイヅナマチ', '赤塩', 'アカシオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上水内郡飯綱町倉井', '20', '20590', '3891204', '長野県', 'ナガノケン', '上水内郡飯綱町', 'カミミノチグンイイヅナマチ', '倉井', 'クライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上水内郡飯綱町川谷', '20', '20590', '3891205', '長野県', 'ナガノケン', '上水内郡飯綱町', 'カミミノチグンイイヅナマチ', '川谷', 'カワタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上水内郡飯綱町普光寺', '20', '20590', '3891206', '長野県', 'ナガノケン', '上水内郡飯綱町', 'カミミノチグンイイヅナマチ', '普光寺', 'フコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上水内郡飯綱町牟礼', '20', '20590', '3891211', '長野県', 'ナガノケン', '上水内郡飯綱町', 'カミミノチグンイイヅナマチ', '牟礼', 'ムレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上水内郡飯綱町豊野', '20', '20590', '3891212', '長野県', 'ナガノケン', '上水内郡飯綱町', 'カミミノチグンイイヅナマチ', '豊野', 'トヨノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上水内郡飯綱町平出', '20', '20590', '3891213', '長野県', 'ナガノケン', '上水内郡飯綱町', 'カミミノチグンイイヅナマチ', '平出', 'ヒライデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上水内郡飯綱町黒川', '20', '20590', '3891214', '長野県', 'ナガノケン', '上水内郡飯綱町', 'カミミノチグンイイヅナマチ', '黒川', 'クロカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上水内郡飯綱町小玉', '20', '20590', '3891215', '長野県', 'ナガノケン', '上水内郡飯綱町', 'カミミノチグンイイヅナマチ', '小玉', 'コダマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上水内郡飯綱町古町', '20', '20590', '3891221', '長野県', 'ナガノケン', '上水内郡飯綱町', 'カミミノチグンイイヅナマチ', '古町', 'フルマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上水内郡飯綱町柳里', '20', '20590', '3891222', '長野県', 'ナガノケン', '上水内郡飯綱町', 'カミミノチグンイイヅナマチ', '柳里', 'ヤナギサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上水内郡飯綱町袖之山', '20', '20590', '3891223', '長野県', 'ナガノケン', '上水内郡飯綱町', 'カミミノチグンイイヅナマチ', '袖之山', 'ソデノヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上水内郡飯綱町地蔵久保', '20', '20590', '3891224', '長野県', 'ナガノケン', '上水内郡飯綱町', 'カミミノチグンイイヅナマチ', '地蔵久保', 'ジゾウクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上水内郡飯綱町坂口', '20', '20590', '3891225', '長野県', 'ナガノケン', '上水内郡飯綱町', 'カミミノチグンイイヅナマチ', '坂口', 'サカグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上水内郡飯綱町川上', '20', '20590', '3891226', '長野県', 'ナガノケン', '上水内郡飯綱町', 'カミミノチグンイイヅナマチ', '川上', 'カワカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上水内郡飯綱町高坂', '20', '20590', '3891227', '長野県', 'ナガノケン', '上水内郡飯綱町', 'カミミノチグンイイヅナマチ', '高坂', 'コウサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上水内郡信濃町', '20', '20583', '3891300', '長野県', 'ナガノケン', '上水内郡信濃町', 'カミミノチグンシナノマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('33648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上水内郡信濃町熊坂', '20', '20583', '3891301', '長野県', 'ナガノケン', '上水内郡信濃町', 'カミミノチグンシナノマチ', '熊坂', 'クマサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上水内郡信濃町古海', '20', '20583', '3891302', '長野県', 'ナガノケン', '上水内郡信濃町', 'カミミノチグンシナノマチ', '古海', 'フルミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上水内郡信濃町野尻', '20', '20583', '3891303', '長野県', 'ナガノケン', '上水内郡信濃町', 'カミミノチグンシナノマチ', '野尻', 'ノジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上水内郡信濃町神山国際村', '20', '20583', '3891304', '長野県', 'ナガノケン', '上水内郡信濃町', 'カミミノチグンシナノマチ', '神山国際村', 'カミヤマコクサイムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上水内郡信濃町柏原', '20', '20583', '3891305', '長野県', 'ナガノケン', '上水内郡信濃町', 'カミミノチグンシナノマチ', '柏原', 'カシワバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上水内郡信濃町野尻大学村', '20', '20583', '3891306', '長野県', 'ナガノケン', '上水内郡信濃町', 'カミミノチグンシナノマチ', '野尻', 'ノジリ', null, null, '大学村', 'ダイガクムラ');
INSERT INTO `ms_addresses` VALUES ('33654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上水内郡信濃町荒瀬原', '20', '20583', '3891311', '長野県', 'ナガノケン', '上水内郡信濃町', 'カミミノチグンシナノマチ', '荒瀬原', 'アラセバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上水内郡信濃町富濃', '20', '20583', '3891312', '長野県', 'ナガノケン', '上水内郡信濃町', 'カミミノチグンシナノマチ', '富濃', 'トミノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上水内郡信濃町古間', '20', '20583', '3891313', '長野県', 'ナガノケン', '上水内郡信濃町', 'カミミノチグンシナノマチ', '古間', 'フルマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上水内郡信濃町穂波', '20', '20583', '3891314', '長野県', 'ナガノケン', '上水内郡信濃町', 'カミミノチグンシナノマチ', '穂波', 'ホナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上水内郡信濃町平岡', '20', '20583', '3891315', '長野県', 'ナガノケン', '上水内郡信濃町', 'カミミノチグンシナノマチ', '平岡', 'ヒラオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上水内郡信濃町大井', '20', '20583', '3891316', '長野県', 'ナガノケン', '上水内郡信濃町', 'カミミノチグンシナノマチ', '大井', 'オオイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県中野市豊津', '20', '20211', '3892101', '長野県', 'ナガノケン', '中野市', 'ナカノシ', '豊津', 'トヨツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県中野市上今井', '20', '20211', '3892102', '長野県', 'ナガノケン', '中野市', 'ナカノシ', '上今井', 'カミイマイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県中野市穴田', '20', '20211', '3892103', '長野県', 'ナガノケン', '中野市', 'ナカノシ', '穴田', 'アナダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県中野市永江', '20', '20211', '3892104', '長野県', 'ナガノケン', '中野市', 'ナカノシ', '永江', 'ナガエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯山市', '20', '20213', '3892200', '長野県', 'ナガノケン', '飯山市', 'イイヤマシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('33667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯山市天神堂', '20', '20213', '3892231', '長野県', 'ナガノケン', '飯山市', 'イイヤマシ', '天神堂', 'テンシンドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯山市下木島', '20', '20213', '3892232', '長野県', 'ナガノケン', '飯山市', 'イイヤマシ', '下木島', 'シモキジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯山市野坂田', '20', '20213', '3892233', '長野県', 'ナガノケン', '飯山市', 'イイヤマシ', '野坂田', 'ノサカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯山市木島', '20', '20213', '3892234', '長野県', 'ナガノケン', '飯山市', 'イイヤマシ', '木島', 'キジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯山市坂井', '20', '20213', '3892235', '長野県', 'ナガノケン', '飯山市', 'イイヤマシ', '坂井', 'サカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯山市山岸', '20', '20213', '3892241', '長野県', 'ナガノケン', '飯山市', 'イイヤマシ', '山岸', 'ヤマギシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯山市其綿', '20', '20213', '3892242', '長野県', 'ナガノケン', '飯山市', 'イイヤマシ', '其綿', 'ソノワタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯山市吉', '20', '20213', '3892243', '長野県', 'ナガノケン', '飯山市', 'イイヤマシ', '吉', 'ヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯山市安田', '20', '20213', '3892244', '長野県', 'ナガノケン', '飯山市', 'イイヤマシ', '安田', 'ヤスダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯山市旭', '20', '20213', '3892251', '長野県', 'ナガノケン', '飯山市', 'イイヤマシ', '旭', 'アサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯山市小佐原', '20', '20213', '3892252', '長野県', 'ナガノケン', '飯山市', 'イイヤマシ', '小佐原', 'コザワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯山市飯山', '20', '20213', '3892253', '長野県', 'ナガノケン', '飯山市', 'イイヤマシ', '飯山', 'イイヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯山市南町', '20', '20213', '3892254', '長野県', 'ナガノケン', '飯山市', 'イイヤマシ', '南町', 'ミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯山市静間', '20', '20213', '3892255', '長野県', 'ナガノケン', '飯山市', 'イイヤマシ', '静間', 'シズマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯山市蓮', '20', '20213', '3892256', '長野県', 'ナガノケン', '飯山市', 'イイヤマシ', '蓮', 'ハチス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯山市斑尾高原', '20', '20213', '3892257', '長野県', 'ナガノケン', '飯山市', 'イイヤマシ', '斑尾高原', 'マダラオコウゲン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯山市富倉', '20', '20213', '3892258', '長野県', 'ナガノケン', '飯山市', 'イイヤマシ', '富倉', 'トミクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市樽本', '15', '15217', '3892261', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '樽本', 'タルモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県下高井郡木島平村', '20', '20562', '3892300', '長野県', 'ナガノケン', '下高井郡木島平村', 'シモタカイグンキジマダイラムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('33688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県下高井郡木島平村穂高', '20', '20562', '3892301', '長野県', 'ナガノケン', '下高井郡木島平村', 'シモタカイグンキジマダイラムラ', '穂高', 'ホタカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県下高井郡木島平村往郷', '20', '20562', '3892302', '長野県', 'ナガノケン', '下高井郡木島平村', 'シモタカイグンキジマダイラムラ', '往郷', 'オウゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県下高井郡木島平村上木島', '20', '20562', '3892303', '長野県', 'ナガノケン', '下高井郡木島平村', 'シモタカイグンキジマダイラムラ', '上木島', 'カミキジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯山市瑞穂豊', '20', '20213', '3892321', '長野県', 'ナガノケン', '飯山市', 'イイヤマシ', '瑞穂豊', 'ミズホトヨ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯山市瑞穂', '20', '20213', '3892322', '長野県', 'ナガノケン', '飯山市', 'イイヤマシ', '瑞穂', 'ミズホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県中野市田上', '20', '20211', '3892371', '長野県', 'ナガノケン', '中野市', 'ナカノシ', '田上', 'タガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯山市豊田', '20', '20213', '3892411', '長野県', 'ナガノケン', '飯山市', 'イイヤマシ', '豊田', 'トヨダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯山市常郷', '20', '20213', '3892412', '長野県', 'ナガノケン', '飯山市', 'イイヤマシ', '常郷', 'トキサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯山市照里', '20', '20213', '3892413', '長野県', 'ナガノケン', '飯山市', 'イイヤマシ', '照里', 'テルサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯山市常盤', '20', '20213', '3892414', '長野県', 'ナガノケン', '飯山市', 'イイヤマシ', '常盤', 'トキワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯山市大池', '20', '20213', '3892415', '長野県', 'ナガノケン', '飯山市', 'イイヤマシ', '大池', 'オオイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯山市緑', '20', '20213', '3892416', '長野県', 'ナガノケン', '飯山市', 'イイヤマシ', '緑', 'ミドリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯山市中曽根', '20', '20213', '3892417', '長野県', 'ナガノケン', '飯山市', 'イイヤマシ', '中曽根', 'ナカソネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯山市寿', '20', '20213', '3892418', '長野県', 'ナガノケン', '飯山市', 'イイヤマシ', '寿', 'コトブキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県下高井郡野沢温泉村', '20', '20563', '3892500', '長野県', 'ナガノケン', '下高井郡野沢温泉村', 'シモタカイグンノザワオンセンムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('33704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県下高井郡野沢温泉村坪山', '20', '20563', '3892501', '長野県', 'ナガノケン', '下高井郡野沢温泉村', 'シモタカイグンノザワオンセンムラ', '坪山', 'ツボヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県下高井郡野沢温泉村豊郷', '20', '20563', '3892502', '長野県', 'ナガノケン', '下高井郡野沢温泉村', 'シモタカイグンノザワオンセンムラ', '豊郷', 'トヨサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県下高井郡野沢温泉村前坂', '20', '20563', '3892503', '長野県', 'ナガノケン', '下高井郡野沢温泉村', 'シモタカイグンノザワオンセンムラ', '前坂', 'マエザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯山市照岡', '20', '20213', '3892601', '長野県', 'ナガノケン', '飯山市', 'イイヤマシ', '照岡', 'テルオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯山市一山', '20', '20213', '3892602', '長野県', 'ナガノケン', '飯山市', 'イイヤマシ', '一山', 'イチヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県下高井郡野沢温泉村東大滝', '20', '20563', '3892611', '長野県', 'ナガノケン', '下高井郡野沢温泉村', 'シモタカイグンノザワオンセンムラ', '東大滝', 'ヒガシオオタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県下高井郡野沢温泉村七ケ巻', '20', '20563', '3892612', '長野県', 'ナガノケン', '下高井郡野沢温泉村', 'シモタカイグンノザワオンセンムラ', '七ケ巻', 'ナナガマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県下高井郡野沢温泉村虫生', '20', '20563', '3892613', '長野県', 'ナガノケン', '下高井郡野沢温泉村', 'シモタカイグンノザワオンセンムラ', '虫生', 'ムシウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県下高井郡野沢温泉村平林', '20', '20563', '3892614', '長野県', 'ナガノケン', '下高井郡野沢温泉村', 'シモタカイグンノザワオンセンムラ', '平林', 'ヒラバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県下水内郡栄村', '20', '20602', '3892700', '長野県', 'ナガノケン', '下水内郡栄村', 'シモミノチグンサカエムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('33715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県下水内郡栄村豊栄', '20', '20602', '3892701', '長野県', 'ナガノケン', '下水内郡栄村', 'シモミノチグンサカエムラ', '豊栄', 'トヨサカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県下水内郡栄村北信', '20', '20602', '3892702', '長野県', 'ナガノケン', '下水内郡栄村', 'シモミノチグンサカエムラ', '北信', 'ホクシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県下水内郡栄村堺', '20', '20602', '3892703', '長野県', 'ナガノケン', '下水内郡栄村', 'シモミノチグンサカエムラ', '堺', 'サカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市里山辺', '20', '20202', '3900221', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '里山辺', 'サトヤマベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市入山辺', '20', '20202', '3900222', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '入山辺', 'イリヤマベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市稲倉', '20', '20202', '3900301', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '稲倉', 'シナグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市三才山', '20', '20202', '3900302', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '三才山', 'ミサヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市浅間温泉', '20', '20202', '3900303', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '浅間温泉', 'アサマオンセン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市大村', '20', '20202', '3900304', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '大村', 'オオムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市惣社', '20', '20202', '3900305', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '惣社', 'ソウザ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市南浅間', '20', '20202', '3900306', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '南浅間', 'ミナミアサマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市水汲', '20', '20202', '3900311', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '水汲', 'ミズクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市岡田松岡', '20', '20202', '3900312', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '岡田松岡', 'オカダマツオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市岡田下岡田', '20', '20202', '3900313', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '岡田下岡田', 'オカダシモオカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市岡田伊深', '20', '20202', '3900314', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '岡田伊深', 'オカダイブカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市岡田町', '20', '20202', '3900315', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '岡田町', 'オカダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市原', '20', '20202', '3900316', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '原', 'ハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市洞', '20', '20202', '3900317', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '洞', 'ホラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市美須々', '20', '20202', '3900801', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '美須々', 'ミスズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市旭', '20', '20202', '3900802', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '旭', 'アサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市元町', '20', '20202', '3900803', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '元町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市横田', '20', '20202', '3900804', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '横田', 'ヨコタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市清水', '20', '20202', '3900805', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '清水', 'シミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市女鳥羽', '20', '20202', '3900806', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '女鳥羽', 'メトバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市城東', '20', '20202', '3900807', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '城東', 'ジョウトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市中央', '20', '20202', '3900811', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市県', '20', '20202', '3900812', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '県', 'アガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市埋橋', '20', '20202', '3900813', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '埋橋', 'ウズハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市本庄', '20', '20202', '3900814', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '本庄', 'ホンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市深志', '20', '20202', '3900815', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '深志', 'フカシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市中条', '20', '20202', '3900816', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '中条', 'ナカジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市巾上', '20', '20202', '3900817', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '巾上', 'ハバウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市筑摩', '20', '20202', '3900821', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '筑摩', 'ツカマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市神田', '20', '20202', '3900822', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '神田', 'カンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市中山', '20', '20202', '3900823', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '中山', 'ナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市中山台', '20', '20202', '3900824', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '中山台', 'ナカヤマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市並柳', '20', '20202', '3900825', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '並柳', 'ナミヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市出川町', '20', '20202', '3900826', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '出川町', 'イデガワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市出川', '20', '20202', '3900827', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '出川', 'イデガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市庄内', '20', '20202', '3900828', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '庄内', 'ショウナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市井川城', '20', '20202', '3900831', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '井川城', 'イガワジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市南松本', '20', '20202', '3900832', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '南松本', 'ミナミマツモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市双葉', '20', '20202', '3900833', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '双葉', 'フタバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市高宮中', '20', '20202', '3900834', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '高宮中', 'タカミヤナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市高宮東', '20', '20202', '3900835', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '高宮東', 'タカミヤヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市高宮北', '20', '20202', '3900836', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '高宮北', 'タカミヤキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市鎌田', '20', '20202', '3900837', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '鎌田', 'カマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市渚', '20', '20202', '3900841', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '渚', 'ナギサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市征矢野', '20', '20202', '3900842', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '征矢野', 'ソヤノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市高宮南', '20', '20202', '3900843', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '高宮南', 'タカミヤミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市高宮西', '20', '20202', '3900844', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '高宮西', 'タカミヤニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市石芝1丁目', '20', '20202', '3900845', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '石芝', 'イシシバ', null, null, '1丁目', '01チョウメ');
INSERT INTO `ms_addresses` VALUES ('33768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市石芝2丁目', '20', '20202', '3900845', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '石芝', 'イシシバ', null, null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('33769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市南原', '20', '20202', '3900846', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '南原', 'ミナミハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市笹部', '20', '20202', '3900847', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '笹部', 'ササベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市両島', '20', '20202', '3900848', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '両島', 'リョウシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市島内', '20', '20202', '3900851', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '島内', 'シマウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市島立', '20', '20202', '3900852', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '島立', 'シマダチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市蟻ケ崎', '20', '20202', '3900861', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '蟻ケ崎', 'アリガサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市宮渕', '20', '20202', '3900862', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '宮渕', 'ミヤブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市白板', '20', '20202', '3900863', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '白板', 'シライタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市宮渕本村', '20', '20202', '3900864', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '宮渕本村', 'ミヤブチホンムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市新橋', '20', '20202', '3900865', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '新橋', 'シンバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市城山', '20', '20202', '3900866', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '城山', 'ジョウヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市蟻ケ崎台', '20', '20202', '3900867', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '蟻ケ崎台', 'アリガサキダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市桐', '20', '20202', '3900871', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '桐', 'キリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市北深志', '20', '20202', '3900872', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '北深志', 'キタフカシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市丸の内', '20', '20202', '3900873', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '丸の内', 'マルノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市大手', '20', '20202', '3900874', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '大手', 'オオテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市城西', '20', '20202', '3900875', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '城西', 'ジョウセイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市開智', '20', '20202', '3900876', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '開智', 'カイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市沢村', '20', '20202', '3900877', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '沢村', 'サワムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡三戸町', '02', '02441', '0390100', '青森県', 'アオモリケン', '三戸郡三戸町', 'サンノヘグンサンノヘマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('33789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡南部町', '02', '02445', '0390100', '青森県', 'アオモリケン', '三戸郡南部町', 'サンノヘグンナンブチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('33790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡南部町玉掛', '02', '02445', '0390101', '青森県', 'アオモリケン', '三戸郡南部町', 'サンノヘグンナンブチョウ', '玉掛', 'タマカケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡南部町赤石', '02', '02445', '0390102', '青森県', 'アオモリケン', '三戸郡南部町', 'サンノヘグンナンブチョウ', '赤石', 'アカイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡南部町大向', '02', '02445', '0390103', '青森県', 'アオモリケン', '三戸郡南部町', 'サンノヘグンナンブチョウ', '大向', 'オオムカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡南部町小向', '02', '02445', '0390104', '青森県', 'アオモリケン', '三戸郡南部町', 'サンノヘグンナンブチョウ', '小向', 'コムカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡南部町沖田面', '02', '02445', '0390105', '青森県', 'アオモリケン', '三戸郡南部町', 'サンノヘグンナンブチョウ', '沖田面', 'オキタオモテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡南部町相内', '02', '02445', '0390106', '青森県', 'アオモリケン', '三戸郡南部町', 'サンノヘグンナンブチョウ', '相内', 'アイナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県東筑摩郡朝日村', '20', '20451', '3901100', '長野県', 'ナガノケン', '東筑摩郡朝日村', 'ヒガシチクマグンアサヒムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('33797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県東筑摩郡朝日村西洗馬', '20', '20451', '3901101', '長野県', 'ナガノケン', '東筑摩郡朝日村', 'ヒガシチクマグンアサヒムラ', '西洗馬', 'ニシセバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県東筑摩郡朝日村小野沢', '20', '20451', '3901102', '長野県', 'ナガノケン', '東筑摩郡朝日村', 'ヒガシチクマグンアサヒムラ', '小野沢', 'オノザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県東筑摩郡朝日村針尾', '20', '20451', '3901103', '長野県', 'ナガノケン', '東筑摩郡朝日村', 'ヒガシチクマグンアサヒムラ', '針尾', 'ハリオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県東筑摩郡朝日村古見', '20', '20451', '3901104', '長野県', 'ナガノケン', '東筑摩郡朝日村', 'ヒガシチクマグンアサヒムラ', '古見', 'コミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡三戸町泉山', '02', '02441', '0390111', '青森県', 'アオモリケン', '三戸郡三戸町', 'サンノヘグンサンノヘマチ', '泉山', 'イズミヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡三戸町梅内', '02', '02441', '0390112', '青森県', 'アオモリケン', '三戸郡三戸町', 'サンノヘグンサンノヘマチ', '梅内', 'ウメナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡三戸町目時', '02', '02441', '0390113', '青森県', 'アオモリケン', '三戸郡三戸町', 'サンノヘグンサンノヘマチ', '目時', 'メトキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市今井', '20', '20202', '3901131', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '今井', 'イマイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市空港東', '20', '20202', '3901132', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '空港東', 'クウコウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡三戸町豊川', '02', '02441', '0390121', '青森県', 'アオモリケン', '三戸郡三戸町', 'サンノヘグンサンノヘマチ', '豊川', 'トヨカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡三戸町斗内', '02', '02441', '0390122', '青森県', 'アオモリケン', '三戸郡三戸町', 'サンノヘグンサンノヘマチ', '斗内', 'トナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市新村', '20', '20202', '3901241', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '新村', 'ニイムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市和田', '20', '20202', '3901242', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '和田', 'ワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市神林', '20', '20202', '3901243', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '神林', 'カンバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県東筑摩郡山形村', '20', '20450', '3901301', '長野県', 'ナガノケン', '東筑摩郡山形村', 'ヒガシチクマグンヤマガタムラ', null, '　', '（全域）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('33827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡三戸町二日町', '02', '02441', '0390131', '青森県', 'アオモリケン', '三戸郡三戸町', 'サンノヘグンサンノヘマチ', '二日町', 'フツカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡三戸町在府小路町', '02', '02441', '0390132', '青森県', 'アオモリケン', '三戸郡三戸町', 'サンノヘグンサンノヘマチ', '在府小路町', 'ザイフコウジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡三戸町馬喰町', '02', '02441', '0390133', '青森県', 'アオモリケン', '三戸郡三戸町', 'サンノヘグンサンノヘマチ', '馬喰町', 'バクロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡三戸町同心町', '02', '02441', '0390134', '青森県', 'アオモリケン', '三戸郡三戸町', 'サンノヘグンサンノヘマチ', '同心町', 'ドウシンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡三戸町八日町', '02', '02441', '0390135', '青森県', 'アオモリケン', '三戸郡三戸町', 'サンノヘグンサンノヘマチ', '八日町', 'ヨウカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県東筑摩郡波田町', '20', '20449', '3901401', '長野県', 'ナガノケン', '東筑摩郡波田町', 'ヒガシチクマグンハタマチ', null, '　', '（全域）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('33836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡三戸町川守田', '02', '02441', '0390141', '青森県', 'アオモリケン', '三戸郡三戸町', 'サンノヘグンサンノヘマチ', '川守田', 'カワモリタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡三戸町久慈町', '02', '02441', '0390142', '青森県', 'アオモリケン', '三戸郡三戸町', 'サンノヘグンサンノヘマチ', '久慈町', 'クジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡三戸町川守田町', '02', '02441', '0390143', '青森県', 'アオモリケン', '三戸郡三戸町', 'サンノヘグンサンノヘマチ', '川守田町', 'カワモリタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡三戸町六日町', '02', '02441', '0390144', '青森県', 'アオモリケン', '三戸郡三戸町', 'サンノヘグンサンノヘマチ', '六日町', 'ムイカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市安曇大野田', '20', '20202', '3901501', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '安曇', 'アヅミ', null, null, '大野田', 'オオノタ');
INSERT INTO `ms_addresses` VALUES ('33842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市安曇島々', '20', '20202', '3901502', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '安曇', 'アヅミ', null, null, '島々', 'シマシマ');
INSERT INTO `ms_addresses` VALUES ('33843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市安曇橋場', '20', '20202', '3901503', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '安曇', 'アヅミ', null, null, '橋場', 'ハシバ');
INSERT INTO `ms_addresses` VALUES ('33844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市安曇稲核', '20', '20202', '3901504', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '安曇', 'アヅミ', null, null, '稲核', 'イネコキ');
INSERT INTO `ms_addresses` VALUES ('33845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市安曇番所', '20', '20202', '3901506', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '安曇', 'アヅミ', null, null, '番所', 'バンドコロ');
INSERT INTO `ms_addresses` VALUES ('33846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市安曇宮の原', '20', '20202', '3901507', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '安曇', 'アヅミ', null, null, '宮の原', 'ミヤノハラ');
INSERT INTO `ms_addresses` VALUES ('33847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市安曇千石平', '20', '20202', '3901511', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '安曇', 'アヅミ', null, null, '千石平', 'センゴクダイラ');
INSERT INTO `ms_addresses` VALUES ('33848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市安曇楢ノ木', '20', '20202', '3901512', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '安曇', 'アヅミ', null, null, '楢ノ木', 'ナラノキ');
INSERT INTO `ms_addresses` VALUES ('33849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市安曇鈴蘭', '20', '20202', '3901513', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '安曇', 'アヅミ', null, null, '鈴蘭', 'スズラン');
INSERT INTO `ms_addresses` VALUES ('33850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市安曇沢渡', '20', '20202', '3901514', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '安曇', 'アヅミ', null, null, '沢渡', 'サワンド');
INSERT INTO `ms_addresses` VALUES ('33851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市安曇白骨', '20', '20202', '3901515', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '安曇', 'アヅミ', null, null, '白骨', 'シラホネ');
INSERT INTO `ms_addresses` VALUES ('33852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市安曇上高地', '20', '20202', '3901516', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '安曇', 'アヅミ', null, null, '上高地', 'カミコウチ');
INSERT INTO `ms_addresses` VALUES ('33853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市安曇', '20', '20202', '3901520', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '安曇', 'アヅミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市奈川', '20', '20202', '3901611', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '奈川', 'ナガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市梓川倭', '20', '20202', '3901701', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '梓川倭', 'アズサガワヤマト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市梓川梓', '20', '20202', '3901702', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '梓川梓', 'アズサガワアズサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市梓川上野', '20', '20202', '3901703', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '梓川上野', 'アズサガワウエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡田子町', '02', '02443', '0390200', '青森県', 'アオモリケン', '三戸郡田子町', 'サンノヘグンタッコマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('33863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡田子町田子', '02', '02443', '0390201', '青森県', 'アオモリケン', '三戸郡田子町', 'サンノヘグンタッコマチ', '田子', 'タッコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡田子町相米', '02', '02443', '0390202', '青森県', 'アオモリケン', '三戸郡田子町', 'サンノヘグンタッコマチ', '相米', 'ソウマイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡田子町原', '02', '02443', '0390311', '青森県', 'アオモリケン', '三戸郡田子町', 'サンノヘグンタッコマチ', '原', 'ハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡田子町石亀', '02', '02443', '0390312', '青森県', 'アオモリケン', '三戸郡田子町', 'サンノヘグンタッコマチ', '石亀', 'イシガメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡田子町茂市', '02', '02443', '0390313', '青森県', 'アオモリケン', '三戸郡田子町', 'サンノヘグンタッコマチ', '茂市', 'モイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡田子町遠瀬', '02', '02443', '0390314', '青森県', 'アオモリケン', '三戸郡田子町', 'サンノヘグンタッコマチ', '遠瀬', 'トウセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡田子町夏坂', '02', '02443', '0390315', '青森県', 'アオモリケン', '三戸郡田子町', 'サンノヘグンタッコマチ', '夏坂', 'ナツサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡田子町関', '02', '02443', '0390316', '青森県', 'アオモリケン', '三戸郡田子町', 'サンノヘグンタッコマチ', '関', 'セキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡田子町山口', '02', '02443', '0390317', '青森県', 'アオモリケン', '三戸郡田子町', 'サンノヘグンタッコマチ', '山口', 'ヤマグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡三戸町蛇沼', '02', '02441', '0390451', '青森県', 'アオモリケン', '三戸郡三戸町', 'サンノヘグンサンノヘマチ', '蛇沼', 'ジャヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡三戸町袴田', '02', '02441', '0390452', '青森県', 'アオモリケン', '三戸郡三戸町', 'サンノヘグンサンノヘマチ', '袴田', 'ハカマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡三戸町貝守', '02', '02441', '0390453', '青森県', 'アオモリケン', '三戸郡三戸町', 'サンノヘグンサンノヘマチ', '貝守', 'カイモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡南部町上名久井', '02', '02445', '0390501', '青森県', 'アオモリケン', '三戸郡南部町', 'サンノヘグンナンブチョウ', '上名久井', 'カミナクイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡南部町下名久井', '02', '02445', '0390502', '青森県', 'アオモリケン', '三戸郡南部町', 'サンノヘグンナンブチョウ', '下名久井', 'シモナクイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡南部町平', '02', '02445', '0390503', '青森県', 'アオモリケン', '三戸郡南部町', 'サンノヘグンナンブチョウ', '平', 'タイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡南部町鳥舌内', '02', '02445', '0390504', '青森県', 'アオモリケン', '三戸郡南部町', 'サンノヘグンナンブチョウ', '鳥舌内', 'チョウシタナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡南部町鳥谷', '02', '02445', '0390505', '青森県', 'アオモリケン', '三戸郡南部町', 'サンノヘグンナンブチョウ', '鳥谷', 'トヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡南部町法光寺', '02', '02445', '0390506', '青森県', 'アオモリケン', '三戸郡南部町', 'サンノヘグンナンブチョウ', '法光寺', 'ホウコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡南部町高瀬', '02', '02445', '0390507', '青森県', 'アオモリケン', '三戸郡南部町', 'サンノヘグンナンブチョウ', '高瀬', 'タカセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡南部町相内柏木久保', '02', '02445', '0390606', '青森県', 'アオモリケン', '三戸郡南部町', 'サンノヘグンナンブチョウ', '相内', 'アイナイ', null, null, '柏木久保', 'カシワギクボ');
INSERT INTO `ms_addresses` VALUES ('33885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡南部町相内鴨ノ首', '02', '02445', '0390606', '青森県', 'アオモリケン', '三戸郡南部町', 'サンノヘグンナンブチョウ', '相内', 'アイナイ', null, null, '鴨ノ首', 'カモノクビ');
INSERT INTO `ms_addresses` VALUES ('33886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡南部町相内留ノ沢', '02', '02445', '0390606', '青森県', 'アオモリケン', '三戸郡南部町', 'サンノヘグンナンブチョウ', '相内', 'アイナイ', null, null, '留ノ沢', 'トメノサワ');
INSERT INTO `ms_addresses` VALUES ('33887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡南部町相内沼久保', '02', '02445', '0390606', '青森県', 'アオモリケン', '三戸郡南部町', 'サンノヘグンナンブチョウ', '相内', 'アイナイ', null, null, '沼久保', 'ヌマクボ');
INSERT INTO `ms_addresses` VALUES ('33888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡南部町相内屋敷久保', '02', '02445', '0390606', '青森県', 'アオモリケン', '三戸郡南部町', 'サンノヘグンナンブチョウ', '相内', 'アイナイ', null, null, '屋敷久保', 'ヤシキクボ');
INSERT INTO `ms_addresses` VALUES ('33889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡南部町斗賀', '02', '02445', '0390611', '青森県', 'アオモリケン', '三戸郡南部町', 'サンノヘグンナンブチョウ', '斗賀', 'トガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡南部町剣吉', '02', '02445', '0390612', '青森県', 'アオモリケン', '三戸郡南部町', 'サンノヘグンナンブチョウ', '剣吉', 'ケンヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡南部町森越', '02', '02445', '0390613', '青森県', 'アオモリケン', '三戸郡南部町', 'サンノヘグンナンブチョウ', '森越', 'モリコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡南部町虎渡', '02', '02445', '0390614', '青森県', 'アオモリケン', '三戸郡南部町', 'サンノヘグンナンブチョウ', '虎渡', 'トラト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡南部町片岸', '02', '02445', '0390801', '青森県', 'アオモリケン', '三戸郡南部町', 'サンノヘグンナンブチョウ', '片岸', 'カタギシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡南部町苫米地', '02', '02445', '0390802', '青森県', 'アオモリケン', '三戸郡南部町', 'サンノヘグンナンブチョウ', '苫米地', 'トマベチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡南部町麦沢', '02', '02445', '0390803', '青森県', 'アオモリケン', '三戸郡南部町', 'サンノヘグンナンブチョウ', '麦沢', 'ムギサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡南部町高橋', '02', '02445', '0390804', '青森県', 'アオモリケン', '三戸郡南部町', 'サンノヘグンナンブチョウ', '高橋', 'タカハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡南部町小泉', '02', '02445', '0390805', '青森県', 'アオモリケン', '三戸郡南部町', 'サンノヘグンナンブチョウ', '小泉', 'コイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡南部町法師岡', '02', '02445', '0390811', '青森県', 'アオモリケン', '三戸郡南部町', 'サンノヘグンナンブチョウ', '法師岡', 'ホウシオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡南部町椛木', '02', '02445', '0390812', '青森県', 'アオモリケン', '三戸郡南部町', 'サンノヘグンナンブチョウ', '椛木', 'カバキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡南部町杉沢', '02', '02445', '0390813', '青森県', 'アオモリケン', '三戸郡南部町', 'サンノヘグンナンブチョウ', '杉沢', 'スギサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡南部町埖渡', '02', '02445', '0390814', '青森県', 'アオモリケン', '三戸郡南部町', 'サンノヘグンナンブチョウ', '埖渡', 'ゴミワタリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡南部町福田', '02', '02445', '0390815', '青森県', 'アオモリケン', '三戸郡南部町', 'サンノヘグンナンブチョウ', '福田', 'フクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県茅野市', '20', '20214', '3910000', '長野県', 'ナガノケン', '茅野市', 'チノシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('33955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県茅野市ちの', '20', '20214', '3910001', '長野県', 'ナガノケン', '茅野市', 'チノシ', 'ちの', 'チノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県茅野市塚原', '20', '20214', '3910002', '長野県', 'ナガノケン', '茅野市', 'チノシ', '塚原', 'ツカハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県茅野市本町', '20', '20214', '3910003', '長野県', 'ナガノケン', '茅野市', 'チノシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県茅野市城山', '20', '20214', '3910004', '長野県', 'ナガノケン', '茅野市', 'チノシ', '城山', 'ジョウヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県茅野市仲町', '20', '20214', '3910005', '長野県', 'ナガノケン', '茅野市', 'チノシ', '仲町', 'ナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県茅野市玉川', '20', '20214', '3910011', '長野県', 'ナガノケン', '茅野市', 'チノシ', '玉川', 'タマガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県茅野市金沢', '20', '20214', '3910012', '長野県', 'ナガノケン', '茅野市', 'チノシ', '金沢', 'カナザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県茅野市宮川', '20', '20214', '3910013', '長野県', 'ナガノケン', '茅野市', 'チノシ', '宮川', 'ミヤガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪郡富士見町富士見入笠湖', '20', '20362', '3910021', '長野県', 'ナガノケン', '諏訪郡富士見町', 'スワグンフジミマチ', '富士見', 'フジミ', null, null, '入笠湖', 'ニュウカサコ');
INSERT INTO `ms_addresses` VALUES ('33964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪郡原村', '20', '20363', '3910100', '長野県', 'ナガノケン', '諏訪郡原村', 'スワグンハラムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('33965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪郡原村大久保', '20', '20363', '3910101', '長野県', 'ナガノケン', '諏訪郡原村', 'スワグンハラムラ', '大久保', 'オオクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪郡原村柳沢', '20', '20363', '3910102', '長野県', 'ナガノケン', '諏訪郡原村', 'スワグンハラムラ', '柳沢', 'ヤナギサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪郡原村八ツ手', '20', '20363', '3910103', '長野県', 'ナガノケン', '諏訪郡原村', 'スワグンハラムラ', '八ツ手', 'ヤツデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪郡原村払沢', '20', '20363', '3910104', '長野県', 'ナガノケン', '諏訪郡原村', 'スワグンハラムラ', '払沢', 'ハライザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪郡原村柏木', '20', '20363', '3910105', '長野県', 'ナガノケン', '諏訪郡原村', 'スワグンハラムラ', '柏木', 'カシワギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪郡原村菖蒲沢', '20', '20363', '3910106', '長野県', 'ナガノケン', '諏訪郡原村', 'スワグンハラムラ', '菖蒲沢', 'ショウブザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪郡原村室内', '20', '20363', '3910107', '長野県', 'ナガノケン', '諏訪郡原村', 'スワグンハラムラ', '室内', 'ムロウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪郡原村中新田', '20', '20363', '3910108', '長野県', 'ナガノケン', '諏訪郡原村', 'スワグンハラムラ', '中新田', 'ナカシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪郡原村南原', '20', '20363', '3910109', '長野県', 'ナガノケン', '諏訪郡原村', 'スワグンハラムラ', '南原', 'ミナミハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪郡原村上里', '20', '20363', '3910111', '長野県', 'ナガノケン', '諏訪郡原村', 'スワグンハラムラ', '上里', 'カミサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪郡原村農場', '20', '20363', '3910112', '長野県', 'ナガノケン', '諏訪郡原村', 'スワグンハラムラ', '農場', 'ノウジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪郡原村やつがね', '20', '20363', '3910113', '長野県', 'ナガノケン', '諏訪郡原村', 'スワグンハラムラ', 'やつがね', 'ヤツガネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪郡原村ペンション', '20', '20363', '3910114', '長野県', 'ナガノケン', '諏訪郡原村', 'スワグンハラムラ', 'ペンション', 'ペンション', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪郡原村原山', '20', '20363', '3910115', '長野県', 'ナガノケン', '諏訪郡原村', 'スワグンハラムラ', '原山', 'ハラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪郡原村判の木', '20', '20363', '3910116', '長野県', 'ナガノケン', '諏訪郡原村', 'スワグンハラムラ', '判の木', 'ハンノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県茅野市湖東', '20', '20214', '3910211', '長野県', 'ナガノケン', '茅野市', 'チノシ', '湖東', 'コヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県茅野市北山', '20', '20214', '3910212', '長野県', 'ナガノケン', '茅野市', 'チノシ', '北山', 'キタヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県茅野市豊平', '20', '20214', '3910213', '長野県', 'ナガノケン', '茅野市', 'チノシ', '豊平', 'トヨヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県茅野市泉野', '20', '20214', '3910214', '長野県', 'ナガノケン', '茅野市', 'チノシ', '泉野', 'イズミノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県茅野市中大塩', '20', '20214', '3910215', '長野県', 'ナガノケン', '茅野市', 'チノシ', '中大塩', 'ナカオオシオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県茅野市米沢', '20', '20214', '3910216', '長野県', 'ナガノケン', '茅野市', 'チノシ', '米沢', 'ヨネザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県茅野市北山', '20', '20214', '3910301', '長野県', 'ナガノケン', '茅野市', 'チノシ', '北山', 'キタヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県北佐久郡立科町芦田八ケ野', '20', '20324', '3910321', '長野県', 'ナガノケン', '北佐久郡立科町', 'キタサクグンタテシナマチ', '芦田八ケ野', 'アシダハッカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('33994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県北佐久郡立科町池の平', '20', '20324', '3910321', '長野県', 'ナガノケン', '北佐久郡立科町', 'キタサクグンタテシナマチ', '池の平', 'イケノタイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市尻内町', '02', '02203', '0391101', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '尻内町', 'シリウチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市一番町', '02', '02203', '0391102', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '一番町', 'イチバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市長苗代', '02', '02203', '0391103', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '長苗代', 'ナガナワシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市田面木', '02', '02203', '0391104', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '田面木', 'タモノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市八幡', '02', '02203', '0391105', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '八幡', 'ヤワタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市坂牛', '02', '02203', '0391106', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '坂牛', 'サカウシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市櫛引', '02', '02203', '0391107', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '櫛引', 'クシビキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市上野', '02', '02203', '0391108', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '上野', 'ウワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市豊崎町', '02', '02203', '0391109', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '豊崎町', 'トヨサキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市東白山台', '02', '02203', '0391111', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '東白山台', 'ヒガシハクサンダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市南白山台', '02', '02203', '0391112', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '南白山台', 'ミナミハクサンダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市西白山台', '02', '02203', '0391113', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '西白山台', 'ニシハクサンダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市北白山台', '02', '02203', '0391114', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '北白山台', 'キタハクサンダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市卸センター', '02', '02203', '0391121', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '卸センター', 'オロシセンター', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市河原木', '02', '02203', '0391161', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '河原木', 'カワラギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市豊洲', '02', '02203', '0391162', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '豊洲', 'トヨス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市高州', '02', '02203', '0391163', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '高州', 'タカス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市下長', '02', '02203', '0391164', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '下長', 'シモナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市石堂', '02', '02203', '0391165', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '石堂', 'イシドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市根城', '02', '02203', '0391166', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '根城', 'ネジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市沢里', '02', '02203', '0391167', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '沢里', 'サワサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市八太郎', '02', '02203', '0391168', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '八太郎', 'ハッタロウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡階上町', '02', '02446', '0391200', '青森県', 'アオモリケン', '三戸郡階上町', 'サンノヘグンハシカミチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('34027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡階上町道仏', '02', '02446', '0391201', '青森県', 'アオモリケン', '三戸郡階上町', 'サンノヘグンハシカミチョウ', '道仏', 'ドウブツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡階上町赤保内', '02', '02446', '0391202', '青森県', 'アオモリケン', '三戸郡階上町', 'サンノヘグンハシカミチョウ', '赤保内', 'アカボナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡階上町鳥屋部', '02', '02446', '0391203', '青森県', 'アオモリケン', '三戸郡階上町', 'サンノヘグンハシカミチョウ', '鳥屋部', 'トヤベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡階上町平内', '02', '02446', '0391204', '青森県', 'アオモリケン', '三戸郡階上町', 'サンノヘグンハシカミチョウ', '平内', 'ヒラナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡階上町晴山沢', '02', '02446', '0391205', '青森県', 'アオモリケン', '三戸郡階上町', 'サンノヘグンハシカミチョウ', '晴山沢', 'ハレヤマサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡階上町田代', '02', '02446', '0391206', '青森県', 'アオモリケン', '三戸郡階上町', 'サンノヘグンハシカミチョウ', '田代', 'タシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡階上町金山沢', '02', '02446', '0391207', '青森県', 'アオモリケン', '三戸郡階上町', 'サンノヘグンハシカミチョウ', '金山沢', 'カネヤマサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡階上町角柄折', '02', '02446', '0391208', '青森県', 'アオモリケン', '三戸郡階上町', 'サンノヘグンハシカミチョウ', '角柄折', 'ツノガラオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡階上町蒼前東', '02', '02446', '0391211', '青森県', 'アオモリケン', '三戸郡階上町', 'サンノヘグンハシカミチョウ', '蒼前東', 'ソウゼンヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡階上町蒼前西', '02', '02446', '0391212', '青森県', 'アオモリケン', '三戸郡階上町', 'サンノヘグンハシカミチョウ', '蒼前西', 'ソウゼンニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町', '02', '02442', '0391500', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('34038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町上市川', '02', '02442', '0391501', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '上市川', 'カミイチカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町切谷内', '02', '02442', '0391502', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '切谷内', 'キリヤナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町大久保', '02', '02442', '0391503', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '大久保', 'オオクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町佐野上谷地', '02', '02442', '0391503', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '佐野上谷地', 'サノカミヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町鮫ノ口', '02', '02442', '0391503', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '鮫ノ口', 'サメノクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町兎内', '02', '02442', '0391504', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '兎内', 'ウサギナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町兎内上保土沢', '02', '02442', '0391504', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '兎内上保土沢', 'ウサギナイカミホトザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町兎内下川原', '02', '02442', '0391504', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '兎内下川原', 'ウサギナイシモカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町兎内下保土沢', '02', '02442', '0391504', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '兎内下保土沢', 'ウサギナイシモホトザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町兎内下谷地', '02', '02442', '0391504', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '兎内下谷地', 'ウサギナイシモヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町上兎内', '02', '02442', '0391504', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '上兎内', 'カミウサギナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町石仏', '02', '02442', '0391505', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '石仏', 'イシボトケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町石仏上川原', '02', '02442', '0391505', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '石仏上川原', 'イシボトケカミカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町石仏下川原', '02', '02442', '0391505', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '石仏下川原', 'イシボトケシモカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町石仏前', '02', '02442', '0391505', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '石仏前', 'イシボトケマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町熊野林', '02', '02442', '0391506', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '熊野林', 'クマノバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町熊野林後', '02', '02442', '0391506', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '熊野林後', 'クマノバヤシウシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町熊野林前', '02', '02442', '0391506', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '熊野林前', 'クマノバヤシマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町蛯川後', '02', '02442', '0391507', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '蛯川後', 'エビカワウシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町蛯川前川原', '02', '02442', '0391507', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '蛯川前川原', 'エビカワマエカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町蛯川村', '02', '02442', '0391507', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '蛯川村', 'エビカワムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町上谷地', '02', '02442', '0391507', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '上谷地', 'カミヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町中森', '02', '02442', '0391507', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '中森', 'ナカモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町赤川', '02', '02442', '0391508', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '赤川', 'アカガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町赤川前', '02', '02442', '0391508', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '赤川前', 'アカガワマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町上新道', '02', '02442', '0391508', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '上新道', 'カミシンミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町下新道', '02', '02442', '0391508', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '下新道', 'シモシンミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町土取場', '02', '02442', '0391508', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '土取場', 'ツチトリバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町中寄', '02', '02442', '0391508', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '中寄', 'ナカヨリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町鍜冶屋窪', '02', '02442', '0391511', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '鍜冶屋窪', 'カジヤクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町鍜冶屋窪上ミ', '02', '02442', '0391511', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '鍜冶屋窪上ミ', 'カジヤクボカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町鍜冶屋敷', '02', '02442', '0391511', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '鍜冶屋敷', 'カジヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町丁塚', '02', '02442', '0391511', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '丁塚', 'チョウヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町西ノ沢', '02', '02442', '0391512', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '西ノ沢', 'ニシノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町古館', '02', '02442', '0391513', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '古館', 'フルダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町古館向', '02', '02442', '0391513', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '古館向', 'フルダテムカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町古館向川原', '02', '02442', '0391513', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '古館向川原', 'フルダテムカイカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町古館脇', '02', '02442', '0391513', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '古館脇', 'フルダテワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町下中崎', '02', '02442', '0391514', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '下中崎', 'シモナカサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町中崎', '02', '02442', '0391514', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '中崎', 'ナカザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町熊ノ沢', '02', '02442', '0391515', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '熊ノ沢', 'クマノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町熊ノ沢頭', '02', '02442', '0391515', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '熊ノ沢頭', 'クマノサワガシラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町治郎左エ門長根', '02', '02442', '0391515', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '治郎左エ門長根', 'ジロウザエモンナガネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町市川道十文字', '02', '02442', '0391516', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '市川道十文字', 'イチカワミチジュウモンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町沢向', '02', '02442', '0391517', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '沢向', 'サワムカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町下モ沢向', '02', '02442', '0391518', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '下モ沢向', 'シモサワムカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町天満', '02', '02442', '0391519', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '天満', 'テンマン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町天満後', '02', '02442', '0391519', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '天満後', 'テンマンウシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町天満下川原', '02', '02442', '0391519', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '天満下川原', 'テンマンシモカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町五百窪', '02', '02442', '0391521', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '五百窪', 'イオクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町泉窪', '02', '02442', '0391521', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '泉窪', 'イズミクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町大渡', '02', '02442', '0391521', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '大渡', 'オオワタリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町大渡道ノ下', '02', '02442', '0391521', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '大渡道ノ下', 'オオワタリミチノシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町久蔵窪', '02', '02442', '0391521', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '久蔵窪', 'キュウゾウクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町小渡', '02', '02442', '0391522', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '小渡', 'コワタリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町小渡頭', '02', '02442', '0391522', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '小渡頭', 'コワタリガシラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町徳良窪', '02', '02442', '0391522', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '徳良窪', 'トクラクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町苗代沢', '02', '02442', '0391522', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '苗代沢', 'ナシロザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町上保土沢', '02', '02442', '0391523', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '上保土沢', 'カミホトザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町下保土沢', '02', '02442', '0391523', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '下保土沢', 'シモホトザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町新蔵長根', '02', '02442', '0391523', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '新蔵長根', 'シンゾウナガネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町豊間内', '02', '02442', '0391524', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '豊間内', 'トヨマナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町地蔵岱', '02', '02442', '0391525', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '地蔵岱', 'ジゾウタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町上長下', '02', '02442', '0391526', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '上長下', 'カミナガシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町下長下', '02', '02442', '0391526', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '下長下', 'シモナガシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町惣林橋', '02', '02442', '0391526', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '惣林橋', 'ソウリンバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町扇田', '02', '02442', '0391527', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '扇田', 'オウギダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町浅水', '02', '02442', '0391528', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '浅水', 'アサミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町手倉橋', '02', '02442', '0391529', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '手倉橋', 'テグラバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町狐森', '02', '02442', '0391531', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '狐森', 'キツネモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町狐森北', '02', '02442', '0391531', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '狐森北', 'キツネモリキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町観音堂', '02', '02442', '0391532', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '観音堂', 'カンノンドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町上大町', '02', '02442', '0391533', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '上大町', 'カミオオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町野月', '02', '02442', '0391533', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '野月', 'ノヅキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町荒町', '02', '02442', '0391534', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '荒町', 'アラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町新丁', '02', '02442', '0391535', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '新丁', 'シンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町愛宕後', '02', '02442', '0391536', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '愛宕後', 'アタゴウシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町愛宕下タ', '02', '02442', '0391536', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '愛宕下タ', 'アタゴシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町愛宕丁', '02', '02442', '0391536', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '愛宕丁', 'アタゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町ウルエ長根', '02', '02442', '0391537', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', 'ウルエ長根', 'ウルエナガネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町ウルエ長根下', '02', '02442', '0391537', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', 'ウルエ長根下', 'ウルエナガネシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町追分', '02', '02442', '0391537', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '追分', 'オイワケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町二本柳', '02', '02442', '0391537', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '二本柳', 'ニホンヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町二本柳向', '02', '02442', '0391537', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '二本柳向', 'ニホンヤナギムカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町塚無岱', '02', '02442', '0391538', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '塚無岱', 'ツカナシタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町古街道長根', '02', '02442', '0391538', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '古街道長根', 'フルカイドウナガネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町石沢境', '02', '02442', '0391539', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '石沢境', 'イシザワサカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町中ノ沢', '02', '02442', '0391539', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '中ノ沢', 'ナカノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町中ノ沢西張', '02', '02442', '0391539', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '中ノ沢西張', 'ナカノサワニシハリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町新田窪', '02', '02442', '0391541', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '新田窪', 'シンデンクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町中道', '02', '02442', '0391542', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '中道', 'ナカミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町中道十文字', '02', '02442', '0391542', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '中道十文字', 'ナカミチジュウモンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町竹原', '02', '02442', '0391543', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '竹原', 'タケハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町二階平', '02', '02442', '0391544', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '二階平', 'ニカイダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町二階平下タ', '02', '02442', '0391544', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '二階平下タ', 'ニカイダイラシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町正場沢', '02', '02442', '0391545', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '正場沢', 'ショウバサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町正場沢長根', '02', '02442', '0391545', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '正場沢長根', 'ショウバサワナガネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町下タノ沢', '02', '02442', '0391546', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '下タノ沢', 'シタノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町下タノ沢頭', '02', '02442', '0391546', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '下タノ沢頭', 'シタノサワガシラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町土井頭', '02', '02442', '0391546', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '土井頭', 'ドイガシラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町神明後', '02', '02442', '0391547', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '神明後', 'シンメイウシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町新町', '02', '02442', '0391548', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町上新井田', '02', '02442', '0391551', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '上新井田', 'カミニイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町上新井田前', '02', '02442', '0391551', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '上新井田前', 'カミニイダマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町姥堤', '02', '02442', '0391552', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '姥堤', 'ウバヅツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町上高田', '02', '02442', '0391552', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '上高田', 'カミタカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町筒口川原', '02', '02442', '0391552', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '筒口川原', 'ドウグチカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町中高田', '02', '02442', '0391552', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '中高田', 'ナカタカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町川原町下裏', '02', '02442', '0391553', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '川原町下裏', 'カワラマチシモウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町川原町西裏', '02', '02442', '0391553', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '川原町西裏', 'カワラマチニシウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町川原町', '02', '02442', '0391554', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '川原町', 'カワラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町川原町裏', '02', '02442', '0391554', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '川原町裏', 'カワラマチウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町傳兵ヱ丁', '02', '02442', '0391554', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '傳兵ヱ丁', 'デンベエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町下高田', '02', '02442', '0391555', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '下高田', 'シモタカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町古堂', '02', '02442', '0391555', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '古堂', 'フルドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町古堂後', '02', '02442', '0391555', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '古堂後', 'フルドウウシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町油出', '02', '02442', '0391556', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '油出', 'アブラデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町上川原', '02', '02442', '0391557', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '上川原', 'カミカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町八景', '02', '02442', '0391557', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '八景', 'ハッケイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町沢', '02', '02442', '0391558', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '沢', 'サワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町館', '02', '02442', '0391558', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '館', 'タテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町博労町', '02', '02442', '0391558', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '博労町', 'バクロウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町堀合', '02', '02442', '0391558', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '堀合', 'ホリアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町下大町', '02', '02442', '0391559', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '下大町', 'シモオオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町横丁', '02', '02442', '0391559', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '横丁', 'ヨコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町赤坂', '02', '02442', '0391561', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '赤坂', 'アカサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町越掛沢', '02', '02442', '0391561', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '越掛沢', 'コシカケザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町越掛沢前', '02', '02442', '0391561', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '越掛沢前', 'コシカケザワマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町越掛沢道下モ', '02', '02442', '0391561', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '越掛沢道下モ', 'コシカケザワミチノシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町鹿内', '02', '02442', '0391562', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '鹿内', 'シカナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町鹿内沖', '02', '02442', '0391562', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '鹿内沖', 'シカナイオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町鹿内下モ', '02', '02442', '0391562', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '鹿内下モ', 'シカナイシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町鹿内前', '02', '02442', '0391562', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '鹿内前', 'シカナイマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町白山', '02', '02442', '0391562', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '白山', 'ハクサン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町白山前', '02', '02442', '0391562', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '白山前', 'ハクサンマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町岡谷地', '02', '02442', '0391563', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '岡谷地', 'オカヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町毛無森', '02', '02442', '0391563', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '毛無森', 'ケナシモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町大学沢', '02', '02442', '0391563', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '大学沢', 'ダイガクザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町大学沢向', '02', '02442', '0391563', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '大学沢向', 'ダイガクザワムカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町大工窪', '02', '02442', '0391563', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '大工窪', 'ダイククボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町平佐窪', '02', '02442', '0391563', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '平佐窪', 'ヘイサクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町古館下川原', '02', '02442', '0391564', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '古館下川原', 'フルダテシモカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町六角', '02', '02442', '0391564', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '六角', 'ロッカク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町下新井田', '02', '02442', '0391565', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '下新井田', 'シモニイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町下新井田前', '02', '02442', '0391565', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '下新井田前', 'シモニイダマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町花道川原', '02', '02442', '0391565', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '花道川原', 'ハナミチカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町幸ノ神', '02', '02442', '0391566', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '幸ノ神', 'サイノカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町幸ノ神前', '02', '02442', '0391566', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '幸ノ神前', 'サイノカミマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町上大平楽', '02', '02442', '0391567', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '上大平楽', 'カミタイヘイラク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町下大平楽', '02', '02442', '0391567', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '下大平楽', 'シモタイヘイラク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町銀杏木', '02', '02442', '0391568', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '銀杏木', 'イチョウノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町銀杏木前', '02', '02442', '0391568', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '銀杏木前', 'イチョウノキマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町一本木', '02', '02442', '0391568', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '一本木', 'イッポンギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町一本木前', '02', '02442', '0391568', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '一本木前', 'イッポンギマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町應田', '02', '02442', '0391568', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '應田', 'オウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町傘松', '02', '02442', '0391568', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '傘松', 'カラカサマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町傘松前', '02', '02442', '0391568', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '傘松前', 'カラカサマツマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町根岸', '02', '02442', '0391569', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '根岸', 'ネギシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町虫追塚前', '02', '02442', '0391569', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '虫追塚前', 'ムシオイヅカマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町倉石石沢', '02', '02442', '0391701', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '倉石石沢', 'クライシイシザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町倉石中市', '02', '02442', '0391702', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '倉石中市', 'クライシナカイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町倉石又重', '02', '02442', '0391703', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '倉石又重', 'クライシマタシゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡新郷村', '02', '02450', '0391800', '青森県', 'アオモリケン', '三戸郡新郷村', 'サンノヘグンシンゴウムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('34201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡新郷村戸来', '02', '02450', '0391801', '青森県', 'アオモリケン', '三戸郡新郷村', 'サンノヘグンシンゴウムラ', '戸来', 'ヘライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡新郷村西越', '02', '02450', '0391802', '青森県', 'アオモリケン', '三戸郡新郷村', 'サンノヘグンシンゴウムラ', '西越', 'サイゴシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪市', '20', '20206', '3920000', '長野県', 'ナガノケン', '諏訪市', 'スワシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('34212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪市大和', '20', '20206', '3920001', '長野県', 'ナガノケン', '諏訪市', 'スワシ', '大和', 'オワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪市湯の脇', '20', '20206', '3920002', '長野県', 'ナガノケン', '諏訪市', 'スワシ', '湯の脇', 'ユノワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪市上諏訪', '20', '20206', '3920003', '長野県', 'ナガノケン', '諏訪市', 'スワシ', '上諏訪', 'カミスワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪市諏訪', '20', '20206', '3920004', '長野県', 'ナガノケン', '諏訪市', 'スワシ', '諏訪', 'スワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪市岡村', '20', '20206', '3920005', '長野県', 'ナガノケン', '諏訪市', 'スワシ', '岡村', 'オカムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪市元町', '20', '20206', '3920006', '長野県', 'ナガノケン', '諏訪市', 'スワシ', '元町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪市清水', '20', '20206', '3920007', '長野県', 'ナガノケン', '諏訪市', 'スワシ', '清水', 'シミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪市霧ケ峰', '20', '20206', '3920008', '長野県', 'ナガノケン', '諏訪市', 'スワシ', '霧ケ峰', 'キリガミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪市杉菜池', '20', '20206', '3920009', '長野県', 'ナガノケン', '諏訪市', 'スワシ', '杉菜池', 'スギナイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪市渋崎', '20', '20206', '3920010', '長野県', 'ナガノケン', '諏訪市', 'スワシ', '渋崎', 'シブサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪市赤羽根', '20', '20206', '3920011', '長野県', 'ナガノケン', '諏訪市', 'スワシ', '赤羽根', 'アカハネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪市四賀', '20', '20206', '3920012', '長野県', 'ナガノケン', '諏訪市', 'スワシ', '四賀', 'シガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪市沖田町', '20', '20206', '3920013', '長野県', 'ナガノケン', '諏訪市', 'スワシ', '沖田町', 'オキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪市南町', '20', '20206', '3920014', '長野県', 'ナガノケン', '諏訪市', 'スワシ', '南町', 'ミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪市中洲', '20', '20206', '3920015', '長野県', 'ナガノケン', '諏訪市', 'スワシ', '中洲', 'ナカス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪市豊田', '20', '20206', '3920016', '長野県', 'ナガノケン', '諏訪市', 'スワシ', '豊田', 'トヨダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪市城南', '20', '20206', '3920017', '長野県', 'ナガノケン', '諏訪市', 'スワシ', '城南', 'ジョウナン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪市上川', '20', '20206', '3920021', '長野県', 'ナガノケン', '諏訪市', 'スワシ', '上川', 'カミガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪市高島', '20', '20206', '3920022', '長野県', 'ナガノケン', '諏訪市', 'スワシ', '高島', 'タカシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪市小和田南', '20', '20206', '3920023', '長野県', 'ナガノケン', '諏訪市', 'スワシ', '小和田南', 'コワタミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪市小和田', '20', '20206', '3920024', '長野県', 'ナガノケン', '諏訪市', 'スワシ', '小和田', 'コワタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪市末広', '20', '20206', '3920025', '長野県', 'ナガノケン', '諏訪市', 'スワシ', '末広', 'スエヒロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪市大手', '20', '20206', '3920026', '長野県', 'ナガノケン', '諏訪市', 'スワシ', '大手', 'オオテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪市湖岸通り', '20', '20206', '3920027', '長野県', 'ナガノケン', '諏訪市', 'スワシ', '湖岸通り', 'コガンドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪市湖南', '20', '20206', '3920131', '長野県', 'ナガノケン', '諏訪市', 'スワシ', '湖南', 'コナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡おいらせ町向平豊栄', '02', '02412', '0392102', '青森県', 'アオモリケン', '上北郡おいらせ町', 'カミキタグンオイラセチョウ', '向平', 'ムカイタイ', null, null, '豊栄', 'トヨサカエ');
INSERT INTO `ms_addresses` VALUES ('34238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡おいらせ町西後谷地', '02', '02412', '0392111', '青森県', 'アオモリケン', '上北郡おいらせ町', 'カミキタグンオイラセチョウ', '西後谷地', 'ニシウシロヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡おいらせ町中野平', '02', '02412', '0392112', '青森県', 'アオモリケン', '上北郡おいらせ町', 'カミキタグンオイラセチョウ', '中野平', 'ナカノタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡おいらせ町犬毛谷地', '02', '02412', '0392113', '青森県', 'アオモリケン', '上北郡おいらせ町', 'カミキタグンオイラセチョウ', '犬毛谷地', 'イヌケヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡おいらせ町高田', '02', '02412', '0392114', '青森県', 'アオモリケン', '上北郡おいらせ町', 'カミキタグンオイラセチョウ', '高田', 'タカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡おいらせ町菜飯', '02', '02412', '0392115', '青森県', 'アオモリケン', '上北郡おいらせ町', 'カミキタグンオイラセチョウ', '菜飯', 'ナメシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡おいらせ町秋堂', '02', '02412', '0392116', '青森県', 'アオモリケン', '上北郡おいらせ町', 'カミキタグンオイラセチョウ', '秋堂', 'アキドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡おいらせ町川端', '02', '02412', '0392117', '青森県', 'アオモリケン', '上北郡おいらせ町', 'カミキタグンオイラセチョウ', '川端', 'カワバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡おいらせ町彦七川原', '02', '02412', '0392118', '青森県', 'アオモリケン', '上北郡おいらせ町', 'カミキタグンオイラセチョウ', '彦七川原', 'ヒコシチガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡おいらせ町下境', '02', '02412', '0392121', '青森県', 'アオモリケン', '上北郡おいらせ町', 'カミキタグンオイラセチョウ', '下境', 'シモサカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡おいらせ町沼小屋', '02', '02412', '0392122', '青森県', 'アオモリケン', '上北郡おいらせ町', 'カミキタグンオイラセチョウ', '沼小屋', 'ヌマコヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡おいらせ町西下谷地', '02', '02412', '0392123', '青森県', 'アオモリケン', '上北郡おいらせ町', 'カミキタグンオイラセチョウ', '西下谷地', 'ニシシモヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡おいらせ町境田', '02', '02412', '0392124', '青森県', 'アオモリケン', '上北郡おいらせ町', 'カミキタグンオイラセチョウ', '境田', 'サカイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡おいらせ町三本木', '02', '02412', '0392125', '青森県', 'アオモリケン', '上北郡おいらせ町', 'カミキタグンオイラセチョウ', '三本木', 'サンボンギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡おいらせ町間木', '02', '02412', '0392126', '青森県', 'アオモリケン', '上北郡おいらせ町', 'カミキタグンオイラセチョウ', '間木', 'マギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡おいらせ町木崎', '02', '02412', '0392127', '青森県', 'アオモリケン', '上北郡おいらせ町', 'カミキタグンオイラセチョウ', '木崎', 'キザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡おいらせ町染屋', '02', '02412', '0392128', '青森県', 'アオモリケン', '上北郡おいらせ町', 'カミキタグンオイラセチョウ', '染屋', 'ソメヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡おいらせ町中平下長根山', '02', '02412', '0392129', '青森県', 'アオモリケン', '上北郡おいらせ町', 'カミキタグンオイラセチョウ', '中平下長根山', 'ナカタイシモナガネヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡おいらせ町向川原', '02', '02412', '0392131', '青森県', 'アオモリケン', '上北郡おいらせ町', 'カミキタグンオイラセチョウ', '向川原', 'ムカイカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡おいらせ町西前川原', '02', '02412', '0392132', '青森県', 'アオモリケン', '上北郡おいらせ町', 'カミキタグンオイラセチョウ', '西前川原', 'ニシマエカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡おいらせ町上川原', '02', '02412', '0392133', '青森県', 'アオモリケン', '上北郡おいらせ町', 'カミキタグンオイラセチョウ', '上川原', 'カミカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡おいらせ町馳下り', '02', '02412', '0392134', '青森県', 'アオモリケン', '上北郡おいらせ町', 'カミキタグンオイラセチョウ', '馳下り', 'ハセクダリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡おいらせ町立蛇', '02', '02412', '0392135', '青森県', 'アオモリケン', '上北郡おいらせ町', 'カミキタグンオイラセチョウ', '立蛇', 'タチジャ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡おいらせ町中下田', '02', '02412', '0392136', '青森県', 'アオモリケン', '上北郡おいらせ町', 'カミキタグンオイラセチョウ', '中下田', 'ナカシモダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡おいらせ町明土', '02', '02412', '0392141', '青森県', 'アオモリケン', '上北郡おいらせ町', 'カミキタグンオイラセチョウ', '明土', 'アケド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡おいらせ町小前谷地', '02', '02412', '0392142', '青森県', 'アオモリケン', '上北郡おいらせ町', 'カミキタグンオイラセチョウ', '小前谷地', 'コマエヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡おいらせ町上水下', '02', '02412', '0392143', '青森県', 'アオモリケン', '上北郡おいらせ町', 'カミキタグンオイラセチョウ', '上水下', 'ジョウスイシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡おいらせ町丈の端', '02', '02412', '0392144', '青森県', 'アオモリケン', '上北郡おいらせ町', 'カミキタグンオイラセチョウ', '丈の端', 'タケノハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡おいらせ町上谷地', '02', '02412', '0392145', '青森県', 'アオモリケン', '上北郡おいらせ町', 'カミキタグンオイラセチョウ', '上谷地', 'カミヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡おいらせ町中谷地', '02', '02412', '0392146', '青森県', 'アオモリケン', '上北郡おいらせ町', 'カミキタグンオイラセチョウ', '中谷地', 'ナカヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡おいらせ町赤田前', '02', '02412', '0392147', '青森県', 'アオモリケン', '上北郡おいらせ町', 'カミキタグンオイラセチョウ', '赤田前', 'アカダマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡おいらせ町向山', '02', '02412', '0392151', '青森県', 'アオモリケン', '上北郡おいらせ町', 'カミキタグンオイラセチョウ', '向山', 'ムカイヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡おいらせ町西下川原', '02', '02412', '0392161', '青森県', 'アオモリケン', '上北郡おいらせ町', 'カミキタグンオイラセチョウ', '西下川原', 'ニシシモカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡おいらせ町南下田', '02', '02412', '0392162', '青森県', 'アオモリケン', '上北郡おいらせ町', 'カミキタグンオイラセチョウ', '南下田', 'ミナミシモダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡おいらせ町館越', '02', '02412', '0392163', '青森県', 'アオモリケン', '上北郡おいらせ町', 'カミキタグンオイラセチョウ', '館越', 'タテゴシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡おいらせ町神明前', '02', '02412', '0392164', '青森県', 'アオモリケン', '上北郡おいらせ町', 'カミキタグンオイラセチョウ', '神明前', 'シンメイマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡おいらせ町阿光坊', '02', '02412', '0392165', '青森県', 'アオモリケン', '上北郡おいらせ町', 'カミキタグンオイラセチョウ', '阿光坊', 'アコウボウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡おいらせ町新敷', '02', '02412', '0392171', '青森県', 'アオモリケン', '上北郡おいらせ町', 'カミキタグンオイラセチョウ', '新敷', 'ニシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡おいらせ町洗平', '02', '02412', '0392172', '青森県', 'アオモリケン', '上北郡おいらせ町', 'カミキタグンオイラセチョウ', '洗平', 'アライダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡おいらせ町瓢', '02', '02412', '0392173', '青森県', 'アオモリケン', '上北郡おいらせ町', 'カミキタグンオイラセチョウ', '瓢', 'フクベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡おいらせ町住吉', '02', '02412', '0392180', '青森県', 'アオモリケン', '上北郡おいらせ町', 'カミキタグンオイラセチョウ', '住吉', 'スミヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡おいらせ町古間木山', '02', '02412', '0392181', '青森県', 'アオモリケン', '上北郡おいらせ町', 'カミキタグンオイラセチョウ', '古間木山', 'フルマギヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡おいらせ町鶉久保', '02', '02412', '0392182', '青森県', 'アオモリケン', '上北郡おいらせ町', 'カミキタグンオイラセチョウ', '鶉久保', 'ウズラクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡おいらせ町鶉久保山', '02', '02412', '0392183', '青森県', 'アオモリケン', '上北郡おいらせ町', 'カミキタグンオイラセチョウ', '鶉久保山', 'ウズラクボヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡おいらせ町浜道', '02', '02412', '0392184', '青森県', 'アオモリケン', '上北郡おいらせ町', 'カミキタグンオイラセチョウ', '浜道', 'ハマミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡おいらせ町上久保', '02', '02412', '0392185', '青森県', 'アオモリケン', '上北郡おいらせ町', 'カミキタグンオイラセチョウ', '上久保', 'カミクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡おいらせ町北下田', '02', '02412', '0392186', '青森県', 'アオモリケン', '上北郡おいらせ町', 'カミキタグンオイラセチョウ', '北下田', 'キタシモダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡おいらせ町緑ケ丘', '02', '02412', '0392187', '青森県', 'アオモリケン', '上北郡おいらせ町', 'カミキタグンオイラセチョウ', '緑ケ丘', 'ミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡おいらせ町若葉', '02', '02412', '0392188', '青森県', 'アオモリケン', '上北郡おいらせ町', 'カミキタグンオイラセチョウ', '若葉', 'ワカバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡おいらせ町青葉', '02', '02412', '0392189', '青森県', 'アオモリケン', '上北郡おいらせ町', 'カミキタグンオイラセチョウ', '青葉', 'アオバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡おいらせ町', '02', '02412', '0392200', '青森県', 'アオモリケン', '上北郡おいらせ町', 'カミキタグンオイラセチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('34289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡おいらせ町二川目', '02', '02412', '0392201', '青森県', 'アオモリケン', '上北郡おいらせ町', 'カミキタグンオイラセチョウ', '二川目', 'フタカワメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡おいらせ町向平', '02', '02412', '0392202', '青森県', 'アオモリケン', '上北郡おいらせ町', 'カミキタグンオイラセチョウ', '向平', 'ムカイタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡おいらせ町一川目', '02', '02412', '0392203', '青森県', 'アオモリケン', '上北郡おいらせ町', 'カミキタグンオイラセチョウ', '一川目', 'ヒトカワメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡おいらせ町深沢', '02', '02412', '0392204', '青森県', 'アオモリケン', '上北郡おいらせ町', 'カミキタグンオイラセチョウ', '深沢', 'フカサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡おいらせ町深沢平', '02', '02412', '0392205', '青森県', 'アオモリケン', '上北郡おいらせ町', 'カミキタグンオイラセチョウ', '深沢平', 'フカサワタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡おいらせ町松原', '02', '02412', '0392206', '青森県', 'アオモリケン', '上北郡おいらせ町', 'カミキタグンオイラセチョウ', '松原', 'マツバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡おいらせ町新田', '02', '02412', '0392211', '青森県', 'アオモリケン', '上北郡おいらせ町', 'カミキタグンオイラセチョウ', '新田', 'シンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡おいらせ町東下川原', '02', '02412', '0392212', '青森県', 'アオモリケン', '上北郡おいらせ町', 'カミキタグンオイラセチョウ', '東下川原', 'ヒガシシモカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡おいらせ町堀ノ内', '02', '02412', '0392213', '青森県', 'アオモリケン', '上北郡おいらせ町', 'カミキタグンオイラセチョウ', '堀ノ内', 'ホリノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡おいらせ町東前川原', '02', '02412', '0392214', '青森県', 'アオモリケン', '上北郡おいらせ町', 'カミキタグンオイラセチョウ', '東前川原', 'ヒガシマエカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡おいらせ町下屋敷', '02', '02412', '0392215', '青森県', 'アオモリケン', '上北郡おいらせ町', 'カミキタグンオイラセチョウ', '下屋敷', 'シモヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡おいらせ町後田', '02', '02412', '0392216', '青森県', 'アオモリケン', '上北郡おいらせ町', 'カミキタグンオイラセチョウ', '後田', 'ウシロダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡おいらせ町牛込平', '02', '02412', '0392217', '青森県', 'アオモリケン', '上北郡おいらせ町', 'カミキタグンオイラセチョウ', '牛込平', 'ウシゴメタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡おいらせ町上前田', '02', '02412', '0392221', '青森県', 'アオモリケン', '上北郡おいらせ町', 'カミキタグンオイラセチョウ', '上前田', 'カミマエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡おいらせ町下前田', '02', '02412', '0392222', '青森県', 'アオモリケン', '上北郡おいらせ町', 'カミキタグンオイラセチョウ', '下前田', 'シモマエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡おいらせ町苗平谷地', '02', '02412', '0392223', '青森県', 'アオモリケン', '上北郡おいらせ町', 'カミキタグンオイラセチョウ', '苗平谷地', 'ナエヒラヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡おいらせ町下明堂', '02', '02412', '0392224', '青森県', 'アオモリケン', '上北郡おいらせ町', 'カミキタグンオイラセチョウ', '下明堂', 'シモアケドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡おいらせ町上明堂', '02', '02412', '0392225', '青森県', 'アオモリケン', '上北郡おいらせ町', 'カミキタグンオイラセチョウ', '上明堂', 'カミアケドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡おいらせ町新助川原', '02', '02412', '0392226', '青森県', 'アオモリケン', '上北郡おいらせ町', 'カミキタグンオイラセチョウ', '新助川原', 'シンスケカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡おいらせ町東下谷地', '02', '02412', '0392231', '青森県', 'アオモリケン', '上北郡おいらせ町', 'カミキタグンオイラセチョウ', '東下谷地', 'ヒガシシモヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡おいらせ町東後谷地', '02', '02412', '0392232', '青森県', 'アオモリケン', '上北郡おいらせ町', 'カミキタグンオイラセチョウ', '東後谷地', 'ヒガシウシロヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡おいらせ町沼端', '02', '02412', '0392233', '青森県', 'アオモリケン', '上北郡おいらせ町', 'カミキタグンオイラセチョウ', '沼端', 'ヌマハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡おいらせ町堤田', '02', '02412', '0392234', '青森県', 'アオモリケン', '上北郡おいらせ町', 'カミキタグンオイラセチョウ', '堤田', 'ツツミダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡おいらせ町千刈田', '02', '02412', '0392235', '青森県', 'アオモリケン', '上北郡おいらせ町', 'カミキタグンオイラセチョウ', '千刈田', 'センガリダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡おいらせ町洋光台', '02', '02412', '0392236', '青森県', 'アオモリケン', '上北郡おいらせ町', 'カミキタグンオイラセチョウ', '洋光台', 'ヨウコウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市市川町', '02', '02203', '0392241', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '市川町', 'イチカワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市多賀台', '02', '02203', '0392242', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '多賀台', 'タガダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市松ケ丘', '02', '02203', '0392243', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '松ケ丘', 'マツガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市北インター工業団地', '02', '02203', '0392245', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '北インター工業団地', 'キタインターコウギョウダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県八戸市桔梗野工業団地', '02', '02203', '0392246', '青森県', 'アオモリケン', '八戸市', 'ハチノヘシ', '桔梗野工業団地', 'キキョウノコウギョウダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡おいらせ町向山', '02', '02412', '0392251', '青森県', 'アオモリケン', '上北郡おいらせ町', 'カミキタグンオイラセチョウ', '向山', 'ムカイヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡おいらせ町向山', '02', '02412', '0392251', '青森県', 'アオモリケン', '上北郡おいらせ町', 'カミキタグンオイラセチョウ', '向山', 'ムカイヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡おいらせ町黒坂谷地', '02', '02412', '0392252', '青森県', 'アオモリケン', '上北郡おいらせ町', 'カミキタグンオイラセチョウ', '黒坂谷地', 'クロサカヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡おいらせ町獺野', '02', '02412', '0392253', '青森県', 'アオモリケン', '上北郡おいらせ町', 'カミキタグンオイラセチョウ', '獺野', 'ウソノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡おいらせ町苗振谷地', '02', '02412', '0392254', '青森県', 'アオモリケン', '上北郡おいらせ町', 'カミキタグンオイラセチョウ', '苗振谷地', 'ナエフリヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡おいらせ町土取', '02', '02412', '0392255', '青森県', 'アオモリケン', '上北郡おいらせ町', 'カミキタグンオイラセチョウ', '土取', 'ツチトリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡六戸町', '02', '02405', '0392300', '青森県', 'アオモリケン', '上北郡六戸町', 'カミキタグンロクノヘマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('34336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県三戸郡五戸町切谷内北田ノ沢', '02', '02442', '0392302', '青森県', 'アオモリケン', '三戸郡五戸町', 'サンノヘグンゴノヘマチ', '切谷内', 'キリヤナイ', null, null, '北田ノ沢', 'キタタノサワ');
INSERT INTO `ms_addresses` VALUES ('34337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡六戸町上吉田', '02', '02405', '0392311', '青森県', 'アオモリケン', '上北郡六戸町', 'カミキタグンロクノヘマチ', '上吉田', 'カミヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡六戸町下吉田', '02', '02405', '0392312', '青森県', 'アオモリケン', '上北郡六戸町', 'カミキタグンロクノヘマチ', '下吉田', 'シモヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡六戸町鶴喰', '02', '02405', '0392313', '青森県', 'アオモリケン', '上北郡六戸町', 'カミキタグンロクノヘマチ', '鶴喰', 'ツルバミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡六戸町小平', '02', '02405', '0392314', '青森県', 'アオモリケン', '上北郡六戸町', 'カミキタグンロクノヘマチ', '小平', 'コダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡六戸町柳町', '02', '02405', '0392315', '青森県', 'アオモリケン', '上北郡六戸町', 'カミキタグンロクノヘマチ', '柳町', 'ヤナギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡六戸町犬落瀬', '02', '02405', '0392371', '青森県', 'アオモリケン', '上北郡六戸町', 'カミキタグンロクノヘマチ', '犬落瀬', 'イヌオトセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡六戸町折茂', '02', '02405', '0392372', '青森県', 'アオモリケン', '上北郡六戸町', 'カミキタグンロクノヘマチ', '折茂', 'オリモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町上野', '02', '02408', '0392401', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '上野', 'ウワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町大浦', '02', '02408', '0392402', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '大浦', 'オオウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町新舘', '02', '02408', '0392403', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '新舘', 'ニイダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町上北北', '02', '02408', '0392404', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '上北北', 'カミキタキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町上北南', '02', '02408', '0392405', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '上北南', 'カミキタミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町旭北', '02', '02408', '0392406', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '旭北', 'アサヒキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町旭南', '02', '02408', '0392407', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '旭南', 'アサヒミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町', '02', '02402', '0392500', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('34356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町荒熊内', '02', '02402', '0392501', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '荒熊内', 'アラクマナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町大沢', '02', '02402', '0392502', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '大沢', 'オオサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町豊間内', '02', '02402', '0392503', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '豊間内', 'トヨマナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町寒水', '02', '02402', '0392504', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '寒水', 'ヒヤミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町立野頭', '02', '02402', '0392505', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '立野頭', 'タテノガシラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町膝森', '02', '02402', '0392506', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '膝森', 'ヒザモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町えぞ花', '02', '02402', '0392507', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', 'えぞ花', 'エゾバナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町大池', '02', '02402', '0392508', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '大池', 'オオイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町笊田川久保', '02', '02402', '0392511', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '笊田川久保', 'ザルタカワクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町笊田', '02', '02402', '0392512', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '笊田', 'ザルタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町東槻木', '02', '02402', '0392513', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '東槻木', 'ヒガシツキノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町太田野', '02', '02402', '0392514', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '太田野', 'オオタノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町蒼前', '02', '02402', '0392515', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '蒼前', 'ソウゼン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町舘野', '02', '02402', '0392516', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '舘野', 'タテノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町夏焼', '02', '02402', '0392517', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '夏焼', 'ナツヤキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町天神林', '02', '02402', '0392518', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '天神林', 'テンジンバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町天王', '02', '02402', '0392521', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '天王', 'テンノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町倉越', '02', '02402', '0392522', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '倉越', 'クラコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町影津内', '02', '02402', '0392523', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '影津内', 'カゲツナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町寺裏', '02', '02402', '0392524', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '寺裏', 'テラウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町七戸', '02', '02402', '0392525', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '七戸', 'シチノヘ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町上町野', '02', '02402', '0392526', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '上町野', 'ウワマチノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町町', '02', '02402', '0392527', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '町', 'マチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町太田', '02', '02402', '0392531', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '太田', 'オオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町大林', '02', '02402', '0392532', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '大林', 'オオバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町川去', '02', '02402', '0392533', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '川去', 'カワサリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町荒屋', '02', '02402', '0392534', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '荒屋', 'アラヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町沼ノ沢', '02', '02402', '0392535', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '沼ノ沢', 'ヌマノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町野佐掛', '02', '02402', '0392536', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '野佐掛', 'ノサカケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町賽ノ神', '02', '02402', '0392537', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '賽ノ神', 'サイノカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町寺下', '02', '02402', '0392538', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '寺下', 'テラシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町中村', '02', '02402', '0392539', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '中村', 'ナカムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町都平', '02', '02402', '0392541', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '都平', 'ミヤコタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町萩ノ沢', '02', '02402', '0392542', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '萩ノ沢', 'ハギノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町有田沢', '02', '02402', '0392543', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '有田沢', 'アリタサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町八栗平', '02', '02402', '0392544', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '八栗平', 'ハックリタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町別曽', '02', '02402', '0392545', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '別曽', 'ベッソウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町清水頭', '02', '02402', '0392546', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '清水頭', 'シミズカシラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町矢倉', '02', '02402', '0392547', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '矢倉', 'ヤグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町見町', '02', '02402', '0392548', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '見町', 'ミルマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町下見町', '02', '02402', '0392549', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '下見町', 'シモミルマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町薬師平', '02', '02402', '0392551', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '薬師平', 'ヤクシタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町鶴打田', '02', '02402', '0392552', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '鶴打田', 'ツルウチタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町八尺堂', '02', '02402', '0392553', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '八尺堂', 'ハッシャクドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町中岫', '02', '02402', '0392554', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '中岫', 'ナカグキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町前田', '02', '02402', '0392555', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '前田', 'マエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町西槻木', '02', '02402', '0392556', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '西槻木', 'ニシツキノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町西野', '02', '02402', '0392557', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '西野', 'セイノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町高屋敷', '02', '02402', '0392558', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '高屋敷', 'タカヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町山屋', '02', '02402', '0392559', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '山屋', 'ヤマヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町銀南木', '02', '02402', '0392561', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '銀南木', 'イチョウノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町倉岡', '02', '02402', '0392562', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '倉岡', 'クラオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町向平', '02', '02402', '0392563', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '向平', 'ムカイタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町古屋敷', '02', '02402', '0392564', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '古屋敷', 'フルヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町治部袋', '02', '02402', '0392565', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '治部袋', 'ジンバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町放森', '02', '02402', '0392566', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '放森', 'ハナツモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町鶴児平', '02', '02402', '0392567', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '鶴児平', 'ツルノコタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町左組', '02', '02402', '0392568', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '左組', 'サグミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町馬門川原', '02', '02402', '0392569', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '馬門川原', 'マカドガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町蛇坂', '02', '02402', '0392571', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '蛇坂', 'ヘビサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町城ノ後', '02', '02402', '0392572', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '城ノ後', 'シロノアト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町野続', '02', '02402', '0392573', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '野続', 'ノツヅキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町宇道坂', '02', '02402', '0392574', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '宇道坂', 'ウドウザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町作田', '02', '02402', '0392575', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '作田', 'サクタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町桜田', '02', '02402', '0392576', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '桜田', 'サクラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町鍛治林', '02', '02402', '0392577', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '鍛治林', 'カジバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町貝ノ口', '02', '02402', '0392578', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '貝ノ口', 'カイノクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町十役野', '02', '02402', '0392579', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '十役野', 'トヤクノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町東上川原', '02', '02402', '0392581', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '東上川原', 'ヒガシカミカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町西上川原', '02', '02402', '0392582', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '西上川原', 'ニシカミカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町前川原', '02', '02402', '0392583', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '前川原', 'マエカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町後川原', '02', '02402', '0392584', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '後川原', 'ウシロカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町上ノ山', '02', '02402', '0392585', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '上ノ山', 'ウエノヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町海内', '02', '02402', '0392586', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '海内', 'ウミナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町上屋田', '02', '02402', '0392587', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '上屋田', 'ウエヤダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町和田下', '02', '02402', '0392588', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '和田下', 'ワダシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町和田', '02', '02402', '0392589', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '和田', 'ワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町', '02', '02408', '0392600', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('34440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町ガス平', '02', '02408', '0392601', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', 'ガス平', 'ガスタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町五十嵐', '02', '02408', '0392602', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '五十嵐', 'イガラシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町細津橋ノ上', '02', '02408', '0392602', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '細津橋ノ上', 'ホソツハシノカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町横沢山', '02', '02408', '0392603', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '横沢山', 'ヨコサワヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町空久保', '02', '02408', '0392604', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '空久保', 'アキクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町饅頭長根', '02', '02408', '0392604', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '饅頭長根', 'マンジュウナガネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町水流', '02', '02408', '0392604', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '水流', 'ミズナガレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町横沢', '02', '02408', '0392604', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '横沢', 'ヨコサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町横沢頭', '02', '02408', '0392604', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '横沢頭', 'ヨコサワガシラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町淋代', '02', '02408', '0392605', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '淋代', 'サビシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町高森', '02', '02408', '0392605', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '高森', 'タカモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町数牛', '02', '02408', '0392606', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '数牛', 'カソシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町谷地頭', '02', '02408', '0392606', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '谷地頭', 'ヤジガシラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町姥沢', '02', '02408', '0392607', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '姥沢', 'ウバサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町中村道ノ上', '02', '02408', '0392611', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '中村道ノ上', 'ナカムラミチノカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町中村道ノ下', '02', '02408', '0392611', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '中村道ノ下', 'ナカムラミチノシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町狼ノ沢', '02', '02408', '0392612', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '狼ノ沢', 'オイノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町沼添左ノ平', '02', '02408', '0392612', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '沼添左ノ平', 'ヌマソエサノタイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町浜台', '02', '02408', '0392612', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '浜台', 'ハマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町子ノ鳥平', '02', '02408', '0392613', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '子ノ鳥平', 'ネノトリタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町野田頭', '02', '02408', '0392613', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '野田頭', 'ノダガシラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町野田頭山', '02', '02408', '0392613', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '野田頭山', 'ノダガシラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町野田尻', '02', '02408', '0392613', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '野田尻', 'ノダジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町切左坂道ノ下', '02', '02408', '0392614', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '切左坂道ノ下', 'キリサザカミチノシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町細津', '02', '02408', '0392615', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '細津', 'ホソツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町萌出道ノ上', '02', '02408', '0392615', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '萌出道ノ上', 'モダシミチノカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町萌出道ノ下', '02', '02408', '0392615', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '萌出道ノ下', 'モダシミチノシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町切左坂道ノ上', '02', '02408', '0392616', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '切左坂道ノ上', 'キリサザカミチノカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町水喰', '02', '02408', '0392617', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '水喰', 'ミズハミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町水喰向', '02', '02408', '0392617', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '水喰向', 'ミズハミムカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町田ノ沢', '02', '02408', '0392621', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '田ノ沢', 'タノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町浜家苫', '02', '02408', '0392622', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '浜家苫', 'ハマケトバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町船ケ沢', '02', '02408', '0392622', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '船ケ沢', 'フネガサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町大久保', '02', '02408', '0392623', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '大久保', 'オオクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町鶴ケ崎', '02', '02408', '0392623', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '鶴ケ崎', 'ツルガサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町横志多', '02', '02408', '0392623', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '横志多', 'ヨコシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町蓼内久保', '02', '02408', '0392624', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '蓼内久保', 'タテナイクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町古屋敷', '02', '02408', '0392624', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '古屋敷', 'フルヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町道ノ北', '02', '02408', '0392624', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '道ノ北', 'ミチノキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町長久保', '02', '02408', '0392625', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '長久保', 'ナガクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町後久保', '02', '02408', '0392626', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '後久保', 'ウシロクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町上久保', '02', '02408', '0392626', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '上久保', 'カミクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町堤尻', '02', '02408', '0392626', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '堤尻', 'ツツミジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町漆玉', '02', '02408', '0392627', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '漆玉', 'シッタマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町滝沢平', '02', '02408', '0392631', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '滝沢平', 'タキサワタイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町日影林ノ上山', '02', '02408', '0392632', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '日影林ノ上山', 'ヒカゲハヤシノカミヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町素柄邸', '02', '02408', '0392633', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '素柄邸', 'スガラヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町和山平', '02', '02408', '0392633', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '和山平', 'ワヤマタイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町往来ノ下', '02', '02408', '0392634', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '往来ノ下', 'オオライノシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町乙越', '02', '02408', '0392635', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '乙越', 'オツコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町舘', '02', '02408', '0392635', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '舘', 'ダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町鳥口平', '02', '02408', '0392635', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '鳥口平', 'トリグチタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町往来ノ上', '02', '02408', '0392636', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '往来ノ上', 'オオライノカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町枋木', '02', '02408', '0392641', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '枋木', 'コボノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町寒水', '02', '02408', '0392642', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '寒水', 'ヒヤミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町寒水下', '02', '02408', '0392642', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '寒水下', 'ヒヤミズシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町寒水山', '02', '02408', '0392642', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '寒水山', 'ヒヤミズヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町乙部道ノ上', '02', '02408', '0392643', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '乙部道ノ上', 'オトベミチノカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町乙部道ノ下', '02', '02408', '0392643', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '乙部道ノ下', 'オトベミチノシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町保戸沢家ノ後', '02', '02408', '0392644', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '保戸沢家ノ後', 'ホドサワイエノウシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町保戸沢家ノ上', '02', '02408', '0392644', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '保戸沢家ノ上', 'ホドサワイエノカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町保戸沢家ノ前', '02', '02408', '0392644', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '保戸沢家ノ前', 'ホドサワイエノマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町外蛯沢前平', '02', '02408', '0392645', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '外蛯沢前平', 'ソトエビサワマエタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町外蛯沢西平', '02', '02408', '0392646', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '外蛯沢西平', 'ソトエビサワニシタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町外蛯沢後久保', '02', '02408', '0392647', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '外蛯沢後久保', 'ソトエビサワウシロクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町外蛯沢北久保', '02', '02408', '0392648', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '外蛯沢北久保', 'ソトエビサワキタクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町大沢', '02', '02408', '0392651', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '大沢', 'オオサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町ほとけ沢', '02', '02408', '0392652', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', 'ほとけ沢', 'ホトケサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町下山', '02', '02408', '0392653', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '下山', 'シモヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町塔ノ沢山', '02', '02408', '0392654', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '塔ノ沢山', 'トウノサワヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町内蛯沢道ノ上', '02', '02408', '0392655', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '内蛯沢道ノ上', 'ウチエビサワミチノカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町内蛯沢向', '02', '02408', '0392656', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '内蛯沢向', 'ウチエビサワムカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町赤川道', '02', '02408', '0392657', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '赤川道', 'アカガワミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町上笹橋', '02', '02408', '0392661', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '上笹橋', 'カミササバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町下笹橋', '02', '02408', '0392662', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '下笹橋', 'シモササバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町舘花', '02', '02408', '0392663', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '舘花', 'ダテハナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町乙供', '02', '02408', '0392664', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '乙供', 'オットモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町柳沢', '02', '02408', '0392665', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '柳沢', 'ヤナギザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町乙供山', '02', '02408', '0392666', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '乙供山', 'オットモヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町膳前', '02', '02408', '0392667', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '膳前', 'ゼンマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町北膳前', '02', '02408', '0392668', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '北膳前', 'キタゼンマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町篠内平', '02', '02408', '0392668', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '篠内平', 'シノナイタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町小沢', '02', '02408', '0392671', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '小沢', 'オザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町栗山添', '02', '02408', '0392672', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '栗山添', 'クリヤマゾイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町向籏屋', '02', '02408', '0392672', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '向籏屋', 'ムカイハタヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町馬尻', '02', '02408', '0392673', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '馬尻', 'ウマジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町大籏屋', '02', '02408', '0392673', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '大籏屋', 'オオハタヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町向屋敷', '02', '02408', '0392673', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '向屋敷', 'ムカイヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町山ノ下', '02', '02408', '0392673', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '山ノ下', 'ヤマノシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町千曳下山', '02', '02408', '0392674', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '千曳下山', 'チビキシモヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町夫雑原', '02', '02408', '0392674', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '夫雑原', 'ブゾウハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町千曳', '02', '02408', '0392675', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '千曳', 'チビキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町下板橋', '02', '02408', '0392676', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '下板橋', 'シモイタバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町夫雑原下山', '02', '02408', '0392677', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '夫雑原下山', 'ブゾウハラシモヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町狐沢山', '02', '02408', '0392678', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '狐沢山', 'キツネサワヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町坂ノ下', '02', '02408', '0392678', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '坂ノ下', 'サカノシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町田面木', '02', '02408', '0392678', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '田面木', 'タモギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町長者久保', '02', '02408', '0392678', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '長者久保', 'チョウジャクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町家ノ前', '02', '02408', '0392681', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '家ノ前', 'イエノマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町山添', '02', '02408', '0392681', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '山添', 'ヤマゾイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町石坂', '02', '02408', '0392682', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '石坂', 'イシザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町湯沢', '02', '02408', '0392682', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '湯沢', 'ユザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町板橋山', '02', '02408', '0392683', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '板橋山', 'イタバシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町大平', '02', '02408', '0392683', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '大平', 'オオダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町向平', '02', '02408', '0392684', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '向平', 'ムカイタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町家ノ下タ', '02', '02408', '0392685', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '家ノ下タ', 'イエノシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町上板橋家ノ後', '02', '02408', '0392685', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '上板橋家ノ後', 'カミイタバシイエノウシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町宇道坂', '02', '02408', '0392686', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '宇道坂', 'ウドウサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町塞ノ神', '02', '02408', '0392686', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '塞ノ神', 'サイノカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町添ノ沢', '02', '02408', '0392686', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '添ノ沢', 'ソエノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町上清水目', '02', '02408', '0392687', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '上清水目', 'カミシミズメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町林ノ下', '02', '02408', '0392687', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '林ノ下', 'ハヤシノシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡東北町大撫沢', '02', '02408', '0392688', '青森県', 'アオモリケン', '上北郡東北町', 'カミキタグントウホクマチ', '大撫沢', 'オオナデサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町中天間舘', '02', '02402', '0392711', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '中天間舘', 'ナカテンマダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町北天間舘', '02', '02402', '0392712', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '北天間舘', 'キタテンマダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町東天間舘', '02', '02402', '0392713', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '東天間舘', 'ヒガシテンマダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町上志多', '02', '02402', '0392714', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '上志多', 'カミシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町尾山頭', '02', '02402', '0392715', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '尾山頭', 'オヤマガシラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町菩提木', '02', '02402', '0392716', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '菩提木', 'ボダイギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町柳平', '02', '02402', '0392717', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '柳平', 'ヤナギタイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町志茂川原', '02', '02402', '0392721', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '志茂川原', 'シモカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町向川原', '02', '02402', '0392722', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '向川原', 'ムカイカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町下志多', '02', '02402', '0392723', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '下志多', 'シモシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町上平', '02', '02402', '0392724', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '上平', 'カミタイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町上川原', '02', '02402', '0392725', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '上川原', 'カミカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町李川原', '02', '02402', '0392726', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '李川原', 'スモモカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町後平', '02', '02402', '0392731', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '後平', 'ウシロタイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町卒古沢', '02', '02402', '0392732', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '卒古沢', 'ソツコザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町天間舘前川原', '02', '02402', '0392733', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '天間舘前川原', 'テンマダテマエカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町猪ノ鼻', '02', '02402', '0392741', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '猪ノ鼻', 'イノハナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町舟場向川久保', '02', '02402', '0392742', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '舟場向川久保', 'フナバムカイガワクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町寺沢前', '02', '02402', '0392743', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '寺沢前', 'テラサワマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町塚長根', '02', '02402', '0392744', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '塚長根', 'ツカナガネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町夷堂', '02', '02402', '0392745', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '夷堂', 'エビスドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町附田川目', '02', '02402', '0392746', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '附田川目', 'ツクタカワメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町附田家ノ前', '02', '02402', '0392747', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '附田家ノ前', 'ツクタイエノマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町南舘向', '02', '02402', '0392748', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '南舘向', 'ミナミダテムカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町貝塚家ノ前', '02', '02402', '0392751', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '貝塚家ノ前', 'カイヅカイエノマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町鉢森平', '02', '02402', '0392752', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '鉢森平', 'ハチモリタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町竿打川原', '02', '02402', '0392753', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '竿打川原', 'サオウチカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町地蔵堂', '02', '02402', '0392754', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '地蔵堂', 'ジゾウドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町榎林家ノ前', '02', '02402', '0392755', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '榎林家ノ前', 'エノキバヤシイエノマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町榎林家ノ後', '02', '02402', '0392756', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '榎林家ノ後', 'エノキバヤシイエノウシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町卒古沢南平', '02', '02402', '0392757', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '卒古沢南平', 'ソツコザワミナミタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町二ツ森家ノ後', '02', '02402', '0392761', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '二ツ森家ノ後', 'フタツモリイエノウシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町二ツ森家ノ下', '02', '02402', '0392762', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '二ツ森家ノ下', 'フタツモリイエノシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町二ツ森家ノ表', '02', '02402', '0392763', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '二ツ森家ノ表', 'フタツモリイエノオモテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町姥沢', '02', '02402', '0392771', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '姥沢', 'ウバサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町下田坪', '02', '02402', '0392772', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '下田坪', 'シモタツボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町前左野', '02', '02402', '0392773', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '前左野', 'マエサノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町柴舘道ノ下', '02', '02402', '0392774', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '柴舘道ノ下', 'シバダテミチノシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町李沢道ノ下', '02', '02402', '0392775', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '李沢道ノ下', 'スモモザワミチノシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町李沢家ノ前', '02', '02402', '0392776', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '李沢家ノ前', 'スモモザワイエノマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町李沢家ノ後', '02', '02402', '0392777', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '李沢家ノ後', 'スモモザワイエノウシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町坂ノ外', '02', '02402', '0392778', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '坂ノ外', 'サカノソト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町榎林古屋敷', '02', '02402', '0392779', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '榎林古屋敷', 'エノキバヤシフルヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町花松林ノ根', '02', '02402', '0392781', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '花松林ノ根', 'ハナマツハヤシノネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町中岫太田嶋', '02', '02402', '0392782', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '中岫太田嶋', 'ナカグキオオタシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町中岫番屋', '02', '02402', '0392783', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '中岫番屋', 'ナカグキバンヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町中岫長沢下', '02', '02402', '0392784', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '中岫長沢下', 'ナカグキナガサワシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町中岫村ノ上', '02', '02402', '0392785', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '中岫村ノ上', 'ナカグキムラノカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町中岫東道添', '02', '02402', '0392786', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '中岫東道添', 'ナカグキヒガシミチゾエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町野崎', '02', '02402', '0392801', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '野崎', 'ノザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町野崎前平', '02', '02402', '0392802', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '野崎前平', 'ノザキマエヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町野崎森ノ下', '02', '02402', '0392803', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '野崎森ノ下', 'ノザキモリノシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町野崎狐久保', '02', '02402', '0392804', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '野崎狐久保', 'ノザキキツネクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町原久保', '02', '02402', '0392805', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '原久保', 'ハラクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町天間舘荒谷', '02', '02402', '0392811', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '天間舘荒谷', 'テンマダテアラヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町小田下', '02', '02402', '0392812', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '小田下', 'コダシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町小田平', '02', '02402', '0392813', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '小田平', 'コダタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町道ノ下', '02', '02402', '0392814', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '道ノ下', 'ミチノシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町森ノ下', '02', '02402', '0392815', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '森ノ下', 'モリノシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町家ノ裏', '02', '02402', '0392816', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '家ノ裏', 'イエノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町大平', '02', '02402', '0392821', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '大平', 'オオダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町小又', '02', '02402', '0392822', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '小又', 'コマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町館ノ下', '02', '02402', '0392823', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '館ノ下', 'ダテノシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町家ノ下', '02', '02402', '0392824', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '家ノ下', 'イエノシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町家ノ上', '02', '02402', '0392825', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '家ノ上', 'イエノカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町中野', '02', '02402', '0392826', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '中野', 'ナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町森ノ上', '02', '02402', '0392827', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '森ノ上', 'モリノカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町森ケ沢', '02', '02402', '0392828', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '森ケ沢', 'モリガサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町金沢平', '02', '02402', '0392831', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '金沢平', 'カナザワタイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町道ノ上', '02', '02402', '0392832', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '道ノ上', 'ミチノカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町家ノ前', '02', '02402', '0392833', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '家ノ前', 'イエノマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町向中野川向', '02', '02402', '0392834', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '向中野川向', 'ムカイナカノカワムカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町松ケ沢', '02', '02402', '0392835', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '松ケ沢', 'マツガサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町下鳥谷部', '02', '02402', '0392841', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '下鳥谷部', 'シモトリヤベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町中鳥谷', '02', '02402', '0392842', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '中鳥谷', 'ナカトリヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町橋ノ上', '02', '02402', '0392843', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '橋ノ上', 'ハシノカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町手代森', '02', '02402', '0392844', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '手代森', 'テシロモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町作田道', '02', '02402', '0392845', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '作田道', 'サクタミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町鳥谷部', '02', '02402', '0392846', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '鳥谷部', 'トリヤベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町堰根', '02', '02402', '0392851', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '堰根', 'セキネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町さそう', '02', '02402', '0392852', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', 'さそう', 'サソウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町さそう平', '02', '02402', '0392853', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', 'さそう平', 'サソウタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町高井名', '02', '02402', '0392854', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '高井名', 'タカイナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町底田', '02', '02402', '0392855', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '底田', 'ソコタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町古和備', '02', '02402', '0392856', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '古和備', 'コワソナエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町天間舘倉越', '02', '02402', '0392857', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '天間舘倉越', 'テンマダテクラコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町天間舘大沢', '02', '02402', '0392861', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '天間舘大沢', 'テンマダテオオサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町夏間木', '02', '02402', '0392862', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '夏間木', 'ナツマギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町十枝内', '02', '02402', '0392863', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '十枝内', 'トシナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町下モ川原', '02', '02402', '0392864', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '下モ川原', 'シモカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町市ノ渡', '02', '02402', '0392865', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '市ノ渡', 'イチノワタリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町栗ノ木沢', '02', '02402', '0392866', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '栗ノ木沢', 'クリノキサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町白石', '02', '02402', '0392871', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '白石', 'シロイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町下タ川原', '02', '02402', '0392872', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '下タ川原', 'シタカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町天間舘寒水', '02', '02402', '0392873', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '天間舘寒水', 'テンマダテカンスイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町坪川原', '02', '02402', '0392874', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '坪川原', 'ツボカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町淋代', '02', '02402', '0392875', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '淋代', 'サビシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町堰代', '02', '02402', '0392876', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '堰代', 'セキシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡七戸町五庵ノ下', '02', '02402', '0392877', '青森県', 'アオモリケン', '上北郡七戸町', 'カミキタグンシチノヘマチ', '五庵ノ下', 'ゴアンノシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪郡下諏訪町', '20', '20361', '3930000', '長野県', 'ナガノケン', '諏訪郡下諏訪町', 'スワグンシモスワマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('34678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪郡下諏訪町樋橋', '20', '20361', '3930001', '長野県', 'ナガノケン', '諏訪郡下諏訪町', 'スワグンシモスワマチ', '樋橋', 'トヨハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪郡下諏訪町東俣', '20', '20361', '3930002', '長野県', 'ナガノケン', '諏訪郡下諏訪町', 'スワグンシモスワマチ', '東俣', 'ヒガシマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪郡下諏訪町萩倉', '20', '20361', '3930003', '長野県', 'ナガノケン', '諏訪郡下諏訪町', 'スワグンシモスワマチ', '萩倉', 'ハギクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪郡下諏訪町東町下', '20', '20361', '3930004', '長野県', 'ナガノケン', '諏訪郡下諏訪町', 'スワグンシモスワマチ', '東町下', 'ヒガシマチシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪郡下諏訪町東町中', '20', '20361', '3930005', '長野県', 'ナガノケン', '諏訪郡下諏訪町', 'スワグンシモスワマチ', '東町中', 'ヒガシマチナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪郡下諏訪町東町上', '20', '20361', '3930006', '長野県', 'ナガノケン', '諏訪郡下諏訪町', 'スワグンシモスワマチ', '東町上', 'ヒガシマチウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪郡下諏訪町下屋敷', '20', '20361', '3930007', '長野県', 'ナガノケン', '諏訪郡下諏訪町', 'スワグンシモスワマチ', '下屋敷', 'シモヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪郡下諏訪町町屋敷', '20', '20361', '3930008', '長野県', 'ナガノケン', '諏訪郡下諏訪町', 'スワグンシモスワマチ', '町屋敷', 'マチヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪郡下諏訪町新町上', '20', '20361', '3930011', '長野県', 'ナガノケン', '諏訪郡下諏訪町', 'スワグンシモスワマチ', '新町上', 'シンマチウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪郡下諏訪町横町', '20', '20361', '3930012', '長野県', 'ナガノケン', '諏訪郡下諏訪町', 'スワグンシモスワマチ', '横町', 'ヨコマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪郡下諏訪町小湯の上', '20', '20361', '3930013', '長野県', 'ナガノケン', '諏訪郡下諏訪町', 'スワグンシモスワマチ', '小湯の上', 'コユノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪郡下諏訪町木の下', '20', '20361', '3930014', '長野県', 'ナガノケン', '諏訪郡下諏訪町', 'スワグンシモスワマチ', '木の下', 'キノシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪郡下諏訪町立町', '20', '20361', '3930015', '長野県', 'ナガノケン', '諏訪郡下諏訪町', 'スワグンシモスワマチ', '立町', 'タツマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪郡下諏訪町湯田町', '20', '20361', '3930016', '長野県', 'ナガノケン', '諏訪郡下諏訪町', 'スワグンシモスワマチ', '湯田町', 'ユダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪郡下諏訪町湯田仲町', '20', '20361', '3930017', '長野県', 'ナガノケン', '諏訪郡下諏訪町', 'スワグンシモスワマチ', '湯田仲町', 'ユダナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪郡下諏訪町新町下', '20', '20361', '3930018', '長野県', 'ナガノケン', '諏訪郡下諏訪町', 'スワグンシモスワマチ', '新町下', 'シンマチシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪郡下諏訪町横町木の下', '20', '20361', '3930019', '長野県', 'ナガノケン', '諏訪郡下諏訪町', 'スワグンシモスワマチ', '横町木の下', 'ヨコマチキノシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪郡下諏訪町武居', '20', '20361', '3930021', '長野県', 'ナガノケン', '諏訪郡下諏訪町', 'スワグンシモスワマチ', '武居', 'タケイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪郡下諏訪町関屋', '20', '20361', '3930022', '長野県', 'ナガノケン', '諏訪郡下諏訪町', 'スワグンシモスワマチ', '関屋', 'セキヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪郡下諏訪町富ケ丘', '20', '20361', '3930023', '長野県', 'ナガノケン', '諏訪郡下諏訪町', 'スワグンシモスワマチ', '富ケ丘', 'トミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪郡下諏訪町五官', '20', '20361', '3930024', '長野県', 'ナガノケン', '諏訪郡下諏訪町', 'スワグンシモスワマチ', '五官', 'ゴカン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪郡下諏訪町本郷', '20', '20361', '3930025', '長野県', 'ナガノケン', '諏訪郡下諏訪町', 'スワグンシモスワマチ', '本郷', 'ホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪郡下諏訪町久保海道', '20', '20361', '3930026', '長野県', 'ナガノケン', '諏訪郡下諏訪町', 'スワグンシモスワマチ', '久保海道', 'クボカイドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪郡下諏訪町東豊', '20', '20361', '3930031', '長野県', 'ナガノケン', '諏訪郡下諏訪町', 'スワグンシモスワマチ', '東豊', 'ヒガシユタカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪郡下諏訪町西浜', '20', '20361', '3930032', '長野県', 'ナガノケン', '諏訪郡下諏訪町', 'スワグンシモスワマチ', '西浜', 'ニシハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪郡下諏訪町高木', '20', '20361', '3930033', '長野県', 'ナガノケン', '諏訪郡下諏訪町', 'スワグンシモスワマチ', '高木', 'タカキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪郡下諏訪町高浜', '20', '20361', '3930034', '長野県', 'ナガノケン', '諏訪郡下諏訪町', 'スワグンシモスワマチ', '高浜', 'タカハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪郡下諏訪町西豊', '20', '20361', '3930035', '長野県', 'ナガノケン', '諏訪郡下諏訪町', 'スワグンシモスワマチ', '西豊', 'ニシユタカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪郡下諏訪町西四王', '20', '20361', '3930041', '長野県', 'ナガノケン', '諏訪郡下諏訪町', 'スワグンシモスワマチ', '西四王', 'ニシシオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪郡下諏訪町北四王', '20', '20361', '3930042', '長野県', 'ナガノケン', '諏訪郡下諏訪町', 'スワグンシモスワマチ', '北四王', 'キタシオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪郡下諏訪町東四王', '20', '20361', '3930043', '長野県', 'ナガノケン', '諏訪郡下諏訪町', 'スワグンシモスワマチ', '東四王', 'ヒガシシオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪郡下諏訪町湖畔町', '20', '20361', '3930044', '長野県', 'ナガノケン', '諏訪郡下諏訪町', 'スワグンシモスワマチ', '湖畔町', 'コハンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪郡下諏訪町南四王', '20', '20361', '3930045', '長野県', 'ナガノケン', '諏訪郡下諏訪町', 'スワグンシモスワマチ', '南四王', 'ミナミシオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪郡下諏訪町東赤砂', '20', '20361', '3930046', '長野県', 'ナガノケン', '諏訪郡下諏訪町', 'スワグンシモスワマチ', '東赤砂', 'ヒガシアカスナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪郡下諏訪町西赤砂', '20', '20361', '3930047', '長野県', 'ナガノケン', '諏訪郡下諏訪町', 'スワグンシモスワマチ', '西赤砂', 'ニシアカスナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪郡下諏訪町大社通', '20', '20361', '3930051', '長野県', 'ナガノケン', '諏訪郡下諏訪町', 'スワグンシモスワマチ', '大社通', 'タイシャドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪郡下諏訪町上久保', '20', '20361', '3930052', '長野県', 'ナガノケン', '諏訪郡下諏訪町', 'スワグンシモスワマチ', '上久保', 'カミクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪郡下諏訪町上馬場', '20', '20361', '3930053', '長野県', 'ナガノケン', '諏訪郡下諏訪町', 'スワグンシモスワマチ', '上馬場', 'カミバツパ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪郡下諏訪町菅野町', '20', '20361', '3930054', '長野県', 'ナガノケン', '諏訪郡下諏訪町', 'スワグンシモスワマチ', '菅野町', 'スゲノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪郡下諏訪町富士見町', '20', '20361', '3930055', '長野県', 'ナガノケン', '諏訪郡下諏訪町', 'スワグンシモスワマチ', '富士見町', 'フジミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪郡下諏訪町広瀬町', '20', '20361', '3930056', '長野県', 'ナガノケン', '諏訪郡下諏訪町', 'スワグンシモスワマチ', '広瀬町', 'ヒロセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪郡下諏訪町友之町', '20', '20361', '3930057', '長野県', 'ナガノケン', '諏訪郡下諏訪町', 'スワグンシモスワマチ', '友之町', 'トモノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪郡下諏訪町御田町', '20', '20361', '3930061', '長野県', 'ナガノケン', '諏訪郡下諏訪町', 'スワグンシモスワマチ', '御田町', 'ミタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪郡下諏訪町平沢町', '20', '20361', '3930062', '長野県', 'ナガノケン', '諏訪郡下諏訪町', 'スワグンシモスワマチ', '平沢町', 'ヒラサワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪郡下諏訪町花咲町', '20', '20361', '3930063', '長野県', 'ナガノケン', '諏訪郡下諏訪町', 'スワグンシモスワマチ', '花咲町', 'ハナサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪郡下諏訪町中汐町', '20', '20361', '3930064', '長野県', 'ナガノケン', '諏訪郡下諏訪町', 'スワグンシモスワマチ', '中汐町', 'ナカシオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪郡下諏訪町魁町', '20', '20361', '3930065', '長野県', 'ナガノケン', '諏訪郡下諏訪町', 'スワグンシモスワマチ', '魁町', 'サキガケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪郡下諏訪町曙町', '20', '20361', '3930066', '長野県', 'ナガノケン', '諏訪郡下諏訪町', 'スワグンシモスワマチ', '曙町', 'アケボノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪郡下諏訪町矢木東', '20', '20361', '3930067', '長野県', 'ナガノケン', '諏訪郡下諏訪町', 'スワグンシモスワマチ', '矢木東', 'ヤギヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪郡下諏訪町春日町', '20', '20361', '3930068', '長野県', 'ナガノケン', '諏訪郡下諏訪町', 'スワグンシモスワマチ', '春日町', 'カスガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪郡下諏訪町仲町', '20', '20361', '3930071', '長野県', 'ナガノケン', '諏訪郡下諏訪町', 'スワグンシモスワマチ', '仲町', 'ナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪郡下諏訪町桜町', '20', '20361', '3930072', '長野県', 'ナガノケン', '諏訪郡下諏訪町', 'スワグンシモスワマチ', '桜町', 'サクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪郡下諏訪町塚田町', '20', '20361', '3930073', '長野県', 'ナガノケン', '諏訪郡下諏訪町', 'スワグンシモスワマチ', '塚田町', 'ツカダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪郡下諏訪町緑町', '20', '20361', '3930074', '長野県', 'ナガノケン', '諏訪郡下諏訪町', 'スワグンシモスワマチ', '緑町', 'ミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪郡下諏訪町中央通', '20', '20361', '3930075', '長野県', 'ナガノケン', '諏訪郡下諏訪町', 'スワグンシモスワマチ', '中央通', 'チュウオウドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪郡下諏訪町矢木西', '20', '20361', '3930076', '長野県', 'ナガノケン', '諏訪郡下諏訪町', 'スワグンシモスワマチ', '矢木西', 'ヤギニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪郡下諏訪町矢木町', '20', '20361', '3930077', '長野県', 'ナガノケン', '諏訪郡下諏訪町', 'スワグンシモスワマチ', '矢木町', 'ヤギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪郡下諏訪町田中町', '20', '20361', '3930078', '長野県', 'ナガノケン', '諏訪郡下諏訪町', 'スワグンシモスワマチ', '田中町', 'タナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪郡下諏訪町社東町', '20', '20361', '3930081', '長野県', 'ナガノケン', '諏訪郡下諏訪町', 'スワグンシモスワマチ', '社東町', 'ヤシロヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪郡下諏訪町西弥生町', '20', '20361', '3930082', '長野県', 'ナガノケン', '諏訪郡下諏訪町', 'スワグンシモスワマチ', '西弥生町', 'ニシヤヨイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪郡下諏訪町東弥生町', '20', '20361', '3930083', '長野県', 'ナガノケン', '諏訪郡下諏訪町', 'スワグンシモスワマチ', '東弥生町', 'ヒガシヤヨイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪郡下諏訪町栄町', '20', '20361', '3930084', '長野県', 'ナガノケン', '諏訪郡下諏訪町', 'スワグンシモスワマチ', '栄町', 'サカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪郡下諏訪町東鷹野町', '20', '20361', '3930085', '長野県', 'ナガノケン', '諏訪郡下諏訪町', 'スワグンシモスワマチ', '東鷹野町', 'ヒガシタカノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪郡下諏訪町清水町', '20', '20361', '3930086', '長野県', 'ナガノケン', '諏訪郡下諏訪町', 'スワグンシモスワマチ', '清水町', 'シミズマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪郡下諏訪町西鷹野町', '20', '20361', '3930087', '長野県', 'ナガノケン', '諏訪郡下諏訪町', 'スワグンシモスワマチ', '西鷹野町', 'ニシタカノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪郡下諏訪町星が丘', '20', '20361', '3930091', '長野県', 'ナガノケン', '諏訪郡下諏訪町', 'スワグンシモスワマチ', '星が丘', 'ホシガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪郡下諏訪町大門', '20', '20361', '3930092', '長野県', 'ナガノケン', '諏訪郡下諏訪町', 'スワグンシモスワマチ', '大門', 'ダイモン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪郡下諏訪町東山田', '20', '20361', '3930093', '長野県', 'ナガノケン', '諏訪郡下諏訪町', 'スワグンシモスワマチ', '東山田', 'ヒガシヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡野辺地町', '02', '02401', '0393100', '青森県', 'アオモリケン', '上北郡野辺地町', 'カミキタグンノヘジマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('34747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡野辺地町浜掛', '02', '02401', '0393101', '青森県', 'アオモリケン', '上北郡野辺地町', 'カミキタグンノヘジマチ', '浜掛', 'ハマカケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡野辺地町米内沢', '02', '02401', '0393102', '青森県', 'アオモリケン', '上北郡野辺地町', 'カミキタグンノヘジマチ', '米内沢', 'ヨナイサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡野辺地町田名部道', '02', '02401', '0393103', '青森県', 'アオモリケン', '上北郡野辺地町', 'カミキタグンノヘジマチ', '田名部道', 'タナブミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡野辺地町大月平', '02', '02401', '0393104', '青森県', 'アオモリケン', '上北郡野辺地町', 'カミキタグンノヘジマチ', '大月平', 'オオツキタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡野辺地町有戸鳥井平', '02', '02401', '0393105', '青森県', 'アオモリケン', '上北郡野辺地町', 'カミキタグンノヘジマチ', '有戸鳥井平', 'アリトトリイタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡野辺地町木明', '02', '02401', '0393105', '青森県', 'アオモリケン', '上北郡野辺地町', 'カミキタグンノヘジマチ', '木明', 'キミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡野辺地町東太田沢', '02', '02401', '0393105', '青森県', 'アオモリケン', '上北郡野辺地町', 'カミキタグンノヘジマチ', '東太田沢', 'ヒガシオオタサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡野辺地町干草橋', '02', '02401', '0393105', '青森県', 'アオモリケン', '上北郡野辺地町', 'カミキタグンノヘジマチ', '干草橋', 'ヒクサバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡野辺地町蟹田', '02', '02401', '0393106', '青森県', 'アオモリケン', '上北郡野辺地町', 'カミキタグンノヘジマチ', '蟹田', 'カニタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡野辺地町古明前', '02', '02401', '0393106', '青森県', 'アオモリケン', '上北郡野辺地町', 'カミキタグンノヘジマチ', '古明前', 'フルミョウマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡野辺地町明前', '02', '02401', '0393106', '青森県', 'アオモリケン', '上北郡野辺地町', 'カミキタグンノヘジマチ', '明前', 'ミョウマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡野辺地町小沢平', '02', '02401', '0393107', '青森県', 'アオモリケン', '上北郡野辺地町', 'カミキタグンノヘジマチ', '小沢平', 'オザワダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡野辺地町有戸', '02', '02401', '0393108', '青森県', 'アオモリケン', '上北郡野辺地町', 'カミキタグンノヘジマチ', '有戸', 'アリト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡野辺地町下道', '02', '02401', '0393108', '青森県', 'アオモリケン', '上北郡野辺地町', 'カミキタグンノヘジマチ', '下道', 'シタミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡野辺地町中田', '02', '02401', '0393108', '青森県', 'アオモリケン', '上北郡野辺地町', 'カミキタグンノヘジマチ', '中田', 'ナカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡野辺地町向田', '02', '02401', '0393109', '青森県', 'アオモリケン', '上北郡野辺地町', 'カミキタグンノヘジマチ', '向田', 'ムカイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡野辺地町石神裏', '02', '02401', '0393111', '青森県', 'アオモリケン', '上北郡野辺地町', 'カミキタグンノヘジマチ', '石神裏', 'イシガミウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡野辺地町中道', '02', '02401', '0393112', '青森県', 'アオモリケン', '上北郡野辺地町', 'カミキタグンノヘジマチ', '中道', 'ナカミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡野辺地町田狭沢', '02', '02401', '0393113', '青森県', 'アオモリケン', '上北郡野辺地町', 'カミキタグンノヘジマチ', '田狭沢', 'タバサミザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡野辺地町助佐小路', '02', '02401', '0393114', '青森県', 'アオモリケン', '上北郡野辺地町', 'カミキタグンノヘジマチ', '助佐小路', 'スケサコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡野辺地町タラノ木', '02', '02401', '0393115', '青森県', 'アオモリケン', '上北郡野辺地町', 'カミキタグンノヘジマチ', 'タラノ木', 'タラノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡野辺地町赤坂', '02', '02401', '0393116', '青森県', 'アオモリケン', '上北郡野辺地町', 'カミキタグンノヘジマチ', '赤坂', 'アカサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡野辺地町下坂', '02', '02401', '0393117', '青森県', 'アオモリケン', '上北郡野辺地町', 'カミキタグンノヘジマチ', '下坂', 'シモサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡野辺地町寺ノ沢', '02', '02401', '0393118', '青森県', 'アオモリケン', '上北郡野辺地町', 'カミキタグンノヘジマチ', '寺ノ沢', 'テラノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡野辺地町船橋', '02', '02401', '0393121', '青森県', 'アオモリケン', '上北郡野辺地町', 'カミキタグンノヘジマチ', '船橋', 'フナバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡野辺地町雑吉沢', '02', '02401', '0393122', '青森県', 'アオモリケン', '上北郡野辺地町', 'カミキタグンノヘジマチ', '雑吉沢', 'ゾウヨシザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡野辺地町種川', '02', '02401', '0393123', '青森県', 'アオモリケン', '上北郡野辺地町', 'カミキタグンノヘジマチ', '種川', 'タネカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡野辺地町白岩', '02', '02401', '0393124', '青森県', 'アオモリケン', '上北郡野辺地町', 'カミキタグンノヘジマチ', '白岩', 'シライワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡野辺地町坊ノ塚', '02', '02401', '0393125', '青森県', 'アオモリケン', '上北郡野辺地町', 'カミキタグンノヘジマチ', '坊ノ塚', 'ボウノツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡野辺地町下前田', '02', '02401', '0393126', '青森県', 'アオモリケン', '上北郡野辺地町', 'カミキタグンノヘジマチ', '下前田', 'シモマエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡野辺地町上川原', '02', '02401', '0393127', '青森県', 'アオモリケン', '上北郡野辺地町', 'カミキタグンノヘジマチ', '上川原', 'カミカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡野辺地町上前田', '02', '02401', '0393128', '青森県', 'アオモリケン', '上北郡野辺地町', 'カミキタグンノヘジマチ', '上前田', 'カミマエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡野辺地町昼場', '02', '02401', '0393128', '青森県', 'アオモリケン', '上北郡野辺地町', 'カミキタグンノヘジマチ', '昼場', 'ヒルバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡野辺地町新田', '02', '02401', '0393129', '青森県', 'アオモリケン', '上北郡野辺地町', 'カミキタグンノヘジマチ', '新田', 'シンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡野辺地町戸田ノ沢', '02', '02401', '0393129', '青森県', 'アオモリケン', '上北郡野辺地町', 'カミキタグンノヘジマチ', '戸田ノ沢', 'トダノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡野辺地町餅粟川原', '02', '02401', '0393129', '青森県', 'アオモリケン', '上北郡野辺地町', 'カミキタグンノヘジマチ', '餅粟川原', 'モチアワカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡野辺地町野辺地', '02', '02401', '0393131', '青森県', 'アオモリケン', '上北郡野辺地町', 'カミキタグンノヘジマチ', '野辺地', 'ノヘジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡野辺地町鳴沢', '02', '02401', '0393141', '青森県', 'アオモリケン', '上北郡野辺地町', 'カミキタグンノヘジマチ', '鳴沢', 'ナルサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡野辺地町久田', '02', '02401', '0393142', '青森県', 'アオモリケン', '上北郡野辺地町', 'カミキタグンノヘジマチ', '久田', 'クンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡野辺地町川目', '02', '02401', '0393143', '青森県', 'アオモリケン', '上北郡野辺地町', 'カミキタグンノヘジマチ', '川目', 'カワメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡野辺地町中屋敷', '02', '02401', '0393143', '青森県', 'アオモリケン', '上北郡野辺地町', 'カミキタグンノヘジマチ', '中屋敷', 'ナカヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡野辺地町一ノ渡', '02', '02401', '0393144', '青森県', 'アオモリケン', '上北郡野辺地町', 'カミキタグンノヘジマチ', '一ノ渡', 'イチノワタリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡野辺地町松ノ木平', '02', '02401', '0393145', '青森県', 'アオモリケン', '上北郡野辺地町', 'カミキタグンノヘジマチ', '松ノ木平', 'マツノキタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡野辺地町下松ノ木平', '02', '02401', '0393146', '青森県', 'アオモリケン', '上北郡野辺地町', 'カミキタグンノヘジマチ', '下松ノ木平', 'シモマツノキタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡野辺地町下与田川', '02', '02401', '0393147', '青森県', 'アオモリケン', '上北郡野辺地町', 'カミキタグンノヘジマチ', '下与田川', 'シモヨタガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡野辺地町与田川尻', '02', '02401', '0393148', '青森県', 'アオモリケン', '上北郡野辺地町', 'カミキタグンノヘジマチ', '与田川尻', 'ヨタガワジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡野辺地町白岩向', '02', '02401', '0393151', '青森県', 'アオモリケン', '上北郡野辺地町', 'カミキタグンノヘジマチ', '白岩向', 'シライワムカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡野辺地町下小中野', '02', '02401', '0393152', '青森県', 'アオモリケン', '上北郡野辺地町', 'カミキタグンノヘジマチ', '下小中野', 'シモコナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡野辺地町中小中野', '02', '02401', '0393153', '青森県', 'アオモリケン', '上北郡野辺地町', 'カミキタグンノヘジマチ', '中小中野', 'ナカコナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡野辺地町上小中野', '02', '02401', '0393154', '青森県', 'アオモリケン', '上北郡野辺地町', 'カミキタグンノヘジマチ', '上小中野', 'カミコナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡野辺地町切明', '02', '02401', '0393155', '青森県', 'アオモリケン', '上北郡野辺地町', 'カミキタグンノヘジマチ', '切明', 'キリアケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡野辺地町枇杷野', '02', '02401', '0393156', '青森県', 'アオモリケン', '上北郡野辺地町', 'カミキタグンノヘジマチ', '枇杷野', 'ビワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡野辺地町獅子沢', '02', '02401', '0393157', '青森県', 'アオモリケン', '上北郡野辺地町', 'カミキタグンノヘジマチ', '獅子沢', 'シシザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡野辺地町松ノ木', '02', '02401', '0393157', '青森県', 'アオモリケン', '上北郡野辺地町', 'カミキタグンノヘジマチ', '松ノ木', 'マツノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡野辺地町観音林後', '02', '02401', '0393158', '青森県', 'アオモリケン', '上北郡野辺地町', 'カミキタグンノヘジマチ', '観音林後', 'カンノンバヤシウシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡野辺地町観音林脇', '02', '02401', '0393159', '青森県', 'アオモリケン', '上北郡野辺地町', 'カミキタグンノヘジマチ', '観音林脇', 'カンノンバヤシワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡野辺地町馬門道', '02', '02401', '0393161', '青森県', 'アオモリケン', '上北郡野辺地町', 'カミキタグンノヘジマチ', '馬門道', 'マカドミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡野辺地町笹館', '02', '02401', '0393162', '青森県', 'アオモリケン', '上北郡野辺地町', 'カミキタグンノヘジマチ', '笹館', 'ササダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡野辺地町新町裏', '02', '02401', '0393163', '青森県', 'アオモリケン', '上北郡野辺地町', 'カミキタグンノヘジマチ', '新町裏', 'シンマチウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡野辺地町前田', '02', '02401', '0393164', '青森県', 'アオモリケン', '上北郡野辺地町', 'カミキタグンノヘジマチ', '前田', 'マエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡野辺地町観音林前田', '02', '02401', '0393165', '青森県', 'アオモリケン', '上北郡野辺地町', 'カミキタグンノヘジマチ', '観音林前田', 'カンノンバヤシマエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡野辺地町二本木向前田', '02', '02401', '0393166', '青森県', 'アオモリケン', '上北郡野辺地町', 'カミキタグンノヘジマチ', '二本木向前田', 'ニホンキムカイマエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡野辺地町二本木向', '02', '02401', '0393167', '青森県', 'アオモリケン', '上北郡野辺地町', 'カミキタグンノヘジマチ', '二本木向', 'ニホンキムカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡野辺地町前平', '02', '02401', '0393168', '青森県', 'アオモリケン', '上北郡野辺地町', 'カミキタグンノヘジマチ', '前平', 'マエヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡野辺地町上御手洗瀬', '02', '02401', '0393171', '青森県', 'アオモリケン', '上北郡野辺地町', 'カミキタグンノヘジマチ', '上御手洗瀬', 'カミミタラセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡野辺地町下御手洗瀬', '02', '02401', '0393171', '青森県', 'アオモリケン', '上北郡野辺地町', 'カミキタグンノヘジマチ', '下御手洗瀬', 'シモミタラセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡野辺地町滝田', '02', '02401', '0393171', '青森県', 'アオモリケン', '上北郡野辺地町', 'カミキタグンノヘジマチ', '滝田', 'タキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡野辺地町槻ノ木', '02', '02401', '0393171', '青森県', 'アオモリケン', '上北郡野辺地町', 'カミキタグンノヘジマチ', '槻ノ木', 'ツキノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡野辺地町二本木', '02', '02401', '0393171', '青森県', 'アオモリケン', '上北郡野辺地町', 'カミキタグンノヘジマチ', '二本木', 'ニホンキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡野辺地町二十平', '02', '02401', '0393171', '青森県', 'アオモリケン', '上北郡野辺地町', 'カミキタグンノヘジマチ', '二十平', 'ハタチタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡野辺地町御手洗瀬', '02', '02401', '0393171', '青森県', 'アオモリケン', '上北郡野辺地町', 'カミキタグンノヘジマチ', '御手洗瀬', 'ミタラセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡野辺地町鳥井平', '02', '02401', '0393172', '青森県', 'アオモリケン', '上北郡野辺地町', 'カミキタグンノヘジマチ', '鳥井平', 'トリイタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡野辺地町陣場川原', '02', '02401', '0393173', '青森県', 'アオモリケン', '上北郡野辺地町', 'カミキタグンノヘジマチ', '陣場川原', 'ジンバガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡野辺地町大平下', '02', '02401', '0393174', '青森県', 'アオモリケン', '上北郡野辺地町', 'カミキタグンノヘジマチ', '大平下', 'オオダイシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡野辺地町上河渡頭', '02', '02401', '0393174', '青森県', 'アオモリケン', '上北郡野辺地町', 'カミキタグンノヘジマチ', '上河渡頭', 'カミカドガシラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡野辺地町下河渡頭', '02', '02401', '0393174', '青森県', 'アオモリケン', '上北郡野辺地町', 'カミキタグンノヘジマチ', '下河渡頭', 'シモカドガシラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡野辺地町田端', '02', '02401', '0393174', '青森県', 'アオモリケン', '上北郡野辺地町', 'カミキタグンノヘジマチ', '田端', 'タバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡野辺地町地続山', '02', '02401', '0393175', '青森県', 'アオモリケン', '上北郡野辺地町', 'カミキタグンノヘジマチ', '地続山', 'ジツヅキヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡野辺地町湯沢', '02', '02401', '0393175', '青森県', 'アオモリケン', '上北郡野辺地町', 'カミキタグンノヘジマチ', '湯沢', 'ユザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡野辺地町湯沢尻', '02', '02401', '0393175', '青森県', 'アオモリケン', '上北郡野辺地町', 'カミキタグンノヘジマチ', '湯沢尻', 'ユザワジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡野辺地町中渡', '02', '02401', '0393176', '青森県', 'アオモリケン', '上北郡野辺地町', 'カミキタグンノヘジマチ', '中渡', 'ナカワタリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡野辺地町柴崎', '02', '02401', '0393177', '青森県', 'アオモリケン', '上北郡野辺地町', 'カミキタグンノヘジマチ', '柴崎', 'シバサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡野辺地町八ノ木谷地', '02', '02401', '0393177', '青森県', 'アオモリケン', '上北郡野辺地町', 'カミキタグンノヘジマチ', '八ノ木谷地', 'ハノキヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡野辺地町家ノ上', '02', '02401', '0393178', '青森県', 'アオモリケン', '上北郡野辺地町', 'カミキタグンノヘジマチ', '家ノ上', 'イエノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡野辺地町馬門', '02', '02401', '0393179', '青森県', 'アオモリケン', '上北郡野辺地町', 'カミキタグンノヘジマチ', '馬門', 'マカド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡六ヶ所村', '02', '02411', '0393200', '青森県', 'アオモリケン', '上北郡六ヶ所村', 'カミキタグンロッカショムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('34833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡六ヶ所村出戸', '02', '02411', '0393211', '青森県', 'アオモリケン', '上北郡六ヶ所村', 'カミキタグンロッカショムラ', '出戸', 'デト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡六ヶ所村尾駮', '02', '02411', '0393212', '青森県', 'アオモリケン', '上北郡六ヶ所村', 'カミキタグンロッカショムラ', '尾駮', 'オブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡六ヶ所村鷹架', '02', '02411', '0393213', '青森県', 'アオモリケン', '上北郡六ヶ所村', 'カミキタグンロッカショムラ', '鷹架', 'タカホコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡六ヶ所村平沼', '02', '02411', '0393214', '青森県', 'アオモリケン', '上北郡六ヶ所村', 'カミキタグンロッカショムラ', '平沼', 'ヒラヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡六ヶ所村倉内', '02', '02411', '0393215', '青森県', 'アオモリケン', '上北郡六ヶ所村', 'カミキタグンロッカショムラ', '倉内', 'クラウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県東津軽郡平内町', '02', '02301', '0393300', '青森県', 'アオモリケン', '東津軽郡平内町', 'ヒガシツガルグンヒラナイマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('34839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県東津軽郡平内町東田沢', '02', '02301', '0393301', '青森県', 'アオモリケン', '東津軽郡平内町', 'ヒガシツガルグンヒラナイマチ', '東田沢', 'ヒガシタザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県東津軽郡平内町白砂', '02', '02301', '0393302', '青森県', 'アオモリケン', '東津軽郡平内町', 'ヒガシツガルグンヒラナイマチ', '白砂', 'シラス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県東津軽郡平内町東滝', '02', '02301', '0393303', '青森県', 'アオモリケン', '東津軽郡平内町', 'ヒガシツガルグンヒラナイマチ', '東滝', 'ヒガシタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県東津軽郡平内町福館', '02', '02301', '0393311', '青森県', 'アオモリケン', '東津軽郡平内町', 'ヒガシツガルグンヒラナイマチ', '福館', 'フクダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県東津軽郡平内町浅所', '02', '02301', '0393312', '青森県', 'アオモリケン', '東津軽郡平内町', 'ヒガシツガルグンヒラナイマチ', '浅所', 'アサドコロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県東津軽郡平内町沼館', '02', '02301', '0393313', '青森県', 'アオモリケン', '東津軽郡平内町', 'ヒガシツガルグンヒラナイマチ', '沼館', 'ヌマダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県東津軽郡平内町盛田', '02', '02301', '0393314', '青森県', 'アオモリケン', '東津軽郡平内町', 'ヒガシツガルグンヒラナイマチ', '盛田', 'モリタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県東津軽郡平内町福島', '02', '02301', '0393315', '青森県', 'アオモリケン', '東津軽郡平内町', 'ヒガシツガルグンヒラナイマチ', '福島', 'フクシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県東津軽郡平内町小湊', '02', '02301', '0393321', '青森県', 'アオモリケン', '東津軽郡平内町', 'ヒガシツガルグンヒラナイマチ', '小湊', 'コミナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県東津軽郡平内町浜子', '02', '02301', '0393331', '青森県', 'アオモリケン', '東津軽郡平内町', 'ヒガシツガルグンヒラナイマチ', '浜子', 'ハマゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県東津軽郡平内町清水川', '02', '02301', '0393332', '青森県', 'アオモリケン', '東津軽郡平内町', 'ヒガシツガルグンヒラナイマチ', '清水川', 'シミズガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県東津軽郡平内町松野木', '02', '02301', '0393333', '青森県', 'アオモリケン', '東津軽郡平内町', 'ヒガシツガルグンヒラナイマチ', '松野木', 'マツノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県東津軽郡平内町薬師野', '02', '02301', '0393341', '青森県', 'アオモリケン', '東津軽郡平内町', 'ヒガシツガルグンヒラナイマチ', '薬師野', 'ヤクシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県東津軽郡平内町口広', '02', '02301', '0393342', '青森県', 'アオモリケン', '東津軽郡平内町', 'ヒガシツガルグンヒラナイマチ', '口広', 'クチヒロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県東津軽郡平内町狩場沢', '02', '02301', '0393343', '青森県', 'アオモリケン', '東津軽郡平内町', 'ヒガシツガルグンヒラナイマチ', '狩場沢', 'カリバサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県東津軽郡平内町外童子', '02', '02301', '0393351', '青森県', 'アオモリケン', '東津軽郡平内町', 'ヒガシツガルグンヒラナイマチ', '外童子', 'ソトドウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県東津軽郡平内町内童子', '02', '02301', '0393352', '青森県', 'アオモリケン', '東津軽郡平内町', 'ヒガシツガルグンヒラナイマチ', '内童子', 'ウチドウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県東津軽郡平内町田茂木', '02', '02301', '0393353', '青森県', 'アオモリケン', '東津軽郡平内町', 'ヒガシツガルグンヒラナイマチ', '田茂木', 'タモギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県東津軽郡平内町藤沢', '02', '02301', '0393361', '青森県', 'アオモリケン', '東津軽郡平内町', 'ヒガシツガルグンヒラナイマチ', '藤沢', 'フジサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県東津軽郡平内町増田', '02', '02301', '0393362', '青森県', 'アオモリケン', '東津軽郡平内町', 'ヒガシツガルグンヒラナイマチ', '増田', 'マスタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県東津軽郡平内町山口', '02', '02301', '0393363', '青森県', 'アオモリケン', '東津軽郡平内町', 'ヒガシツガルグンヒラナイマチ', '山口', 'ヤマグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県東津軽郡平内町小豆沢', '02', '02301', '0393364', '青森県', 'アオモリケン', '東津軽郡平内町', 'ヒガシツガルグンヒラナイマチ', '小豆沢', 'アズキサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県東津軽郡平内町中野', '02', '02301', '0393371', '青森県', 'アオモリケン', '東津軽郡平内町', 'ヒガシツガルグンヒラナイマチ', '中野', 'ナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県東津軽郡平内町土屋', '02', '02301', '0393372', '青森県', 'アオモリケン', '東津軽郡平内町', 'ヒガシツガルグンヒラナイマチ', '土屋', 'ツチヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県東津軽郡平内町浪打', '02', '02301', '0393373', '青森県', 'アオモリケン', '東津軽郡平内町', 'ヒガシツガルグンヒラナイマチ', '浪打', 'ナミウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県東津軽郡平内町茂浦', '02', '02301', '0393381', '青森県', 'アオモリケン', '東津軽郡平内町', 'ヒガシツガルグンヒラナイマチ', '茂浦', 'モウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県東津軽郡平内町稲生', '02', '02301', '0393382', '青森県', 'アオモリケン', '東津軽郡平内町', 'ヒガシツガルグンヒラナイマチ', '稲生', 'イノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市浅虫', '02', '02201', '0393501', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '浅虫', 'アサムシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市久栗坂', '02', '02201', '0393502', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '久栗坂', 'クグリザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市野内', '02', '02201', '0393503', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '野内', 'ノナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市矢田', '02', '02201', '0393504', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '矢田', 'ヤダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市宮田', '02', '02201', '0393505', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '宮田', 'ミヤタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市三本木', '02', '02201', '0393506', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '三本木', 'サンボンギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市馬屋尻', '02', '02201', '0393507', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '馬屋尻', 'マヤジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県青森市滝沢', '02', '02201', '0393524', '青森県', 'アオモリケン', '青森市', 'アオモリシ', '滝沢', 'タキサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県岡谷市', '20', '20204', '3940000', '長野県', 'ナガノケン', '岡谷市', 'オカヤシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('34882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県岡谷市今井', '20', '20204', '3940001', '長野県', 'ナガノケン', '岡谷市', 'オカヤシ', '今井', 'イマイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県岡谷市赤羽', '20', '20204', '3940002', '長野県', 'ナガノケン', '岡谷市', 'オカヤシ', '赤羽', 'アカハネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県岡谷市加茂町', '20', '20204', '3940003', '長野県', 'ナガノケン', '岡谷市', 'オカヤシ', '加茂町', 'カモチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県岡谷市神明町', '20', '20204', '3940004', '長野県', 'ナガノケン', '岡谷市', 'オカヤシ', '神明町', 'シンメイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県岡谷市山下町', '20', '20204', '3940005', '長野県', 'ナガノケン', '岡谷市', 'オカヤシ', '山下町', 'ヤマシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県岡谷市長地', '20', '20204', '3940011', '長野県', 'ナガノケン', '岡谷市', 'オカヤシ', '長地', 'オサチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県岡谷市郷田', '20', '20204', '3940021', '長野県', 'ナガノケン', '岡谷市', 'オカヤシ', '郷田', 'ゴウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県岡谷市銀座', '20', '20204', '3940022', '長野県', 'ナガノケン', '岡谷市', 'オカヤシ', '銀座', 'ギンザ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県岡谷市東銀座', '20', '20204', '3940023', '長野県', 'ナガノケン', '岡谷市', 'オカヤシ', '東銀座', 'ヒガシギンザ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県岡谷市堀ノ内', '20', '20204', '3940024', '長野県', 'ナガノケン', '岡谷市', 'オカヤシ', '堀ノ内', 'ホリノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県岡谷市大栄町', '20', '20204', '3940025', '長野県', 'ナガノケン', '岡谷市', 'オカヤシ', '大栄町', 'ダイエイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県岡谷市塚間町', '20', '20204', '3940026', '長野県', 'ナガノケン', '岡谷市', 'オカヤシ', '塚間町', 'ツカマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県岡谷市中央町', '20', '20204', '3940027', '長野県', 'ナガノケン', '岡谷市', 'オカヤシ', '中央町', 'チュウオウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県岡谷市本町', '20', '20204', '3940028', '長野県', 'ナガノケン', '岡谷市', 'オカヤシ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県岡谷市幸町', '20', '20204', '3940029', '長野県', 'ナガノケン', '岡谷市', 'オカヤシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県岡谷市田中町', '20', '20204', '3940031', '長野県', 'ナガノケン', '岡谷市', 'オカヤシ', '田中町', 'タナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県岡谷市若宮', '20', '20204', '3940032', '長野県', 'ナガノケン', '岡谷市', 'オカヤシ', '若宮', 'ワカミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県岡谷市南宮', '20', '20204', '3940033', '長野県', 'ナガノケン', '岡谷市', 'オカヤシ', '南宮', 'ナングウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県岡谷市湖畔', '20', '20204', '3940034', '長野県', 'ナガノケン', '岡谷市', 'オカヤシ', '湖畔', 'コハン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県岡谷市天竜町', '20', '20204', '3940035', '長野県', 'ナガノケン', '岡谷市', 'オカヤシ', '天竜町', 'テンリュウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県岡谷市山手町', '20', '20204', '3940041', '長野県', 'ナガノケン', '岡谷市', 'オカヤシ', '山手町', 'ヤマテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県岡谷市成田町', '20', '20204', '3940042', '長野県', 'ナガノケン', '岡谷市', 'オカヤシ', '成田町', 'ナルタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県岡谷市御倉町', '20', '20204', '3940043', '長野県', 'ナガノケン', '岡谷市', 'オカヤシ', '御倉町', 'オクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県岡谷市湊', '20', '20204', '3940044', '長野県', 'ナガノケン', '岡谷市', 'オカヤシ', '湊', 'ミナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県岡谷市川岸東', '20', '20204', '3940045', '長野県', 'ナガノケン', '岡谷市', 'オカヤシ', '川岸東', 'カワギシヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県岡谷市川岸西', '20', '20204', '3940046', '長野県', 'ナガノケン', '岡谷市', 'オカヤシ', '川岸西', 'カワギシニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県岡谷市川岸中', '20', '20204', '3940047', '長野県', 'ナガノケン', '岡谷市', 'オカヤシ', '川岸中', 'カワギシナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県岡谷市川岸上', '20', '20204', '3940048', '長野県', 'ナガノケン', '岡谷市', 'オカヤシ', '川岸上', 'カワギシカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県岡谷市塩嶺', '20', '20204', '3940051', '長野県', 'ナガノケン', '岡谷市', 'オカヤシ', '塩嶺', 'エンレイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県岡谷市西林', '20', '20204', '3940052', '長野県', 'ナガノケン', '岡谷市', 'オカヤシ', '西林', 'ニシバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県岡谷市芦ノ沢', '20', '20204', '3940053', '長野県', 'ナガノケン', '岡谷市', 'オカヤシ', '芦ノ沢', 'アシノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県岡谷市ヨギトギ沢', '20', '20204', '3940053', '長野県', 'ナガノケン', '岡谷市', 'オカヤシ', 'ヨギトギ沢', 'ヨギトギサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県岡谷市半ノ木', '20', '20204', '3940054', '長野県', 'ナガノケン', '岡谷市', 'オカヤシ', '半ノ木', 'ハンノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県岡谷市内山', '20', '20204', '3940055', '長野県', 'ナガノケン', '岡谷市', 'オカヤシ', '内山', 'ウチヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県岡谷市樋沢', '20', '20204', '3940056', '長野県', 'ナガノケン', '岡谷市', 'オカヤシ', '樋沢', 'ヒザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県岡谷市長地権現町', '20', '20204', '3940081', '長野県', 'ナガノケン', '岡谷市', 'オカヤシ', '長地権現町', 'オサチゴンゲンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県岡谷市長地御所', '20', '20204', '3940082', '長野県', 'ナガノケン', '岡谷市', 'オカヤシ', '長地御所', 'オサチゴショ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県岡谷市長地柴宮', '20', '20204', '3940083', '長野県', 'ナガノケン', '岡谷市', 'オカヤシ', '長地柴宮', 'オサチシバミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県岡谷市長地片間町', '20', '20204', '3940084', '長野県', 'ナガノケン', '岡谷市', 'オカヤシ', '長地片間町', 'オサチカタマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県岡谷市長地小萩', '20', '20204', '3940085', '長野県', 'ナガノケン', '岡谷市', 'オカヤシ', '長地小萩', 'オサチコハギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県岡谷市長地源', '20', '20204', '3940086', '長野県', 'ナガノケン', '岡谷市', 'オカヤシ', '長地源', 'オサチミナモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県岡谷市長地鎮', '20', '20204', '3940087', '長野県', 'ナガノケン', '岡谷市', 'オカヤシ', '長地鎮', 'オサチシズメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県岡谷市長地梨久保', '20', '20204', '3940088', '長野県', 'ナガノケン', '岡谷市', 'オカヤシ', '長地梨久保', 'オサチナシクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県岡谷市長地出早', '20', '20204', '3940089', '長野県', 'ナガノケン', '岡谷市', 'オカヤシ', '長地出早', 'オサチイズハヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡横浜町', '02', '02406', '0394100', '青森県', 'アオモリケン', '上北郡横浜町', 'カミキタグンヨコハママチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('34927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡横浜町林尻', '02', '02406', '0394101', '青森県', 'アオモリケン', '上北郡横浜町', 'カミキタグンヨコハママチ', '林尻', 'ハヤシジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡横浜町浜田', '02', '02406', '0394102', '青森県', 'アオモリケン', '上北郡横浜町', 'カミキタグンヨコハママチ', '浜田', 'ハマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡横浜町川太郎川目', '02', '02406', '0394103', '青森県', 'アオモリケン', '上北郡横浜町', 'カミキタグンヨコハママチ', '川太郎川目', 'カワタロウカワメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡横浜町下苗代川目', '02', '02406', '0394104', '青森県', 'アオモリケン', '上北郡横浜町', 'カミキタグンヨコハママチ', '下苗代川目', 'シモナワシロカワメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡横浜町苗代川目', '02', '02406', '0394105', '青森県', 'アオモリケン', '上北郡横浜町', 'カミキタグンヨコハママチ', '苗代川目', 'ナワシロカワメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡横浜町有畑', '02', '02406', '0394106', '青森県', 'アオモリケン', '上北郡横浜町', 'カミキタグンヨコハママチ', '有畑', 'アリハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡横浜町大畑', '02', '02406', '0394111', '青森県', 'アオモリケン', '上北郡横浜町', 'カミキタグンヨコハママチ', '大畑', 'オオハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡横浜町夷ケ沢平', '02', '02406', '0394112', '青森県', 'アオモリケン', '上北郡横浜町', 'カミキタグンヨコハママチ', '夷ケ沢平', 'エゾガサワタイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡横浜町家ノ前川目', '02', '02406', '0394113', '青森県', 'アオモリケン', '上北郡横浜町', 'カミキタグンヨコハママチ', '家ノ前川目', 'イエノマエカワメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡横浜町大豆田', '02', '02406', '0394114', '青森県', 'アオモリケン', '上北郡横浜町', 'カミキタグンヨコハママチ', '大豆田', 'マメダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡横浜町稲荷平', '02', '02406', '0394115', '青森県', 'アオモリケン', '上北郡横浜町', 'カミキタグンヨコハママチ', '稲荷平', 'イナリタイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡横浜町中畑', '02', '02406', '0394116', '青森県', 'アオモリケン', '上北郡横浜町', 'カミキタグンヨコハママチ', '中畑', 'ナカハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡横浜町鶏沢', '02', '02406', '0394117', '青森県', 'アオモリケン', '上北郡横浜町', 'カミキタグンヨコハママチ', '鶏沢', 'ニワトリザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡横浜町桧木', '02', '02406', '0394121', '青森県', 'アオモリケン', '上北郡横浜町', 'カミキタグンヨコハママチ', '桧木', 'ヒノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡横浜町鶏ケ唄', '02', '02406', '0394122', '青森県', 'アオモリケン', '上北郡横浜町', 'カミキタグンヨコハママチ', '鶏ケ唄', 'トリガウタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡横浜町茅平', '02', '02406', '0394123', '青森県', 'アオモリケン', '上北郡横浜町', 'カミキタグンヨコハママチ', '茅平', 'カヤタイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡横浜町川尻', '02', '02406', '0394124', '青森県', 'アオモリケン', '上北郡横浜町', 'カミキタグンヨコハママチ', '川尻', 'カワジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡横浜町椛名木', '02', '02406', '0394131', '青森県', 'アオモリケン', '上北郡横浜町', 'カミキタグンヨコハママチ', '椛名木', 'カバナキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡横浜町太郎須田', '02', '02406', '0394132', '青森県', 'アオモリケン', '上北郡横浜町', 'カミキタグンヨコハママチ', '太郎須田', 'タロウスダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡横浜町舘の後', '02', '02406', '0394133', '青森県', 'アオモリケン', '上北郡横浜町', 'カミキタグンヨコハママチ', '舘の後', 'タテノウシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡横浜町林の脇', '02', '02406', '0394134', '青森県', 'アオモリケン', '上北郡横浜町', 'カミキタグンヨコハママチ', '林の脇', 'ハヤシノワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡横浜町林の後', '02', '02406', '0394135', '青森県', 'アオモリケン', '上北郡横浜町', 'カミキタグンヨコハママチ', '林の後', 'ハヤシノウシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡横浜町横浜', '02', '02406', '0394136', '青森県', 'アオモリケン', '上北郡横浜町', 'カミキタグンヨコハママチ', '横浜', 'ヨコハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡横浜町下川原', '02', '02406', '0394137', '青森県', 'アオモリケン', '上北郡横浜町', 'カミキタグンヨコハママチ', '下川原', 'シモガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡横浜町塚名平', '02', '02406', '0394138', '青森県', 'アオモリケン', '上北郡横浜町', 'カミキタグンヨコハママチ', '塚名平', 'ツカナタイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡横浜町三保野', '02', '02406', '0394141', '青森県', 'アオモリケン', '上北郡横浜町', 'カミキタグンヨコハママチ', '三保野', 'ミホノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡横浜町上イタヤノ木', '02', '02406', '0394142', '青森県', 'アオモリケン', '上北郡横浜町', 'カミキタグンヨコハママチ', '上イタヤノ木', 'カミイタヤノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡横浜町屋敷形', '02', '02406', '0394143', '青森県', 'アオモリケン', '上北郡横浜町', 'カミキタグンヨコハママチ', '屋敷形', 'ヤシキガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡横浜町浜懸', '02', '02406', '0394144', '青森県', 'アオモリケン', '上北郡横浜町', 'カミキタグンヨコハママチ', '浜懸', 'ハマガケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡横浜町寺下', '02', '02406', '0394145', '青森県', 'アオモリケン', '上北郡横浜町', 'カミキタグンヨコハママチ', '寺下', 'テラシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡横浜町向平', '02', '02406', '0394151', '青森県', 'アオモリケン', '上北郡横浜町', 'カミキタグンヨコハママチ', '向平', 'ムカイタイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡横浜町百目木', '02', '02406', '0394152', '青森県', 'アオモリケン', '上北郡横浜町', 'カミキタグンヨコハママチ', '百目木', 'ドメキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡横浜町吹越', '02', '02406', '0394153', '青森県', 'アオモリケン', '上北郡横浜町', 'カミキタグンヨコハママチ', '吹越', 'フッコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡横浜町明神平', '02', '02406', '0394154', '青森県', 'アオモリケン', '上北郡横浜町', 'カミキタグンヨコハママチ', '明神平', 'ミョウジンタイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡横浜町豊栄平', '02', '02406', '0394155', '青森県', 'アオモリケン', '上北郡横浜町', 'カミキタグンヨコハママチ', '豊栄平', 'トヨサカタイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡横浜町雲雀平', '02', '02406', '0394156', '青森県', 'アオモリケン', '上北郡横浜町', 'カミキタグンヨコハママチ', '雲雀平', 'ヒバリタイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡横浜町二又', '02', '02406', '0394157', '青森県', 'アオモリケン', '上北郡横浜町', 'カミキタグンヨコハママチ', '二又', 'フタマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県下北郡東通村猿ケ森', '02', '02424', '0394221', '青森県', 'アオモリケン', '下北郡東通村', 'シモキタグンヒガシドオリムラ', '猿ケ森', 'サルガモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県下北郡東通村砂子又', '02', '02424', '0394222', '青森県', 'アオモリケン', '下北郡東通村', 'シモキタグンヒガシドオリムラ', '砂子又', 'スナゴマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県下北郡東通村小田野沢', '02', '02424', '0394223', '青森県', 'アオモリケン', '下北郡東通村', 'シモキタグンヒガシドオリムラ', '小田野沢', 'オダノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県下北郡東通村白糠', '02', '02424', '0394224', '青森県', 'アオモリケン', '下北郡東通村', 'シモキタグンヒガシドオリムラ', '白糠', 'シラヌカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県上北郡六ヶ所村泊', '02', '02411', '0394301', '青森県', 'アオモリケン', '上北郡六ヶ所村', 'カミキタグンロッカショムラ', '泊', 'トマリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県むつ市大畑町', '02', '02208', '0394401', '青森県', 'アオモリケン', 'むつ市', 'ムツシ', '大畑町', 'オオハタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県むつ市大畑町正津川', '02', '02208', '0394402', '青森県', 'アオモリケン', 'むつ市', 'ムツシ', '大畑町正津川', 'オオハタマチショウヅガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県下北郡風間浦村', '02', '02425', '0394500', '青森県', 'アオモリケン', '下北郡風間浦村', 'シモキタグンカザマウラムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('34975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県下北郡風間浦村下風呂', '02', '02425', '0394501', '青森県', 'アオモリケン', '下北郡風間浦村', 'シモキタグンカザマウラムラ', '下風呂', 'シモフロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県下北郡風間浦村易国間', '02', '02425', '0394502', '青森県', 'アオモリケン', '下北郡風間浦村', 'シモキタグンカザマウラムラ', '易国間', 'イコクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県下北郡風間浦村蛇浦', '02', '02425', '0394503', '青森県', 'アオモリケン', '下北郡風間浦村', 'シモキタグンカザマウラムラ', '蛇浦', 'ヘビウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県下北郡大間町', '02', '02423', '0394600', '青森県', 'アオモリケン', '下北郡大間町', 'シモキタグンオオママチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('34979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県下北郡大間町大間', '02', '02423', '0394601', '青森県', 'アオモリケン', '下北郡大間町', 'シモキタグンオオママチ', '大間', 'オオマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県下北郡大間町奥戸', '02', '02423', '0394602', '青森県', 'アオモリケン', '下北郡大間町', 'シモキタグンオオママチ', '奥戸', 'オコッペ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県下北郡佐井村', '02', '02426', '0394700', '青森県', 'アオモリケン', '下北郡佐井村', 'シモキタグンサイムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('34983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県むつ市川内町板家戸', '02', '02208', '0394701', '青森県', 'アオモリケン', 'むつ市', 'ムツシ', '川内町', 'カワウチマチ', null, null, '板家戸', 'イタゲド');
INSERT INTO `ms_addresses` VALUES ('34984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県むつ市川内町野平', '02', '02208', '0394701', '青森県', 'アオモリケン', 'むつ市', 'ムツシ', '川内町', 'カワウチマチ', null, null, '野平', 'ノダイ');
INSERT INTO `ms_addresses` VALUES ('34985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県むつ市川内町福浦山', '02', '02208', '0394701', '青森県', 'アオモリケン', 'むつ市', 'ムツシ', '川内町', 'カワウチマチ', null, null, '福浦山', 'フクウラヤマ');
INSERT INTO `ms_addresses` VALUES ('34986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県下北郡佐井村佐井', '02', '02426', '0394711', '青森県', 'アオモリケン', '下北郡佐井村', 'シモキタグンサイムラ', '佐井', 'サイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('34987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県下北郡佐井村長後', '02', '02426', '0394712', '青森県', 'アオモリケン', '下北郡佐井村', 'シモキタグンサイムラ', '長後', 'チョウゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市', '20', '20205', '3950000', '長野県', 'ナガノケン', '飯田市', 'イイダシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('35003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市座光寺', '20', '20205', '3950001', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '座光寺', 'ザコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市上郷飯沼', '20', '20205', '3950002', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '上郷飯沼', 'カミサトイイヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市上郷別府', '20', '20205', '3950003', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '上郷別府', 'カミサトベップ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市上郷黒田', '20', '20205', '3950004', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '上郷黒田', 'カミサトクロダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市大門町', '20', '20205', '3950011', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '大門町', 'ダイモンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市大王路', '20', '20205', '3950012', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '大王路', 'ダイオウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市小伝馬町', '20', '20205', '3950013', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '小伝馬町', 'コデンマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市桜町', '20', '20205', '3950014', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '桜町', 'サクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市江戸町', '20', '20205', '3950015', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '江戸町', 'エドマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市伝馬町', '20', '20205', '3950016', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '伝馬町', 'テンマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市東新町', '20', '20205', '3950017', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '東新町', 'トウシンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市諏訪町', '20', '20205', '3950018', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '諏訪町', 'スワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市仲ノ町', '20', '20205', '3950021', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '仲ノ町', 'ナカノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市浜井町', '20', '20205', '3950022', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '浜井町', 'ハマイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市江戸浜町', '20', '20205', '3950023', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '江戸浜町', 'エドハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市東栄町', '20', '20205', '3950024', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '東栄町', 'トウエイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市東中央通り', '20', '20205', '3950025', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '東中央通り', 'ヒガシチュウオウドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市鼎西鼎', '20', '20205', '3950026', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '鼎西鼎', 'カナエニシカナエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市馬場町', '20', '20205', '3950027', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '馬場町', 'ババンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市長姫町', '20', '20205', '3950028', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '長姫町', 'オサヒメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市二本松', '20', '20205', '3950029', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '二本松', 'ニホンマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市銀座', '20', '20205', '3950031', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '銀座', 'ギンザ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市主税町', '20', '20205', '3950032', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '主税町', 'チカラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市常盤町', '20', '20205', '3950033', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '常盤町', 'トキワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市追手町', '20', '20205', '3950034', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '追手町', 'オウテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市水の手町', '20', '20205', '3950035', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '水の手町', 'ミズノテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市愛宕町', '20', '20205', '3950036', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '愛宕町', 'アタゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市南常盤町', '20', '20205', '3950037', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '南常盤町', 'ミナミトキワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市中央通り', '20', '20205', '3950041', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '中央通り', 'チュウオウドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市松尾町', '20', '20205', '3950042', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '松尾町', 'マツオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市通り町', '20', '20205', '3950043', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '通り町', 'トオリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市本町', '20', '20205', '3950044', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市知久町', '20', '20205', '3950045', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '知久町', 'チクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市扇町', '20', '20205', '3950046', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '扇町', 'オウギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市滝の沢', '20', '20205', '3950048', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '滝の沢', 'タキノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市高羽町', '20', '20205', '3950051', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '高羽町', 'タカハチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市元町', '20', '20205', '3950052', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '元町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市大久保町', '20', '20205', '3950053', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '大久保町', 'オオクボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市箕瀬町', '20', '20205', '3950054', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '箕瀬町', 'ミノゼチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市旭町', '20', '20205', '3950055', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '旭町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市大通', '20', '20205', '3950056', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '大通', 'オオドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市正永町', '20', '20205', '3950061', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '正永町', 'ショウエイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市砂払町', '20', '20205', '3950062', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '砂払町', 'スナハライチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市羽場町', '20', '20205', '3950063', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '羽場町', 'ハバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市羽場仲畑', '20', '20205', '3950064', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '羽場仲畑', 'ハバナカハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市羽場上河原', '20', '20205', '3950065', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '羽場上河原', 'ハバカミガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市羽場赤坂', '20', '20205', '3950066', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '羽場赤坂', 'ハバアカサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市羽場権現', '20', '20205', '3950067', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '羽場権現', 'ハバゴンゲン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市大休', '20', '20205', '3950068', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '大休', 'オオヤスミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市今宮町', '20', '20205', '3950071', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '今宮町', 'イマミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市曙町', '20', '20205', '3950072', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '曙町', 'アケボノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市羽場坂町', '20', '20205', '3950073', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '羽場坂町', 'ハバザカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市松川町', '20', '20205', '3950074', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '松川町', 'マツカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市白山通り', '20', '20205', '3950075', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '白山通り', 'ハクサンドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市白山町', '20', '20205', '3950076', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '白山町', 'ハクサンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市丸山町', '20', '20205', '3950077', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '丸山町', 'マルヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市宮ノ上', '20', '20205', '3950081', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '宮ノ上', 'ミヤノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市宮の前', '20', '20205', '3950082', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '宮の前', 'ミヤノマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市錦町', '20', '20205', '3950083', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '錦町', 'ニシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市鈴加町', '20', '20205', '3950084', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '鈴加町', 'スズカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市吾妻町', '20', '20205', '3950085', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '吾妻町', 'アズマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市東和町', '20', '20205', '3950086', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '東和町', 'トウワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市北方', '20', '20205', '3950151', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '北方', 'キタガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市育良町', '20', '20205', '3950152', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '育良町', 'イクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市上殿岡', '20', '20205', '3950153', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '上殿岡', 'カミトノオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市下殿岡', '20', '20205', '3950154', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '下殿岡', 'シモトノオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市三日市場', '20', '20205', '3950155', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '三日市場', 'ミッカイチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市中村', '20', '20205', '3950156', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '中村', 'ナカムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市大瀬木', '20', '20205', '3950157', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '大瀬木', 'オオセギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市久米', '20', '20205', '3950241', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '久米', 'クメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市竹佐', '20', '20205', '3950242', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '竹佐', 'タケサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市箱川', '20', '20205', '3950243', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '箱川', 'ハコガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市山本', '20', '20205', '3950244', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '山本', 'ヤマモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市山本二ツ山団地', '20', '20205', '3950245', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '山本二ツ山団地', 'ヤマモトフタツヤマダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県下伊那郡阿智村', '20', '20407', '3950300', '長野県', 'ナガノケン', '下伊那郡阿智村', 'シモイナグンアチムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('35082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県下伊那郡阿智村春日', '20', '20407', '3950301', '長野県', 'ナガノケン', '下伊那郡阿智村', 'シモイナグンアチムラ', '春日', 'カスガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県下伊那郡阿智村伍和', '20', '20407', '3950302', '長野県', 'ナガノケン', '下伊那郡阿智村', 'シモイナグンアチムラ', '伍和', 'ゴカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県下伊那郡阿智村駒場', '20', '20407', '3950303', '長野県', 'ナガノケン', '下伊那郡阿智村', 'シモイナグンアチムラ', '駒場', 'コマバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県下伊那郡阿智村智里', '20', '20407', '3950304', '長野県', 'ナガノケン', '下伊那郡阿智村', 'シモイナグンアチムラ', '智里', 'チサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県下伊那郡阿智村駒', '20', '20407', '3950305', '長野県', 'ナガノケン', '下伊那郡阿智村', 'シモイナグンアチムラ', '駒', 'コマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県下伊那郡阿智村清内路', '20', '20407', '3950401', '長野県', 'ナガノケン', '下伊那郡阿智村', 'シモイナグンアチムラ', '清内路', 'セイナイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県下伊那郡阿智村浪合', '20', '20407', '3950501', '長野県', 'ナガノケン', '下伊那郡阿智村', 'シモイナグンアチムラ', '浪合', 'ナミアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県下伊那郡平谷村', '20', '20409', '3950601', '長野県', 'ナガノケン', '下伊那郡平谷村', 'シモイナグンヒラヤムラ', null, '　', '（全域）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('35090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県下伊那郡根羽村', '20', '20410', '3950701', '長野県', 'ナガノケン', '下伊那郡根羽村', 'シモイナグンネバムラ', null, '　', '（全域）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('35091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市鼎中平', '20', '20205', '3950801', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '鼎中平', 'カナエナカダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市鼎下茶屋', '20', '20205', '3950802', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '鼎下茶屋', 'カナエシモチャヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市鼎下山', '20', '20205', '3950803', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '鼎下山', 'カナエシモヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市鼎名古熊', '20', '20205', '3950804', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '鼎名古熊', 'カナエナゴクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市鼎一色', '20', '20205', '3950805', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '鼎一色', 'カナエイッシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市鼎上山', '20', '20205', '3950806', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '鼎上山', 'カナエカミヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市鼎切石', '20', '20205', '3950807', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '鼎切石', 'カナエキリイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市鼎上茶屋', '20', '20205', '3950808', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '鼎上茶屋', 'カナエカミチャヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市松尾上溝', '20', '20205', '3950811', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '松尾上溝', 'マツオアゲミゾ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市松尾代田', '20', '20205', '3950812', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '松尾代田', 'マツオシロダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市毛賀', '20', '20205', '3950813', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '毛賀', 'ケガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市八幡町', '20', '20205', '3950814', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '八幡町', 'ヤワタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市松尾常盤台', '20', '20205', '3950815', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '松尾常盤台', 'マツオトキワダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市松尾久井', '20', '20205', '3950816', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '松尾久井', 'マツオヒサイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市鼎東鼎', '20', '20205', '3950817', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '鼎東鼎', 'カナエヒガシカナエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市松尾新井', '20', '20205', '3950821', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '松尾新井', 'マツオアライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市松尾寺所', '20', '20205', '3950822', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '松尾寺所', 'マツオテラドコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市松尾明', '20', '20205', '3950823', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '松尾明', 'マツオミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市松尾清水', '20', '20205', '3950824', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '松尾清水', 'マツオシミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市松尾城', '20', '20205', '3950825', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '松尾城', 'マツオジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市松尾水城', '20', '20205', '3950826', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '松尾水城', 'マツオミサジロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県下伊那郡喬木村', '20', '20415', '3951100', '長野県', 'ナガノケン', '下伊那郡喬木村', 'シモイナグンタカギムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('35113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県下伊那郡喬木村阿島', '20', '20415', '3951101', '長野県', 'ナガノケン', '下伊那郡喬木村', 'シモイナグンタカギムラ', '阿島', 'アジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県下伊那郡喬木村加々須', '20', '20415', '3951102', '長野県', 'ナガノケン', '下伊那郡喬木村', 'シモイナグンタカギムラ', '加々須', 'カカス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県下伊那郡喬木村大島', '20', '20415', '3951103', '長野県', 'ナガノケン', '下伊那郡喬木村', 'シモイナグンタカギムラ', '大島', 'オオシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県下伊那郡喬木村氏乗', '20', '20415', '3951104', '長野県', 'ナガノケン', '下伊那郡喬木村', 'シモイナグンタカギムラ', '氏乗', 'ウジノリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県下伊那郡喬木村大和知', '20', '20415', '3951105', '長野県', 'ナガノケン', '下伊那郡喬木村', 'シモイナグンタカギムラ', '大和知', 'オオワチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県下伊那郡喬木村富田', '20', '20415', '3951106', '長野県', 'ナガノケン', '下伊那郡喬木村', 'シモイナグンタカギムラ', '富田', 'トミダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県下伊那郡喬木村小川', '20', '20415', '3951107', '長野県', 'ナガノケン', '下伊那郡喬木村', 'シモイナグンタカギムラ', '小川', 'オガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県下伊那郡喬木村伊久間', '20', '20415', '3951108', '長野県', 'ナガノケン', '下伊那郡喬木村', 'シモイナグンタカギムラ', '伊久間', 'イクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県むつ市川内町', '02', '02208', '0395201', '青森県', 'アオモリケン', 'むつ市', 'ムツシ', '川内町', 'カワウチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県むつ市川内町桧川', '02', '02208', '0395202', '青森県', 'アオモリケン', 'むつ市', 'ムツシ', '川内町桧川', 'カワウチマチヒノキガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県むつ市川内町宿野部', '02', '02208', '0395203', '青森県', 'アオモリケン', 'むつ市', 'ムツシ', '川内町宿野部', 'カワウチマチシュクノヘ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県むつ市川内町蛎崎', '02', '02208', '0395204', '青森県', 'アオモリケン', 'むつ市', 'ムツシ', '川内町蛎崎', 'カワウチマチカキザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県むつ市川内町蛎崎半右エ門沢', '02', '02208', '0395304', '青森県', 'アオモリケン', 'むつ市', 'ムツシ', '川内町蛎崎', 'カワウチマチカキザキ', null, null, '半右エ門沢', 'ハンエモンザワ');
INSERT INTO `ms_addresses` VALUES ('35126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県むつ市脇野沢源藤城', '02', '02208', '0395321', '青森県', 'アオモリケン', 'むつ市', 'ムツシ', '脇野沢源藤城', 'ワキノサワゲンドウシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県むつ市脇野沢滝山', '02', '02208', '0395322', '青森県', 'アオモリケン', 'むつ市', 'ムツシ', '脇野沢滝山', 'ワキノサワタキヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県むつ市脇野沢七引', '02', '02208', '0395323', '青森県', 'アオモリケン', 'むつ市', 'ムツシ', '脇野沢七引', 'ワキノサワシチビキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県むつ市脇野沢田ノ頭', '02', '02208', '0395324', '青森県', 'アオモリケン', 'むつ市', 'ムツシ', '脇野沢田ノ頭', 'ワキノサワタノカシラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県むつ市脇野沢辰内', '02', '02208', '0395325', '青森県', 'アオモリケン', 'むつ市', 'ムツシ', '脇野沢辰内', 'ワキノサワタツウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県むつ市脇野沢桂沢', '02', '02208', '0395326', '青森県', 'アオモリケン', 'むつ市', 'ムツシ', '脇野沢桂沢', 'ワキノサワカツラザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県むつ市脇野沢本村', '02', '02208', '0395327', '青森県', 'アオモリケン', 'むつ市', 'ムツシ', '脇野沢本村', 'ワキノサワホンソン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県むつ市脇野沢渡向', '02', '02208', '0395331', '青森県', 'アオモリケン', 'むつ市', 'ムツシ', '脇野沢渡向', 'ワキノサワワタムカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県むつ市脇野沢瀬野川目', '02', '02208', '0395332', '青森県', 'アオモリケン', 'むつ市', 'ムツシ', '脇野沢瀬野川目', 'ワキノサワセノカワメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県むつ市脇野沢黒岩', '02', '02208', '0395333', '青森県', 'アオモリケン', 'むつ市', 'ムツシ', '脇野沢黒岩', 'ワキノサワクロイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県むつ市脇野沢新井田', '02', '02208', '0395334', '青森県', 'アオモリケン', 'むつ市', 'ムツシ', '脇野沢新井田', 'ワキノサワニイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県むつ市脇野沢寄浪', '02', '02208', '0395335', '青森県', 'アオモリケン', 'むつ市', 'ムツシ', '脇野沢寄浪', 'ワキノサワキナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県むつ市脇野沢蛸田', '02', '02208', '0395336', '青森県', 'アオモリケン', 'むつ市', 'ムツシ', '脇野沢蛸田', 'ワキノサワタコダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県むつ市脇野沢九艘泊', '02', '02208', '0395337', '青森県', 'アオモリケン', 'むつ市', 'ムツシ', '脇野沢九艘泊', 'ワキノサワクソウドマリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県むつ市脇野沢鹿間平', '02', '02208', '0395341', '青森県', 'アオモリケン', 'むつ市', 'ムツシ', '脇野沢鹿間平', 'ワキノサワシカマダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県むつ市脇野沢小沢', '02', '02208', '0395342', '青森県', 'アオモリケン', 'むつ市', 'ムツシ', '脇野沢小沢', 'ワキノサワコザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県むつ市脇野沢小サ沢', '02', '02208', '0395343', '青森県', 'アオモリケン', 'むつ市', 'ムツシ', '脇野沢小サ沢', 'ワキノサワコササワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県むつ市脇野沢稲平', '02', '02208', '0395344', '青森県', 'アオモリケン', 'むつ市', 'ムツシ', '脇野沢稲平', 'ワキノサワイナダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県むつ市脇野沢赤坂', '02', '02208', '0395345', '青森県', 'アオモリケン', 'むつ市', 'ムツシ', '脇野沢赤坂', 'ワキノサワアカサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '青森県むつ市脇野沢口広', '02', '02208', '0395346', '青森県', 'アオモリケン', 'むつ市', 'ムツシ', '脇野沢口広', 'ワキノサワクチヒロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県伊那市', '20', '20209', '3960000', '長野県', 'ナガノケン', '伊那市', 'イナシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('35174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県伊那市福島', '20', '20209', '3960001', '長野県', 'ナガノケン', '伊那市', 'イナシ', '福島', 'フクジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県伊那市手良沢岡', '20', '20209', '3960002', '長野県', 'ナガノケン', '伊那市', 'イナシ', '手良沢岡', 'テラサワオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県伊那市手良野口', '20', '20209', '3960003', '長野県', 'ナガノケン', '伊那市', 'イナシ', '手良野口', 'テラノグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県伊那市手良中坪', '20', '20209', '3960004', '長野県', 'ナガノケン', '伊那市', 'イナシ', '手良中坪', 'テラナカツボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県伊那市野底', '20', '20209', '3960005', '長野県', 'ナガノケン', '伊那市', 'イナシ', '野底', 'ノソコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県伊那市上牧', '20', '20209', '3960006', '長野県', 'ナガノケン', '伊那市', 'イナシ', '上牧', 'カミマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県伊那市若宮', '20', '20209', '3960007', '長野県', 'ナガノケン', '伊那市', 'イナシ', '若宮', 'ワカミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県伊那市上の原', '20', '20209', '3960008', '長野県', 'ナガノケン', '伊那市', 'イナシ', '上の原', 'ウエノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県伊那市日影', '20', '20209', '3960009', '長野県', 'ナガノケン', '伊那市', 'イナシ', '日影', 'ヒカゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県伊那市境', '20', '20209', '3960010', '長野県', 'ナガノケン', '伊那市', 'イナシ', '境', 'サカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県伊那市伊那部', '20', '20209', '3960011', '長野県', 'ナガノケン', '伊那市', 'イナシ', '伊那部', 'イナベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県伊那市上新田', '20', '20209', '3960012', '長野県', 'ナガノケン', '伊那市', 'イナシ', '上新田', 'カミシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県伊那市下新田', '20', '20209', '3960013', '長野県', 'ナガノケン', '伊那市', 'イナシ', '下新田', 'シモシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県伊那市狐島', '20', '20209', '3960014', '長野県', 'ナガノケン', '伊那市', 'イナシ', '狐島', 'キツネジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県伊那市中央', '20', '20209', '3960015', '長野県', 'ナガノケン', '伊那市', 'イナシ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県伊那市伊那', '20', '20209', '3960021', '長野県', 'ナガノケン', '伊那市', 'イナシ', '伊那', 'イナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県伊那市御園', '20', '20209', '3960022', '長野県', 'ナガノケン', '伊那市', 'イナシ', '御園', 'ミソノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県伊那市山寺', '20', '20209', '3960023', '長野県', 'ナガノケン', '伊那市', 'イナシ', '山寺', 'ヤマデラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県伊那市坂下', '20', '20209', '3960024', '長野県', 'ナガノケン', '伊那市', 'イナシ', '坂下', 'サカシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県伊那市荒井', '20', '20209', '3960025', '長野県', 'ナガノケン', '伊那市', 'イナシ', '荒井', 'アライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県伊那市西町', '20', '20209', '3960026', '長野県', 'ナガノケン', '伊那市', 'イナシ', '西町', 'ニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県伊那市ますみヶ丘', '20', '20209', '3960027', '長野県', 'ナガノケン', '伊那市', 'イナシ', 'ますみヶ丘', 'マスミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県伊那市荒井内の萱', '20', '20209', '3960028', '長野県', 'ナガノケン', '伊那市', 'イナシ', '荒井内の萱', 'アライウチノカヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県伊那市横山', '20', '20209', '3960029', '長野県', 'ナガノケン', '伊那市', 'イナシ', '横山', 'ヨコヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県伊那市平沢', '20', '20209', '3960030', '長野県', 'ナガノケン', '伊那市', 'イナシ', '平沢', 'ヒラサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県伊那市中の原', '20', '20209', '3960031', '長野県', 'ナガノケン', '伊那市', 'イナシ', '中の原', 'ナカノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県伊那市小沢', '20', '20209', '3960032', '長野県', 'ナガノケン', '伊那市', 'イナシ', '小沢', 'オザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県伊那市小四郎久保', '20', '20209', '3960033', '長野県', 'ナガノケン', '伊那市', 'イナシ', '小四郎久保', 'コシロウクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県伊那市美篶', '20', '20209', '3960111', '長野県', 'ナガノケン', '伊那市', 'イナシ', '美篶', 'ミスズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県伊那市前原', '20', '20209', '3960112', '長野県', 'ナガノケン', '伊那市', 'イナシ', '前原', 'マエハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県伊那市美原', '20', '20209', '3960113', '長野県', 'ナガノケン', '伊那市', 'イナシ', '美原', 'ミハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県伊那市仙美', '20', '20209', '3960114', '長野県', 'ナガノケン', '伊那市', 'イナシ', '仙美', 'センミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県伊那市高遠町西高遠', '20', '20209', '3960211', '長野県', 'ナガノケン', '伊那市', 'イナシ', '高遠町西高遠', 'タカトオマチニシタカトオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県伊那市高遠町長藤', '20', '20209', '3960212', '長野県', 'ナガノケン', '伊那市', 'イナシ', '高遠町長藤', 'タカトオマチオサフジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県伊那市高遠町東高遠', '20', '20209', '3960213', '長野県', 'ナガノケン', '伊那市', 'イナシ', '高遠町東高遠', 'タカトオマチヒガシタカトオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県伊那市高遠町勝間', '20', '20209', '3960214', '長野県', 'ナガノケン', '伊那市', 'イナシ', '高遠町勝間', 'タカトオマチカツマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県伊那市高遠町小原', '20', '20209', '3960215', '長野県', 'ナガノケン', '伊那市', 'イナシ', '高遠町小原', 'タカトオマチオバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県伊那市高遠町下山田', '20', '20209', '3960216', '長野県', 'ナガノケン', '伊那市', 'イナシ', '高遠町下山田', 'タカトオマチシモヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県伊那市高遠町上山田', '20', '20209', '3960217', '長野県', 'ナガノケン', '伊那市', 'イナシ', '高遠町上山田', 'タカトオマチカミヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県伊那市高遠町藤沢', '20', '20209', '3960301', '長野県', 'ナガノケン', '伊那市', 'イナシ', '高遠町藤沢', 'タカトオマチフジサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県伊那市高遠町芝平', '20', '20209', '3960302', '長野県', 'ナガノケン', '伊那市', 'イナシ', '高遠町芝平', 'タカトオマチシビラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県伊那市高遠町荊口', '20', '20209', '3960303', '長野県', 'ナガノケン', '伊那市', 'イナシ', '高遠町荊口', 'タカトオマチバラグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県伊那市高遠町山室', '20', '20209', '3960304', '長野県', 'ナガノケン', '伊那市', 'イナシ', '高遠町山室', 'タカトオマチヤマムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県伊那市高遠町長藤', '20', '20209', '3960305', '長野県', 'ナガノケン', '伊那市', 'イナシ', '高遠町長藤', 'タカトオマチオサフジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県伊那市長谷非持', '20', '20209', '3960401', '長野県', 'ナガノケン', '伊那市', 'イナシ', '長谷非持', 'ハセヒジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県伊那市長谷溝口', '20', '20209', '3960402', '長野県', 'ナガノケン', '伊那市', 'イナシ', '長谷溝口', 'ハセミゾクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県伊那市長谷黒河内', '20', '20209', '3960403', '長野県', 'ナガノケン', '伊那市', 'イナシ', '長谷黒河内', 'ハセクロゴウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県伊那市長谷中尾', '20', '20209', '3960404', '長野県', 'ナガノケン', '伊那市', 'イナシ', '長谷中尾', 'ハセナカオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県伊那市長谷市野瀬', '20', '20209', '3960405', '長野県', 'ナガノケン', '伊那市', 'イナシ', '長谷市野瀬', 'ハセイチノセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県伊那市長谷杉島', '20', '20209', '3960406', '長野県', 'ナガノケン', '伊那市', 'イナシ', '長谷杉島', 'ハセスギシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県伊那市長谷浦', '20', '20209', '3960407', '長野県', 'ナガノケン', '伊那市', 'イナシ', '長谷浦', 'ハセウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県伊那市富県', '20', '20209', '3960621', '長野県', 'ナガノケン', '伊那市', 'イナシ', '富県', 'トミガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県木曽郡木曽町', '20', '20432', '3970000', '長野県', 'ナガノケン', '木曽郡木曽町', 'キソグンキソマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('35239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県木曽郡木曽町福島', '20', '20432', '3970001', '長野県', 'ナガノケン', '木曽郡木曽町', 'キソグンキソマチ', '福島', 'フクシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県木曽郡木曽町新開', '20', '20432', '3970002', '長野県', 'ナガノケン', '木曽郡木曽町', 'キソグンキソマチ', '新開', 'シンカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県木曽郡木曽町新開福', '20', '20432', '3970003', '長野県', 'ナガノケン', '木曽郡木曽町', 'キソグンキソマチ', '新開福', 'シンカイフク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県木曽郡木曽町三岳', '20', '20432', '3970101', '長野県', 'ナガノケン', '木曽郡木曽町', 'キソグンキソマチ', '三岳', 'ミタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県木曽郡王滝村', '20', '20429', '3970201', '長野県', 'ナガノケン', '木曽郡王滝村', 'キソグンオウタキムラ', null, '　', '（全域）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('35245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県木曽郡木曽町開田高原末川', '20', '20432', '3970301', '長野県', 'ナガノケン', '木曽郡木曽町', 'キソグンキソマチ', '開田高原末川', 'カイダコウゲンスエカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県木曽郡木曽町開田高原西野', '20', '20432', '3970302', '長野県', 'ナガノケン', '木曽郡木曽町', 'キソグンキソマチ', '開田高原西野', 'カイダコウゲンニシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県大町市', '20', '20212', '3980000', '長野県', 'ナガノケン', '大町市', 'オオマチシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('35256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県大町市平', '20', '20212', '3980001', '長野県', 'ナガノケン', '大町市', 'オオマチシ', '平', 'タイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県大町市大町', '20', '20212', '3980002', '長野県', 'ナガノケン', '大町市', 'オオマチシ', '大町', 'オオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県大町市社', '20', '20212', '3980003', '長野県', 'ナガノケン', '大町市', 'オオマチシ', '社', 'ヤシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県大町市常盤', '20', '20212', '3980004', '長野県', 'ナガノケン', '大町市', 'オオマチシ', '常盤', 'トキワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市', '20', '20202', '3990000', '長野県', 'ナガノケン', '松本市', 'マツモトシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('35265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市宮田', '20', '20202', '3990001', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '宮田', 'ミヤタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市芳野', '20', '20202', '3990002', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '芳野', 'ヨシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市芳川野溝', '20', '20202', '3990003', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '芳川野溝', 'ヨシカワノミゾ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市市場', '20', '20202', '3990004', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '市場', 'イチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市野溝木工', '20', '20202', '3990005', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '野溝木工', 'ノミゾモッコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市野溝西', '20', '20202', '3990006', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '野溝西', 'ノミゾニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市石芝3丁目', '20', '20202', '3990007', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '石芝', 'イシシバ', null, null, '3丁目', '03チョウメ');
INSERT INTO `ms_addresses` VALUES ('35272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市石芝4丁目', '20', '20202', '3990007', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '石芝', 'イシシバ', null, null, '4丁目', '04チョウメ');
INSERT INTO `ms_addresses` VALUES ('35273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市寿北', '20', '20202', '3990011', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '寿北', 'コトブキキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市寿白瀬渕', '20', '20202', '3990012', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '寿白瀬渕', 'コトブキシラセブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市芳川平田', '20', '20202', '3990013', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '芳川平田', 'ヨシカワヒラタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市平田東', '20', '20202', '3990014', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '平田東', 'ヒラタヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市平田西', '20', '20202', '3990015', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '平田西', 'ヒラタニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市寿豊丘', '20', '20202', '3990021', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '寿豊丘', 'コトブキトヨオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市松原', '20', '20202', '3990022', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '松原', 'マツバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市内田', '20', '20202', '3990023', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '内田', 'ウチダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市寿小赤', '20', '20202', '3990024', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '寿小赤', 'コトブキコアカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市寿台', '20', '20202', '3990025', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '寿台', 'コトブキダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市寿中', '20', '20202', '3990026', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '寿中', 'コトブキナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市寿南', '20', '20202', '3990027', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '寿南', 'コトブキミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市芳川小屋', '20', '20202', '3990031', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '芳川小屋', 'ヨシカワコヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市芳川村井町', '20', '20202', '3990032', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '芳川村井町', 'ヨシカワムライマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市笹賀', '20', '20202', '3990033', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '笹賀', 'ササガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市野溝東', '20', '20202', '3990034', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '野溝東', 'ノミゾヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県塩尻市片丘', '20', '20215', '3990071', '長野県', 'ナガノケン', '塩尻市', 'シオジリシ', '片丘', 'カタオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪郡富士見町境', '20', '20362', '3990101', '長野県', 'ナガノケン', '諏訪郡富士見町', 'スワグンフジミマチ', '境', 'サカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪郡富士見町落合', '20', '20362', '3990102', '長野県', 'ナガノケン', '諏訪郡富士見町', 'スワグンフジミマチ', '落合', 'オチアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪郡富士見町', '20', '20362', '3990200', '長野県', 'ナガノケン', '諏訪郡富士見町', 'スワグンフジミマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('35293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪郡富士見町富士見', '20', '20362', '3990211', '長野県', 'ナガノケン', '諏訪郡富士見町', 'スワグンフジミマチ', '富士見', 'フジミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪郡富士見町立沢', '20', '20362', '3990212', '長野県', 'ナガノケン', '諏訪郡富士見町', 'スワグンフジミマチ', '立沢', 'タツザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪郡富士見町乙事', '20', '20362', '3990213', '長野県', 'ナガノケン', '諏訪郡富士見町', 'スワグンフジミマチ', '乙事', 'オッコト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県諏訪郡富士見町落合', '20', '20362', '3990214', '長野県', 'ナガノケン', '諏訪郡富士見町', 'スワグンフジミマチ', '落合', 'オチアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上伊那郡辰野町', '20', '20382', '3990400', '長野県', 'ナガノケン', '上伊那郡辰野町', 'カミイナグンタツノマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('35301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上伊那郡辰野町辰野', '20', '20382', '3990421', '長野県', 'ナガノケン', '上伊那郡辰野町', 'カミイナグンタツノマチ', '辰野', 'タツノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上伊那郡辰野町平出', '20', '20382', '3990422', '長野県', 'ナガノケン', '上伊那郡辰野町', 'カミイナグンタツノマチ', '平出', 'ヒライデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上伊那郡辰野町沢底', '20', '20382', '3990423', '長野県', 'ナガノケン', '上伊那郡辰野町', 'カミイナグンタツノマチ', '沢底', 'サワソコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上伊那郡辰野町赤羽', '20', '20382', '3990424', '長野県', 'ナガノケン', '上伊那郡辰野町', 'カミイナグンタツノマチ', '赤羽', 'アカハネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上伊那郡辰野町樋口', '20', '20382', '3990425', '長野県', 'ナガノケン', '上伊那郡辰野町', 'カミイナグンタツノマチ', '樋口', 'ヒグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上伊那郡辰野町宮木', '20', '20382', '3990426', '長野県', 'ナガノケン', '上伊那郡辰野町', 'カミイナグンタツノマチ', '宮木', 'ミヤキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上伊那郡辰野町中央', '20', '20382', '3990427', '長野県', 'ナガノケン', '上伊那郡辰野町', 'カミイナグンタツノマチ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上伊那郡辰野町伊那富', '20', '20382', '3990428', '長野県', 'ナガノケン', '上伊那郡辰野町', 'カミイナグンタツノマチ', '伊那富', 'イナトミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上伊那郡辰野町横川', '20', '20382', '3990511', '長野県', 'ナガノケン', '上伊那郡辰野町', 'カミイナグンタツノマチ', '横川', 'ヨコカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上伊那郡辰野町上島', '20', '20382', '3990512', '長野県', 'ナガノケン', '上伊那郡辰野町', 'カミイナグンタツノマチ', '上島', 'カミジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上伊那郡辰野町小野', '20', '20382', '3990601', '長野県', 'ナガノケン', '上伊那郡辰野町', 'カミイナグンタツノマチ', '小野', 'オノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県塩尻市北小野', '20', '20215', '3990651', '長野県', 'ナガノケン', '塩尻市', 'シオジリシ', '北小野', 'キタオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県塩尻市', '20', '20215', '3990700', '長野県', 'ナガノケン', '塩尻市', 'シオジリシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('35320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県塩尻市広丘吉田', '20', '20215', '3990701', '長野県', 'ナガノケン', '塩尻市', 'シオジリシ', '広丘吉田', 'ヒロオカヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県塩尻市広丘野村', '20', '20215', '3990702', '長野県', 'ナガノケン', '塩尻市', 'シオジリシ', '広丘野村', 'ヒロオカノムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県塩尻市広丘高出', '20', '20215', '3990703', '長野県', 'ナガノケン', '塩尻市', 'シオジリシ', '広丘高出', 'ヒロオカタカイデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県塩尻市広丘郷原', '20', '20215', '3990704', '長野県', 'ナガノケン', '塩尻市', 'シオジリシ', '広丘郷原', 'ヒロオカゴウバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県塩尻市広丘堅石', '20', '20215', '3990705', '長野県', 'ナガノケン', '塩尻市', 'シオジリシ', '広丘堅石', 'ヒロオカカタイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県塩尻市広丘原新田', '20', '20215', '3990706', '長野県', 'ナガノケン', '塩尻市', 'シオジリシ', '広丘原新田', 'ヒロオカハラシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県塩尻市片丘', '20', '20215', '3990711', '長野県', 'ナガノケン', '塩尻市', 'シオジリシ', '片丘', 'カタオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県塩尻市塩尻町', '20', '20215', '3990712', '長野県', 'ナガノケン', '塩尻市', 'シオジリシ', '塩尻町', 'シオジリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県塩尻市大小屋', '20', '20215', '3990713', '長野県', 'ナガノケン', '塩尻市', 'シオジリシ', '大小屋', 'オオゴヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県塩尻市堀ノ内', '20', '20215', '3990714', '長野県', 'ナガノケン', '塩尻市', 'シオジリシ', '堀ノ内', 'ホリノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県塩尻市長畝', '20', '20215', '3990715', '長野県', 'ナガノケン', '塩尻市', 'シオジリシ', '長畝', 'ナガウネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県塩尻市桟敷', '20', '20215', '3990716', '長野県', 'ナガノケン', '塩尻市', 'シオジリシ', '桟敷', 'サジキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県塩尻市金井', '20', '20215', '3990721', '長野県', 'ナガノケン', '塩尻市', 'シオジリシ', '金井', 'カナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県塩尻市柿沢', '20', '20215', '3990722', '長野県', 'ナガノケン', '塩尻市', 'シオジリシ', '柿沢', 'カキザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県塩尻市旧塩尻', '20', '20215', '3990723', '長野県', 'ナガノケン', '塩尻市', 'シオジリシ', '旧塩尻', 'キュウシオジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県塩尻市上西条', '20', '20215', '3990724', '長野県', 'ナガノケン', '塩尻市', 'シオジリシ', '上西条', 'カミニシジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県塩尻市中西条', '20', '20215', '3990725', '長野県', 'ナガノケン', '塩尻市', 'シオジリシ', '中西条', 'ナカニシジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県塩尻市下西条', '20', '20215', '3990726', '長野県', 'ナガノケン', '塩尻市', 'シオジリシ', '下西条', 'シモニシジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県塩尻市みどり湖', '20', '20215', '3990727', '長野県', 'ナガノケン', '塩尻市', 'シオジリシ', 'みどり湖', 'ミドリコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県塩尻市峰原', '20', '20215', '3990728', '長野県', 'ナガノケン', '塩尻市', 'シオジリシ', '峰原', 'ミネハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県塩尻市大門六番町', '20', '20215', '3990731', '長野県', 'ナガノケン', '塩尻市', 'シオジリシ', '大門六番町', 'ダイモン06バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県塩尻市大門五番町', '20', '20215', '3990732', '長野県', 'ナガノケン', '塩尻市', 'シオジリシ', '大門五番町', 'ダイモン05バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県塩尻市大門三番町', '20', '20215', '3990733', '長野県', 'ナガノケン', '塩尻市', 'シオジリシ', '大門三番町', 'ダイモン03バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県塩尻市大門四番町', '20', '20215', '3990734', '長野県', 'ナガノケン', '塩尻市', 'シオジリシ', '大門四番町', 'ダイモン04バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県塩尻市大門二番町', '20', '20215', '3990735', '長野県', 'ナガノケン', '塩尻市', 'シオジリシ', '大門二番町', 'ダイモン02バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県塩尻市大門一番町', '20', '20215', '3990736', '長野県', 'ナガノケン', '塩尻市', 'シオジリシ', '大門一番町', 'ダイモン01バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県塩尻市大門八番町', '20', '20215', '3990737', '長野県', 'ナガノケン', '塩尻市', 'シオジリシ', '大門八番町', 'ダイモン08バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県塩尻市大門七番町', '20', '20215', '3990738', '長野県', 'ナガノケン', '塩尻市', 'シオジリシ', '大門七番町', 'ダイモン07バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県塩尻市大門幸町', '20', '20215', '3990741', '長野県', 'ナガノケン', '塩尻市', 'シオジリシ', '大門幸町', 'ダイモンサイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県塩尻市大門泉町', '20', '20215', '3990742', '長野県', 'ナガノケン', '塩尻市', 'シオジリシ', '大門泉町', 'ダイモンイズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県塩尻市大門田川町', '20', '20215', '3990743', '長野県', 'ナガノケン', '塩尻市', 'シオジリシ', '大門田川町', 'ダイモンタガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県塩尻市大門', '20', '20215', '3990744', '長野県', 'ナガノケン', '塩尻市', 'シオジリシ', '大門', 'ダイモン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県塩尻市大門七区', '20', '20215', '3990744', '長野県', 'ナガノケン', '塩尻市', 'シオジリシ', '大門七区', 'ダイモン07ク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県塩尻市大門桔梗町', '20', '20215', '3990745', '長野県', 'ナガノケン', '塩尻市', 'シオジリシ', '大門桔梗町', 'ダイモンキキョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県塩尻市大門並木町', '20', '20215', '3990746', '長野県', 'ナガノケン', '塩尻市', 'シオジリシ', '大門並木町', 'ダイモンナミキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県下伊那郡天龍村', '20', '20413', '3991200', '長野県', 'ナガノケン', '下伊那郡天龍村', 'シモイナグンテンリュウムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('35362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県下伊那郡天龍村平岡', '20', '20413', '3991201', '長野県', 'ナガノケン', '下伊那郡天龍村', 'シモイナグンテンリュウムラ', '平岡', 'ヒラオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県下伊那郡天龍村神原', '20', '20413', '3991202', '長野県', 'ナガノケン', '下伊那郡天龍村', 'シモイナグンテンリュウムラ', '神原', 'カミハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県下伊那郡天龍村長島', '20', '20413', '3991203', '長野県', 'ナガノケン', '下伊那郡天龍村', 'シモイナグンテンリュウムラ', '長島', 'ナガシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市南信濃南和田万古', '20', '20205', '3991221', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '南信濃南和田', 'ミナミシナノミナミワダ', null, null, '万古', 'マンゴ');
INSERT INTO `ms_addresses` VALUES ('35366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市南信濃和田', '20', '20205', '3991311', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '南信濃和田', 'ミナミシナノワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市南信濃八重河内', '20', '20205', '3991312', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '南信濃八重河内', 'ミナミシナノヤエゴウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市南信濃南和田', '20', '20205', '3991313', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '南信濃南和田', 'ミナミシナノミナミワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市南信濃木沢', '20', '20205', '3991401', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '南信濃木沢', 'ミナミシナノキザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市上村', '20', '20205', '3991403', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '上村', 'カミムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県下伊那郡阿南町', '20', '20404', '3991500', '長野県', 'ナガノケン', '下伊那郡阿南町', 'シモイナグンアナンチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('35373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県下伊那郡阿南町北條', '20', '20404', '3991501', '長野県', 'ナガノケン', '下伊那郡阿南町', 'シモイナグンアナンチョウ', '北條', 'キタジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県下伊那郡阿南町東條', '20', '20404', '3991502', '長野県', 'ナガノケン', '下伊那郡阿南町', 'シモイナグンアナンチョウ', '東條', 'ヒガシジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県下伊那郡阿南町南條', '20', '20404', '3991503', '長野県', 'ナガノケン', '下伊那郡阿南町', 'シモイナグンアナンチョウ', '南條', 'ミナミジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県下伊那郡阿南町西條', '20', '20404', '3991504', '長野県', 'ナガノケン', '下伊那郡阿南町', 'シモイナグンアナンチョウ', '西條', 'ニシジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県下伊那郡阿南町富草', '20', '20404', '3991505', '長野県', 'ナガノケン', '下伊那郡阿南町', 'シモイナグンアナンチョウ', '富草', 'トミクサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県下伊那郡売木村', '20', '20412', '3991601', '長野県', 'ナガノケン', '下伊那郡売木村', 'シモイナグンウルギムラ', null, '　', '（全域）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('35380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県下伊那郡阿南町和合', '20', '20404', '3991611', '長野県', 'ナガノケン', '下伊那郡阿南町', 'シモイナグンアナンチョウ', '和合', 'ワゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県下伊那郡阿南町新野', '20', '20404', '3991612', '長野県', 'ナガノケン', '下伊那郡阿南町', 'シモイナグンアナンチョウ', '新野', 'ニイノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県下伊那郡泰阜村', '20', '20414', '3991801', '長野県', 'ナガノケン', '下伊那郡泰阜村', 'シモイナグンヤスオカムラ', null, '　', '（全域）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('35385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県下伊那郡下條村', '20', '20411', '3992100', '長野県', 'ナガノケン', '下伊那郡下條村', 'シモイナグンシモジョウムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('35386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県下伊那郡下條村睦沢', '20', '20411', '3992101', '長野県', 'ナガノケン', '下伊那郡下條村', 'シモイナグンシモジョウムラ', '睦沢', 'ムツザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県下伊那郡下條村陽皐', '20', '20411', '3992102', '長野県', 'ナガノケン', '下伊那郡下條村', 'シモイナグンシモジョウムラ', '陽皐', 'ヒサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市龍江', '20', '20205', '3992221', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '龍江', 'タツエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市千代', '20', '20205', '3992222', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '千代', 'チヨ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市千栄', '20', '20205', '3992223', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '千栄', 'チハエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市川路', '20', '20205', '3992431', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '川路', 'カワジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市下瀬', '20', '20205', '3992432', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '下瀬', 'シモゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市立石', '20', '20205', '3992433', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '立石', 'タテイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市伊豆木', '20', '20205', '3992434', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '伊豆木', 'イズキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市駄科', '20', '20205', '3992561', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '駄科', 'ダシナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市長野原', '20', '20205', '3992562', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '長野原', 'ナガノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市時又', '20', '20205', '3992563', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '時又', 'トキマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市上川路', '20', '20205', '3992564', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '上川路', 'カミカワジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市桐林', '20', '20205', '3992565', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '桐林', 'キリバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市嶋', '20', '20205', '3992566', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '嶋', 'シマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市虎岩', '20', '20205', '3992601', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '虎岩', 'トライワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市下久堅下虎岩', '20', '20205', '3992602', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '下久堅下虎岩', 'シモヒサカタシモトライワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市下久堅知久平', '20', '20205', '3992603', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '下久堅知久平', 'シモヒサカタチクダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市下久堅柿野沢', '20', '20205', '3992604', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '下久堅柿野沢', 'シモヒサカタカキノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市下久堅小林', '20', '20205', '3992605', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '下久堅小林', 'シモヒサカタコバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市下久堅稲葉', '20', '20205', '3992606', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '下久堅稲葉', 'シモヒサカタイナバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市下久堅南原', '20', '20205', '3992607', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '下久堅南原', 'シモヒサカタミナバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市上久堅', '20', '20205', '3992611', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '上久堅', 'カミヒサカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県飯田市上久堅戊', '20', '20205', '3992612', '長野県', 'ナガノケン', '飯田市', 'イイダシ', '上久堅戊', 'カミヒサカタボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県下伊那郡高森町', '20', '20403', '3993100', '長野県', 'ナガノケン', '下伊那郡高森町', 'シモイナグンタカモリマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('35411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県下伊那郡高森町山吹', '20', '20403', '3993101', '長野県', 'ナガノケン', '下伊那郡高森町', 'シモイナグンタカモリマチ', '山吹', 'ヤマブキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県下伊那郡高森町吉田', '20', '20403', '3993102', '長野県', 'ナガノケン', '下伊那郡高森町', 'シモイナグンタカモリマチ', '吉田', 'ヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県下伊那郡高森町下市田', '20', '20403', '3993103', '長野県', 'ナガノケン', '下伊那郡高森町', 'シモイナグンタカモリマチ', '下市田', 'シモイチダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県下伊那郡高森町上市田', '20', '20403', '3993104', '長野県', 'ナガノケン', '下伊那郡高森町', 'シモイナグンタカモリマチ', '上市田', 'カミイチダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県下伊那郡高森町牛牧', '20', '20403', '3993105', '長野県', 'ナガノケン', '下伊那郡高森町', 'シモイナグンタカモリマチ', '牛牧', 'ウシマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県下伊那郡高森町大島山', '20', '20403', '3993106', '長野県', 'ナガノケン', '下伊那郡高森町', 'シモイナグンタカモリマチ', '大島山', 'オオジマサン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県下伊那郡高森町出原', '20', '20403', '3993107', '長野県', 'ナガノケン', '下伊那郡高森町', 'シモイナグンタカモリマチ', '出原', 'イズハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県下伊那郡豊丘村', '20', '20416', '3993200', '長野県', 'ナガノケン', '下伊那郡豊丘村', 'シモイナグントヨオカムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('35421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県下伊那郡豊丘村河野', '20', '20416', '3993201', '長野県', 'ナガノケン', '下伊那郡豊丘村', 'シモイナグントヨオカムラ', '河野', 'カワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県下伊那郡豊丘村神稲', '20', '20416', '3993202', '長野県', 'ナガノケン', '下伊那郡豊丘村', 'シモイナグントヨオカムラ', '神稲', 'クマシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県下伊那郡松川町', '20', '20402', '3993300', '長野県', 'ナガノケン', '下伊那郡松川町', 'シモイナグンマツカワマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('35425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県下伊那郡松川町上片桐', '20', '20402', '3993301', '長野県', 'ナガノケン', '下伊那郡松川町', 'シモイナグンマツカワマチ', '上片桐', 'カミカタギリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県下伊那郡松川町生田', '20', '20402', '3993302', '長野県', 'ナガノケン', '下伊那郡松川町', 'シモイナグンマツカワマチ', '生田', 'イクタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県下伊那郡松川町元大島', '20', '20402', '3993303', '長野県', 'ナガノケン', '下伊那郡松川町', 'シモイナグンマツカワマチ', '元大島', 'モトオオシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県下伊那郡松川町大島', '20', '20402', '3993304', '長野県', 'ナガノケン', '下伊那郡松川町', 'シモイナグンマツカワマチ', '大島', 'オオシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県下伊那郡豊丘村河野', '20', '20416', '3993311', '長野県', 'ナガノケン', '下伊那郡豊丘村', 'シモイナグントヨオカムラ', '河野', 'カワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県下伊那郡大鹿村', '20', '20417', '3993500', '長野県', 'ナガノケン', '下伊那郡大鹿村', 'シモイナグンオオシカムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('35431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県下伊那郡大鹿村鹿塩', '20', '20417', '3993501', '長野県', 'ナガノケン', '下伊那郡大鹿村', 'シモイナグンオオシカムラ', '鹿塩', 'カシオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県下伊那郡大鹿村大河原', '20', '20417', '3993502', '長野県', 'ナガノケン', '下伊那郡大鹿村', 'シモイナグンオオシカムラ', '大河原', 'オオカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上伊那郡飯島町', '20', '20384', '3993700', '長野県', 'ナガノケン', '上伊那郡飯島町', 'カミイナグンイイジママチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('35434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上伊那郡飯島町田切', '20', '20384', '3993701', '長野県', 'ナガノケン', '上伊那郡飯島町', 'カミイナグンイイジママチ', '田切', 'タギリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上伊那郡飯島町飯島', '20', '20384', '3993702', '長野県', 'ナガノケン', '上伊那郡飯島町', 'カミイナグンイイジママチ', '飯島', 'イイジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上伊那郡飯島町日曽利', '20', '20384', '3993703', '長野県', 'ナガノケン', '上伊那郡飯島町', 'カミイナグンイイジママチ', '日曽利', 'ヒッソリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上伊那郡飯島町本郷', '20', '20384', '3993704', '長野県', 'ナガノケン', '上伊那郡飯島町', 'カミイナグンイイジママチ', '本郷', 'ホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上伊那郡飯島町七久保', '20', '20384', '3993705', '長野県', 'ナガノケン', '上伊那郡飯島町', 'カミイナグンイイジママチ', '七久保', 'ナナクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上伊那郡中川村', '20', '20386', '3993800', '長野県', 'ナガノケン', '上伊那郡中川村', 'カミイナグンナカガワムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('35441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上伊那郡中川村大草', '20', '20386', '3993801', '長野県', 'ナガノケン', '上伊那郡中川村', 'カミイナグンナカガワムラ', '大草', 'オオクサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上伊那郡中川村片桐', '20', '20386', '3993802', '長野県', 'ナガノケン', '上伊那郡中川村', 'カミイナグンナカガワムラ', '片桐', 'カタギリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上伊那郡中川村葛島', '20', '20386', '3993803', '長野県', 'ナガノケン', '上伊那郡中川村', 'カミイナグンナカガワムラ', '葛島', 'カツラシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上伊那郡中川村四徳', '20', '20386', '3993804', '長野県', 'ナガノケン', '上伊那郡中川村', 'カミイナグンナカガワムラ', '四徳', 'シトク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県駒ヶ根市', '20', '20210', '3994100', '長野県', 'ナガノケン', '駒ヶ根市', 'コマガネシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('35447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県駒ヶ根市下平', '20', '20210', '3994101', '長野県', 'ナガノケン', '駒ヶ根市', 'コマガネシ', '下平', 'シモダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県駒ヶ根市飯坂', '20', '20210', '3994102', '長野県', 'ナガノケン', '駒ヶ根市', 'コマガネシ', '飯坂', 'イイザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県駒ヶ根市梨の木', '20', '20210', '3994103', '長野県', 'ナガノケン', '駒ヶ根市', 'コマガネシ', '梨の木', 'ナシノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県駒ヶ根市経塚', '20', '20210', '3994104', '長野県', 'ナガノケン', '駒ヶ根市', 'コマガネシ', '経塚', 'キョウヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県駒ヶ根市赤須東', '20', '20210', '3994105', '長野県', 'ナガノケン', '駒ヶ根市', 'コマガネシ', '赤須東', 'アカズヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県駒ヶ根市東町', '20', '20210', '3994106', '長野県', 'ナガノケン', '駒ヶ根市', 'コマガネシ', '東町', 'ヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県駒ヶ根市北町', '20', '20210', '3994111', '長野県', 'ナガノケン', '駒ヶ根市', 'コマガネシ', '北町', 'キタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県駒ヶ根市中央', '20', '20210', '3994112', '長野県', 'ナガノケン', '駒ヶ根市', 'コマガネシ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県駒ヶ根市赤須町', '20', '20210', '3994113', '長野県', 'ナガノケン', '駒ヶ根市', 'コマガネシ', '赤須町', 'アカズマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県駒ヶ根市上穂南', '20', '20210', '3994114', '長野県', 'ナガノケン', '駒ヶ根市', 'コマガネシ', '上穂南', 'ウワブミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県駒ヶ根市上穂栄町', '20', '20210', '3994115', '長野県', 'ナガノケン', '駒ヶ根市', 'コマガネシ', '上穂栄町', 'ウワブサカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県駒ヶ根市上穂北', '20', '20210', '3994116', '長野県', 'ナガノケン', '駒ヶ根市', 'コマガネシ', '上穂北', 'ウワブキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県駒ヶ根市赤穂', '20', '20210', '3994117', '長野県', 'ナガノケン', '駒ヶ根市', 'コマガネシ', '赤穂', 'アカホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県駒ヶ根市中沢', '20', '20210', '3994231', '長野県', 'ナガノケン', '駒ヶ根市', 'コマガネシ', '中沢', 'ナカザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県駒ヶ根市下平', '20', '20210', '3994232', '長野県', 'ナガノケン', '駒ヶ根市', 'コマガネシ', '下平', 'シモダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上伊那郡宮田村', '20', '20388', '3994301', '長野県', 'ナガノケン', '上伊那郡宮田村', 'カミイナグンミヤダムラ', null, '　', '（全域）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('35465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県駒ヶ根市東伊那', '20', '20210', '3994321', '長野県', 'ナガノケン', '駒ヶ根市', 'コマガネシ', '東伊那', 'ヒガシイナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県伊那市西春近', '20', '20209', '3994431', '長野県', 'ナガノケン', '伊那市', 'イナシ', '西春近', 'ニシハルチカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県伊那市東春近', '20', '20209', '3994432', '長野県', 'ナガノケン', '伊那市', 'イナシ', '東春近', 'ヒガシハルチカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県伊那市西箕輪', '20', '20209', '3994501', '長野県', 'ナガノケン', '伊那市', 'イナシ', '西箕輪', 'ニシミノワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上伊那郡南箕輪村', '20', '20385', '3994511', '長野県', 'ナガノケン', '上伊那郡南箕輪村', 'カミイナグンミナミミノワムラ', null, '　', '（全域）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('35501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上伊那郡箕輪町', '20', '20383', '3994600', '長野県', 'ナガノケン', '上伊那郡箕輪町', 'カミイナグンミノワマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('35502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上伊那郡箕輪町中箕輪', '20', '20383', '3994601', '長野県', 'ナガノケン', '上伊那郡箕輪町', 'カミイナグンミノワマチ', '中箕輪', 'ナカミノワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上伊那郡箕輪町東箕輪', '20', '20383', '3994602', '長野県', 'ナガノケン', '上伊那郡箕輪町', 'カミイナグンミノワマチ', '東箕輪', 'ヒガシミノワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上伊那郡箕輪町三日町', '20', '20383', '3994603', '長野県', 'ナガノケン', '上伊那郡箕輪町', 'カミイナグンミノワマチ', '三日町', 'ミッカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上伊那郡箕輪町福与', '20', '20383', '3994604', '長野県', 'ナガノケン', '上伊那郡箕輪町', 'カミイナグンミノワマチ', '福与', 'フクヨ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県上伊那郡箕輪町中曽根', '20', '20383', '3994605', '長野県', 'ナガノケン', '上伊那郡箕輪町', 'カミイナグンミノワマチ', '中曽根', 'ナカゾネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県木曽郡南木曽町', '20', '20423', '3995300', '長野県', 'ナガノケン', '木曽郡南木曽町', 'キソグンナギソマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('35513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県木曽郡南木曽町読書', '20', '20423', '3995301', '長野県', 'ナガノケン', '木曽郡南木曽町', 'キソグンナギソマチ', '読書', 'ヨミカキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県木曽郡南木曽町吾妻', '20', '20423', '3995302', '長野県', 'ナガノケン', '木曽郡南木曽町', 'キソグンナギソマチ', '吾妻', 'アヅマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県木曽郡南木曽町田立', '20', '20423', '3995303', '長野県', 'ナガノケン', '木曽郡南木曽町', 'キソグンナギソマチ', '田立', 'タダチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県木曽郡大桑村', '20', '20430', '3995500', '長野県', 'ナガノケン', '木曽郡大桑村', 'キソグンオオクワムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('35517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県木曽郡大桑村殿', '20', '20430', '3995501', '長野県', 'ナガノケン', '木曽郡大桑村', 'キソグンオオクワムラ', '殿', 'トノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県木曽郡大桑村須原', '20', '20430', '3995502', '長野県', 'ナガノケン', '木曽郡大桑村', 'キソグンオオクワムラ', '須原', 'スハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県木曽郡大桑村長野', '20', '20430', '3995503', '長野県', 'ナガノケン', '木曽郡大桑村', 'キソグンオオクワムラ', '長野', 'ナガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県木曽郡大桑村野尻', '20', '20430', '3995504', '長野県', 'ナガノケン', '木曽郡大桑村', 'キソグンオオクワムラ', '野尻', 'ノジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県木曽郡上松町', '20', '20422', '3995600', '長野県', 'ナガノケン', '木曽郡上松町', 'キソグンアゲマツマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('35522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県木曽郡上松町上松', '20', '20422', '3995601', '長野県', 'ナガノケン', '木曽郡上松町', 'キソグンアゲマツマチ', '上松', 'アゲマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県木曽郡上松町本町通り', '20', '20422', '3995602', '長野県', 'ナガノケン', '木曽郡上松町', 'キソグンアゲマツマチ', '本町通り', 'ホンマチドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県木曽郡上松町駅前通り', '20', '20422', '3995603', '長野県', 'ナガノケン', '木曽郡上松町', 'キソグンアゲマツマチ', '駅前通り', 'エキマエドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県木曽郡上松町正島町', '20', '20422', '3995604', '長野県', 'ナガノケン', '木曽郡上松町', 'キソグンアゲマツマチ', '正島町', 'ショウジママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県木曽郡上松町栄町', '20', '20422', '3995605', '長野県', 'ナガノケン', '木曽郡上松町', 'キソグンアゲマツマチ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県木曽郡上松町緑町', '20', '20422', '3995606', '長野県', 'ナガノケン', '木曽郡上松町', 'キソグンアゲマツマチ', '緑町', 'ミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県木曽郡上松町小川', '20', '20422', '3995607', '長野県', 'ナガノケン', '木曽郡上松町', 'キソグンアゲマツマチ', '小川', 'オガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県木曽郡上松町荻原', '20', '20422', '3995608', '長野県', 'ナガノケン', '木曽郡上松町', 'キソグンアゲマツマチ', '荻原', 'オギハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県木曽郡上松町旭町', '20', '20422', '3995609', '長野県', 'ナガノケン', '木曽郡上松町', 'キソグンアゲマツマチ', '旭町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県木曽郡木曽町日義', '20', '20432', '3996101', '長野県', 'ナガノケン', '木曽郡木曽町', 'キソグンキソマチ', '日義', 'ヒヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県木曽郡木祖村', '20', '20425', '3996200', '長野県', 'ナガノケン', '木曽郡木祖村', 'キソグンキソムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('35533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県木曽郡木祖村薮原', '20', '20425', '3996201', '長野県', 'ナガノケン', '木曽郡木祖村', 'キソグンキソムラ', '薮原', 'ヤブハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県木曽郡木祖村菅', '20', '20425', '3996202', '長野県', 'ナガノケン', '木曽郡木祖村', 'キソグンキソムラ', '菅', 'スゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県木曽郡木祖村小木曽', '20', '20425', '3996203', '長野県', 'ナガノケン', '木曽郡木祖村', 'キソグンキソムラ', '小木曽', 'オギソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県塩尻市贄川', '20', '20215', '3996301', '長野県', 'ナガノケン', '塩尻市', 'シオジリシ', '贄川', 'ニエカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県塩尻市木曽平沢', '20', '20215', '3996302', '長野県', 'ナガノケン', '塩尻市', 'シオジリシ', '木曽平沢', 'キソヒラサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県塩尻市奈良井', '20', '20215', '3996303', '長野県', 'ナガノケン', '塩尻市', 'シオジリシ', '奈良井', 'ナライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県塩尻市宗賀', '20', '20215', '3996461', '長野県', 'ナガノケン', '塩尻市', 'シオジリシ', '宗賀', 'ソウガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県塩尻市洗馬', '20', '20215', '3996462', '長野県', 'ナガノケン', '塩尻市', 'シオジリシ', '洗馬', 'セバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県安曇野市明科東川手', '20', '20220', '3997101', '長野県', 'ナガノケン', '安曇野市', 'アヅミノシ', '明科東川手', 'アカシナヒガシカワテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県安曇野市明科中川手', '20', '20220', '3997102', '長野県', 'ナガノケン', '安曇野市', 'アヅミノシ', '明科中川手', 'アカシナナカガワテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県安曇野市明科光', '20', '20220', '3997103', '長野県', 'ナガノケン', '安曇野市', 'アヅミノシ', '明科光', 'アカシナヒカル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県安曇野市明科七貴', '20', '20220', '3997104', '長野県', 'ナガノケン', '安曇野市', 'アヅミノシ', '明科七貴', 'アカシナナナキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県安曇野市明科南陸郷', '20', '20220', '3997105', '長野県', 'ナガノケン', '安曇野市', 'アヅミノシ', '明科南陸郷', 'アカシナミナミリクゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県東筑摩郡生坂村', '20', '20448', '3997200', '長野県', 'ナガノケン', '東筑摩郡生坂村', 'ヒガシチクマグンイクサカムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('35548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県東筑摩郡生坂村', '20', '20448', '3997201', '長野県', 'ナガノケン', '東筑摩郡生坂村', 'ヒガシチクマグンイクサカムラ', null, '　', '（直番地）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('35549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県東筑摩郡生坂村北陸郷', '20', '20448', '3997202', '長野県', 'ナガノケン', '東筑摩郡生坂村', 'ヒガシチクマグンイクサカムラ', '北陸郷', 'キタリクゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県大町市八坂', '20', '20212', '3997301', '長野県', 'ナガノケン', '大町市', 'オオマチシ', '八坂', 'ヤサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県大町市八坂菖蒲', '20', '20212', '3997302', '長野県', 'ナガノケン', '大町市', 'オオマチシ', '八坂菖蒲', 'ヤサカショウブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県東筑摩郡生坂村東広津', '20', '20448', '3997311', '長野県', 'ナガノケン', '東筑摩郡生坂村', 'ヒガシチクマグンイクサカムラ', '東広津', 'ヒガシヒロツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市五常', '20', '20202', '3997401', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '五常', 'ゴジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市会田', '20', '20202', '3997402', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '会田', 'アイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市穴沢', '20', '20202', '3997403', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '穴沢', 'アナザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市取出', '20', '20202', '3997404', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '取出', 'トリイデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市板場', '20', '20202', '3997405', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '板場', 'イタバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市中川', '20', '20202', '3997411', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '中川', 'ナカガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市保福寺町', '20', '20202', '3997412', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '保福寺町', 'ホフクジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市金山町', '20', '20202', '3997413', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '金山町', 'カナヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市殿野入', '20', '20202', '3997414', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '殿野入', 'トノノイリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市赤怒田', '20', '20202', '3997415', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '赤怒田', 'アカヌタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市七嵐', '20', '20202', '3997416', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '七嵐', 'ナナアラシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市刈谷原町', '20', '20202', '3997417', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '刈谷原町', 'カリヤハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市反町', '20', '20202', '3997418', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '反町', 'ソリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県東筑摩郡筑北村', '20', '20452', '3997500', '長野県', 'ナガノケン', '東筑摩郡筑北村', 'ヒガシチクマグンチクホクムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('35567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県東筑摩郡筑北村西条', '20', '20452', '3997501', '長野県', 'ナガノケン', '東筑摩郡筑北村', 'ヒガシチクマグンチクホクムラ', '西条', 'ニシジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県東筑摩郡筑北村東条', '20', '20452', '3997502', '長野県', 'ナガノケン', '東筑摩郡筑北村', 'ヒガシチクマグンチクホクムラ', '東条', 'ヒガシジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県東筑摩郡筑北村大沢新田', '20', '20452', '3997503', '長野県', 'ナガノケン', '東筑摩郡筑北村', 'ヒガシチクマグンチクホクムラ', '大沢新田', 'オオサワシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県東筑摩郡筑北村乱橋', '20', '20452', '3997504', '長野県', 'ナガノケン', '東筑摩郡筑北村', 'ヒガシチクマグンチクホクムラ', '乱橋', 'ミダレハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県東筑摩郡筑北村坂北', '20', '20452', '3997601', '長野県', 'ナガノケン', '東筑摩郡筑北村', 'ヒガシチクマグンチクホクムラ', '坂北', 'サカキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県東筑摩郡麻績村', '20', '20446', '3997700', '長野県', 'ナガノケン', '東筑摩郡麻績村', 'ヒガシチクマグンオミムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('35573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県東筑摩郡麻績村麻', '20', '20446', '3997701', '長野県', 'ナガノケン', '東筑摩郡麻績村', 'ヒガシチクマグンオミムラ', '麻', 'オ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県東筑摩郡麻績村日', '20', '20446', '3997702', '長野県', 'ナガノケン', '東筑摩郡麻績村', 'ヒガシチクマグンオミムラ', '日', 'ヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県東筑摩郡筑北村坂井', '20', '20452', '3997711', '長野県', 'ナガノケン', '東筑摩郡筑北村', 'ヒガシチクマグンチクホクムラ', '坂井', 'サカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県安曇野市三郷明盛', '20', '20220', '3998101', '長野県', 'ナガノケン', '安曇野市', 'アヅミノシ', '三郷明盛', 'ミサトメイセイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県安曇野市三郷温', '20', '20220', '3998102', '長野県', 'ナガノケン', '安曇野市', 'アヅミノシ', '三郷温', 'ミサトユタカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県安曇野市三郷小倉', '20', '20220', '3998103', '長野県', 'ナガノケン', '安曇野市', 'アヅミノシ', '三郷小倉', 'ミサトオグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県安曇野市', '20', '20220', '3998200', '長野県', 'ナガノケン', '安曇野市', 'アヅミノシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('35581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県安曇野市豊科南穂高', '20', '20220', '3998201', '長野県', 'ナガノケン', '安曇野市', 'アヅミノシ', '豊科南穂高', 'トヨシナミナミホタカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県安曇野市豊科光', '20', '20220', '3998202', '長野県', 'ナガノケン', '安曇野市', 'アヅミノシ', '豊科光', 'トヨシナヒカル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県安曇野市豊科田沢', '20', '20220', '3998203', '長野県', 'ナガノケン', '安曇野市', 'アヅミノシ', '豊科田沢', 'トヨシナタザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県安曇野市豊科高家', '20', '20220', '3998204', '長野県', 'ナガノケン', '安曇野市', 'アヅミノシ', '豊科高家', 'トヨシナタキベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県安曇野市豊科', '20', '20220', '3998205', '長野県', 'ナガノケン', '安曇野市', 'アヅミノシ', '豊科', 'トヨシナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県安曇野市堀金烏川', '20', '20220', '3998211', '長野県', 'ナガノケン', '安曇野市', 'アヅミノシ', '堀金烏川', 'ホリガネカラスガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県安曇野市堀金三田', '20', '20220', '3998212', '長野県', 'ナガノケン', '安曇野市', 'アヅミノシ', '堀金三田', 'ホリガネミタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県松本市島内', '20', '20202', '3998251', '長野県', 'ナガノケン', '松本市', 'マツモトシ', '島内', 'シマウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県安曇野市穂高有明', '20', '20220', '3998301', '長野県', 'ナガノケン', '安曇野市', 'アヅミノシ', '穂高有明', 'ホタカアリアケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県安曇野市穂高北穂高', '20', '20220', '3998302', '長野県', 'ナガノケン', '安曇野市', 'アヅミノシ', '穂高北穂高', 'ホタカキタホタカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県安曇野市穂高', '20', '20220', '3998303', '長野県', 'ナガノケン', '安曇野市', 'アヅミノシ', '穂高', 'ホタカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県安曇野市穂高柏原', '20', '20220', '3998304', '長野県', 'ナガノケン', '安曇野市', 'アヅミノシ', '穂高柏原', 'ホタカカシワバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県安曇野市穂高牧', '20', '20220', '3998305', '長野県', 'ナガノケン', '安曇野市', 'アヅミノシ', '穂高牧', 'ホタカマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県安曇野市中房温泉', '20', '20220', '3998306', '長野県', 'ナガノケン', '安曇野市', 'アヅミノシ', '中房温泉', 'ナカブサオンセン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県北安曇郡松川村', '20', '20482', '3998501', '長野県', 'ナガノケン', '北安曇郡松川村', 'キタアヅミグンマツカワムラ', null, '　', '（全域）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('35608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県北安曇郡池田町', '20', '20481', '3998600', '長野県', 'ナガノケン', '北安曇郡池田町', 'キタアヅミグンイケダマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('35609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県北安曇郡池田町池田', '20', '20481', '3998601', '長野県', 'ナガノケン', '北安曇郡池田町', 'キタアヅミグンイケダマチ', '池田', 'イケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県北安曇郡池田町会染', '20', '20481', '3998602', '長野県', 'ナガノケン', '北安曇郡池田町', 'キタアヅミグンイケダマチ', '会染', 'アイソメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県北安曇郡池田町中鵜', '20', '20481', '3998603', '長野県', 'ナガノケン', '北安曇郡池田町', 'キタアヅミグンイケダマチ', '中鵜', 'ナカウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県北安曇郡池田町広津', '20', '20481', '3998604', '長野県', 'ナガノケン', '北安曇郡池田町', 'キタアヅミグンイケダマチ', '広津', 'ヒロツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県北安曇郡池田町陸郷', '20', '20481', '3998605', '長野県', 'ナガノケン', '北安曇郡池田町', 'キタアヅミグンイケダマチ', '陸郷', 'リクゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県大町市美麻', '20', '20212', '3999101', '長野県', 'ナガノケン', '大町市', 'オオマチシ', '美麻', 'ミアサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県北安曇郡白馬村神城', '20', '20485', '3999211', '長野県', 'ナガノケン', '北安曇郡白馬村', 'キタアヅミグンハクバムラ', '神城', 'カミシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県北安曇郡白馬村', '20', '20485', '3999300', '長野県', 'ナガノケン', '北安曇郡白馬村', 'キタアヅミグンハクバムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('35642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県北安曇郡白馬村北城', '20', '20485', '3999301', '長野県', 'ナガノケン', '北安曇郡白馬村', 'キタアヅミグンハクバムラ', '北城', 'ホクジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県北安曇郡小谷村', '20', '20486', '3999400', '長野県', 'ナガノケン', '北安曇郡小谷村', 'キタアヅミグンオタリムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('35645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県北安曇郡小谷村中小谷丙', '20', '20486', '3999421', '長野県', 'ナガノケン', '北安曇郡小谷村', 'キタアヅミグンオタリムラ', '中小谷丙', 'ナカオタリヘイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県北安曇郡小谷村千国乙', '20', '20486', '3999422', '長野県', 'ナガノケン', '北安曇郡小谷村', 'キタアヅミグンオタリムラ', '千国乙', 'チクニオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県北安曇郡小谷村中土', '20', '20486', '3999511', '長野県', 'ナガノケン', '北安曇郡小谷村', 'キタアヅミグンオタリムラ', '中土', 'ナカツチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県北安曇郡小谷村北小谷', '20', '20486', '3999601', '長野県', 'ナガノケン', '北安曇郡小谷村', 'キタアヅミグンオタリムラ', '北小谷', 'キタオタリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市厚別区', '01', '01108', '0040000', '北海道', 'ホッカイドウ', '札幌市厚別区', 'サッポロシアツベツク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('35651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市', '01', '01202', '0400000', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('35652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市', '19', '19201', '4000000', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('35653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市清田区', '01', '01110', '0040000', '北海道', 'ホッカイドウ', '札幌市清田区', 'サッポロシキヨタク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('35654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市和田町', '19', '19201', '4000001', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '和田町', 'ワダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市小松町', '19', '19201', '4000002', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '小松町', 'コマツマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市塚原町', '19', '19201', '4000003', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '塚原町', 'ツカハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市西田町', '19', '19201', '4000004', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '西田町', 'ニシダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市北新', '19', '19201', '4000005', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '北新', 'キタシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市天神町', '19', '19201', '4000006', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '天神町', 'テンジンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市美咲', '19', '19201', '4000007', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '美咲', 'ミサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市緑が丘', '19', '19201', '4000008', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '緑が丘', 'ミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市五稜郭町', '01', '01202', '0400001', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '五稜郭町', 'ゴリョウカクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市上積翠寺町', '19', '19201', '4000011', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '上積翠寺町', 'カミセキスイジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市下積翠寺町', '19', '19201', '4000012', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '下積翠寺町', 'シモセキスイジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市岩窪町', '19', '19201', '4000013', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '岩窪町', 'イワクボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市古府中町', '19', '19201', '4000014', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '古府中町', 'コフチュウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市大手', '19', '19201', '4000015', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '大手', 'オオテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市武田', '19', '19201', '4000016', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '武田', 'タケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市屋形', '19', '19201', '4000017', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '屋形', 'ヤカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市柳町', '01', '01202', '0400002', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '柳町', 'ヤナギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市宮前町', '19', '19201', '4000021', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '宮前町', 'ミヤマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市元紺屋町', '19', '19201', '4000022', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '元紺屋町', 'モトコンヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市愛宕町', '19', '19201', '4000023', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '愛宕町', 'アタゴマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市北口', '19', '19201', '4000024', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '北口', 'キタグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市朝日', '19', '19201', '4000025', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '朝日', 'アサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市塩部', '19', '19201', '4000026', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '塩部', 'シオベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市富士見', '19', '19201', '4000027', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '富士見', 'フジミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市音羽町', '19', '19201', '4000028', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '音羽町', 'オトワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市松陰町', '01', '01202', '0400003', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '松陰町', 'マツカゲチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市丸の内', '19', '19201', '4000031', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '丸の内', 'マルノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市中央', '19', '19201', '4000032', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市寿町', '19', '19201', '4000033', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '寿町', 'コトブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市宝', '19', '19201', '4000034', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '宝', 'タカラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市飯田', '19', '19201', '4000035', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '飯田', 'イイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市杉並町', '01', '01202', '0400004', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '杉並町', 'スギナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市上石田', '19', '19201', '4000041', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '上石田', 'カミイシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市高畑', '19', '19201', '4000042', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '高畑', 'タカバタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市国母', '19', '19201', '4000043', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '国母', 'コクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市上小河原町', '19', '19201', '4000044', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '上小河原町', 'カミコガワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市後屋町', '19', '19201', '4000045', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '後屋町', 'ウシロヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市下石田', '19', '19201', '4000046', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '下石田', 'シモイシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市徳行', '19', '19201', '4000047', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '徳行', 'トクギョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市貢川本町', '19', '19201', '4000048', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '貢川本町', 'クガワホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市富竹', '19', '19201', '4000049', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '富竹', 'トミタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市人見町', '01', '01202', '0400005', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '人見町', 'ヒトミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市古上条町', '19', '19201', '4000051', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '古上条町', 'フルカミジョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市上条新居町', '19', '19201', '4000052', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '上条新居町', 'カミジョウアライマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市大里町', '19', '19201', '4000053', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '大里町', 'オオサトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市西下条町', '19', '19201', '4000054', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '西下条町', 'ニシシモジョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市大津町', '19', '19201', '4000055', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '大津町', 'オオツマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市堀之内町', '19', '19201', '4000056', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '堀之内町', 'ホリノウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市高室町', '19', '19201', '4000057', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '高室町', 'タカムロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市宮原町', '19', '19201', '4000058', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '宮原町', 'ミヤバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市荒川', '19', '19201', '4000061', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '荒川', 'アラカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市池田', '19', '19201', '4000062', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '池田', 'イケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市金竹町', '19', '19201', '4000063', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '金竹町', 'カネタケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市下飯田', '19', '19201', '4000064', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '下飯田', 'シモイイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市貢川', '19', '19201', '4000065', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '貢川', 'クガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市新田町', '19', '19201', '4000066', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '新田町', 'シンデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市長松寺町', '19', '19201', '4000067', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '長松寺町', 'チョウショウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市下河原町', '19', '19201', '4000068', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '下河原町', 'シモガワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市中村町', '19', '19201', '4000069', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '中村町', 'ナカムラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市羽黒町', '19', '19201', '4000071', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '羽黒町', 'ハグロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市大和町', '19', '19201', '4000072', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '大和町', 'ダイワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市湯村', '19', '19201', '4000073', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '湯村', 'ユムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市千塚', '19', '19201', '4000074', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '千塚', 'チヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市山宮町', '19', '19201', '4000075', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '山宮町', 'ヤマミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市上帯那町', '19', '19201', '4000081', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '上帯那町', 'カミオビナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市下帯那町', '19', '19201', '4000082', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '下帯那町', 'シモオビナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市平瀬町', '19', '19201', '4000083', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '平瀬町', 'ヒラセマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市厚別区厚別東1条', '01', '01108', '0040001', '北海道', 'ホッカイドウ', '札幌市厚別区', 'サッポロシアツベツク', '厚別東1条', 'アツベツヒガシ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲斐市', '19', '19210', '4000100', '山梨県', 'ヤマナシケン', '甲斐市', 'カイシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('35723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲斐市菖蒲沢', '19', '19210', '4000101', '山梨県', 'ヤマナシケン', '甲斐市', 'カイシ', '菖蒲沢', 'ショウブザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲斐市団子新居', '19', '19210', '4000102', '山梨県', 'ヤマナシケン', '甲斐市', 'カイシ', '団子新居', 'ダンゴアライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲斐市大垈', '19', '19210', '4000103', '山梨県', 'ヤマナシケン', '甲斐市', 'カイシ', '大垈', 'オオヌタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲斐市龍地', '19', '19210', '4000104', '山梨県', 'ヤマナシケン', '甲斐市', 'カイシ', '龍地', 'リュウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲斐市下今井', '19', '19210', '4000105', '山梨県', 'ヤマナシケン', '甲斐市', 'カイシ', '下今井', 'シモイマイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲斐市岩森', '19', '19210', '4000106', '山梨県', 'ヤマナシケン', '甲斐市', 'カイシ', '岩森', 'イワモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲斐市志田', '19', '19210', '4000107', '山梨県', 'ヤマナシケン', '甲斐市', 'カイシ', '志田', 'シダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲斐市宇津谷', '19', '19210', '4000108', '山梨県', 'ヤマナシケン', '甲斐市', 'カイシ', '宇津谷', 'ウツヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市本町', '01', '01202', '0400011', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲斐市竜王新町', '19', '19210', '4000111', '山梨県', 'ヤマナシケン', '甲斐市', 'カイシ', '竜王新町', 'リュウオウシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲斐市名取', '19', '19210', '4000112', '山梨県', 'ヤマナシケン', '甲斐市', 'カイシ', '名取', 'ナトリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲斐市富竹新田', '19', '19210', '4000113', '山梨県', 'ヤマナシケン', '甲斐市', 'カイシ', '富竹新田', 'トミタケシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲斐市万才', '19', '19210', '4000114', '山梨県', 'ヤマナシケン', '甲斐市', 'カイシ', '万才', 'マンザイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲斐市篠原', '19', '19210', '4000115', '山梨県', 'ヤマナシケン', '甲斐市', 'カイシ', '篠原', 'シノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲斐市玉川', '19', '19210', '4000116', '山梨県', 'ヤマナシケン', '甲斐市', 'カイシ', '玉川', 'タマガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲斐市西八幡', '19', '19210', '4000117', '山梨県', 'ヤマナシケン', '甲斐市', 'カイシ', '西八幡', 'ニシヤハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲斐市竜王', '19', '19210', '4000118', '山梨県', 'ヤマナシケン', '甲斐市', 'カイシ', '竜王', 'リュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市時任町', '01', '01202', '0400012', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '時任町', 'トキトウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲斐市牛句', '19', '19210', '4000121', '山梨県', 'ヤマナシケン', '甲斐市', 'カイシ', '牛句', 'ウシク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲斐市境', '19', '19210', '4000122', '山梨県', 'ヤマナシケン', '甲斐市', 'カイシ', '境', 'サカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲斐市島上条', '19', '19210', '4000123', '山梨県', 'ヤマナシケン', '甲斐市', 'カイシ', '島上条', 'シマカミジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲斐市中下条', '19', '19210', '4000124', '山梨県', 'ヤマナシケン', '甲斐市', 'カイシ', '中下条', 'ナカシモジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲斐市長塚', '19', '19210', '4000125', '山梨県', 'ヤマナシケン', '甲斐市', 'カイシ', '長塚', 'ナガヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲斐市大下条', '19', '19210', '4000126', '山梨県', 'ヤマナシケン', '甲斐市', 'カイシ', '大下条', 'オオシモジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲斐市天狗沢', '19', '19210', '4000127', '山梨県', 'ヤマナシケン', '甲斐市', 'カイシ', '天狗沢', 'テングサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲斐市大久保', '19', '19210', '4000128', '山梨県', 'ヤマナシケン', '甲斐市', 'カイシ', '大久保', 'オオクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市千代台町', '01', '01202', '0400013', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '千代台町', 'チヨガダイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市中島町', '01', '01202', '0400014', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '中島町', 'ナカジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市梁川町', '01', '01202', '0400015', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '梁川町', 'ヤナガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市厚別区厚別東2条', '01', '01108', '0040002', '北海道', 'ホッカイドウ', '札幌市厚別区', 'サッポロシアツベツク', '厚別東2条', 'アツベツヒガシ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南アルプス市上高砂', '19', '19208', '4000201', '山梨県', 'ヤマナシケン', '南アルプス市', 'ミナミアルプスシ', '上高砂', 'カミタカスナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南アルプス市下高砂', '19', '19208', '4000202', '山梨県', 'ヤマナシケン', '南アルプス市', 'ミナミアルプスシ', '下高砂', 'シモタカスナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南アルプス市徳永', '19', '19208', '4000203', '山梨県', 'ヤマナシケン', '南アルプス市', 'ミナミアルプスシ', '徳永', 'トクナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南アルプス市榎原', '19', '19208', '4000204', '山梨県', 'ヤマナシケン', '南アルプス市', 'ミナミアルプスシ', '榎原', 'エノキハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南アルプス市野牛島', '19', '19208', '4000205', '山梨県', 'ヤマナシケン', '南アルプス市', 'ミナミアルプスシ', '野牛島', 'ヤゴシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南アルプス市六科', '19', '19208', '4000206', '山梨県', 'ヤマナシケン', '南アルプス市', 'ミナミアルプスシ', '六科', 'ムジナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市的場町', '01', '01202', '0400021', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '的場町', 'マトバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南アルプス市上今諏訪', '19', '19208', '4000211', '山梨県', 'ヤマナシケン', '南アルプス市', 'ミナミアルプスシ', '上今諏訪', 'カミイマスワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南アルプス市下今諏訪', '19', '19208', '4000212', '山梨県', 'ヤマナシケン', '南アルプス市', 'ミナミアルプスシ', '下今諏訪', 'シモイマスワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南アルプス市西野', '19', '19208', '4000213', '山梨県', 'ヤマナシケン', '南アルプス市', 'ミナミアルプスシ', '西野', 'ニシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南アルプス市百々', '19', '19208', '4000214', '山梨県', 'ヤマナシケン', '南アルプス市', 'ミナミアルプスシ', '百々', 'ドウドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南アルプス市上八田', '19', '19208', '4000215', '山梨県', 'ヤマナシケン', '南アルプス市', 'ミナミアルプスシ', '上八田', 'ウエハッタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市日乃出町', '01', '01202', '0400022', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '日乃出町', 'ヒノデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南アルプス市在家塚', '19', '19208', '4000221', '山梨県', 'ヤマナシケン', '南アルプス市', 'ミナミアルプスシ', '在家塚', 'ザイケツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南アルプス市飯野', '19', '19208', '4000222', '山梨県', 'ヤマナシケン', '南アルプス市', 'ミナミアルプスシ', '飯野', 'イイノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南アルプス市曲輪田新田', '19', '19208', '4000223', '山梨県', 'ヤマナシケン', '南アルプス市', 'ミナミアルプスシ', '曲輪田新田', 'クルワダシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南アルプス市飯野新田', '19', '19208', '4000224', '山梨県', 'ヤマナシケン', '南アルプス市', 'ミナミアルプスシ', '飯野新田', 'イイノシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南アルプス市築山', '19', '19208', '4000225', '山梨県', 'ヤマナシケン', '南アルプス市', 'ミナミアルプスシ', '築山', 'ツクヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南アルプス市有野', '19', '19208', '4000226', '山梨県', 'ヤマナシケン', '南アルプス市', 'ミナミアルプスシ', '有野', 'アリノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市宇賀浦町', '01', '01202', '0400023', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '宇賀浦町', 'ウガウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南アルプス市塩前', '19', '19208', '4000231', '山梨県', 'ヤマナシケン', '南アルプス市', 'ミナミアルプスシ', '塩前', 'シオノマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南アルプス市駒場', '19', '19208', '4000232', '山梨県', 'ヤマナシケン', '南アルプス市', 'ミナミアルプスシ', '駒場', 'コマバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南アルプス市須沢', '19', '19208', '4000233', '山梨県', 'ヤマナシケン', '南アルプス市', 'ミナミアルプスシ', '須沢', 'スサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南アルプス市大嵐', '19', '19208', '4000234', '山梨県', 'ヤマナシケン', '南アルプス市', 'ミナミアルプスシ', '大嵐', 'オオアラシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市高盛町', '01', '01202', '0400024', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '高盛町', 'タカモリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南アルプス市芦安芦倉', '19', '19208', '4000241', '山梨県', 'ヤマナシケン', '南アルプス市', 'ミナミアルプスシ', '芦安芦倉', 'アシヤスアシクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南アルプス市芦安安通', '19', '19208', '4000242', '山梨県', 'ヤマナシケン', '南アルプス市', 'ミナミアルプスシ', '芦安安通', 'アシヤスアンツウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市堀川町', '01', '01202', '0400025', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '堀川町', 'ホリカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市厚別区厚別東3条', '01', '01108', '0040003', '北海道', 'ホッカイドウ', '札幌市厚別区', 'サッポロシアツベツク', '厚別東3条', 'アツベツヒガシ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南アルプス市桃園', '19', '19208', '4000301', '山梨県', 'ヤマナシケン', '南アルプス市', 'ミナミアルプスシ', '桃園', 'モモソノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南アルプス市沢登', '19', '19208', '4000302', '山梨県', 'ヤマナシケン', '南アルプス市', 'ミナミアルプスシ', '沢登', 'サワノボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南アルプス市上今井', '19', '19208', '4000303', '山梨県', 'ヤマナシケン', '南アルプス市', 'ミナミアルプスシ', '上今井', 'カミイマイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南アルプス市吉田', '19', '19208', '4000304', '山梨県', 'ヤマナシケン', '南アルプス市', 'ミナミアルプスシ', '吉田', 'ヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南アルプス市十五所', '19', '19208', '4000305', '山梨県', 'ヤマナシケン', '南アルプス市', 'ミナミアルプスシ', '十五所', 'ジュウゴショ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南アルプス市小笠原', '19', '19208', '4000306', '山梨県', 'ヤマナシケン', '南アルプス市', 'ミナミアルプスシ', '小笠原', 'オガサハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南アルプス市山寺', '19', '19208', '4000308', '山梨県', 'ヤマナシケン', '南アルプス市', 'ミナミアルプスシ', '山寺', 'ヤマデラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市上新川町', '01', '01202', '0400031', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '上新川町', 'カミシンカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南アルプス市曲輪田', '19', '19208', '4000311', '山梨県', 'ヤマナシケン', '南アルプス市', 'ミナミアルプスシ', '曲輪田', 'クルワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南アルプス市上宮地', '19', '19208', '4000312', '山梨県', 'ヤマナシケン', '南アルプス市', 'ミナミアルプスシ', '上宮地', 'カミミヤジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南アルプス市平岡', '19', '19208', '4000313', '山梨県', 'ヤマナシケン', '南アルプス市', 'ミナミアルプスシ', '平岡', 'ヒラオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南アルプス市下市之瀬', '19', '19208', '4000314', '山梨県', 'ヤマナシケン', '南アルプス市', 'ミナミアルプスシ', '下市之瀬', 'シモイチノセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南アルプス市上野', '19', '19208', '4000315', '山梨県', 'ヤマナシケン', '南アルプス市', 'ミナミアルプスシ', '上野', 'ウエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南アルプス市中野', '19', '19208', '4000316', '山梨県', 'ヤマナシケン', '南アルプス市', 'ミナミアルプスシ', '中野', 'ナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南アルプス市上市之瀬', '19', '19208', '4000317', '山梨県', 'ヤマナシケン', '南アルプス市', 'ミナミアルプスシ', '上市之瀬', 'カミイチノセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南アルプス市高尾', '19', '19208', '4000318', '山梨県', 'ヤマナシケン', '南アルプス市', 'ミナミアルプスシ', '高尾', 'タカオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南アルプス市あやめが丘', '19', '19208', '4000319', '山梨県', 'ヤマナシケン', '南アルプス市', 'ミナミアルプスシ', 'あやめが丘', 'アヤメガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市新川町', '01', '01202', '0400032', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '新川町', 'シンカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市千歳町', '01', '01202', '0400033', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '千歳町', 'チトセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南アルプス市下今井', '19', '19208', '4000331', '山梨県', 'ヤマナシケン', '南アルプス市', 'ミナミアルプスシ', '下今井', 'シモイマイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南アルプス市鏡中條', '19', '19208', '4000332', '山梨県', 'ヤマナシケン', '南アルプス市', 'ミナミアルプスシ', '鏡中條', 'カガミナカジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南アルプス市浅原', '19', '19208', '4000333', '山梨県', 'ヤマナシケン', '南アルプス市', 'ミナミアルプスシ', '浅原', 'アサバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南アルプス市藤田', '19', '19208', '4000334', '山梨県', 'ヤマナシケン', '南アルプス市', 'ミナミアルプスシ', '藤田', 'トウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南アルプス市加賀美', '19', '19208', '4000335', '山梨県', 'ヤマナシケン', '南アルプス市', 'ミナミアルプスシ', '加賀美', 'カガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南アルプス市十日市場', '19', '19208', '4000336', '山梨県', 'ヤマナシケン', '南アルプス市', 'ミナミアルプスシ', '十日市場', 'トウカイチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南アルプス市寺部', '19', '19208', '4000337', '山梨県', 'ヤマナシケン', '南アルプス市', 'ミナミアルプスシ', '寺部', 'テラベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市大森町', '01', '01202', '0400034', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '大森町', 'オオモリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市松風町', '01', '01202', '0400035', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '松風町', 'マツカゼチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市東雲町', '01', '01202', '0400036', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '東雲町', 'シノノメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市旭町', '01', '01202', '0400037', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '旭町', 'アサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市厚別区厚別東4条', '01', '01108', '0040004', '北海道', 'ホッカイドウ', '札幌市厚別区', 'サッポロシアツベツク', '厚別東4条', 'アツベツヒガシ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南アルプス市', '19', '19208', '4000400', '山梨県', 'ヤマナシケン', '南アルプス市', 'ミナミアルプスシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('35826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南アルプス市江原', '19', '19208', '4000401', '山梨県', 'ヤマナシケン', '南アルプス市', 'ミナミアルプスシ', '江原', 'エバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南アルプス市田島', '19', '19208', '4000402', '山梨県', 'ヤマナシケン', '南アルプス市', 'ミナミアルプスシ', '田島', 'タジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南アルプス市鮎沢', '19', '19208', '4000403', '山梨県', 'ヤマナシケン', '南アルプス市', 'ミナミアルプスシ', '鮎沢', 'アユザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南アルプス市古市場', '19', '19208', '4000404', '山梨県', 'ヤマナシケン', '南アルプス市', 'ミナミアルプスシ', '古市場', 'フルイチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南アルプス市下宮地', '19', '19208', '4000405', '山梨県', 'ヤマナシケン', '南アルプス市', 'ミナミアルプスシ', '下宮地', 'シモミヤジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市栄町', '01', '01202', '0400041', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '栄町', 'サカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南アルプス市西南湖', '19', '19208', '4000411', '山梨県', 'ヤマナシケン', '南アルプス市', 'ミナミアルプスシ', '西南湖', 'ニシナンゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南アルプス市東南湖', '19', '19208', '4000412', '山梨県', 'ヤマナシケン', '南アルプス市', 'ミナミアルプスシ', '東南湖', 'ヒガシナンゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南アルプス市和泉', '19', '19208', '4000413', '山梨県', 'ヤマナシケン', '南アルプス市', 'ミナミアルプスシ', '和泉', 'イズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南アルプス市戸田', '19', '19208', '4000414', '山梨県', 'ヤマナシケン', '南アルプス市', 'ミナミアルプスシ', '戸田', 'トダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南アルプス市宮沢', '19', '19208', '4000415', '山梨県', 'ヤマナシケン', '南アルプス市', 'ミナミアルプスシ', '宮沢', 'ミヤザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南アルプス市大師', '19', '19208', '4000416', '山梨県', 'ヤマナシケン', '南アルプス市', 'ミナミアルプスシ', '大師', 'ダイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南アルプス市清水', '19', '19208', '4000417', '山梨県', 'ヤマナシケン', '南アルプス市', 'ミナミアルプスシ', '清水', 'シミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市東川町', '01', '01202', '0400042', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '東川町', 'ヒガシカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南アルプス市川上', '19', '19208', '4000421', '山梨県', 'ヤマナシケン', '南アルプス市', 'ミナミアルプスシ', '川上', 'カワカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南アルプス市荊沢', '19', '19208', '4000422', '山梨県', 'ヤマナシケン', '南アルプス市', 'ミナミアルプスシ', '荊沢', 'バラザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南アルプス市落合', '19', '19208', '4000423', '山梨県', 'ヤマナシケン', '南アルプス市', 'ミナミアルプスシ', '落合', 'オチアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南アルプス市秋山', '19', '19208', '4000424', '山梨県', 'ヤマナシケン', '南アルプス市', 'ミナミアルプスシ', '秋山', 'アキヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南アルプス市湯沢', '19', '19208', '4000425', '山梨県', 'ヤマナシケン', '南アルプス市', 'ミナミアルプスシ', '湯沢', 'ユザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南アルプス市塚原', '19', '19208', '4000426', '山梨県', 'ヤマナシケン', '南アルプス市', 'ミナミアルプスシ', '塚原', 'ツカハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市宝来町', '01', '01202', '0400043', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '宝来町', 'ホウライチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市青柳町', '01', '01202', '0400044', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '青柳町', 'アオヤギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市住吉町', '01', '01202', '0400045', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '住吉町', 'スミヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市谷地頭町', '01', '01202', '0400046', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '谷地頭町', 'ヤチガシラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市厚別区厚別東5条', '01', '01108', '0040005', '北海道', 'ホッカイドウ', '札幌市厚別区', 'サッポロシアツベツク', '厚別東5条', 'アツベツヒガシ05ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡増穂町', '19', '19361', '4000500', '山梨県', 'ヤマナシケン', '南巨摩郡増穂町', 'ミナミコマグンマスホチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('35856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡増穂町青柳町', '19', '19361', '4000501', '山梨県', 'ヤマナシケン', '南巨摩郡増穂町', 'ミナミコマグンマスホチョウ', '青柳町', 'アオヤギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡増穂町最勝寺', '19', '19361', '4000502', '山梨県', 'ヤマナシケン', '南巨摩郡増穂町', 'ミナミコマグンマスホチョウ', '最勝寺', 'サイショウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡増穂町天神中條', '19', '19361', '4000503', '山梨県', 'ヤマナシケン', '南巨摩郡増穂町', 'ミナミコマグンマスホチョウ', '天神中條', 'テンジンナカジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡増穂町小林', '19', '19361', '4000504', '山梨県', 'ヤマナシケン', '南巨摩郡増穂町', 'ミナミコマグンマスホチョウ', '小林', 'コバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡増穂町長澤', '19', '19361', '4000505', '山梨県', 'ヤマナシケン', '南巨摩郡増穂町', 'ミナミコマグンマスホチョウ', '長澤', 'ナガサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡増穂町大椚', '19', '19361', '4000506', '山梨県', 'ヤマナシケン', '南巨摩郡増穂町', 'ミナミコマグンマスホチョウ', '大椚', 'オオクヌギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市弁天町', '01', '01202', '0400051', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '弁天町', 'ベンテンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡増穂町大久保', '19', '19361', '4000511', '山梨県', 'ヤマナシケン', '南巨摩郡増穂町', 'ミナミコマグンマスホチョウ', '大久保', 'オオクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡増穂町小室', '19', '19361', '4000512', '山梨県', 'ヤマナシケン', '南巨摩郡増穂町', 'ミナミコマグンマスホチョウ', '小室', 'コムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡増穂町高下', '19', '19361', '4000513', '山梨県', 'ヤマナシケン', '南巨摩郡増穂町', 'ミナミコマグンマスホチョウ', '高下', 'タカオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡増穂町平林', '19', '19361', '4000514', '山梨県', 'ヤマナシケン', '南巨摩郡増穂町', 'ミナミコマグンマスホチョウ', '平林', 'ヒラバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡増穂町舂米', '19', '19361', '4000515', '山梨県', 'ヤマナシケン', '南巨摩郡増穂町', 'ミナミコマグンマスホチョウ', '舂米', 'ツキヨネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市大町', '01', '01202', '0400052', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '大町', 'オオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市末広町', '01', '01202', '0400053', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '末広町', 'スエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市元町', '01', '01202', '0400054', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '元町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市船見町', '01', '01202', '0400055', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '船見町', 'フナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市弥生町', '01', '01202', '0400056', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '弥生町', 'ヤヨイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市入舟町', '01', '01202', '0400057', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '入舟町', 'イリフネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市厚別区厚別町小野幌', '01', '01108', '0040006', '北海道', 'ホッカイドウ', '札幌市厚別区', 'サッポロシアツベツク', '厚別町小野幌', 'アツベツチョウコノッポロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡鰍沢町', '19', '19362', '4000600', '山梨県', 'ヤマナシケン', '南巨摩郡鰍沢町', 'ミナミコマグンカジカザワチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('35879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡鰍沢町', '19', '19362', '4000601', '山梨県', 'ヤマナシケン', '南巨摩郡鰍沢町', 'ミナミコマグンカジカザワチョウ', null, '　', '（直番地）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('35880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡鰍沢町駅前通', '19', '19362', '4000602', '山梨県', 'ヤマナシケン', '南巨摩郡鰍沢町', 'ミナミコマグンカジカザワチョウ', '駅前通', 'エキマエドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡鰍沢町鹿島', '19', '19362', '4000603', '山梨県', 'ヤマナシケン', '南巨摩郡鰍沢町', 'ミナミコマグンカジカザワチョウ', '鹿島', 'カシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡鰍沢町箱原', '19', '19362', '4000604', '山梨県', 'ヤマナシケン', '南巨摩郡鰍沢町', 'ミナミコマグンカジカザワチョウ', '箱原', 'ハコバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡鰍沢町柳川', '19', '19362', '4000605', '山梨県', 'ヤマナシケン', '南巨摩郡鰍沢町', 'ミナミコマグンカジカザワチョウ', '柳川', 'ヤナガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡鰍沢町十谷', '19', '19362', '4000606', '山梨県', 'ヤマナシケン', '南巨摩郡鰍沢町', 'ミナミコマグンカジカザワチョウ', '十谷', 'ジュッコク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡鰍沢町鳥屋', '19', '19362', '4000607', '山梨県', 'ヤマナシケン', '南巨摩郡鰍沢町', 'ミナミコマグンカジカザワチョウ', '鳥屋', 'トヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡鰍沢町長知沢', '19', '19362', '4000608', '山梨県', 'ヤマナシケン', '南巨摩郡鰍沢町', 'ミナミコマグンカジカザワチョウ', '長知沢', 'チョウチザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市海岸町', '01', '01202', '0400061', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '海岸町', 'カイガンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市大縄町', '01', '01202', '0400062', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '大縄町', 'オオナワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市若松町', '01', '01202', '0400063', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '若松町', 'ワカマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市大手町', '01', '01202', '0400064', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '大手町', 'オオテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市豊川町', '01', '01202', '0400065', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '豊川町', 'トヨカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市厚別区厚別町下野幌', '01', '01108', '0040007', '北海道', 'ホッカイドウ', '札幌市厚別区', 'サッポロシアツベツク', '厚別町下野幌', 'アツベツチョウシモノッポロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市追分町', '01', '01202', '0400071', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '追分町', 'オイワケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市亀田町', '01', '01202', '0400072', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '亀田町', 'カメダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市宮前町', '01', '01202', '0400073', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '宮前町', 'ミヤマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市松川町', '01', '01202', '0400074', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '松川町', 'マツカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市万代町', '01', '01202', '0400075', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '万代町', 'バンダイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市浅野町', '01', '01202', '0400076', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '浅野町', 'アサノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市吉川町', '01', '01202', '0400077', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '吉川町', 'ヨシカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市北浜町', '01', '01202', '0400078', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '北浜町', 'キタハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市善光寺町', '19', '19201', '4000801', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '善光寺町', 'ゼンコウジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市横根町', '19', '19201', '4000802', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '横根町', 'ヨコネマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市桜井町', '19', '19201', '4000803', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '桜井町', 'サクライチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市酒折町', '19', '19201', '4000804', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '酒折町', 'サカオリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市酒折', '19', '19201', '4000805', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '酒折', 'サカオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市善光寺', '19', '19201', '4000806', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '善光寺', 'ゼンコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市東光寺', '19', '19201', '4000807', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '東光寺', 'トウコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市東光寺町', '19', '19201', '4000808', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '東光寺町', 'トウコウジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市田家町', '01', '01202', '0400081', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '田家町', 'タヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市川田町', '19', '19201', '4000811', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '川田町', 'カワダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市和戸町', '19', '19201', '4000812', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '和戸町', 'ワドマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市向町', '19', '19201', '4000813', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '向町', 'ムコウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市上阿原町', '19', '19201', '4000814', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '上阿原町', 'カミアハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市国玉町', '19', '19201', '4000815', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '国玉町', 'クダマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市白鳥町', '01', '01202', '0400082', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '白鳥町', 'シラトリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市砂田町', '19', '19201', '4000821', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '砂田町', 'スナダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市里吉', '19', '19201', '4000822', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '里吉', 'サトヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市里吉町', '19', '19201', '4000823', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '里吉町', 'サトヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市蓬沢町', '19', '19201', '4000824', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '蓬沢町', 'ヨモギサワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市七沢町', '19', '19201', '4000825', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '七沢町', 'ナナサワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市西高橋町', '19', '19201', '4000826', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '西高橋町', 'ニシタカハシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市蓬沢', '19', '19201', '4000827', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '蓬沢', 'ヨモギサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市青葉町', '19', '19201', '4000828', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '青葉町', 'アオバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市八幡町', '01', '01202', '0400083', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '八幡町', 'ハチマンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市上町', '19', '19201', '4000831', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '上町', 'カミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市増坪町', '19', '19201', '4000832', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '増坪町', 'マスツボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市西油川町', '19', '19201', '4000833', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '西油川町', 'ニシアブラカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市落合町', '19', '19201', '4000834', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '落合町', 'オチアイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市下鍛冶屋町', '19', '19201', '4000835', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '下鍛冶屋町', 'シモカジヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市小瀬町', '19', '19201', '4000836', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '小瀬町', 'コセマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市大川町', '01', '01202', '0400084', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '大川町', 'オオカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市小曲町', '19', '19201', '4000841', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '小曲町', 'オマガリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市下今井町', '19', '19201', '4000842', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '下今井町', 'シモイマイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市東下条町', '19', '19201', '4000843', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '東下条町', 'ヒガシシモジョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市中町', '19', '19201', '4000844', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '中町', 'ナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市上今井町', '19', '19201', '4000845', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '上今井町', 'カミイマイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市住吉', '19', '19201', '4000851', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '住吉', 'スミヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市住吉本町', '19', '19201', '4000852', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '住吉本町', 'スミヨシホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市下小河原町', '19', '19201', '4000853', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '下小河原町', 'シモコガワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市中小河原町', '19', '19201', '4000854', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '中小河原町', 'ナカコガワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市中小河原', '19', '19201', '4000855', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '中小河原', 'ナカコガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市伊勢', '19', '19201', '4000856', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '伊勢', 'イセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市幸町', '19', '19201', '4000857', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市相生', '19', '19201', '4000858', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '相生', 'アイオイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市城東', '19', '19201', '4000861', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '城東', 'ジョウトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市朝気', '19', '19201', '4000862', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '朝気', 'アサケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市南口町', '19', '19201', '4000863', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '南口町', 'ミナミグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市湯田', '19', '19201', '4000864', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '湯田', 'ユダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市太田町', '19', '19201', '4000865', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '太田町', 'オオタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市若松町', '19', '19201', '4000866', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '若松町', 'ワカマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市青沼', '19', '19201', '4000867', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '青沼', 'アオヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市厚別区もみじ台東', '01', '01108', '0040011', '北海道', 'ホッカイドウ', '札幌市厚別区', 'サッポロシアツベツク', 'もみじ台東', 'モミジダイヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲斐市千田', '19', '19210', '4001111', '山梨県', 'ヤマナシケン', '甲斐市', 'カイシ', '千田', 'センダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲斐市吉沢', '19', '19210', '4001112', '山梨県', 'ヤマナシケン', '甲斐市', 'カイシ', '吉沢', 'キッサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲斐市亀沢', '19', '19210', '4001113', '山梨県', 'ヤマナシケン', '甲斐市', 'カイシ', '亀沢', 'カメザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲斐市打返', '19', '19210', '4001114', '山梨県', 'ヤマナシケン', '甲斐市', 'カイシ', '打返', 'ウチガエシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲斐市漆戸', '19', '19210', '4001115', '山梨県', 'ヤマナシケン', '甲斐市', 'カイシ', '漆戸', 'ウルシド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲斐市獅子平', '19', '19210', '4001116', '山梨県', 'ヤマナシケン', '甲斐市', 'カイシ', '獅子平', 'シシダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲斐市上菅口', '19', '19210', '4001117', '山梨県', 'ヤマナシケン', '甲斐市', 'カイシ', '上菅口', 'カミスゲクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲斐市上芦沢', '19', '19210', '4001121', '山梨県', 'ヤマナシケン', '甲斐市', 'カイシ', '上芦沢', 'カミアシザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲斐市下芦沢', '19', '19210', '4001122', '山梨県', 'ヤマナシケン', '甲斐市', 'カイシ', '下芦沢', 'シモアシザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲斐市上福沢', '19', '19210', '4001123', '山梨県', 'ヤマナシケン', '甲斐市', 'カイシ', '上福沢', 'カミフクザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲斐市下福沢', '19', '19210', '4001124', '山梨県', 'ヤマナシケン', '甲斐市', 'カイシ', '下福沢', 'シモフクザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲斐市下菅口', '19', '19210', '4001125', '山梨県', 'ヤマナシケン', '甲斐市', 'カイシ', '下菅口', 'シモスゲグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲斐市安寺', '19', '19210', '4001126', '山梨県', 'ヤマナシケン', '甲斐市', 'カイシ', '安寺', 'アテラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲斐市神戸', '19', '19210', '4001127', '山梨県', 'ヤマナシケン', '甲斐市', 'カイシ', '神戸', 'ゴウド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲斐市亀沢', '19', '19210', '4001131', '山梨県', 'ヤマナシケン', '甲斐市', 'カイシ', '亀沢', 'カメザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲斐市亀沢大明神', '19', '19210', '4001131', '山梨県', 'ヤマナシケン', '甲斐市', 'カイシ', '亀沢', 'カメザワ', null, null, '大明神', 'ダイミョウジン');
INSERT INTO `ms_addresses` VALUES ('35972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市厚別区もみじ台南', '01', '01108', '0040012', '北海道', 'ホッカイドウ', '札幌市厚別区', 'サッポロシアツベツク', 'もみじ台南', 'モミジダイミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市黒平町', '19', '19201', '4001211', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '黒平町', 'クロベラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市高町', '19', '19201', '4001212', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '高町', 'タカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市川窪町', '19', '19201', '4001213', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '川窪町', 'カワクボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市高成町', '19', '19201', '4001214', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '高成町', 'タカナリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市竹日向町', '19', '19201', '4001215', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '竹日向町', 'タケヒナタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市塔岩町', '19', '19201', '4001216', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '塔岩町', 'トウイワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市猪狩町', '19', '19201', '4001217', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '猪狩町', 'イカリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市御岳町', '19', '19201', '4001218', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '御岳町', 'ミタケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市草鹿沢町', '19', '19201', '4001219', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '草鹿沢町', 'ソウカザワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市厚別区もみじ台西', '01', '01108', '0040013', '北海道', 'ホッカイドウ', '札幌市厚別区', 'サッポロシアツベツク', 'もみじ台西', 'モミジダイニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市厚別区もみじ台北', '01', '01108', '0040014', '北海道', 'ホッカイドウ', '札幌市厚別区', 'サッポロシアツベツク', 'もみじ台北', 'モミジダイキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市厚別区下野幌テクノパーク', '01', '01108', '0040015', '北海道', 'ホッカイドウ', '札幌市厚別区', 'サッポロシアツベツク', '下野幌テクノパーク', 'シモノッポロテクノパーク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市上曽根町', '19', '19201', '4001501', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '上曽根町', 'カミソネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市白井町', '19', '19201', '4001502', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '白井町', 'シライチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市心経寺町', '19', '19201', '4001503', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '心経寺町', 'シンギョウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市右左口町', '19', '19201', '4001504', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '右左口町', 'ウバグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市中畑町', '19', '19201', '4001505', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '中畑町', 'ナカバタケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市上向山町', '19', '19201', '4001506', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '上向山町', 'カミムコウヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市下向山町', '19', '19201', '4001507', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '下向山町', 'シモムコウヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市下曽根町', '19', '19201', '4001508', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '下曽根町', 'シモソネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県中央市木原', '19', '19214', '4001511', '山梨県', 'ヤマナシケン', '中央市', 'チュウオウシ', '木原', 'キハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県中央市関原', '19', '19214', '4001512', '山梨県', 'ヤマナシケン', '中央市', 'チュウオウシ', '関原', 'セキハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県中央市大鳥居', '19', '19214', '4001513', '山梨県', 'ヤマナシケン', '中央市', 'チュウオウシ', '大鳥居', 'オオトリイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県中央市浅利', '19', '19214', '4001514', '山梨県', 'ヤマナシケン', '中央市', 'チュウオウシ', '浅利', 'アサリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('35997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県中央市高部', '19', '19214', '4001515', '山梨県', 'ヤマナシケン', '中央市', 'チュウオウシ', '高部', 'タカベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市厚別区青葉町', '01', '01108', '0040021', '北海道', 'ホッカイドウ', '札幌市厚別区', 'サッポロシアツベツク', '青葉町', 'アオバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市厚別区厚別南', '01', '01108', '0040022', '北海道', 'ホッカイドウ', '札幌市厚別区', 'サッポロシアツベツク', '厚別南', 'アツベツミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市厚別区上野幌1条', '01', '01108', '0040031', '北海道', 'ホッカイドウ', '札幌市厚別区', 'サッポロシアツベツク', '上野幌1条', 'カミノッポロ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市厚別区上野幌2条', '01', '01108', '0040032', '北海道', 'ホッカイドウ', '札幌市厚別区', 'サッポロシアツベツク', '上野幌2条', 'カミノッポロ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市厚別区上野幌3条', '01', '01108', '0040033', '北海道', 'ホッカイドウ', '札幌市厚別区', 'サッポロシアツベツク', '上野幌3条', 'カミノッポロ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市厚別区厚別町上野幌', '01', '01108', '0040039', '北海道', 'ホッカイドウ', '札幌市厚別区', 'サッポロシアツベツク', '厚別町上野幌', 'アツベツチョウカミノッポロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市厚別区大谷地東', '01', '01108', '0040041', '北海道', 'ホッカイドウ', '札幌市厚別区', 'サッポロシアツベツク', '大谷地東', 'オオヤチヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市厚別区大谷地西', '01', '01108', '0040042', '北海道', 'ホッカイドウ', '札幌市厚別区', 'サッポロシアツベツク', '大谷地西', 'オオヤチニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市厚別区厚別中央1条', '01', '01108', '0040051', '北海道', 'ホッカイドウ', '札幌市厚別区', 'サッポロシアツベツク', '厚別中央1条', 'アツベツチュウオウ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市厚別区厚別中央2条', '01', '01108', '0040052', '北海道', 'ホッカイドウ', '札幌市厚別区', 'サッポロシアツベツク', '厚別中央2条', 'アツベツチュウオウ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市厚別区厚別中央3条', '01', '01108', '0040053', '北海道', 'ホッカイドウ', '札幌市厚別区', 'サッポロシアツベツク', '厚別中央3条', 'アツベツチュウオウ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市厚別区厚別中央4条', '01', '01108', '0040054', '北海道', 'ホッカイドウ', '札幌市厚別区', 'サッポロシアツベツク', '厚別中央4条', 'アツベツチュウオウ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市厚別区厚別中央5条', '01', '01108', '0040055', '北海道', 'ホッカイドウ', '札幌市厚別区', 'サッポロシアツベツク', '厚別中央5条', 'アツベツチュウオウ05ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市厚別区厚別西1条', '01', '01108', '0040061', '北海道', 'ホッカイドウ', '札幌市厚別区', 'サッポロシアツベツク', '厚別西1条', 'アツベツニシ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市厚別区厚別西2条', '01', '01108', '0040062', '北海道', 'ホッカイドウ', '札幌市厚別区', 'サッポロシアツベツク', '厚別西2条', 'アツベツニシ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市厚別区厚別西3条', '01', '01108', '0040063', '北海道', 'ホッカイドウ', '札幌市厚別区', 'サッポロシアツベツク', '厚別西3条', 'アツベツニシ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市厚別区厚別西4条', '01', '01108', '0040064', '北海道', 'ホッカイドウ', '札幌市厚別区', 'サッポロシアツベツク', '厚別西4条', 'アツベツニシ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市厚別区厚別西5条', '01', '01108', '0040065', '北海道', 'ホッカイドウ', '札幌市厚別区', 'サッポロシアツベツク', '厚別西5条', 'アツベツニシ05ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市厚別区厚別西', '01', '01108', '0040068', '北海道', 'ホッカイドウ', '札幌市厚別区', 'サッポロシアツベツク', '厚別西', 'アツベツニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市厚別区厚別町山本', '01', '01108', '0040069', '北海道', 'ホッカイドウ', '札幌市厚別区', 'サッポロシアツベツク', '厚別町山本', 'アツベツチョウヤマモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市厚別区厚別北1条', '01', '01108', '0040071', '北海道', 'ホッカイドウ', '札幌市厚別区', 'サッポロシアツベツク', '厚別北1条', 'アツベツキタ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市厚別区厚別北2条', '01', '01108', '0040072', '北海道', 'ホッカイドウ', '札幌市厚別区', 'サッポロシアツベツク', '厚別北2条', 'アツベツキタ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市厚別区厚別北3条', '01', '01108', '0040073', '北海道', 'ホッカイドウ', '札幌市厚別区', 'サッポロシアツベツク', '厚別北3条', 'アツベツキタ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市厚別区厚別北4条', '01', '01108', '0040074', '北海道', 'ホッカイドウ', '札幌市厚別区', 'サッポロシアツベツク', '厚別北4条', 'アツベツキタ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市厚別区厚別北5条', '01', '01108', '0040075', '北海道', 'ホッカイドウ', '札幌市厚別区', 'サッポロシアツベツク', '厚別北5条', 'アツベツキタ05ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市厚別区厚別北6条', '01', '01108', '0040076', '北海道', 'ホッカイドウ', '札幌市厚別区', 'サッポロシアツベツク', '厚別北6条', 'アツベツキタ06ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県大月市', '19', '19206', '4010000', '山梨県', 'ヤマナシケン', '大月市', 'オオツキシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('36066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県大月市賑岡町畑倉', '19', '19206', '4010001', '山梨県', 'ヤマナシケン', '大月市', 'オオツキシ', '賑岡町畑倉', 'ニギオカマチハタグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県大月市賑岡町岩殿', '19', '19206', '4010002', '山梨県', 'ヤマナシケン', '大月市', 'オオツキシ', '賑岡町岩殿', 'ニギオカマチイワドノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県大月市賑岡町ゆりケ丘', '19', '19206', '4010003', '山梨県', 'ヤマナシケン', '大月市', 'オオツキシ', '賑岡町ゆりケ丘', 'ニギオカマチユリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県大月市賑岡町強瀬', '19', '19206', '4010004', '山梨県', 'ヤマナシケン', '大月市', 'オオツキシ', '賑岡町強瀬', 'ニギオカマチコワゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県大月市賑岡町浅利', '19', '19206', '4010005', '山梨県', 'ヤマナシケン', '大月市', 'オオツキシ', '賑岡町浅利', 'ニギオカマチアサリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県大月市賑岡町奥山', '19', '19206', '4010006', '山梨県', 'ヤマナシケン', '大月市', 'オオツキシ', '賑岡町奥山', 'ニギオカマチオクヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県大月市駒橋', '19', '19206', '4010011', '山梨県', 'ヤマナシケン', '大月市', 'オオツキシ', '駒橋', 'コマハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県大月市御太刀', '19', '19206', '4010012', '山梨県', 'ヤマナシケン', '大月市', 'オオツキシ', '御太刀', 'ミタチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県大月市大月1丁目', '19', '19206', '4010013', '山梨県', 'ヤマナシケン', '大月市', 'オオツキシ', '大月', 'オオツキ', null, null, '1丁目', '01チョウメ');
INSERT INTO `ms_addresses` VALUES ('36075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県大月市大月2丁目', '19', '19206', '4010013', '山梨県', 'ヤマナシケン', '大月市', 'オオツキシ', '大月', 'オオツキ', null, null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('36076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県大月市大月3丁目', '19', '19206', '4010013', '山梨県', 'ヤマナシケン', '大月市', 'オオツキシ', '大月', 'オオツキ', null, null, '3丁目', '03チョウメ');
INSERT INTO `ms_addresses` VALUES ('36077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県大月市大月町大月', '19', '19206', '4010014', '山梨県', 'ヤマナシケン', '大月市', 'オオツキシ', '大月町大月', 'オオツキマチオオツキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県大月市大月町花咲', '19', '19206', '4010015', '山梨県', 'ヤマナシケン', '大月市', 'オオツキシ', '大月町花咲', 'オオツキマチハナサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県大月市大月町真木', '19', '19206', '4010016', '山梨県', 'ヤマナシケン', '大月市', 'オオツキシ', '大月町真木', 'オオツキマチマギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県大月市初狩町下初狩', '19', '19206', '4010021', '山梨県', 'ヤマナシケン', '大月市', 'オオツキシ', '初狩町下初狩', 'ハツカリマチシモハツカリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県大月市初狩町中初狩', '19', '19206', '4010022', '山梨県', 'ヤマナシケン', '大月市', 'オオツキシ', '初狩町中初狩', 'ハツカリマチナカハツカリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県大月市笹子町白野', '19', '19206', '4010023', '山梨県', 'ヤマナシケン', '大月市', 'オオツキシ', '笹子町白野', 'ササゴマチシラノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県大月市笹子町吉久保', '19', '19206', '4010024', '山梨県', 'ヤマナシケン', '大月市', 'オオツキシ', '笹子町吉久保', 'ササゴマチヨシクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県大月市笹子町黒野田', '19', '19206', '4010025', '山梨県', 'ヤマナシケン', '大月市', 'オオツキシ', '笹子町黒野田', 'ササゴマチクロノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県上野原市秋山', '19', '19212', '4010201', '山梨県', 'ヤマナシケン', '上野原市', 'ウエノハラシ', '秋山', 'アキヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南都留郡富士河口湖町', '19', '19430', '4010300', '山梨県', 'ヤマナシケン', '南都留郡富士河口湖町', 'ミナミツルグンフジカワグチコマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('36088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南都留郡富士河口湖町船津', '19', '19430', '4010301', '山梨県', 'ヤマナシケン', '南都留郡富士河口湖町', 'ミナミツルグンフジカワグチコマチ', '船津', 'フナツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南都留郡富士河口湖町小立', '19', '19430', '4010302', '山梨県', 'ヤマナシケン', '南都留郡富士河口湖町', 'ミナミツルグンフジカワグチコマチ', '小立', 'コダチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南都留郡富士河口湖町浅川', '19', '19430', '4010303', '山梨県', 'ヤマナシケン', '南都留郡富士河口湖町', 'ミナミツルグンフジカワグチコマチ', '浅川', 'アザガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南都留郡富士河口湖町河口', '19', '19430', '4010304', '山梨県', 'ヤマナシケン', '南都留郡富士河口湖町', 'ミナミツルグンフジカワグチコマチ', '河口', 'カワグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南都留郡富士河口湖町大石', '19', '19430', '4010305', '山梨県', 'ヤマナシケン', '南都留郡富士河口湖町', 'ミナミツルグンフジカワグチコマチ', '大石', 'オオイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南都留郡富士河口湖町勝山', '19', '19430', '4010310', '山梨県', 'ヤマナシケン', '南都留郡富士河口湖町', 'ミナミツルグンフジカワグチコマチ', '勝山', 'カツヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南都留郡鳴沢村', '19', '19429', '4010320', '山梨県', 'ヤマナシケン', '南都留郡鳴沢村', 'ミナミツルグンナルサワムラ', null, '　', '（全域）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('36095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南都留郡富士河口湖町長浜', '19', '19430', '4010331', '山梨県', 'ヤマナシケン', '南都留郡富士河口湖町', 'ミナミツルグンフジカワグチコマチ', '長浜', 'ナガハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南都留郡富士河口湖町西湖', '19', '19430', '4010332', '山梨県', 'ヤマナシケン', '南都留郡富士河口湖町', 'ミナミツルグンフジカワグチコマチ', '西湖', 'サイコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南都留郡富士河口湖町西湖西', '19', '19430', '4010333', '山梨県', 'ヤマナシケン', '南都留郡富士河口湖町', 'ミナミツルグンフジカワグチコマチ', '西湖西', 'サイコニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南都留郡富士河口湖町西湖南', '19', '19430', '4010334', '山梨県', 'ヤマナシケン', '南都留郡富士河口湖町', 'ミナミツルグンフジカワグチコマチ', '西湖南', 'サイコミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南都留郡富士河口湖町大嵐', '19', '19430', '4010335', '山梨県', 'ヤマナシケン', '南都留郡富士河口湖町', 'ミナミツルグンフジカワグチコマチ', '大嵐', 'オオアラシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南都留郡富士河口湖町精進', '19', '19430', '4010336', '山梨県', 'ヤマナシケン', '南都留郡富士河口湖町', 'ミナミツルグンフジカワグチコマチ', '精進', 'ショウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南都留郡富士河口湖町本栖', '19', '19430', '4010337', '山梨県', 'ヤマナシケン', '南都留郡富士河口湖町', 'ミナミツルグンフジカワグチコマチ', '本栖', 'モトス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南都留郡富士河口湖町富士ケ嶺', '19', '19430', '4010338', '山梨県', 'ヤマナシケン', '南都留郡富士河口湖町', 'ミナミツルグンフジカワグチコマチ', '富士ケ嶺', 'フジガネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南都留郡忍野村', '19', '19424', '4010500', '山梨県', 'ヤマナシケン', '南都留郡忍野村', 'ミナミツルグンオシノムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('36109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南都留郡山中湖村', '19', '19425', '4010500', '山梨県', 'ヤマナシケン', '南都留郡山中湖村', 'ミナミツルグンヤマナカコムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('36110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南都留郡山中湖村山中', '19', '19425', '4010501', '山梨県', 'ヤマナシケン', '南都留郡山中湖村', 'ミナミツルグンヤマナカコムラ', '山中', 'ヤマナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南都留郡山中湖村平野', '19', '19425', '4010502', '山梨県', 'ヤマナシケン', '南都留郡山中湖村', 'ミナミツルグンヤマナカコムラ', '平野', 'ヒラノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南都留郡忍野村忍草', '19', '19424', '4010511', '山梨県', 'ヤマナシケン', '南都留郡忍野村', 'ミナミツルグンオシノムラ', '忍草', 'シボクサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南都留郡忍野村内野', '19', '19424', '4010512', '山梨県', 'ヤマナシケン', '南都留郡忍野村', 'ミナミツルグンオシノムラ', '内野', 'ウチノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県都留市', '19', '19204', '4020000', '山梨県', 'ヤマナシケン', '都留市', 'ツルシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('36120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県都留市田野倉', '19', '19204', '4020001', '山梨県', 'ヤマナシケン', '都留市', 'ツルシ', '田野倉', 'タノクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県都留市大原', '19', '19204', '4020002', '山梨県', 'ヤマナシケン', '都留市', 'ツルシ', '大原', 'オオハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県都留市川茂', '19', '19204', '4020003', '山梨県', 'ヤマナシケン', '都留市', 'ツルシ', '川茂', 'カワモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県都留市古川渡', '19', '19204', '4020004', '山梨県', 'ヤマナシケン', '都留市', 'ツルシ', '古川渡', 'フルカワド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県都留市四日市場', '19', '19204', '4020005', '山梨県', 'ヤマナシケン', '都留市', 'ツルシ', '四日市場', 'ヨッカイチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県都留市小形山', '19', '19204', '4020006', '山梨県', 'ヤマナシケン', '都留市', 'ツルシ', '小形山', 'オガタヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県都留市井倉', '19', '19204', '4020011', '山梨県', 'ヤマナシケン', '都留市', 'ツルシ', '井倉', 'イグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県都留市与縄', '19', '19204', '4020012', '山梨県', 'ヤマナシケン', '都留市', 'ツルシ', '与縄', 'ヨナワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県都留市盛里', '19', '19204', '4020013', '山梨県', 'ヤマナシケン', '都留市', 'ツルシ', '盛里', 'モリサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県都留市朝日馬場', '19', '19204', '4020014', '山梨県', 'ヤマナシケン', '都留市', 'ツルシ', '朝日馬場', 'アサヒババ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県都留市朝日曽雌', '19', '19204', '4020015', '山梨県', 'ヤマナシケン', '都留市', 'ツルシ', '朝日曽雌', 'アサヒソシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県都留市玉川', '19', '19204', '4020021', '山梨県', 'ヤマナシケン', '都留市', 'ツルシ', '玉川', 'タマガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県都留市戸沢', '19', '19204', '4020022', '山梨県', 'ヤマナシケン', '都留市', 'ツルシ', '戸沢', 'トザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県都留市大野', '19', '19204', '4020023', '山梨県', 'ヤマナシケン', '都留市', 'ツルシ', '大野', 'オオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県都留市小野', '19', '19204', '4020024', '山梨県', 'ヤマナシケン', '都留市', 'ツルシ', '小野', 'オノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県都留市法能', '19', '19204', '4020025', '山梨県', 'ヤマナシケン', '都留市', 'ツルシ', '法能', 'ホウノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県都留市十日市場', '19', '19204', '4020031', '山梨県', 'ヤマナシケン', '都留市', 'ツルシ', '十日市場', 'トオカイチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県都留市鹿留', '19', '19204', '4020032', '山梨県', 'ヤマナシケン', '都留市', 'ツルシ', '鹿留', 'シシドメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県都留市境', '19', '19204', '4020033', '山梨県', 'ヤマナシケン', '都留市', 'ツルシ', '境', 'サカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県都留市桂町', '19', '19204', '4020034', '山梨県', 'ヤマナシケン', '都留市', 'ツルシ', '桂町', 'カツラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県都留市夏狩', '19', '19204', '4020035', '山梨県', 'ヤマナシケン', '都留市', 'ツルシ', '夏狩', 'ナツガリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県都留市金井', '19', '19204', '4020041', '山梨県', 'ヤマナシケン', '都留市', 'ツルシ', '金井', 'カナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県都留市厚原', '19', '19204', '4020042', '山梨県', 'ヤマナシケン', '都留市', 'ツルシ', '厚原', 'アツハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県都留市平栗', '19', '19204', '4020043', '山梨県', 'ヤマナシケン', '都留市', 'ツルシ', '平栗', 'ヒラグリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県都留市加畑', '19', '19204', '4020044', '山梨県', 'ヤマナシケン', '都留市', 'ツルシ', '加畑', 'カハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県都留市大幡', '19', '19204', '4020045', '山梨県', 'ヤマナシケン', '都留市', 'ツルシ', '大幡', 'オオハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県都留市中津森', '19', '19204', '4020046', '山梨県', 'ヤマナシケン', '都留市', 'ツルシ', '中津森', 'ナカツモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県都留市下谷', '19', '19204', '4020051', '山梨県', 'ヤマナシケン', '都留市', 'ツルシ', '下谷', 'シモヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県都留市中央', '19', '19204', '4020052', '山梨県', 'ヤマナシケン', '都留市', 'ツルシ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県都留市上谷', '19', '19204', '4020053', '山梨県', 'ヤマナシケン', '都留市', 'ツルシ', '上谷', 'カミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県都留市田原', '19', '19204', '4020054', '山梨県', 'ヤマナシケン', '都留市', 'ツルシ', '田原', 'タハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県都留市川棚', '19', '19204', '4020055', '山梨県', 'ヤマナシケン', '都留市', 'ツルシ', '川棚', 'カワダナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県都留市つる', '19', '19204', '4020056', '山梨県', 'ヤマナシケン', '都留市', 'ツルシ', 'つる', 'ツル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南都留郡道志村', '19', '19422', '4020200', '山梨県', 'ヤマナシケン', '南都留郡道志村', 'ミナミツルグンドウシムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('36154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南都留郡道志村月夜野', '19', '19422', '4020201', '山梨県', 'ヤマナシケン', '南都留郡道志村', 'ミナミツルグンドウシムラ', '月夜野', 'ツキヨノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南都留郡道志村大野', '19', '19422', '4020202', '山梨県', 'ヤマナシケン', '南都留郡道志村', 'ミナミツルグンドウシムラ', '大野', 'オオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南都留郡道志村久保', '19', '19422', '4020203', '山梨県', 'ヤマナシケン', '南都留郡道志村', 'ミナミツルグンドウシムラ', '久保', 'クボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南都留郡道志村大室指', '19', '19422', '4020204', '山梨県', 'ヤマナシケン', '南都留郡道志村', 'ミナミツルグンドウシムラ', '大室指', 'オオムロザス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南都留郡道志村椿', '19', '19422', '4020205', '山梨県', 'ヤマナシケン', '南都留郡道志村', 'ミナミツルグンドウシムラ', '椿', 'ツバキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南都留郡道志村小善地', '19', '19422', '4020206', '山梨県', 'ヤマナシケン', '南都留郡道志村', 'ミナミツルグンドウシムラ', '小善地', 'コゼンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南都留郡道志村大栗', '19', '19422', '4020207', '山梨県', 'ヤマナシケン', '南都留郡道志村', 'ミナミツルグンドウシムラ', '大栗', 'オオグリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南都留郡道志村馬場', '19', '19422', '4020208', '山梨県', 'ヤマナシケン', '南都留郡道志村', 'ミナミツルグンドウシムラ', '馬場', 'バンバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南都留郡道志村竹之本', '19', '19422', '4020209', '山梨県', 'ヤマナシケン', '南都留郡道志村', 'ミナミツルグンドウシムラ', '竹之本', 'タケノモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南都留郡道志村東和出村', '19', '19422', '4020211', '山梨県', 'ヤマナシケン', '南都留郡道志村', 'ミナミツルグンドウシムラ', '東和出村', 'ヒガシワデムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南都留郡道志村西和出村', '19', '19422', '4020212', '山梨県', 'ヤマナシケン', '南都留郡道志村', 'ミナミツルグンドウシムラ', '西和出村', 'ニシワデムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南都留郡道志村谷相', '19', '19422', '4020213', '山梨県', 'ヤマナシケン', '南都留郡道志村', 'ミナミツルグンドウシムラ', '谷相', 'ヤソウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南都留郡道志村川原畑', '19', '19422', '4020214', '山梨県', 'ヤマナシケン', '南都留郡道志村', 'ミナミツルグンドウシムラ', '川原畑', 'カワラハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南都留郡道志村大指', '19', '19422', '4020215', '山梨県', 'ヤマナシケン', '南都留郡道志村', 'ミナミツルグンドウシムラ', '大指', 'オオザス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南都留郡道志村釜之前', '19', '19422', '4020216', '山梨県', 'ヤマナシケン', '南都留郡道志村', 'ミナミツルグンドウシムラ', '釜之前', 'カマノマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南都留郡道志村東神地', '19', '19422', '4020217', '山梨県', 'ヤマナシケン', '南都留郡道志村', 'ミナミツルグンドウシムラ', '東神地', 'ヒガシカンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南都留郡道志村中神地', '19', '19422', '4020218', '山梨県', 'ヤマナシケン', '南都留郡道志村', 'ミナミツルグンドウシムラ', '中神地', 'ナカカンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南都留郡道志村下中山', '19', '19422', '4020219', '山梨県', 'ヤマナシケン', '南都留郡道志村', 'ミナミツルグンドウシムラ', '下中山', 'シモナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南都留郡道志村上中山', '19', '19422', '4020221', '山梨県', 'ヤマナシケン', '南都留郡道志村', 'ミナミツルグンドウシムラ', '上中山', 'カミナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南都留郡道志村下善之木', '19', '19422', '4020222', '山梨県', 'ヤマナシケン', '南都留郡道志村', 'ミナミツルグンドウシムラ', '下善之木', 'シモゼンノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南都留郡道志村上善之木', '19', '19422', '4020223', '山梨県', 'ヤマナシケン', '南都留郡道志村', 'ミナミツルグンドウシムラ', '上善之木', 'カミゼンノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南都留郡道志村川村', '19', '19422', '4020224', '山梨県', 'ヤマナシケン', '南都留郡道志村', 'ミナミツルグンドウシムラ', '川村', 'カワムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南都留郡道志村板橋', '19', '19422', '4020225', '山梨県', 'ヤマナシケン', '南都留郡道志村', 'ミナミツルグンドウシムラ', '板橋', 'イタバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南都留郡道志村下白井平', '19', '19422', '4020226', '山梨県', 'ヤマナシケン', '南都留郡道志村', 'ミナミツルグンドウシムラ', '下白井平', 'シモシロイタイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南都留郡道志村上白井平', '19', '19422', '4020227', '山梨県', 'ヤマナシケン', '南都留郡道志村', 'ミナミツルグンドウシムラ', '上白井平', 'カミシロイタイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南都留郡道志村長又', '19', '19422', '4020228', '山梨県', 'ヤマナシケン', '南都留郡道志村', 'ミナミツルグンドウシムラ', '長又', 'ナガマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県富士吉田市', '19', '19202', '4030000', '山梨県', 'ヤマナシケン', '富士吉田市', 'フジヨシダシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('36183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南都留郡西桂町', '19', '19423', '4030000', '山梨県', 'ヤマナシケン', '南都留郡西桂町', 'ミナミツルグンニシカツラチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('36184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県富士吉田市上暮地', '19', '19202', '4030001', '山梨県', 'ヤマナシケン', '富士吉田市', 'フジヨシダシ', '上暮地', 'カミクレチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県富士吉田市小明見', '19', '19202', '4030002', '山梨県', 'ヤマナシケン', '富士吉田市', 'フジヨシダシ', '小明見', 'コアスミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県富士吉田市大明見', '19', '19202', '4030003', '山梨県', 'ヤマナシケン', '富士吉田市', 'フジヨシダシ', '大明見', 'オオアスミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県富士吉田市下吉田', '19', '19202', '4030004', '山梨県', 'ヤマナシケン', '富士吉田市', 'フジヨシダシ', '下吉田', 'シモヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県富士吉田市上吉田', '19', '19202', '4030005', '山梨県', 'ヤマナシケン', '富士吉田市', 'フジヨシダシ', '上吉田', 'カミヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県富士吉田市新屋', '19', '19202', '4030006', '山梨県', 'ヤマナシケン', '富士吉田市', 'フジヨシダシ', '新屋', 'アラヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県富士吉田市新倉', '19', '19202', '4030011', '山梨県', 'ヤマナシケン', '富士吉田市', 'フジヨシダシ', '新倉', 'アラクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県富士吉田市旭', '19', '19202', '4030012', '山梨県', 'ヤマナシケン', '富士吉田市', 'フジヨシダシ', '旭', 'アサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県富士吉田市緑ケ丘', '19', '19202', '4030013', '山梨県', 'ヤマナシケン', '富士吉田市', 'フジヨシダシ', '緑ケ丘', 'ミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県富士吉田市竜ケ丘', '19', '19202', '4030014', '山梨県', 'ヤマナシケン', '富士吉田市', 'フジヨシダシ', '竜ケ丘', 'タツガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県富士吉田市ときわ台', '19', '19202', '4030015', '山梨県', 'ヤマナシケン', '富士吉田市', 'フジヨシダシ', 'ときわ台', 'トキワダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県富士吉田市松山', '19', '19202', '4030016', '山梨県', 'ヤマナシケン', '富士吉田市', 'フジヨシダシ', '松山', 'マツヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県富士吉田市新西原', '19', '19202', '4030017', '山梨県', 'ヤマナシケン', '富士吉田市', 'フジヨシダシ', '新西原', 'シンニシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南都留郡西桂町下暮地', '19', '19423', '4030021', '山梨県', 'ヤマナシケン', '南都留郡西桂町', 'ミナミツルグンニシカツラチョウ', '下暮地', 'シモクレチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南都留郡西桂町小沼', '19', '19423', '4030022', '山梨県', 'ヤマナシケン', '南都留郡西桂町', 'ミナミツルグンニシカツラチョウ', '小沼', 'オヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南都留郡西桂町倉見', '19', '19423', '4030023', '山梨県', 'ヤマナシケン', '南都留郡西桂町', 'ミナミツルグンニシカツラチョウ', '倉見', 'クラミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲州市', '19', '19213', '4040000', '山梨県', 'ヤマナシケン', '甲州市', 'コウシュウシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('36204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県山梨市牧丘町柳平', '19', '19205', '4040001', '山梨県', 'ヤマナシケン', '山梨市', 'ヤマナシシ', '牧丘町柳平', 'マキオカチョウヤナギダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県山梨市牧丘町杣口', '19', '19205', '4040002', '山梨県', 'ヤマナシケン', '山梨市', 'ヤマナシシ', '牧丘町杣口', 'マキオカチョウソマグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県山梨市牧丘町倉科', '19', '19205', '4040003', '山梨県', 'ヤマナシケン', '山梨市', 'ヤマナシシ', '牧丘町倉科', 'マキオカチョウクラシナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県山梨市牧丘町西保下', '19', '19205', '4040004', '山梨県', 'ヤマナシケン', '山梨市', 'ヤマナシシ', '牧丘町西保下', 'マキオカチョウニシホシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県山梨市牧丘町西保中', '19', '19205', '4040005', '山梨県', 'ヤマナシケン', '山梨市', 'ヤマナシシ', '牧丘町西保中', 'マキオカチョウニシホナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県山梨市牧丘町牧平', '19', '19205', '4040006', '山梨県', 'ヤマナシケン', '山梨市', 'ヤマナシシ', '牧丘町牧平', 'マキオカチョウマキダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県山梨市牧丘町北原', '19', '19205', '4040007', '山梨県', 'ヤマナシケン', '山梨市', 'ヤマナシシ', '牧丘町北原', 'マキオカチョウキタバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県山梨市牧丘町成沢', '19', '19205', '4040011', '山梨県', 'ヤマナシケン', '山梨市', 'ヤマナシシ', '牧丘町成沢', 'マキオカチョウナルサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県山梨市牧丘町室伏', '19', '19205', '4040012', '山梨県', 'ヤマナシケン', '山梨市', 'ヤマナシシ', '牧丘町室伏', 'マキオカチョウムロブシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県山梨市牧丘町窪平', '19', '19205', '4040013', '山梨県', 'ヤマナシケン', '山梨市', 'ヤマナシシ', '牧丘町窪平', 'マキオカチョウクボダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県山梨市牧丘町隼', '19', '19205', '4040014', '山梨県', 'ヤマナシケン', '山梨市', 'ヤマナシシ', '牧丘町隼', 'マキオカチョウハヤブサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県山梨市牧丘町城古寺', '19', '19205', '4040015', '山梨県', 'ヤマナシケン', '山梨市', 'ヤマナシシ', '牧丘町城古寺', 'マキオカチョウジョウコジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県山梨市牧丘町千野々宮', '19', '19205', '4040016', '山梨県', 'ヤマナシケン', '山梨市', 'ヤマナシシ', '牧丘町千野々宮', 'マキオカチョウチノノミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲州市塩山一之瀬高橋', '19', '19213', '4040021', '山梨県', 'ヤマナシケン', '甲州市', 'コウシュウシ', '塩山一之瀬高橋', 'エンザンイチノセタカハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲州市塩山上萩原', '19', '19213', '4040022', '山梨県', 'ヤマナシケン', '甲州市', 'コウシュウシ', '塩山上萩原', 'エンザンカミハギハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲州市塩山中萩原', '19', '19213', '4040023', '山梨県', 'ヤマナシケン', '甲州市', 'コウシュウシ', '塩山中萩原', 'エンザンナカハギハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲州市塩山下萩原', '19', '19213', '4040024', '山梨県', 'ヤマナシケン', '甲州市', 'コウシュウシ', '塩山下萩原', 'エンザンシモハギハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲州市塩山下小田原', '19', '19213', '4040025', '山梨県', 'ヤマナシケン', '甲州市', 'コウシュウシ', '塩山下小田原', 'エンザンシモオダワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲州市塩山上小田原', '19', '19213', '4040026', '山梨県', 'ヤマナシケン', '甲州市', 'コウシュウシ', '塩山上小田原', 'エンザンカミオダワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲州市塩山上粟生野', '19', '19213', '4040031', '山梨県', 'ヤマナシケン', '甲州市', 'コウシュウシ', '塩山上粟生野', 'エンザンカミアオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲州市塩山下粟生野', '19', '19213', '4040032', '山梨県', 'ヤマナシケン', '甲州市', 'コウシュウシ', '塩山下粟生野', 'エンザンシモアオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲州市塩山赤尾', '19', '19213', '4040033', '山梨県', 'ヤマナシケン', '甲州市', 'コウシュウシ', '塩山赤尾', 'エンザンアカオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲州市塩山牛奥', '19', '19213', '4040034', '山梨県', 'ヤマナシケン', '甲州市', 'コウシュウシ', '塩山牛奥', 'エンザンウシオク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲州市塩山西野原', '19', '19213', '4040035', '山梨県', 'ヤマナシケン', '甲州市', 'コウシュウシ', '塩山西野原', 'エンザンニシノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲州市塩山熊野', '19', '19213', '4040036', '山梨県', 'ヤマナシケン', '甲州市', 'コウシュウシ', '塩山熊野', 'エンザンクマノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲州市塩山西広門田', '19', '19213', '4040037', '山梨県', 'ヤマナシケン', '甲州市', 'コウシュウシ', '塩山西広門田', 'エンザンカワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲州市塩山千野', '19', '19213', '4040041', '山梨県', 'ヤマナシケン', '甲州市', 'コウシュウシ', '塩山千野', 'エンザンチノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲州市塩山上於曽', '19', '19213', '4040042', '山梨県', 'ヤマナシケン', '甲州市', 'コウシュウシ', '塩山上於曽', 'エンザンカミオゾ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲州市塩山下於曽', '19', '19213', '4040043', '山梨県', 'ヤマナシケン', '甲州市', 'コウシュウシ', '塩山下於曽', 'エンザンシモオゾ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲州市塩山下塩後', '19', '19213', '4040044', '山梨県', 'ヤマナシケン', '甲州市', 'コウシュウシ', '塩山下塩後', 'エンザンシモシオゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲州市塩山上塩後', '19', '19213', '4040045', '山梨県', 'ヤマナシケン', '甲州市', 'コウシュウシ', '塩山上塩後', 'エンザンカミシオゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲州市塩山上井尻', '19', '19213', '4040046', '山梨県', 'ヤマナシケン', '甲州市', 'コウシュウシ', '塩山上井尻', 'エンザンカミイジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲州市塩山三日市場', '19', '19213', '4040047', '山梨県', 'ヤマナシケン', '甲州市', 'コウシュウシ', '塩山三日市場', 'エンザンミッカイチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲州市塩山竹森', '19', '19213', '4040051', '山梨県', 'ヤマナシケン', '甲州市', 'コウシュウシ', '塩山竹森', 'エンザンタケモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲州市塩山平沢', '19', '19213', '4040052', '山梨県', 'ヤマナシケン', '甲州市', 'コウシュウシ', '塩山平沢', 'エンザンヒラサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲州市塩山小屋敷', '19', '19213', '4040053', '山梨県', 'ヤマナシケン', '甲州市', 'コウシュウシ', '塩山小屋敷', 'エンザンオヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲州市塩山藤木', '19', '19213', '4040054', '山梨県', 'ヤマナシケン', '甲州市', 'コウシュウシ', '塩山藤木', 'エンザンフジキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲州市塩山下柚木', '19', '19213', '4040055', '山梨県', 'ヤマナシケン', '甲州市', 'コウシュウシ', '塩山下柚木', 'エンザンシモユノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲州市塩山福生里', '19', '19213', '4040056', '山梨県', 'ヤマナシケン', '甲州市', 'コウシュウシ', '塩山福生里', 'エンザンフクオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県山梨市三富川浦', '19', '19205', '4040201', '山梨県', 'ヤマナシケン', '山梨市', 'ヤマナシシ', '三富川浦', 'ミトミカワウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県山梨市三富上柚木', '19', '19205', '4040202', '山梨県', 'ヤマナシケン', '山梨市', 'ヤマナシシ', '三富上柚木', 'ミトミカミユノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県山梨市三富下荻原', '19', '19205', '4040203', '山梨県', 'ヤマナシケン', '山梨市', 'ヤマナシシ', '三富下荻原', 'ミトミシモオギハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県山梨市三富下釜口', '19', '19205', '4040204', '山梨県', 'ヤマナシケン', '山梨市', 'ヤマナシシ', '三富下釜口', 'ミトミシモカマクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県山梨市三富徳和', '19', '19205', '4040205', '山梨県', 'ヤマナシケン', '山梨市', 'ヤマナシシ', '三富徳和', 'ミトミトクワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県山梨市三富上釜口', '19', '19205', '4040206', '山梨県', 'ヤマナシケン', '山梨市', 'ヤマナシシ', '三富上釜口', 'ミトミカミカマクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲州市塩山小屋敷滑沢', '19', '19213', '4040211', '山梨県', 'ヤマナシケン', '甲州市', 'コウシュウシ', '塩山小屋敷', 'エンザンオヤシキ', null, null, '滑沢', 'ナメザワ');
INSERT INTO `ms_addresses` VALUES ('36252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県山梨市', '19', '19205', '4050000', '山梨県', 'ヤマナシケン', '山梨市', 'ヤマナシシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('36253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県山梨市西', '19', '19205', '4050001', '山梨県', 'ヤマナシケン', '山梨市', 'ヤマナシシ', '西', 'ニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県山梨市東', '19', '19205', '4050002', '山梨県', 'ヤマナシケン', '山梨市', 'ヤマナシシ', '東', 'ヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県山梨市下井尻', '19', '19205', '4050003', '山梨県', 'ヤマナシケン', '山梨市', 'ヤマナシシ', '下井尻', 'シモイジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県山梨市上之割', '19', '19205', '4050004', '山梨県', 'ヤマナシケン', '山梨市', 'ヤマナシシ', '上之割', 'カミノワリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県山梨市小原東', '19', '19205', '4050005', '山梨県', 'ヤマナシケン', '山梨市', 'ヤマナシシ', '小原東', 'コバラヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県山梨市小原西', '19', '19205', '4050006', '山梨県', 'ヤマナシケン', '山梨市', 'ヤマナシシ', '小原西', 'コバラニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県山梨市七日市場', '19', '19205', '4050007', '山梨県', 'ヤマナシケン', '山梨市', 'ヤマナシシ', '七日市場', 'ナノカイチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県山梨市三ケ所', '19', '19205', '4050011', '山梨県', 'ヤマナシケン', '山梨市', 'ヤマナシシ', '三ケ所', 'サンガショ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県山梨市東後屋敷', '19', '19205', '4050012', '山梨県', 'ヤマナシケン', '山梨市', 'ヤマナシシ', '東後屋敷', 'ヒガシゴヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県山梨市鴨居寺', '19', '19205', '4050013', '山梨県', 'ヤマナシケン', '山梨市', 'ヤマナシシ', '鴨居寺', 'カモイデラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県山梨市上石森', '19', '19205', '4050014', '山梨県', 'ヤマナシケン', '山梨市', 'ヤマナシシ', '上石森', 'カミイシモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県山梨市下石森', '19', '19205', '4050015', '山梨県', 'ヤマナシケン', '山梨市', 'ヤマナシシ', '下石森', 'シモイシモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県山梨市大野', '19', '19205', '4050016', '山梨県', 'ヤマナシケン', '山梨市', 'ヤマナシシ', '大野', 'オオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県山梨市下神内川', '19', '19205', '4050017', '山梨県', 'ヤマナシケン', '山梨市', 'ヤマナシシ', '下神内川', 'シモカノガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県山梨市上神内川', '19', '19205', '4050018', '山梨県', 'ヤマナシケン', '山梨市', 'ヤマナシシ', '上神内川', 'カミカノガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県山梨市中村', '19', '19205', '4050021', '山梨県', 'ヤマナシケン', '山梨市', 'ヤマナシシ', '中村', 'ナカムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県山梨市上栗原', '19', '19205', '4050022', '山梨県', 'ヤマナシケン', '山梨市', 'ヤマナシシ', '上栗原', 'カミクリバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県山梨市下栗原', '19', '19205', '4050023', '山梨県', 'ヤマナシケン', '山梨市', 'ヤマナシシ', '下栗原', 'シモクリバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県山梨市歌田', '19', '19205', '4050024', '山梨県', 'ヤマナシケン', '山梨市', 'ヤマナシシ', '歌田', 'ウタダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県山梨市一町田中', '19', '19205', '4050025', '山梨県', 'ヤマナシケン', '山梨市', 'ヤマナシシ', '一町田中', 'イッチョウタナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県山梨市万力', '19', '19205', '4050031', '山梨県', 'ヤマナシケン', '山梨市', 'ヤマナシシ', '万力', 'マンリキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県山梨市正徳寺', '19', '19205', '4050032', '山梨県', 'ヤマナシケン', '山梨市', 'ヤマナシシ', '正徳寺', 'ショウトクジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県山梨市落合', '19', '19205', '4050033', '山梨県', 'ヤマナシケン', '山梨市', 'ヤマナシシ', '落合', 'オチアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県山梨市上岩下', '19', '19205', '4050034', '山梨県', 'ヤマナシケン', '山梨市', 'ヤマナシシ', '上岩下', 'カミイワシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県山梨市山根', '19', '19205', '4050035', '山梨県', 'ヤマナシケン', '山梨市', 'ヤマナシシ', '山根', 'ヤマネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県山梨市矢坪', '19', '19205', '4050036', '山梨県', 'ヤマナシケン', '山梨市', 'ヤマナシシ', '矢坪', 'ヤツボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県山梨市北', '19', '19205', '4050041', '山梨県', 'ヤマナシケン', '山梨市', 'ヤマナシシ', '北', 'キタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県山梨市南', '19', '19205', '4050042', '山梨県', 'ヤマナシケン', '山梨市', 'ヤマナシシ', '南', 'ミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県山梨市江曽原', '19', '19205', '4050043', '山梨県', 'ヤマナシケン', '山梨市', 'ヤマナシシ', '江曽原', 'エゾハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県山梨市市川', '19', '19205', '4050044', '山梨県', 'ヤマナシケン', '山梨市', 'ヤマナシシ', '市川', 'イチガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県山梨市大工', '19', '19205', '4050045', '山梨県', 'ヤマナシケン', '山梨市', 'ヤマナシシ', '大工', 'ダイク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県山梨市堀内', '19', '19205', '4050046', '山梨県', 'ヤマナシケン', '山梨市', 'ヤマナシシ', '堀内', 'ホリノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県山梨市水口', '19', '19205', '4050047', '山梨県', 'ヤマナシケン', '山梨市', 'ヤマナシシ', '水口', 'ミズクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県山梨市切差', '19', '19205', '4050048', '山梨県', 'ヤマナシケン', '山梨市', 'ヤマナシシ', '切差', 'キッサツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県笛吹市一宮町北野呂', '19', '19211', '4050051', '山梨県', 'ヤマナシケン', '笛吹市', 'フエフキシ', '一宮町北野呂', 'イチノミヤチョウキタノロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県笛吹市一宮町南野呂', '19', '19211', '4050052', '山梨県', 'ヤマナシケン', '笛吹市', 'フエフキシ', '一宮町南野呂', 'イチノミヤチョウミナミノロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県笛吹市一宮町中尾', '19', '19211', '4050053', '山梨県', 'ヤマナシケン', '笛吹市', 'フエフキシ', '一宮町中尾', 'イチノミヤチョウナカオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県笛吹市一宮町千米寺', '19', '19211', '4050054', '山梨県', 'ヤマナシケン', '笛吹市', 'フエフキシ', '一宮町千米寺', 'イチノミヤチョウセンベイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県笛吹市一宮町地蔵堂', '19', '19211', '4050055', '山梨県', 'ヤマナシケン', '笛吹市', 'フエフキシ', '一宮町地蔵堂', 'イチノミヤチョウジゾウドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県笛吹市一宮町一ノ宮', '19', '19211', '4050056', '山梨県', 'ヤマナシケン', '笛吹市', 'フエフキシ', '一宮町一ノ宮', 'イチノミヤチョウイチノミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県笛吹市一宮町下矢作', '19', '19211', '4050057', '山梨県', 'ヤマナシケン', '笛吹市', 'フエフキシ', '一宮町下矢作', 'イチノミヤチョウシモヤハギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県笛吹市一宮町小城', '19', '19211', '4050058', '山梨県', 'ヤマナシケン', '笛吹市', 'フエフキシ', '一宮町小城', 'イチノミヤチョウコジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県笛吹市一宮町上矢作', '19', '19211', '4050059', '山梨県', 'ヤマナシケン', '笛吹市', 'フエフキシ', '一宮町上矢作', 'イチノミヤチョウカミヤハギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県笛吹市一宮町石', '19', '19211', '4050061', '山梨県', 'ヤマナシケン', '笛吹市', 'フエフキシ', '一宮町石', 'イチノミヤチョウイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県笛吹市一宮町金沢', '19', '19211', '4050062', '山梨県', 'ヤマナシケン', '笛吹市', 'フエフキシ', '一宮町金沢', 'イチノミヤチョウカナザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県笛吹市一宮町市之蔵', '19', '19211', '4050063', '山梨県', 'ヤマナシケン', '笛吹市', 'フエフキシ', '一宮町市之蔵', 'イチノミヤチョウイチノクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県笛吹市一宮町塩田', '19', '19211', '4050064', '山梨県', 'ヤマナシケン', '笛吹市', 'フエフキシ', '一宮町塩田', 'イチノミヤチョウシオダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県笛吹市一宮町新巻', '19', '19211', '4050065', '山梨県', 'ヤマナシケン', '笛吹市', 'フエフキシ', '一宮町新巻', 'イチノミヤチョウアラマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県笛吹市一宮町神沢', '19', '19211', '4050066', '山梨県', 'ヤマナシケン', '笛吹市', 'フエフキシ', '一宮町神沢', 'イチノミヤチョウカンザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県笛吹市一宮町土塚', '19', '19211', '4050067', '山梨県', 'ヤマナシケン', '笛吹市', 'フエフキシ', '一宮町土塚', 'イチノミヤチョウツチヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県笛吹市一宮町狐新居', '19', '19211', '4050068', '山梨県', 'ヤマナシケン', '笛吹市', 'フエフキシ', '一宮町狐新居', 'イチノミヤチョウキツネアライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県笛吹市一宮町東新居', '19', '19211', '4050069', '山梨県', 'ヤマナシケン', '笛吹市', 'フエフキシ', '一宮町東新居', 'イチノミヤチョウヒガシアライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県笛吹市一宮町北都塚', '19', '19211', '4050071', '山梨県', 'ヤマナシケン', '笛吹市', 'フエフキシ', '一宮町北都塚', 'イチノミヤチョウキタミヤコヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県笛吹市一宮町本都塚', '19', '19211', '4050072', '山梨県', 'ヤマナシケン', '笛吹市', 'フエフキシ', '一宮町本都塚', 'イチノミヤチョウモトミヤコヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県笛吹市一宮町末木', '19', '19211', '4050073', '山梨県', 'ヤマナシケン', '笛吹市', 'フエフキシ', '一宮町末木', 'イチノミヤチョウスエキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県笛吹市一宮町国分', '19', '19211', '4050074', '山梨県', 'ヤマナシケン', '笛吹市', 'フエフキシ', '一宮町国分', 'イチノミヤチョウコクブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県笛吹市一宮町橋立', '19', '19211', '4050075', '山梨県', 'ヤマナシケン', '笛吹市', 'フエフキシ', '一宮町橋立', 'イチノミヤチョウハシタテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県笛吹市一宮町東原', '19', '19211', '4050075', '山梨県', 'ヤマナシケン', '笛吹市', 'フエフキシ', '一宮町東原', 'イチノミヤチョウヒガシバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県笛吹市一宮町竹原田', '19', '19211', '4050076', '山梨県', 'ヤマナシケン', '笛吹市', 'フエフキシ', '一宮町竹原田', 'イチノミヤチョウタケハラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県笛吹市一宮町坪井', '19', '19211', '4050077', '山梨県', 'ヤマナシケン', '笛吹市', 'フエフキシ', '一宮町坪井', 'イチノミヤチョウツボイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県笛吹市一宮町田中', '19', '19211', '4050078', '山梨県', 'ヤマナシケン', '笛吹市', 'フエフキシ', '一宮町田中', 'イチノミヤチョウタナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県笛吹市一宮町金田', '19', '19211', '4050079', '山梨県', 'ヤマナシケン', '笛吹市', 'フエフキシ', '一宮町金田', 'イチノミヤチョウカネタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県笛吹市', '19', '19211', '4060000', '山梨県', 'ヤマナシケン', '笛吹市', 'フエフキシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('36320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県笛吹市春日居町下岩下', '19', '19211', '4060001', '山梨県', 'ヤマナシケン', '笛吹市', 'フエフキシ', '春日居町下岩下', 'カスガイチョウシモイワシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県笛吹市春日居町別田', '19', '19211', '4060002', '山梨県', 'ヤマナシケン', '笛吹市', 'フエフキシ', '春日居町別田', 'カスガイチョウベツデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県笛吹市春日居町桑戸', '19', '19211', '4060003', '山梨県', 'ヤマナシケン', '笛吹市', 'フエフキシ', '春日居町桑戸', 'カスガイチョウクワド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県笛吹市春日居町小松', '19', '19211', '4060004', '山梨県', 'ヤマナシケン', '笛吹市', 'フエフキシ', '春日居町小松', 'カスガイチョウコマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県笛吹市春日居町加茂', '19', '19211', '4060005', '山梨県', 'ヤマナシケン', '笛吹市', 'フエフキシ', '春日居町加茂', 'カスガイチョウカモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県笛吹市春日居町徳条', '19', '19211', '4060011', '山梨県', 'ヤマナシケン', '笛吹市', 'フエフキシ', '春日居町徳条', 'カスガイチョウトクジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県笛吹市春日居町熊野堂', '19', '19211', '4060012', '山梨県', 'ヤマナシケン', '笛吹市', 'フエフキシ', '春日居町熊野堂', 'カスガイチョウクマノドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県笛吹市春日居町寺本', '19', '19211', '4060013', '山梨県', 'ヤマナシケン', '笛吹市', 'フエフキシ', '春日居町寺本', 'カスガイチョウテラモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県笛吹市春日居町国府', '19', '19211', '4060014', '山梨県', 'ヤマナシケン', '笛吹市', 'フエフキシ', '春日居町国府', 'カスガイチョウコクフ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県笛吹市春日居町鎮目', '19', '19211', '4060015', '山梨県', 'ヤマナシケン', '笛吹市', 'フエフキシ', '春日居町鎮目', 'カスガイチョウシズメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県笛吹市石和町松本', '19', '19211', '4060021', '山梨県', 'ヤマナシケン', '笛吹市', 'フエフキシ', '石和町松本', 'イサワチョウマツモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県笛吹市石和町山崎', '19', '19211', '4060022', '山梨県', 'ヤマナシケン', '笛吹市', 'フエフキシ', '石和町山崎', 'イサワチョウヤマサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県笛吹市石和町八田', '19', '19211', '4060023', '山梨県', 'ヤマナシケン', '笛吹市', 'フエフキシ', '石和町八田', 'イサワチョウハツタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県笛吹市石和町川中島', '19', '19211', '4060024', '山梨県', 'ヤマナシケン', '笛吹市', 'フエフキシ', '石和町川中島', 'イサワチョウカワナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県笛吹市石和町上平井', '19', '19211', '4060025', '山梨県', 'ヤマナシケン', '笛吹市', 'フエフキシ', '石和町上平井', 'イサワチョウカミヒライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県笛吹市石和町中川', '19', '19211', '4060026', '山梨県', 'ヤマナシケン', '笛吹市', 'フエフキシ', '石和町中川', 'イサワチョウナカガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県笛吹市石和町下平井', '19', '19211', '4060027', '山梨県', 'ヤマナシケン', '笛吹市', 'フエフキシ', '石和町下平井', 'イサワチョウシモヒライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県笛吹市石和町市部', '19', '19211', '4060031', '山梨県', 'ヤマナシケン', '笛吹市', 'フエフキシ', '石和町市部', 'イサワチョウイチベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県笛吹市石和町四日市場', '19', '19211', '4060032', '山梨県', 'ヤマナシケン', '笛吹市', 'フエフキシ', '石和町四日市場', 'イサワチョウヨッカイチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県笛吹市石和町小石和', '19', '19211', '4060033', '山梨県', 'ヤマナシケン', '笛吹市', 'フエフキシ', '石和町小石和', 'イサワチョウコイサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県笛吹市石和町唐柏', '19', '19211', '4060034', '山梨県', 'ヤマナシケン', '笛吹市', 'フエフキシ', '石和町唐柏', 'イサワチョウカラカシワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県笛吹市石和町広瀬', '19', '19211', '4060035', '山梨県', 'ヤマナシケン', '笛吹市', 'フエフキシ', '石和町広瀬', 'イサワチョウヒロセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県笛吹市石和町窪中島', '19', '19211', '4060036', '山梨県', 'ヤマナシケン', '笛吹市', 'フエフキシ', '石和町窪中島', 'イサワチョウクボナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県笛吹市石和町東高橋', '19', '19211', '4060041', '山梨県', 'ヤマナシケン', '笛吹市', 'フエフキシ', '石和町東高橋', 'イサワチョウヒガシタカハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県笛吹市石和町今井', '19', '19211', '4060042', '山梨県', 'ヤマナシケン', '笛吹市', 'フエフキシ', '石和町今井', 'イサワチョウイマイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県笛吹市石和町河内', '19', '19211', '4060043', '山梨県', 'ヤマナシケン', '笛吹市', 'フエフキシ', '石和町河内', 'イサワチョウコウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県笛吹市石和町砂原', '19', '19211', '4060044', '山梨県', 'ヤマナシケン', '笛吹市', 'フエフキシ', '石和町砂原', 'イサワチョウスナハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県笛吹市石和町井戸', '19', '19211', '4060045', '山梨県', 'ヤマナシケン', '笛吹市', 'フエフキシ', '石和町井戸', 'イサワチョウイド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県笛吹市石和町東油川', '19', '19211', '4060046', '山梨県', 'ヤマナシケン', '笛吹市', 'フエフキシ', '石和町東油川', 'イサワチョウヒガシアブラカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県笛吹市御坂町成田', '19', '19211', '4060801', '山梨県', 'ヤマナシケン', '笛吹市', 'フエフキシ', '御坂町成田', 'ミサカチョウナリタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県笛吹市御坂町金川原', '19', '19211', '4060802', '山梨県', 'ヤマナシケン', '笛吹市', 'フエフキシ', '御坂町金川原', 'ミサカチョウカネガワバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県笛吹市御坂町井之上', '19', '19211', '4060803', '山梨県', 'ヤマナシケン', '笛吹市', 'フエフキシ', '御坂町井之上', 'ミサカチョウイノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県笛吹市御坂町夏目原', '19', '19211', '4060804', '山梨県', 'ヤマナシケン', '笛吹市', 'フエフキシ', '御坂町夏目原', 'ミサカチョウナツメハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県笛吹市御坂町栗合', '19', '19211', '4060805', '山梨県', 'ヤマナシケン', '笛吹市', 'フエフキシ', '御坂町栗合', 'ミサカチョウクリアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県笛吹市御坂町八千蔵', '19', '19211', '4060806', '山梨県', 'ヤマナシケン', '笛吹市', 'フエフキシ', '御坂町八千蔵', 'ミサカチョウヤチクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県笛吹市御坂町二之宮', '19', '19211', '4060807', '山梨県', 'ヤマナシケン', '笛吹市', 'フエフキシ', '御坂町二之宮', 'ミサカチョウニノミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県笛吹市御坂町国衙', '19', '19211', '4060808', '山梨県', 'ヤマナシケン', '笛吹市', 'フエフキシ', '御坂町国衙', 'ミサカチョウコクガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県笛吹市御坂町下野原', '19', '19211', '4060811', '山梨県', 'ヤマナシケン', '笛吹市', 'フエフキシ', '御坂町下野原', 'ミサカチョウシモノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県笛吹市御坂町下黒駒', '19', '19211', '4060812', '山梨県', 'ヤマナシケン', '笛吹市', 'フエフキシ', '御坂町下黒駒', 'ミサカチョウシモクロコマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県笛吹市御坂町上黒駒', '19', '19211', '4060813', '山梨県', 'ヤマナシケン', '笛吹市', 'フエフキシ', '御坂町上黒駒', 'ミサカチョウカミクロコマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県笛吹市御坂町藤野木', '19', '19211', '4060814', '山梨県', 'ヤマナシケン', '笛吹市', 'フエフキシ', '御坂町藤野木', 'ミサカチョウトウノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県笛吹市御坂町尾山', '19', '19211', '4060815', '山梨県', 'ヤマナシケン', '笛吹市', 'フエフキシ', '御坂町尾山', 'ミサカチョウオヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県笛吹市御坂町竹居', '19', '19211', '4060816', '山梨県', 'ヤマナシケン', '笛吹市', 'フエフキシ', '御坂町竹居', 'ミサカチョウタケイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県笛吹市御坂町大野寺', '19', '19211', '4060817', '山梨県', 'ヤマナシケン', '笛吹市', 'フエフキシ', '御坂町大野寺', 'ミサカチョウオオノジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県笛吹市御坂町蕎麦塚', '19', '19211', '4060818', '山梨県', 'ヤマナシケン', '笛吹市', 'フエフキシ', '御坂町蕎麦塚', 'ミサカチョウソバツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県笛吹市八代町北', '19', '19211', '4060821', '山梨県', 'ヤマナシケン', '笛吹市', 'フエフキシ', '八代町北', 'ヤツシロチョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県笛吹市八代町南', '19', '19211', '4060822', '山梨県', 'ヤマナシケン', '笛吹市', 'フエフキシ', '八代町南', 'ヤツシロチョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県笛吹市八代町永井', '19', '19211', '4060823', '山梨県', 'ヤマナシケン', '笛吹市', 'フエフキシ', '八代町永井', 'ヤツシロチョウナガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県笛吹市八代町増利', '19', '19211', '4060824', '山梨県', 'ヤマナシケン', '笛吹市', 'フエフキシ', '八代町増利', 'ヤツシロチョウマサリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県笛吹市八代町大間田', '19', '19211', '4060825', '山梨県', 'ヤマナシケン', '笛吹市', 'フエフキシ', '八代町大間田', 'ヤツシロチョウオオマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県笛吹市八代町高家', '19', '19211', '4060831', '山梨県', 'ヤマナシケン', '笛吹市', 'フエフキシ', '八代町高家', 'ヤツシロチョウコウカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県笛吹市八代町竹居', '19', '19211', '4060832', '山梨県', 'ヤマナシケン', '笛吹市', 'フエフキシ', '八代町竹居', 'ヤツシロチョウタケイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県笛吹市八代町奈良原', '19', '19211', '4060833', '山梨県', 'ヤマナシケン', '笛吹市', 'フエフキシ', '八代町奈良原', 'ヤツシロチョウナラバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県笛吹市八代町岡', '19', '19211', '4060834', '山梨県', 'ヤマナシケン', '笛吹市', 'フエフキシ', '八代町岡', 'ヤツシロチョウオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県笛吹市八代町米倉', '19', '19211', '4060835', '山梨県', 'ヤマナシケン', '笛吹市', 'フエフキシ', '八代町米倉', 'ヤツシロチョウヨネクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県笛吹市境川町大坪', '19', '19211', '4060841', '山梨県', 'ヤマナシケン', '笛吹市', 'フエフキシ', '境川町大坪', 'サカイガワチョウオオツボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県笛吹市境川町石橋', '19', '19211', '4060842', '山梨県', 'ヤマナシケン', '笛吹市', 'フエフキシ', '境川町石橋', 'サカイガワチョウイシバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県笛吹市境川町前間田', '19', '19211', '4060843', '山梨県', 'ヤマナシケン', '笛吹市', 'フエフキシ', '境川町前間田', 'サカイガワチョウマエマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県笛吹市境川町小山', '19', '19211', '4060844', '山梨県', 'ヤマナシケン', '笛吹市', 'フエフキシ', '境川町小山', 'サカイガワチョウコヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県笛吹市境川町坊ケ峰', '19', '19211', '4060845', '山梨県', 'ヤマナシケン', '笛吹市', 'フエフキシ', '境川町坊ケ峰', 'サカイガワチョウボウガミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県笛吹市境川町三椚', '19', '19211', '4060846', '山梨県', 'ヤマナシケン', '笛吹市', 'フエフキシ', '境川町三椚', 'サカイガワチョウミツクヌギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県笛吹市境川町小黒坂', '19', '19211', '4060851', '山梨県', 'ヤマナシケン', '笛吹市', 'フエフキシ', '境川町小黒坂', 'サカイガワチョウコグロサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県笛吹市境川町大黒坂', '19', '19211', '4060852', '山梨県', 'ヤマナシケン', '笛吹市', 'フエフキシ', '境川町大黒坂', 'サカイガワチョウオオグロサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県笛吹市境川町藤垈', '19', '19211', '4060853', '山梨県', 'ヤマナシケン', '笛吹市', 'フエフキシ', '境川町藤垈', 'サカイガワチョウフジヌタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県笛吹市境川町寺尾', '19', '19211', '4060854', '山梨県', 'ヤマナシケン', '笛吹市', 'フエフキシ', '境川町寺尾', 'サカイガワチョウテラオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県笛吹市境川町大窪', '19', '19211', '4060855', '山梨県', 'ヤマナシケン', '笛吹市', 'フエフキシ', '境川町大窪', 'サカイガワチョウオオクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県韮崎市', '19', '19207', '4070000', '山梨県', 'ヤマナシケン', '韮崎市', 'ニラサキシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('36392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県韮崎市藤井町駒井', '19', '19207', '4070001', '山梨県', 'ヤマナシケン', '韮崎市', 'ニラサキシ', '藤井町駒井', 'フジイマチコマイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県韮崎市藤井町坂井', '19', '19207', '4070002', '山梨県', 'ヤマナシケン', '韮崎市', 'ニラサキシ', '藤井町坂井', 'フジイマチサカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県韮崎市藤井町北下條', '19', '19207', '4070003', '山梨県', 'ヤマナシケン', '韮崎市', 'ニラサキシ', '藤井町北下條', 'フジイマチキタゲジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県韮崎市藤井町南下條', '19', '19207', '4070004', '山梨県', 'ヤマナシケン', '韮崎市', 'ニラサキシ', '藤井町南下條', 'フジイマチミナミゲジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県韮崎市一ツ谷', '19', '19207', '4070005', '山梨県', 'ヤマナシケン', '韮崎市', 'ニラサキシ', '一ツ谷', 'ヒトツヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県韮崎市下祖母石', '19', '19207', '4070006', '山梨県', 'ヤマナシケン', '韮崎市', 'ニラサキシ', '下祖母石', 'シモウバイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県韮崎市上祖母石', '19', '19207', '4070007', '山梨県', 'ヤマナシケン', '韮崎市', 'ニラサキシ', '上祖母石', 'カミウバイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県韮崎市上ノ山', '19', '19207', '4070011', '山梨県', 'ヤマナシケン', '韮崎市', 'ニラサキシ', '上ノ山', 'ウエノヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県韮崎市岩下', '19', '19207', '4070012', '山梨県', 'ヤマナシケン', '韮崎市', 'ニラサキシ', '岩下', 'イワシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県韮崎市中島', '19', '19207', '4070013', '山梨県', 'ヤマナシケン', '韮崎市', 'ニラサキシ', '中島', 'ナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県韮崎市富士見', '19', '19207', '4070014', '山梨県', 'ヤマナシケン', '韮崎市', 'ニラサキシ', '富士見', 'フジミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県韮崎市若宮', '19', '19207', '4070015', '山梨県', 'ヤマナシケン', '韮崎市', 'ニラサキシ', '若宮', 'ワカミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県韮崎市富士見ケ丘', '19', '19207', '4070021', '山梨県', 'ヤマナシケン', '韮崎市', 'ニラサキシ', '富士見ケ丘', 'フジミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県韮崎市水神', '19', '19207', '4070022', '山梨県', 'ヤマナシケン', '韮崎市', 'ニラサキシ', '水神', 'スイジン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県韮崎市中央町', '19', '19207', '4070023', '山梨県', 'ヤマナシケン', '韮崎市', 'ニラサキシ', '中央町', 'チュウオウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県韮崎市本町', '19', '19207', '4070024', '山梨県', 'ヤマナシケン', '韮崎市', 'ニラサキシ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県韮崎市栄', '19', '19207', '4070025', '山梨県', 'ヤマナシケン', '韮崎市', 'ニラサキシ', '栄', 'サカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県韮崎市龍岡町若尾新田', '19', '19207', '4070031', '山梨県', 'ヤマナシケン', '韮崎市', 'ニラサキシ', '龍岡町若尾新田', 'タツオカマチワカオシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県韮崎市龍岡町下條東割', '19', '19207', '4070032', '山梨県', 'ヤマナシケン', '韮崎市', 'ニラサキシ', '龍岡町下條東割', 'タツオカマチシモジョウヒガシワリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県韮崎市龍岡町下條南割', '19', '19207', '4070033', '山梨県', 'ヤマナシケン', '韮崎市', 'ニラサキシ', '龍岡町下條南割', 'タツオカマチシモジョウミナミワリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県韮崎市大草町下條中割', '19', '19207', '4070034', '山梨県', 'ヤマナシケン', '韮崎市', 'ニラサキシ', '大草町下條中割', 'オオクサマチシモジョウナカワリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県韮崎市大草町下條西割', '19', '19207', '4070035', '山梨県', 'ヤマナシケン', '韮崎市', 'ニラサキシ', '大草町下條西割', 'オオクサマチシモジョウニシワリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県韮崎市大草町上條東割', '19', '19207', '4070036', '山梨県', 'ヤマナシケン', '韮崎市', 'ニラサキシ', '大草町上條東割', 'オオクサマチカミジョウヒガシワリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県韮崎市大草町若尾', '19', '19207', '4070037', '山梨県', 'ヤマナシケン', '韮崎市', 'ニラサキシ', '大草町若尾', 'オオクサマチワカオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県韮崎市神山町武田', '19', '19207', '4070041', '山梨県', 'ヤマナシケン', '韮崎市', 'ニラサキシ', '神山町武田', 'カミヤママチタケタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県韮崎市神山町北宮地', '19', '19207', '4070042', '山梨県', 'ヤマナシケン', '韮崎市', 'ニラサキシ', '神山町北宮地', 'カミヤママチキタミヤジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県韮崎市神山町鍋山', '19', '19207', '4070043', '山梨県', 'ヤマナシケン', '韮崎市', 'ニラサキシ', '神山町鍋山', 'カミヤママチナベヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県韮崎市旭町上條北割', '19', '19207', '4070044', '山梨県', 'ヤマナシケン', '韮崎市', 'ニラサキシ', '旭町上條北割', 'アサヒマチカミジョウキタワリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県韮崎市旭町上條中割', '19', '19207', '4070045', '山梨県', 'ヤマナシケン', '韮崎市', 'ニラサキシ', '旭町上條中割', 'アサヒマチカミジョウナカワリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県韮崎市旭町上條南割', '19', '19207', '4070046', '山梨県', 'ヤマナシケン', '韮崎市', 'ニラサキシ', '旭町上條南割', 'アサヒマチカミジョウミナミワリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県韮崎市円野町上円井', '19', '19207', '4070051', '山梨県', 'ヤマナシケン', '韮崎市', 'ニラサキシ', '円野町上円井', 'マルノマチカミツブライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県韮崎市円野町下円井', '19', '19207', '4070052', '山梨県', 'ヤマナシケン', '韮崎市', 'ニラサキシ', '円野町下円井', 'マルノマチシモツブライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県韮崎市円野町入戸野', '19', '19207', '4070053', '山梨県', 'ヤマナシケン', '韮崎市', 'ニラサキシ', '円野町入戸野', 'マルノマチニットノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県韮崎市清哲町折居', '19', '19207', '4070054', '山梨県', 'ヤマナシケン', '韮崎市', 'ニラサキシ', '清哲町折居', 'セイテツマチオリイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県韮崎市清哲町青木', '19', '19207', '4070055', '山梨県', 'ヤマナシケン', '韮崎市', 'ニラサキシ', '清哲町青木', 'セイテツマチアオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県韮崎市清哲町樋口', '19', '19207', '4070057', '山梨県', 'ヤマナシケン', '韮崎市', 'ニラサキシ', '清哲町樋口', 'セイテツマチヒノグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県韮崎市清哲町水上', '19', '19207', '4070058', '山梨県', 'ヤマナシケン', '韮崎市', 'ニラサキシ', '清哲町水上', 'セイテツマチミズカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県韮崎市穂坂町柳平', '19', '19207', '4070171', '山梨県', 'ヤマナシケン', '韮崎市', 'ニラサキシ', '穂坂町柳平', 'ホサカマチヤナギダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県韮崎市穂坂町上今井', '19', '19207', '4070172', '山梨県', 'ヤマナシケン', '韮崎市', 'ニラサキシ', '穂坂町上今井', 'ホサカマチカミイマイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県韮崎市穂坂町長久保', '19', '19207', '4070173', '山梨県', 'ヤマナシケン', '韮崎市', 'ニラサキシ', '穂坂町長久保', 'ホサカマチナガクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県韮崎市穂坂町三ツ沢', '19', '19207', '4070174', '山梨県', 'ヤマナシケン', '韮崎市', 'ニラサキシ', '穂坂町三ツ沢', 'ホサカマチミツサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県韮崎市穂坂町宮久保', '19', '19207', '4070175', '山梨県', 'ヤマナシケン', '韮崎市', 'ニラサキシ', '穂坂町宮久保', 'ホサカマチミヤクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県韮崎市穂坂町三之蔵', '19', '19207', '4070176', '山梨県', 'ヤマナシケン', '韮崎市', 'ニラサキシ', '穂坂町三之蔵', 'ホサカマチサンノクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県韮崎市中田町小田川', '19', '19207', '4070261', '山梨県', 'ヤマナシケン', '韮崎市', 'ニラサキシ', '中田町小田川', 'ナカダマチコタガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県韮崎市中田町中條', '19', '19207', '4070262', '山梨県', 'ヤマナシケン', '韮崎市', 'ニラサキシ', '中田町中條', 'ナカダマチナカジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県韮崎市穴山町', '19', '19207', '4070263', '山梨県', 'ヤマナシケン', '韮崎市', 'ニラサキシ', '穴山町', 'アナヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県北杜市高根町清里', '19', '19209', '4070301', '山梨県', 'ヤマナシケン', '北杜市', 'ホクトシ', '高根町清里', 'タカネチョウキヨサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県北杜市高根町浅川', '19', '19209', '4070302', '山梨県', 'ヤマナシケン', '北杜市', 'ホクトシ', '高根町浅川', 'タカネチョウアサカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県北杜市大泉町西井出', '19', '19209', '4070311', '山梨県', 'ヤマナシケン', '北杜市', 'ホクトシ', '大泉町西井出', 'オオイズミチョウニシイデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県北杜市須玉町上津金', '19', '19209', '4070321', '山梨県', 'ヤマナシケン', '北杜市', 'ホクトシ', '須玉町上津金', 'スタマチョウカミツガネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県北杜市須玉町下津金', '19', '19209', '4070322', '山梨県', 'ヤマナシケン', '北杜市', 'ホクトシ', '須玉町下津金', 'スタマチョウシモツガネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県北杜市', '19', '19209', '4080000', '山梨県', 'ヤマナシケン', '北杜市', 'ホクトシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('36447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県北杜市高根町長沢', '19', '19209', '4080001', '山梨県', 'ヤマナシケン', '北杜市', 'ホクトシ', '高根町長沢', 'タカネチョウナガサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県北杜市高根町村山北割', '19', '19209', '4080002', '山梨県', 'ヤマナシケン', '北杜市', 'ホクトシ', '高根町村山北割', 'タカネチョウムラヤマキタワリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県北杜市高根町東井出', '19', '19209', '4080003', '山梨県', 'ヤマナシケン', '北杜市', 'ホクトシ', '高根町東井出', 'タカネチョウヒガシイデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県北杜市高根町堤', '19', '19209', '4080004', '山梨県', 'ヤマナシケン', '北杜市', 'ホクトシ', '高根町堤', 'タカネチョウツツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県北杜市高根町箕輪新町', '19', '19209', '4080011', '山梨県', 'ヤマナシケン', '北杜市', 'ホクトシ', '高根町箕輪新町', 'タカネチョウミノワシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県北杜市高根町箕輪', '19', '19209', '4080012', '山梨県', 'ヤマナシケン', '北杜市', 'ホクトシ', '高根町箕輪', 'タカネチョウミノワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県北杜市高根町蔵原', '19', '19209', '4080013', '山梨県', 'ヤマナシケン', '北杜市', 'ホクトシ', '高根町蔵原', 'タカネチョウクラバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県北杜市高根町小池', '19', '19209', '4080014', '山梨県', 'ヤマナシケン', '北杜市', 'ホクトシ', '高根町小池', 'タカネチョウコイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県北杜市高根町下黒澤', '19', '19209', '4080015', '山梨県', 'ヤマナシケン', '北杜市', 'ホクトシ', '高根町下黒澤', 'タカネチョウシモクロザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県北杜市高根町上黒澤', '19', '19209', '4080016', '山梨県', 'ヤマナシケン', '北杜市', 'ホクトシ', '高根町上黒澤', 'タカネチョウカミクロザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県北杜市高根町五町田', '19', '19209', '4080017', '山梨県', 'ヤマナシケン', '北杜市', 'ホクトシ', '高根町五町田', 'タカネチョウゴチョウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県北杜市高根町村山西割', '19', '19209', '4080018', '山梨県', 'ヤマナシケン', '北杜市', 'ホクトシ', '高根町村山西割', 'タカネチョウムラヤマニシワリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県北杜市高根町村山東割', '19', '19209', '4080019', '山梨県', 'ヤマナシケン', '北杜市', 'ホクトシ', '高根町村山東割', 'タカネチョウムラヤマヒガシワリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県北杜市長坂町長坂上条', '19', '19209', '4080021', '山梨県', 'ヤマナシケン', '北杜市', 'ホクトシ', '長坂町長坂上条', 'ナガサカチョウナガサカカミジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県北杜市長坂町塚川', '19', '19209', '4080022', '山梨県', 'ヤマナシケン', '北杜市', 'ホクトシ', '長坂町塚川', 'ナガサカチョウツカカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県北杜市長坂町渋沢', '19', '19209', '4080023', '山梨県', 'ヤマナシケン', '北杜市', 'ホクトシ', '長坂町渋沢', 'ナガサカチョウシブサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県北杜市長坂町富岡', '19', '19209', '4080024', '山梨県', 'ヤマナシケン', '北杜市', 'ホクトシ', '長坂町富岡', 'ナガサカチョウトミオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県北杜市長坂町長坂下条', '19', '19209', '4080025', '山梨県', 'ヤマナシケン', '北杜市', 'ホクトシ', '長坂町長坂下条', 'ナガサカチョウナガサカシモジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県北杜市長坂町日野', '19', '19209', '4080026', '山梨県', 'ヤマナシケン', '北杜市', 'ホクトシ', '長坂町日野', 'ナガサカチョウヒノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県北杜市長坂町小荒間', '19', '19209', '4080031', '山梨県', 'ヤマナシケン', '北杜市', 'ホクトシ', '長坂町小荒間', 'ナガサカチョウコアラマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県北杜市長坂町大井ケ森', '19', '19209', '4080032', '山梨県', 'ヤマナシケン', '北杜市', 'ホクトシ', '長坂町大井ケ森', 'ナガサカチョウオイガモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県北杜市長坂町白井沢', '19', '19209', '4080033', '山梨県', 'ヤマナシケン', '北杜市', 'ホクトシ', '長坂町白井沢', 'ナガサカチョウシロイザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県北杜市長坂町大八田', '19', '19209', '4080034', '山梨県', 'ヤマナシケン', '北杜市', 'ホクトシ', '長坂町大八田', 'ナガサカチョウオオバッタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県北杜市長坂町夏秋', '19', '19209', '4080035', '山梨県', 'ヤマナシケン', '北杜市', 'ホクトシ', '長坂町夏秋', 'ナガサカチョウナツアキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県北杜市長坂町中丸', '19', '19209', '4080036', '山梨県', 'ヤマナシケン', '北杜市', 'ホクトシ', '長坂町中丸', 'ナガサカチョウナカマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県北杜市長坂町中島', '19', '19209', '4080037', '山梨県', 'ヤマナシケン', '北杜市', 'ホクトシ', '長坂町中島', 'ナガサカチョウナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県北杜市小淵沢町上笹尾', '19', '19209', '4080041', '山梨県', 'ヤマナシケン', '北杜市', 'ホクトシ', '小淵沢町上笹尾', 'コブチサワチョウカミササオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県北杜市小淵沢町松向', '19', '19209', '4080042', '山梨県', 'ヤマナシケン', '北杜市', 'ホクトシ', '小淵沢町松向', 'コブチサワチョウショウコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県北杜市小淵沢町下笹尾', '19', '19209', '4080043', '山梨県', 'ヤマナシケン', '北杜市', 'ホクトシ', '小淵沢町下笹尾', 'コブチサワチョウシモササオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県北杜市小淵沢町', '19', '19209', '4080044', '山梨県', 'ヤマナシケン', '北杜市', 'ホクトシ', '小淵沢町', 'コブチサワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市清田区里塚1条', '01', '01110', '0040801', '北海道', 'ホッカイドウ', '札幌市清田区', 'サッポロシキヨタク', '里塚1条', 'サトヅカ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県北杜市須玉町小尾', '19', '19209', '4080101', '山梨県', 'ヤマナシケン', '北杜市', 'ホクトシ', '須玉町小尾', 'スタマチョウオビ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県北杜市須玉町比志', '19', '19209', '4080102', '山梨県', 'ヤマナシケン', '北杜市', 'ホクトシ', '須玉町比志', 'スタマチョウヒシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県北杜市須玉町江草', '19', '19209', '4080103', '山梨県', 'ヤマナシケン', '北杜市', 'ホクトシ', '須玉町江草', 'スタマチョウエグサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県北杜市須玉町小倉', '19', '19209', '4080104', '山梨県', 'ヤマナシケン', '北杜市', 'ホクトシ', '須玉町小倉', 'スタマチョウコゴエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県北杜市須玉町東向', '19', '19209', '4080105', '山梨県', 'ヤマナシケン', '北杜市', 'ホクトシ', '須玉町東向', 'スタマチョウヒガシムキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県北杜市須玉町穴平', '19', '19209', '4080111', '山梨県', 'ヤマナシケン', '北杜市', 'ホクトシ', '須玉町穴平', 'スタマチョウアナダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県北杜市須玉町若神子', '19', '19209', '4080112', '山梨県', 'ヤマナシケン', '北杜市', 'ホクトシ', '須玉町若神子', 'スタマチョウワカミコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県北杜市須玉町大蔵', '19', '19209', '4080113', '山梨県', 'ヤマナシケン', '北杜市', 'ホクトシ', '須玉町大蔵', 'スタマチョウオオクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県北杜市須玉町藤田', '19', '19209', '4080114', '山梨県', 'ヤマナシケン', '北杜市', 'ホクトシ', '須玉町藤田', 'スタマチョウトウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県北杜市須玉町大豆生田', '19', '19209', '4080115', '山梨県', 'ヤマナシケン', '北杜市', 'ホクトシ', '須玉町大豆生田', 'スタマチョウマミョウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県北杜市須玉町境之澤', '19', '19209', '4080116', '山梨県', 'ヤマナシケン', '北杜市', 'ホクトシ', '須玉町境之澤', 'スタマチョウサカイノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県北杜市須玉町若神子新町', '19', '19209', '4080117', '山梨県', 'ヤマナシケン', '北杜市', 'ホクトシ', '須玉町若神子新町', 'スタマチョウワカミコシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市清田区里塚2条', '01', '01110', '0040802', '北海道', 'ホッカイドウ', '札幌市清田区', 'サッポロシキヨタク', '里塚2条', 'サトヅカ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県北杜市明野町浅尾', '19', '19209', '4080201', '山梨県', 'ヤマナシケン', '北杜市', 'ホクトシ', '明野町浅尾', 'アケノチョウアサオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県北杜市明野町小笠原', '19', '19209', '4080202', '山梨県', 'ヤマナシケン', '北杜市', 'ホクトシ', '明野町小笠原', 'アケノチョウオガサハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県北杜市明野町三之蔵', '19', '19209', '4080203', '山梨県', 'ヤマナシケン', '北杜市', 'ホクトシ', '明野町三之蔵', 'アケノチョウサンノクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県北杜市明野町上手', '19', '19209', '4080204', '山梨県', 'ヤマナシケン', '北杜市', 'ホクトシ', '明野町上手', 'アケノチョウウエデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県北杜市明野町浅尾新田', '19', '19209', '4080205', '山梨県', 'ヤマナシケン', '北杜市', 'ホクトシ', '明野町浅尾新田', 'アケノチョウアサオシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県北杜市明野町下神取', '19', '19209', '4080206', '山梨県', 'ヤマナシケン', '北杜市', 'ホクトシ', '明野町下神取', 'アケノチョウシモカンドリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県北杜市明野町上神取', '19', '19209', '4080207', '山梨県', 'ヤマナシケン', '北杜市', 'ホクトシ', '明野町上神取', 'アケノチョウカミカンドリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市清田区里塚3条', '01', '01110', '0040803', '北海道', 'ホッカイドウ', '札幌市清田区', 'サッポロシキヨタク', '里塚3条', 'サトヅカ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県北杜市武川町三吹', '19', '19209', '4080301', '山梨県', 'ヤマナシケン', '北杜市', 'ホクトシ', '武川町三吹', 'ムカワチョウミフキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県北杜市武川町牧原', '19', '19209', '4080302', '山梨県', 'ヤマナシケン', '北杜市', 'ホクトシ', '武川町牧原', 'ムカワチョウマギノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県北杜市武川町宮脇', '19', '19209', '4080303', '山梨県', 'ヤマナシケン', '北杜市', 'ホクトシ', '武川町宮脇', 'ムカワチョウミヤノワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県北杜市武川町新奥', '19', '19209', '4080304', '山梨県', 'ヤマナシケン', '北杜市', 'ホクトシ', '武川町新奥', 'ムカワチョウシンオク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県北杜市武川町黒澤', '19', '19209', '4080305', '山梨県', 'ヤマナシケン', '北杜市', 'ホクトシ', '武川町黒澤', 'ムカワチョウクロサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県北杜市武川町山高', '19', '19209', '4080306', '山梨県', 'ヤマナシケン', '北杜市', 'ホクトシ', '武川町山高', 'ムカワチョウヤマタカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県北杜市武川町柳澤', '19', '19209', '4080307', '山梨県', 'ヤマナシケン', '北杜市', 'ホクトシ', '武川町柳澤', 'ムカワチョウヤナギサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県北杜市白州町花水', '19', '19209', '4080311', '山梨県', 'ヤマナシケン', '北杜市', 'ホクトシ', '白州町花水', 'ハクシュウチョウハナミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県北杜市白州町台ケ原', '19', '19209', '4080312', '山梨県', 'ヤマナシケン', '北杜市', 'ホクトシ', '白州町台ケ原', 'ハクシュウチョウダイガハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県北杜市白州町横手', '19', '19209', '4080313', '山梨県', 'ヤマナシケン', '北杜市', 'ホクトシ', '白州町横手', 'ハクシュウチョウヨコテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県北杜市白州町大坊', '19', '19209', '4080314', '山梨県', 'ヤマナシケン', '北杜市', 'ホクトシ', '白州町大坊', 'ハクシュウチョウダイボウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県北杜市白州町白須', '19', '19209', '4080315', '山梨県', 'ヤマナシケン', '北杜市', 'ホクトシ', '白州町白須', 'ハクシュウチョウシラス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県北杜市白州町鳥原', '19', '19209', '4080316', '山梨県', 'ヤマナシケン', '北杜市', 'ホクトシ', '白州町鳥原', 'ハクシュウチョウトリハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県北杜市白州町下教来石', '19', '19209', '4080317', '山梨県', 'ヤマナシケン', '北杜市', 'ホクトシ', '白州町下教来石', 'ハクシュウチョウシモキョウライシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県北杜市白州町上教来石', '19', '19209', '4080318', '山梨県', 'ヤマナシケン', '北杜市', 'ホクトシ', '白州町上教来石', 'ハクシュウチョウカミキョウライシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県北杜市白州町大武川', '19', '19209', '4080319', '山梨県', 'ヤマナシケン', '北杜市', 'ホクトシ', '白州町大武川', 'ハクシュウチョウオオムカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市清田区里塚4条', '01', '01110', '0040804', '北海道', 'ホッカイドウ', '札幌市清田区', 'サッポロシキヨタク', '里塚4条', 'サトヅカ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市清田区里塚緑ケ丘', '01', '01110', '0040805', '北海道', 'ホッカイドウ', '札幌市清田区', 'サッポロシキヨタク', '里塚緑ケ丘', 'サトヅカミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市清田区里塚', '01', '01110', '0040809', '北海道', 'ホッカイドウ', '札幌市清田区', 'サッポロシキヨタク', '里塚', 'サトヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市清田区美しが丘1条', '01', '01110', '0040811', '北海道', 'ホッカイドウ', '札幌市清田区', 'サッポロシキヨタク', '美しが丘1条', 'ウツクシガオカ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市清田区美しが丘2条', '01', '01110', '0040812', '北海道', 'ホッカイドウ', '札幌市清田区', 'サッポロシキヨタク', '美しが丘2条', 'ウツクシガオカ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市清田区美しが丘3条', '01', '01110', '0040813', '北海道', 'ホッカイドウ', '札幌市清田区', 'サッポロシキヨタク', '美しが丘3条', 'ウツクシガオカ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市清田区美しが丘4条', '01', '01110', '0040814', '北海道', 'ホッカイドウ', '札幌市清田区', 'サッポロシキヨタク', '美しが丘4条', 'ウツクシガオカ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市清田区美しが丘5条', '01', '01110', '0040815', '北海道', 'ホッカイドウ', '札幌市清田区', 'サッポロシキヨタク', '美しが丘5条', 'ウツクシガオカ05ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市清田区有明', '01', '01110', '0040821', '北海道', 'ホッカイドウ', '札幌市清田区', 'サッポロシキヨタク', '有明', 'アリアケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市清田区真栄1条', '01', '01110', '0040831', '北海道', 'ホッカイドウ', '札幌市清田区', 'サッポロシキヨタク', '真栄1条', 'シンエイ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市清田区真栄2条', '01', '01110', '0040832', '北海道', 'ホッカイドウ', '札幌市清田区', 'サッポロシキヨタク', '真栄2条', 'シンエイ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市清田区真栄3条', '01', '01110', '0040833', '北海道', 'ホッカイドウ', '札幌市清田区', 'サッポロシキヨタク', '真栄3条', 'シンエイ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市清田区真栄4条', '01', '01110', '0040834', '北海道', 'ホッカイドウ', '札幌市清田区', 'サッポロシキヨタク', '真栄4条', 'シンエイ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市清田区真栄5条', '01', '01110', '0040835', '北海道', 'ホッカイドウ', '札幌市清田区', 'サッポロシキヨタク', '真栄5条', 'シンエイ05ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市清田区真栄6条', '01', '01110', '0040836', '北海道', 'ホッカイドウ', '札幌市清田区', 'サッポロシキヨタク', '真栄6条', 'シンエイ06ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市清田区真栄', '01', '01110', '0040839', '北海道', 'ホッカイドウ', '札幌市清田区', 'サッポロシキヨタク', '真栄', 'シンエイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市清田区清田10条', '01', '01110', '0040840', '北海道', 'ホッカイドウ', '札幌市清田区', 'サッポロシキヨタク', '清田10条', 'キヨタ10ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市清田区清田1条', '01', '01110', '0040841', '北海道', 'ホッカイドウ', '札幌市清田区', 'サッポロシキヨタク', '清田1条', 'キヨタ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市清田区清田2条', '01', '01110', '0040842', '北海道', 'ホッカイドウ', '札幌市清田区', 'サッポロシキヨタク', '清田2条', 'キヨタ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市清田区清田3条', '01', '01110', '0040843', '北海道', 'ホッカイドウ', '札幌市清田区', 'サッポロシキヨタク', '清田3条', 'キヨタ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市清田区清田4条', '01', '01110', '0040844', '北海道', 'ホッカイドウ', '札幌市清田区', 'サッポロシキヨタク', '清田4条', 'キヨタ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市清田区清田5条', '01', '01110', '0040845', '北海道', 'ホッカイドウ', '札幌市清田区', 'サッポロシキヨタク', '清田5条', 'キヨタ05ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市清田区清田6条', '01', '01110', '0040846', '北海道', 'ホッカイドウ', '札幌市清田区', 'サッポロシキヨタク', '清田6条', 'キヨタ06ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市清田区清田7条', '01', '01110', '0040847', '北海道', 'ホッカイドウ', '札幌市清田区', 'サッポロシキヨタク', '清田7条', 'キヨタ07ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市清田区清田8条', '01', '01110', '0040848', '北海道', 'ホッカイドウ', '札幌市清田区', 'サッポロシキヨタク', '清田8条', 'キヨタ08ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市清田区清田9条', '01', '01110', '0040849', '北海道', 'ホッカイドウ', '札幌市清田区', 'サッポロシキヨタク', '清田9条', 'キヨタ09ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市清田区清田', '01', '01110', '0040859', '北海道', 'ホッカイドウ', '札幌市清田区', 'サッポロシキヨタク', '清田', 'キヨタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市清田区北野1条', '01', '01110', '0040861', '北海道', 'ホッカイドウ', '札幌市清田区', 'サッポロシキヨタク', '北野1条', 'キタノ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市清田区北野2条', '01', '01110', '0040862', '北海道', 'ホッカイドウ', '札幌市清田区', 'サッポロシキヨタク', '北野2条', 'キタノ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市清田区北野3条', '01', '01110', '0040863', '北海道', 'ホッカイドウ', '札幌市清田区', 'サッポロシキヨタク', '北野3条', 'キタノ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市清田区北野4条', '01', '01110', '0040864', '北海道', 'ホッカイドウ', '札幌市清田区', 'サッポロシキヨタク', '北野4条', 'キタノ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市清田区北野5条', '01', '01110', '0040865', '北海道', 'ホッカイドウ', '札幌市清田区', 'サッポロシキヨタク', '北野5条', 'キタノ05ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市清田区北野6条', '01', '01110', '0040866', '北海道', 'ホッカイドウ', '札幌市清田区', 'サッポロシキヨタク', '北野6条', 'キタノ06ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市清田区北野7条', '01', '01110', '0040867', '北海道', 'ホッカイドウ', '札幌市清田区', 'サッポロシキヨタク', '北野7条', 'キタノ07ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市清田区平岡1条', '01', '01110', '0040871', '北海道', 'ホッカイドウ', '札幌市清田区', 'サッポロシキヨタク', '平岡1条', 'ヒラオカ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市清田区平岡2条', '01', '01110', '0040872', '北海道', 'ホッカイドウ', '札幌市清田区', 'サッポロシキヨタク', '平岡2条', 'ヒラオカ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市清田区平岡3条', '01', '01110', '0040873', '北海道', 'ホッカイドウ', '札幌市清田区', 'サッポロシキヨタク', '平岡3条', 'ヒラオカ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市清田区平岡4条', '01', '01110', '0040874', '北海道', 'ホッカイドウ', '札幌市清田区', 'サッポロシキヨタク', '平岡4条', 'ヒラオカ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市清田区平岡5条', '01', '01110', '0040875', '北海道', 'ホッカイドウ', '札幌市清田区', 'サッポロシキヨタク', '平岡5条', 'ヒラオカ05ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市清田区平岡6条', '01', '01110', '0040876', '北海道', 'ホッカイドウ', '札幌市清田区', 'サッポロシキヨタク', '平岡6条', 'ヒラオカ06ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市清田区平岡7条', '01', '01110', '0040877', '北海道', 'ホッカイドウ', '札幌市清田区', 'サッポロシキヨタク', '平岡7条', 'ヒラオカ07ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市清田区平岡8条', '01', '01110', '0040878', '北海道', 'ホッカイドウ', '札幌市清田区', 'サッポロシキヨタク', '平岡8条', 'ヒラオカ08ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市清田区平岡9条', '01', '01110', '0040879', '北海道', 'ホッカイドウ', '札幌市清田区', 'サッポロシキヨタク', '平岡9条', 'ヒラオカ09ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市清田区平岡10条', '01', '01110', '0040880', '北海道', 'ホッカイドウ', '札幌市清田区', 'サッポロシキヨタク', '平岡10条', 'ヒラオカ10ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市清田区平岡公園', '01', '01110', '0040881', '北海道', 'ホッカイドウ', '札幌市清田区', 'サッポロシキヨタク', '平岡公園', 'ヒラオカコウエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市清田区平岡公園東', '01', '01110', '0040882', '北海道', 'ホッカイドウ', '札幌市清田区', 'サッポロシキヨタク', '平岡公園東', 'ヒラオカコウエンヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市清田区平岡', '01', '01110', '0040889', '北海道', 'ホッカイドウ', '札幌市清田区', 'サッポロシキヨタク', '平岡', 'ヒラオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県上野原市', '19', '19212', '4090100', '山梨県', 'ヤマナシケン', '上野原市', 'ウエノハラシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('36621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県上野原市棡原', '19', '19212', '4090111', '山梨県', 'ヤマナシケン', '上野原市', 'ウエノハラシ', '棡原', 'ユズリハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県上野原市上野原', '19', '19212', '4090112', '山梨県', 'ヤマナシケン', '上野原市', 'ウエノハラシ', '上野原', 'ウエノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県上野原市新田', '19', '19212', '4090113', '山梨県', 'ヤマナシケン', '上野原市', 'ウエノハラシ', '新田', 'アラタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県上野原市鶴島', '19', '19212', '4090114', '山梨県', 'ヤマナシケン', '上野原市', 'ウエノハラシ', '鶴島', 'ツルシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県上野原市松留', '19', '19212', '4090115', '山梨県', 'ヤマナシケン', '上野原市', 'ウエノハラシ', '松留', 'マツドメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県上野原市四方津', '19', '19212', '4090121', '山梨県', 'ヤマナシケン', '上野原市', 'ウエノハラシ', '四方津', 'シオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県上野原市川合', '19', '19212', '4090122', '山梨県', 'ヤマナシケン', '上野原市', 'ウエノハラシ', '川合', 'カワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県上野原市大野', '19', '19212', '4090123', '山梨県', 'ヤマナシケン', '上野原市', 'ウエノハラシ', '大野', 'オオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県上野原市犬目', '19', '19212', '4090124', '山梨県', 'ヤマナシケン', '上野原市', 'ウエノハラシ', '犬目', 'イヌメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県上野原市野田尻', '19', '19212', '4090125', '山梨県', 'ヤマナシケン', '上野原市', 'ウエノハラシ', '野田尻', 'ノタジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県上野原市コモアしおつ', '19', '19212', '4090126', '山梨県', 'ヤマナシケン', '上野原市', 'ウエノハラシ', 'コモアしおつ', 'コモアシオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県上野原市大曽根', '19', '19212', '4090131', '山梨県', 'ヤマナシケン', '上野原市', 'ウエノハラシ', '大曽根', 'オオゾネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県上野原市鶴川', '19', '19212', '4090132', '山梨県', 'ヤマナシケン', '上野原市', 'ウエノハラシ', '鶴川', 'ツルガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県上野原市八ツ沢', '19', '19212', '4090133', '山梨県', 'ヤマナシケン', '上野原市', 'ウエノハラシ', '八ツ沢', 'ヤツサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県上野原市大椚', '19', '19212', '4090134', '山梨県', 'ヤマナシケン', '上野原市', 'ウエノハラシ', '大椚', 'オオクヌギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県上野原市芦垣', '19', '19212', '4090135', '山梨県', 'ヤマナシケン', '上野原市', 'ウエノハラシ', '芦垣', 'アシガキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県上野原市桑久保', '19', '19212', '4090136', '山梨県', 'ヤマナシケン', '上野原市', 'ウエノハラシ', '桑久保', 'クワクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県上野原市和見', '19', '19212', '4090137', '山梨県', 'ヤマナシケン', '上野原市', 'ウエノハラシ', '和見', 'ワミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県上野原市大倉', '19', '19212', '4090138', '山梨県', 'ヤマナシケン', '上野原市', 'ウエノハラシ', '大倉', 'オオクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県上野原市西原', '19', '19212', '4090141', '山梨県', 'ヤマナシケン', '上野原市', 'ウエノハラシ', '西原', 'サイハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県北都留郡小菅村小菅村', '19', '19442', '4090142', '山梨県', 'ヤマナシケン', '北都留郡小菅村', 'キタツルグンコスゲムラ', '小菅村', 'コスゲムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県北都留郡小菅村', '19', '19442', '4090200', '山梨県', 'ヤマナシケン', '北都留郡小菅村', 'キタツルグンコスゲムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('36647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県北都留郡小菅村小菅村', '19', '19442', '4090211', '山梨県', 'ヤマナシケン', '北都留郡小菅村', 'キタツルグンコスゲムラ', '小菅村', 'コスゲムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県北都留郡丹波山村', '19', '19443', '4090300', '山梨県', 'ヤマナシケン', '北都留郡丹波山村', 'キタツルグンタバヤマムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('36649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県北都留郡丹波山村奥秋', '19', '19443', '4090301', '山梨県', 'ヤマナシケン', '北都留郡丹波山村', 'キタツルグンタバヤマムラ', '奥秋', 'オクアキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県北都留郡丹波山村上組', '19', '19443', '4090302', '山梨県', 'ヤマナシケン', '北都留郡丹波山村', 'キタツルグンタバヤマムラ', '上組', 'カミグミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県北都留郡丹波山村中組', '19', '19443', '4090303', '山梨県', 'ヤマナシケン', '北都留郡丹波山村', 'キタツルグンタバヤマムラ', '中組', 'ナカグミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県北都留郡丹波山村下組', '19', '19443', '4090304', '山梨県', 'ヤマナシケン', '北都留郡丹波山村', 'キタツルグンタバヤマムラ', '下組', 'シモグミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県北都留郡丹波山村高尾', '19', '19443', '4090305', '山梨県', 'ヤマナシケン', '北都留郡丹波山村', 'キタツルグンタバヤマムラ', '高尾', 'タカオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県北都留郡丹波山村押垣外', '19', '19443', '4090306', '山梨県', 'ヤマナシケン', '北都留郡丹波山村', 'キタツルグンタバヤマムラ', '押垣外', 'オシガイト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県北都留郡丹波山村保之瀬', '19', '19443', '4090311', '山梨県', 'ヤマナシケン', '北都留郡丹波山村', 'キタツルグンタバヤマムラ', '保之瀬', 'ホノセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県北都留郡丹波山村高畑', '19', '19443', '4090312', '山梨県', 'ヤマナシケン', '北都留郡丹波山村', 'キタツルグンタバヤマムラ', '高畑', 'タカハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県北都留郡丹波山村親川', '19', '19443', '4090313', '山梨県', 'ヤマナシケン', '北都留郡丹波山村', 'キタツルグンタバヤマムラ', '親川', 'オヤガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県北都留郡丹波山村御祭', '19', '19443', '4090314', '山梨県', 'ヤマナシケン', '北都留郡丹波山村', 'キタツルグンタバヤマムラ', '御祭', 'オマツリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県北都留郡丹波山村杉奈久保', '19', '19443', '4090315', '山梨県', 'ヤマナシケン', '北都留郡丹波山村', 'キタツルグンタバヤマムラ', '杉奈久保', 'スギナクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県北都留郡丹波山村所畑', '19', '19443', '4090316', '山梨県', 'ヤマナシケン', '北都留郡丹波山村', 'キタツルグンタバヤマムラ', '所畑', 'トコロハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県北都留郡丹波山村小袖', '19', '19443', '4090317', '山梨県', 'ヤマナシケン', '北都留郡丹波山村', 'キタツルグンタバヤマムラ', '小袖', 'コソデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県北都留郡丹波山村鴨沢', '19', '19443', '4090318', '山梨県', 'ヤマナシケン', '北都留郡丹波山村', 'キタツルグンタバヤマムラ', '鴨沢', 'カモサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県大月市富浜町宮谷', '19', '19206', '4090501', '山梨県', 'ヤマナシケン', '大月市', 'オオツキシ', '富浜町宮谷', 'トミハママチミヤタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県大月市富浜町鳥沢', '19', '19206', '4090502', '山梨県', 'ヤマナシケン', '大月市', 'オオツキシ', '富浜町鳥沢', 'トミハママチトリサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県大月市梁川町綱の上', '19', '19206', '4090503', '山梨県', 'ヤマナシケン', '大月市', 'オオツキシ', '梁川町綱の上', 'ヤナガワマチツナノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県大月市梁川町新倉', '19', '19206', '4090504', '山梨県', 'ヤマナシケン', '大月市', 'オオツキシ', '梁川町新倉', 'ヤナガワマチアラクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県大月市梁川町塩瀬', '19', '19206', '4090505', '山梨県', 'ヤマナシケン', '大月市', 'オオツキシ', '梁川町塩瀬', 'ヤナガワマチシオゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県大月市梁川町立野', '19', '19206', '4090506', '山梨県', 'ヤマナシケン', '大月市', 'オオツキシ', '梁川町立野', 'ヤナガワマチタチノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県大月市猿橋町小篠', '19', '19206', '4090611', '山梨県', 'ヤマナシケン', '大月市', 'オオツキシ', '猿橋町小篠', 'サルハシマチオシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県大月市猿橋町藤崎', '19', '19206', '4090612', '山梨県', 'ヤマナシケン', '大月市', 'オオツキシ', '猿橋町藤崎', 'サルハシマチフジサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県大月市猿橋町伊良原', '19', '19206', '4090613', '山梨県', 'ヤマナシケン', '大月市', 'オオツキシ', '猿橋町伊良原', 'サルハシマチイラバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県大月市猿橋町猿橋', '19', '19206', '4090614', '山梨県', 'ヤマナシケン', '大月市', 'オオツキシ', '猿橋町猿橋', 'サルハシマチサルハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県大月市猿橋町朝日小沢', '19', '19206', '4090615', '山梨県', 'ヤマナシケン', '大月市', 'オオツキシ', '猿橋町朝日小沢', 'サルハシマチアサヒオザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県大月市猿橋町小沢', '19', '19206', '4090616', '山梨県', 'ヤマナシケン', '大月市', 'オオツキシ', '猿橋町小沢', 'サルハシマチオザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県大月市猿橋町殿上', '19', '19206', '4090617', '山梨県', 'ヤマナシケン', '大月市', 'オオツキシ', '猿橋町殿上', 'サルハシマチトノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県大月市猿橋町桂台', '19', '19206', '4090618', '山梨県', 'ヤマナシケン', '大月市', 'オオツキシ', '猿橋町桂台', 'サルハシマチカツラダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県大月市七保町浅川', '19', '19206', '4090621', '山梨県', 'ヤマナシケン', '大月市', 'オオツキシ', '七保町浅川', 'ナナホマチアサカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県大月市七保町下和田', '19', '19206', '4090622', '山梨県', 'ヤマナシケン', '大月市', 'オオツキシ', '七保町下和田', 'ナナホマチシモワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県大月市七保町葛野', '19', '19206', '4090623', '山梨県', 'ヤマナシケン', '大月市', 'オオツキシ', '七保町葛野', 'ナナホマチカズノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県大月市七保町林', '19', '19206', '4090624', '山梨県', 'ヤマナシケン', '大月市', 'オオツキシ', '七保町林', 'ナナホマチハヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県大月市七保町奈良子', '19', '19206', '4090625', '山梨県', 'ヤマナシケン', '大月市', 'オオツキシ', '七保町奈良子', 'ナナホマチナラゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県大月市七保町瀬戸', '19', '19206', '4090626', '山梨県', 'ヤマナシケン', '大月市', 'オオツキシ', '七保町瀬戸', 'ナナホマチセト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県大月市七保町駒宮', '19', '19206', '4090627', '山梨県', 'ヤマナシケン', '大月市', 'オオツキシ', '七保町駒宮', 'ナナホマチコマミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲州市大和町木賊', '19', '19213', '4091201', '山梨県', 'ヤマナシケン', '甲州市', 'コウシュウシ', '大和町木賊', 'ヤマトチョウトクサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲州市大和町田野', '19', '19213', '4091202', '山梨県', 'ヤマナシケン', '甲州市', 'コウシュウシ', '大和町田野', 'ヤマトチョウタノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲州市大和町初鹿野', '19', '19213', '4091203', '山梨県', 'ヤマナシケン', '甲州市', 'コウシュウシ', '大和町初鹿野', 'ヤマトチョウハジカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲州市大和町日影', '19', '19213', '4091204', '山梨県', 'ヤマナシケン', '甲州市', 'コウシュウシ', '大和町日影', 'ヤマトチョウヒカゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲州市大和町鶴瀬', '19', '19213', '4091205', '山梨県', 'ヤマナシケン', '甲州市', 'コウシュウシ', '大和町鶴瀬', 'ヤマトチョウツルセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲州市塩山上萩原', '19', '19213', '4091211', '山梨県', 'ヤマナシケン', '甲州市', 'コウシュウシ', '塩山上萩原', 'エンザンカミハギハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲州市塩山上萩原すずらん荘', '19', '19213', '4091211', '山梨県', 'ヤマナシケン', '甲州市', 'コウシュウシ', '塩山上萩原', 'エンザンカミハギハラ', null, null, 'すずらん荘', 'スズランソウ');
INSERT INTO `ms_addresses` VALUES ('36691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲州市塩山上萩原東電上部ダム', '19', '19213', '4091211', '山梨県', 'ヤマナシケン', '甲州市', 'コウシュウシ', '塩山上萩原', 'エンザンカミハギハラ', null, null, '東電上部ダム', 'トウデンジョウブダム');
INSERT INTO `ms_addresses` VALUES ('36692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲州市塩山中萩原日川小屋', '19', '19213', '4091212', '山梨県', 'ヤマナシケン', '甲州市', 'コウシュウシ', '塩山中萩原', 'エンザンナカハギハラ', null, null, '日川小屋', 'ヒカワコヤ');
INSERT INTO `ms_addresses` VALUES ('36693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲州市塩山牛奥', '19', '19213', '4091213', '山梨県', 'ヤマナシケン', '甲州市', 'コウシュウシ', '塩山牛奥', 'エンザンウシオク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲州市塩山牛奥奥野田開拓', '19', '19213', '4091213', '山梨県', 'ヤマナシケン', '甲州市', 'コウシュウシ', '塩山牛奥', 'エンザンウシオク', null, null, '奥野田開拓', 'オクノタカイタク');
INSERT INTO `ms_addresses` VALUES ('36695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲州市塩山牛奥嵯峨塩温泉', '19', '19213', '4091213', '山梨県', 'ヤマナシケン', '甲州市', 'コウシュウシ', '塩山牛奥', 'エンザンウシオク', null, null, '嵯峨塩温泉', 'サガシオオンセン');
INSERT INTO `ms_addresses` VALUES ('36696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲州市塩山牛奥嵯峨塩開拓', '19', '19213', '4091213', '山梨県', 'ヤマナシケン', '甲州市', 'コウシュウシ', '塩山牛奥', 'エンザンウシオク', null, null, '嵯峨塩開拓', 'サガシオカイタク');
INSERT INTO `ms_addresses` VALUES ('36698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲州市勝沼町中原', '19', '19213', '4091301', '山梨県', 'ヤマナシケン', '甲州市', 'コウシュウシ', '勝沼町中原', 'カツヌマチョウナカハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲州市勝沼町菱山', '19', '19213', '4091302', '山梨県', 'ヤマナシケン', '甲州市', 'コウシュウシ', '勝沼町菱山', 'カツヌマチョウヒシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲州市勝沼町小佐手', '19', '19213', '4091303', '山梨県', 'ヤマナシケン', '甲州市', 'コウシュウシ', '勝沼町小佐手', 'カツヌマチョウオサデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲州市勝沼町休息', '19', '19213', '4091304', '山梨県', 'ヤマナシケン', '甲州市', 'コウシュウシ', '勝沼町休息', 'カツヌマチョウキュウソク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲州市勝沼町綿塚', '19', '19213', '4091305', '山梨県', 'ヤマナシケン', '甲州市', 'コウシュウシ', '勝沼町綿塚', 'カツヌマチョウワタヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲州市勝沼町山', '19', '19213', '4091306', '山梨県', 'ヤマナシケン', '甲州市', 'コウシュウシ', '勝沼町山', 'カツヌマチョウヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲州市勝沼町深沢', '19', '19213', '4091311', '山梨県', 'ヤマナシケン', '甲州市', 'コウシュウシ', '勝沼町深沢', 'カツヌマチョウフカサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲州市勝沼町上岩崎', '19', '19213', '4091312', '山梨県', 'ヤマナシケン', '甲州市', 'コウシュウシ', '勝沼町上岩崎', 'カツヌマチョウカミイワサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲州市勝沼町下岩崎', '19', '19213', '4091313', '山梨県', 'ヤマナシケン', '甲州市', 'コウシュウシ', '勝沼町下岩崎', 'カツヌマチョウシモイワサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲州市勝沼町藤井', '19', '19213', '4091314', '山梨県', 'ヤマナシケン', '甲州市', 'コウシュウシ', '勝沼町藤井', 'カツヌマチョウフジイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲州市勝沼町等々力', '19', '19213', '4091315', '山梨県', 'ヤマナシケン', '甲州市', 'コウシュウシ', '勝沼町等々力', 'カツヌマチョウトドロキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲州市勝沼町勝沼', '19', '19213', '4091316', '山梨県', 'ヤマナシケン', '甲州市', 'コウシュウシ', '勝沼町勝沼', 'カツヌマチョウカツヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲州市塩山牛奥', '19', '19213', '4091321', '山梨県', 'ヤマナシケン', '甲州市', 'コウシュウシ', '塩山牛奥', 'エンザンウシオク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県北杜市大泉町西井出', '19', '19209', '4091501', '山梨県', 'ヤマナシケン', '北杜市', 'ホクトシ', '大泉町西井出', 'オオイズミチョウニシイデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県北杜市大泉町谷戸', '19', '19209', '4091502', '山梨県', 'ヤマナシケン', '北杜市', 'ホクトシ', '大泉町谷戸', 'オオイズミチョウヤト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡南部町', '19', '19366', '4092100', '山梨県', 'ヤマナシケン', '南巨摩郡南部町', 'ミナミコマグンナンブチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('36715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡南部町楮根', '19', '19366', '4092101', '山梨県', 'ヤマナシケン', '南巨摩郡南部町', 'ミナミコマグンナンブチョウ', '楮根', 'カゾネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡南部町福士', '19', '19366', '4092102', '山梨県', 'ヤマナシケン', '南巨摩郡南部町', 'ミナミコマグンナンブチョウ', '福士', 'フクシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡南部町万沢', '19', '19366', '4092103', '山梨県', 'ヤマナシケン', '南巨摩郡南部町', 'ミナミコマグンナンブチョウ', '万沢', 'マンザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡南部町中野', '19', '19366', '4092211', '山梨県', 'ヤマナシケン', '南巨摩郡南部町', 'ミナミコマグンナンブチョウ', '中野', 'ナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡南部町南部', '19', '19366', '4092212', '山梨県', 'ヤマナシケン', '南巨摩郡南部町', 'ミナミコマグンナンブチョウ', '南部', 'ナンブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡南部町大和', '19', '19366', '4092213', '山梨県', 'ヤマナシケン', '南巨摩郡南部町', 'ミナミコマグンナンブチョウ', '大和', 'オオワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡南部町塩沢', '19', '19366', '4092214', '山梨県', 'ヤマナシケン', '南巨摩郡南部町', 'ミナミコマグンナンブチョウ', '塩沢', 'シオザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡南部町柳島', '19', '19366', '4092215', '山梨県', 'ヤマナシケン', '南巨摩郡南部町', 'ミナミコマグンナンブチョウ', '柳島', 'ヤナギシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡南部町成島', '19', '19366', '4092216', '山梨県', 'ヤマナシケン', '南巨摩郡南部町', 'ミナミコマグンナンブチョウ', '成島', 'ナルシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡南部町本郷', '19', '19366', '4092217', '山梨県', 'ヤマナシケン', '南巨摩郡南部町', 'ミナミコマグンナンブチョウ', '本郷', 'ホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡南部町上佐野', '19', '19366', '4092301', '山梨県', 'ヤマナシケン', '南巨摩郡南部町', 'ミナミコマグンナンブチョウ', '上佐野', 'カミサノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡南部町下佐野', '19', '19366', '4092302', '山梨県', 'ヤマナシケン', '南巨摩郡南部町', 'ミナミコマグンナンブチョウ', '下佐野', 'シモサノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡南部町十島', '19', '19366', '4092303', '山梨県', 'ヤマナシケン', '南巨摩郡南部町', 'ミナミコマグンナンブチョウ', '十島', 'トオシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡南部町井出', '19', '19366', '4092304', '山梨県', 'ヤマナシケン', '南巨摩郡南部町', 'ミナミコマグンナンブチョウ', '井出', 'イデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡南部町内船', '19', '19366', '4092305', '山梨県', 'ヤマナシケン', '南巨摩郡南部町', 'ミナミコマグンナンブチョウ', '内船', 'ウツブナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡身延町上八木沢', '19', '19365', '4092401', '山梨県', 'ヤマナシケン', '南巨摩郡身延町', 'ミナミコマグンミノブチョウ', '上八木沢', 'カミヤギサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡身延町下八木沢', '19', '19365', '4092402', '山梨県', 'ヤマナシケン', '南巨摩郡身延町', 'ミナミコマグンミノブチョウ', '下八木沢', 'シモヤギサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡身延町帯金', '19', '19365', '4092403', '山梨県', 'ヤマナシケン', '南巨摩郡身延町', 'ミナミコマグンミノブチョウ', '帯金', 'オビカネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡身延町大垈', '19', '19365', '4092404', '山梨県', 'ヤマナシケン', '南巨摩郡身延町', 'ミナミコマグンミノブチョウ', '大垈', 'オオヌタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡身延町椿草里', '19', '19365', '4092405', '山梨県', 'ヤマナシケン', '南巨摩郡身延町', 'ミナミコマグンミノブチョウ', '椿草里', 'ツバキゾウリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡身延町大崩', '19', '19365', '4092406', '山梨県', 'ヤマナシケン', '南巨摩郡身延町', 'ミナミコマグンミノブチョウ', '大崩', 'オオクズレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡身延町丸滝', '19', '19365', '4092411', '山梨県', 'ヤマナシケン', '南巨摩郡身延町', 'ミナミコマグンミノブチョウ', '丸滝', 'マルタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡身延町角打', '19', '19365', '4092412', '山梨県', 'ヤマナシケン', '南巨摩郡身延町', 'ミナミコマグンミノブチョウ', '角打', 'ツノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡身延町和田', '19', '19365', '4092413', '山梨県', 'ヤマナシケン', '南巨摩郡身延町', 'ミナミコマグンミノブチョウ', '和田', 'ワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡身延町樋之上', '19', '19365', '4092414', '山梨県', 'ヤマナシケン', '南巨摩郡身延町', 'ミナミコマグンミノブチョウ', '樋之上', 'ヒノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡身延町大島', '19', '19365', '4092415', '山梨県', 'ヤマナシケン', '南巨摩郡身延町', 'ミナミコマグンミノブチョウ', '大島', 'オオシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡身延町', '19', '19365', '4092500', '山梨県', 'ヤマナシケン', '南巨摩郡身延町', 'ミナミコマグンミノブチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('36748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡身延町粟倉', '19', '19365', '4092521', '山梨県', 'ヤマナシケン', '南巨摩郡身延町', 'ミナミコマグンミノブチョウ', '粟倉', 'アワグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡身延町下山', '19', '19365', '4092522', '山梨県', 'ヤマナシケン', '南巨摩郡身延町', 'ミナミコマグンミノブチョウ', '下山', 'シモヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡身延町波木井', '19', '19365', '4092523', '山梨県', 'ヤマナシケン', '南巨摩郡身延町', 'ミナミコマグンミノブチョウ', '波木井', 'ハキイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡身延町身延', '19', '19365', '4092524', '山梨県', 'ヤマナシケン', '南巨摩郡身延町', 'ミナミコマグンミノブチョウ', '身延', 'ミノブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡身延町梅平', '19', '19365', '4092531', '山梨県', 'ヤマナシケン', '南巨摩郡身延町', 'ミナミコマグンミノブチョウ', '梅平', 'ウメダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡身延町大野', '19', '19365', '4092532', '山梨県', 'ヤマナシケン', '南巨摩郡身延町', 'ミナミコマグンミノブチョウ', '大野', 'オオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡身延町清子', '19', '19365', '4092533', '山梨県', 'ヤマナシケン', '南巨摩郡身延町', 'ミナミコマグンミノブチョウ', '清子', 'セイゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡身延町光子沢', '19', '19365', '4092534', '山梨県', 'ヤマナシケン', '南巨摩郡身延町', 'ミナミコマグンミノブチョウ', '光子沢', 'ミツゴザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡身延町横根中', '19', '19365', '4092535', '山梨県', 'ヤマナシケン', '南巨摩郡身延町', 'ミナミコマグンミノブチョウ', '横根中', 'ヨコネナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡身延町相又', '19', '19365', '4092536', '山梨県', 'ヤマナシケン', '南巨摩郡身延町', 'ミナミコマグンミノブチョウ', '相又', 'アイマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡身延町大城', '19', '19365', '4092537', '山梨県', 'ヤマナシケン', '南巨摩郡身延町', 'ミナミコマグンミノブチョウ', '大城', 'オオジロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡身延町門野', '19', '19365', '4092538', '山梨県', 'ヤマナシケン', '南巨摩郡身延町', 'ミナミコマグンミノブチョウ', '門野', 'カドノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡身延町小田船原', '19', '19365', '4092539', '山梨県', 'ヤマナシケン', '南巨摩郡身延町', 'ミナミコマグンミノブチョウ', '小田船原', 'オダフナハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡早川町', '19', '19364', '4092700', '山梨県', 'ヤマナシケン', '南巨摩郡早川町', 'ミナミコマグンハヤカワチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('36766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡早川町奈良田', '19', '19364', '4092701', '山梨県', 'ヤマナシケン', '南巨摩郡早川町', 'ミナミコマグンハヤカワチョウ', '奈良田', 'ナラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡早川町湯島', '19', '19364', '4092702', '山梨県', 'ヤマナシケン', '南巨摩郡早川町', 'ミナミコマグンハヤカワチョウ', '湯島', 'ユジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡早川町新倉', '19', '19364', '4092703', '山梨県', 'ヤマナシケン', '南巨摩郡早川町', 'ミナミコマグンハヤカワチョウ', '新倉', 'アラクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡早川町大原野', '19', '19364', '4092704', '山梨県', 'ヤマナシケン', '南巨摩郡早川町', 'ミナミコマグンハヤカワチョウ', '大原野', 'オオハラノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡早川町早川', '19', '19364', '4092705', '山梨県', 'ヤマナシケン', '南巨摩郡早川町', 'ミナミコマグンハヤカワチョウ', '早川', 'ハヤカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡早川町黒桂', '19', '19364', '4092711', '山梨県', 'ヤマナシケン', '南巨摩郡早川町', 'ミナミコマグンハヤカワチョウ', '黒桂', 'ツヅラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡早川町西之宮', '19', '19364', '4092712', '山梨県', 'ヤマナシケン', '南巨摩郡早川町', 'ミナミコマグンハヤカワチョウ', '西之宮', 'ニシノミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡早川町保', '19', '19364', '4092713', '山梨県', 'ヤマナシケン', '南巨摩郡早川町', 'ミナミコマグンハヤカワチョウ', '保', 'ホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡早川町草塩', '19', '19364', '4092714', '山梨県', 'ヤマナシケン', '南巨摩郡早川町', 'ミナミコマグンハヤカワチョウ', '草塩', 'クサシオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡早川町京ケ島', '19', '19364', '4092715', '山梨県', 'ヤマナシケン', '南巨摩郡早川町', 'ミナミコマグンハヤカワチョウ', '京ケ島', 'キョウガシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡早川町塩之上', '19', '19364', '4092721', '山梨県', 'ヤマナシケン', '南巨摩郡早川町', 'ミナミコマグンハヤカワチョウ', '塩之上', 'シオノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡早川町笹走', '19', '19364', '4092722', '山梨県', 'ヤマナシケン', '南巨摩郡早川町', 'ミナミコマグンハヤカワチョウ', '笹走', 'ササバシリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡早川町榑坪', '19', '19364', '4092723', '山梨県', 'ヤマナシケン', '南巨摩郡早川町', 'ミナミコマグンハヤカワチョウ', '榑坪', 'クレツボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡早川町初鹿島', '19', '19364', '4092724', '山梨県', 'ヤマナシケン', '南巨摩郡早川町', 'ミナミコマグンハヤカワチョウ', '初鹿島', 'ハジカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡早川町小縄', '19', '19364', '4092725', '山梨県', 'ヤマナシケン', '南巨摩郡早川町', 'ミナミコマグンハヤカワチョウ', '小縄', 'コナワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡早川町千須和', '19', '19364', '4092726', '山梨県', 'ヤマナシケン', '南巨摩郡早川町', 'ミナミコマグンハヤカワチョウ', '千須和', 'センズワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡早川町薬袋', '19', '19364', '4092727', '山梨県', 'ヤマナシケン', '南巨摩郡早川町', 'ミナミコマグンハヤカワチョウ', '薬袋', 'ミナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡早川町大島', '19', '19364', '4092731', '山梨県', 'ヤマナシケン', '南巨摩郡早川町', 'ミナミコマグンハヤカワチョウ', '大島', 'オオシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡早川町高住', '19', '19364', '4092732', '山梨県', 'ヤマナシケン', '南巨摩郡早川町', 'ミナミコマグンハヤカワチョウ', '高住', 'コウジュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡早川町赤沢', '19', '19364', '4092733', '山梨県', 'ヤマナシケン', '南巨摩郡早川町', 'ミナミコマグンハヤカワチョウ', '赤沢', 'アカサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡早川町雨畑', '19', '19364', '4092734', '山梨県', 'ヤマナシケン', '南巨摩郡早川町', 'ミナミコマグンハヤカワチョウ', '雨畑', 'アメハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡身延町北川', '19', '19365', '4092931', '山梨県', 'ヤマナシケン', '南巨摩郡身延町', 'ミナミコマグンミノブチョウ', '北川', 'キタガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡身延町杉山', '19', '19365', '4092932', '山梨県', 'ヤマナシケン', '南巨摩郡身延町', 'ミナミコマグンミノブチョウ', '杉山', 'スギヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡身延町岩欠', '19', '19365', '4092933', '山梨県', 'ヤマナシケン', '南巨摩郡身延町', 'ミナミコマグンミノブチョウ', '岩欠', 'イワカケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡身延町大炊平', '19', '19365', '4092934', '山梨県', 'ヤマナシケン', '南巨摩郡身延町', 'ミナミコマグンミノブチョウ', '大炊平', 'オイダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡身延町清沢', '19', '19365', '4092935', '山梨県', 'ヤマナシケン', '南巨摩郡身延町', 'ミナミコマグンミノブチョウ', '清沢', 'キヨザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡身延町常葉', '19', '19365', '4092936', '山梨県', 'ヤマナシケン', '南巨摩郡身延町', 'ミナミコマグンミノブチョウ', '常葉', 'トキワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡身延町一色', '19', '19365', '4092937', '山梨県', 'ヤマナシケン', '南巨摩郡身延町', 'ミナミコマグンミノブチョウ', '一色', 'イッシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡身延町市之瀬', '19', '19365', '4092938', '山梨県', 'ヤマナシケン', '南巨摩郡身延町', 'ミナミコマグンミノブチョウ', '市之瀬', 'イチノセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡身延町湯之奥', '19', '19365', '4092941', '山梨県', 'ヤマナシケン', '南巨摩郡身延町', 'ミナミコマグンミノブチョウ', '湯之奥', 'ユノオク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡身延町下部', '19', '19365', '4092942', '山梨県', 'ヤマナシケン', '南巨摩郡身延町', 'ミナミコマグンミノブチョウ', '下部', 'シモベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡身延町川向', '19', '19365', '4092943', '山梨県', 'ヤマナシケン', '南巨摩郡身延町', 'ミナミコマグンミノブチョウ', '川向', 'カワムキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡身延町桃ケ窪', '19', '19365', '4092944', '山梨県', 'ヤマナシケン', '南巨摩郡身延町', 'ミナミコマグンミノブチョウ', '桃ケ窪', 'モモガクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡身延町波高島', '19', '19365', '4092945', '山梨県', 'ヤマナシケン', '南巨摩郡身延町', 'ミナミコマグンミノブチョウ', '波高島', 'ハダカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡身延町大子', '19', '19365', '4092946', '山梨県', 'ヤマナシケン', '南巨摩郡身延町', 'ミナミコマグンミノブチョウ', '大子', 'ダイゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡身延町上之平', '19', '19365', '4092947', '山梨県', 'ヤマナシケン', '南巨摩郡身延町', 'ミナミコマグンミノブチョウ', '上之平', 'ウエノタイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡身延町折門', '19', '19365', '4093101', '山梨県', 'ヤマナシケン', '南巨摩郡身延町', 'ミナミコマグンミノブチョウ', '折門', 'オリカド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡身延町八坂', '19', '19365', '4093102', '山梨県', 'ヤマナシケン', '南巨摩郡身延町', 'ミナミコマグンミノブチョウ', '八坂', 'ハッサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡身延町根子', '19', '19365', '4093103', '山梨県', 'ヤマナシケン', '南巨摩郡身延町', 'ミナミコマグンミノブチョウ', '根子', 'ネッコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡身延町中之倉', '19', '19365', '4093104', '山梨県', 'ヤマナシケン', '南巨摩郡身延町', 'ミナミコマグンミノブチョウ', '中之倉', 'ナカノクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡身延町釜額', '19', '19365', '4093105', '山梨県', 'ヤマナシケン', '南巨摩郡身延町', 'ミナミコマグンミノブチョウ', '釜額', 'カマヒタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡身延町古関', '19', '19365', '4093106', '山梨県', 'ヤマナシケン', '南巨摩郡身延町', 'ミナミコマグンミノブチョウ', '古関', 'フルセキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡身延町瀬戸', '19', '19365', '4093107', '山梨県', 'ヤマナシケン', '南巨摩郡身延町', 'ミナミコマグンミノブチョウ', '瀬戸', 'セト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡身延町大磯小磯', '19', '19365', '4093111', '山梨県', 'ヤマナシケン', '南巨摩郡身延町', 'ミナミコマグンミノブチョウ', '大磯小磯', 'オオイソコイソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡身延町芝草', '19', '19365', '4093112', '山梨県', 'ヤマナシケン', '南巨摩郡身延町', 'ミナミコマグンミノブチョウ', '芝草', 'シバクサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡身延町水船', '19', '19365', '4093113', '山梨県', 'ヤマナシケン', '南巨摩郡身延町', 'ミナミコマグンミノブチョウ', '水船', 'ミズフネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡身延町道', '19', '19365', '4093114', '山梨県', 'ヤマナシケン', '南巨摩郡身延町', 'ミナミコマグンミノブチョウ', '道', 'ミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡身延町切房木', '19', '19365', '4093115', '山梨県', 'ヤマナシケン', '南巨摩郡身延町', 'ミナミコマグンミノブチョウ', '切房木', 'キリフサギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡身延町車田', '19', '19365', '4093116', '山梨県', 'ヤマナシケン', '南巨摩郡身延町', 'ミナミコマグンミノブチョウ', '車田', 'クルマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡身延町三沢', '19', '19365', '4093117', '山梨県', 'ヤマナシケン', '南巨摩郡身延町', 'ミナミコマグンミノブチョウ', '三沢', 'ミサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡身延町上田原', '19', '19365', '4093118', '山梨県', 'ヤマナシケン', '南巨摩郡身延町', 'ミナミコマグンミノブチョウ', '上田原', 'カミタンバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡身延町大山', '19', '19365', '4093121', '山梨県', 'ヤマナシケン', '南巨摩郡身延町', 'ミナミコマグンミノブチョウ', '大山', 'オオヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡身延町久保', '19', '19365', '4093122', '山梨県', 'ヤマナシケン', '南巨摩郡身延町', 'ミナミコマグンミノブチョウ', '久保', 'クボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡身延町熊沢', '19', '19365', '4093123', '山梨県', 'ヤマナシケン', '南巨摩郡身延町', 'ミナミコマグンミノブチョウ', '熊沢', 'クマザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡身延町樋田', '19', '19365', '4093124', '山梨県', 'ヤマナシケン', '南巨摩郡身延町', 'ミナミコマグンミノブチョウ', '樋田', 'トイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡身延町嶺', '19', '19365', '4093125', '山梨県', 'ヤマナシケン', '南巨摩郡身延町', 'ミナミコマグンミノブチョウ', '嶺', 'ミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡身延町山家', '19', '19365', '4093126', '山梨県', 'ヤマナシケン', '南巨摩郡身延町', 'ミナミコマグンミノブチョウ', '山家', 'ヤマガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県西八代郡市川三郷町落居', '19', '19346', '4093231', '山梨県', 'ヤマナシケン', '西八代郡市川三郷町', 'ニシヤツシログンイチカワミサトチョウ', '落居', 'オチイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県西八代郡市川三郷町寺所', '19', '19346', '4093232', '山梨県', 'ヤマナシケン', '西八代郡市川三郷町', 'ニシヤツシログンイチカワミサトチョウ', '寺所', 'テラドコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県西八代郡市川三郷町五八', '19', '19346', '4093233', '山梨県', 'ヤマナシケン', '西八代郡市川三郷町', 'ニシヤツシログンイチカワミサトチョウ', '五八', 'ゴハチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県西八代郡市川三郷町岩下', '19', '19346', '4093234', '山梨県', 'ヤマナシケン', '西八代郡市川三郷町', 'ニシヤツシログンイチカワミサトチョウ', '岩下', 'イワシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県西八代郡市川三郷町葛籠沢', '19', '19346', '4093241', '山梨県', 'ヤマナシケン', '西八代郡市川三郷町', 'ニシヤツシログンイチカワミサトチョウ', '葛籠沢', 'ツヅラサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県西八代郡市川三郷町宮原', '19', '19346', '4093242', '山梨県', 'ヤマナシケン', '西八代郡市川三郷町', 'ニシヤツシログンイチカワミサトチョウ', '宮原', 'ミヤバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県西八代郡市川三郷町鴨狩津向', '19', '19346', '4093243', '山梨県', 'ヤマナシケン', '西八代郡市川三郷町', 'ニシヤツシログンイチカワミサトチョウ', '鴨狩津向', 'カモガリツムギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県西八代郡市川三郷町岩間', '19', '19346', '4093244', '山梨県', 'ヤマナシケン', '西八代郡市川三郷町', 'ニシヤツシログンイチカワミサトチョウ', '岩間', 'イワマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県西八代郡市川三郷町楠甫', '19', '19346', '4093245', '山梨県', 'ヤマナシケン', '西八代郡市川三郷町', 'ニシヤツシログンイチカワミサトチョウ', '楠甫', 'クスホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡身延町西嶋', '19', '19365', '4093301', '山梨県', 'ヤマナシケン', '南巨摩郡身延町', 'ミナミコマグンミノブチョウ', '西嶋', 'ニシジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡身延町手打沢', '19', '19365', '4093302', '山梨県', 'ヤマナシケン', '南巨摩郡身延町', 'ミナミコマグンミノブチョウ', '手打沢', 'テウチザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡身延町寺沢', '19', '19365', '4093303', '山梨県', 'ヤマナシケン', '南巨摩郡身延町', 'ミナミコマグンミノブチョウ', '寺沢', 'テラサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡身延町切石', '19', '19365', '4093304', '山梨県', 'ヤマナシケン', '南巨摩郡身延町', 'ミナミコマグンミノブチョウ', '切石', 'キリイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡身延町下田原', '19', '19365', '4093305', '山梨県', 'ヤマナシケン', '南巨摩郡身延町', 'ミナミコマグンミノブチョウ', '下田原', 'シモタンバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡身延町夜子沢', '19', '19365', '4093306', '山梨県', 'ヤマナシケン', '南巨摩郡身延町', 'ミナミコマグンミノブチョウ', '夜子沢', 'ヨゴサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡身延町日向南沢', '19', '19365', '4093307', '山梨県', 'ヤマナシケン', '南巨摩郡身延町', 'ミナミコマグンミノブチョウ', '日向南沢', 'ヒナタミナミザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡身延町大塩', '19', '19365', '4093311', '山梨県', 'ヤマナシケン', '南巨摩郡身延町', 'ミナミコマグンミノブチョウ', '大塩', 'オオシオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡身延町久成', '19', '19365', '4093312', '山梨県', 'ヤマナシケン', '南巨摩郡身延町', 'ミナミコマグンミノブチョウ', '久成', 'クナリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡身延町平須', '19', '19365', '4093313', '山梨県', 'ヤマナシケン', '南巨摩郡身延町', 'ミナミコマグンミノブチョウ', '平須', 'ヒラス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡身延町八日市場', '19', '19365', '4093421', '山梨県', 'ヤマナシケン', '南巨摩郡身延町', 'ミナミコマグンミノブチョウ', '八日市場', 'ヨウカイチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡身延町宮木', '19', '19365', '4093422', '山梨県', 'ヤマナシケン', '南巨摩郡身延町', 'ミナミコマグンミノブチョウ', '宮木', 'ミヤキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡身延町飯富', '19', '19365', '4093423', '山梨県', 'ヤマナシケン', '南巨摩郡身延町', 'ミナミコマグンミノブチョウ', '飯富', 'イイトミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡身延町伊沼', '19', '19365', '4093424', '山梨県', 'ヤマナシケン', '南巨摩郡身延町', 'ミナミコマグンミノブチョウ', '伊沼', 'イヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡身延町矢細工', '19', '19365', '4093431', '山梨県', 'ヤマナシケン', '南巨摩郡身延町', 'ミナミコマグンミノブチョウ', '矢細工', 'ヤサイク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡身延町中山', '19', '19365', '4093432', '山梨県', 'ヤマナシケン', '南巨摩郡身延町', 'ミナミコマグンミノブチョウ', '中山', 'ナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡身延町遅沢', '19', '19365', '4093433', '山梨県', 'ヤマナシケン', '南巨摩郡身延町', 'ミナミコマグンミノブチョウ', '遅沢', 'オソザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡身延町江尻窪', '19', '19365', '4093434', '山梨県', 'ヤマナシケン', '南巨摩郡身延町', 'ミナミコマグンミノブチョウ', '江尻窪', 'エジリクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡身延町梨子', '19', '19365', '4093435', '山梨県', 'ヤマナシケン', '南巨摩郡身延町', 'ミナミコマグンミノブチョウ', '梨子', 'ナシゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡身延町福原', '19', '19365', '4093436', '山梨県', 'ヤマナシケン', '南巨摩郡身延町', 'ミナミコマグンミノブチョウ', '福原', 'フクハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県南巨摩郡身延町古長谷', '19', '19365', '4093437', '山梨県', 'ヤマナシケン', '南巨摩郡身延町', 'ミナミコマグンミノブチョウ', '古長谷', 'フルハセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県西八代郡市川三郷町', '19', '19346', '4093600', '山梨県', 'ヤマナシケン', '西八代郡市川三郷町', 'ニシヤツシログンイチカワミサトチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('36858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県西八代郡市川三郷町市川大門', '19', '19346', '4093601', '山梨県', 'ヤマナシケン', '西八代郡市川三郷町', 'ニシヤツシログンイチカワミサトチョウ', '市川大門', 'イチカワダイモン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県西八代郡市川三郷町山保', '19', '19346', '4093602', '山梨県', 'ヤマナシケン', '西八代郡市川三郷町', 'ニシヤツシログンイチカワミサトチョウ', '山保', 'ヤマホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県西八代郡市川三郷町黒沢', '19', '19346', '4093603', '山梨県', 'ヤマナシケン', '西八代郡市川三郷町', 'ニシヤツシログンイチカワミサトチョウ', '黒沢', 'クロザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県西八代郡市川三郷町八之尻', '19', '19346', '4093604', '山梨県', 'ヤマナシケン', '西八代郡市川三郷町', 'ニシヤツシログンイチカワミサトチョウ', '八之尻', 'ハチノシリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県西八代郡市川三郷町下大鳥居', '19', '19346', '4093605', '山梨県', 'ヤマナシケン', '西八代郡市川三郷町', 'ニシヤツシログンイチカワミサトチョウ', '下大鳥居', 'シモオオドリイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県西八代郡市川三郷町高田', '19', '19346', '4093606', '山梨県', 'ヤマナシケン', '西八代郡市川三郷町', 'ニシヤツシログンイチカワミサトチョウ', '高田', 'タカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県西八代郡市川三郷町印沢', '19', '19346', '4093607', '山梨県', 'ヤマナシケン', '西八代郡市川三郷町', 'ニシヤツシログンイチカワミサトチョウ', '印沢', 'インザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県西八代郡市川三郷町大塚', '19', '19346', '4093611', '山梨県', 'ヤマナシケン', '西八代郡市川三郷町', 'ニシヤツシログンイチカワミサトチョウ', '大塚', 'オオツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県西八代郡市川三郷町上野', '19', '19346', '4093612', '山梨県', 'ヤマナシケン', '西八代郡市川三郷町', 'ニシヤツシログンイチカワミサトチョウ', '上野', 'ウエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県西八代郡市川三郷町下芦川', '19', '19346', '4093621', '山梨県', 'ヤマナシケン', '西八代郡市川三郷町', 'ニシヤツシログンイチカワミサトチョウ', '下芦川', 'シモアシガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県西八代郡市川三郷町三帳', '19', '19346', '4093622', '山梨県', 'ヤマナシケン', '西八代郡市川三郷町', 'ニシヤツシログンイチカワミサトチョウ', '三帳', 'サンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県西八代郡市川三郷町高萩', '19', '19346', '4093623', '山梨県', 'ヤマナシケン', '西八代郡市川三郷町', 'ニシヤツシログンイチカワミサトチョウ', '高萩', 'タカハギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県西八代郡市川三郷町垈', '19', '19346', '4093624', '山梨県', 'ヤマナシケン', '西八代郡市川三郷町', 'ニシヤツシログンイチカワミサトチョウ', '垈', 'ヌタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県西八代郡市川三郷町中山', '19', '19346', '4093625', '山梨県', 'ヤマナシケン', '西八代郡市川三郷町', 'ニシヤツシログンイチカワミサトチョウ', '中山', 'ナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県西八代郡市川三郷町畑熊', '19', '19346', '4093626', '山梨県', 'ヤマナシケン', '西八代郡市川三郷町', 'ニシヤツシログンイチカワミサトチョウ', '畑熊', 'ハタクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県笛吹市芦川町上芦川', '19', '19211', '4093701', '山梨県', 'ヤマナシケン', '笛吹市', 'フエフキシ', '芦川町上芦川', 'アシガワチョウカミアシガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県笛吹市芦川町新井原', '19', '19211', '4093702', '山梨県', 'ヤマナシケン', '笛吹市', 'フエフキシ', '芦川町新井原', 'アシガワチョウアライバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県笛吹市芦川町中芦川', '19', '19211', '4093703', '山梨県', 'ヤマナシケン', '笛吹市', 'フエフキシ', '芦川町中芦川', 'アシガワチョウナカアシガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県笛吹市芦川町鶯宿', '19', '19211', '4093704', '山梨県', 'ヤマナシケン', '笛吹市', 'フエフキシ', '芦川町鶯宿', 'アシガワチョウオウシュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市梯町', '19', '19201', '4093711', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '梯町', 'カケハシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県甲府市古関町', '19', '19201', '4093712', '山梨県', 'ヤマナシケン', '甲府市', 'コウフシ', '古関町', 'フルセキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県中央市', '19', '19214', '4093800', '山梨県', 'ヤマナシケン', '中央市', 'チュウオウシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('36883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県中巨摩郡昭和町', '19', '19384', '4093800', '山梨県', 'ヤマナシケン', '中巨摩郡昭和町', 'ナカコマグンショウワチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('36884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県中央市中楯', '19', '19214', '4093801', '山梨県', 'ヤマナシケン', '中央市', 'チュウオウシ', '中楯', 'ナカダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県中央市西新居', '19', '19214', '4093802', '山梨県', 'ヤマナシケン', '中央市', 'チュウオウシ', '西新居', 'ニシアライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県中央市若宮', '19', '19214', '4093803', '山梨県', 'ヤマナシケン', '中央市', 'チュウオウシ', '若宮', 'ワカミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県中央市井之口', '19', '19214', '4093804', '山梨県', 'ヤマナシケン', '中央市', 'チュウオウシ', '井之口', 'イノクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県中央市極楽寺', '19', '19214', '4093811', '山梨県', 'ヤマナシケン', '中央市', 'チュウオウシ', '極楽寺', 'ゴクラクジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県中央市乙黒', '19', '19214', '4093812', '山梨県', 'ヤマナシケン', '中央市', 'チュウオウシ', '乙黒', 'オトグロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県中央市一町畑', '19', '19214', '4093813', '山梨県', 'ヤマナシケン', '中央市', 'チュウオウシ', '一町畑', 'イッチョウハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県中央市町之田', '19', '19214', '4093814', '山梨県', 'ヤマナシケン', '中央市', 'チュウオウシ', '町之田', 'マチノタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県中央市成島', '19', '19214', '4093815', '山梨県', 'ヤマナシケン', '中央市', 'チュウオウシ', '成島', 'ナルシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県中央市下河東', '19', '19214', '4093821', '山梨県', 'ヤマナシケン', '中央市', 'チュウオウシ', '下河東', 'シモカトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県中央市下三條', '19', '19214', '4093822', '山梨県', 'ヤマナシケン', '中央市', 'チュウオウシ', '下三條', 'シモサンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県中央市上三條', '19', '19214', '4093823', '山梨県', 'ヤマナシケン', '中央市', 'チュウオウシ', '上三條', 'カミサンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県中央市大田和', '19', '19214', '4093831', '山梨県', 'ヤマナシケン', '中央市', 'チュウオウシ', '大田和', 'オオダワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県中央市馬籠', '19', '19214', '4093832', '山梨県', 'ヤマナシケン', '中央市', 'チュウオウシ', '馬籠', 'マゴメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県中央市藤巻', '19', '19214', '4093833', '山梨県', 'ヤマナシケン', '中央市', 'チュウオウシ', '藤巻', 'フジマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県中央市今福', '19', '19214', '4093834', '山梨県', 'ヤマナシケン', '中央市', 'チュウオウシ', '今福', 'イマフク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県中央市今福新田', '19', '19214', '4093835', '山梨県', 'ヤマナシケン', '中央市', 'チュウオウシ', '今福新田', 'イマフクシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県中央市布施', '19', '19214', '4093841', '山梨県', 'ヤマナシケン', '中央市', 'チュウオウシ', '布施', 'フセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県中央市東花輪', '19', '19214', '4093842', '山梨県', 'ヤマナシケン', '中央市', 'チュウオウシ', '東花輪', 'ヒガシハナワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県中央市西花輪', '19', '19214', '4093843', '山梨県', 'ヤマナシケン', '中央市', 'チュウオウシ', '西花輪', 'ニシハナワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県中央市臼井阿原', '19', '19214', '4093844', '山梨県', 'ヤマナシケン', '中央市', 'チュウオウシ', '臼井阿原', 'ウスイアワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県中央市山之神', '19', '19214', '4093845', '山梨県', 'ヤマナシケン', '中央市', 'チュウオウシ', '山之神', 'ヤマノカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県中巨摩郡昭和町河西', '19', '19384', '4093851', '山梨県', 'ヤマナシケン', '中巨摩郡昭和町', 'ナカコマグンショウワチョウ', '河西', 'カサイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県中巨摩郡昭和町飯喰', '19', '19384', '4093852', '山梨県', 'ヤマナシケン', '中巨摩郡昭和町', 'ナカコマグンショウワチョウ', '飯喰', 'イックイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県中巨摩郡昭和町築地新居', '19', '19384', '4093853', '山梨県', 'ヤマナシケン', '中巨摩郡昭和町', 'ナカコマグンショウワチョウ', '築地新居', 'ツイジアライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県中巨摩郡昭和町築地新田', '19', '19384', '4093854', '山梨県', 'ヤマナシケン', '中巨摩郡昭和町', 'ナカコマグンショウワチョウ', '築地新田', 'ツイジシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県中巨摩郡昭和町紙漉阿原', '19', '19384', '4093861', '山梨県', 'ヤマナシケン', '中巨摩郡昭和町', 'ナカコマグンショウワチョウ', '紙漉阿原', 'カミスキアワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県中巨摩郡昭和町上河東', '19', '19384', '4093862', '山梨県', 'ヤマナシケン', '中巨摩郡昭和町', 'ナカコマグンショウワチョウ', '上河東', 'カミガトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県中巨摩郡昭和町河東中島', '19', '19384', '4093863', '山梨県', 'ヤマナシケン', '中巨摩郡昭和町', 'ナカコマグンショウワチョウ', '河東中島', 'カトウナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県中巨摩郡昭和町押越', '19', '19384', '4093864', '山梨県', 'ヤマナシケン', '中巨摩郡昭和町', 'ナカコマグンショウワチョウ', '押越', 'オシコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県中巨摩郡昭和町西条新田', '19', '19384', '4093865', '山梨県', 'ヤマナシケン', '中巨摩郡昭和町', 'ナカコマグンショウワチョウ', '西条新田', 'サイジョウシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県中巨摩郡昭和町西条', '19', '19384', '4093866', '山梨県', 'ヤマナシケン', '中巨摩郡昭和町', 'ナカコマグンショウワチョウ', '西条', 'サイジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山梨県中巨摩郡昭和町清水新居', '19', '19384', '4093867', '山梨県', 'ヤマナシケン', '中巨摩郡昭和町', 'ナカコマグンショウワチョウ', '清水新居', 'シミズアライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市', '22', '22203', '4100000', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('36932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市足高', '22', '22203', '4100001', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '足高', 'アシタカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市東沢田', '22', '22203', '4100002', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '東沢田', 'ヒガシサワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市新沢田町', '22', '22203', '4100003', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '新沢田町', 'シンサワダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市本田町', '22', '22203', '4100004', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '本田町', 'ホンタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市双葉町', '22', '22203', '4100005', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '双葉町', 'フタバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市中沢田', '22', '22203', '4100006', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '中沢田', 'ナカサワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市西沢田', '22', '22203', '4100007', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '西沢田', 'ニシサワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市岡宮', '22', '22203', '4100011', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '岡宮', 'オカノミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市岡一色', '22', '22203', '4100012', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '岡一色', 'オカイッシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市東熊堂', '22', '22203', '4100013', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '東熊堂', 'ヒガシクマンドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市松沢町', '22', '22203', '4100014', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '松沢町', 'マツサワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市駿河台', '22', '22203', '4100015', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '駿河台', 'スルガダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市高砂町', '22', '22203', '4100016', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '高砂町', 'タカサゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市高尾台', '22', '22203', '4100017', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '高尾台', 'タカオダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市豊町', '22', '22203', '4100018', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '豊町', 'ユタカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市小林台', '22', '22203', '4100021', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '小林台', 'コバヤシダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市大岡', '22', '22203', '4100022', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '大岡', 'オオオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市三枚橋', '22', '22203', '4100031', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '三枚橋', 'サンマイバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市日の出町', '22', '22203', '4100032', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '日の出町', 'ヒノデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市杉崎町', '22', '22203', '4100033', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '杉崎町', 'スギザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市富士見町', '22', '22203', '4100034', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '富士見町', 'フジミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市山王台', '22', '22203', '4100035', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '山王台', 'サンノウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市平町', '22', '22203', '4100036', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '平町', 'ヒラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市三枚橋町', '22', '22203', '4100037', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '三枚橋町', 'サンマイバシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市三芳町', '22', '22203', '4100038', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '三芳町', 'ミヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市筒井町', '22', '22203', '4100041', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '筒井町', 'ツツイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市神田町', '22', '22203', '4100042', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '神田町', 'カンダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市柳町', '22', '22203', '4100043', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '柳町', 'ヤナギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市五月町', '22', '22203', '4100044', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '五月町', 'サツキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市泉町', '22', '22203', '4100045', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '泉町', 'イズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市米山町', '22', '22203', '4100046', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '米山町', 'ヨネヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市庄栄町', '22', '22203', '4100047', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '庄栄町', 'ショウエイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市新宿町', '22', '22203', '4100048', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '新宿町', 'シンジュクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市江原町', '22', '22203', '4100049', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '江原町', 'エバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市西熊堂', '22', '22203', '4100051', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '西熊堂', 'ニシクマンドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市沢田町', '22', '22203', '4100052', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '沢田町', 'サワダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市寿町', '22', '22203', '4100053', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '寿町', 'コトブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市北高島町', '22', '22203', '4100054', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '北高島町', 'キタタカシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市高島本町', '22', '22203', '4100055', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '高島本町', 'タカシマホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市高島町', '22', '22203', '4100056', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '高島町', 'タカシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市高沢町', '22', '22203', '4100057', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '高沢町', 'タカザワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市沼北町', '22', '22203', '4100058', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '沼北町', 'ヌマキタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市若葉町', '22', '22203', '4100059', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '若葉町', 'ワカバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市北園町', '22', '22203', '4100061', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '北園町', 'キタゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市宮前町', '22', '22203', '4100062', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '宮前町', 'ミヤマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市緑ケ丘', '22', '22203', '4100063', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '緑ケ丘', 'ミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市共栄町', '22', '22203', '4100064', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '共栄町', 'キョウエイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市花園町', '22', '22203', '4100065', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '花園町', 'ハナゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市多比', '22', '22203', '4100101', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '多比', 'タビ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市口野', '22', '22203', '4100102', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '口野', 'クチノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市江浦', '22', '22203', '4100103', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '江浦', 'エノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市獅子浜', '22', '22203', '4100104', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '獅子浜', 'シシハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市馬込', '22', '22203', '4100105', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '馬込', 'マゴメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市志下', '22', '22203', '4100106', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '志下', 'シゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市内浦重寺', '22', '22203', '4100221', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '内浦重寺', 'ウチウラシゲデラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市内浦小海', '22', '22203', '4100222', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '内浦小海', 'ウチウラコウミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市内浦三津', '22', '22203', '4100223', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '内浦三津', 'ウチウラミト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市内浦長浜', '22', '22203', '4100224', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '内浦長浜', 'ウチウラナガハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市内浦重須', '22', '22203', '4100225', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '内浦重須', 'ウチウラオモス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市西浦木負', '22', '22203', '4100231', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '西浦木負', 'ニシウラキショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市西浦河内', '22', '22203', '4100232', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '西浦河内', 'ニシウラコウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市西浦久連', '22', '22203', '4100233', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '西浦久連', 'ニシウラクヅラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市西浦平沢', '22', '22203', '4100234', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '西浦平沢', 'ニシウラヒラサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市西浦立保', '22', '22203', '4100235', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '西浦立保', 'ニシウラタチボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市西浦古宇', '22', '22203', '4100241', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '西浦古宇', 'ニシウラコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市西浦足保', '22', '22203', '4100242', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '西浦足保', 'ニシウラアシボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('36999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市西浦久料', '22', '22203', '4100243', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '西浦久料', 'ニシウラクリョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市西浦江梨', '22', '22203', '4100244', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '西浦江梨', 'ニシウラエナシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市西浦大瀬', '22', '22203', '4100244', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '西浦大瀬', 'ニシウラオオセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市宮本', '22', '22203', '4100301', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '宮本', 'ミヤモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市東椎路', '22', '22203', '4100302', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '東椎路', 'ヒガシシイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市西椎路', '22', '22203', '4100303', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '西椎路', 'ニシシイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市東原', '22', '22203', '4100304', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '東原', 'ヒガシバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市鳥谷', '22', '22203', '4100305', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '鳥谷', 'トヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市大塚', '22', '22203', '4100306', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '大塚', 'オオツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市青野', '22', '22203', '4100307', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '青野', 'オオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市柳沢', '22', '22203', '4100308', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '柳沢', 'ヤナギサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市根古屋', '22', '22203', '4100309', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '根古屋', 'ネゴヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市原町中', '22', '22203', '4100311', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '原町中', 'ハラマチナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市原', '22', '22203', '4100312', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '原', 'ハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市西添町', '22', '22203', '4100313', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '西添町', 'ニシゾエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市一本松', '22', '22203', '4100314', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '一本松', 'イッポンマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市桃里', '22', '22203', '4100315', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '桃里', 'モモザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市植田', '22', '22203', '4100316', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '植田', 'ウエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市石川', '22', '22203', '4100317', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '石川', 'イシカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市平沼', '22', '22203', '4100318', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '平沼', 'ヒラヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市井出', '22', '22203', '4100319', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '井出', 'イデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市西野', '22', '22203', '4100321', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '西野', 'ニシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市大手町', '22', '22203', '4100801', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '大手町', 'オオテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市上土町', '22', '22203', '4100802', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '上土町', 'アゲツチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市添地町', '22', '22203', '4100803', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '添地町', 'ソエチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市西条町', '22', '22203', '4100804', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '西条町', 'サイジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市白銀町', '22', '22203', '4100805', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '白銀町', 'シロガネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市丸子町', '22', '22203', '4100806', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '丸子町', 'マルコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市錦町', '22', '22203', '4100807', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '錦町', 'ニシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市中瀬町', '22', '22203', '4100811', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '中瀬町', 'ナカセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市山ケ下町', '22', '22203', '4100812', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '山ケ下町', 'ヤマガシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市上香貫', '22', '22203', '4100813', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '上香貫', 'カミカヌキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市玉江町', '22', '22203', '4100814', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '玉江町', 'タマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市南本郷町', '22', '22203', '4100815', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '南本郷町', 'ミナミホンゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市住吉町', '22', '22203', '4100816', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '住吉町', 'スミヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市本郷町', '22', '22203', '4100817', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '本郷町', 'ホンゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市中原町', '22', '22203', '4100818', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '中原町', 'ナカハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市黒瀬町', '22', '22203', '4100819', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '黒瀬町', 'クロセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市大平', '22', '22203', '4100821', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '大平', 'オオヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市下香貫', '22', '22203', '4100822', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '下香貫', 'シモカヌキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市我入道', '22', '22203', '4100823', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '我入道', 'ガニュウドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市香貫が丘', '22', '22203', '4100824', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '香貫が丘', 'カヌキガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市市場町', '22', '22203', '4100831', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '市場町', 'イチバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市御幸町', '22', '22203', '4100832', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '御幸町', 'ミユキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市三園町', '22', '22203', '4100833', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '三園町', 'ミソノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市槇島町', '22', '22203', '4100834', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '槇島町', 'マキジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市西島町', '22', '22203', '4100835', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '西島町', 'ニシジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市吉田町', '22', '22203', '4100836', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '吉田町', 'ヨシダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市下河原町', '22', '22203', '4100841', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '下河原町', 'シモガワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市蛇松町', '22', '22203', '4100842', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '蛇松町', 'ジャマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市蓼原町', '22', '22203', '4100843', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '蓼原町', 'タデハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市春日町', '22', '22203', '4100844', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '春日町', 'カスガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市千本港町', '22', '22203', '4100845', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '千本港町', 'センボンミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市千本東町', '22', '22203', '4100846', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '千本東町', 'センボンヒガシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市千本中町', '22', '22203', '4100847', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '千本中町', 'センボンナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市千本西町', '22', '22203', '4100848', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '千本西町', 'センボンニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市千本郷林', '22', '22203', '4100849', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '千本郷林', 'センボンゴウリン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市宮町', '22', '22203', '4100851', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '宮町', 'ミヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市旭町', '22', '22203', '4100852', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '旭町', 'アサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市常盤町', '22', '22203', '4100853', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '常盤町', 'トキワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市千本常盤町', '22', '22203', '4100854', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '千本常盤町', 'センボントキワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市千本緑町', '22', '22203', '4100855', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '千本緑町', 'センボンミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市真砂町', '22', '22203', '4100861', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '真砂町', 'マサゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市幸町', '22', '22203', '4100862', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市下一丁田', '22', '22203', '4100863', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '下一丁田', 'シモイッチョウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市松下', '22', '22203', '4100864', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '松下', 'マツシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市東間門', '22', '22203', '4100865', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '東間門', 'ヒガシマカド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市市道', '22', '22203', '4100866', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '市道', 'イチミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市下小路町', '22', '22203', '4100867', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '下小路町', 'シタコウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市下中溝', '22', '22203', '4100867', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '下中溝', 'シモナカミゾ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市千本', '22', '22203', '4100867', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '千本', 'センボン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市出口町', '22', '22203', '4100867', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '出口町', 'デグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市西松下', '22', '22203', '4100867', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '西松下', 'ニシマツシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市本', '22', '22203', '4100867', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '本', 'ホン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市前田', '22', '22203', '4100867', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '前田', 'マエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市松下七反田', '22', '22203', '4100867', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '松下七反田', 'マツシタヒチタンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市西間門', '22', '22203', '4100871', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '西間門', 'ニシマカド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市小諏訪', '22', '22203', '4100872', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '小諏訪', 'コズワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市大諏訪', '22', '22203', '4100873', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '大諏訪', 'オオズワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市松長', '22', '22203', '4100874', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '松長', 'マツナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市今沢', '22', '22203', '4100875', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '今沢', 'イマザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市北今沢', '22', '22203', '4100876', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '北今沢', 'キタイマザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市八幡町', '22', '22203', '4100881', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '八幡町', 'ハチマンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市町方町', '22', '22203', '4100882', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '町方町', 'マチカタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市大門町', '22', '22203', '4100883', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '大門町', 'ダイモンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市本町', '22', '22203', '4100884', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市下本町', '22', '22203', '4100885', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '下本町', 'シモホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市浅間町', '22', '22203', '4100886', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '浅間町', 'センゲンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市東宮後町', '22', '22203', '4100887', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '東宮後町', 'ヒガシミヤウシロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市末広町', '22', '22203', '4100888', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '末広町', 'スエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市通横町', '22', '22203', '4100891', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '通横町', 'トオリヨコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市魚町', '22', '22203', '4100892', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '魚町', 'ウオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市くまだか町', '22', '22203', '4100893', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', 'くまだか町', 'クマダカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市仲町', '22', '22203', '4100894', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '仲町', 'ナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市新町', '22', '22203', '4100895', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '新町', 'シンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県裾野市', '22', '22220', '4101100', '静岡県', 'シズオカケン', '裾野市', 'スソノシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('37098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県裾野市岩波', '22', '22220', '4101101', '静岡県', 'シズオカケン', '裾野市', 'スソノシ', '岩波', 'イワナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県裾野市深良', '22', '22220', '4101102', '静岡県', 'シズオカケン', '裾野市', 'スソノシ', '深良', 'フカラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県裾野市葛山', '22', '22220', '4101103', '静岡県', 'シズオカケン', '裾野市', 'スソノシ', '葛山', 'カズラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県裾野市今里', '22', '22220', '4101104', '静岡県', 'シズオカケン', '裾野市', 'スソノシ', '今里', 'イマザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県裾野市下和田', '22', '22220', '4101105', '静岡県', 'シズオカケン', '裾野市', 'スソノシ', '下和田', 'シモワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県裾野市金沢', '22', '22220', '4101106', '静岡県', 'シズオカケン', '裾野市', 'スソノシ', '金沢', 'カネザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県裾野市御宿', '22', '22220', '4101107', '静岡県', 'シズオカケン', '裾野市', 'スソノシ', '御宿', 'ミシュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県裾野市上ケ田', '22', '22220', '4101108', '静岡県', 'シズオカケン', '裾野市', 'スソノシ', '上ケ田', 'アゲタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県裾野市呼子', '22', '22220', '4101109', '静岡県', 'シズオカケン', '裾野市', 'スソノシ', '呼子', 'ヨビコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県裾野市久根', '22', '22220', '4101111', '静岡県', 'シズオカケン', '裾野市', 'スソノシ', '久根', 'クネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県裾野市公文名', '22', '22220', '4101112', '静岡県', 'シズオカケン', '裾野市', 'スソノシ', '公文名', 'クモミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県裾野市稲荷', '22', '22220', '4101113', '静岡県', 'シズオカケン', '裾野市', 'スソノシ', '稲荷', 'イナリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県裾野市大畑', '22', '22220', '4101114', '静岡県', 'シズオカケン', '裾野市', 'スソノシ', '大畑', 'オオハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県裾野市千福が丘', '22', '22220', '4101115', '静岡県', 'シズオカケン', '裾野市', 'スソノシ', '千福が丘', 'センプクガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県裾野市千福', '22', '22220', '4101116', '静岡県', 'シズオカケン', '裾野市', 'スソノシ', '千福', 'センプク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県裾野市石脇', '22', '22220', '4101117', '静岡県', 'シズオカケン', '裾野市', 'スソノシ', '石脇', 'イシワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県裾野市佐野', '22', '22220', '4101118', '静岡県', 'シズオカケン', '裾野市', 'スソノシ', '佐野', 'サノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県裾野市茶畑', '22', '22220', '4101121', '静岡県', 'シズオカケン', '裾野市', 'スソノシ', '茶畑', 'チャバタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県裾野市麦塚', '22', '22220', '4101122', '静岡県', 'シズオカケン', '裾野市', 'スソノシ', '麦塚', 'ムギツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県裾野市伊豆島田', '22', '22220', '4101123', '静岡県', 'シズオカケン', '裾野市', 'スソノシ', '伊豆島田', 'イズシマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県裾野市水窪', '22', '22220', '4101124', '静岡県', 'シズオカケン', '裾野市', 'スソノシ', '水窪', 'ミズクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県裾野市富沢', '22', '22220', '4101125', '静岡県', 'シズオカケン', '裾野市', 'スソノシ', '富沢', 'トミザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県裾野市桃園', '22', '22220', '4101126', '静岡県', 'シズオカケン', '裾野市', 'スソノシ', '桃園', 'モモゾノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県裾野市平松', '22', '22220', '4101127', '静岡県', 'シズオカケン', '裾野市', 'スソノシ', '平松', 'ヒラマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県裾野市二ツ屋', '22', '22220', '4101128', '静岡県', 'シズオカケン', '裾野市', 'スソノシ', '二ツ屋', 'フタツヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県裾野市須山', '22', '22220', '4101231', '静岡県', 'シズオカケン', '裾野市', 'スソノシ', '須山', 'スヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県駿東郡小山町', '22', '22344', '4101300', '静岡県', 'シズオカケン', '駿東郡小山町', 'スントウグンオヤマチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('37129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県駿東郡小山町柳島', '22', '22344', '4101301', '静岡県', 'シズオカケン', '駿東郡小山町', 'スントウグンオヤマチョウ', '柳島', 'ヤナギシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県駿東郡小山町中島', '22', '22344', '4101302', '静岡県', 'シズオカケン', '駿東郡小山町', 'スントウグンオヤマチョウ', '中島', 'ナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県駿東郡小山町生土', '22', '22344', '4101303', '静岡県', 'シズオカケン', '駿東郡小山町', 'スントウグンオヤマチョウ', '生土', 'イキド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県駿東郡小山町藤曲', '22', '22344', '4101304', '静岡県', 'シズオカケン', '駿東郡小山町', 'スントウグンオヤマチョウ', '藤曲', 'フジマガリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県駿東郡小山町湯船', '22', '22344', '4101305', '静岡県', 'シズオカケン', '駿東郡小山町', 'スントウグンオヤマチョウ', '湯船', 'ユブネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県駿東郡小山町上野', '22', '22344', '4101306', '静岡県', 'シズオカケン', '駿東郡小山町', 'スントウグンオヤマチョウ', '上野', 'ウエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県駿東郡小山町中日向', '22', '22344', '4101307', '静岡県', 'シズオカケン', '駿東郡小山町', 'スントウグンオヤマチョウ', '中日向', 'ナカヒナタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県駿東郡小山町大御神', '22', '22344', '4101308', '静岡県', 'シズオカケン', '駿東郡小山町', 'スントウグンオヤマチョウ', '大御神', 'オオミカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県駿東郡小山町小山', '22', '22344', '4101311', '静岡県', 'シズオカケン', '駿東郡小山町', 'スントウグンオヤマチョウ', '小山', 'オヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県駿東郡小山町菅沼', '22', '22344', '4101312', '静岡県', 'シズオカケン', '駿東郡小山町', 'スントウグンオヤマチョウ', '菅沼', 'スガヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県駿東郡小山町竹之下', '22', '22344', '4101313', '静岡県', 'シズオカケン', '駿東郡小山町', 'スントウグンオヤマチョウ', '竹之下', 'タケノシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県駿東郡小山町新柴', '22', '22344', '4101314', '静岡県', 'シズオカケン', '駿東郡小山町', 'スントウグンオヤマチョウ', '新柴', 'アラシバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県駿東郡小山町桑木', '22', '22344', '4101315', '静岡県', 'シズオカケン', '駿東郡小山町', 'スントウグンオヤマチョウ', '桑木', 'クワギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県駿東郡小山町下古城', '22', '22344', '4101316', '静岡県', 'シズオカケン', '駿東郡小山町', 'スントウグンオヤマチョウ', '下古城', 'シモフルシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県駿東郡小山町大胡田', '22', '22344', '4101317', '静岡県', 'シズオカケン', '駿東郡小山町', 'スントウグンオヤマチョウ', '大胡田', 'オオゴダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県駿東郡小山町阿多野', '22', '22344', '4101321', '静岡県', 'シズオカケン', '駿東郡小山町', 'スントウグンオヤマチョウ', '阿多野', 'アダノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県駿東郡小山町吉久保', '22', '22344', '4101322', '静岡県', 'シズオカケン', '駿東郡小山町', 'スントウグンオヤマチョウ', '吉久保', 'ヨシクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県駿東郡小山町上古城', '22', '22344', '4101323', '静岡県', 'シズオカケン', '駿東郡小山町', 'スントウグンオヤマチョウ', '上古城', 'カミフルシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県駿東郡小山町下小林', '22', '22344', '4101324', '静岡県', 'シズオカケン', '駿東郡小山町', 'スントウグンオヤマチョウ', '下小林', 'シモコバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県駿東郡小山町一色', '22', '22344', '4101325', '静岡県', 'シズオカケン', '駿東郡小山町', 'スントウグンオヤマチョウ', '一色', 'イシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県駿東郡小山町用沢', '22', '22344', '4101326', '静岡県', 'シズオカケン', '駿東郡小山町', 'スントウグンオヤマチョウ', '用沢', 'ヨウサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県駿東郡小山町棚頭', '22', '22344', '4101327', '静岡県', 'シズオカケン', '駿東郡小山町', 'スントウグンオヤマチョウ', '棚頭', 'タナガシラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県駿東郡小山町須走', '22', '22344', '4101431', '静岡県', 'シズオカケン', '駿東郡小山町', 'スントウグンオヤマチョウ', '須走', 'スバシリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県駿東郡小山町自衛隊富士学校', '22', '22344', '4101432', '静岡県', 'シズオカケン', '駿東郡小山町', 'スントウグンオヤマチョウ', '自衛隊富士学校', 'ジエイタイフジガッコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊豆の国市小松ケ原', '22', '22225', '4102101', '静岡県', 'シズオカケン', '伊豆の国市', 'イズノクニシ', '小松ケ原', 'コマツガハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊豆の国市富士見ニュータウン', '22', '22225', '4102102', '静岡県', 'シズオカケン', '伊豆の国市', 'イズノクニシ', '富士見ニュータウン', 'フジミニュータウン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊豆の国市エメラルドタウン', '22', '22225', '4102103', '静岡県', 'シズオカケン', '伊豆の国市', 'イズノクニシ', 'エメラルドタウン', 'エメラルドタウン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊豆の国市立花台', '22', '22225', '4102111', '静岡県', 'シズオカケン', '伊豆の国市', 'イズノクニシ', '立花台', 'タチバナダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊豆の国市内中', '22', '22225', '4102112', '静岡県', 'シズオカケン', '伊豆の国市', 'イズノクニシ', '内中', 'ウチナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊豆の国市中', '22', '22225', '4102113', '静岡県', 'シズオカケン', '伊豆の国市', 'イズノクニシ', '中', 'ナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊豆の国市南條', '22', '22225', '4102114', '静岡県', 'シズオカケン', '伊豆の国市', 'イズノクニシ', '南條', 'ナンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊豆の国市中條', '22', '22225', '4102121', '静岡県', 'シズオカケン', '伊豆の国市', 'イズノクニシ', '中條', 'チュウジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊豆の国市寺家', '22', '22225', '4102122', '静岡県', 'シズオカケン', '伊豆の国市', 'イズノクニシ', '寺家', 'ジケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊豆の国市四日町', '22', '22225', '4102123', '静岡県', 'シズオカケン', '伊豆の国市', 'イズノクニシ', '四日町', 'ヨッカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊豆の国市原木', '22', '22225', '4102124', '静岡県', 'シズオカケン', '伊豆の国市', 'イズノクニシ', '原木', 'バラキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊豆の国市長崎', '22', '22225', '4102131', '静岡県', 'シズオカケン', '伊豆の国市', 'イズノクニシ', '長崎', 'ナガサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊豆の国市奈古谷', '22', '22225', '4102132', '静岡県', 'シズオカケン', '伊豆の国市', 'イズノクニシ', '奈古谷', 'ナゴヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊豆の国市韮山多田', '22', '22225', '4102133', '静岡県', 'シズオカケン', '伊豆の国市', 'イズノクニシ', '韮山多田', 'ニラヤマタダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊豆の国市韮山山木', '22', '22225', '4102141', '静岡県', 'シズオカケン', '伊豆の国市', 'イズノクニシ', '韮山山木', 'ニラヤマヤマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊豆の国市韮山金谷', '22', '22225', '4102142', '静岡県', 'シズオカケン', '伊豆の国市', 'イズノクニシ', '韮山金谷', 'ニラヤマカナヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊豆の国市韮山韮山', '22', '22225', '4102143', '静岡県', 'シズオカケン', '伊豆の国市', 'イズノクニシ', '韮山韮山', 'ニラヤマニラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊豆の国市韮山土手和田', '22', '22225', '4102144', '静岡県', 'シズオカケン', '伊豆の国市', 'イズノクニシ', '韮山土手和田', 'ニラヤマドテワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊豆の国市', '22', '22225', '4102200', '静岡県', 'シズオカケン', '伊豆の国市', 'イズノクニシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('37181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊豆の国市古奈', '22', '22225', '4102201', '静岡県', 'シズオカケン', '伊豆の国市', 'イズノクニシ', '古奈', 'コナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊豆の国市天野', '22', '22225', '4102202', '静岡県', 'シズオカケン', '伊豆の国市', 'イズノクニシ', '天野', 'アマノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊豆の国市小坂', '22', '22225', '4102203', '静岡県', 'シズオカケン', '伊豆の国市', 'イズノクニシ', '小坂', 'オサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊豆の国市墹之上', '22', '22225', '4102204', '静岡県', 'シズオカケン', '伊豆の国市', 'イズノクニシ', '墹之上', 'ママノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊豆の国市富士見', '22', '22225', '4102205', '静岡県', 'シズオカケン', '伊豆の国市', 'イズノクニシ', '富士見', 'フジミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊豆の国市長岡', '22', '22225', '4102211', '静岡県', 'シズオカケン', '伊豆の国市', 'イズノクニシ', '長岡', 'ナガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊豆の国市長瀬', '22', '22225', '4102212', '静岡県', 'シズオカケン', '伊豆の国市', 'イズノクニシ', '長瀬', 'ナガセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊豆の国市戸沢', '22', '22225', '4102213', '静岡県', 'シズオカケン', '伊豆の国市', 'イズノクニシ', '戸沢', 'トサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊豆の国市花坂', '22', '22225', '4102214', '静岡県', 'シズオカケン', '伊豆の国市', 'イズノクニシ', '花坂', 'ハナサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊豆の国市南江間', '22', '22225', '4102221', '静岡県', 'シズオカケン', '伊豆の国市', 'イズノクニシ', '南江間', 'ミナミエマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊豆の国市北江間', '22', '22225', '4102223', '静岡県', 'シズオカケン', '伊豆の国市', 'イズノクニシ', '北江間', 'キタエマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊豆の国市田中山', '22', '22225', '4102301', '静岡県', 'シズオカケン', '伊豆の国市', 'イズノクニシ', '田中山', 'タナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊豆の国市宗光寺', '22', '22225', '4102302', '静岡県', 'シズオカケン', '伊豆の国市', 'イズノクニシ', '宗光寺', 'ソウコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊豆の国市立花', '22', '22225', '4102303', '静岡県', 'シズオカケン', '伊豆の国市', 'イズノクニシ', '立花', 'タチバナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊豆の国市宗光寺星和', '22', '22225', '4102304', '静岡県', 'シズオカケン', '伊豆の国市', 'イズノクニシ', '宗光寺', 'ソウコウジ', null, null, '星和', 'セイワ');
INSERT INTO `ms_addresses` VALUES ('37199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊豆の国市浮橋', '22', '22225', '4102311', '静岡県', 'シズオカケン', '伊豆の国市', 'イズノクニシ', '浮橋', 'ウキハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊豆の国市長者原', '22', '22225', '4102312', '静岡県', 'シズオカケン', '伊豆の国市', 'イズノクニシ', '長者原', 'チョウジャガハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊豆の国市田原野', '22', '22225', '4102313', '静岡県', 'シズオカケン', '伊豆の国市', 'イズノクニシ', '田原野', 'タワラノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊豆の国市下畑', '22', '22225', '4102314', '静岡県', 'シズオカケン', '伊豆の国市', 'イズノクニシ', '下畑', 'シモハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊豆の国市田京', '22', '22225', '4102315', '静岡県', 'シズオカケン', '伊豆の国市', 'イズノクニシ', '田京', 'タキョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊豆の国市御門', '22', '22225', '4102316', '静岡県', 'シズオカケン', '伊豆の国市', 'イズノクニシ', '御門', 'ミカド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊豆の国市守木', '22', '22225', '4102317', '静岡県', 'シズオカケン', '伊豆の国市', 'イズノクニシ', '守木', 'モリキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊豆の国市白山堂', '22', '22225', '4102318', '静岡県', 'シズオカケン', '伊豆の国市', 'イズノクニシ', '白山堂', 'シラヤマドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊豆の国市三福', '22', '22225', '4102321', '静岡県', 'シズオカケン', '伊豆の国市', 'イズノクニシ', '三福', 'ミフク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊豆の国市吉田', '22', '22225', '4102322', '静岡県', 'シズオカケン', '伊豆の国市', 'イズノクニシ', '吉田', 'ヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊豆の国市大仁', '22', '22225', '4102323', '静岡県', 'シズオカケン', '伊豆の国市', 'イズノクニシ', '大仁', 'オオヒト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊豆の国市中島', '22', '22225', '4102324', '静岡県', 'シズオカケン', '伊豆の国市', 'イズノクニシ', '中島', 'ナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊豆の国市神島', '22', '22225', '4102325', '静岡県', 'シズオカケン', '伊豆の国市', 'イズノクニシ', '神島', 'カミシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊豆市', '22', '22222', '4102400', '静岡県', 'シズオカケン', '伊豆市', 'イズシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('37218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊豆市牧之郷', '22', '22222', '4102401', '静岡県', 'シズオカケン', '伊豆市', 'イズシ', '牧之郷', 'マキノコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊豆市大野', '22', '22222', '4102402', '静岡県', 'シズオカケン', '伊豆市', 'イズシ', '大野', 'オオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊豆市年川', '22', '22222', '4102403', '静岡県', 'シズオカケン', '伊豆市', 'イズシ', '年川', 'トシガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊豆市田代', '22', '22222', '4102404', '静岡県', 'シズオカケン', '伊豆市', 'イズシ', '田代', 'タシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊豆市加殿', '22', '22222', '4102405', '静岡県', 'シズオカケン', '伊豆市', 'イズシ', '加殿', 'カドノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊豆市日向', '22', '22222', '4102406', '静岡県', 'シズオカケン', '伊豆市', 'イズシ', '日向', 'ヒナタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊豆市柏久保', '22', '22222', '4102407', '静岡県', 'シズオカケン', '伊豆市', 'イズシ', '柏久保', 'カシワクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊豆市熊坂', '22', '22222', '4102411', '静岡県', 'シズオカケン', '伊豆市', 'イズシ', '熊坂', 'クマサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊豆市瓜生野', '22', '22222', '4102412', '静岡県', 'シズオカケン', '伊豆市', 'イズシ', '瓜生野', 'ウリュウノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊豆市小立野', '22', '22222', '4102413', '静岡県', 'シズオカケン', '伊豆市', 'イズシ', '小立野', 'コダチノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊豆市本立野', '22', '22222', '4102414', '静岡県', 'シズオカケン', '伊豆市', 'イズシ', '本立野', 'ホンダチノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊豆市大平', '22', '22222', '4102415', '静岡県', 'シズオカケン', '伊豆市', 'イズシ', '大平', 'オオダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊豆市修善寺', '22', '22222', '4102416', '静岡県', 'シズオカケン', '伊豆市', 'イズシ', '修善寺', 'シュゼンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊豆市大沢', '22', '22222', '4102417', '静岡県', 'シズオカケン', '伊豆市', 'イズシ', '大沢', 'オオサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊豆市堀切', '22', '22222', '4102418', '静岡県', 'シズオカケン', '伊豆市', 'イズシ', '堀切', 'ホリギリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊豆市下白岩', '22', '22222', '4102501', '静岡県', 'シズオカケン', '伊豆市', 'イズシ', '下白岩', 'シモシライワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊豆市上白岩', '22', '22222', '4102502', '静岡県', 'シズオカケン', '伊豆市', 'イズシ', '上白岩', 'カミシライワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊豆市城', '22', '22222', '4102503', '静岡県', 'シズオカケン', '伊豆市', 'イズシ', '城', 'ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊豆市関野', '22', '22222', '4102504', '静岡県', 'シズオカケン', '伊豆市', 'イズシ', '関野', 'セキノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊豆市八幡', '22', '22222', '4102505', '静岡県', 'シズオカケン', '伊豆市', 'イズシ', '八幡', 'ハツマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊豆市徳永', '22', '22222', '4102506', '静岡県', 'シズオカケン', '伊豆市', 'イズシ', '徳永', 'トクナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊豆市冷川', '22', '22222', '4102507', '静岡県', 'シズオカケン', '伊豆市', 'イズシ', '冷川', 'ヒエカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊豆市柳瀬', '22', '22222', '4102508', '静岡県', 'シズオカケン', '伊豆市', 'イズシ', '柳瀬', 'ヤナセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊豆市梅木', '22', '22222', '4102509', '静岡県', 'シズオカケン', '伊豆市', 'イズシ', '梅木', 'ウメギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市小安町', '01', '01202', '0410251', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '小安町', 'オヤスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊豆市宮上', '22', '22222', '4102511', '静岡県', 'シズオカケン', '伊豆市', 'イズシ', '宮上', 'ミヤカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊豆市中原戸', '22', '22222', '4102512', '静岡県', 'シズオカケン', '伊豆市', 'イズシ', '中原戸', 'ナカハラト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊豆市菅引', '22', '22222', '4102513', '静岡県', 'シズオカケン', '伊豆市', 'イズシ', '菅引', 'スゲヒキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊豆市原保', '22', '22222', '4102514', '静岡県', 'シズオカケン', '伊豆市', 'イズシ', '原保', 'ワラボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊豆市地蔵堂', '22', '22222', '4102515', '静岡県', 'シズオカケン', '伊豆市', 'イズシ', '地蔵堂', 'ジゾウドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊豆市筏場', '22', '22222', '4102516', '静岡県', 'シズオカケン', '伊豆市', 'イズシ', '筏場', 'イカダバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊豆市貴僧坊', '22', '22222', '4102517', '静岡県', 'シズオカケン', '伊豆市', 'イズシ', '貴僧坊', 'キソウボウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊豆市姫之湯', '22', '22222', '4102518', '静岡県', 'シズオカケン', '伊豆市', 'イズシ', '姫之湯', 'ヒメノユ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊豆市戸倉野', '22', '22222', '4102519', '静岡県', 'シズオカケン', '伊豆市', 'イズシ', '戸倉野', 'トクラノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市釜谷町', '01', '01202', '0410252', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '釜谷町', 'カマヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市小安山町', '01', '01202', '0410253', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '小安山町', 'オヤスヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市石崎町', '01', '01202', '0410261', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '石崎町', 'イシザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市古川町', '01', '01202', '0410262', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '古川町', 'フルカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市豊原町', '01', '01202', '0410263', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '豊原町', 'トヨハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市鶴野町', '01', '01202', '0410264', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '鶴野町', 'ツルノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市白石町', '01', '01202', '0410265', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '白石町', 'シロイシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市汐首町', '01', '01202', '0410301', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '汐首町', 'シオクビチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市瀬田来町', '01', '01202', '0410302', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '瀬田来町', 'セタライチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市弁才町', '01', '01202', '0410303', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '弁才町', 'ベンザイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市泊町', '01', '01202', '0410304', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '泊町', 'トマリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市館町', '01', '01202', '0410305', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '館町', 'タテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市丸山町', '01', '01202', '0410306', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '丸山町', 'マルヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市浜町', '01', '01202', '0410311', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '浜町', 'ハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市新二見町', '01', '01202', '0410312', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '新二見町', 'シンフタミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市原木町', '01', '01202', '0410313', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '原木町', 'ハラキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊豆市佐野', '22', '22222', '4103201', '静岡県', 'シズオカケン', '伊豆市', 'イズシ', '佐野', 'サノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊豆市雲金', '22', '22222', '4103202', '静岡県', 'シズオカケン', '伊豆市', 'イズシ', '雲金', 'クモガネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊豆市矢熊', '22', '22222', '4103203', '静岡県', 'シズオカケン', '伊豆市', 'イズシ', '矢熊', 'ヤグマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊豆市田沢', '22', '22222', '4103204', '静岡県', 'シズオカケン', '伊豆市', 'イズシ', '田沢', 'タザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊豆市市山', '22', '22222', '4103205', '静岡県', 'シズオカケン', '伊豆市', 'イズシ', '市山', 'イチヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊豆市湯ケ島', '22', '22222', '4103206', '静岡県', 'シズオカケン', '伊豆市', 'イズシ', '湯ケ島', 'ユガシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊豆市持越', '22', '22222', '4103207', '静岡県', 'シズオカケン', '伊豆市', 'イズシ', '持越', 'モチコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊豆市吉奈', '22', '22222', '4103208', '静岡県', 'シズオカケン', '伊豆市', 'イズシ', '吉奈', 'ヨシナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊豆市門野原', '22', '22222', '4103209', '静岡県', 'シズオカケン', '伊豆市', 'イズシ', '門野原', 'カドノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊豆市松ケ瀬', '22', '22222', '4103211', '静岡県', 'シズオカケン', '伊豆市', 'イズシ', '松ケ瀬', 'マツガセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊豆市本柿木', '22', '22222', '4103212', '静岡県', 'シズオカケン', '伊豆市', 'イズシ', '本柿木', 'ホンカキギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊豆市青羽根', '22', '22222', '4103213', '静岡県', 'シズオカケン', '伊豆市', 'イズシ', '青羽根', 'アオバネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊豆市下船原', '22', '22222', '4103214', '静岡県', 'シズオカケン', '伊豆市', 'イズシ', '下船原', 'シモフナバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊豆市月ケ瀬', '22', '22222', '4103215', '静岡県', 'シズオカケン', '伊豆市', 'イズシ', '月ケ瀬', 'ツキガセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊豆市上船原', '22', '22222', '4103216', '静岡県', 'シズオカケン', '伊豆市', 'イズシ', '上船原', 'カミフナバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊豆市大平柿木', '22', '22222', '4103217', '静岡県', 'シズオカケン', '伊豆市', 'イズシ', '大平柿木', 'オオダイラカキギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊豆市小土肥', '22', '22222', '4103301', '静岡県', 'シズオカケン', '伊豆市', 'イズシ', '小土肥', 'オドイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊豆市土肥', '22', '22222', '4103302', '静岡県', 'シズオカケン', '伊豆市', 'イズシ', '土肥', 'トイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊豆市八木沢', '22', '22222', '4103303', '静岡県', 'シズオカケン', '伊豆市', 'イズシ', '八木沢', 'ヤギサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊豆市小下田', '22', '22222', '4103304', '静岡県', 'シズオカケン', '伊豆市', 'イズシ', '小下田', 'コシモダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市井田', '22', '22203', '4103401', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '井田', 'イタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県沼津市戸田', '22', '22203', '4103402', '静岡県', 'シズオカケン', '沼津市', 'ヌマヅシ', '戸田', 'ヘダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県賀茂郡西伊豆町', '22', '22306', '4103500', '静岡県', 'シズオカケン', '賀茂郡西伊豆町', 'カモグンニシイズチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('37294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県賀茂郡西伊豆町宇久須', '22', '22306', '4103501', '静岡県', 'シズオカケン', '賀茂郡西伊豆町', 'カモグンニシイズチョウ', '宇久須', 'ウグス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県賀茂郡西伊豆町安良里', '22', '22306', '4103502', '静岡県', 'シズオカケン', '賀茂郡西伊豆町', 'カモグンニシイズチョウ', '安良里', 'アラリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県賀茂郡西伊豆町大沢里', '22', '22306', '4103511', '静岡県', 'シズオカケン', '賀茂郡西伊豆町', 'カモグンニシイズチョウ', '大沢里', 'オオソウリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県賀茂郡西伊豆町一色', '22', '22306', '4103512', '静岡県', 'シズオカケン', '賀茂郡西伊豆町', 'カモグンニシイズチョウ', '一色', 'イシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県賀茂郡西伊豆町中', '22', '22306', '4103513', '静岡県', 'シズオカケン', '賀茂郡西伊豆町', 'カモグンニシイズチョウ', '中', 'ナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県賀茂郡西伊豆町仁科', '22', '22306', '4103514', '静岡県', 'シズオカケン', '賀茂郡西伊豆町', 'カモグンニシイズチョウ', '仁科', 'ニシナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県賀茂郡西伊豆町田子', '22', '22306', '4103515', '静岡県', 'シズオカケン', '賀茂郡西伊豆町', 'カモグンニシイズチョウ', '田子', 'タゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県賀茂郡松崎町', '22', '22305', '4103600', '静岡県', 'シズオカケン', '賀茂郡松崎町', 'カモグンマツザキチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('37302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県賀茂郡松崎町池代', '22', '22305', '4103601', '静岡県', 'シズオカケン', '賀茂郡松崎町', 'カモグンマツザキチョウ', '池代', 'イケシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県賀茂郡松崎町小杉原', '22', '22305', '4103602', '静岡県', 'シズオカケン', '賀茂郡松崎町', 'カモグンマツザキチョウ', '小杉原', 'コスギハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県賀茂郡松崎町明伏', '22', '22305', '4103603', '静岡県', 'シズオカケン', '賀茂郡松崎町', 'カモグンマツザキチョウ', '明伏', 'アケブシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県賀茂郡松崎町大沢', '22', '22305', '4103604', '静岡県', 'シズオカケン', '賀茂郡松崎町', 'カモグンマツザキチョウ', '大沢', 'オオサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県賀茂郡松崎町峰輪', '22', '22305', '4103605', '静岡県', 'シズオカケン', '賀茂郡松崎町', 'カモグンマツザキチョウ', '峰輪', 'ミネワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県賀茂郡松崎町船田', '22', '22305', '4103606', '静岡県', 'シズオカケン', '賀茂郡松崎町', 'カモグンマツザキチョウ', '船田', 'フナタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県賀茂郡松崎町門野', '22', '22305', '4103607', '静岡県', 'シズオカケン', '賀茂郡松崎町', 'カモグンマツザキチョウ', '門野', 'カドノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県賀茂郡松崎町松崎', '22', '22305', '4103611', '静岡県', 'シズオカケン', '賀茂郡松崎町', 'カモグンマツザキチョウ', '松崎', 'マツザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県賀茂郡松崎町宮内', '22', '22305', '4103612', '静岡県', 'シズオカケン', '賀茂郡松崎町', 'カモグンマツザキチョウ', '宮内', 'ミヤウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県賀茂郡松崎町岩科北側', '22', '22305', '4103613', '静岡県', 'シズオカケン', '賀茂郡松崎町', 'カモグンマツザキチョウ', '岩科北側', 'イワシナホクソク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県賀茂郡松崎町岩科南側', '22', '22305', '4103614', '静岡県', 'シズオカケン', '賀茂郡松崎町', 'カモグンマツザキチョウ', '岩科南側', 'イワシナナンソク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県賀茂郡松崎町雲見', '22', '22305', '4103615', '静岡県', 'シズオカケン', '賀茂郡松崎町', 'カモグンマツザキチョウ', '雲見', 'クモミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県賀茂郡松崎町石部', '22', '22305', '4103616', '静岡県', 'シズオカケン', '賀茂郡松崎町', 'カモグンマツザキチョウ', '石部', 'イシブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県賀茂郡松崎町岩地', '22', '22305', '4103617', '静岡県', 'シズオカケン', '賀茂郡松崎町', 'カモグンマツザキチョウ', '岩地', 'イワチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県賀茂郡松崎町道部', '22', '22305', '4103618', '静岡県', 'シズオカケン', '賀茂郡松崎町', 'カモグンマツザキチョウ', '道部', 'ミチブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県賀茂郡松崎町吉田', '22', '22305', '4103621', '静岡県', 'シズオカケン', '賀茂郡松崎町', 'カモグンマツザキチョウ', '吉田', 'ヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県賀茂郡松崎町南郷', '22', '22305', '4103622', '静岡県', 'シズオカケン', '賀茂郡松崎町', 'カモグンマツザキチョウ', '南郷', 'ナンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県賀茂郡松崎町伏倉', '22', '22305', '4103623', '静岡県', 'シズオカケン', '賀茂郡松崎町', 'カモグンマツザキチョウ', '伏倉', 'シクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県賀茂郡松崎町江奈', '22', '22305', '4103624', '静岡県', 'シズオカケン', '賀茂郡松崎町', 'カモグンマツザキチョウ', '江奈', 'エナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県賀茂郡松崎町桜田', '22', '22305', '4103625', '静岡県', 'シズオカケン', '賀茂郡松崎町', 'カモグンマツザキチョウ', '桜田', 'サクラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県賀茂郡松崎町那賀', '22', '22305', '4103626', '静岡県', 'シズオカケン', '賀茂郡松崎町', 'カモグンマツザキチョウ', '那賀', 'ナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県賀茂郡松崎町建久寺', '22', '22305', '4103627', '静岡県', 'シズオカケン', '賀茂郡松崎町', 'カモグンマツザキチョウ', '建久寺', 'ケンキュウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市日浦町', '01', '01202', '0410401', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '日浦町', 'ヒウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市豊浦町', '01', '01202', '0410402', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '豊浦町', 'トヨウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市大澗町', '01', '01202', '0410403', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '大澗町', 'オオマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市中浜町', '01', '01202', '0410404', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '中浜町', 'ナカハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市川上町', '01', '01202', '0410405', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '川上町', 'カワカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市女那川町', '01', '01202', '0410406', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '女那川町', 'メナガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市日和山町', '01', '01202', '0410407', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '日和山町', 'ヒヨリヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市吉畑町', '01', '01202', '0410408', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '吉畑町', 'キチハタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市御崎町', '01', '01202', '0410521', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '御崎町', 'ミサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市恵山町', '01', '01202', '0410522', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '恵山町', 'エサンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市柏野町', '01', '01202', '0410523', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '柏野町', 'カシワノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市古武井町', '01', '01202', '0410524', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '古武井町', 'コブイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市日ノ浜町', '01', '01202', '0410525', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '日ノ浜町', 'ヒノハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市高岱町', '01', '01202', '0410526', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '高岱町', 'タカダイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市新八幡町', '01', '01202', '0410601', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '新八幡町', 'シンハチマンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市島泊町', '01', '01202', '0410602', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '島泊町', 'シマドマリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市富浦町', '01', '01202', '0410603', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '富浦町', 'トミウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市元村町', '01', '01202', '0410604', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '元村町', 'モトムラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市恵山岬町', '01', '01202', '0410605', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '恵山岬町', 'エサンミサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市新恵山町', '01', '01202', '0410606', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '新恵山町', 'シンエサンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市新浜町', '01', '01202', '0410611', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '新浜町', 'シンハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市銚子町', '01', '01202', '0410612', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '銚子町', 'チョウシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市絵紙山町', '01', '01202', '0410613', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '絵紙山町', 'エガミヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市桔梗町', '01', '01202', '0410801', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '桔梗町', 'キキョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市石川町', '01', '01202', '0410802', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '石川町', 'イシカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市亀田中野町', '01', '01202', '0410803', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '亀田中野町', 'カメダナカノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市赤川町', '01', '01202', '0410804', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '赤川町', 'アカガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市赤川', '01', '01202', '0410805', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '赤川', 'アカガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市美原', '01', '01202', '0410806', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '美原', 'ミハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市北美原', '01', '01202', '0410807', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '北美原', 'キタミハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市桔梗', '01', '01202', '0410808', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '桔梗', 'キキョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市富岡町', '01', '01202', '0410811', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '富岡町', 'トミオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市昭和', '01', '01202', '0410812', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '昭和', 'ショウワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市亀田本町', '01', '01202', '0410813', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '亀田本町', 'カメダホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市港町', '01', '01202', '0410821', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '港町', 'ミナトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市亀田港町', '01', '01202', '0410822', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '亀田港町', 'カメダミナトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市昭和町', '01', '01202', '0410823', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '昭和町', 'ショウワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市西桔梗町', '01', '01202', '0410824', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '西桔梗町', 'ニシキキョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市神山町', '01', '01202', '0410831', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '神山町', 'カミヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市神山', '01', '01202', '0410832', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '神山', 'カミヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市陣川町', '01', '01202', '0410833', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '陣川町', 'ジンカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市東山町', '01', '01202', '0410834', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '東山町', 'ヒガシヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市東山', '01', '01202', '0410835', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '東山', 'ヒガシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市山の手', '01', '01202', '0410836', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '山の手', 'ヤマノテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市陣川', '01', '01202', '0410837', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '陣川', 'ジンカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市日吉町', '01', '01202', '0410841', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '日吉町', 'ヒヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市滝沢町', '01', '01202', '0410842', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '滝沢町', 'タキサワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市花園町', '01', '01202', '0410843', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '花園町', 'ハナゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市川原町', '01', '01202', '0410844', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '川原町', 'カワハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市本通', '01', '01202', '0410851', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '本通', 'ホンドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市鍛治', '01', '01202', '0410852', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '鍛治', 'カジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市中道', '01', '01202', '0410853', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '中道', 'ナカミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県三島市', '22', '22206', '4110000', '静岡県', 'シズオカケン', '三島市', 'ミシマシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('37416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県駿東郡清水町', '22', '22341', '4110000', '静岡県', 'シズオカケン', '駿東郡清水町', 'スントウグンシミズチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('37417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県駿東郡長泉町', '22', '22342', '4110000', '静岡県', 'シズオカケン', '駿東郡長泉町', 'スントウグンナガイズミチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('37418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県田方郡函南町桑原茨ケ平', '22', '22325', '4110001', '静岡県', 'シズオカケン', '田方郡函南町', 'タガタグンカンナミチョウ', '桑原', 'クワハラ', null, null, '茨ケ平', 'イバラガヒラ');
INSERT INTO `ms_addresses` VALUES ('37419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県田方郡函南町桑原箱根峠', '22', '22325', '4110001', '静岡県', 'シズオカケン', '田方郡函南町', 'タガタグンカンナミチョウ', '桑原', 'クワハラ', null, null, '箱根峠', 'ハコネトウゲ');
INSERT INTO `ms_addresses` VALUES ('37420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県三島市山中新田', '22', '22206', '4110011', '静岡県', 'シズオカケン', '三島市', 'ミシマシ', '山中新田', 'ヤマナカシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県三島市笹原新田', '22', '22206', '4110012', '静岡県', 'シズオカケン', '三島市', 'ミシマシ', '笹原新田', 'ササハラシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県三島市三ツ谷新田', '22', '22206', '4110013', '静岡県', 'シズオカケン', '三島市', 'ミシマシ', '三ツ谷新田', 'ミツヤシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県三島市玉沢', '22', '22206', '4110014', '静岡県', 'シズオカケン', '三島市', 'ミシマシ', '玉沢', 'タマザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県三島市市ノ山新田', '22', '22206', '4110015', '静岡県', 'シズオカケン', '三島市', 'ミシマシ', '市ノ山新田', 'イチノヤマシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県三島市塚原新田', '22', '22206', '4110016', '静岡県', 'シズオカケン', '三島市', 'ミシマシ', '塚原新田', 'ツカハラシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県三島市三恵台', '22', '22206', '4110017', '静岡県', 'シズオカケン', '三島市', 'ミシマシ', '三恵台', 'サンケイダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県三島市初音台', '22', '22206', '4110018', '静岡県', 'シズオカケン', '三島市', 'ミシマシ', '初音台', 'ハツネダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県三島市松が丘', '22', '22206', '4110019', '静岡県', 'シズオカケン', '三島市', 'ミシマシ', '松が丘', 'マツガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県三島市旭ケ丘', '22', '22206', '4110020', '静岡県', 'シズオカケン', '三島市', 'ミシマシ', '旭ケ丘', 'アサヒガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県三島市富士見台', '22', '22206', '4110021', '静岡県', 'シズオカケン', '三島市', 'ミシマシ', '富士見台', 'フジミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県三島市川原ケ谷', '22', '22206', '4110022', '静岡県', 'シズオカケン', '三島市', 'ミシマシ', '川原ケ谷', 'カワハラガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県三島市加茂', '22', '22206', '4110023', '静岡県', 'シズオカケン', '三島市', 'ミシマシ', '加茂', 'カモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県三島市若松町', '22', '22206', '4110024', '静岡県', 'シズオカケン', '三島市', 'ミシマシ', '若松町', 'ワカマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県三島市壱町田', '22', '22206', '4110025', '静岡県', 'シズオカケン', '三島市', 'ミシマシ', '壱町田', 'イッチョウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県三島市東壱町田', '22', '22206', '4110026', '静岡県', 'シズオカケン', '三島市', 'ミシマシ', '東壱町田', 'ヒガシイッチョウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県三島市千枚原', '22', '22206', '4110027', '静岡県', 'シズオカケン', '三島市', 'ミシマシ', '千枚原', 'センマイバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県三島市富士ビレッジ', '22', '22206', '4110028', '静岡県', 'シズオカケン', '三島市', 'ミシマシ', '富士ビレッジ', 'フジビレッジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県三島市光ケ丘', '22', '22206', '4110029', '静岡県', 'シズオカケン', '三島市', 'ミシマシ', '光ケ丘', 'ヒカリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県三島市幸原町', '22', '22206', '4110031', '静岡県', 'シズオカケン', '三島市', 'ミシマシ', '幸原町', 'コウバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県三島市末広町', '22', '22206', '4110032', '静岡県', 'シズオカケン', '三島市', 'ミシマシ', '末広町', 'スエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県三島市文教町', '22', '22206', '4110033', '静岡県', 'シズオカケン', '三島市', 'ミシマシ', '文教町', 'ブンキョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県三島市加茂川町', '22', '22206', '4110034', '静岡県', 'シズオカケン', '三島市', 'ミシマシ', '加茂川町', 'カモガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県三島市大宮町', '22', '22206', '4110035', '静岡県', 'シズオカケン', '三島市', 'ミシマシ', '大宮町', 'オオミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県三島市一番町', '22', '22206', '4110036', '静岡県', 'シズオカケン', '三島市', 'ミシマシ', '一番町', 'イチバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県三島市泉町', '22', '22206', '4110037', '静岡県', 'シズオカケン', '三島市', 'ミシマシ', '泉町', 'イズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県三島市西若町', '22', '22206', '4110038', '静岡県', 'シズオカケン', '三島市', 'ミシマシ', '西若町', 'ニシワカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県三島市寿町', '22', '22206', '4110039', '静岡県', 'シズオカケン', '三島市', 'ミシマシ', '寿町', 'コトブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県三島市佐野見晴台', '22', '22206', '4110041', '静岡県', 'シズオカケン', '三島市', 'ミシマシ', '佐野見晴台', 'サノミハラシダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県三島市平成台', '22', '22206', '4110042', '静岡県', 'シズオカケン', '三島市', 'ミシマシ', '平成台', 'ヘイセイダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県三島市沢地', '22', '22206', '4110043', '静岡県', 'シズオカケン', '三島市', 'ミシマシ', '沢地', 'サワジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県三島市徳倉', '22', '22206', '4110044', '静岡県', 'シズオカケン', '三島市', 'ミシマシ', '徳倉', 'トクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県三島市萩', '22', '22206', '4110045', '静岡県', 'シズオカケン', '三島市', 'ミシマシ', '萩', 'ハギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県三島市芙蓉台', '22', '22206', '4110046', '静岡県', 'シズオカケン', '三島市', 'ミシマシ', '芙蓉台', 'フヨウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県三島市佐野', '22', '22206', '4110047', '静岡県', 'シズオカケン', '三島市', 'ミシマシ', '佐野', 'サノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県三島市谷田', '22', '22206', '4110801', '静岡県', 'シズオカケン', '三島市', 'ミシマシ', '谷田', 'ヤタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県三島市東大場', '22', '22206', '4110802', '静岡県', 'シズオカケン', '三島市', 'ミシマシ', '東大場', 'ヒガシダイバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県三島市大場', '22', '22206', '4110803', '静岡県', 'シズオカケン', '三島市', 'ミシマシ', '大場', 'ダイバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県三島市多呂', '22', '22206', '4110804', '静岡県', 'シズオカケン', '三島市', 'ミシマシ', '多呂', 'タロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県三島市北沢', '22', '22206', '4110805', '静岡県', 'シズオカケン', '三島市', 'ミシマシ', '北沢', 'キタザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県三島市柳郷地', '22', '22206', '4110806', '静岡県', 'シズオカケン', '三島市', 'ミシマシ', '柳郷地', 'ヤナギゴウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県三島市竹倉', '22', '22206', '4110807', '静岡県', 'シズオカケン', '三島市', 'ミシマシ', '竹倉', 'タケクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県三島市錦が丘', '22', '22206', '4110808', '静岡県', 'シズオカケン', '三島市', 'ミシマシ', '錦が丘', 'ニシキガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県三島市青木', '22', '22206', '4110811', '静岡県', 'シズオカケン', '三島市', 'ミシマシ', '青木', 'アオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県三島市藤代町', '22', '22206', '4110812', '静岡県', 'シズオカケン', '三島市', 'ミシマシ', '藤代町', 'フジシロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県三島市鶴喰', '22', '22206', '4110813', '静岡県', 'シズオカケン', '三島市', 'ミシマシ', '鶴喰', 'ツルハミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県三島市中島', '22', '22206', '4110814', '静岡県', 'シズオカケン', '三島市', 'ミシマシ', '中島', 'ナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県三島市安久', '22', '22206', '4110815', '静岡県', 'シズオカケン', '三島市', 'ミシマシ', '安久', 'ヤスヒサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県三島市梅名', '22', '22206', '4110816', '静岡県', 'シズオカケン', '三島市', 'ミシマシ', '梅名', 'ウメナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県三島市八反畑', '22', '22206', '4110817', '静岡県', 'シズオカケン', '三島市', 'ミシマシ', '八反畑', 'ハッタバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県三島市平田', '22', '22206', '4110821', '静岡県', 'シズオカケン', '三島市', 'ミシマシ', '平田', 'ヒラタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県三島市松本', '22', '22206', '4110822', '静岡県', 'シズオカケン', '三島市', 'ミシマシ', '松本', 'マツモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県三島市御園', '22', '22206', '4110823', '静岡県', 'シズオカケン', '三島市', 'ミシマシ', '御園', 'ミソノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県三島市長伏', '22', '22206', '4110824', '静岡県', 'シズオカケン', '三島市', 'ミシマシ', '長伏', 'ナガブセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県三島市東本町', '22', '22206', '4110831', '静岡県', 'シズオカケン', '三島市', 'ミシマシ', '東本町', 'ヒガシホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県三島市南二日町', '22', '22206', '4110832', '静岡県', 'シズオカケン', '三島市', 'ミシマシ', '南二日町', 'ミナミフツカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県三島市中', '22', '22206', '4110833', '静岡県', 'シズオカケン', '三島市', 'ミシマシ', '中', 'ナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県三島市新谷', '22', '22206', '4110834', '静岡県', 'シズオカケン', '三島市', 'ミシマシ', '新谷', 'アラヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県三島市玉川', '22', '22206', '4110835', '静岡県', 'シズオカケン', '三島市', 'ミシマシ', '玉川', 'タマガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県三島市富田町', '22', '22206', '4110836', '静岡県', 'シズオカケン', '三島市', 'ミシマシ', '富田町', 'トミタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県三島市南田町', '22', '22206', '4110837', '静岡県', 'シズオカケン', '三島市', 'ミシマシ', '南田町', 'ミナミタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県三島市中田町', '22', '22206', '4110838', '静岡県', 'シズオカケン', '三島市', 'ミシマシ', '中田町', 'ナカタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県三島市南本町', '22', '22206', '4110841', '静岡県', 'シズオカケン', '三島市', 'ミシマシ', '南本町', 'ミナミホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県三島市南町', '22', '22206', '4110842', '静岡県', 'シズオカケン', '三島市', 'ミシマシ', '南町', 'ミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県三島市三好町', '22', '22206', '4110843', '静岡県', 'シズオカケン', '三島市', 'ミシマシ', '三好町', 'ミヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県三島市清住町', '22', '22206', '4110844', '静岡県', 'シズオカケン', '三島市', 'ミシマシ', '清住町', 'キヨズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県三島市加屋町', '22', '22206', '4110845', '静岡県', 'シズオカケン', '三島市', 'ミシマシ', '加屋町', 'カヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県三島市栄町', '22', '22206', '4110846', '静岡県', 'シズオカケン', '三島市', 'ミシマシ', '栄町', 'サカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県三島市西本町', '22', '22206', '4110847', '静岡県', 'シズオカケン', '三島市', 'ミシマシ', '西本町', 'ニシホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県三島市緑町', '22', '22206', '4110848', '静岡県', 'シズオカケン', '三島市', 'ミシマシ', '緑町', 'ミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県三島市日の出町', '22', '22206', '4110851', '静岡県', 'シズオカケン', '三島市', 'ミシマシ', '日の出町', 'ヒノデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県三島市東町', '22', '22206', '4110852', '静岡県', 'シズオカケン', '三島市', 'ミシマシ', '東町', 'ヒガシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県三島市大社町', '22', '22206', '4110853', '静岡県', 'シズオカケン', '三島市', 'ミシマシ', '大社町', 'タイシャチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県三島市北田町', '22', '22206', '4110854', '静岡県', 'シズオカケン', '三島市', 'ミシマシ', '北田町', 'キタタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県三島市本町', '22', '22206', '4110855', '静岡県', 'シズオカケン', '三島市', 'ミシマシ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県三島市広小路町', '22', '22206', '4110856', '静岡県', 'シズオカケン', '三島市', 'ミシマシ', '広小路町', 'ヒロコウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県三島市芝本町', '22', '22206', '4110857', '静岡県', 'シズオカケン', '三島市', 'ミシマシ', '芝本町', 'シバホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県三島市中央町', '22', '22206', '4110858', '静岡県', 'シズオカケン', '三島市', 'ミシマシ', '中央町', 'チュウオウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県駿東郡清水町新宿', '22', '22341', '4110901', '静岡県', 'シズオカケン', '駿東郡清水町', 'スントウグンシミズチョウ', '新宿', 'シンシュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県駿東郡清水町玉川', '22', '22341', '4110902', '静岡県', 'シズオカケン', '駿東郡清水町', 'スントウグンシミズチョウ', '玉川', 'タマガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県駿東郡清水町堂庭', '22', '22341', '4110903', '静岡県', 'シズオカケン', '駿東郡清水町', 'スントウグンシミズチョウ', '堂庭', 'ドウニワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県駿東郡清水町柿田', '22', '22341', '4110904', '静岡県', 'シズオカケン', '駿東郡清水町', 'スントウグンシミズチョウ', '柿田', 'カキダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県駿東郡清水町長沢', '22', '22341', '4110905', '静岡県', 'シズオカケン', '駿東郡清水町', 'スントウグンシミズチョウ', '長沢', 'ナガサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県駿東郡清水町八幡', '22', '22341', '4110906', '静岡県', 'シズオカケン', '駿東郡清水町', 'スントウグンシミズチョウ', '八幡', 'ヤハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県駿東郡清水町伏見', '22', '22341', '4110907', '静岡県', 'シズオカケン', '駿東郡清水町', 'スントウグンシミズチョウ', '伏見', 'フシミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県駿東郡清水町久米田', '22', '22341', '4110911', '静岡県', 'シズオカケン', '駿東郡清水町', 'スントウグンシミズチョウ', '久米田', 'クマイデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県駿東郡清水町卸団地', '22', '22341', '4110912', '静岡県', 'シズオカケン', '駿東郡清水町', 'スントウグンシミズチョウ', '卸団地', 'オロシダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県駿東郡清水町戸田', '22', '22341', '4110913', '静岡県', 'シズオカケン', '駿東郡清水町', 'スントウグンシミズチョウ', '戸田', 'トダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県駿東郡清水町畑中', '22', '22341', '4110914', '静岡県', 'シズオカケン', '駿東郡清水町', 'スントウグンシミズチョウ', '畑中', 'ハタケナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県駿東郡清水町的場', '22', '22341', '4110915', '静岡県', 'シズオカケン', '駿東郡清水町', 'スントウグンシミズチョウ', '的場', 'マトバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県駿東郡清水町中徳倉', '22', '22341', '4110916', '静岡県', 'シズオカケン', '駿東郡清水町', 'スントウグンシミズチョウ', '中徳倉', 'ナカトクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県駿東郡清水町徳倉上徳倉', '22', '22341', '4110917', '静岡県', 'シズオカケン', '駿東郡清水町', 'スントウグンシミズチョウ', '徳倉', 'トクラ', null, null, '上徳倉', 'カミトクラ');
INSERT INTO `ms_addresses` VALUES ('37512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県駿東郡清水町徳倉下徳倉', '22', '22341', '4110917', '静岡県', 'シズオカケン', '駿東郡清水町', 'スントウグンシミズチョウ', '徳倉', 'トクラ', null, null, '下徳倉', 'シモトクラ');
INSERT INTO `ms_addresses` VALUES ('37513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県駿東郡清水町徳倉外原', '22', '22341', '4110917', '静岡県', 'シズオカケン', '駿東郡清水町', 'スントウグンシミズチョウ', '徳倉', 'トクラ', null, null, '外原', 'ソトハラ');
INSERT INTO `ms_addresses` VALUES ('37514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県駿東郡清水町湯川', '22', '22341', '4110918', '静岡県', 'シズオカケン', '駿東郡清水町', 'スントウグンシミズチョウ', '湯川', 'ユカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県駿東郡長泉町東野', '22', '22342', '4110931', '静岡県', 'シズオカケン', '駿東郡長泉町', 'スントウグンナガイズミチョウ', '東野', 'ヒガシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県駿東郡長泉町南一色', '22', '22342', '4110932', '静岡県', 'シズオカケン', '駿東郡長泉町', 'スントウグンナガイズミチョウ', '南一色', 'ミナミイシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県駿東郡長泉町納米里', '22', '22342', '4110933', '静岡県', 'シズオカケン', '駿東郡長泉町', 'スントウグンナガイズミチョウ', '納米里', 'ナメリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県駿東郡長泉町下長窪', '22', '22342', '4110934', '静岡県', 'シズオカケン', '駿東郡長泉町', 'スントウグンナガイズミチョウ', '下長窪', 'シモナガクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県駿東郡長泉町上長窪', '22', '22342', '4110935', '静岡県', 'シズオカケン', '駿東郡長泉町', 'スントウグンナガイズミチョウ', '上長窪', 'カミナガクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県駿東郡長泉町元長窪', '22', '22342', '4110936', '静岡県', 'シズオカケン', '駿東郡長泉町', 'スントウグンナガイズミチョウ', '元長窪', 'モトナガクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県駿東郡長泉町上土狩', '22', '22342', '4110941', '静岡県', 'シズオカケン', '駿東郡長泉町', 'スントウグンナガイズミチョウ', '上土狩', 'カミトガリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県駿東郡長泉町中土狩', '22', '22342', '4110942', '静岡県', 'シズオカケン', '駿東郡長泉町', 'スントウグンナガイズミチョウ', '中土狩', 'ナカトガリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県駿東郡長泉町下土狩', '22', '22342', '4110943', '静岡県', 'シズオカケン', '駿東郡長泉町', 'スントウグンナガイズミチョウ', '下土狩', 'シモトガリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県駿東郡長泉町竹原', '22', '22342', '4110944', '静岡県', 'シズオカケン', '駿東郡長泉町', 'スントウグンナガイズミチョウ', '竹原', 'タケハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県駿東郡長泉町本宿', '22', '22342', '4110945', '静岡県', 'シズオカケン', '駿東郡長泉町', 'スントウグンナガイズミチョウ', '本宿', 'ホンジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県駿東郡長泉町桜堤', '22', '22342', '4110951', '静岡県', 'シズオカケン', '駿東郡長泉町', 'スントウグンナガイズミチョウ', '桜堤', 'サクラヅツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道亀田郡七飯町', '01', '01337', '0411100', '北海道', 'ホッカイドウ', '亀田郡七飯町', 'カメダグンナナエチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('37528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道亀田郡七飯町仁山', '01', '01337', '0411101', '北海道', 'ホッカイドウ', '亀田郡七飯町', 'カメダグンナナエチョウ', '仁山', 'ニヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道亀田郡七飯町峠下', '01', '01337', '0411102', '北海道', 'ホッカイドウ', '亀田郡七飯町', 'カメダグンナナエチョウ', '峠下', 'トウゲシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道亀田郡七飯町藤城', '01', '01337', '0411103', '北海道', 'ホッカイドウ', '亀田郡七飯町', 'カメダグンナナエチョウ', '藤城', 'フジシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道亀田郡七飯町上藤城', '01', '01337', '0411104', '北海道', 'ホッカイドウ', '亀田郡七飯町', 'カメダグンナナエチョウ', '上藤城', 'カミフジシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道亀田郡七飯町桜町', '01', '01337', '0411105', '北海道', 'ホッカイドウ', '亀田郡七飯町', 'カメダグンナナエチョウ', '桜町', 'サクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道亀田郡七飯町本町', '01', '01337', '0411111', '北海道', 'ホッカイドウ', '亀田郡七飯町', 'カメダグンナナエチョウ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道亀田郡七飯町鳴川', '01', '01337', '0411112', '北海道', 'ホッカイドウ', '亀田郡七飯町', 'カメダグンナナエチョウ', '鳴川', 'ナルカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道亀田郡七飯町鳴川町', '01', '01337', '0411112', '北海道', 'ホッカイドウ', '亀田郡七飯町', 'カメダグンナナエチョウ', '鳴川町', 'ナルカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道亀田郡七飯町大中山', '01', '01337', '0411121', '北海道', 'ホッカイドウ', '亀田郡七飯町', 'カメダグンナナエチョウ', '大中山', 'オオナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道亀田郡七飯町大川', '01', '01337', '0411122', '北海道', 'ホッカイドウ', '亀田郡七飯町', 'カメダグンナナエチョウ', '大川', 'オオカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道亀田郡七飯町中野', '01', '01337', '0411131', '北海道', 'ホッカイドウ', '亀田郡七飯町', 'カメダグンナナエチョウ', '中野', 'ナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道亀田郡七飯町豊田', '01', '01337', '0411132', '北海道', 'ホッカイドウ', '亀田郡七飯町', 'カメダグンナナエチョウ', '豊田', 'トヨダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道亀田郡七飯町中島', '01', '01337', '0411133', '北海道', 'ホッカイドウ', '亀田郡七飯町', 'カメダグンナナエチョウ', '中島', 'ナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道亀田郡七飯町鶴野', '01', '01337', '0411134', '北海道', 'ホッカイドウ', '亀田郡七飯町', 'カメダグンナナエチョウ', '鶴野', 'ツルノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道亀田郡七飯町緑町', '01', '01337', '0411135', '北海道', 'ホッカイドウ', '亀田郡七飯町', 'カメダグンナナエチョウ', '緑町', 'ミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道亀田郡七飯町飯田町', '01', '01337', '0411136', '北海道', 'ホッカイドウ', '亀田郡七飯町', 'カメダグンナナエチョウ', '飯田町', 'イイダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北斗市本町', '01', '01236', '0411201', '北海道', 'ホッカイドウ', '北斗市', 'ホクトシ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北斗市白川', '01', '01236', '0411211', '北海道', 'ホッカイドウ', '北斗市', 'ホクトシ', '白川', 'シラカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北斗市細入', '01', '01236', '0411212', '北海道', 'ホッカイドウ', '北斗市', 'ホクトシ', '細入', 'ホソイレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北斗市開発', '01', '01236', '0411213', '北海道', 'ホッカイドウ', '北斗市', 'ホクトシ', '開発', 'カイハツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北斗市東前', '01', '01236', '0411214', '北海道', 'ホッカイドウ', '北斗市', 'ホクトシ', '東前', 'ヒガシマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北斗市萩野', '01', '01236', '0411215', '北海道', 'ホッカイドウ', '北斗市', 'ホクトシ', '萩野', 'ハギノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北斗市清水川', '01', '01236', '0411221', '北海道', 'ホッカイドウ', '北斗市', 'ホクトシ', '清水川', 'シミズカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北斗市千代田', '01', '01236', '0411222', '北海道', 'ホッカイドウ', '北斗市', 'ホクトシ', '千代田', 'チヨダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北斗市一本木', '01', '01236', '0411223', '北海道', 'ホッカイドウ', '北斗市', 'ホクトシ', '一本木', 'イッポンギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北斗市南大野', '01', '01236', '0411224', '北海道', 'ホッカイドウ', '北斗市', 'ホクトシ', '南大野', 'ミナミオオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北斗市文月', '01', '01236', '0411225', '北海道', 'ホッカイドウ', '北斗市', 'ホクトシ', '文月', 'フミヅキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北斗市村内', '01', '01236', '0411226', '北海道', 'ホッカイドウ', '北斗市', 'ホクトシ', '村内', 'ムラウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北斗市向野', '01', '01236', '0411231', '北海道', 'ホッカイドウ', '北斗市', 'ホクトシ', '向野', 'ムカイノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北斗市稲里', '01', '01236', '0411241', '北海道', 'ホッカイドウ', '北斗市', 'ホクトシ', '稲里', 'イナサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北斗市市渡', '01', '01236', '0411242', '北海道', 'ホッカイドウ', '北斗市', 'ホクトシ', '市渡', 'イチノワタリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北斗市中山', '01', '01236', '0411243', '北海道', 'ホッカイドウ', '北斗市', 'ホクトシ', '中山', 'ナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北斗市村山', '01', '01236', '0411244', '北海道', 'ホッカイドウ', '北斗市', 'ホクトシ', '村山', 'ムラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北斗市本郷', '01', '01236', '0411251', '北海道', 'ホッカイドウ', '北斗市', 'ホクトシ', '本郷', 'ホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道亀田郡七飯町東大沼', '01', '01337', '0411351', '北海道', 'ホッカイドウ', '亀田郡七飯町', 'カメダグンナナエチョウ', '東大沼', 'ヒガシオオヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道亀田郡七飯町軍川', '01', '01337', '0411352', '北海道', 'ホッカイドウ', '亀田郡七飯町', 'カメダグンナナエチョウ', '軍川', 'イクサガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道亀田郡七飯町上軍川', '01', '01337', '0411353', '北海道', 'ホッカイドウ', '亀田郡七飯町', 'カメダグンナナエチョウ', '上軍川', 'カミイクサガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道亀田郡七飯町大沼町', '01', '01337', '0411354', '北海道', 'ホッカイドウ', '亀田郡七飯町', 'カメダグンナナエチョウ', '大沼町', 'オオヌマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道亀田郡七飯町西大沼', '01', '01337', '0411355', '北海道', 'ホッカイドウ', '亀田郡七飯町', 'カメダグンナナエチョウ', '西大沼', 'ニシオオヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道茅部郡鹿部町', '01', '01343', '0411400', '北海道', 'ホッカイドウ', '茅部郡鹿部町', 'カヤベグンシカベチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('37574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道茅部郡鹿部町大岩', '01', '01343', '0411401', '北海道', 'ホッカイドウ', '茅部郡鹿部町', 'カヤベグンシカベチョウ', '大岩', 'オオイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道茅部郡鹿部町鹿部', '01', '01343', '0411402', '北海道', 'ホッカイドウ', '茅部郡鹿部町', 'カヤベグンシカベチョウ', '鹿部', 'シカベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道茅部郡鹿部町宮浜', '01', '01343', '0411403', '北海道', 'ホッカイドウ', '茅部郡鹿部町', 'カヤベグンシカベチョウ', '宮浜', 'ミヤハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道茅部郡鹿部町本別', '01', '01343', '0411404', '北海道', 'ホッカイドウ', '茅部郡鹿部町', 'カヤベグンシカベチョウ', '本別', 'ホンベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道茅部郡鹿部町駒見', '01', '01343', '0411405', '北海道', 'ホッカイドウ', '茅部郡鹿部町', 'カヤベグンシカベチョウ', '駒見', 'コマミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市古部町', '01', '01202', '0411601', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '古部町', 'フルベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市木直町', '01', '01202', '0411602', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '木直町', 'キナオシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市尾札部町', '01', '01202', '0411603', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '尾札部町', 'オサツベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市川汲町', '01', '01202', '0411611', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '川汲町', 'カックミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市安浦町', '01', '01202', '0411612', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '安浦町', 'ヤスウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市臼尻町', '01', '01202', '0411613', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '臼尻町', 'ウスジリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市豊崎町', '01', '01202', '0411621', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '豊崎町', 'トヨサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市大船町', '01', '01202', '0411622', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '大船町', 'オオフネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市双見町', '01', '01202', '0411623', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '双見町', 'フタミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市岩戸町', '01', '01202', '0411624', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '岩戸町', 'イワトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県御殿場市', '22', '22215', '4120000', '静岡県', 'シズオカケン', '御殿場市', 'ゴテンバシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('37629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県御殿場市水土野', '22', '22215', '4120001', '静岡県', 'シズオカケン', '御殿場市', 'ゴテンバシ', '水土野', 'ミドノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県御殿場市上小林', '22', '22215', '4120002', '静岡県', 'シズオカケン', '御殿場市', 'ゴテンバシ', '上小林', 'カミコバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県御殿場市柴怒田', '22', '22215', '4120003', '静岡県', 'シズオカケン', '御殿場市', 'ゴテンバシ', '柴怒田', 'シバンタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県御殿場市北久原', '22', '22215', '4120004', '静岡県', 'シズオカケン', '御殿場市', 'ゴテンバシ', '北久原', 'ホックバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県御殿場市仁杉', '22', '22215', '4120005', '静岡県', 'シズオカケン', '御殿場市', 'ゴテンバシ', '仁杉', 'ヒトスギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県御殿場市中畑', '22', '22215', '4120006', '静岡県', 'シズオカケン', '御殿場市', 'ゴテンバシ', '中畑', 'ナカバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県御殿場市永塚', '22', '22215', '4120007', '静岡県', 'シズオカケン', '御殿場市', 'ゴテンバシ', '永塚', 'ナガツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県御殿場市印野', '22', '22215', '4120008', '静岡県', 'シズオカケン', '御殿場市', 'ゴテンバシ', '印野', 'インノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県御殿場市川柳', '22', '22215', '4120009', '静岡県', 'シズオカケン', '御殿場市', 'ゴテンバシ', '川柳', 'カワヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県御殿場市古沢', '22', '22215', '4120011', '静岡県', 'シズオカケン', '御殿場市', 'ゴテンバシ', '古沢', 'フルサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県御殿場市増田', '22', '22215', '4120012', '静岡県', 'シズオカケン', '御殿場市', 'ゴテンバシ', '増田', 'マシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県御殿場市小倉野', '22', '22215', '4120013', '静岡県', 'シズオカケン', '御殿場市', 'ゴテンバシ', '小倉野', 'オグラノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県御殿場市大堰', '22', '22215', '4120014', '静岡県', 'シズオカケン', '御殿場市', 'ゴテンバシ', '大堰', 'オオセギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県御殿場市中丸', '22', '22215', '4120015', '静岡県', 'シズオカケン', '御殿場市', 'ゴテンバシ', '中丸', 'ナカマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県御殿場市六日市場', '22', '22215', '4120016', '静岡県', 'シズオカケン', '御殿場市', 'ゴテンバシ', '六日市場', 'ムイカイチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県御殿場市塚原', '22', '22215', '4120017', '静岡県', 'シズオカケン', '御殿場市', 'ゴテンバシ', '塚原', 'ツカバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県御殿場市山之尻', '22', '22215', '4120018', '静岡県', 'シズオカケン', '御殿場市', 'ゴテンバシ', '山之尻', 'ヤマノシリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県御殿場市山尾田', '22', '22215', '4120019', '静岡県', 'シズオカケン', '御殿場市', 'ゴテンバシ', '山尾田', 'ヤマオダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県御殿場市二枚橋', '22', '22215', '4120021', '静岡県', 'シズオカケン', '御殿場市', 'ゴテンバシ', '二枚橋', 'ニマイバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県御殿場市清後', '22', '22215', '4120022', '静岡県', 'シズオカケン', '御殿場市', 'ゴテンバシ', '清後', 'セイゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県御殿場市深沢', '22', '22215', '4120023', '静岡県', 'シズオカケン', '御殿場市', 'ゴテンバシ', '深沢', 'フカサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県御殿場市東山', '22', '22215', '4120024', '静岡県', 'シズオカケン', '御殿場市', 'ゴテンバシ', '東山', 'ヒガシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県御殿場市二の岡', '22', '22215', '4120025', '静岡県', 'シズオカケン', '御殿場市', 'ゴテンバシ', '二の岡', 'ニノオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県御殿場市東田中', '22', '22215', '4120026', '静岡県', 'シズオカケン', '御殿場市', 'ゴテンバシ', '東田中', 'ヒガシタナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県御殿場市西田中', '22', '22215', '4120027', '静岡県', 'シズオカケン', '御殿場市', 'ゴテンバシ', '西田中', 'ニシタナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県御殿場市御殿場', '22', '22215', '4120028', '静岡県', 'シズオカケン', '御殿場市', 'ゴテンバシ', '御殿場', 'ゴテンバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県御殿場市神山平', '22', '22215', '4120029', '静岡県', 'シズオカケン', '御殿場市', 'ゴテンバシ', '神山平', 'コウヤマダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県御殿場市沼田', '22', '22215', '4120031', '静岡県', 'シズオカケン', '御殿場市', 'ゴテンバシ', '沼田', 'ヌマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県御殿場市二子', '22', '22215', '4120032', '静岡県', 'シズオカケン', '御殿場市', 'ゴテンバシ', '二子', 'フタゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県御殿場市神山', '22', '22215', '4120033', '静岡県', 'シズオカケン', '御殿場市', 'ゴテンバシ', '神山', 'コウヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県御殿場市大坂', '22', '22215', '4120034', '静岡県', 'シズオカケン', '御殿場市', 'ゴテンバシ', '大坂', 'オオサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県御殿場市中山', '22', '22215', '4120035', '静岡県', 'シズオカケン', '御殿場市', 'ゴテンバシ', '中山', 'ナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県御殿場市萩蕪', '22', '22215', '4120036', '静岡県', 'シズオカケン', '御殿場市', 'ゴテンバシ', '萩蕪', 'ハギカブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県御殿場市中清水', '22', '22215', '4120037', '静岡県', 'シズオカケン', '御殿場市', 'ゴテンバシ', '中清水', 'ナカシミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県御殿場市駒門', '22', '22215', '4120038', '静岡県', 'シズオカケン', '御殿場市', 'ゴテンバシ', '駒門', 'コマカド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県御殿場市竈', '22', '22215', '4120039', '静岡県', 'シズオカケン', '御殿場市', 'ゴテンバシ', '竈', 'カマド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県御殿場市茱萸沢', '22', '22215', '4120041', '静岡県', 'シズオカケン', '御殿場市', 'ゴテンバシ', '茱萸沢', 'グミザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県御殿場市萩原', '22', '22215', '4120042', '静岡県', 'シズオカケン', '御殿場市', 'ゴテンバシ', '萩原', 'ハギワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県御殿場市新橋', '22', '22215', '4120043', '静岡県', 'シズオカケン', '御殿場市', 'ゴテンバシ', '新橋', 'ニイハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県御殿場市杉名沢', '22', '22215', '4120044', '静岡県', 'シズオカケン', '御殿場市', 'ゴテンバシ', '杉名沢', 'スギナザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県御殿場市川島田', '22', '22215', '4120045', '静岡県', 'シズオカケン', '御殿場市', 'ゴテンバシ', '川島田', 'カワシマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県御殿場市保土沢', '22', '22215', '4120046', '静岡県', 'シズオカケン', '御殿場市', 'ゴテンバシ', '保土沢', 'ホトザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県御殿場市神場', '22', '22215', '4120047', '静岡県', 'シズオカケン', '御殿場市', 'ゴテンバシ', '神場', 'ジンバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県御殿場市板妻', '22', '22215', '4120048', '静岡県', 'シズオカケン', '御殿場市', 'ゴテンバシ', '板妻', 'イタヅマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県御殿場市富士見原', '22', '22215', '4120051', '静岡県', 'シズオカケン', '御殿場市', 'ゴテンバシ', '富士見原', 'フジミハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県熱海市', '22', '22205', '4130000', '静岡県', 'シズオカケン', '熱海市', 'アタミシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('37688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県熱海市泉', '22', '22205', '4130001', '静岡県', 'シズオカケン', '熱海市', 'アタミシ', '泉', 'イズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県熱海市伊豆山', '22', '22205', '4130002', '静岡県', 'シズオカケン', '熱海市', 'アタミシ', '伊豆山', 'イズサン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県熱海市海光町', '22', '22205', '4130003', '静岡県', 'シズオカケン', '熱海市', 'アタミシ', '海光町', 'カイコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県熱海市初島', '22', '22205', '4130004', '静岡県', 'シズオカケン', '熱海市', 'アタミシ', '初島', 'ハツシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県熱海市春日町', '22', '22205', '4130005', '静岡県', 'シズオカケン', '熱海市', 'アタミシ', '春日町', 'カスガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県熱海市桃山町', '22', '22205', '4130006', '静岡県', 'シズオカケン', '熱海市', 'アタミシ', '桃山町', 'モモヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県熱海市田原本町', '22', '22205', '4130011', '静岡県', 'シズオカケン', '熱海市', 'アタミシ', '田原本町', 'タハラホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県熱海市東海岸町', '22', '22205', '4130012', '静岡県', 'シズオカケン', '熱海市', 'アタミシ', '東海岸町', 'ヒガシカイガンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県熱海市銀座町', '22', '22205', '4130013', '静岡県', 'シズオカケン', '熱海市', 'アタミシ', '銀座町', 'ギンザチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県熱海市渚町', '22', '22205', '4130014', '静岡県', 'シズオカケン', '熱海市', 'アタミシ', '渚町', 'ナギサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県熱海市中央町', '22', '22205', '4130015', '静岡県', 'シズオカケン', '熱海市', 'アタミシ', '中央町', 'チュウオウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県熱海市水口町', '22', '22205', '4130016', '静岡県', 'シズオカケン', '熱海市', 'アタミシ', '水口町', 'ミナグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県熱海市福道町', '22', '22205', '4130017', '静岡県', 'シズオカケン', '熱海市', 'アタミシ', '福道町', 'フクミチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県熱海市上宿町', '22', '22205', '4130018', '静岡県', 'シズオカケン', '熱海市', 'アタミシ', '上宿町', 'カミジュクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県熱海市咲見町', '22', '22205', '4130019', '静岡県', 'シズオカケン', '熱海市', 'アタミシ', '咲見町', 'サキミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県熱海市清水町', '22', '22205', '4130021', '静岡県', 'シズオカケン', '熱海市', 'アタミシ', '清水町', 'シミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県熱海市昭和町', '22', '22205', '4130022', '静岡県', 'シズオカケン', '熱海市', 'アタミシ', '昭和町', 'ショウワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県熱海市和田浜南町', '22', '22205', '4130023', '静岡県', 'シズオカケン', '熱海市', 'アタミシ', '和田浜南町', 'ワダハマミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県熱海市和田町', '22', '22205', '4130024', '静岡県', 'シズオカケン', '熱海市', 'アタミシ', '和田町', 'ワダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県熱海市桜木町', '22', '22205', '4130025', '静岡県', 'シズオカケン', '熱海市', 'アタミシ', '桜木町', 'サクラギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県熱海市梅花町', '22', '22205', '4130026', '静岡県', 'シズオカケン', '熱海市', 'アタミシ', '梅花町', 'バイカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県熱海市紅葉ガ丘町', '22', '22205', '4130027', '静岡県', 'シズオカケン', '熱海市', 'アタミシ', '紅葉ガ丘町', 'モミジガオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県熱海市桜町', '22', '22205', '4130028', '静岡県', 'シズオカケン', '熱海市', 'アタミシ', '桜町', 'サクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県熱海市小嵐町', '22', '22205', '4130029', '静岡県', 'シズオカケン', '熱海市', 'アタミシ', '小嵐町', 'コアラシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県熱海市林ガ丘町', '22', '22205', '4130031', '静岡県', 'シズオカケン', '熱海市', 'アタミシ', '林ガ丘町', 'ハヤシガオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県熱海市梅園町', '22', '22205', '4130032', '静岡県', 'シズオカケン', '熱海市', 'アタミシ', '梅園町', 'バイエンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県熱海市熱海', '22', '22205', '4130033', '静岡県', 'シズオカケン', '熱海市', 'アタミシ', '熱海', 'アタミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県熱海市西山町', '22', '22205', '4130034', '静岡県', 'シズオカケン', '熱海市', 'アタミシ', '西山町', 'ニシヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県熱海市緑ガ丘町', '22', '22205', '4130035', '静岡県', 'シズオカケン', '熱海市', 'アタミシ', '緑ガ丘町', 'ミドリガオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県熱海市日金町', '22', '22205', '4130036', '静岡県', 'シズオカケン', '熱海市', 'アタミシ', '日金町', 'ヒガネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県熱海市笹良ケ台町', '22', '22205', '4130037', '静岡県', 'シズオカケン', '熱海市', 'アタミシ', '笹良ケ台町', 'ササラガダイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県熱海市西熱海町', '22', '22205', '4130038', '静岡県', 'シズオカケン', '熱海市', 'アタミシ', '西熱海町', 'ニシアタミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県熱海市相の原町', '22', '22205', '4130039', '静岡県', 'シズオカケン', '熱海市', 'アタミシ', '相の原町', 'アイノハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県熱海市青葉町', '22', '22205', '4130041', '静岡県', 'シズオカケン', '熱海市', 'アタミシ', '青葉町', 'アオバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県熱海市山手町', '22', '22205', '4130042', '静岡県', 'シズオカケン', '熱海市', 'アタミシ', '山手町', 'ヤマテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県熱海市上多賀', '22', '22205', '4130101', '静岡県', 'シズオカケン', '熱海市', 'アタミシ', '上多賀', 'カミタガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県熱海市下多賀', '22', '22205', '4130102', '静岡県', 'シズオカケン', '熱海市', 'アタミシ', '下多賀', 'シモタガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県熱海市網代', '22', '22205', '4130103', '静岡県', 'シズオカケン', '熱海市', 'アタミシ', '網代', 'アジロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊東市グリーンヒル別荘地', '22', '22208', '4130111', '静岡県', 'シズオカケン', '伊東市', 'イトウシ', 'グリーンヒル別荘地', 'グリーンヒルベツソウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊東市富戸', '22', '22208', '4130231', '静岡県', 'シズオカケン', '伊東市', 'イトウシ', '富戸', 'フト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊東市八幡野', '22', '22208', '4130232', '静岡県', 'シズオカケン', '伊東市', 'イトウシ', '八幡野', 'ヤワタノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊東市赤沢', '22', '22208', '4130233', '静岡県', 'シズオカケン', '伊東市', 'イトウシ', '赤沢', 'アカザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊東市池', '22', '22208', '4130234', '静岡県', 'シズオカケン', '伊東市', 'イトウシ', '池', 'イケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊東市大室高原', '22', '22208', '4130235', '静岡県', 'シズオカケン', '伊東市', 'イトウシ', '大室高原', 'オオムロコウゲン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県賀茂郡東伊豆町', '22', '22301', '4130300', '静岡県', 'シズオカケン', '賀茂郡東伊豆町', 'カモグンヒガシイズチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('37737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県賀茂郡東伊豆町大川', '22', '22301', '4130301', '静岡県', 'シズオカケン', '賀茂郡東伊豆町', 'カモグンヒガシイズチョウ', '大川', 'オオカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県賀茂郡東伊豆町奈良本', '22', '22301', '4130302', '静岡県', 'シズオカケン', '賀茂郡東伊豆町', 'カモグンヒガシイズチョウ', '奈良本', 'ナラモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県賀茂郡東伊豆町北川', '22', '22301', '4130302', '静岡県', 'シズオカケン', '賀茂郡東伊豆町', 'カモグンヒガシイズチョウ', '北川', 'ホツカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県賀茂郡東伊豆町片瀬', '22', '22301', '4130303', '静岡県', 'シズオカケン', '賀茂郡東伊豆町', 'カモグンヒガシイズチョウ', '片瀬', 'カタセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県賀茂郡東伊豆町白田', '22', '22301', '4130304', '静岡県', 'シズオカケン', '賀茂郡東伊豆町', 'カモグンヒガシイズチョウ', '白田', 'シラタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県賀茂郡東伊豆町稲取', '22', '22301', '4130411', '静岡県', 'シズオカケン', '賀茂郡東伊豆町', 'カモグンヒガシイズチョウ', '稲取', 'イナトリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県賀茂郡河津町', '22', '22302', '4130500', '静岡県', 'シズオカケン', '賀茂郡河津町', 'カモグンカワヅチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('37746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県賀茂郡河津町梨本', '22', '22302', '4130501', '静岡県', 'シズオカケン', '賀茂郡河津町', 'カモグンカワヅチョウ', '梨本', 'ナシモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県賀茂郡河津町川津筏場', '22', '22302', '4130502', '静岡県', 'シズオカケン', '賀茂郡河津町', 'カモグンカワヅチョウ', '川津筏場', 'カワヅイカダバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県賀茂郡河津町見高', '22', '22302', '4130503', '静岡県', 'シズオカケン', '賀茂郡河津町', 'カモグンカワヅチョウ', '見高', 'ミダカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県賀茂郡河津町田中', '22', '22302', '4130504', '静岡県', 'シズオカケン', '賀茂郡河津町', 'カモグンカワヅチョウ', '田中', 'タナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県賀茂郡河津町沢田', '22', '22302', '4130505', '静岡県', 'シズオカケン', '賀茂郡河津町', 'カモグンカワヅチョウ', '沢田', 'サワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県賀茂郡河津町下佐ケ野', '22', '22302', '4130506', '静岡県', 'シズオカケン', '賀茂郡河津町', 'カモグンカワヅチョウ', '下佐ケ野', 'シモサガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県賀茂郡河津町湯ケ野', '22', '22302', '4130507', '静岡県', 'シズオカケン', '賀茂郡河津町', 'カモグンカワヅチョウ', '湯ケ野', 'ユガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県賀茂郡河津町小鍋', '22', '22302', '4130508', '静岡県', 'シズオカケン', '賀茂郡河津町', 'カモグンカワヅチョウ', '小鍋', 'コナベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県賀茂郡河津町大鍋', '22', '22302', '4130509', '静岡県', 'シズオカケン', '賀茂郡河津町', 'カモグンカワヅチョウ', '大鍋', 'オオナベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県賀茂郡河津町峰', '22', '22302', '4130511', '静岡県', 'シズオカケン', '賀茂郡河津町', 'カモグンカワヅチョウ', '峰', 'ミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県賀茂郡河津町笹原', '22', '22302', '4130512', '静岡県', 'シズオカケン', '賀茂郡河津町', 'カモグンカワヅチョウ', '笹原', 'ササハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県賀茂郡河津町浜', '22', '22302', '4130513', '静岡県', 'シズオカケン', '賀茂郡河津町', 'カモグンカワヅチョウ', '浜', 'ハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県賀茂郡河津町縄地', '22', '22302', '4130514', '静岡県', 'シズオカケン', '賀茂郡河津町', 'カモグンカワヅチョウ', '縄地', 'ナワジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県賀茂郡河津町谷津', '22', '22302', '4130515', '静岡県', 'シズオカケン', '賀茂郡河津町', 'カモグンカワヅチョウ', '谷津', 'ヤツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県賀茂郡河津町逆川', '22', '22302', '4130516', '静岡県', 'シズオカケン', '賀茂郡河津町', 'カモグンカワヅチョウ', '逆川', 'サカサガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県下田市落合', '22', '22219', '4130701', '静岡県', 'シズオカケン', '下田市', 'シモダシ', '落合', 'オチアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県下田市堀之内', '22', '22219', '4130702', '静岡県', 'シズオカケン', '下田市', 'シモダシ', '堀之内', 'ホリノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県下田市荒増', '22', '22219', '4130703', '静岡県', 'シズオカケン', '下田市', 'シモダシ', '荒増', 'アラゾウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県下田市椎原', '22', '22219', '4130704', '静岡県', 'シズオカケン', '下田市', 'シモダシ', '椎原', 'シイバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県下田市箕作', '22', '22219', '4130705', '静岡県', 'シズオカケン', '下田市', 'シモダシ', '箕作', 'ミツクリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県下田市相玉', '22', '22219', '4130711', '静岡県', 'シズオカケン', '下田市', 'シモダシ', '相玉', 'アイタマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県下田市横川', '22', '22219', '4130712', '静岡県', 'シズオカケン', '下田市', 'シモダシ', '横川', 'ヨコカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県下田市加増野', '22', '22219', '4130713', '静岡県', 'シズオカケン', '下田市', 'シモダシ', '加増野', 'カゾウノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県下田市北湯ケ野', '22', '22219', '4130714', '静岡県', 'シズオカケン', '下田市', 'シモダシ', '北湯ケ野', 'キタユガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県下田市宇土金', '22', '22219', '4130715', '静岡県', 'シズオカケン', '下田市', 'シモダシ', '宇土金', 'ウドガネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県下田市須原', '22', '22219', '4130716', '静岡県', 'シズオカケン', '下田市', 'シモダシ', '須原', 'スハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊東市', '22', '22208', '4140000', '静岡県', 'シズオカケン', '伊東市', 'イトウシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('37790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊東市宇佐美', '22', '22208', '4140001', '静岡県', 'シズオカケン', '伊東市', 'イトウシ', '宇佐美', 'ウサミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊東市湯川', '22', '22208', '4140002', '静岡県', 'シズオカケン', '伊東市', 'イトウシ', '湯川', 'ユカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊東市中央町', '22', '22208', '4140003', '静岡県', 'シズオカケン', '伊東市', 'イトウシ', '中央町', 'チュウオウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊東市猪戸', '22', '22208', '4140004', '静岡県', 'シズオカケン', '伊東市', 'イトウシ', '猪戸', 'シシド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊東市松原湯端町', '22', '22208', '4140005', '静岡県', 'シズオカケン', '伊東市', 'イトウシ', '松原湯端町', 'マツバラユバタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊東市松原', '22', '22208', '4140006', '静岡県', 'シズオカケン', '伊東市', 'イトウシ', '松原', 'マツバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊東市松川町', '22', '22208', '4140011', '静岡県', 'シズオカケン', '伊東市', 'イトウシ', '松川町', 'マツカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊東市宝町', '22', '22208', '4140012', '静岡県', 'シズオカケン', '伊東市', 'イトウシ', '宝町', 'タカラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊東市桜木町', '22', '22208', '4140013', '静岡県', 'シズオカケン', '伊東市', 'イトウシ', '桜木町', 'サクラギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊東市弥生町', '22', '22208', '4140014', '静岡県', 'シズオカケン', '伊東市', 'イトウシ', '弥生町', 'ヤヨイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊東市末広町', '22', '22208', '4140015', '静岡県', 'シズオカケン', '伊東市', 'イトウシ', '末広町', 'スエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊東市岡広町', '22', '22208', '4140016', '静岡県', 'シズオカケン', '伊東市', 'イトウシ', '岡広町', 'オカヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊東市幸町', '22', '22208', '4140017', '静岡県', 'シズオカケン', '伊東市', 'イトウシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊東市寿町', '22', '22208', '4140018', '静岡県', 'シズオカケン', '伊東市', 'イトウシ', '寿町', 'コトブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊東市松原本町', '22', '22208', '4140021', '静岡県', 'シズオカケン', '伊東市', 'イトウシ', '松原本町', 'マツバラホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊東市東松原町', '22', '22208', '4140022', '静岡県', 'シズオカケン', '伊東市', 'イトウシ', '東松原町', 'ヒガシマツバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊東市渚町', '22', '22208', '4140023', '静岡県', 'シズオカケン', '伊東市', 'イトウシ', '渚町', 'ナギサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊東市和田', '22', '22208', '4140024', '静岡県', 'シズオカケン', '伊東市', 'イトウシ', '和田', 'ワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊東市物見が丘', '22', '22208', '4140025', '静岡県', 'シズオカケン', '伊東市', 'イトウシ', '物見が丘', 'モノミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊東市竹の台', '22', '22208', '4140026', '静岡県', 'シズオカケン', '伊東市', 'イトウシ', '竹の台', 'タケノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊東市竹の内', '22', '22208', '4140027', '静岡県', 'シズオカケン', '伊東市', 'イトウシ', '竹の内', 'タケノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊東市銀座元町', '22', '22208', '4140028', '静岡県', 'シズオカケン', '伊東市', 'イトウシ', '銀座元町', 'ギンザモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊東市湯田町', '22', '22208', '4140031', '静岡県', 'シズオカケン', '伊東市', 'イトウシ', '湯田町', 'ユダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊東市音無町', '22', '22208', '4140032', '静岡県', 'シズオカケン', '伊東市', 'イトウシ', '音無町', 'オトナシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊東市馬場町', '22', '22208', '4140033', '静岡県', 'シズオカケン', '伊東市', 'イトウシ', '馬場町', 'ババチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊東市瓶山', '22', '22208', '4140034', '静岡県', 'シズオカケン', '伊東市', 'イトウシ', '瓶山', 'カメヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊東市南町', '22', '22208', '4140035', '静岡県', 'シズオカケン', '伊東市', 'イトウシ', '南町', 'ミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊東市宮川町', '22', '22208', '4140036', '静岡県', 'シズオカケン', '伊東市', 'イトウシ', '宮川町', 'ミヤガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊東市桜が丘', '22', '22208', '4140037', '静岡県', 'シズオカケン', '伊東市', 'イトウシ', '桜が丘', 'サクラガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊東市広野', '22', '22208', '4140038', '静岡県', 'シズオカケン', '伊東市', 'イトウシ', '広野', 'ヒロノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊東市芝町', '22', '22208', '4140041', '静岡県', 'シズオカケン', '伊東市', 'イトウシ', '芝町', 'シバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊東市静海町', '22', '22208', '4140042', '静岡県', 'シズオカケン', '伊東市', 'イトウシ', '静海町', 'シズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊東市新井', '22', '22208', '4140043', '静岡県', 'シズオカケン', '伊東市', 'イトウシ', '新井', 'アライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊東市川奈', '22', '22208', '4140044', '静岡県', 'シズオカケン', '伊東市', 'イトウシ', '川奈', 'カワナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊東市玖須美元和田', '22', '22208', '4140045', '静岡県', 'シズオカケン', '伊東市', 'イトウシ', '玖須美元和田', 'クスミモトワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊東市大原', '22', '22208', '4140046', '静岡県', 'シズオカケン', '伊東市', 'イトウシ', '大原', 'オオハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊東市吉田', '22', '22208', '4140051', '静岡県', 'シズオカケン', '伊東市', 'イトウシ', '吉田', 'ヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊東市十足', '22', '22208', '4140052', '静岡県', 'シズオカケン', '伊東市', 'イトウシ', '十足', 'トオタリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊東市荻', '22', '22208', '4140053', '静岡県', 'シズオカケン', '伊東市', 'イトウシ', '荻', 'オギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊東市鎌田', '22', '22208', '4140054', '静岡県', 'シズオカケン', '伊東市', 'イトウシ', '鎌田', 'カマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県伊東市岡', '22', '22208', '4140055', '静岡県', 'シズオカケン', '伊東市', 'イトウシ', '岡', 'オカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県下田市', '22', '22219', '4150000', '静岡県', 'シズオカケン', '下田市', 'シモダシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('37837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県下田市', '22', '22219', '4150001', '静岡県', 'シズオカケン', '下田市', 'シモダシ', null, '　', '（直番地）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('37838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県下田市河内', '22', '22219', '4150011', '静岡県', 'シズオカケン', '下田市', 'シモダシ', '河内', 'コウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県下田市白浜', '22', '22219', '4150012', '静岡県', 'シズオカケン', '下田市', 'シモダシ', '白浜', 'シラハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県下田市柿崎', '22', '22219', '4150013', '静岡県', 'シズオカケン', '下田市', 'シモダシ', '柿崎', 'カキサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県下田市須崎', '22', '22219', '4150014', '静岡県', 'シズオカケン', '下田市', 'シモダシ', '須崎', 'スザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県下田市武ガ浜', '22', '22219', '4150015', '静岡県', 'シズオカケン', '下田市', 'シモダシ', '武ガ浜', 'タケガハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県下田市中', '22', '22219', '4150016', '静岡県', 'シズオカケン', '下田市', 'シモダシ', '中', 'ナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県下田市東中', '22', '22219', '4150017', '静岡県', 'シズオカケン', '下田市', 'シモダシ', '東中', 'ヒガシナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県下田市西中', '22', '22219', '4150018', '静岡県', 'シズオカケン', '下田市', 'シモダシ', '西中', 'ニシナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県下田市一丁目', '22', '22219', '4150021', '静岡県', 'シズオカケン', '下田市', 'シモダシ', '一丁目', 'イッチョウメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県下田市二丁目', '22', '22219', '4150022', '静岡県', 'シズオカケン', '下田市', 'シモダシ', '二丁目', 'ニチョウメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県下田市三丁目', '22', '22219', '4150023', '静岡県', 'シズオカケン', '下田市', 'シモダシ', '三丁目', 'サンチョウメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県下田市四丁目', '22', '22219', '4150024', '静岡県', 'シズオカケン', '下田市', 'シモダシ', '四丁目', 'ヨンチョウメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県下田市五丁目', '22', '22219', '4150025', '静岡県', 'シズオカケン', '下田市', 'シモダシ', '五丁目', 'ゴチョウメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県下田市六丁目', '22', '22219', '4150026', '静岡県', 'シズオカケン', '下田市', 'シモダシ', '六丁目', 'ロクチョウメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県下田市旧岡方村', '22', '22219', '4150027', '静岡県', 'シズオカケン', '下田市', 'シモダシ', '旧岡方村', 'キュウオカガタムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県下田市吉佐美', '22', '22219', '4150028', '静岡県', 'シズオカケン', '下田市', 'シモダシ', '吉佐美', 'キサミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県下田市田牛', '22', '22219', '4150029', '静岡県', 'シズオカケン', '下田市', 'シモダシ', '田牛', 'トウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県下田市蓮台寺', '22', '22219', '4150031', '静岡県', 'シズオカケン', '下田市', 'シモダシ', '蓮台寺', 'レンダイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県下田市立野', '22', '22219', '4150032', '静岡県', 'シズオカケン', '下田市', 'シモダシ', '立野', 'タチノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県下田市本郷', '22', '22219', '4150033', '静岡県', 'シズオカケン', '下田市', 'シモダシ', '本郷', 'ホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県下田市高馬', '22', '22219', '4150034', '静岡県', 'シズオカケン', '下田市', 'シモダシ', '高馬', 'タコウマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県下田市東本郷', '22', '22219', '4150035', '静岡県', 'シズオカケン', '下田市', 'シモダシ', '東本郷', 'ヒガシホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県下田市西本郷', '22', '22219', '4150036', '静岡県', 'シズオカケン', '下田市', 'シモダシ', '西本郷', 'ニシホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県下田市敷根', '22', '22219', '4150037', '静岡県', 'シズオカケン', '下田市', 'シモダシ', '敷根', 'シキネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県下田市大賀茂', '22', '22219', '4150038', '静岡県', 'シズオカケン', '下田市', 'シモダシ', '大賀茂', 'オオガモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県下田市大沢', '22', '22219', '4150039', '静岡県', 'シズオカケン', '下田市', 'シモダシ', '大沢', 'オオサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県賀茂郡南伊豆町青市', '22', '22304', '4150151', '静岡県', 'シズオカケン', '賀茂郡南伊豆町', 'カモグンミナミイズチョウ', '青市', 'アオイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県賀茂郡南伊豆町湊', '22', '22304', '4150152', '静岡県', 'シズオカケン', '賀茂郡南伊豆町', 'カモグンミナミイズチョウ', '湊', 'ミナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県賀茂郡南伊豆町手石', '22', '22304', '4150153', '静岡県', 'シズオカケン', '賀茂郡南伊豆町', 'カモグンミナミイズチョウ', '手石', 'テイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県賀茂郡南伊豆町下流', '22', '22304', '4150154', '静岡県', 'シズオカケン', '賀茂郡南伊豆町', 'カモグンミナミイズチョウ', '下流', 'シタル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県賀茂郡南伊豆町大瀬', '22', '22304', '4150155', '静岡県', 'シズオカケン', '賀茂郡南伊豆町', 'カモグンミナミイズチョウ', '大瀬', 'オオセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県賀茂郡南伊豆町石廊崎', '22', '22304', '4150156', '静岡県', 'シズオカケン', '賀茂郡南伊豆町', 'カモグンミナミイズチョウ', '石廊崎', 'イロウザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県賀茂郡南伊豆町', '22', '22304', '4150300', '静岡県', 'シズオカケン', '賀茂郡南伊豆町', 'カモグンミナミイズチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('37874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県賀茂郡南伊豆町一條', '22', '22304', '4150301', '静岡県', 'シズオカケン', '賀茂郡南伊豆町', 'カモグンミナミイズチョウ', '一條', 'イチジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県賀茂郡南伊豆町上賀茂', '22', '22304', '4150302', '静岡県', 'シズオカケン', '賀茂郡南伊豆町', 'カモグンミナミイズチョウ', '上賀茂', 'カミガモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県賀茂郡南伊豆町下賀茂', '22', '22304', '4150303', '静岡県', 'シズオカケン', '賀茂郡南伊豆町', 'カモグンミナミイズチョウ', '下賀茂', 'シモガモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県賀茂郡南伊豆町加納', '22', '22304', '4150304', '静岡県', 'シズオカケン', '賀茂郡南伊豆町', 'カモグンミナミイズチョウ', '加納', 'カノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県賀茂郡南伊豆町二條', '22', '22304', '4150305', '静岡県', 'シズオカケン', '賀茂郡南伊豆町', 'カモグンミナミイズチョウ', '二條', 'ニジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県賀茂郡南伊豆町石井', '22', '22304', '4150306', '静岡県', 'シズオカケン', '賀茂郡南伊豆町', 'カモグンミナミイズチョウ', '石井', 'イシイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県賀茂郡南伊豆町中木', '22', '22304', '4150311', '静岡県', 'シズオカケン', '賀茂郡南伊豆町', 'カモグンミナミイズチョウ', '中木', 'ナカギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県賀茂郡南伊豆町入間', '22', '22304', '4150312', '静岡県', 'シズオカケン', '賀茂郡南伊豆町', 'カモグンミナミイズチョウ', '入間', 'イルマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県賀茂郡南伊豆町差田', '22', '22304', '4150312', '静岡県', 'シズオカケン', '賀茂郡南伊豆町', 'カモグンミナミイズチョウ', '差田', 'サシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県賀茂郡南伊豆町一色', '22', '22304', '4150313', '静岡県', 'シズオカケン', '賀茂郡南伊豆町', 'カモグンミナミイズチョウ', '一色', 'イシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県賀茂郡南伊豆町蝶ケ野', '22', '22304', '4150314', '静岡県', 'シズオカケン', '賀茂郡南伊豆町', 'カモグンミナミイズチョウ', '蝶ケ野', 'チョウガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県賀茂郡南伊豆町毛倉野', '22', '22304', '4150321', '静岡県', 'シズオカケン', '賀茂郡南伊豆町', 'カモグンミナミイズチョウ', '毛倉野', 'ケグラノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県賀茂郡南伊豆町岩殿', '22', '22304', '4150322', '静岡県', 'シズオカケン', '賀茂郡南伊豆町', 'カモグンミナミイズチョウ', '岩殿', 'イワドノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県賀茂郡南伊豆町川合野', '22', '22304', '4150323', '静岡県', 'シズオカケン', '賀茂郡南伊豆町', 'カモグンミナミイズチョウ', '川合野', 'カワイノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県賀茂郡南伊豆町下小野', '22', '22304', '4150323', '静岡県', 'シズオカケン', '賀茂郡南伊豆町', 'カモグンミナミイズチョウ', '下小野', 'シモオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県賀茂郡南伊豆町上小野', '22', '22304', '4150324', '静岡県', 'シズオカケン', '賀茂郡南伊豆町', 'カモグンミナミイズチョウ', '上小野', 'カミオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県賀茂郡南伊豆町市之瀬', '22', '22304', '4150325', '静岡県', 'シズオカケン', '賀茂郡南伊豆町', 'カモグンミナミイズチョウ', '市之瀬', 'イチノセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県賀茂郡南伊豆町平戸', '22', '22304', '4150325', '静岡県', 'シズオカケン', '賀茂郡南伊豆町', 'カモグンミナミイズチョウ', '平戸', 'ヒラド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県賀茂郡南伊豆町蛇石', '22', '22304', '4150326', '静岡県', 'シズオカケン', '賀茂郡南伊豆町', 'カモグンミナミイズチョウ', '蛇石', 'ジャイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県賀茂郡南伊豆町青野', '22', '22304', '4150327', '静岡県', 'シズオカケン', '賀茂郡南伊豆町', 'カモグンミナミイズチョウ', '青野', 'アオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県賀茂郡南伊豆町一町田', '22', '22304', '4150531', '静岡県', 'シズオカケン', '賀茂郡南伊豆町', 'カモグンミナミイズチョウ', '一町田', 'イッチョウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県賀茂郡南伊豆町伊浜', '22', '22304', '4150531', '静岡県', 'シズオカケン', '賀茂郡南伊豆町', 'カモグンミナミイズチョウ', '伊浜', 'イハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県賀茂郡南伊豆町落居', '22', '22304', '4150531', '静岡県', 'シズオカケン', '賀茂郡南伊豆町', 'カモグンミナミイズチョウ', '落居', 'オチイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県賀茂郡南伊豆町天神原', '22', '22304', '4150531', '静岡県', 'シズオカケン', '賀茂郡南伊豆町', 'カモグンミナミイズチョウ', '天神原', 'テンジンバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県賀茂郡南伊豆町子浦', '22', '22304', '4150532', '静岡県', 'シズオカケン', '賀茂郡南伊豆町', 'カモグンミナミイズチョウ', '子浦', 'コウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県賀茂郡南伊豆町立岩', '22', '22304', '4150533', '静岡県', 'シズオカケン', '賀茂郡南伊豆町', 'カモグンミナミイズチョウ', '立岩', 'タテイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県賀茂郡南伊豆町妻良', '22', '22304', '4150533', '静岡県', 'シズオカケン', '賀茂郡南伊豆町', 'カモグンミナミイズチョウ', '妻良', 'メラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県賀茂郡南伊豆町吉田', '22', '22304', '4150533', '静岡県', 'シズオカケン', '賀茂郡南伊豆町', 'カモグンミナミイズチョウ', '吉田', 'ヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市岩本', '22', '22210', '4160901', '静岡県', 'シズオカケン', '富士市', 'フジシ', '岩本', 'イワモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市長通', '22', '22210', '4160902', '静岡県', 'シズオカケン', '富士市', 'フジシ', '長通', 'ナガドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市松本', '22', '22210', '4160903', '静岡県', 'シズオカケン', '富士市', 'フジシ', '松本', 'マツモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市本市場新田', '22', '22210', '4160904', '静岡県', 'シズオカケン', '富士市', 'フジシ', '本市場新田', 'モトイチバシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市五味島', '22', '22210', '4160905', '静岡県', 'シズオカケン', '富士市', 'フジシ', '五味島', 'ゴミジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市本市場', '22', '22210', '4160906', '静岡県', 'シズオカケン', '富士市', 'フジシ', '本市場', 'モトイチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市中島', '22', '22210', '4160907', '静岡県', 'シズオカケン', '富士市', 'フジシ', '中島', 'ナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市柚木', '22', '22210', '4160908', '静岡県', 'シズオカケン', '富士市', 'フジシ', '柚木', 'ユノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市松岡', '22', '22210', '4160909', '静岡県', 'シズオカケン', '富士市', 'フジシ', '松岡', 'マツオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市八幡町', '22', '22210', '4160911', '静岡県', 'シズオカケン', '富士市', 'フジシ', '八幡町', 'ハチマンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市加島町', '22', '22210', '4160912', '静岡県', 'シズオカケン', '富士市', 'フジシ', '加島町', 'カジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市平垣本町', '22', '22210', '4160913', '静岡県', 'シズオカケン', '富士市', 'フジシ', '平垣本町', 'ヘイガキホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市本町', '22', '22210', '4160914', '静岡県', 'シズオカケン', '富士市', 'フジシ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市富士町', '22', '22210', '4160915', '静岡県', 'シズオカケン', '富士市', 'フジシ', '富士町', 'フジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市平垣', '22', '22210', '4160916', '静岡県', 'シズオカケン', '富士市', 'フジシ', '平垣', 'ヘイガキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市元町', '22', '22210', '4160917', '静岡県', 'シズオカケン', '富士市', 'フジシ', '元町', 'モトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市平垣町', '22', '22210', '4160918', '静岡県', 'シズオカケン', '富士市', 'フジシ', '平垣町', 'ヘイガキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市松富町', '22', '22210', '4160919', '静岡県', 'シズオカケン', '富士市', 'フジシ', '松富町', 'マツトミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市水戸島', '22', '22210', '4160921', '静岡県', 'シズオカケン', '富士市', 'フジシ', '水戸島', 'ミトジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市水戸島元町', '22', '22210', '4160922', '静岡県', 'シズオカケン', '富士市', 'フジシ', '水戸島元町', 'ミトジマモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市横割本町', '22', '22210', '4160923', '静岡県', 'シズオカケン', '富士市', 'フジシ', '横割本町', 'ヨコワリホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市水戸島本町', '22', '22210', '4160924', '静岡県', 'シズオカケン', '富士市', 'フジシ', '水戸島本町', 'ミトジマホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市蓼原', '22', '22210', '4160931', '静岡県', 'シズオカケン', '富士市', 'フジシ', '蓼原', 'タデハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市柳島', '22', '22210', '4160932', '静岡県', 'シズオカケン', '富士市', 'フジシ', '柳島', 'ヤナギシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市中丸', '22', '22210', '4160933', '静岡県', 'シズオカケン', '富士市', 'フジシ', '中丸', 'ナカマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市鮫島', '22', '22210', '4160934', '静岡県', 'シズオカケン', '富士市', 'フジシ', '鮫島', 'サメジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市田子', '22', '22210', '4160935', '静岡県', 'シズオカケン', '富士市', 'フジシ', '田子', 'タゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市中河原', '22', '22210', '4160936', '静岡県', 'シズオカケン', '富士市', 'フジシ', '中河原', 'ナカカワハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市前田', '22', '22210', '4160937', '静岡県', 'シズオカケン', '富士市', 'フジシ', '前田', 'マエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市浜田町', '22', '22210', '4160938', '静岡県', 'シズオカケン', '富士市', 'フジシ', '浜田町', 'ハマダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市川成島', '22', '22210', '4160939', '静岡県', 'シズオカケン', '富士市', 'フジシ', '川成島', 'カワナリジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市十兵衛', '22', '22210', '4160941', '静岡県', 'シズオカケン', '富士市', 'フジシ', '十兵衛', 'ジュウベエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市上横割', '22', '22210', '4160942', '静岡県', 'シズオカケン', '富士市', 'フジシ', '上横割', 'カミヨコワリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市下横割', '22', '22210', '4160943', '静岡県', 'シズオカケン', '富士市', 'フジシ', '下横割', 'シモヨコワリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市横割', '22', '22210', '4160944', '静岡県', 'シズオカケン', '富士市', 'フジシ', '横割', 'ヨコワリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市宮島', '22', '22210', '4160945', '静岡県', 'シズオカケン', '富士市', 'フジシ', '宮島', 'ミヤジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市五貫島', '22', '22210', '4160946', '静岡県', 'シズオカケン', '富士市', 'フジシ', '五貫島', 'ゴカンジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市宮下', '22', '22210', '4160947', '静岡県', 'シズオカケン', '富士市', 'フジシ', '宮下', 'ミヤシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市森島', '22', '22210', '4160948', '静岡県', 'シズオカケン', '富士市', 'フジシ', '森島', 'モリジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市森下', '22', '22210', '4160949', '静岡県', 'シズオカケン', '富士市', 'フジシ', '森下', 'モリシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市米之宮町', '22', '22210', '4160951', '静岡県', 'シズオカケン', '富士市', 'フジシ', '米之宮町', 'ヨネノミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市青葉町', '22', '22210', '4160952', '静岡県', 'シズオカケン', '富士市', 'フジシ', '青葉町', 'アオバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市蓼原町', '22', '22210', '4160953', '静岡県', 'シズオカケン', '富士市', 'フジシ', '蓼原町', 'タデハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市本市場町', '22', '22210', '4160954', '静岡県', 'シズオカケン', '富士市', 'フジシ', '本市場町', 'モトイチバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市川成新町', '22', '22210', '4160955', '静岡県', 'シズオカケン', '富士市', 'フジシ', '川成新町', 'カワナリシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市', '22', '22210', '4170000', '静岡県', 'シズオカケン', '富士市', 'フジシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('37993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市今泉', '22', '22210', '4170001', '静岡県', 'シズオカケン', '富士市', 'フジシ', '今泉', 'イマイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市依田橋', '22', '22210', '4170002', '静岡県', 'シズオカケン', '富士市', 'フジシ', '依田橋', 'ヨダバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市依田橋町', '22', '22210', '4170003', '静岡県', 'シズオカケン', '富士市', 'フジシ', '依田橋町', 'ヨダバシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市新橋町', '22', '22210', '4170004', '静岡県', 'シズオカケン', '富士市', 'フジシ', '新橋町', 'シンバシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市鈴川本町', '22', '22210', '4170011', '静岡県', 'シズオカケン', '富士市', 'フジシ', '鈴川本町', 'スズカワホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市鈴川東町', '22', '22210', '4170012', '静岡県', 'シズオカケン', '富士市', 'フジシ', '鈴川東町', 'スズカワヒガシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('37999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市鈴川中町', '22', '22210', '4170013', '静岡県', 'シズオカケン', '富士市', 'フジシ', '鈴川中町', 'スズカワナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市鈴川西町', '22', '22210', '4170014', '静岡県', 'シズオカケン', '富士市', 'フジシ', '鈴川西町', 'スズカワニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市鈴川町', '22', '22210', '4170015', '静岡県', 'シズオカケン', '富士市', 'フジシ', '鈴川町', 'スズカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市依田原', '22', '22210', '4170021', '静岡県', 'シズオカケン', '富士市', 'フジシ', '依田原', 'ヨダハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市依田原町', '22', '22210', '4170022', '静岡県', 'シズオカケン', '富士市', 'フジシ', '依田原町', 'ヨダハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市吉原宝町', '22', '22210', '4170023', '静岡県', 'シズオカケン', '富士市', 'フジシ', '吉原宝町', 'ヨシワラタカラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市八代町', '22', '22210', '4170024', '静岡県', 'シズオカケン', '富士市', 'フジシ', '八代町', 'ヤシロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市瓜島', '22', '22210', '4170025', '静岡県', 'シズオカケン', '富士市', 'フジシ', '瓜島', 'ウリジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市南町', '22', '22210', '4170026', '静岡県', 'シズオカケン', '富士市', 'フジシ', '南町', 'ミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市田島', '22', '22210', '4170031', '静岡県', 'シズオカケン', '富士市', 'フジシ', '田島', 'タジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市田島新田', '22', '22210', '4170032', '静岡県', 'シズオカケン', '富士市', 'フジシ', '田島新田', 'タジマシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市島田町', '22', '22210', '4170033', '静岡県', 'シズオカケン', '富士市', 'フジシ', '島田町', 'シマダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市津田', '22', '22210', '4170034', '静岡県', 'シズオカケン', '富士市', 'フジシ', '津田', 'ツタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市津田町', '22', '22210', '4170035', '静岡県', 'シズオカケン', '富士市', 'フジシ', '津田町', 'ツタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市中河原', '22', '22210', '4170036', '静岡県', 'シズオカケン', '富士市', 'フジシ', '中河原', 'ナカカワハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市外木', '22', '22210', '4170037', '静岡県', 'シズオカケン', '富士市', 'フジシ', '外木', 'トノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市御幸町', '22', '22210', '4170041', '静岡県', 'シズオカケン', '富士市', 'フジシ', '御幸町', 'ミユキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市荒田島', '22', '22210', '4170042', '静岡県', 'シズオカケン', '富士市', 'フジシ', '荒田島', 'アラタジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市荒田島町', '22', '22210', '4170043', '静岡県', 'シズオカケン', '富士市', 'フジシ', '荒田島町', 'アラタジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市高嶺町', '22', '22210', '4170044', '静岡県', 'シズオカケン', '富士市', 'フジシ', '高嶺町', 'タカネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市錦町', '22', '22210', '4170045', '静岡県', 'シズオカケン', '富士市', 'フジシ', '錦町', 'ニシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市青島', '22', '22210', '4170046', '静岡県', 'シズオカケン', '富士市', 'フジシ', '青島', 'アオシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市青島町', '22', '22210', '4170047', '静岡県', 'シズオカケン', '富士市', 'フジシ', '青島町', 'アオシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市高島町', '22', '22210', '4170048', '静岡県', 'シズオカケン', '富士市', 'フジシ', '高島町', 'タカシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市緑町', '22', '22210', '4170049', '静岡県', 'シズオカケン', '富士市', 'フジシ', '緑町', 'ミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市吉原', '22', '22210', '4170051', '静岡県', 'シズオカケン', '富士市', 'フジシ', '吉原', 'ヨシワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市中央町', '22', '22210', '4170052', '静岡県', 'シズオカケン', '富士市', 'フジシ', '中央町', 'チュウオウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市依田原新田', '22', '22210', '4170053', '静岡県', 'シズオカケン', '富士市', 'フジシ', '依田原新田', 'ヨダハラシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市永田', '22', '22210', '4170054', '静岡県', 'シズオカケン', '富士市', 'フジシ', '永田', 'ナガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市永田町', '22', '22210', '4170055', '静岡県', 'シズオカケン', '富士市', 'フジシ', '永田町', 'ナガタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市日乃出町', '22', '22210', '4170056', '静岡県', 'シズオカケン', '富士市', 'フジシ', '日乃出町', 'ヒノデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市瓜島町', '22', '22210', '4170057', '静岡県', 'シズオカケン', '富士市', 'フジシ', '瓜島町', 'ウリジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市永田北町', '22', '22210', '4170058', '静岡県', 'シズオカケン', '富士市', 'フジシ', '永田北町', 'ナガタキタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市伝法', '22', '22210', '4170061', '静岡県', 'シズオカケン', '富士市', 'フジシ', '伝法', 'デンボウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市香西', '22', '22210', '4170062', '静岡県', 'シズオカケン', '富士市', 'フジシ', '香西', 'コウサイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市香西新田', '22', '22210', '4170063', '静岡県', 'シズオカケン', '富士市', 'フジシ', '香西新田', 'コウサイシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市弥生', '22', '22210', '4170064', '静岡県', 'シズオカケン', '富士市', 'フジシ', '弥生', 'ヤヨイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市弥生新田', '22', '22210', '4170065', '静岡県', 'シズオカケン', '富士市', 'フジシ', '弥生新田', 'ヤヨイシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市国久保', '22', '22210', '4170071', '静岡県', 'シズオカケン', '富士市', 'フジシ', '国久保', 'クニクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市浅間上町', '22', '22210', '4170072', '静岡県', 'シズオカケン', '富士市', 'フジシ', '浅間上町', 'センゲンカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市浅間本町', '22', '22210', '4170073', '静岡県', 'シズオカケン', '富士市', 'フジシ', '浅間本町', 'センゲンホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市大淵', '22', '22210', '4170801', '静岡県', 'シズオカケン', '富士市', 'フジシ', '大淵', 'オオブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市今宮', '22', '22210', '4170802', '静岡県', 'シズオカケン', '富士市', 'フジシ', '今宮', 'イマミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市桑崎', '22', '22210', '4170803', '静岡県', 'シズオカケン', '富士市', 'フジシ', '桑崎', 'カザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市石井', '22', '22210', '4170804', '静岡県', 'シズオカケン', '富士市', 'フジシ', '石井', 'イシイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市鵜無ケ淵', '22', '22210', '4170805', '静岡県', 'シズオカケン', '富士市', 'フジシ', '鵜無ケ淵', 'ウナイガフチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市間門', '22', '22210', '4170806', '静岡県', 'シズオカケン', '富士市', 'フジシ', '間門', 'マカド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市神戸', '22', '22210', '4170807', '静岡県', 'シズオカケン', '富士市', 'フジシ', '神戸', 'ゴウド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市一色', '22', '22210', '4170808', '静岡県', 'シズオカケン', '富士市', 'フジシ', '一色', 'イッシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市中野', '22', '22210', '4170809', '静岡県', 'シズオカケン', '富士市', 'フジシ', '中野', 'ナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市江尾', '22', '22210', '4170811', '静岡県', 'シズオカケン', '富士市', 'フジシ', '江尾', 'エノオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市境', '22', '22210', '4170812', '静岡県', 'シズオカケン', '富士市', 'フジシ', '境', 'サカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市船津', '22', '22210', '4170813', '静岡県', 'シズオカケン', '富士市', 'フジシ', '船津', 'フナツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市西船津', '22', '22210', '4170814', '静岡県', 'シズオカケン', '富士市', 'フジシ', '西船津', 'ニシフナツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市増川', '22', '22210', '4170815', '静岡県', 'シズオカケン', '富士市', 'フジシ', '増川', 'マスガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市増川新町', '22', '22210', '4170816', '静岡県', 'シズオカケン', '富士市', 'フジシ', '増川新町', 'マスガワシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市江尾南', '22', '22210', '4170817', '静岡県', 'シズオカケン', '富士市', 'フジシ', '江尾南', 'エノオミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市神谷', '22', '22210', '4170821', '静岡県', 'シズオカケン', '富士市', 'フジシ', '神谷', 'カミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市神谷新町', '22', '22210', '4170822', '静岡県', 'シズオカケン', '富士市', 'フジシ', '神谷新町', 'カミヤシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市神谷南', '22', '22210', '4170823', '静岡県', 'シズオカケン', '富士市', 'フジシ', '神谷南', 'カミヤミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市川尻東', '22', '22210', '4170824', '静岡県', 'シズオカケン', '富士市', 'フジシ', '川尻東', 'カワシリヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市川尻', '22', '22210', '4170825', '静岡県', 'シズオカケン', '富士市', 'フジシ', '川尻', 'カワシリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市中里', '22', '22210', '4170826', '静岡県', 'シズオカケン', '富士市', 'フジシ', '中里', 'ナカザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市東柏原新田', '22', '22210', '4170831', '静岡県', 'シズオカケン', '富士市', 'フジシ', '東柏原新田', 'ヒガシカシワバラシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市中柏原新田', '22', '22210', '4170832', '静岡県', 'シズオカケン', '富士市', 'フジシ', '中柏原新田', 'ナカカシワバラシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市沼田新田', '22', '22210', '4170833', '静岡県', 'シズオカケン', '富士市', 'フジシ', '沼田新田', 'ヌマタシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市西柏原新田', '22', '22210', '4170834', '静岡県', 'シズオカケン', '富士市', 'フジシ', '西柏原新田', 'ニシカシワバラシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市柏原', '22', '22210', '4170835', '静岡県', 'シズオカケン', '富士市', 'フジシ', '柏原', 'カシワバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市富士岡', '22', '22210', '4170841', '静岡県', 'シズオカケン', '富士市', 'フジシ', '富士岡', 'フジオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市三新田', '22', '22210', '4170842', '静岡県', 'シズオカケン', '富士市', 'フジシ', '三新田', 'サンシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市田中新田', '22', '22210', '4170843', '静岡県', 'シズオカケン', '富士市', 'フジシ', '田中新田', 'タナカシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市桧新田', '22', '22210', '4170844', '静岡県', 'シズオカケン', '富士市', 'フジシ', '桧新田', 'ヒノキシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市大野新田', '22', '22210', '4170845', '静岡県', 'シズオカケン', '富士市', 'フジシ', '大野新田', 'オオノシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市今井', '22', '22210', '4170846', '静岡県', 'シズオカケン', '富士市', 'フジシ', '今井', 'イマイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市比奈', '22', '22210', '4170847', '静岡県', 'シズオカケン', '富士市', 'フジシ', '比奈', 'ヒナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市富士見台', '22', '22210', '4170851', '静岡県', 'シズオカケン', '富士市', 'フジシ', '富士見台', 'フジミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市原田', '22', '22210', '4170852', '静岡県', 'シズオカケン', '富士市', 'フジシ', '原田', 'ハラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市宇東川東町', '22', '22210', '4170853', '静岡県', 'シズオカケン', '富士市', 'フジシ', '宇東川東町', 'ウトガワヒガシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市宇東川西町', '22', '22210', '4170854', '静岡県', 'シズオカケン', '富士市', 'フジシ', '宇東川西町', 'ウトガワニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市三ツ沢', '22', '22210', '4170855', '静岡県', 'シズオカケン', '富士市', 'フジシ', '三ツ沢', 'ミツザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市広見東本町', '22', '22210', '4170861', '静岡県', 'シズオカケン', '富士市', 'フジシ', '広見東本町', 'ヒロミヒガシホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市石坂', '22', '22210', '4170862', '静岡県', 'シズオカケン', '富士市', 'フジシ', '石坂', 'イシザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市広見西本町', '22', '22210', '4170863', '静岡県', 'シズオカケン', '富士市', 'フジシ', '広見西本町', 'ヒロミニシホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市広見本町', '22', '22210', '4170864', '静岡県', 'シズオカケン', '富士市', 'フジシ', '広見本町', 'ヒロミホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士宮市', '22', '22207', '4180000', '静岡県', 'シズオカケン', '富士宮市', 'フジノミヤシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('38124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士宮市万野原新田', '22', '22207', '4180001', '静岡県', 'シズオカケン', '富士宮市', 'フジノミヤシ', '万野原新田', 'マンノハラシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士宮市中原町', '22', '22207', '4180002', '静岡県', 'シズオカケン', '富士宮市', 'フジノミヤシ', '中原町', 'ナカハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士宮市ひばりが丘', '22', '22207', '4180003', '静岡県', 'シズオカケン', '富士宮市', 'フジノミヤシ', 'ひばりが丘', 'ヒバリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士宮市三園平', '22', '22207', '4180004', '静岡県', 'シズオカケン', '富士宮市', 'フジノミヤシ', '三園平', 'ミソノダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士宮市宮原', '22', '22207', '4180005', '静岡県', 'シズオカケン', '富士宮市', 'フジノミヤシ', '宮原', 'ミヤハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士宮市外神', '22', '22207', '4180006', '静岡県', 'シズオカケン', '富士宮市', 'フジノミヤシ', '外神', 'トガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士宮市外神東町', '22', '22207', '4180007', '静岡県', 'シズオカケン', '富士宮市', 'フジノミヤシ', '外神東町', 'トガミヒガシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士宮市粟倉', '22', '22207', '4180011', '静岡県', 'シズオカケン', '富士宮市', 'フジノミヤシ', '粟倉', 'アワクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士宮市村山', '22', '22207', '4180012', '静岡県', 'シズオカケン', '富士宮市', 'フジノミヤシ', '村山', 'ムラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士宮市大岩', '22', '22207', '4180013', '静岡県', 'シズオカケン', '富士宮市', 'フジノミヤシ', '大岩', 'オオイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士宮市富士見ケ丘', '22', '22207', '4180014', '静岡県', 'シズオカケン', '富士宮市', 'フジノミヤシ', '富士見ケ丘', 'フジミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士宮市舞々木町', '22', '22207', '4180015', '静岡県', 'シズオカケン', '富士宮市', 'フジノミヤシ', '舞々木町', 'マイマイギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士宮市阿幸地', '22', '22207', '4180016', '静岡県', 'シズオカケン', '富士宮市', 'フジノミヤシ', '阿幸地', 'アコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士宮市舟久保町', '22', '22207', '4180017', '静岡県', 'シズオカケン', '富士宮市', 'フジノミヤシ', '舟久保町', 'フナクボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士宮市粟倉南町', '22', '22207', '4180018', '静岡県', 'シズオカケン', '富士宮市', 'フジノミヤシ', '粟倉南町', 'アワクラミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士宮市杉田', '22', '22207', '4180021', '静岡県', 'シズオカケン', '富士宮市', 'フジノミヤシ', '杉田', 'スギタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士宮市小泉', '22', '22207', '4180022', '静岡県', 'シズオカケン', '富士宮市', 'フジノミヤシ', '小泉', 'コイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士宮市山本', '22', '22207', '4180023', '静岡県', 'シズオカケン', '富士宮市', 'フジノミヤシ', '山本', 'ヤマモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士宮市貫戸', '22', '22207', '4180024', '静岡県', 'シズオカケン', '富士宮市', 'フジノミヤシ', '貫戸', 'ヌクド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士宮市前田町', '22', '22207', '4180025', '静岡県', 'シズオカケン', '富士宮市', 'フジノミヤシ', '前田町', 'マエダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士宮市西小泉町', '22', '22207', '4180026', '静岡県', 'シズオカケン', '富士宮市', 'フジノミヤシ', '西小泉町', 'ニシコイズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士宮市神田川町', '22', '22207', '4180031', '静岡県', 'シズオカケン', '富士宮市', 'フジノミヤシ', '神田川町', 'カンダガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士宮市浅間町', '22', '22207', '4180032', '静岡県', 'シズオカケン', '富士宮市', 'フジノミヤシ', '浅間町', 'アサマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士宮市野中東町', '22', '22207', '4180033', '静岡県', 'シズオカケン', '富士宮市', 'フジノミヤシ', '野中東町', 'ノナカヒガシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士宮市黒田', '22', '22207', '4180034', '静岡県', 'シズオカケン', '富士宮市', 'フジノミヤシ', '黒田', 'クロダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士宮市星山', '22', '22207', '4180035', '静岡県', 'シズオカケン', '富士宮市', 'フジノミヤシ', '星山', 'ホシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士宮市沼久保', '22', '22207', '4180036', '静岡県', 'シズオカケン', '富士宮市', 'フジノミヤシ', '沼久保', 'ヌマクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士宮市安居山', '22', '22207', '4180037', '静岡県', 'シズオカケン', '富士宮市', 'フジノミヤシ', '安居山', 'アゴヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士宮市野中町', '22', '22207', '4180038', '静岡県', 'シズオカケン', '富士宮市', 'フジノミヤシ', '野中町', 'ノナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士宮市野中', '22', '22207', '4180039', '静岡県', 'シズオカケン', '富士宮市', 'フジノミヤシ', '野中', 'ノナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士宮市淀川町', '22', '22207', '4180041', '静岡県', 'シズオカケン', '富士宮市', 'フジノミヤシ', '淀川町', 'ヨドガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士宮市貴船町', '22', '22207', '4180042', '静岡県', 'シズオカケン', '富士宮市', 'フジノミヤシ', '貴船町', 'キブネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士宮市泉町', '22', '22207', '4180043', '静岡県', 'シズオカケン', '富士宮市', 'フジノミヤシ', '泉町', 'イズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士宮市大中里', '22', '22207', '4180044', '静岡県', 'シズオカケン', '富士宮市', 'フジノミヤシ', '大中里', 'オオナカザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士宮市中島町', '22', '22207', '4180045', '静岡県', 'シズオカケン', '富士宮市', 'フジノミヤシ', '中島町', 'ナカジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士宮市中里東町', '22', '22207', '4180046', '静岡県', 'シズオカケン', '富士宮市', 'フジノミヤシ', '中里東町', 'ナカザトヒガシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士宮市青木', '22', '22207', '4180047', '静岡県', 'シズオカケン', '富士宮市', 'フジノミヤシ', '青木', 'アオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士宮市青木平', '22', '22207', '4180048', '静岡県', 'シズオカケン', '富士宮市', 'フジノミヤシ', '青木平', 'アオキダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士宮市淀師', '22', '22207', '4180051', '静岡県', 'シズオカケン', '富士宮市', 'フジノミヤシ', '淀師', 'ヨドシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士宮市淀平町', '22', '22207', '4180052', '静岡県', 'シズオカケン', '富士宮市', 'フジノミヤシ', '淀平町', 'ヨドヒラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士宮市宮北町', '22', '22207', '4180053', '静岡県', 'シズオカケン', '富士宮市', 'フジノミヤシ', '宮北町', 'ミヤキタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士宮市光町', '22', '22207', '4180054', '静岡県', 'シズオカケン', '富士宮市', 'フジノミヤシ', '光町', 'ヒカリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士宮市宝町', '22', '22207', '4180055', '静岡県', 'シズオカケン', '富士宮市', 'フジノミヤシ', '宝町', 'タカラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士宮市西町', '22', '22207', '4180056', '静岡県', 'シズオカケン', '富士宮市', 'フジノミヤシ', '西町', 'ニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士宮市朝日町', '22', '22207', '4180057', '静岡県', 'シズオカケン', '富士宮市', 'フジノミヤシ', '朝日町', 'アサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士宮市穂波町', '22', '22207', '4180058', '静岡県', 'シズオカケン', '富士宮市', 'フジノミヤシ', '穂波町', 'ホナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士宮市北町', '22', '22207', '4180061', '静岡県', 'シズオカケン', '富士宮市', 'フジノミヤシ', '北町', 'キタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士宮市城北町', '22', '22207', '4180062', '静岡県', 'シズオカケン', '富士宮市', 'フジノミヤシ', '城北町', 'ジョウホクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士宮市若の宮町', '22', '22207', '4180063', '静岡県', 'シズオカケン', '富士宮市', 'フジノミヤシ', '若の宮町', 'ワカノミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士宮市元城町', '22', '22207', '4180064', '静岡県', 'シズオカケン', '富士宮市', 'フジノミヤシ', '元城町', 'モトシロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士宮市中央町', '22', '22207', '4180065', '静岡県', 'シズオカケン', '富士宮市', 'フジノミヤシ', '中央町', 'チュウオウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士宮市大宮町', '22', '22207', '4180066', '静岡県', 'シズオカケン', '富士宮市', 'フジノミヤシ', '大宮町', 'オオミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士宮市宮町', '22', '22207', '4180067', '静岡県', 'シズオカケン', '富士宮市', 'フジノミヤシ', '宮町', 'ミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士宮市豊町', '22', '22207', '4180068', '静岡県', 'シズオカケン', '富士宮市', 'フジノミヤシ', '豊町', 'ユタカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士宮市東阿幸地', '22', '22207', '4180071', '静岡県', 'シズオカケン', '富士宮市', 'フジノミヤシ', '東阿幸地', 'ヒガシアコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士宮市矢立町', '22', '22207', '4180072', '静岡県', 'シズオカケン', '富士宮市', 'フジノミヤシ', '矢立町', 'ヤタテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士宮市弓沢町', '22', '22207', '4180073', '静岡県', 'シズオカケン', '富士宮市', 'フジノミヤシ', '弓沢町', 'ユミザワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士宮市源道寺町', '22', '22207', '4180074', '静岡県', 'シズオカケン', '富士宮市', 'フジノミヤシ', '源道寺町', 'ゲンドウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士宮市田中町', '22', '22207', '4180075', '静岡県', 'シズオカケン', '富士宮市', 'フジノミヤシ', '田中町', 'タナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士宮市錦町', '22', '22207', '4180076', '静岡県', 'シズオカケン', '富士宮市', 'フジノミヤシ', '錦町', 'ニシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士宮市東町', '22', '22207', '4180077', '静岡県', 'シズオカケン', '富士宮市', 'フジノミヤシ', '東町', 'ヒガシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士宮市阿幸地町', '22', '22207', '4180078', '静岡県', 'シズオカケン', '富士宮市', 'フジノミヤシ', '阿幸地町', 'アコウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士宮市根原', '22', '22207', '4180101', '静岡県', 'シズオカケン', '富士宮市', 'フジノミヤシ', '根原', 'ネバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士宮市人穴', '22', '22207', '4180102', '静岡県', 'シズオカケン', '富士宮市', 'フジノミヤシ', '人穴', 'ヒトアナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士宮市上井出', '22', '22207', '4180103', '静岡県', 'シズオカケン', '富士宮市', 'フジノミヤシ', '上井出', 'カミイデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士宮市内野', '22', '22207', '4180104', '静岡県', 'シズオカケン', '富士宮市', 'フジノミヤシ', '内野', 'ウツノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士宮市原', '22', '22207', '4180105', '静岡県', 'シズオカケン', '富士宮市', 'フジノミヤシ', '原', 'ハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士宮市半野', '22', '22207', '4180106', '静岡県', 'シズオカケン', '富士宮市', 'フジノミヤシ', '半野', 'ハンノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士宮市佐折', '22', '22207', '4180107', '静岡県', 'シズオカケン', '富士宮市', 'フジノミヤシ', '佐折', 'サオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士宮市猪之頭', '22', '22207', '4180108', '静岡県', 'シズオカケン', '富士宮市', 'フジノミヤシ', '猪之頭', 'イノカシラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士宮市麓', '22', '22207', '4180109', '静岡県', 'シズオカケン', '富士宮市', 'フジノミヤシ', '麓', 'フモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士宮市山宮', '22', '22207', '4180111', '静岡県', 'シズオカケン', '富士宮市', 'フジノミヤシ', '山宮', 'ヤマミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士宮市北山', '22', '22207', '4180112', '静岡県', 'シズオカケン', '富士宮市', 'フジノミヤシ', '北山', 'キタヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士宮市馬見塚', '22', '22207', '4180113', '静岡県', 'シズオカケン', '富士宮市', 'フジノミヤシ', '馬見塚', 'ウマミヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士宮市下条', '22', '22207', '4180114', '静岡県', 'シズオカケン', '富士宮市', 'フジノミヤシ', '下条', 'シモジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士宮市精進川', '22', '22207', '4180115', '静岡県', 'シズオカケン', '富士宮市', 'フジノミヤシ', '精進川', 'ショウジンガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士宮市上条', '22', '22207', '4180116', '静岡県', 'シズオカケン', '富士宮市', 'フジノミヤシ', '上条', 'カミジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士宮市狩宿', '22', '22207', '4180117', '静岡県', 'シズオカケン', '富士宮市', 'フジノミヤシ', '狩宿', 'カリヤド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県田方郡函南町', '22', '22325', '4190100', '静岡県', 'シズオカケン', '田方郡函南町', 'タガタグンカンナミチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('38236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県田方郡函南町桑原', '22', '22325', '4190101', '静岡県', 'シズオカケン', '田方郡函南町', 'タガタグンカンナミチョウ', '桑原', 'クワハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県田方郡函南町田代', '22', '22325', '4190102', '静岡県', 'シズオカケン', '田方郡函南町', 'タガタグンカンナミチョウ', '田代', 'タシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県田方郡函南町軽井沢', '22', '22325', '4190103', '静岡県', 'シズオカケン', '田方郡函南町', 'タガタグンカンナミチョウ', '軽井沢', 'カルイサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県田方郡函南町畑', '22', '22325', '4190104', '静岡県', 'シズオカケン', '田方郡函南町', 'タガタグンカンナミチョウ', '畑', 'ハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県田方郡函南町丹那', '22', '22325', '4190105', '静岡県', 'シズオカケン', '田方郡函南町', 'タガタグンカンナミチョウ', '丹那', 'タンナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県田方郡函南町南箱根ダイヤランド', '22', '22325', '4190106', '静岡県', 'シズオカケン', '田方郡函南町', 'タガタグンカンナミチョウ', '南箱根ダイヤランド', 'ミナミハコネダイヤランド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県田方郡函南町平井', '22', '22325', '4190107', '静岡県', 'シズオカケン', '田方郡函南町', 'タガタグンカンナミチョウ', '平井', 'ヒライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県田方郡函南町畑毛', '22', '22325', '4190111', '静岡県', 'シズオカケン', '田方郡函南町', 'タガタグンカンナミチョウ', '畑毛', 'ハタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県田方郡函南町柏谷', '22', '22325', '4190112', '静岡県', 'シズオカケン', '田方郡函南町', 'タガタグンカンナミチョウ', '柏谷', 'カシヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県田方郡函南町大土肥', '22', '22325', '4190113', '静岡県', 'シズオカケン', '田方郡函南町', 'タガタグンカンナミチョウ', '大土肥', 'オオドイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県田方郡函南町仁田', '22', '22325', '4190114', '静岡県', 'シズオカケン', '田方郡函南町', 'タガタグンカンナミチョウ', '仁田', 'ニッタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県田方郡函南町新田', '22', '22325', '4190115', '静岡県', 'シズオカケン', '田方郡函南町', 'タガタグンカンナミチョウ', '新田', 'シンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県田方郡函南町日守', '22', '22325', '4190116', '静岡県', 'シズオカケン', '田方郡函南町', 'タガタグンカンナミチョウ', '日守', 'ヒモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県田方郡函南町大竹', '22', '22325', '4190121', '静岡県', 'シズオカケン', '田方郡函南町', 'タガタグンカンナミチョウ', '大竹', 'オオタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県田方郡函南町上沢', '22', '22325', '4190122', '静岡県', 'シズオカケン', '田方郡函南町', 'タガタグンカンナミチョウ', '上沢', 'カミサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県田方郡函南町間宮', '22', '22325', '4190123', '静岡県', 'シズオカケン', '田方郡函南町', 'タガタグンカンナミチョウ', '間宮', 'マミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県田方郡函南町塚本', '22', '22325', '4190124', '静岡県', 'シズオカケン', '田方郡函南町', 'タガタグンカンナミチョウ', '塚本', 'ツカモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県田方郡函南町肥田', '22', '22325', '4190125', '静岡県', 'シズオカケン', '田方郡函南町', 'タガタグンカンナミチョウ', '肥田', 'ヒタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市厚原', '22', '22210', '4190201', '静岡県', 'シズオカケン', '富士市', 'フジシ', '厚原', 'アツハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市久沢', '22', '22210', '4190202', '静岡県', 'シズオカケン', '富士市', 'フジシ', '久沢', 'クザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市鷹岡本町', '22', '22210', '4190203', '静岡県', 'シズオカケン', '富士市', 'フジシ', '鷹岡本町', 'タカオカホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市入山瀬', '22', '22210', '4190204', '静岡県', 'シズオカケン', '富士市', 'フジシ', '入山瀬', 'イリヤマセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市天間', '22', '22210', '4190205', '静岡県', 'シズオカケン', '富士市', 'フジシ', '天間', 'テンマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士郡芝川町', '22', '22361', '4190300', '静岡県', 'シズオカケン', '富士郡芝川町', 'フジグンシバカワチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('38264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士郡芝川町上柚野', '22', '22361', '4190301', '静岡県', 'シズオカケン', '富士郡芝川町', 'フジグンシバカワチョウ', '上柚野', 'カミユノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士郡芝川町猫沢', '22', '22361', '4190302', '静岡県', 'シズオカケン', '富士郡芝川町', 'フジグンシバカワチョウ', '猫沢', 'ネコザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士郡芝川町大鹿窪', '22', '22361', '4190303', '静岡県', 'シズオカケン', '富士郡芝川町', 'フジグンシバカワチョウ', '大鹿窪', 'オオシカクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士郡芝川町鳥並', '22', '22361', '4190304', '静岡県', 'シズオカケン', '富士郡芝川町', 'フジグンシバカワチョウ', '鳥並', 'トリナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士郡芝川町下柚野', '22', '22361', '4190305', '静岡県', 'シズオカケン', '富士郡芝川町', 'フジグンシバカワチョウ', '下柚野', 'シモユノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士郡芝川町上稲子', '22', '22361', '4190311', '静岡県', 'シズオカケン', '富士郡芝川町', 'フジグンシバカワチョウ', '上稲子', 'カミイナコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士郡芝川町下稲子', '22', '22361', '4190312', '静岡県', 'シズオカケン', '富士郡芝川町', 'フジグンシバカワチョウ', '下稲子', 'シモイナコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士郡芝川町西山', '22', '22361', '4190313', '静岡県', 'シズオカケン', '富士郡芝川町', 'フジグンシバカワチョウ', '西山', 'ニシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士郡芝川町大久保', '22', '22361', '4190314', '静岡県', 'シズオカケン', '富士郡芝川町', 'フジグンシバカワチョウ', '大久保', 'オオクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士郡芝川町長貫', '22', '22361', '4190315', '静岡県', 'シズオカケン', '富士郡芝川町', 'フジグンシバカワチョウ', '長貫', 'ナガヌキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士郡芝川町羽鮒', '22', '22361', '4190316', '静岡県', 'シズオカケン', '富士郡芝川町', 'フジグンシバカワチョウ', '羽鮒', 'ハブナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士郡芝川町内房', '22', '22361', '4190317', '静岡県', 'シズオカケン', '富士郡芝川町', 'フジグンシバカワチョウ', '内房', 'ウツブサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区井宮町', '22', '22101', '4200001', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '井宮町', 'イノミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区材木町', '22', '22101', '4200002', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '材木町', 'ザイモクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区片羽町', '22', '22101', '4200003', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '片羽町', 'カタハチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区末広町', '22', '22101', '4200004', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '末広町', 'スエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区北番町', '22', '22101', '4200005', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '北番町', 'キタバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区若松町', '22', '22101', '4200006', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '若松町', 'ワカマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区柳町', '22', '22101', '4200007', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '柳町', 'ヤナギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区水道町', '22', '22101', '4200008', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '水道町', 'スイドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区神明町', '22', '22101', '4200009', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '神明町', 'シンメイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区安西', '22', '22101', '4200011', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '安西', 'アンザイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区柚木町', '22', '22101', '4200012', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '柚木町', 'ユズノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区八千代町', '22', '22101', '4200013', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '八千代町', 'ヤチヨチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区上桶屋町', '22', '22101', '4200014', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '上桶屋町', 'カミオケヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区錦町', '22', '22101', '4200015', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '錦町', 'ニシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区住吉町', '22', '22101', '4200016', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '住吉町', 'スミヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区葵町', '22', '22101', '4200017', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '葵町', 'アオイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区土太夫町', '22', '22101', '4200018', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '土太夫町', 'ドダユウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区茶町', '22', '22101', '4200021', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '茶町', 'チャマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区車町', '22', '22101', '4200022', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '車町', 'クルマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区富士見町', '22', '22101', '4200023', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '富士見町', 'フジミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区中町', '22', '22101', '4200024', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '中町', 'ナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区金座町', '22', '22101', '4200025', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '金座町', 'キンザマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区大鋸町', '22', '22101', '4200026', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '大鋸町', 'オオガマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区大工町', '22', '22101', '4200027', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '大工町', 'ダイクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区屋形町', '22', '22101', '4200028', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '屋形町', 'ヤカタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区研屋町', '22', '22101', '4200029', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '研屋町', 'トギヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区呉服町', '22', '22101', '4200031', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '呉服町', 'ゴフクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区両替町', '22', '22101', '4200032', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '両替町', 'リョウガエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区昭和町', '22', '22101', '4200033', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '昭和町', 'ショウワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区常磐町', '22', '22101', '4200034', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '常磐町', 'トキワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区七間町', '22', '22101', '4200035', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '七間町', 'シチケンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区駿河町', '22', '22101', '4200036', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '駿河町', 'スルガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区人宿町', '22', '22101', '4200037', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '人宿町', 'ヒトヤドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区梅屋町', '22', '22101', '4200038', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '梅屋町', 'ウメヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区上石町', '22', '22101', '4200039', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '上石町', 'カミゴクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区双葉町', '22', '22101', '4200041', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '双葉町', 'フタバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区駒形通', '22', '22101', '4200042', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '駒形通', 'コマガタドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区川辺町', '22', '22101', '4200043', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '川辺町', 'カワナベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区西門町', '22', '22101', '4200044', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '西門町', 'ニシモンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区天王町', '22', '22101', '4200045', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '天王町', 'テンノウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区吉野町', '22', '22101', '4200046', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '吉野町', 'ヨシノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区清閑町', '22', '22101', '4200047', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '清閑町', 'セイカンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区桜木町', '22', '22101', '4200048', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '桜木町', 'サクラギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区南田町', '22', '22101', '4200051', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '南田町', 'ミナミタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区川越町', '22', '22101', '4200052', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '川越町', 'カワゴシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区弥勒', '22', '22101', '4200053', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '弥勒', 'ミロク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区南安倍1丁目', '22', '22101', '4200054', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '南安倍', 'ミナミアベ', null, null, '1丁目', '01チョウメ');
INSERT INTO `ms_addresses` VALUES ('38324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区南安倍2丁目', '22', '22101', '4200054', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '南安倍', 'ミナミアベ', null, null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('38325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区新富町', '22', '22101', '4200061', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '新富町', 'シントミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区上新富町', '22', '22101', '4200062', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '上新富町', 'カミシントミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区通車町', '22', '22101', '4200063', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '通車町', 'トオリクルマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区本通', '22', '22101', '4200064', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '本通', 'ホントオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区新通', '22', '22101', '4200065', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '新通', 'シントオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区本通西町', '22', '22101', '4200066', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '本通西町', 'ホントオリニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区幸町', '22', '22101', '4200067', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区田町', '22', '22101', '4200068', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '田町', 'タマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区一番町', '22', '22101', '4200071', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '一番町', 'イチバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区二番町', '22', '22101', '4200072', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '二番町', 'ニバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区三番町', '22', '22101', '4200073', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '三番町', 'サンバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区四番町', '22', '22101', '4200074', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '四番町', 'ヨンバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区五番町', '22', '22101', '4200075', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '五番町', 'ゴバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区六番町', '22', '22101', '4200076', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '六番町', 'ロクバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区七番町', '22', '22101', '4200077', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '七番町', 'シチバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区八番町', '22', '22101', '4200078', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '八番町', 'ハチバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区東千代田', '22', '22101', '4200801', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '東千代田', 'ヒガシチヨダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区千代田', '22', '22101', '4200803', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '千代田', 'チヨダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区竜南', '22', '22101', '4200804', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '竜南', 'リュウナン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区城北', '22', '22101', '4200805', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '城北', 'ジョウホク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区上土', '22', '22101', '4200810', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '上土', 'アゲツチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区上土新田', '22', '22101', '4200811', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '上土新田', 'アゲツチシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区古庄', '22', '22101', '4200812', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '古庄', 'フルショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区長沼', '22', '22101', '4200813', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '長沼', 'ナガヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区上沓谷町', '22', '22101', '4200815', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '上沓谷町', 'カミクツノヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区沓谷', '22', '22101', '4200816', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '沓谷', 'クツノヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区柚木', '22', '22101', '4200821', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '柚木', 'ユノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区宮前町', '22', '22101', '4200822', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '宮前町', 'ミヤマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区春日', '22', '22101', '4200823', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '春日', 'カスガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区春日町', '22', '22101', '4200824', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '春日町', 'カスガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区瓦場町', '22', '22101', '4200825', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '瓦場町', 'カワラバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区水落町', '22', '22101', '4200831', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '水落町', 'ミズオチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区横内町', '22', '22101', '4200832', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '横内町', 'ヨコウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区東鷹匠町', '22', '22101', '4200833', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '東鷹匠町', 'ヒガシタカジョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区音羽町', '22', '22101', '4200834', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '音羽町', 'オトワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区横田町', '22', '22101', '4200835', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '横田町', 'ヨコタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区東町', '22', '22101', '4200836', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '東町', 'アズマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区日出町', '22', '22101', '4200837', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '日出町', 'ヒノデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区相生町', '22', '22101', '4200838', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '相生町', 'アイオイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区鷹匠', '22', '22101', '4200839', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '鷹匠', 'タカジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区上足洗', '22', '22101', '4200841', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '上足洗', 'カミアシアライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区銭座町', '22', '22101', '4200842', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '銭座町', 'ゼンザマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区巴町', '22', '22101', '4200843', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '巴町', 'トモエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区緑町', '22', '22101', '4200844', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '緑町', 'ミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区太田町', '22', '22101', '4200845', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '太田町', 'オオタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区城東町', '22', '22101', '4200846', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '城東町', 'ジョウトウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区西千代田町', '22', '22101', '4200847', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '西千代田町', 'ニシチヨダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区黒金町', '22', '22101', '4200851', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '黒金町', 'クロガネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区紺屋町', '22', '22101', '4200852', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '紺屋町', 'コウヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区追手町', '22', '22101', '4200853', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '追手町', 'オウテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区城内町', '22', '22101', '4200854', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '城内町', 'ジョウナイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区駿府公園', '22', '22101', '4200855', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '駿府公園', 'スンプコウエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区駿府町', '22', '22101', '4200856', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '駿府町', 'スンプチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区御幸町', '22', '22101', '4200857', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '御幸町', 'ミユキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区伝馬町', '22', '22101', '4200858', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '伝馬町', 'テンマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区栄町', '22', '22101', '4200859', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '栄町', 'サカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区丸山町', '22', '22101', '4200861', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '丸山町', 'マルヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区浅間町', '22', '22101', '4200862', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '浅間町', 'センゲンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区安東柳町', '22', '22101', '4200863', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '安東柳町', 'アンドウヤナギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区長谷町', '22', '22101', '4200864', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '長谷町', 'ハセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区東草深町', '22', '22101', '4200865', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '東草深町', 'ヒガシクサブカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区西草深町', '22', '22101', '4200866', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '西草深町', 'ニシクサブカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区馬場町', '22', '22101', '4200867', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '馬場町', 'ババンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区宮ケ崎町', '22', '22101', '4200868', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '宮ケ崎町', 'ミヤガサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区安倍町', '22', '22101', '4200869', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '安倍町', 'アベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区昭府', '22', '22101', '4200871', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '昭府', 'ショウブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区昭府町', '22', '22101', '4200872', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '昭府町', 'ショウブチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区籠上', '22', '22101', '4200873', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '籠上', 'カゴウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区辰起町', '22', '22101', '4200874', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '辰起町', 'タツキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区美川町', '22', '22101', '4200875', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '美川町', 'ミカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区平和', '22', '22101', '4200876', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '平和', 'ヘイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区北安東', '22', '22101', '4200881', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '北安東', 'キタアンドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区安東', '22', '22101', '4200882', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '安東', 'アンドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区大岩宮下町', '22', '22101', '4200883', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '大岩宮下町', 'オオイワミヤシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区大岩本町', '22', '22101', '4200884', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '大岩本町', 'オオイワホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区大岩町', '22', '22101', '4200885', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '大岩町', 'オオイワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区大岩', '22', '22101', '4200886', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '大岩', 'オオイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区北沼上', '22', '22101', '4200901', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '北沼上', 'キタヌマガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区諏訪', '22', '22101', '4200902', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '諏訪', 'スワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区長尾', '22', '22101', '4200903', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '長尾', 'ナガオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区平山', '22', '22101', '4200904', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '平山', 'ヒラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区南沼上', '22', '22101', '4200905', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '南沼上', 'ミナミヌマガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区薬師', '22', '22101', '4200906', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '薬師', 'ヤクシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区瀬名', '22', '22101', '4200911', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '瀬名', 'セナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区東瀬名町', '22', '22101', '4200912', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '東瀬名町', 'ヒガシセナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区瀬名川', '22', '22101', '4200913', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '瀬名川', 'セナガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区西瀬名町', '22', '22101', '4200914', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '西瀬名町', 'ニシセナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区南瀬名町', '22', '22101', '4200915', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '南瀬名町', 'ミナミセナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区瀬名中央', '22', '22101', '4200916', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '瀬名中央', 'セナチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区野丈', '22', '22101', '4200921', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '野丈', 'ノダケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区流通センター', '22', '22101', '4200922', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '流通センター', 'リュウツウセンター', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区川合', '22', '22101', '4200923', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '川合', 'カワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区川合新田', '22', '22101', '4200924', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '川合新田', 'カワイシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区加藤島', '22', '22101', '4200925', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '加藤島', 'カトウジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区観山', '22', '22101', '4200931', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '観山', 'カンザン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区豊地', '22', '22101', '4200932', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '豊地', 'トヨチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区立石', '22', '22101', '4200933', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '立石', 'タテイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区岳美', '22', '22101', '4200934', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '岳美', 'タケミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区池ケ谷東', '22', '22101', '4200935', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '池ケ谷東', 'イケガヤヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区池ケ谷', '22', '22101', '4200936', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '池ケ谷', 'イケガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区唐瀬', '22', '22101', '4200937', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '唐瀬', 'カラセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区松富', '22', '22101', '4200941', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '松富', 'マツドミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区松富上組', '22', '22101', '4200942', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '松富上組', 'マツドミカミグミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区上伝馬', '22', '22101', '4200943', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '上伝馬', 'カミテンマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区新伝馬', '22', '22101', '4200944', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '新伝馬', 'シンテンマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区桜町', '22', '22101', '4200945', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '桜町', 'サクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区伊呂波町', '22', '22101', '4200946', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '伊呂波町', 'イロハチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区堤町', '22', '22101', '4200947', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '堤町', 'ツツミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区秋山町', '22', '22101', '4200948', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '秋山町', 'アキヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区与一', '22', '22101', '4200949', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '与一', 'ヨイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区天神前', '22', '22101', '4200951', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '天神前', 'テンジンマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区牛田', '22', '22101', '4200952', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '牛田', 'ウシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区漆山', '22', '22101', '4200953', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '漆山', 'ウルシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区平柳', '22', '22101', '4200954', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '平柳', 'ヒラヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区芝原', '22', '22101', '4200955', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '芝原', 'シバハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区南', '22', '22101', '4200956', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '南', 'ミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区前林', '22', '22101', '4200957', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '前林', 'マエバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区北', '22', '22101', '4200961', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '北', 'キタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区東', '22', '22101', '4200962', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '東', 'ヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区赤松', '22', '22101', '4200963', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '赤松', 'アカマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区柳原', '22', '22101', '4200964', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '柳原', 'ヤナギハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区有永', '22', '22101', '4200965', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '有永', 'アリナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区羽高', '22', '22101', '4200966', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '羽高', 'ハタカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市蛾眉野町', '01', '01202', '0420901', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '蛾眉野町', 'ガビノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市鉄山町', '01', '01202', '0420902', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '鉄山町', 'テツザンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市東畑町', '01', '01202', '0420903', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '東畑町', 'ヒガシハタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市庵原町', '01', '01202', '0420904', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '庵原町', 'イオハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市紅葉山町', '01', '01202', '0420905', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '紅葉山町', 'モミジヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市三森町', '01', '01202', '0420906', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '三森町', 'ミツモリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市鱒川町', '01', '01202', '0420907', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '鱒川町', 'マスカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市銅山町', '01', '01202', '0420908', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '銅山町', 'ドウザンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市石倉町', '01', '01202', '0420911', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '石倉町', 'イシクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市中野町', '01', '01202', '0420912', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '中野町', 'ナカノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市赤坂町', '01', '01202', '0420913', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '赤坂町', 'アカサカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市上湯川町', '01', '01202', '0420914', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '上湯川町', 'カミユノカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市西旭岡町', '01', '01202', '0420915', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '西旭岡町', 'ニシアサヒオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市旭岡町', '01', '01202', '0420916', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '旭岡町', 'アサヒオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市亀尾町', '01', '01202', '0420917', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '亀尾町', 'カメオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市米原町', '01', '01202', '0420918', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '米原町', 'マイハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市新湊町', '01', '01202', '0420921', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '新湊町', 'シンミナトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市銭亀町', '01', '01202', '0420922', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '銭亀町', 'ゼニカメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市志海苔町', '01', '01202', '0420923', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '志海苔町', 'シノリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市根崎町', '01', '01202', '0420924', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '根崎町', 'ネサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市榎本町', '01', '01202', '0420931', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '榎本町', 'エノモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市湯川町', '01', '01202', '0420932', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '湯川町', 'ユノカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市湯浜町', '01', '01202', '0420933', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '湯浜町', 'ユノハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市広野町', '01', '01202', '0420934', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '広野町', 'ヒロノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市駒場町', '01', '01202', '0420935', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '駒場町', 'コマバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市深堀町', '01', '01202', '0420941', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '深堀町', 'フカボリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市柏木町', '01', '01202', '0420942', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '柏木町', 'カシワギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市乃木町', '01', '01202', '0420943', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '乃木町', 'ノギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市金堀町', '01', '01202', '0420944', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '金堀町', 'カナホリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市瀬戸川町', '01', '01202', '0420951', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '瀬戸川町', 'セトガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市高松町', '01', '01202', '0420952', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '高松町', 'タカマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市戸倉町', '01', '01202', '0420953', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '戸倉町', 'トクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市上野町', '01', '01202', '0420954', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '上野町', 'ウエノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市高丘町', '01', '01202', '0420955', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '高丘町', 'タカオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市見晴町', '01', '01202', '0420956', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '見晴町', 'ミハラシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市滝沢町', '01', '01202', '0420957', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '滝沢町', 'タキサワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道函館市鈴蘭丘町', '01', '01202', '0420958', '北海道', 'ホッカイドウ', '函館市', 'ハコダテシ', '鈴蘭丘町', 'スズランオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市駿河区向敷地', '22', '22102', '4210101', '静岡県', 'シズオカケン', '静岡市駿河区', 'シズオカシスルガク', '向敷地', 'ムコウシキジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市駿河区手越', '22', '22102', '4210102', '静岡県', 'シズオカケン', '静岡市駿河区', 'シズオカシスルガク', '手越', 'テゴシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市駿河区丸子', '22', '22102', '4210103', '静岡県', 'シズオカケン', '静岡市駿河区', 'シズオカシスルガク', '丸子', 'マリコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市駿河区丸子芹が谷町', '22', '22102', '4210104', '静岡県', 'シズオカケン', '静岡市駿河区', 'シズオカシスルガク', '丸子芹が谷町', 'マリコセリガヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市駿河区宇津ノ谷', '22', '22102', '4210105', '静岡県', 'シズオカケン', '静岡市駿河区', 'シズオカシスルガク', '宇津ノ谷', 'ウツノヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市駿河区北丸子', '22', '22102', '4210106', '静岡県', 'シズオカケン', '静岡市駿河区', 'シズオカシスルガク', '北丸子', 'キタマリコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市駿河区丸子新田', '22', '22102', '4210111', '静岡県', 'シズオカケン', '静岡市駿河区', 'シズオカシスルガク', '丸子新田', 'マリコシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市駿河区東新田', '22', '22102', '4210112', '静岡県', 'シズオカケン', '静岡市駿河区', 'シズオカシスルガク', '東新田', 'トウシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市駿河区下川原', '22', '22102', '4210113', '静岡県', 'シズオカケン', '静岡市駿河区', 'シズオカシスルガク', '下川原', 'シモカワハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市駿河区桃園町', '22', '22102', '4210114', '静岡県', 'シズオカケン', '静岡市駿河区', 'シズオカシスルガク', '桃園町', 'モモゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市駿河区みずほ', '22', '22102', '4210115', '静岡県', 'シズオカケン', '静岡市駿河区', 'シズオカシスルガク', 'みずほ', 'ミズホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市駿河区光陽町', '22', '22102', '4210116', '静岡県', 'シズオカケン', '静岡市駿河区', 'シズオカシスルガク', '光陽町', 'コウヨウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市駿河区下川原南', '22', '22102', '4210117', '静岡県', 'シズオカケン', '静岡市駿河区', 'シズオカシスルガク', '下川原南', 'シモカワハラミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市駿河区広野', '22', '22102', '4210121', '静岡県', 'シズオカケン', '静岡市駿河区', 'シズオカシスルガク', '広野', 'ヒロノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市駿河区用宗', '22', '22102', '4210122', '静岡県', 'シズオカケン', '静岡市駿河区', 'シズオカシスルガク', '用宗', 'モチムネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市駿河区石部', '22', '22102', '4210123', '静岡県', 'シズオカケン', '静岡市駿河区', 'シズオカシスルガク', '石部', 'セキベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市駿河区用宗城山町', '22', '22102', '4210124', '静岡県', 'シズオカケン', '静岡市駿河区', 'シズオカシスルガク', '用宗城山町', 'モチムネシロヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市駿河区用宗小石町', '22', '22102', '4210125', '静岡県', 'シズオカケン', '静岡市駿河区', 'シズオカシスルガク', '用宗小石町', 'モチムネコイシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市駿河区用宗巴町', '22', '22102', '4210126', '静岡県', 'シズオカケン', '静岡市駿河区', 'シズオカシスルガク', '用宗巴町', 'モチムネトモエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市駿河区手越原', '22', '22102', '4210131', '静岡県', 'シズオカケン', '静岡市駿河区', 'シズオカシスルガク', '手越原', 'テゴシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市駿河区上川原', '22', '22102', '4210132', '静岡県', 'シズオカケン', '静岡市駿河区', 'シズオカシスルガク', '上川原', 'カミカワハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市駿河区鎌田', '22', '22102', '4210133', '静岡県', 'シズオカケン', '静岡市駿河区', 'シズオカシスルガク', '鎌田', 'カマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市駿河区青木', '22', '22102', '4210134', '静岡県', 'シズオカケン', '静岡市駿河区', 'シズオカシスルガク', '青木', 'アオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市駿河区小坂', '22', '22102', '4210135', '静岡県', 'シズオカケン', '静岡市駿河区', 'シズオカシスルガク', '小坂', 'オサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市駿河区大和田', '22', '22102', '4210136', '静岡県', 'シズオカケン', '静岡市駿河区', 'シズオカシスルガク', '大和田', 'オオワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市駿河区寺田', '22', '22102', '4210137', '静岡県', 'シズオカケン', '静岡市駿河区', 'シズオカシスルガク', '寺田', 'テラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県焼津市上小杉', '22', '22212', '4210201', '静岡県', 'シズオカケン', '焼津市', 'ヤイヅシ', '上小杉', 'カミコスギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県焼津市下小杉', '22', '22212', '4210202', '静岡県', 'シズオカケン', '焼津市', 'ヤイヅシ', '下小杉', 'シモコスギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県焼津市藤守', '22', '22212', '4210203', '静岡県', 'シズオカケン', '焼津市', 'ヤイヅシ', '藤守', 'フジモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県焼津市高新田', '22', '22212', '4210204', '静岡県', 'シズオカケン', '焼津市', 'ヤイヅシ', '高新田', 'タカシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県焼津市宗高', '22', '22212', '4210205', '静岡県', 'シズオカケン', '焼津市', 'ヤイヅシ', '宗高', 'ムナダカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県焼津市上新田', '22', '22212', '4210206', '静岡県', 'シズオカケン', '焼津市', 'ヤイヅシ', '上新田', 'カミシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県焼津市吉永', '22', '22212', '4210211', '静岡県', 'シズオカケン', '焼津市', 'ヤイヅシ', '吉永', 'ヨシナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県焼津市利右衛門', '22', '22212', '4210212', '静岡県', 'シズオカケン', '焼津市', 'ヤイヅシ', '利右衛門', 'リエモン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県焼津市飯淵', '22', '22212', '4210213', '静岡県', 'シズオカケン', '焼津市', 'ヤイヅシ', '飯淵', 'ハブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県焼津市中島', '22', '22212', '4210214', '静岡県', 'シズオカケン', '焼津市', 'ヤイヅシ', '中島', 'ナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県焼津市西島', '22', '22212', '4210215', '静岡県', 'シズオカケン', '焼津市', 'ヤイヅシ', '西島', 'ニシジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県焼津市相川', '22', '22212', '4210216', '静岡県', 'シズオカケン', '焼津市', 'ヤイヅシ', '相川', 'アイカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県焼津市上泉', '22', '22212', '4210217', '静岡県', 'シズオカケン', '焼津市', 'ヤイヅシ', '上泉', 'カミイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県焼津市下江留', '22', '22212', '4210218', '静岡県', 'シズオカケン', '焼津市', 'ヤイヅシ', '下江留', 'シモエドメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県榛原郡吉田町', '22', '22424', '4210300', '静岡県', 'シズオカケン', '榛原郡吉田町', 'ハイバラグンヨシダチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('38627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県榛原郡吉田町住吉', '22', '22424', '4210301', '静岡県', 'シズオカケン', '榛原郡吉田町', 'ハイバラグンヨシダチョウ', '住吉', 'スミヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県榛原郡吉田町川尻', '22', '22424', '4210302', '静岡県', 'シズオカケン', '榛原郡吉田町', 'ハイバラグンヨシダチョウ', '川尻', 'カワシリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県榛原郡吉田町片岡', '22', '22424', '4210303', '静岡県', 'シズオカケン', '榛原郡吉田町', 'ハイバラグンヨシダチョウ', '片岡', 'カタオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県榛原郡吉田町神戸', '22', '22424', '4210304', '静岡県', 'シズオカケン', '榛原郡吉田町', 'ハイバラグンヨシダチョウ', '神戸', 'カンド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県榛原郡吉田町大幡', '22', '22424', '4210305', '静岡県', 'シズオカケン', '榛原郡吉田町', 'ハイバラグンヨシダチョウ', '大幡', 'オオハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県牧之原市切山', '22', '22226', '4210401', '静岡県', 'シズオカケン', '牧之原市', 'マキノハラシ', '切山', 'キリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県牧之原市勝間', '22', '22226', '4210402', '静岡県', 'シズオカケン', '牧之原市', 'マキノハラシ', '勝間', 'カツマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県牧之原市中', '22', '22226', '4210403', '静岡県', 'シズオカケン', '牧之原市', 'マキノハラシ', '中', 'ナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県牧之原市静谷', '22', '22226', '4210404', '静岡県', 'シズオカケン', '牧之原市', 'マキノハラシ', '静谷', 'シズタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県牧之原市白井', '22', '22226', '4210405', '静岡県', 'シズオカケン', '牧之原市', 'マキノハラシ', '白井', 'シライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県牧之原市勝田', '22', '22226', '4210406', '静岡県', 'シズオカケン', '牧之原市', 'マキノハラシ', '勝田', 'カツタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県牧之原市布引原', '22', '22226', '4210407', '静岡県', 'シズオカケン', '牧之原市', 'マキノハラシ', '布引原', 'ヌノヒキハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県牧之原市嶋', '22', '22226', '4210408', '静岡県', 'シズオカケン', '牧之原市', 'マキノハラシ', '嶋', 'シマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県牧之原市牧之原', '22', '22226', '4210409', '静岡県', 'シズオカケン', '牧之原市', 'マキノハラシ', '牧之原', 'マキノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県牧之原市坂口', '22', '22226', '4210411', '静岡県', 'シズオカケン', '牧之原市', 'マキノハラシ', '坂口', 'サカグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県牧之原市坂部', '22', '22226', '4210412', '静岡県', 'シズオカケン', '牧之原市', 'マキノハラシ', '坂部', 'サカベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県牧之原市仁田', '22', '22226', '4210413', '静岡県', 'シズオカケン', '牧之原市', 'マキノハラシ', '仁田', 'ニタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県牧之原市勝俣', '22', '22226', '4210414', '静岡県', 'シズオカケン', '牧之原市', 'マキノハラシ', '勝俣', 'カツマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県牧之原市道場', '22', '22226', '4210415', '静岡県', 'シズオカケン', '牧之原市', 'マキノハラシ', '道場', 'ドウジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県牧之原市細江', '22', '22226', '4210421', '静岡県', 'シズオカケン', '牧之原市', 'マキノハラシ', '細江', 'ホソエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県牧之原市静波', '22', '22226', '4210422', '静岡県', 'シズオカケン', '牧之原市', 'マキノハラシ', '静波', 'シズナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県牧之原市', '22', '22226', '4210500', '静岡県', 'シズオカケン', '牧之原市', 'マキノハラシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('38659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県牧之原市東萩間', '22', '22226', '4210501', '静岡県', 'シズオカケン', '牧之原市', 'マキノハラシ', '東萩間', 'ヒガシハギマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県牧之原市白井', '22', '22226', '4210502', '静岡県', 'シズオカケン', '牧之原市', 'マキノハラシ', '白井', 'シライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県牧之原市蛭ケ谷', '22', '22226', '4210503', '静岡県', 'シズオカケン', '牧之原市', 'マキノハラシ', '蛭ケ谷', 'ヒルガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県牧之原市黒子', '22', '22226', '4210504', '静岡県', 'シズオカケン', '牧之原市', 'マキノハラシ', '黒子', 'クロコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県牧之原市中西', '22', '22226', '4210505', '静岡県', 'シズオカケン', '牧之原市', 'マキノハラシ', '中西', 'ナカニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県牧之原市大寄', '22', '22226', '4210506', '静岡県', 'シズオカケン', '牧之原市', 'マキノハラシ', '大寄', 'オオヨリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県牧之原市和田', '22', '22226', '4210507', '静岡県', 'シズオカケン', '牧之原市', 'マキノハラシ', '和田', 'ワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県牧之原市西萩間', '22', '22226', '4210508', '静岡県', 'シズオカケン', '牧之原市', 'マキノハラシ', '西萩間', 'ニシハギマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県牧之原市牧之原', '22', '22226', '4210509', '静岡県', 'シズオカケン', '牧之原市', 'マキノハラシ', '牧之原', 'マキノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県牧之原市片浜', '22', '22226', '4210511', '静岡県', 'シズオカケン', '牧之原市', 'マキノハラシ', '片浜', 'カタハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県牧之原市大江', '22', '22226', '4210512', '静岡県', 'シズオカケン', '牧之原市', 'マキノハラシ', '大江', 'オオエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県牧之原市松本', '22', '22226', '4210513', '静岡県', 'シズオカケン', '牧之原市', 'マキノハラシ', '松本', 'マツモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県牧之原市菅ケ谷', '22', '22226', '4210514', '静岡県', 'シズオカケン', '牧之原市', 'マキノハラシ', '菅ケ谷', 'スゲガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県牧之原市西山寺', '22', '22226', '4210515', '静岡県', 'シズオカケン', '牧之原市', 'マキノハラシ', '西山寺', 'サイサンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県牧之原市女神', '22', '22226', '4210516', '静岡県', 'シズオカケン', '牧之原市', 'マキノハラシ', '女神', 'メカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県牧之原市男神', '22', '22226', '4210517', '静岡県', 'シズオカケン', '牧之原市', 'マキノハラシ', '男神', 'オカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県牧之原市福岡', '22', '22226', '4210521', '静岡県', 'シズオカケン', '牧之原市', 'マキノハラシ', '福岡', 'フクオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県牧之原市相良', '22', '22226', '4210522', '静岡県', 'シズオカケン', '牧之原市', 'マキノハラシ', '相良', 'サガラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県牧之原市波津', '22', '22226', '4210523', '静岡県', 'シズオカケン', '牧之原市', 'マキノハラシ', '波津', 'ハヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県牧之原市須々木', '22', '22226', '4210524', '静岡県', 'シズオカケン', '牧之原市', 'マキノハラシ', '須々木', 'ススキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県牧之原市鬼女新田', '22', '22226', '4210525', '静岡県', 'シズオカケン', '牧之原市', 'マキノハラシ', '鬼女新田', 'キジョシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県牧之原市大沢', '22', '22226', '4210526', '静岡県', 'シズオカケン', '牧之原市', 'マキノハラシ', '大沢', 'オオサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県牧之原市汐見台', '22', '22226', '4210527', '静岡県', 'シズオカケン', '牧之原市', 'マキノハラシ', '汐見台', 'シオミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県牧之原市落居', '22', '22226', '4210531', '静岡県', 'シズオカケン', '牧之原市', 'マキノハラシ', '落居', 'オチイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県牧之原市地頭方', '22', '22226', '4210532', '静岡県', 'シズオカケン', '牧之原市', 'マキノハラシ', '地頭方', 'ジトウガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県牧之原市新庄', '22', '22226', '4210533', '静岡県', 'シズオカケン', '牧之原市', 'マキノハラシ', '新庄', 'シンショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県牧之原市堀野新田', '22', '22226', '4210534', '静岡県', 'シズオカケン', '牧之原市', 'マキノハラシ', '堀野新田', 'ホリノシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県牧之原市笠名', '22', '22226', '4210535', '静岡県', 'シズオカケン', '牧之原市', 'マキノハラシ', '笠名', 'カサナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市岡部町玉取', '22', '22214', '4211101', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', '岡部町玉取', 'オカベチョウタマトリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市岡部町宮島', '22', '22214', '4211102', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', '岡部町宮島', 'オカベチョウミヤジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市岡部町青羽根', '22', '22214', '4211103', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', '岡部町青羽根', 'オカベチョウアオハネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市岡部町野田沢', '22', '22214', '4211111', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', '岡部町野田沢', 'オカベチョウノタザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市岡部町殿', '22', '22214', '4211112', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', '岡部町殿', 'オカベチョウトノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市岡部町桂島', '22', '22214', '4211113', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', '岡部町桂島', 'オカベチョウカツラシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市岡部町羽佐間', '22', '22214', '4211114', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', '岡部町羽佐間', 'オカベチョウハサマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市岡部町新舟', '22', '22214', '4211115', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', '岡部町新舟', 'オカベチョウニュウフネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市岡部町岡部', '22', '22214', '4211121', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', '岡部町岡部', 'オカベチョウオカベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市岡部町子持坂', '22', '22214', '4211122', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', '岡部町子持坂', 'オカベチョウコモチザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市岡部町入野', '22', '22214', '4211123', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', '岡部町入野', 'オカベチョウイリノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市岡部町村良', '22', '22214', '4211124', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', '岡部町村良', 'オカベチョウムララ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市岡部町内谷', '22', '22214', '4211131', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', '岡部町内谷', 'オカベチョウウツタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市岡部町三輪', '22', '22214', '4211132', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', '岡部町三輪', 'オカベチョウミワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区新間', '22', '22101', '4211201', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '新間', 'シンマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区谷津', '22', '22101', '4211202', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '谷津', 'ヤツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区慈悲尾', '22', '22101', '4211211', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '慈悲尾', 'シイノオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区千代', '22', '22101', '4211212', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '千代', 'センダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区山崎', '22', '22101', '4211213', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '山崎', 'ヤマザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区建穂', '22', '22101', '4211214', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '建穂', 'タキョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区羽鳥', '22', '22101', '4211215', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '羽鳥', 'ハトリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区羽鳥大門町', '22', '22101', '4211216', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '羽鳥大門町', 'ハトリダイモンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区羽鳥本町', '22', '22101', '4211217', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '羽鳥本町', 'ハトリホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区牧ケ谷', '22', '22101', '4211221', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '牧ケ谷', 'マキガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区産女', '22', '22101', '4211222', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '産女', 'ウブメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区吉津', '22', '22101', '4211223', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '吉津', 'ヨシヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区飯間', '22', '22101', '4211224', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '飯間', 'ハンマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区小瀬戸', '22', '22101', '4211225', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '小瀬戸', 'コゼト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区西又', '22', '22101', '4211226', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '西又', 'ニシマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区小島', '22', '22101', '4211301', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '小島', 'コジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区鍵穴', '22', '22101', '4211302', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '鍵穴', 'カギアナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区坂本', '22', '22101', '4211303', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '坂本', 'サカモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区寺島', '22', '22101', '4211304', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '寺島', 'テラジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区赤沢', '22', '22101', '4211305', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '赤沢', 'アカザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区昼居渡', '22', '22101', '4211306', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '昼居渡', 'ヒルイド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区相俣', '22', '22101', '4211307', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '相俣', 'アイマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区黒俣', '22', '22101', '4211308', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '黒俣', 'クロマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区杉尾', '22', '22101', '4211309', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '杉尾', 'スギオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区富沢', '22', '22101', '4211311', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '富沢', 'トンザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区奈良間', '22', '22101', '4211312', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '奈良間', 'ナラマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区水見色', '22', '22101', '4211313', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '水見色', 'ミズミイロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区大原', '22', '22101', '4211314', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '大原', 'オオハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区富厚里', '22', '22101', '4211315', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '富厚里', 'フコウリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区小布杉', '22', '22101', '4211316', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '小布杉', 'コブスギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区大間', '22', '22101', '4211401', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '大間', 'オオマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区諸子沢', '22', '22101', '4211402', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '諸子沢', 'モロコザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区日向', '22', '22101', '4211403', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '日向', 'ヒナタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区栃沢', '22', '22101', '4211404', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '栃沢', 'トチザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区坂ノ上', '22', '22101', '4211405', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '坂ノ上', 'サカノカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区湯ノ島', '22', '22101', '4211406', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '湯ノ島', 'ユノシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区楢尾', '22', '22101', '4211407', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '楢尾', 'ナラオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区崩野', '22', '22101', '4211408', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '崩野', 'クズレノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区八草', '22', '22101', '4211409', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '八草', 'ヤクサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区俵峰', '22', '22101', '4212101', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '俵峰', 'タワラミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区油島', '22', '22101', '4212102', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '油島', 'ユジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区俵沢', '22', '22101', '4212103', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '俵沢', 'タワラザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区野田平', '22', '22101', '4212104', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '野田平', 'ノタヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区郷島', '22', '22101', '4212105', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '郷島', 'ゴウジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区牛妻', '22', '22101', '4212106', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '牛妻', 'ウシヅマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区門屋', '22', '22101', '4212107', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '門屋', 'カドヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区下', '22', '22101', '4212108', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '下', 'シモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区福田ケ谷', '22', '22101', '4212109', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '福田ケ谷', 'フクダガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区中ノ郷', '22', '22101', '4212111', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '中ノ郷', 'ナカノゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区遠藤新田', '22', '22101', '4212112', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '遠藤新田', 'エンドウシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区安倍口団地', '22', '22101', '4212113', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '安倍口団地', 'アベグチダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区安倍口新田', '22', '22101', '4212114', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '安倍口新田', 'アベグチシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区与左衛門新田', '22', '22101', '4212115', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '与左衛門新田', 'ヨザエモンシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区西ケ谷', '22', '22101', '4212116', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '西ケ谷', 'ニシガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区幸庵新田', '22', '22101', '4212117', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '幸庵新田', 'コウアンシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区内牧', '22', '22101', '4212118', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '内牧', 'ウチマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区津渡野', '22', '22101', '4212121', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '津渡野', 'ツドノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区松野', '22', '22101', '4212122', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '松野', 'マツノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区油山', '22', '22101', '4212123', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '油山', 'ユヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区足久保口組', '22', '22101', '4212124', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '足久保口組', 'アシクボクチグミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区足久保奥組', '22', '22101', '4212125', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '足久保奥組', 'アシクボオクグミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区奥仙俣', '22', '22101', '4212201', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '奥仙俣', 'オクセンマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区口仙俣', '22', '22101', '4212202', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '口仙俣', 'クチセンマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区口坂本', '22', '22101', '4212203', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '口坂本', 'クチサカモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区上落合', '22', '22101', '4212211', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '上落合', 'カミオチアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区油野', '22', '22101', '4212212', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '油野', 'ユノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区長妻田', '22', '22101', '4212213', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '長妻田', 'ナガツマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区柿島', '22', '22101', '4212214', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '柿島', 'カキシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区奥池ケ谷', '22', '22101', '4212215', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '奥池ケ谷', 'オクイケガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区長熊', '22', '22101', '4212216', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '長熊', 'ナガクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区森腰', '22', '22101', '4212217', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '森腰', 'モリコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区中沢', '22', '22101', '4212221', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '中沢', 'ナカザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区桂山', '22', '22101', '4212222', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '桂山', 'カヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区落合', '22', '22101', '4212223', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '落合', 'オチアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区内匠', '22', '22101', '4212224', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '内匠', 'タクミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区腰越', '22', '22101', '4212225', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '腰越', 'コシゴエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区横沢', '22', '22101', '4212226', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '横沢', 'ヨコサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区大沢', '22', '22101', '4212227', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '大沢', 'オオサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区梅ケ島', '22', '22101', '4212301', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '梅ケ島', 'ウメガシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区入島', '22', '22101', '4212302', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '入島', 'ニュウジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区有東木', '22', '22101', '4212303', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '有東木', 'ウトウギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区渡', '22', '22101', '4212304', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '渡', 'ド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区中平', '22', '22101', '4212305', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '中平', 'ナカヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区平野', '22', '22101', '4212306', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '平野', 'ヒラノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区横山', '22', '22101', '4212307', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '横山', 'ヨコヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区蕨野', '22', '22101', '4212308', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '蕨野', 'ワラビノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区相渕', '22', '22101', '4212309', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '相渕', 'アイブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区由比入山', '22', '22103', '4213101', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '由比入山', 'ユイイリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区由比東山寺', '22', '22103', '4213102', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '由比東山寺', 'ユイヒガシヤマデラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区由比', '22', '22103', '4213103', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '由比', 'ユイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区由比北田', '22', '22103', '4213104', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '由比北田', 'ユイキタダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区由比町屋原', '22', '22103', '4213105', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '由比町屋原', 'ユイマチヤハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区由比西山寺', '22', '22103', '4213106', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '由比西山寺', 'ユイニシヤマデラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区由比阿僧', '22', '22103', '4213107', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '由比阿僧', 'ユイアソウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区由比今宿', '22', '22103', '4213111', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '由比今宿', 'ユイイマジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区由比寺尾', '22', '22103', '4213112', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '由比寺尾', 'ユイテラオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区由比東倉澤', '22', '22103', '4213114', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '由比東倉澤', 'ユイヒガシクラサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区由比西倉澤', '22', '22103', '4213115', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '由比西倉澤', 'ユイニシクラサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区蒲原東', '22', '22103', '4213201', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '蒲原東', 'カンバラヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区蒲原新栄', '22', '22103', '4213202', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '蒲原新栄', 'カンバラシンエイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区蒲原', '22', '22103', '4213203', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '蒲原', 'カンバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区蒲原新田', '22', '22103', '4213211', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '蒲原新田', 'カンバラシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区蒲原小金', '22', '22103', '4213212', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '蒲原小金', 'カンバラコガネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区蒲原中', '22', '22103', '4213213', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '蒲原中', 'カンバラナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区蒲原堰沢', '22', '22103', '4213214', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '蒲原堰沢', 'カンバラセギザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区蒲原神沢', '22', '22103', '4213215', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '蒲原神沢', 'カンバラカンザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市北松野', '22', '22210', '4213301', '静岡県', 'シズオカケン', '富士市', 'フジシ', '北松野', 'キタマツノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市中野台', '22', '22210', '4213302', '静岡県', 'シズオカケン', '富士市', 'フジシ', '中野台', 'ナカノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市南松野', '22', '22210', '4213303', '静岡県', 'シズオカケン', '富士市', 'フジシ', '南松野', 'ミナミマツノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市木島', '22', '22210', '4213304', '静岡県', 'シズオカケン', '富士市', 'フジシ', '木島', 'キジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市岩渕', '22', '22210', '4213305', '静岡県', 'シズオカケン', '富士市', 'フジシ', '岩渕', 'イワブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県富士市中之郷', '22', '22210', '4213306', '静岡県', 'シズオカケン', '富士市', 'フジシ', '中之郷', 'ナカノゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区', '22', '22101', '4220000', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('38830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市駿河区', '22', '22102', '4220000', '静岡県', 'シズオカケン', '静岡市駿河区', 'シズオカシスルガク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('38831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区', '22', '22103', '4220000', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('38832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市駿河区中吉田', '22', '22102', '4228001', '静岡県', 'シズオカケン', '静岡市駿河区', 'シズオカシスルガク', '中吉田', 'ナカヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市駿河区谷田', '22', '22102', '4228002', '静岡県', 'シズオカケン', '静岡市駿河区', 'シズオカシスルガク', '谷田', 'ヤダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市駿河区平沢', '22', '22102', '4228003', '静岡県', 'シズオカケン', '静岡市駿河区', 'シズオカシスルガク', '平沢', 'ヒラサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市駿河区国吉田', '22', '22102', '4228004', '静岡県', 'シズオカケン', '静岡市駿河区', 'シズオカシスルガク', '国吉田', 'クニヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市駿河区池田', '22', '22102', '4228005', '静岡県', 'シズオカケン', '静岡市駿河区', 'シズオカシスルガク', '池田', 'イケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市駿河区曲金', '22', '22102', '4228006', '静岡県', 'シズオカケン', '静岡市駿河区', 'シズオカシスルガク', '曲金', 'マガリカネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市駿河区聖一色', '22', '22102', '4228007', '静岡県', 'シズオカケン', '静岡市駿河区', 'シズオカシスルガク', '聖一色', 'ヒジリイッシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市駿河区栗原', '22', '22102', '4228008', '静岡県', 'シズオカケン', '静岡市駿河区', 'シズオカシスルガク', '栗原', 'クリハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市駿河区弥生町', '22', '22102', '4228009', '静岡県', 'シズオカケン', '静岡市駿河区', 'シズオカシスルガク', '弥生町', 'ヤヨイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市駿河区根古屋', '22', '22102', '4228011', '静岡県', 'シズオカケン', '静岡市駿河区', 'シズオカシスルガク', '根古屋', 'ネゴヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市駿河区安居', '22', '22102', '4228012', '静岡県', 'シズオカケン', '静岡市駿河区', 'シズオカシスルガク', '安居', 'アゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市駿河区古宿', '22', '22102', '4228013', '静岡県', 'シズオカケン', '静岡市駿河区', 'シズオカシスルガク', '古宿', 'フルヤド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市駿河区青沢', '22', '22102', '4228014', '静岡県', 'シズオカケン', '静岡市駿河区', 'シズオカシスルガク', '青沢', 'アオサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市駿河区中平松', '22', '22102', '4228015', '静岡県', 'シズオカケン', '静岡市駿河区', 'シズオカシスルガク', '中平松', 'ナカヒラマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市駿河区西平松', '22', '22102', '4228016', '静岡県', 'シズオカケン', '静岡市駿河区', 'シズオカシスルガク', '西平松', 'ニシヒラマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市駿河区大谷', '22', '22102', '4228017', '静岡県', 'シズオカケン', '静岡市駿河区', 'シズオカシスルガク', '大谷', 'オオヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市駿河区西大谷', '22', '22102', '4228018', '静岡県', 'シズオカケン', '静岡市駿河区', 'シズオカシスルガク', '西大谷', 'ニシオオヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市駿河区小鹿', '22', '22102', '4228021', '静岡県', 'シズオカケン', '静岡市駿河区', 'シズオカシスルガク', '小鹿', 'オシカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市駿河区恩田原', '22', '22102', '4228022', '静岡県', 'シズオカケン', '静岡市駿河区', 'シズオカシスルガク', '恩田原', 'オンダバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市駿河区片山', '22', '22102', '4228023', '静岡県', 'シズオカケン', '静岡市駿河区', 'シズオカシスルガク', '片山', 'カタヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市駿河区宮川', '22', '22102', '4228024', '静岡県', 'シズオカケン', '静岡市駿河区', 'シズオカシスルガク', '宮川', 'ミヤガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市駿河区水上', '22', '22102', '4228025', '静岡県', 'シズオカケン', '静岡市駿河区', 'シズオカシスルガク', '水上', 'ミズカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市駿河区富士見台', '22', '22102', '4228026', '静岡県', 'シズオカケン', '静岡市駿河区', 'シズオカシスルガク', '富士見台', 'フジミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市駿河区豊田', '22', '22102', '4228027', '静岡県', 'シズオカケン', '静岡市駿河区', 'シズオカシスルガク', '豊田', 'トヨダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市駿河区有明町', '22', '22102', '4228031', '静岡県', 'シズオカケン', '静岡市駿河区', 'シズオカシスルガク', '有明町', 'アリアケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市駿河区有東', '22', '22102', '4228032', '静岡県', 'シズオカケン', '静岡市駿河区', 'シズオカシスルガク', '有東', 'ウトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市駿河区登呂', '22', '22102', '4228033', '静岡県', 'シズオカケン', '静岡市駿河区', 'シズオカシスルガク', '登呂', 'トロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市駿河区高松', '22', '22102', '4228034', '静岡県', 'シズオカケン', '静岡市駿河区', 'シズオカシスルガク', '高松', 'タカマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市駿河区宮竹', '22', '22102', '4228035', '静岡県', 'シズオカケン', '静岡市駿河区', 'シズオカシスルガク', '宮竹', 'ミヤタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市駿河区敷地', '22', '22102', '4228036', '静岡県', 'シズオカケン', '静岡市駿河区', 'シズオカシスルガク', '敷地', 'シキジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市駿河区下島', '22', '22102', '4228037', '静岡県', 'シズオカケン', '静岡市駿河区', 'シズオカシスルガク', '下島', 'シモジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市駿河区中田', '22', '22102', '4228041', '静岡県', 'シズオカケン', '静岡市駿河区', 'シズオカシスルガク', '中田', 'ナカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市駿河区石田', '22', '22102', '4228042', '静岡県', 'シズオカケン', '静岡市駿河区', 'シズオカシスルガク', '石田', 'イシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市駿河区中田本町', '22', '22102', '4228043', '静岡県', 'シズオカケン', '静岡市駿河区', 'シズオカシスルガク', '中田本町', 'ナカダホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市駿河区西脇', '22', '22102', '4228044', '静岡県', 'シズオカケン', '静岡市駿河区', 'シズオカシスルガク', '西脇', 'ニシワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市駿河区西島', '22', '22102', '4228045', '静岡県', 'シズオカケン', '静岡市駿河区', 'シズオカシスルガク', '西島', 'ニシジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市駿河区中島', '22', '22102', '4228046', '静岡県', 'シズオカケン', '静岡市駿河区', 'シズオカシスルガク', '中島', 'ナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市駿河区中村町', '22', '22102', '4228047', '静岡県', 'シズオカケン', '静岡市駿河区', 'シズオカシスルガク', '中村町', 'ナカムラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市駿河区中野新田', '22', '22102', '4228051', '静岡県', 'シズオカケン', '静岡市駿河区', 'シズオカシスルガク', '中野新田', 'ナカノシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市駿河区緑が丘町', '22', '22102', '4228052', '静岡県', 'シズオカケン', '静岡市駿河区', 'シズオカシスルガク', '緑が丘町', 'ミドリガオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市駿河区西中原', '22', '22102', '4228053', '静岡県', 'シズオカケン', '静岡市駿河区', 'シズオカシスルガク', '西中原', 'ニシナカハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市駿河区南安倍3丁目', '22', '22102', '4228054', '静岡県', 'シズオカケン', '静岡市駿河区', 'シズオカシスルガク', '南安倍', 'ミナミアベ', null, null, '3丁目', '03チョウメ');
INSERT INTO `ms_addresses` VALUES ('38874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市駿河区寿町', '22', '22102', '4228055', '静岡県', 'シズオカケン', '静岡市駿河区', 'シズオカシスルガク', '寿町', 'コトブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市駿河区津島町', '22', '22102', '4228056', '静岡県', 'シズオカケン', '静岡市駿河区', 'シズオカシスルガク', '津島町', 'ツシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市駿河区見瀬', '22', '22102', '4228057', '静岡県', 'シズオカケン', '静岡市駿河区', 'シズオカシスルガク', '見瀬', 'ミセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市駿河区中原', '22', '22102', '4228058', '静岡県', 'シズオカケン', '静岡市駿河区', 'シズオカシスルガク', '中原', 'ナカハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市駿河区森下町', '22', '22102', '4228061', '静岡県', 'シズオカケン', '静岡市駿河区', 'シズオカシスルガク', '森下町', 'モリシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市駿河区稲川', '22', '22102', '4228062', '静岡県', 'シズオカケン', '静岡市駿河区', 'シズオカシスルガク', '稲川', 'イナガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市駿河区馬渕', '22', '22102', '4228063', '静岡県', 'シズオカケン', '静岡市駿河区', 'シズオカシスルガク', '馬渕', 'マブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市駿河区新川', '22', '22102', '4228064', '静岡県', 'シズオカケン', '静岡市駿河区', 'シズオカシスルガク', '新川', 'シンカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市駿河区宮本町', '22', '22102', '4228065', '静岡県', 'シズオカケン', '静岡市駿河区', 'シズオカシスルガク', '宮本町', 'ミヤモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市駿河区泉町', '22', '22102', '4228066', '静岡県', 'シズオカケン', '静岡市駿河区', 'シズオカシスルガク', '泉町', 'イズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市駿河区南町', '22', '22102', '4228067', '静岡県', 'シズオカケン', '静岡市駿河区', 'シズオカシスルガク', '南町', 'ミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市駿河区豊原町', '22', '22102', '4228071', '静岡県', 'シズオカケン', '静岡市駿河区', 'シズオカシスルガク', '豊原町', 'トヨハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市駿河区小黒', '22', '22102', '4228072', '静岡県', 'シズオカケン', '静岡市駿河区', 'シズオカシスルガク', '小黒', 'オグロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市駿河区八幡山', '22', '22102', '4228073', '静岡県', 'シズオカケン', '静岡市駿河区', 'シズオカシスルガク', '八幡山', 'ヤハタヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市駿河区南八幡町', '22', '22102', '4228074', '静岡県', 'シズオカケン', '静岡市駿河区', 'シズオカシスルガク', '南八幡町', 'ミナミヤハタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市駿河区大坪町', '22', '22102', '4228075', '静岡県', 'シズオカケン', '静岡市駿河区', 'シズオカシスルガク', '大坪町', 'オオツボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市駿河区八幡', '22', '22102', '4228076', '静岡県', 'シズオカケン', '静岡市駿河区', 'シズオカシスルガク', '八幡', 'ヤハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市駿河区大和', '22', '22102', '4228077', '静岡県', 'シズオカケン', '静岡市駿河区', 'シズオカシスルガク', '大和', 'ヤマト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市駿河区さつき町', '22', '22102', '4228078', '静岡県', 'シズオカケン', '静岡市駿河区', 'シズオカシスルガク', 'さつき町', 'サツキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区梅ケ谷', '22', '22103', '4240001', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '梅ケ谷', 'ウメガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区山原', '22', '22103', '4240002', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '山原', 'ヤンバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区蜂ケ谷', '22', '22103', '4240003', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '蜂ケ谷', 'ハチガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区蜂ケ谷南町', '22', '22103', '4240004', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '蜂ケ谷南町', 'ハチガヤミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区石川', '22', '22103', '4240005', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '石川', 'イシカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区石川本町', '22', '22103', '4240006', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '石川本町', 'イシカワホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区石川新町', '22', '22103', '4240007', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '石川新町', 'イシカワシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区押切', '22', '22103', '4240008', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '押切', 'オシキリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区柏尾', '22', '22103', '4240009', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '柏尾', 'カシオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区下野町', '22', '22103', '4240011', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '下野町', 'シモノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区下野西', '22', '22103', '4240012', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '下野西', 'シモノニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区下野緑町', '22', '22103', '4240013', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '下野緑町', 'シモノミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区天王南', '22', '22103', '4240014', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '天王南', 'テンノウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区天王町', '22', '22103', '4240015', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '天王町', 'テンノウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区天王西', '22', '22103', '4240016', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '天王西', 'テンノウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区天王東', '22', '22103', '4240017', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '天王東', 'テンノウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区弥生町', '22', '22103', '4240018', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '弥生町', 'ヤヨイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区下野北', '22', '22103', '4240021', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '下野北', 'シモノキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区八坂町', '22', '22103', '4240022', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '八坂町', 'ヤサカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区八坂北', '22', '22103', '4240023', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '八坂北', 'ヤサカキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区八坂東', '22', '22103', '4240024', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '八坂東', 'ヤサカヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区八坂西町', '22', '22103', '4240025', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '八坂西町', 'ヤサカニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区八坂南町', '22', '22103', '4240026', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '八坂南町', 'ヤサカミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区飯田町', '22', '22103', '4240027', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '飯田町', 'イイダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区下野東', '22', '22103', '4240028', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '下野東', 'シモノヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区下野中', '22', '22103', '4240029', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '下野中', 'シモノナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区横砂', '22', '22103', '4240031', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '横砂', 'ヨコスナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区横砂東町', '22', '22103', '4240032', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '横砂東町', 'ヨコスナヒガシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区横砂本町', '22', '22103', '4240033', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '横砂本町', 'ヨコスナホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区横砂中町', '22', '22103', '4240034', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '横砂中町', 'ヨコスナナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区横砂南町', '22', '22103', '4240035', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '横砂南町', 'ヨコスナミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区横砂西町', '22', '22103', '4240036', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '横砂西町', 'ヨコスナニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区袖師町', '22', '22103', '4240037', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '袖師町', 'ソデシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区西久保', '22', '22103', '4240038', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '西久保', 'ニシクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区高橋', '22', '22103', '4240041', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '高橋', 'タカハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区高橋南町', '22', '22103', '4240042', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '高橋南町', 'タカハシミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区永楽町', '22', '22103', '4240043', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '永楽町', 'エイラクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区江尻台町', '22', '22103', '4240044', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '江尻台町', 'エジリダイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区東大曲町', '22', '22103', '4240045', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '東大曲町', 'ヒガシオオマガリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('38999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区西大曲町', '22', '22103', '4240046', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '西大曲町', 'ニシオオマガリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区鶴舞町', '22', '22103', '4240047', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '鶴舞町', 'ツルマイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区高橋町', '22', '22103', '4240048', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '高橋町', 'タカハシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区北脇新田', '22', '22103', '4240051', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '北脇新田', 'キタワキシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区北脇', '22', '22103', '4240052', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '北脇', 'キタワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区渋川', '22', '22103', '4240053', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '渋川', 'シブカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区恵比寿町', '22', '22103', '4240054', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '恵比寿町', 'エビスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区吉川', '22', '22103', '4240055', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '吉川', 'キッカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区半左衛門新田', '22', '22103', '4240056', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '半左衛門新田', 'ハンザエモンシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区堀込', '22', '22103', '4240057', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '堀込', 'ホリゴメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区大内', '22', '22103', '4240061', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '大内', 'オオウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区大内新田', '22', '22103', '4240062', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '大内新田', 'オオウチシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区能島', '22', '22103', '4240063', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '能島', 'ノウジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区長崎新田', '22', '22103', '4240064', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '長崎新田', 'ナガサキシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区長崎', '22', '22103', '4240065', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '長崎', 'ナガサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区七ツ新屋', '22', '22103', '4240066', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '七ツ新屋', 'ナナツシンヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区鳥坂', '22', '22103', '4240067', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '鳥坂', 'トリサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区長崎南町', '22', '22103', '4240068', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '長崎南町', 'ナガサキミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区茂畑', '22', '22103', '4240101', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '茂畑', 'モバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区広瀬', '22', '22103', '4240102', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '広瀬', 'ヒロセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区尾羽', '22', '22103', '4240103', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '尾羽', 'オバネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区草ケ谷', '22', '22103', '4240104', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '草ケ谷', 'クサガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区山切', '22', '22103', '4240105', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '山切', 'ヤマキリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区杉山', '22', '22103', '4240106', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '杉山', 'スギヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区吉原', '22', '22103', '4240111', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '吉原', 'ヨシワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区伊佐布', '22', '22103', '4240112', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '伊佐布', 'イサブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区原', '22', '22103', '4240113', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '原', 'ハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区庵原町', '22', '22103', '4240114', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '庵原町', 'イハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区承元寺町', '22', '22103', '4240201', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '承元寺町', 'ショウゲンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区興津井上町', '22', '22103', '4240202', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '興津井上町', 'オキツイノウエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区興津東町', '22', '22103', '4240203', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '興津東町', 'オキツアズマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区興津中町', '22', '22103', '4240204', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '興津中町', 'オキツナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区興津本町', '22', '22103', '4240205', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '興津本町', 'オキツホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区興津清見寺町', '22', '22103', '4240206', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '興津清見寺町', 'オキツセイケンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区谷津町', '22', '22103', '4240211', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '谷津町', 'ヤツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区八木間町', '22', '22103', '4240212', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '八木間町', 'ヤギマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区宍原', '22', '22103', '4240301', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '宍原', 'シシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区小河内', '22', '22103', '4240302', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '小河内', 'コゴウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区但沼町', '22', '22103', '4240303', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '但沼町', 'タダヌマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区立花', '22', '22103', '4240304', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '立花', 'タチバナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区小島町', '22', '22103', '4240305', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '小島町', 'オジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区小島本町', '22', '22103', '4240306', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '小島本町', 'オジマホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区中河内', '22', '22103', '4240401', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '中河内', 'ナカゴウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区清地', '22', '22103', '4240402', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '清地', 'キヨジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区和田島', '22', '22103', '4240403', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '和田島', 'ワダシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区高山', '22', '22103', '4240404', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '高山', 'タカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区茂野島', '22', '22103', '4240405', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '茂野島', 'シゲノシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区葛沢', '22', '22103', '4240406', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '葛沢', 'トズラサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区大平', '22', '22103', '4240411', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '大平', 'オオヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区河内', '22', '22103', '4240412', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '河内', 'コウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区西里', '22', '22103', '4240413', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '西里', 'ニシザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区土', '22', '22103', '4240414', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '土', 'ド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区布沢', '22', '22103', '4240415', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '布沢', 'ヌノザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区秋吉町', '22', '22103', '4240801', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '秋吉町', 'アキヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区矢倉町', '22', '22103', '4240802', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '矢倉町', 'ヤグラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区宮下町', '22', '22103', '4240803', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '宮下町', 'ミヤシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区田町', '22', '22103', '4240804', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '田町', 'タマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区愛染町', '22', '22103', '4240805', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '愛染町', 'アイゾメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区辻', '22', '22103', '4240806', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '辻', 'ツジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区宮代町', '22', '22103', '4240807', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '宮代町', 'ミヤシロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区大手', '22', '22103', '4240808', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '大手', 'オオテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区天神', '22', '22103', '4240809', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '天神', 'テンジン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区二の丸町', '22', '22103', '4240811', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '二の丸町', 'ニノマルチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区小芝町', '22', '22103', '4240812', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '小芝町', 'オシバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区宝町', '22', '22103', '4240813', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '宝町', 'タカラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区本郷町', '22', '22103', '4240814', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '本郷町', 'ホンゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区江尻東', '22', '22103', '4240815', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '江尻東', 'エジリヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区真砂町', '22', '22103', '4240816', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '真砂町', 'マサゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区銀座', '22', '22103', '4240817', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '銀座', 'ギンザ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区江尻町', '22', '22103', '4240818', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '江尻町', 'エジリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区元城町', '22', '22103', '4240819', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '元城町', 'モトシロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区相生町', '22', '22103', '4240821', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '相生町', 'アイオイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区旭町', '22', '22103', '4240822', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '旭町', 'アサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区島崎町', '22', '22103', '4240823', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '島崎町', 'シマザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区新港町', '22', '22103', '4240824', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '新港町', 'シンミナトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区松原町', '22', '22103', '4240825', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '松原町', 'マツバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区万世町', '22', '22103', '4240826', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '万世町', 'マンセイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区上', '22', '22103', '4240827', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '上', 'カミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区千歳町', '22', '22103', '4240828', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '千歳町', 'チトセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区巴町', '22', '22103', '4240829', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '巴町', 'トモエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区入江', '22', '22103', '4240831', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '入江', 'イリエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区入江南町', '22', '22103', '4240832', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '入江南町', 'イリエミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区新富町', '22', '22103', '4240833', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '新富町', 'シントミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区浜田町', '22', '22103', '4240834', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '浜田町', 'ハマダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区上清水町', '22', '22103', '4240835', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '上清水町', 'カミシミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区桜が丘町', '22', '22103', '4240836', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '桜が丘町', 'サクラガオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区桜橋町', '22', '22103', '4240837', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '桜橋町', 'サクラバシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区淡島町', '22', '22103', '4240838', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '淡島町', 'アワシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区入江岡町', '22', '22103', '4240839', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '入江岡町', 'イリエオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区追分', '22', '22103', '4240841', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '追分', 'オイワケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区春日', '22', '22103', '4240842', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '春日', 'カスガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区青葉町', '22', '22103', '4240843', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '青葉町', 'アオバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区西高町', '22', '22103', '4240844', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '西高町', 'ニシタカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区船原', '22', '22103', '4240845', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '船原', 'フナバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区木の下町', '22', '22103', '4240846', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '木の下町', 'キノシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区大坪', '22', '22103', '4240847', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '大坪', 'オオツボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区堂林', '22', '22103', '4240851', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '堂林', 'ドウバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区神田町', '22', '22103', '4240852', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '神田町', 'カンダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区月見町', '22', '22103', '4240853', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '月見町', 'ツキミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区中矢部町', '22', '22103', '4240854', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '中矢部町', 'ナカヤベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区庄福町', '22', '22103', '4240855', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '庄福町', 'ショウフクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区上力町', '22', '22103', '4240856', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '上力町', 'ジョウリキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区川原町', '22', '22103', '4240857', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '川原町', 'カワハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区大沢町', '22', '22103', '4240858', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '大沢町', 'オオサワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区船越町', '22', '22103', '4240861', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '船越町', 'フナコシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区船越東町', '22', '22103', '4240862', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '船越東町', 'フナコシヒガシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区船越南町', '22', '22103', '4240863', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '船越南町', 'フナコシミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区南矢部', '22', '22103', '4240864', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '南矢部', 'ミナミヤベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区北矢部', '22', '22103', '4240865', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '北矢部', 'キタヤベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区船越', '22', '22103', '4240866', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '船越', 'フナコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区上原', '22', '22103', '4240871', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '上原', 'ウワハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区平川地', '22', '22103', '4240872', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '平川地', 'ヒラカワジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区有東坂', '22', '22103', '4240873', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '有東坂', 'ウトウザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区今泉', '22', '22103', '4240874', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '今泉', 'イマイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区馬走', '22', '22103', '4240875', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '馬走', 'マバセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区馬走北', '22', '22103', '4240876', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '馬走北', 'マバセキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区馬走坂の上', '22', '22103', '4240877', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '馬走坂の上', 'マバセサカノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区御門台', '22', '22103', '4240878', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '御門台', 'ミカドダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区有度本町', '22', '22103', '4240879', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '有度本町', 'ウドホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区楠', '22', '22103', '4240881', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '楠', 'クスノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区楠新田', '22', '22103', '4240882', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '楠新田', 'クスノキシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区草薙北', '22', '22103', '4240883', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '草薙北', 'クサナギキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区草薙一里山', '22', '22103', '4240884', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '草薙一里山', 'クサナギイチリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区草薙杉道', '22', '22103', '4240885', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '草薙杉道', 'クサナギスギミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区草薙', '22', '22103', '4240886', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '草薙', 'クサナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区谷田', '22', '22103', '4240887', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '谷田', 'ヤダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区中之郷', '22', '22103', '4240888', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '中之郷', 'ナカノゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区三保', '22', '22103', '4240901', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '三保', 'ミホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区折戸', '22', '22103', '4240902', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '折戸', 'オリド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区駒越南町', '22', '22103', '4240903', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '駒越南町', 'コマゴエミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区駒越中', '22', '22103', '4240904', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '駒越中', 'コマゴエナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区駒越西', '22', '22103', '4240905', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '駒越西', 'コマゴエニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区駒越北町', '22', '22103', '4240906', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '駒越北町', 'コマゴエキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区駒越東町', '22', '22103', '4240907', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '駒越東町', 'コマゴエヒガシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区宮加三', '22', '22103', '4240911', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '宮加三', 'ミヤカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区殿沢', '22', '22103', '4240912', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '殿沢', 'トノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区迎山町', '22', '22103', '4240913', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '迎山町', 'ムカエヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区港南町', '22', '22103', '4240914', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '港南町', 'コウナンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区増', '22', '22103', '4240915', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '増', 'ゾウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区蛇塚', '22', '22103', '4240916', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '蛇塚', 'ヘビツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区駒越', '22', '22103', '4240917', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '駒越', 'コマゴエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区松井町', '22', '22103', '4240921', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '松井町', 'マツイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区日の出町', '22', '22103', '4240922', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '日の出町', 'ヒノデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区幸町', '22', '22103', '4240923', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区清開', '22', '22103', '4240924', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '清開', 'セイカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区清水村松地先新田', '22', '22103', '4240925', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '清水村松地先新田', 'シミズムラマツチサキシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区村松', '22', '22103', '4240926', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '村松', 'ムラマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区新緑町', '22', '22103', '4240927', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '新緑町', 'シンミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区緑が丘町', '22', '22103', '4240928', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '緑が丘町', 'ミドリガオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区日立町', '22', '22103', '4240929', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '日立町', 'ヒタチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区岡町', '22', '22103', '4240931', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '岡町', 'オカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区南岡町', '22', '22103', '4240932', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '南岡町', 'ミナミオカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区三光町', '22', '22103', '4240933', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '三光町', 'サンコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区村松原', '22', '22103', '4240934', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '村松原', 'ムラマツハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区沼田町', '22', '22103', '4240935', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '沼田町', 'ヌマタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区向田町', '22', '22103', '4240936', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '向田町', 'ムカイダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区北矢部町', '22', '22103', '4240937', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '北矢部町', 'キタヤベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区梅が岡', '22', '22103', '4240938', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '梅が岡', 'ウメガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区下清水町', '22', '22103', '4240939', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '下清水町', 'シモシミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区富士見町', '22', '22103', '4240941', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '富士見町', 'フジミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区入船町', '22', '22103', '4240942', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '入船町', 'イリフネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区港町', '22', '22103', '4240943', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '港町', 'ミナトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区築地町', '22', '22103', '4240944', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '築地町', 'ツキジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区美濃輪町', '22', '22103', '4240945', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '美濃輪町', 'ミノワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区八千代町', '22', '22103', '4240946', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '八千代町', 'ヤチヨチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区清水町', '22', '22103', '4240947', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '清水町', 'シミズマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区梅田町', '22', '22103', '4240948', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '梅田町', 'ウメダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市清水区本町', '22', '22103', '4240949', '静岡県', 'シズオカケン', '静岡市清水区', 'シズオカシシミズク', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県焼津市', '22', '22212', '4250000', '静岡県', 'シズオカケン', '焼津市', 'ヤイヅシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('39216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県焼津市花沢', '22', '22212', '4250001', '静岡県', 'シズオカケン', '焼津市', 'ヤイヅシ', '花沢', 'ハナザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県焼津市吉津', '22', '22212', '4250002', '静岡県', 'シズオカケン', '焼津市', 'ヤイヅシ', '吉津', 'ヨシヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県焼津市高崎', '22', '22212', '4250003', '静岡県', 'シズオカケン', '焼津市', 'ヤイヅシ', '高崎', 'タカサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県焼津市坂本', '22', '22212', '4250004', '静岡県', 'シズオカケン', '焼津市', 'ヤイヅシ', '坂本', 'サカモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県焼津市方ノ上', '22', '22212', '4250005', '静岡県', 'シズオカケン', '焼津市', 'ヤイヅシ', '方ノ上', 'カタノカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県焼津市関方', '22', '22212', '4250006', '静岡県', 'シズオカケン', '焼津市', 'ヤイヅシ', '関方', 'セキガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県焼津市策牛', '22', '22212', '4250007', '静岡県', 'シズオカケン', '焼津市', 'ヤイヅシ', '策牛', 'ムチウシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県焼津市小浜', '22', '22212', '4250011', '静岡県', 'シズオカケン', '焼津市', 'ヤイヅシ', '小浜', 'オバマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県焼津市浜当目', '22', '22212', '4250012', '静岡県', 'シズオカケン', '焼津市', 'ヤイヅシ', '浜当目', 'ハマトウメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県焼津市岡当目', '22', '22212', '4250013', '静岡県', 'シズオカケン', '焼津市', 'ヤイヅシ', '岡当目', 'オカトウメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県焼津市中里', '22', '22212', '4250014', '静岡県', 'シズオカケン', '焼津市', 'ヤイヅシ', '中里', 'ナカザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県焼津市石脇上', '22', '22212', '4250015', '静岡県', 'シズオカケン', '焼津市', 'ヤイヅシ', '石脇上', 'イシワキカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県焼津市石脇下', '22', '22212', '4250016', '静岡県', 'シズオカケン', '焼津市', 'ヤイヅシ', '石脇下', 'イシワキシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県焼津市野秋', '22', '22212', '4250017', '静岡県', 'シズオカケン', '焼津市', 'ヤイヅシ', '野秋', 'ノアキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県焼津市中港', '22', '22212', '4250021', '静岡県', 'シズオカケン', '焼津市', 'ヤイヅシ', '中港', 'ナカミナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県焼津市本町', '22', '22212', '4250022', '静岡県', 'シズオカケン', '焼津市', 'ヤイヅシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県焼津市新屋', '22', '22212', '4250023', '静岡県', 'シズオカケン', '焼津市', 'ヤイヅシ', '新屋', 'アラヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県焼津市北浜通', '22', '22212', '4250024', '静岡県', 'シズオカケン', '焼津市', 'ヤイヅシ', '北浜通', 'キタハマドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県焼津市城之腰', '22', '22212', '4250025', '静岡県', 'シズオカケン', '焼津市', 'ヤイヅシ', '城之腰', 'ジョウノコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県焼津市焼津', '22', '22212', '4250026', '静岡県', 'シズオカケン', '焼津市', 'ヤイヅシ', '焼津', 'ヤイヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県焼津市栄町', '22', '22212', '4250027', '静岡県', 'シズオカケン', '焼津市', 'ヤイヅシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県焼津市駅北', '22', '22212', '4250028', '静岡県', 'シズオカケン', '焼津市', 'ヤイヅシ', '駅北', 'エキキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県焼津市小川新町', '22', '22212', '4250031', '静岡県', 'シズオカケン', '焼津市', 'ヤイヅシ', '小川新町', 'コガワシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県焼津市鰯ケ島', '22', '22212', '4250032', '静岡県', 'シズオカケン', '焼津市', 'ヤイヅシ', '鰯ケ島', 'イワシガシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県焼津市小川', '22', '22212', '4250033', '静岡県', 'シズオカケン', '焼津市', 'ヤイヅシ', '小川', 'コガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県焼津市与惣次', '22', '22212', '4250034', '静岡県', 'シズオカケン', '焼津市', 'ヤイヅシ', '与惣次', 'ヨソウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県焼津市東小川', '22', '22212', '4250035', '静岡県', 'シズオカケン', '焼津市', 'ヤイヅシ', '東小川', 'ヒガシコガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県焼津市西小川', '22', '22212', '4250036', '静岡県', 'シズオカケン', '焼津市', 'ヤイヅシ', '西小川', 'ニシコガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県焼津市石津', '22', '22212', '4250041', '静岡県', 'シズオカケン', '焼津市', 'ヤイヅシ', '石津', 'イシヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県焼津市石津港町', '22', '22212', '4250042', '静岡県', 'シズオカケン', '焼津市', 'ヤイヅシ', '石津港町', 'イシヅミナトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県焼津市石津中町', '22', '22212', '4250043', '静岡県', 'シズオカケン', '焼津市', 'ヤイヅシ', '石津中町', 'イシヅナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県焼津市石津向町', '22', '22212', '4250044', '静岡県', 'シズオカケン', '焼津市', 'ヤイヅシ', '石津向町', 'イシヅムカイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県焼津市祢宜島', '22', '22212', '4250045', '静岡県', 'シズオカケン', '焼津市', 'ヤイヅシ', '祢宜島', 'ネギシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県焼津市三右衛門新田', '22', '22212', '4250046', '静岡県', 'シズオカケン', '焼津市', 'ヤイヅシ', '三右衛門新田', 'サンウエモンシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県焼津市田尻北', '22', '22212', '4250051', '静岡県', 'シズオカケン', '焼津市', 'ヤイヅシ', '田尻北', 'タジリキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県焼津市田尻', '22', '22212', '4250052', '静岡県', 'シズオカケン', '焼津市', 'ヤイヅシ', '田尻', 'タジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県焼津市すみれ台', '22', '22212', '4250053', '静岡県', 'シズオカケン', '焼津市', 'ヤイヅシ', 'すみれ台', 'スミレダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県焼津市一色', '22', '22212', '4250054', '静岡県', 'シズオカケン', '焼津市', 'ヤイヅシ', '一色', 'イッシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県焼津市道原', '22', '22212', '4250055', '静岡県', 'シズオカケン', '焼津市', 'ヤイヅシ', '道原', 'ドウバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県焼津市下小田中町', '22', '22212', '4250056', '静岡県', 'シズオカケン', '焼津市', 'ヤイヅシ', '下小田中町', 'シモオダナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県焼津市下小田', '22', '22212', '4250057', '静岡県', 'シズオカケン', '焼津市', 'ヤイヅシ', '下小田', 'シモオダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県焼津市北新田', '22', '22212', '4250058', '静岡県', 'シズオカケン', '焼津市', 'ヤイヅシ', '北新田', 'キタシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県焼津市中根', '22', '22212', '4250061', '静岡県', 'シズオカケン', '焼津市', 'ヤイヅシ', '中根', 'ナカネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県焼津市中根新田', '22', '22212', '4250062', '静岡県', 'シズオカケン', '焼津市', 'ヤイヅシ', '中根新田', 'ナカネシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県焼津市本中根', '22', '22212', '4250063', '静岡県', 'シズオカケン', '焼津市', 'ヤイヅシ', '本中根', 'ホンナカネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県焼津市三和', '22', '22212', '4250064', '静岡県', 'シズオカケン', '焼津市', 'ヤイヅシ', '三和', 'ミワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県焼津市惣右衛門', '22', '22212', '4250065', '静岡県', 'シズオカケン', '焼津市', 'ヤイヅシ', '惣右衛門', 'ソウウエモン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県焼津市大島', '22', '22212', '4250066', '静岡県', 'シズオカケン', '焼津市', 'ヤイヅシ', '大島', 'オオジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県焼津市治長請所', '22', '22212', '4250067', '静岡県', 'シズオカケン', '焼津市', 'ヤイヅシ', '治長請所', 'ジチョウウケショ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県焼津市中新田', '22', '22212', '4250068', '静岡県', 'シズオカケン', '焼津市', 'ヤイヅシ', '中新田', 'ナカシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県焼津市大島新田', '22', '22212', '4250069', '静岡県', 'シズオカケン', '焼津市', 'ヤイヅシ', '大島新田', 'オオシマシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県焼津市三ケ名', '22', '22212', '4250071', '静岡県', 'シズオカケン', '焼津市', 'ヤイヅシ', '三ケ名', 'サンガミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県焼津市大住', '22', '22212', '4250072', '静岡県', 'シズオカケン', '焼津市', 'ヤイヅシ', '大住', 'オオズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県焼津市小柳津', '22', '22212', '4250073', '静岡県', 'シズオカケン', '焼津市', 'ヤイヅシ', '小柳津', 'オヤイヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県焼津市柳新屋', '22', '22212', '4250074', '静岡県', 'シズオカケン', '焼津市', 'ヤイヅシ', '柳新屋', 'ヤナギアラヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県焼津市西焼津', '22', '22212', '4250075', '静岡県', 'シズオカケン', '焼津市', 'ヤイヅシ', '西焼津', 'ニシヤイヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県焼津市小屋敷', '22', '22212', '4250076', '静岡県', 'シズオカケン', '焼津市', 'ヤイヅシ', '小屋敷', 'コヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県焼津市五ケ堀之内', '22', '22212', '4250077', '静岡県', 'シズオカケン', '焼津市', 'ヤイヅシ', '五ケ堀之内', 'ゴカホリノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県焼津市大栄町', '22', '22212', '4250081', '静岡県', 'シズオカケン', '焼津市', 'ヤイヅシ', '大栄町', 'ダイエイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県焼津市大村', '22', '22212', '4250082', '静岡県', 'シズオカケン', '焼津市', 'ヤイヅシ', '大村', 'オオムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県焼津市大', '22', '22212', '4250083', '静岡県', 'シズオカケン', '焼津市', 'ヤイヅシ', '大', 'オオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県焼津市大村新田', '22', '22212', '4250084', '静岡県', 'シズオカケン', '焼津市', 'ヤイヅシ', '大村新田', 'オオムラシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県焼津市塩津', '22', '22212', '4250085', '静岡県', 'シズオカケン', '焼津市', 'ヤイヅシ', '塩津', 'シオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県焼津市小土', '22', '22212', '4250086', '静岡県', 'シズオカケン', '焼津市', 'ヤイヅシ', '小土', 'コヒジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県焼津市保福島', '22', '22212', '4250087', '静岡県', 'シズオカケン', '焼津市', 'ヤイヅシ', '保福島', 'ホフクジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県焼津市大覚寺', '22', '22212', '4250088', '静岡県', 'シズオカケン', '焼津市', 'ヤイヅシ', '大覚寺', 'ダイカクジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県焼津市八楠', '22', '22212', '4250091', '静岡県', 'シズオカケン', '焼津市', 'ヤイヅシ', '八楠', 'ヤグス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県焼津市越後島', '22', '22212', '4250092', '静岡県', 'シズオカケン', '焼津市', 'ヤイヅシ', '越後島', 'エチゴシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市', '22', '22214', '4260000', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('39303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市仮宿', '22', '22214', '4260001', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', '仮宿', 'カリヤド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市横内', '22', '22214', '4260002', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', '横内', 'ヨコウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市下当間', '22', '22214', '4260003', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', '下当間', 'シモドウマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市上当間', '22', '22214', '4260004', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', '上当間', 'カミドウマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市水守', '22', '22214', '4260005', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', '水守', 'ミズモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市藤岡', '22', '22214', '4260006', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', '藤岡', 'フジオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市潮', '22', '22214', '4260007', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', '潮', 'ウシオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市鬼島', '22', '22214', '4260008', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', '鬼島', 'オニジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市八幡', '22', '22214', '4260009', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', '八幡', 'ヤワタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市平島', '22', '22214', '4260011', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', '平島', 'ヒラシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市田中', '22', '22214', '4260012', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', '田中', 'タナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市立花', '22', '22214', '4260013', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', '立花', 'タチバナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市若王子', '22', '22214', '4260014', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', '若王子', 'ニャクオウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市五十海', '22', '22214', '4260015', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', '五十海', 'イカルミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市郡', '22', '22214', '4260016', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', '郡', 'コオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市大手', '22', '22214', '4260017', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', '大手', 'オオテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市本町', '22', '22214', '4260018', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市天王町', '22', '22214', '4260019', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', '天王町', 'テンノウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市城南', '22', '22214', '4260021', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', '城南', 'ジョウナン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市稲川', '22', '22214', '4260022', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', '稲川', 'イナガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市茶町', '22', '22214', '4260023', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', '茶町', 'チャマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市鬼岩寺', '22', '22214', '4260024', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', '鬼岩寺', 'キガンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市藤枝', '22', '22214', '4260025', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', '藤枝', 'フジエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市岡出山', '22', '22214', '4260026', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', '岡出山', 'オカデヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市緑町', '22', '22214', '4260027', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', '緑町', 'ミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市益津下', '22', '22214', '4260028', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', '益津下', 'マシヅシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市益津', '22', '22214', '4260029', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', '益津', 'マシヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市築地', '22', '22214', '4260031', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', '築地', 'ツイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市築地上', '22', '22214', '4260032', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', '築地上', 'ツイジカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市小石川町', '22', '22214', '4260033', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', '小石川町', 'コイシガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市駅前', '22', '22214', '4260034', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', '駅前', 'エキマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市下青島', '22', '22214', '4260035', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', '下青島', 'シモアオジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市上青島', '22', '22214', '4260036', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', '上青島', 'カミアオジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市青木', '22', '22214', '4260037', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', '青木', 'アオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市東町', '22', '22214', '4260038', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', '東町', 'ヒガシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市高柳', '22', '22214', '4260041', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', '高柳', 'タカヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市兵太夫', '22', '22214', '4260042', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', '兵太夫', 'ヒョウダユウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市大新島', '22', '22214', '4260043', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', '大新島', 'タイシンジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市大東町', '22', '22214', '4260044', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', '大東町', 'ダイトウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市泉町', '22', '22214', '4260045', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', '泉町', 'イズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市高洲', '22', '22214', '4260046', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', '高洲', 'タカス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市与左衛門', '22', '22214', '4260047', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', '与左衛門', 'ヨザエモン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市大洲', '22', '22214', '4260051', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', '大洲', 'オオス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市弥左衛門', '22', '22214', '4260052', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', '弥左衛門', 'ヤザエモン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市善左衛門', '22', '22214', '4260053', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', '善左衛門', 'ゼンザエモン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市源助', '22', '22214', '4260054', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', '源助', 'ゲンスケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市大西町', '22', '22214', '4260055', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', '大西町', 'ダイセイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市五平', '22', '22214', '4260056', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', '五平', 'ゴヘイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市忠兵衛', '22', '22214', '4260057', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', '忠兵衛', 'チュウベエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市田沼', '22', '22214', '4260061', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', '田沼', 'タヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市高岡', '22', '22214', '4260062', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', '高岡', 'タカオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市青南町', '22', '22214', '4260063', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', '青南町', 'セイナンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市久兵衛市右衛門請新田', '22', '22214', '4260064', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', '久兵衛市右衛門請新田', 'キュウベエイチウエモンウケシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市末広', '22', '22214', '4260065', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', '末広', 'スエヒロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市青葉町', '22', '22214', '4260066', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', '青葉町', 'アオバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市前島', '22', '22214', '4260067', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', '前島', 'マエジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市緑の丘', '22', '22214', '4260070', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', '緑の丘', 'ミドリノオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市志太', '22', '22214', '4260071', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', '志太', 'シダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市南新屋', '22', '22214', '4260072', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', '南新屋', 'ミナミアラヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市新南新屋', '22', '22214', '4260073', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', '新南新屋', 'シンミナミアラヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市水上', '22', '22214', '4260074', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', '水上', 'ミズカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市瀬戸新屋', '22', '22214', '4260075', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', '瀬戸新屋', 'セトアラヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市内瀬戸', '22', '22214', '4260076', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', '内瀬戸', 'ウチセト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市駿河台', '22', '22214', '4260077', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', '駿河台', 'スルガダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市南駿河台', '22', '22214', '4260078', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', '南駿河台', 'ミナミスルガダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市光洋台', '22', '22214', '4260079', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', '光洋台', 'コウヨウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市旭が丘', '22', '22214', '4260081', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', '旭が丘', 'アサヒガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市瀬古', '22', '22214', '4260082', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', '瀬古', 'セコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市谷稲葉', '22', '22214', '4260083', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', '谷稲葉', 'ヤイナバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市寺島', '22', '22214', '4260084', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', '寺島', 'テラジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市助宗', '22', '22214', '4260085', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', '助宗', 'スケムネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市原', '22', '22214', '4260086', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', '原', 'ハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市音羽町', '22', '22214', '4260087', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', '音羽町', 'オトワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市堀之内', '22', '22214', '4260088', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', '堀之内', 'ホリノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市瀬戸ノ谷', '22', '22214', '4260131', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', '瀬戸ノ谷', 'セトノヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市本郷', '22', '22214', '4260132', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', '本郷', 'ホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市宮原', '22', '22214', '4260133', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', '宮原', 'ミヤバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市滝沢', '22', '22214', '4260134', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', '滝沢', 'タキサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市下藪田', '22', '22214', '4260201', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', '下藪田', 'シモヤブタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市上藪田', '22', '22214', '4260202', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', '上藪田', 'カミヤブタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市下之郷', '22', '22214', '4260203', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', '下之郷', 'シモノゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市時ケ谷', '22', '22214', '4260204', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', '時ケ谷', 'トキガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市花倉', '22', '22214', '4260205', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', '花倉', 'ハナグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市西方', '22', '22214', '4260211', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', '西方', 'ニシガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市北方', '22', '22214', '4260212', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', '北方', 'キタガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市中ノ合', '22', '22214', '4260213', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', '中ノ合', 'ナカノゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市高田', '22', '22214', '4260221', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', '高田', 'タカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市中藪田', '22', '22214', '4260222', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', '中藪田', 'ナカヤブタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市清里', '22', '22214', '4260223', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', '清里', 'キヨサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県藤枝市南清里', '22', '22214', '4260224', '静岡県', 'シズオカケン', '藤枝市', 'フジエダシ', '南清里', 'ミナミキヨサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市', '22', '22209', '4270000', '静岡県', 'シズオカケン', '島田市', 'シマダシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('39423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市千葉', '22', '22209', '4270001', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '千葉', 'チバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市大草', '22', '22209', '4270002', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '大草', 'オオクサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市東光寺', '22', '22209', '4270003', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '東光寺', 'トウコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市岸', '22', '22209', '4270004', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '岸', 'キシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市岸町', '22', '22209', '4270005', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '岸町', 'キシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市阿知ケ谷', '22', '22209', '4270006', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '阿知ケ谷', 'アチガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市野田', '22', '22209', '4270007', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '野田', 'ノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市落合', '22', '22209', '4270008', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '落合', 'オチアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市尾川', '22', '22209', '4270009', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '尾川', 'オガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市東町', '22', '22209', '4270011', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '東町', 'ヒガシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市細島', '22', '22209', '4270012', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '細島', 'ホソジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市御請', '22', '22209', '4270013', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '御請', 'オウケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市道悦島', '22', '22209', '4270014', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '道悦島', 'ドウエツジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市高島町', '22', '22209', '4270015', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '高島町', 'タカジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市宝来町', '22', '22209', '4270016', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '宝来町', 'ホウライチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市南', '22', '22209', '4270017', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '南', 'ミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市旭', '22', '22209', '4270018', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '旭', 'アサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市道悦', '22', '22209', '4270019', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '道悦', 'ドウエツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市柳町', '22', '22209', '4270021', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '柳町', 'ヤナギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市本通', '22', '22209', '4270022', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '本通', 'ホントオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市大川町', '22', '22209', '4270023', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '大川町', 'オオカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市横井', '22', '22209', '4270024', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '横井', 'ヨコイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市大井町', '22', '22209', '4270025', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '大井町', 'オオイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市扇町', '22', '22209', '4270026', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '扇町', 'オウギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市幸町', '22', '22209', '4270027', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '幸町', 'サイワイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市栄町', '22', '22209', '4270028', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '栄町', 'サカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市日之出町', '22', '22209', '4270029', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '日之出町', 'ヒノデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市鵜網', '22', '22209', '4270031', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '鵜網', 'ウアミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市神座', '22', '22209', '4270032', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '神座', 'カンザ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市相賀', '22', '22209', '4270033', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '相賀', 'オオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市伊太', '22', '22209', '4270034', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '伊太', 'イタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市向谷元町', '22', '22209', '4270035', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '向谷元町', 'ムクヤモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市三ツ合町', '22', '22209', '4270036', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '三ツ合町', 'ミツアイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市河原', '22', '22209', '4270037', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '河原', 'カワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市稲荷', '22', '22209', '4270038', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '稲荷', 'イナリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市向谷', '22', '22209', '4270039', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '向谷', 'ムクヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市中河町', '22', '22209', '4270041', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '中河町', 'ナカガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市中央町', '22', '22209', '4270042', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '中央町', 'チュウオウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市中溝', '22', '22209', '4270043', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '中溝', 'ナカミゾ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市宮川町', '22', '22209', '4270044', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '宮川町', 'ミヤガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市向島町', '22', '22209', '4270045', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '向島町', 'ムカイジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市若松町', '22', '22209', '4270046', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '若松町', 'ワカマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市中溝町', '22', '22209', '4270047', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '中溝町', 'ナカミゾチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市旗指', '22', '22209', '4270048', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '旗指', 'ハッサシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市元島田東町', '22', '22209', '4270051', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '元島田東町', 'モトシマダヒガシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市松葉町', '22', '22209', '4270052', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '松葉町', 'マツバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市御仮屋町', '22', '22209', '4270053', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '御仮屋町', 'オカリヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市高砂町', '22', '22209', '4270054', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '高砂町', 'タカサゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市新町通', '22', '22209', '4270055', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '新町通', 'シンマチドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市大津通', '22', '22209', '4270056', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '大津通', 'オオツドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市元島田', '22', '22209', '4270057', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '元島田', 'モトシマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市祇園町', '22', '22209', '4270058', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '祇園町', 'ギオンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市新田町', '22', '22209', '4270059', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '新田町', 'シンデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市ばらの丘', '22', '22209', '4270061', '静岡県', 'シズオカケン', '島田市', 'シマダシ', 'ばらの丘', 'バラノオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市大柳', '22', '22209', '4270101', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '大柳', 'オオヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市大柳南', '22', '22209', '4270102', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '大柳南', 'オオヤナギミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市中河', '22', '22209', '4270103', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '中河', 'ナカガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市井口', '22', '22209', '4270104', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '井口', 'イグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市南原', '22', '22209', '4270105', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '南原', 'ミナミハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市岡田', '22', '22209', '4270106', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '岡田', 'オカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市船木', '22', '22209', '4270107', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '船木', 'フナキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市牧之原', '22', '22209', '4270108', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '牧之原', 'マキノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市阪本', '22', '22209', '4270111', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '阪本', 'サカモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市月坂', '22', '22209', '4270112', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '月坂', 'ツキサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市湯日', '22', '22209', '4270113', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '湯日', 'ユイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市笹間下', '22', '22209', '4270231', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '笹間下', 'ササマシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市伊久美', '22', '22209', '4270232', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '伊久美', 'イクミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市身成', '22', '22209', '4270233', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '身成', 'ミナリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市高熊', '22', '22209', '4280001', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '高熊', 'タカクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市福用', '22', '22209', '4280002', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '福用', 'フクヨウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市神尾', '22', '22209', '4280003', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '神尾', 'カミオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市横岡', '22', '22209', '4280004', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '横岡', 'ヨコオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市横岡新田', '22', '22209', '4280005', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '横岡新田', 'ヨコオカシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市牛尾', '22', '22209', '4280006', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '牛尾', 'ウシオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市島', '22', '22209', '4280007', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '島', 'シマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市竹下', '22', '22209', '4280008', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '竹下', 'タケシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市大代', '22', '22209', '4280009', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '大代', 'オオジロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市番生寺', '22', '22209', '4280011', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '番生寺', 'バンショウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市代官町', '22', '22209', '4280012', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '代官町', 'ダイカンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市金谷東町', '22', '22209', '4280013', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '金谷東町', 'カナヤアズマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市泉町', '22', '22209', '4280014', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '泉町', 'イズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市金谷扇町', '22', '22209', '4280015', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '金谷扇町', 'カナヤオウギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市宮崎町', '22', '22209', '4280016', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '宮崎町', 'ミヤザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市金谷栄町', '22', '22209', '4280017', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '金谷栄町', 'カナヤサカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市根岸町', '22', '22209', '4280018', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '根岸町', 'ネギシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市志戸呂', '22', '22209', '4280019', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '志戸呂', 'シトロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市金谷河原', '22', '22209', '4280021', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '金谷河原', 'カナヤカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市金谷', '22', '22209', '4280022', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '金谷', 'カナヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市坂町', '22', '22209', '4280023', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '坂町', 'サカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市南町', '22', '22209', '4280024', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '南町', 'ミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市田町', '22', '22209', '4280025', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '田町', 'タマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市本町', '22', '22209', '4280026', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市上十五軒', '22', '22209', '4280027', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '上十五軒', 'カミジュウゴケン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市下十五軒', '22', '22209', '4280028', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '下十五軒', 'シモジュウゴケン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市横丁', '22', '22209', '4280029', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '横丁', 'ヨコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市清水', '22', '22209', '4280031', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '清水', 'シミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市天王町', '22', '22209', '4280032', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '天王町', 'テンノウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市二軒家', '22', '22209', '4280033', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '二軒家', 'ニケンヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市富士見町', '22', '22209', '4280034', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '富士見町', 'フジミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市切山', '22', '22209', '4280035', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '切山', 'キリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市神谷城', '22', '22209', '4280036', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '神谷城', 'カミヤシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市菊川', '22', '22209', '4280037', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '菊川', 'キクガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市佐夜鹿', '22', '22209', '4280038', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '佐夜鹿', 'サヨシカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市猪土居', '22', '22209', '4280039', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '猪土居', 'シシドイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市都町', '22', '22209', '4280041', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '都町', 'ミヤコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市古横町', '22', '22209', '4280042', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '古横町', 'フルヨコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市中町', '22', '22209', '4280043', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '中町', 'ナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市緑町', '22', '22209', '4280044', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '緑町', 'ミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市大和町', '22', '22209', '4280045', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '大和町', 'ヤマトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市金山町', '22', '22209', '4280046', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '金山町', 'キンザンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市新町', '22', '22209', '4280047', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市城山', '22', '22209', '4280048', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '城山', 'シロヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市牧之原', '22', '22209', '4280049', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '牧之原', 'マキノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市川根町笹間渡', '22', '22209', '4280101', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '川根町笹間渡', 'カワネチョウササマド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市川根町上河内', '22', '22209', '4280102', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '川根町上河内', 'カワネチョウカミゴウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市川根町身成', '22', '22209', '4280103', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '川根町身成', 'カワネチョウミナリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市川根町家山', '22', '22209', '4280104', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '川根町家山', 'カワネチョウイエヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市川根町葛籠', '22', '22209', '4280105', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '川根町葛籠', 'カワネチョウツヅラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市川根町抜里', '22', '22209', '4280106', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '川根町抜里', 'カワネチョウヌクリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市川根町笹間上', '22', '22209', '4280211', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '川根町笹間上', 'カワネチョウササマカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県島田市川根町笹間下', '22', '22209', '4280212', '静岡県', 'シズオカケン', '島田市', 'シマダシ', '川根町笹間下', 'カワネチョウササマシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県榛原郡川根本町', '22', '22429', '4280300', '静岡県', 'シズオカケン', '榛原郡川根本町', 'ハイバラグンカワネホンチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('39567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県榛原郡川根本町徳山', '22', '22429', '4280301', '静岡県', 'シズオカケン', '榛原郡川根本町', 'ハイバラグンカワネホンチョウ', '徳山', 'トクヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県榛原郡川根本町文沢', '22', '22429', '4280302', '静岡県', 'シズオカケン', '榛原郡川根本町', 'ハイバラグンカワネホンチョウ', '文沢', 'ブンザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県榛原郡川根本町壱町河内', '22', '22429', '4280303', '静岡県', 'シズオカケン', '榛原郡川根本町', 'ハイバラグンカワネホンチョウ', '壱町河内', 'イチョウゴウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県榛原郡川根本町下泉', '22', '22429', '4280304', '静岡県', 'シズオカケン', '榛原郡川根本町', 'ハイバラグンカワネホンチョウ', '下泉', 'シモイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県榛原郡川根本町地名', '22', '22429', '4280305', '静岡県', 'シズオカケン', '榛原郡川根本町', 'ハイバラグンカワネホンチョウ', '地名', 'ジナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県榛原郡川根本町田野口', '22', '22429', '4280306', '静岡県', 'シズオカケン', '榛原郡川根本町', 'ハイバラグンカワネホンチョウ', '田野口', 'タノクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県榛原郡川根本町元藤川', '22', '22429', '4280311', '静岡県', 'シズオカケン', '榛原郡川根本町', 'ハイバラグンカワネホンチョウ', '元藤川', 'モトフジカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県榛原郡川根本町水川', '22', '22429', '4280312', '静岡県', 'シズオカケン', '榛原郡川根本町', 'ハイバラグンカワネホンチョウ', '水川', 'ミズカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県榛原郡川根本町上長尾', '22', '22429', '4280313', '静岡県', 'シズオカケン', '榛原郡川根本町', 'ハイバラグンカワネホンチョウ', '上長尾', 'カミナガオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県榛原郡川根本町下長尾', '22', '22429', '4280314', '静岡県', 'シズオカケン', '榛原郡川根本町', 'ハイバラグンカワネホンチョウ', '下長尾', 'シモナガオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県榛原郡川根本町久野脇', '22', '22429', '4280315', '静岡県', 'シズオカケン', '榛原郡川根本町', 'ハイバラグンカワネホンチョウ', '久野脇', 'クノワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県榛原郡川根本町梅地', '22', '22429', '4280401', '静岡県', 'シズオカケン', '榛原郡川根本町', 'ハイバラグンカワネホンチョウ', '梅地', 'ウメジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県榛原郡川根本町犬間', '22', '22429', '4280402', '静岡県', 'シズオカケン', '榛原郡川根本町', 'ハイバラグンカワネホンチョウ', '犬間', 'イヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県榛原郡川根本町千頭', '22', '22429', '4280411', '静岡県', 'シズオカケン', '榛原郡川根本町', 'ハイバラグンカワネホンチョウ', '千頭', 'センズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県榛原郡川根本町奥泉', '22', '22429', '4280412', '静岡県', 'シズオカケン', '榛原郡川根本町', 'ハイバラグンカワネホンチョウ', '奥泉', 'オクイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県榛原郡川根本町桑野山', '22', '22429', '4280413', '静岡県', 'シズオカケン', '榛原郡川根本町', 'ハイバラグンカワネホンチョウ', '桑野山', 'クワノヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県榛原郡川根本町東藤川', '22', '22429', '4280414', '静岡県', 'シズオカケン', '榛原郡川根本町', 'ハイバラグンカワネホンチョウ', '東藤川', 'ヒガシフジカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県榛原郡川根本町上岸', '22', '22429', '4280415', '静岡県', 'シズオカケン', '榛原郡川根本町', 'ハイバラグンカワネホンチョウ', '上岸', 'カミキシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県榛原郡川根本町田代', '22', '22429', '4280416', '静岡県', 'シズオカケン', '榛原郡川根本町', 'ハイバラグンカワネホンチョウ', '田代', 'タシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県榛原郡川根本町青部', '22', '22429', '4280417', '静岡県', 'シズオカケン', '榛原郡川根本町', 'ハイバラグンカワネホンチョウ', '青部', 'アオベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県榛原郡川根本町崎平', '22', '22429', '4280418', '静岡県', 'シズオカケン', '榛原郡川根本町', 'ハイバラグンカワネホンチョウ', '崎平', 'サキダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区小河内', '22', '22101', '4280501', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '小河内', 'コゴウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区上坂本', '22', '22101', '4280502', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '上坂本', 'カミサカモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区岩崎', '22', '22101', '4280503', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '岩崎', 'イワサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区井川', '22', '22101', '4280504', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '井川', 'イカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県静岡市葵区田代', '22', '22101', '4280505', '静岡県', 'シズオカケン', '静岡市葵区', 'シズオカシアオイク', '田代', 'タシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道檜山郡江差町', '01', '01361', '0430000', '北海道', 'ホッカイドウ', '檜山郡江差町', 'ヒヤマグンエサシチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('39611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道檜山郡江差町五厘沢町', '01', '01361', '0430011', '北海道', 'ホッカイドウ', '檜山郡江差町', 'ヒヤマグンエサシチョウ', '五厘沢町', 'ゴリンザワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道檜山郡江差町鰔川町', '01', '01361', '0430012', '北海道', 'ホッカイドウ', '檜山郡江差町', 'ヒヤマグンエサシチョウ', '鰔川町', 'ウグイカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道檜山郡江差町朝日町', '01', '01361', '0430013', '北海道', 'ホッカイドウ', '檜山郡江差町', 'ヒヤマグンエサシチョウ', '朝日町', 'アサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道檜山郡江差町小黒部町', '01', '01361', '0430014', '北海道', 'ホッカイドウ', '檜山郡江差町', 'ヒヤマグンエサシチョウ', '小黒部町', 'オグロッペチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道檜山郡江差町中網町', '01', '01361', '0430015', '北海道', 'ホッカイドウ', '檜山郡江差町', 'ヒヤマグンエサシチョウ', '中網町', 'ナカアミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道檜山郡江差町越前町', '01', '01361', '0430016', '北海道', 'ホッカイドウ', '檜山郡江差町', 'ヒヤマグンエサシチョウ', '越前町', 'エチゼンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道檜山郡江差町水堀町', '01', '01361', '0430017', '北海道', 'ホッカイドウ', '檜山郡江差町', 'ヒヤマグンエサシチョウ', '水堀町', 'ミズホリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道檜山郡江差町柳崎町', '01', '01361', '0430021', '北海道', 'ホッカイドウ', '檜山郡江差町', 'ヒヤマグンエサシチョウ', '柳崎町', 'ヤナギザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道檜山郡江差町伏木戸町', '01', '01361', '0430022', '北海道', 'ホッカイドウ', '檜山郡江差町', 'ヒヤマグンエサシチョウ', '伏木戸町', 'フシキドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道檜山郡江差町田沢町', '01', '01361', '0430023', '北海道', 'ホッカイドウ', '檜山郡江差町', 'ヒヤマグンエサシチョウ', '田沢町', 'タザワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道檜山郡江差町尾山町', '01', '01361', '0430024', '北海道', 'ホッカイドウ', '檜山郡江差町', 'ヒヤマグンエサシチョウ', '尾山町', 'オヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道檜山郡江差町泊町', '01', '01361', '0430025', '北海道', 'ホッカイドウ', '檜山郡江差町', 'ヒヤマグンエサシチョウ', '泊町', 'トマリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道檜山郡江差町大澗町', '01', '01361', '0430026', '北海道', 'ホッカイドウ', '檜山郡江差町', 'ヒヤマグンエサシチョウ', '大澗町', 'オオマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道檜山郡江差町愛宕町', '01', '01361', '0430031', '北海道', 'ホッカイドウ', '檜山郡江差町', 'ヒヤマグンエサシチョウ', '愛宕町', 'アタゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道檜山郡江差町新栄町', '01', '01361', '0430032', '北海道', 'ホッカイドウ', '檜山郡江差町', 'ヒヤマグンエサシチョウ', '新栄町', 'シンエイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道檜山郡江差町豊川町', '01', '01361', '0430033', '北海道', 'ホッカイドウ', '檜山郡江差町', 'ヒヤマグンエサシチョウ', '豊川町', 'トヨカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道檜山郡江差町中歌町', '01', '01361', '0430034', '北海道', 'ホッカイドウ', '檜山郡江差町', 'ヒヤマグンエサシチョウ', '中歌町', 'ナカウタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道檜山郡江差町桧岱', '01', '01361', '0430035', '北海道', 'ホッカイドウ', '檜山郡江差町', 'ヒヤマグンエサシチョウ', '桧岱', 'ヒノキタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道檜山郡江差町東山', '01', '01361', '0430036', '北海道', 'ホッカイドウ', '檜山郡江差町', 'ヒヤマグンエサシチョウ', '東山', 'ヒガシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道檜山郡江差町姥神町', '01', '01361', '0430041', '北海道', 'ホッカイドウ', '檜山郡江差町', 'ヒヤマグンエサシチョウ', '姥神町', 'ウバガミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道檜山郡江差町上野町', '01', '01361', '0430042', '北海道', 'ホッカイドウ', '檜山郡江差町', 'ヒヤマグンエサシチョウ', '上野町', 'ウエノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道檜山郡江差町本町', '01', '01361', '0430043', '北海道', 'ホッカイドウ', '檜山郡江差町', 'ヒヤマグンエサシチョウ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道檜山郡江差町橋本町', '01', '01361', '0430044', '北海道', 'ホッカイドウ', '檜山郡江差町', 'ヒヤマグンエサシチョウ', '橋本町', 'ハシモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道檜山郡江差町鴎島', '01', '01361', '0430045', '北海道', 'ホッカイドウ', '檜山郡江差町', 'ヒヤマグンエサシチョウ', '鴎島', 'カモメジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道檜山郡江差町津花町', '01', '01361', '0430051', '北海道', 'ホッカイドウ', '檜山郡江差町', 'ヒヤマグンエサシチョウ', '津花町', 'ツバナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道檜山郡江差町茂尻町', '01', '01361', '0430052', '北海道', 'ホッカイドウ', '檜山郡江差町', 'ヒヤマグンエサシチョウ', '茂尻町', 'モシリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道檜山郡江差町新地町', '01', '01361', '0430053', '北海道', 'ホッカイドウ', '檜山郡江差町', 'ヒヤマグンエサシチョウ', '新地町', 'シンチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道檜山郡江差町緑丘', '01', '01361', '0430054', '北海道', 'ホッカイドウ', '檜山郡江差町', 'ヒヤマグンエサシチョウ', '緑丘', 'ミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道檜山郡江差町円山', '01', '01361', '0430055', '北海道', 'ホッカイドウ', '檜山郡江差町', 'ヒヤマグンエサシチョウ', '円山', 'マルヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道檜山郡江差町陣屋町', '01', '01361', '0430056', '北海道', 'ホッカイドウ', '檜山郡江差町', 'ヒヤマグンエサシチョウ', '陣屋町', 'ジンヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道檜山郡江差町海岸町', '01', '01361', '0430057', '北海道', 'ホッカイドウ', '檜山郡江差町', 'ヒヤマグンエサシチョウ', '海岸町', 'カイガンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道檜山郡江差町南が丘', '01', '01361', '0430061', '北海道', 'ホッカイドウ', '檜山郡江差町', 'ヒヤマグンエサシチョウ', '南が丘', 'ミナミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道檜山郡江差町萩の岱', '01', '01361', '0430062', '北海道', 'ホッカイドウ', '檜山郡江差町', 'ヒヤマグンエサシチョウ', '萩の岱', 'ハギノタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道檜山郡江差町南浜町', '01', '01361', '0430063', '北海道', 'ホッカイドウ', '檜山郡江差町', 'ヒヤマグンエサシチョウ', '南浜町', 'ミナミハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道檜山郡江差町柏町', '01', '01361', '0430064', '北海道', 'ホッカイドウ', '檜山郡江差町', 'ヒヤマグンエサシチョウ', '柏町', 'カシワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道檜山郡江差町砂川', '01', '01361', '0430065', '北海道', 'ホッカイドウ', '檜山郡江差町', 'ヒヤマグンエサシチョウ', '砂川', 'スナガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道檜山郡江差町とど川町', '01', '01361', '0430066', '北海道', 'ホッカイドウ', '檜山郡江差町', 'ヒヤマグンエサシチョウ', 'とど川町', 'トドガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市東区神立町', '22', '22132', '4300801', '静岡県', 'シズオカケン', '浜松市東区', 'ハママツシヒガシク', '神立町', 'コウダチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市東区将監町', '22', '22132', '4300802', '静岡県', 'シズオカケン', '浜松市東区', 'ハママツシヒガシク', '将監町', 'ショウゲンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市東区植松町', '22', '22132', '4300803', '静岡県', 'シズオカケン', '浜松市東区', 'ハママツシヒガシク', '植松町', 'ウエマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区富吉町', '22', '22131', '4300804', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '富吉町', 'トミヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区相生町', '22', '22131', '4300805', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '相生町', 'アイオイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区木戸町', '22', '22131', '4300806', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '木戸町', 'キドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区佐藤', '22', '22131', '4300807', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '佐藤', 'サトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区天神町', '22', '22131', '4300808', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '天神町', 'テンジンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区名塚町', '22', '22131', '4300811', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '名塚町', 'ナヅカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市南区本郷町', '22', '22134', '4300812', '静岡県', 'シズオカケン', '浜松市南区', 'ハママツシミナミク', '本郷町', 'ホンゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市南区芳川町', '22', '22134', '4300813', '静岡県', 'シズオカケン', '浜松市南区', 'ハママツシミナミク', '芳川町', 'ホウガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市南区恩地町', '22', '22134', '4300814', '静岡県', 'シズオカケン', '浜松市南区', 'ハママツシミナミク', '恩地町', 'オンヂチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市南区都盛町', '22', '22134', '4300815', '静岡県', 'シズオカケン', '浜松市南区', 'ハママツシミナミク', '都盛町', 'ツモリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市南区参野町', '22', '22134', '4300816', '静岡県', 'シズオカケン', '浜松市南区', 'ハママツシミナミク', '参野町', 'サンジノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市南区頭陀寺町', '22', '22134', '4300817', '静岡県', 'シズオカケン', '浜松市南区', 'ハママツシミナミク', '頭陀寺町', 'ズダジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市南区西町', '22', '22134', '4300821', '静岡県', 'シズオカケン', '浜松市南区', 'ハママツシミナミク', '西町', 'ニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市南区東町', '22', '22134', '4300822', '静岡県', 'シズオカケン', '浜松市南区', 'ハママツシミナミク', '東町', 'ヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市南区河輪町', '22', '22134', '4300823', '静岡県', 'シズオカケン', '浜松市南区', 'ハママツシミナミク', '河輪町', 'カワワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市南区富屋町', '22', '22134', '4300824', '静岡県', 'シズオカケン', '浜松市南区', 'ハママツシミナミク', '富屋町', 'トミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市南区下江町', '22', '22134', '4300825', '静岡県', 'シズオカケン', '浜松市南区', 'ハママツシミナミク', '下江町', 'シモエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市南区四本松町', '22', '22134', '4300826', '静岡県', 'シズオカケン', '浜松市南区', 'ハママツシミナミク', '四本松町', 'シホンマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市南区立野町', '22', '22134', '4300827', '静岡県', 'シズオカケン', '浜松市南区', 'ハママツシミナミク', '立野町', 'タテノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市南区御給町', '22', '22134', '4300831', '静岡県', 'シズオカケン', '浜松市南区', 'ハママツシミナミク', '御給町', 'ゴキュウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市南区長田町', '22', '22134', '4300832', '静岡県', 'シズオカケン', '浜松市南区', 'ハママツシミナミク', '長田町', 'ナガタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市南区三新町', '22', '22134', '4300833', '静岡県', 'シズオカケン', '浜松市南区', 'ハママツシミナミク', '三新町', 'サンシンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市南区松島町', '22', '22134', '4300834', '静岡県', 'シズオカケン', '浜松市南区', 'ハママツシミナミク', '松島町', 'マツシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市南区遠州浜', '22', '22134', '4300835', '静岡県', 'シズオカケン', '浜松市南区', 'ハママツシミナミク', '遠州浜', 'エンシュウハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市南区福島町', '22', '22134', '4300836', '静岡県', 'シズオカケン', '浜松市南区', 'ハママツシミナミク', '福島町', 'フクシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市南区西島町', '22', '22134', '4300837', '静岡県', 'シズオカケン', '浜松市南区', 'ハママツシミナミク', '西島町', 'ニシジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市南区鼡野町', '22', '22134', '4300838', '静岡県', 'シズオカケン', '浜松市南区', 'ハママツシミナミク', '鼡野町', 'ネズミノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市南区寺脇町', '22', '22134', '4300841', '静岡県', 'シズオカケン', '浜松市南区', 'ハママツシミナミク', '寺脇町', 'テラワキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市南区大柳町', '22', '22134', '4300842', '静岡県', 'シズオカケン', '浜松市南区', 'ハママツシミナミク', '大柳町', 'オオヤギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市南区福塚町', '22', '22134', '4300843', '静岡県', 'シズオカケン', '浜松市南区', 'ハママツシミナミク', '福塚町', 'フクヅカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市南区江之島町', '22', '22134', '4300844', '静岡県', 'シズオカケン', '浜松市南区', 'ハママツシミナミク', '江之島町', 'エノシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市南区中田島町', '22', '22134', '4300845', '静岡県', 'シズオカケン', '浜松市南区', 'ハママツシミナミク', '中田島町', 'ナカタジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市南区白羽町', '22', '22134', '4300846', '静岡県', 'シズオカケン', '浜松市南区', 'ハママツシミナミク', '白羽町', 'シロワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区向宿', '22', '22131', '4300851', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '向宿', 'ムコウジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区領家', '22', '22131', '4300852', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '領家', 'リョウケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市南区三島町', '22', '22134', '4300853', '静岡県', 'シズオカケン', '浜松市南区', 'ハママツシミナミク', '三島町', 'ミシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区瓜内町', '22', '22131', '4300854', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '瓜内町', 'ウリウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市南区瓜内町', '22', '22134', '4300854', '静岡県', 'シズオカケン', '浜松市南区', 'ハママツシミナミク', '瓜内町', 'ウリウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市南区楊子町', '22', '22134', '4300855', '静岡県', 'シズオカケン', '浜松市南区', 'ハママツシミナミク', '楊子町', 'ヨウズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区中島', '22', '22131', '4300856', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '中島', 'ナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区中島町', '22', '22131', '4300857', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '中島町', 'ナカジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区曳馬', '22', '22131', '4300901', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '曳馬', 'ヒクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区曳馬町', '22', '22131', '4300902', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '曳馬町', 'ヒクマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区助信町', '22', '22131', '4300903', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '助信町', 'スケノブチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区中沢町', '22', '22131', '4300904', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '中沢町', 'ナカザワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区下池川町', '22', '22131', '4300905', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '下池川町', 'シモイケガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区住吉', '22', '22131', '4300906', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '住吉', 'スミヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区高林', '22', '22131', '4300907', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '高林', 'タカバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区新津町', '22', '22131', '4300911', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '新津町', 'シンヅチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区茄子町', '22', '22131', '4300912', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '茄子町', 'ナスビチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区船越町', '22', '22131', '4300913', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '船越町', 'フナコシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区東田町', '22', '22131', '4300915', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '東田町', 'ヒガシタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区早馬町', '22', '22131', '4300916', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '早馬町', 'ハヤウマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区常盤町', '22', '22131', '4300917', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '常盤町', 'トキワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区八幡町', '22', '22131', '4300918', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '八幡町', 'ハチマンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区野口町', '22', '22131', '4300919', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '野口町', 'ノグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区北寺島町', '22', '22131', '4300923', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '北寺島町', 'キタテラジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区龍禅寺町', '22', '22131', '4300924', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '龍禅寺町', 'リュウゼンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区寺島町', '22', '22131', '4300925', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '寺島町', 'テラジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区砂山町', '22', '22131', '4300926', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '砂山町', 'スナヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区旭町', '22', '22131', '4300927', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '旭町', 'アサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区板屋町', '22', '22131', '4300928', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '板屋町', 'イタヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区中央', '22', '22131', '4300929', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区神明町', '22', '22131', '4300931', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '神明町', 'シンメイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区肴町', '22', '22131', '4300932', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '肴町', 'サカナマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区鍛冶町', '22', '22131', '4300933', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '鍛冶町', 'カジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区千歳町', '22', '22131', '4300934', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '千歳町', 'チトセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区伝馬町', '22', '22131', '4300935', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '伝馬町', 'テンマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区大工町', '22', '22131', '4300936', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '大工町', 'ダイクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区利町', '22', '22131', '4300937', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '利町', 'トギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区紺屋町', '22', '22131', '4300938', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '紺屋町', 'コウヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区連尺町', '22', '22131', '4300939', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '連尺町', 'レンジャクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区山下町', '22', '22131', '4300941', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '山下町', 'ヤマシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区元浜町', '22', '22131', '4300942', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '元浜町', 'モトハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区北田町', '22', '22131', '4300943', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '北田町', 'キタタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区田町', '22', '22131', '4300944', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '田町', 'タマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区池町', '22', '22131', '4300945', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '池町', 'イケマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区元城町', '22', '22131', '4300946', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '元城町', 'モトシロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区松城町', '22', '22131', '4300947', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '松城町', 'マツシロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区元目町', '22', '22131', '4300948', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '元目町', 'ゲンモクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区尾張町', '22', '22131', '4300949', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '尾張町', 'オワリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道爾志郡乙部町', '01', '01364', '0430100', '北海道', 'ホッカイドウ', '爾志郡乙部町', 'ニシグンオトベチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('39734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道爾志郡乙部町滝瀬', '01', '01364', '0430101', '北海道', 'ホッカイドウ', '爾志郡乙部町', 'ニシグンオトベチョウ', '滝瀬', 'タキセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道爾志郡乙部町元町', '01', '01364', '0430102', '北海道', 'ホッカイドウ', '爾志郡乙部町', 'ニシグンオトベチョウ', '元町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道爾志郡乙部町緑町', '01', '01364', '0430103', '北海道', 'ホッカイドウ', '爾志郡乙部町', 'ニシグンオトベチョウ', '緑町', 'ミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道爾志郡乙部町館浦', '01', '01364', '0430104', '北海道', 'ホッカイドウ', '爾志郡乙部町', 'ニシグンオトベチョウ', '館浦', 'タテウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道爾志郡乙部町鳥山', '01', '01364', '0430111', '北海道', 'ホッカイドウ', '爾志郡乙部町', 'ニシグンオトベチョウ', '鳥山', 'トリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道爾志郡乙部町栄野', '01', '01364', '0430112', '北海道', 'ホッカイドウ', '爾志郡乙部町', 'ニシグンオトベチョウ', '栄野', 'サカエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道爾志郡乙部町栄浜', '01', '01364', '0430113', '北海道', 'ホッカイドウ', '爾志郡乙部町', 'ニシグンオトベチョウ', '栄浜', 'サカエハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道爾志郡乙部町元和', '01', '01364', '0430114', '北海道', 'ホッカイドウ', '爾志郡乙部町', 'ニシグンオトベチョウ', '元和', 'ゲンナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道爾志郡乙部町富岡', '01', '01364', '0430115', '北海道', 'ホッカイドウ', '爾志郡乙部町', 'ニシグンオトベチョウ', '富岡', 'トミオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道爾志郡乙部町旭岱', '01', '01364', '0430116', '北海道', 'ホッカイドウ', '爾志郡乙部町', 'ニシグンオトベチョウ', '旭岱', 'アサヒタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道爾志郡乙部町姫川', '01', '01364', '0430117', '北海道', 'ホッカイドウ', '爾志郡乙部町', 'ニシグンオトベチョウ', '姫川', 'ヒメカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道爾志郡乙部町豊浜', '01', '01364', '0430231', '北海道', 'ホッカイドウ', '爾志郡乙部町', 'ニシグンオトベチョウ', '豊浜', 'トヨハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道爾志郡乙部町花磯', '01', '01364', '0430232', '北海道', 'ホッカイドウ', '爾志郡乙部町', 'ニシグンオトベチョウ', '花磯', 'ハナイソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道爾志郡乙部町潮見', '01', '01364', '0430233', '北海道', 'ホッカイドウ', '爾志郡乙部町', 'ニシグンオトベチョウ', '潮見', 'シオミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道爾志郡乙部町三ツ谷', '01', '01364', '0430234', '北海道', 'ホッカイドウ', '爾志郡乙部町', 'ニシグンオトベチョウ', '三ツ谷', 'ミツヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道二海郡八雲町熊石折戸町', '01', '01346', '0430331', '北海道', 'ホッカイドウ', '二海郡八雲町', 'フタミグンヤクモチョウ', '熊石折戸町', 'クマイシオリトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道二海郡八雲町熊石相沼町', '01', '01346', '0430332', '北海道', 'ホッカイドウ', '二海郡八雲町', 'フタミグンヤクモチョウ', '熊石相沼町', 'クマイシアイヌマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道二海郡八雲町熊石館平町', '01', '01346', '0430333', '北海道', 'ホッカイドウ', '二海郡八雲町', 'フタミグンヤクモチョウ', '熊石館平町', 'クマイシタテヒラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道二海郡八雲町熊石泊川町', '01', '01346', '0430334', '北海道', 'ホッカイドウ', '二海郡八雲町', 'フタミグンヤクモチョウ', '熊石泊川町', 'クマイシトマリカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道二海郡八雲町熊石黒岩町', '01', '01346', '0430335', '北海道', 'ホッカイドウ', '二海郡八雲町', 'フタミグンヤクモチョウ', '熊石黒岩町', 'クマイシクロイワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道二海郡八雲町熊石見日町', '01', '01346', '0430401', '北海道', 'ホッカイドウ', '二海郡八雲町', 'フタミグンヤクモチョウ', '熊石見日町', 'クマイシケンニチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道二海郡八雲町熊石鮎川町', '01', '01346', '0430402', '北海道', 'ホッカイドウ', '二海郡八雲町', 'フタミグンヤクモチョウ', '熊石鮎川町', 'クマイシアユカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道二海郡八雲町熊石平町', '01', '01346', '0430403', '北海道', 'ホッカイドウ', '二海郡八雲町', 'フタミグンヤクモチョウ', '熊石平町', 'クマイシタイラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道二海郡八雲町熊石畳岩町', '01', '01346', '0430404', '北海道', 'ホッカイドウ', '二海郡八雲町', 'フタミグンヤクモチョウ', '熊石畳岩町', 'クマイシタタミイワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道二海郡八雲町熊石大谷町', '01', '01346', '0430405', '北海道', 'ホッカイドウ', '二海郡八雲町', 'フタミグンヤクモチョウ', '熊石大谷町', 'クマイシオオタニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道二海郡八雲町熊石根崎町', '01', '01346', '0430415', '北海道', 'ホッカイドウ', '二海郡八雲町', 'フタミグンヤクモチョウ', '熊石根崎町', 'クマイシネザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道二海郡八雲町熊石雲石町', '01', '01346', '0430416', '北海道', 'ホッカイドウ', '二海郡八雲町', 'フタミグンヤクモチョウ', '熊石雲石町', 'クマイシウンセキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道二海郡八雲町熊石鳴神町', '01', '01346', '0430417', '北海道', 'ホッカイドウ', '二海郡八雲町', 'フタミグンヤクモチョウ', '熊石鳴神町', 'クマイシナルガミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道二海郡八雲町熊石関内町', '01', '01346', '0430418', '北海道', 'ホッカイドウ', '二海郡八雲町', 'フタミグンヤクモチョウ', '熊石関内町', 'クマイシセキナイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道二海郡八雲町熊石西浜町', '01', '01346', '0430419', '北海道', 'ホッカイドウ', '二海郡八雲町', 'フタミグンヤクモチョウ', '熊石西浜町', 'クマイシニシハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道久遠郡せたな町大成区長磯', '01', '01371', '0430421', '北海道', 'ホッカイドウ', '久遠郡せたな町', 'クドウグンセタナチョウ', '大成区長磯', 'タイセイクナガイソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道久遠郡せたな町大成区太田', '01', '01371', '0430501', '北海道', 'ホッカイドウ', '久遠郡せたな町', 'クドウグンセタナチョウ', '大成区太田', 'タイセイクオオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道久遠郡せたな町大成区富磯', '01', '01371', '0430502', '北海道', 'ホッカイドウ', '久遠郡せたな町', 'クドウグンセタナチョウ', '大成区富磯', 'タイセイクトミイソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道久遠郡せたな町大成区上浦', '01', '01371', '0430503', '北海道', 'ホッカイドウ', '久遠郡せたな町', 'クドウグンセタナチョウ', '大成区上浦', 'タイセイクカミウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道久遠郡せたな町大成区都', '01', '01371', '0430504', '北海道', 'ホッカイドウ', '久遠郡せたな町', 'クドウグンセタナチョウ', '大成区都', 'タイセイクミヤコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道久遠郡せたな町大成区本陣', '01', '01371', '0430505', '北海道', 'ホッカイドウ', '久遠郡せたな町', 'クドウグンセタナチョウ', '大成区本陣', 'タイセイクホンジン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道久遠郡せたな町大成区久遠', '01', '01371', '0430511', '北海道', 'ホッカイドウ', '久遠郡せたな町', 'クドウグンセタナチョウ', '大成区久遠', 'タイセイククドオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道久遠郡せたな町大成区花歌', '01', '01371', '0430512', '北海道', 'ホッカイドウ', '久遠郡せたな町', 'クドウグンセタナチョウ', '大成区花歌', 'タイセイクハナウタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道久遠郡せたな町大成区宮野', '01', '01371', '0430513', '北海道', 'ホッカイドウ', '久遠郡せたな町', 'クドウグンセタナチョウ', '大成区宮野', 'タイセイクミヤノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道久遠郡せたな町大成区平浜', '01', '01371', '0430514', '北海道', 'ホッカイドウ', '久遠郡せたな町', 'クドウグンセタナチョウ', '大成区平浜', 'タイセイクヒラハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道久遠郡せたな町大成区貝取澗', '01', '01371', '0430515', '北海道', 'ホッカイドウ', '久遠郡せたな町', 'クドウグンセタナチョウ', '大成区貝取澗', 'タイセイクカイトリマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区板屋町浜松アクトタワー　1階', '22', '22131', '4307701', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '板屋町', 'イタヤマチ', null, null, '浜松アクトタワー　1階', 'ハママツアクトタワー　01カイ');
INSERT INTO `ms_addresses` VALUES ('39778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区板屋町浜松アクトタワー　2階', '22', '22131', '4307702', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '板屋町', 'イタヤマチ', null, null, '浜松アクトタワー　2階', 'ハママツアクトタワー　02カイ');
INSERT INTO `ms_addresses` VALUES ('39779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区板屋町浜松アクトタワー　3階', '22', '22131', '4307703', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '板屋町', 'イタヤマチ', null, null, '浜松アクトタワー　3階', 'ハママツアクトタワー　03カイ');
INSERT INTO `ms_addresses` VALUES ('39780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区板屋町浜松アクトタワー　4階', '22', '22131', '4307704', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '板屋町', 'イタヤマチ', null, null, '浜松アクトタワー　4階', 'ハママツアクトタワー　04カイ');
INSERT INTO `ms_addresses` VALUES ('39781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区板屋町浜松アクトタワー　5階', '22', '22131', '4307705', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '板屋町', 'イタヤマチ', null, null, '浜松アクトタワー　5階', 'ハママツアクトタワー　05カイ');
INSERT INTO `ms_addresses` VALUES ('39782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区板屋町浜松アクトタワー　6階', '22', '22131', '4307706', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '板屋町', 'イタヤマチ', null, null, '浜松アクトタワー　6階', 'ハママツアクトタワー　06カイ');
INSERT INTO `ms_addresses` VALUES ('39783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区板屋町浜松アクトタワー　7階', '22', '22131', '4307707', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '板屋町', 'イタヤマチ', null, null, '浜松アクトタワー　7階', 'ハママツアクトタワー　07カイ');
INSERT INTO `ms_addresses` VALUES ('39784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区板屋町浜松アクトタワー　8階', '22', '22131', '4307708', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '板屋町', 'イタヤマチ', null, null, '浜松アクトタワー　8階', 'ハママツアクトタワー　08カイ');
INSERT INTO `ms_addresses` VALUES ('39785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区板屋町浜松アクトタワー　9階', '22', '22131', '4307709', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '板屋町', 'イタヤマチ', null, null, '浜松アクトタワー　9階', 'ハママツアクトタワー　09カイ');
INSERT INTO `ms_addresses` VALUES ('39786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区板屋町浜松アクトタワー　10階', '22', '22131', '4307710', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '板屋町', 'イタヤマチ', null, null, '浜松アクトタワー　10階', 'ハママツアクトタワー　10カイ');
INSERT INTO `ms_addresses` VALUES ('39787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区板屋町浜松アクトタワー　11階', '22', '22131', '4307711', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '板屋町', 'イタヤマチ', null, null, '浜松アクトタワー　11階', 'ハママツアクトタワー　11カイ');
INSERT INTO `ms_addresses` VALUES ('39788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区板屋町浜松アクトタワー　12階', '22', '22131', '4307712', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '板屋町', 'イタヤマチ', null, null, '浜松アクトタワー　12階', 'ハママツアクトタワー　12カイ');
INSERT INTO `ms_addresses` VALUES ('39789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区板屋町浜松アクトタワー　13階', '22', '22131', '4307713', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '板屋町', 'イタヤマチ', null, null, '浜松アクトタワー　13階', 'ハママツアクトタワー　13カイ');
INSERT INTO `ms_addresses` VALUES ('39790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区板屋町浜松アクトタワー　14階', '22', '22131', '4307714', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '板屋町', 'イタヤマチ', null, null, '浜松アクトタワー　14階', 'ハママツアクトタワー　14カイ');
INSERT INTO `ms_addresses` VALUES ('39791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区板屋町浜松アクトタワー　15階', '22', '22131', '4307715', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '板屋町', 'イタヤマチ', null, null, '浜松アクトタワー　15階', 'ハママツアクトタワー　15カイ');
INSERT INTO `ms_addresses` VALUES ('39792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区板屋町浜松アクトタワー　16階', '22', '22131', '4307716', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '板屋町', 'イタヤマチ', null, null, '浜松アクトタワー　16階', 'ハママツアクトタワー　16カイ');
INSERT INTO `ms_addresses` VALUES ('39793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区板屋町浜松アクトタワー　17階', '22', '22131', '4307717', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '板屋町', 'イタヤマチ', null, null, '浜松アクトタワー　17階', 'ハママツアクトタワー　17カイ');
INSERT INTO `ms_addresses` VALUES ('39794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区板屋町浜松アクトタワー　18階', '22', '22131', '4307718', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '板屋町', 'イタヤマチ', null, null, '浜松アクトタワー　18階', 'ハママツアクトタワー　18カイ');
INSERT INTO `ms_addresses` VALUES ('39795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区板屋町浜松アクトタワー　19階', '22', '22131', '4307719', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '板屋町', 'イタヤマチ', null, null, '浜松アクトタワー　19階', 'ハママツアクトタワー　19カイ');
INSERT INTO `ms_addresses` VALUES ('39796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区板屋町浜松アクトタワー　20階', '22', '22131', '4307720', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '板屋町', 'イタヤマチ', null, null, '浜松アクトタワー　20階', 'ハママツアクトタワー　20カイ');
INSERT INTO `ms_addresses` VALUES ('39797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区板屋町浜松アクトタワー　21階', '22', '22131', '4307721', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '板屋町', 'イタヤマチ', null, null, '浜松アクトタワー　21階', 'ハママツアクトタワー　21カイ');
INSERT INTO `ms_addresses` VALUES ('39798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区板屋町浜松アクトタワー　22階', '22', '22131', '4307722', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '板屋町', 'イタヤマチ', null, null, '浜松アクトタワー　22階', 'ハママツアクトタワー　22カイ');
INSERT INTO `ms_addresses` VALUES ('39799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区板屋町浜松アクトタワー　23階', '22', '22131', '4307723', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '板屋町', 'イタヤマチ', null, null, '浜松アクトタワー　23階', 'ハママツアクトタワー　23カイ');
INSERT INTO `ms_addresses` VALUES ('39800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区板屋町浜松アクトタワー　24階', '22', '22131', '4307724', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '板屋町', 'イタヤマチ', null, null, '浜松アクトタワー　24階', 'ハママツアクトタワー　24カイ');
INSERT INTO `ms_addresses` VALUES ('39801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区板屋町浜松アクトタワー　25階', '22', '22131', '4307725', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '板屋町', 'イタヤマチ', null, null, '浜松アクトタワー　25階', 'ハママツアクトタワー　25カイ');
INSERT INTO `ms_addresses` VALUES ('39802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区板屋町浜松アクトタワー　26階', '22', '22131', '4307726', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '板屋町', 'イタヤマチ', null, null, '浜松アクトタワー　26階', 'ハママツアクトタワー　26カイ');
INSERT INTO `ms_addresses` VALUES ('39803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区板屋町浜松アクトタワー　27階', '22', '22131', '4307727', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '板屋町', 'イタヤマチ', null, null, '浜松アクトタワー　27階', 'ハママツアクトタワー　27カイ');
INSERT INTO `ms_addresses` VALUES ('39804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区板屋町浜松アクトタワー　28階', '22', '22131', '4307728', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '板屋町', 'イタヤマチ', null, null, '浜松アクトタワー　28階', 'ハママツアクトタワー　28カイ');
INSERT INTO `ms_addresses` VALUES ('39805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区板屋町浜松アクトタワー　29階', '22', '22131', '4307729', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '板屋町', 'イタヤマチ', null, null, '浜松アクトタワー　29階', 'ハママツアクトタワー　29カイ');
INSERT INTO `ms_addresses` VALUES ('39806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区板屋町浜松アクトタワー　30階', '22', '22131', '4307730', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '板屋町', 'イタヤマチ', null, null, '浜松アクトタワー　30階', 'ハママツアクトタワー　30カイ');
INSERT INTO `ms_addresses` VALUES ('39807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区板屋町浜松アクトタワー　31階', '22', '22131', '4307731', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '板屋町', 'イタヤマチ', null, null, '浜松アクトタワー　31階', 'ハママツアクトタワー　31カイ');
INSERT INTO `ms_addresses` VALUES ('39808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区板屋町浜松アクトタワー　32階', '22', '22131', '4307732', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '板屋町', 'イタヤマチ', null, null, '浜松アクトタワー　32階', 'ハママツアクトタワー　32カイ');
INSERT INTO `ms_addresses` VALUES ('39809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区板屋町浜松アクトタワー　33階', '22', '22131', '4307733', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '板屋町', 'イタヤマチ', null, null, '浜松アクトタワー　33階', 'ハママツアクトタワー　33カイ');
INSERT INTO `ms_addresses` VALUES ('39810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区板屋町浜松アクトタワー　34階', '22', '22131', '4307734', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '板屋町', 'イタヤマチ', null, null, '浜松アクトタワー　34階', 'ハママツアクトタワー　34カイ');
INSERT INTO `ms_addresses` VALUES ('39811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区板屋町浜松アクトタワー　35階', '22', '22131', '4307735', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '板屋町', 'イタヤマチ', null, null, '浜松アクトタワー　35階', 'ハママツアクトタワー　35カイ');
INSERT INTO `ms_addresses` VALUES ('39812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区板屋町浜松アクトタワー　36階', '22', '22131', '4307736', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '板屋町', 'イタヤマチ', null, null, '浜松アクトタワー　36階', 'ハママツアクトタワー　36カイ');
INSERT INTO `ms_addresses` VALUES ('39813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区板屋町浜松アクトタワー　37階', '22', '22131', '4307737', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '板屋町', 'イタヤマチ', null, null, '浜松アクトタワー　37階', 'ハママツアクトタワー　37カイ');
INSERT INTO `ms_addresses` VALUES ('39814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区板屋町浜松アクトタワー　38階', '22', '22131', '4307738', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '板屋町', 'イタヤマチ', null, null, '浜松アクトタワー　38階', 'ハママツアクトタワー　38カイ');
INSERT INTO `ms_addresses` VALUES ('39815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区板屋町浜松アクトタワー　39階', '22', '22131', '4307739', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '板屋町', 'イタヤマチ', null, null, '浜松アクトタワー　39階', 'ハママツアクトタワー　39カイ');
INSERT INTO `ms_addresses` VALUES ('39816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区板屋町浜松アクトタワー　40階', '22', '22131', '4307740', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '板屋町', 'イタヤマチ', null, null, '浜松アクトタワー　40階', 'ハママツアクトタワー　40カイ');
INSERT INTO `ms_addresses` VALUES ('39817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区板屋町浜松アクトタワー　41階', '22', '22131', '4307741', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '板屋町', 'イタヤマチ', null, null, '浜松アクトタワー　41階', 'ハママツアクトタワー　41カイ');
INSERT INTO `ms_addresses` VALUES ('39818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区板屋町浜松アクトタワー　42階', '22', '22131', '4307742', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '板屋町', 'イタヤマチ', null, null, '浜松アクトタワー　42階', 'ハママツアクトタワー　42カイ');
INSERT INTO `ms_addresses` VALUES ('39819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区板屋町浜松アクトタワー　43階', '22', '22131', '4307743', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '板屋町', 'イタヤマチ', null, null, '浜松アクトタワー　43階', 'ハママツアクトタワー　43カイ');
INSERT INTO `ms_addresses` VALUES ('39820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区板屋町浜松アクトタワー　44階', '22', '22131', '4307744', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '板屋町', 'イタヤマチ', null, null, '浜松アクトタワー　44階', 'ハママツアクトタワー　44カイ');
INSERT INTO `ms_addresses` VALUES ('39821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区板屋町浜松アクトタワー　45階', '22', '22131', '4307745', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '板屋町', 'イタヤマチ', null, null, '浜松アクトタワー　45階', 'ハママツアクトタワー　45カイ');
INSERT INTO `ms_addresses` VALUES ('39822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区板屋町浜松アクトタワー　', '22', '22131', '4307790', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '板屋町', 'イタヤマチ', null, null, '浜松アクトタワー　', 'ハママツアクトタワー　');
INSERT INTO `ms_addresses` VALUES ('39860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市西区雄踏町山崎', '22', '22133', '4310101', '静岡県', 'シズオカケン', '浜松市西区', 'ハママツシニシク', '雄踏町山崎', 'ユウトウチョウヤマザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市西区雄踏町宇布見', '22', '22133', '4310102', '静岡県', 'シズオカケン', '浜松市西区', 'ハママツシニシク', '雄踏町宇布見', 'ユウトウチョウウブミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市西区雄踏', '22', '22133', '4310103', '静岡県', 'シズオカケン', '浜松市西区', 'ハママツシニシク', '雄踏', 'ユウトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市西区篠原町', '22', '22133', '4310201', '静岡県', 'シズオカケン', '浜松市西区', 'ハママツシニシク', '篠原町', 'シノハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市西区坪井町', '22', '22133', '4310202', '静岡県', 'シズオカケン', '浜松市西区', 'ハママツシニシク', '坪井町', 'ツボイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市西区馬郡町', '22', '22133', '4310203', '静岡県', 'シズオカケン', '浜松市西区', 'ハママツシニシク', '馬郡町', 'マゴオリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市西区舞阪町舞阪', '22', '22133', '4310211', '静岡県', 'シズオカケン', '浜松市西区', 'ハママツシニシク', '舞阪町舞阪', 'マイサカチョウマイサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市西区舞阪町長十新田', '22', '22133', '4310212', '静岡県', 'シズオカケン', '浜松市西区', 'ハママツシニシク', '舞阪町長十新田', 'マイサカチョウチョウジュウシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市西区舞阪町浜田', '22', '22133', '4310213', '静岡県', 'シズオカケン', '浜松市西区', 'ハママツシニシク', '舞阪町浜田', 'マイサカチョウハマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市西区舞阪町弁天島', '22', '22133', '4310214', '静岡県', 'シズオカケン', '浜松市西区', 'ハママツシニシク', '舞阪町弁天島', 'マイサカチョウベンテンジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜名郡新居町', '22', '22503', '4310300', '静岡県', 'シズオカケン', '浜名郡新居町', 'ハマナグンアライチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('39876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜名郡新居町中之郷', '22', '22503', '4310301', '静岡県', 'シズオカケン', '浜名郡新居町', 'ハマナグンアライチョウ', '中之郷', 'ナカノゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜名郡新居町新居', '22', '22503', '4310302', '静岡県', 'シズオカケン', '浜名郡新居町', 'ハマナグンアライチョウ', '新居', 'アライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜名郡新居町浜名', '22', '22503', '4310303', '静岡県', 'シズオカケン', '浜名郡新居町', 'ハマナグンアライチョウ', '浜名', 'ハマナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜名郡新居町内山', '22', '22503', '4310304', '静岡県', 'シズオカケン', '浜名郡新居町', 'ハマナグンアライチョウ', '内山', 'ウチヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県湖西市', '22', '22221', '4310400', '静岡県', 'シズオカケン', '湖西市', 'コサイシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('39882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県湖西市横山', '22', '22221', '4310401', '静岡県', 'シズオカケン', '湖西市', 'コサイシ', '横山', 'ヨコヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県湖西市利木', '22', '22221', '4310402', '静岡県', 'シズオカケン', '湖西市', 'コサイシ', '利木', 'リキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県湖西市大知波', '22', '22221', '4310403', '静岡県', 'シズオカケン', '湖西市', 'コサイシ', '大知波', 'オオチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県湖西市太田', '22', '22221', '4310404', '静岡県', 'シズオカケン', '湖西市', 'コサイシ', '太田', 'オオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県湖西市神座', '22', '22221', '4310405', '静岡県', 'シズオカケン', '湖西市', 'コサイシ', '神座', 'カンザ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県湖西市入出', '22', '22221', '4310411', '静岡県', 'シズオカケン', '湖西市', 'コサイシ', '入出', 'イリデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県湖西市内浦', '22', '22221', '4310412', '静岡県', 'シズオカケン', '湖西市', 'コサイシ', '内浦', 'ウチウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県湖西市新所', '22', '22221', '4310421', '静岡県', 'シズオカケン', '湖西市', 'コサイシ', '新所', 'シンジョ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県湖西市岡崎', '22', '22221', '4310422', '静岡県', 'シズオカケン', '湖西市', 'コサイシ', '岡崎', 'オカサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県湖西市新所・岡崎・梅田入会地', '22', '22221', '4310423', '静岡県', 'シズオカケン', '湖西市', 'コサイシ', '新所・岡崎・梅田入会地', 'シンジョ・オカサキ・ウメダニュウカイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県湖西市新所原', '22', '22221', '4310424', '静岡県', 'シズオカケン', '湖西市', 'コサイシ', '新所原', 'シンジョハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県湖西市梅田', '22', '22221', '4310425', '静岡県', 'シズオカケン', '湖西市', 'コサイシ', '梅田', 'ウメダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県湖西市新所原東', '22', '22221', '4310426', '静岡県', 'シズオカケン', '湖西市', 'コサイシ', '新所原東', 'シンジョハラヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県湖西市駅南', '22', '22221', '4310427', '静岡県', 'シズオカケン', '湖西市', 'コサイシ', '駅南', 'エキミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県湖西市ときわ', '22', '22221', '4310428', '静岡県', 'シズオカケン', '湖西市', 'コサイシ', 'ときわ', 'トキワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県湖西市南台', '22', '22221', '4310429', '静岡県', 'シズオカケン', '湖西市', 'コサイシ', '南台', 'ミナミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県湖西市鷲津', '22', '22221', '4310431', '静岡県', 'シズオカケン', '湖西市', 'コサイシ', '鷲津', 'ワシヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県湖西市風の杜', '22', '22221', '4310432', '静岡県', 'シズオカケン', '湖西市', 'コサイシ', '風の杜', 'カゼノモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県湖西市吉美', '22', '22221', '4310441', '静岡県', 'シズオカケン', '湖西市', 'コサイシ', '吉美', 'キビ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県湖西市古見', '22', '22221', '4310442', '静岡県', 'シズオカケン', '湖西市', 'コサイシ', '古見', 'コミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県湖西市山口', '22', '22221', '4310443', '静岡県', 'シズオカケン', '湖西市', 'コサイシ', '山口', 'ヤマグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県湖西市坊瀬', '22', '22221', '4310444', '静岡県', 'シズオカケン', '湖西市', 'コサイシ', '坊瀬', 'ボウゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県湖西市白須賀', '22', '22221', '4310451', '静岡県', 'シズオカケン', '湖西市', 'コサイシ', '白須賀', 'シラスカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県湖西市境宿', '22', '22221', '4310452', '静岡県', 'シズオカケン', '湖西市', 'コサイシ', '境宿', 'サカイジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道檜山郡厚沢部町', '01', '01363', '0431100', '北海道', 'ホッカイドウ', '檜山郡厚沢部町', 'ヒヤマグンアッサブチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('39912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道檜山郡厚沢部町清水', '01', '01363', '0431101', '北海道', 'ホッカイドウ', '檜山郡厚沢部町', 'ヒヤマグンアッサブチョウ', '清水', 'シミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道檜山郡厚沢部町稲見', '01', '01363', '0431102', '北海道', 'ホッカイドウ', '檜山郡厚沢部町', 'ヒヤマグンアッサブチョウ', '稲見', 'イナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道檜山郡厚沢部町滝野', '01', '01363', '0431103', '北海道', 'ホッカイドウ', '檜山郡厚沢部町', 'ヒヤマグンアッサブチョウ', '滝野', 'タキノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道檜山郡厚沢部町上里', '01', '01363', '0431104', '北海道', 'ホッカイドウ', '檜山郡厚沢部町', 'ヒヤマグンアッサブチョウ', '上里', 'カミサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市西区和光町', '22', '22133', '4311101', '静岡県', 'シズオカケン', '浜松市西区', 'ハママツシニシク', '和光町', 'ワコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市西区大山町', '22', '22133', '4311102', '静岡県', 'シズオカケン', '浜松市西区', 'ハママツシニシク', '大山町', 'オオヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市西区湖東町', '22', '22133', '4311103', '静岡県', 'シズオカケン', '浜松市西区', 'ハママツシニシク', '湖東町', 'コトウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市西区桜台', '22', '22133', '4311104', '静岡県', 'シズオカケン', '浜松市西区', 'ハママツシニシク', '桜台', 'サクラダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道檜山郡厚沢部町赤沼町', '01', '01363', '0431111', '北海道', 'ホッカイドウ', '檜山郡厚沢部町', 'ヒヤマグンアッサブチョウ', '赤沼町', 'アカヌママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市西区伊左地町', '22', '22133', '4311111', '静岡県', 'シズオカケン', '浜松市西区', 'ハママツシニシク', '伊左地町', 'イサジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市西区大人見町', '22', '22133', '4311112', '静岡県', 'シズオカケン', '浜松市西区', 'ハママツシニシク', '大人見町', 'オオヒトミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市西区古人見町', '22', '22133', '4311113', '静岡県', 'シズオカケン', '浜松市西区', 'ハママツシニシク', '古人見町', 'コヒトミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市西区佐浜町', '22', '22133', '4311114', '静岡県', 'シズオカケン', '浜松市西区', 'ハママツシニシク', '佐浜町', 'サハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市西区和地町', '22', '22133', '4311115', '静岡県', 'シズオカケン', '浜松市西区', 'ハママツシニシク', '和地町', 'ワジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道檜山郡厚沢部町緑町', '01', '01363', '0431112', '北海道', 'ホッカイドウ', '檜山郡厚沢部町', 'ヒヤマグンアッサブチョウ', '緑町', 'ミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道檜山郡厚沢部町新町', '01', '01363', '0431113', '北海道', 'ホッカイドウ', '檜山郡厚沢部町', 'ヒヤマグンアッサブチョウ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道檜山郡厚沢部町本町', '01', '01363', '0431114', '北海道', 'ホッカイドウ', '檜山郡厚沢部町', 'ヒヤマグンアッサブチョウ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道檜山郡厚沢部町松園町', '01', '01363', '0431115', '北海道', 'ホッカイドウ', '檜山郡厚沢部町', 'ヒヤマグンアッサブチョウ', '松園町', 'マツゾノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道檜山郡厚沢部町上の山', '01', '01363', '0431116', '北海道', 'ホッカイドウ', '檜山郡厚沢部町', 'ヒヤマグンアッサブチョウ', '上の山', 'カミノヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道檜山郡厚沢部町美和', '01', '01363', '0431117', '北海道', 'ホッカイドウ', '檜山郡厚沢部町', 'ヒヤマグンアッサブチョウ', '美和', 'ミワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道檜山郡厚沢部町富栄', '01', '01363', '0431118', '北海道', 'ホッカイドウ', '檜山郡厚沢部町', 'ヒヤマグンアッサブチョウ', '富栄', 'トミエイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市西区深萩町', '22', '22133', '4311201', '静岡県', 'シズオカケン', '浜松市西区', 'ハママツシニシク', '深萩町', 'フカハギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市西区呉松町', '22', '22133', '4311202', '静岡県', 'シズオカケン', '浜松市西区', 'ハママツシニシク', '呉松町', 'クレマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市西区平松町', '22', '22133', '4311203', '静岡県', 'シズオカケン', '浜松市西区', 'ハママツシニシク', '平松町', 'ヒラマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市西区白洲町', '22', '22133', '4311204', '静岡県', 'シズオカケン', '浜松市西区', 'ハママツシニシク', '白洲町', 'シラスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市西区協和町', '22', '22133', '4311205', '静岡県', 'シズオカケン', '浜松市西区', 'ハママツシニシク', '協和町', 'キョウワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市西区庄和町', '22', '22133', '4311206', '静岡県', 'シズオカケン', '浜松市西区', 'ハママツシニシク', '庄和町', 'ショウワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市西区村櫛町', '22', '22133', '4311207', '静岡県', 'シズオカケン', '浜松市西区', 'ハママツシニシク', '村櫛町', 'ムラクシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市西区庄内町', '22', '22133', '4311208', '静岡県', 'シズオカケン', '浜松市西区', 'ハママツシニシク', '庄内町', 'ショウナイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市西区舘山寺町', '22', '22133', '4311209', '静岡県', 'シズオカケン', '浜松市西区', 'ハママツシニシク', '舘山寺町', 'カンザンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市北区細江町小野', '22', '22135', '4311301', '静岡県', 'シズオカケン', '浜松市北区', 'ハママツシキタク', '細江町小野', 'ホソエチョウオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市北区細江町広岡', '22', '22135', '4311302', '静岡県', 'シズオカケン', '浜松市北区', 'ハママツシキタク', '細江町広岡', 'ホソエチョウヒロオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市北区細江町三和', '22', '22135', '4311303', '静岡県', 'シズオカケン', '浜松市北区', 'ハママツシキタク', '細江町三和', 'ホソエチョウミワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市北区細江町中川', '22', '22135', '4311304', '静岡県', 'シズオカケン', '浜松市北区', 'ハママツシキタク', '細江町中川', 'ホソエチョウナカガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市北区細江町気賀', '22', '22135', '4311305', '静岡県', 'シズオカケン', '浜松市北区', 'ハママツシキタク', '細江町気賀', 'ホソエチョウキガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市北区三ヶ日町佐久米', '22', '22135', '4311401', '静岡県', 'シズオカケン', '浜松市北区', 'ハママツシキタク', '三ヶ日町佐久米', 'ミッカビチョウサクメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市北区三ヶ日町都筑', '22', '22135', '4311402', '静岡県', 'シズオカケン', '浜松市北区', 'ハママツシキタク', '三ヶ日町都筑', 'ミッカビチョウツヅキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市北区三ヶ日町大崎', '22', '22135', '4311403', '静岡県', 'シズオカケン', '浜松市北区', 'ハママツシキタク', '三ヶ日町大崎', 'ミッカビチョウオオサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市北区三ヶ日町宇志', '22', '22135', '4311404', '静岡県', 'シズオカケン', '浜松市北区', 'ハママツシキタク', '三ヶ日町宇志', 'ミッカビチョウウシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市北区三ヶ日町津々崎', '22', '22135', '4311405', '静岡県', 'シズオカケン', '浜松市北区', 'ハママツシキタク', '三ヶ日町津々崎', 'ミッカビチョウツヅサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市北区三ヶ日町駒場', '22', '22135', '4311406', '静岡県', 'シズオカケン', '浜松市北区', 'ハママツシキタク', '三ヶ日町駒場', 'ミッカビチョウコマバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市北区三ヶ日町大谷', '22', '22135', '4311407', '静岡県', 'シズオカケン', '浜松市北区', 'ハママツシキタク', '三ヶ日町大谷', 'ミッカビチョウオオヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市北区三ヶ日町福長', '22', '22135', '4311411', '静岡県', 'シズオカケン', '浜松市北区', 'ハママツシキタク', '三ヶ日町福長', 'ミッカビチョウフクナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市北区三ヶ日町只木', '22', '22135', '4311412', '静岡県', 'シズオカケン', '浜松市北区', 'ハママツシキタク', '三ヶ日町只木', 'ミッカビチョウタダキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市北区三ヶ日町摩訶耶', '22', '22135', '4311413', '静岡県', 'シズオカケン', '浜松市北区', 'ハママツシキタク', '三ヶ日町摩訶耶', 'ミッカビチョウマカヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市北区三ヶ日町三ヶ日', '22', '22135', '4311414', '静岡県', 'シズオカケン', '浜松市北区', 'ハママツシキタク', '三ヶ日町三ヶ日', 'ミッカビチョウミッカビ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市北区三ヶ日町岡本', '22', '22135', '4311415', '静岡県', 'シズオカケン', '浜松市北区', 'ハママツシキタク', '三ヶ日町岡本', 'ミッカビチョウオカモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市北区三ヶ日町釣', '22', '22135', '4311416', '静岡県', 'シズオカケン', '浜松市北区', 'ハママツシキタク', '三ヶ日町釣', 'ミッカビチョウツリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市北区三ヶ日町平山', '22', '22135', '4311417', '静岡県', 'シズオカケン', '浜松市北区', 'ハママツシキタク', '三ヶ日町平山', 'ミッカビチョウヒラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市北区三ヶ日町本坂', '22', '22135', '4311421', '静岡県', 'シズオカケン', '浜松市北区', 'ハママツシキタク', '三ヶ日町本坂', 'ミッカビチョウホンザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市北区三ヶ日町日比沢', '22', '22135', '4311422', '静岡県', 'シズオカケン', '浜松市北区', 'ハママツシキタク', '三ヶ日町日比沢', 'ミッカビチョウヒビサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市北区三ヶ日町鵺代', '22', '22135', '4311423', '静岡県', 'シズオカケン', '浜松市北区', 'ハママツシキタク', '三ヶ日町鵺代', 'ミッカビチョウヌエシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市北区三ヶ日町下尾奈', '22', '22135', '4311424', '静岡県', 'シズオカケン', '浜松市北区', 'ハママツシキタク', '三ヶ日町下尾奈', 'ミッカビチョウシモオナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市北区三ヶ日町上尾奈', '22', '22135', '4311425', '静岡県', 'シズオカケン', '浜松市北区', 'ハママツシキタク', '三ヶ日町上尾奈', 'ミッカビチョウカミオナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市北区滝沢町', '22', '22135', '4312101', '静岡県', 'シズオカケン', '浜松市北区', 'ハママツシキタク', '滝沢町', 'タキサワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市北区都田町', '22', '22135', '4312102', '静岡県', 'シズオカケン', '浜松市北区', 'ハママツシキタク', '都田町', 'ミヤコダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市北区新都田', '22', '22135', '4312103', '静岡県', 'シズオカケン', '浜松市北区', 'ハママツシキタク', '新都田', 'シンミヤコダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市北区鷲沢町', '22', '22135', '4312104', '静岡県', 'シズオカケン', '浜松市北区', 'ハママツシキタク', '鷲沢町', 'ワシザワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市北区引佐町東久留女木', '22', '22135', '4312201', '静岡県', 'シズオカケン', '浜松市北区', 'ハママツシキタク', '引佐町東久留女木', 'イナサチョウヒガシクルメキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市北区引佐町川名', '22', '22135', '4312202', '静岡県', 'シズオカケン', '浜松市北区', 'ハママツシキタク', '引佐町川名', 'イナサチョウカワナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市北区引佐町三岳', '22', '22135', '4312203', '静岡県', 'シズオカケン', '浜松市北区', 'ハママツシキタク', '引佐町三岳', 'イナサチョウミタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市北区引佐町兎荷', '22', '22135', '4312204', '静岡県', 'シズオカケン', '浜松市北区', 'ハママツシキタク', '引佐町兎荷', 'イナサチョウトッカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市北区引佐町伊平', '22', '22135', '4312205', '静岡県', 'シズオカケン', '浜松市北区', 'ハママツシキタク', '引佐町伊平', 'イナサチョウイダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市北区引佐町西黒田', '22', '22135', '4312206', '静岡県', 'シズオカケン', '浜松市北区', 'ハママツシキタク', '引佐町西黒田', 'イナサチョウニシクロダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市北区引佐町東黒田', '22', '22135', '4312207', '静岡県', 'シズオカケン', '浜松市北区', 'ハママツシキタク', '引佐町東黒田', 'イナサチョウヒガシクロダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市北区引佐町花平', '22', '22135', '4312211', '静岡県', 'シズオカケン', '浜松市北区', 'ハママツシキタク', '引佐町花平', 'イナサチョウハナダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市北区引佐町井伊谷', '22', '22135', '4312212', '静岡県', 'シズオカケン', '浜松市北区', 'ハママツシキタク', '引佐町井伊谷', 'イナサチョウイイノヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市北区引佐町金指', '22', '22135', '4312213', '静岡県', 'シズオカケン', '浜松市北区', 'ハママツシキタク', '引佐町金指', 'イナサチョウカナサシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市北区引佐町横尾', '22', '22135', '4312214', '静岡県', 'シズオカケン', '浜松市北区', 'ハママツシキタク', '引佐町横尾', 'イナサチョウヨコオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市北区引佐町白岩', '22', '22135', '4312215', '静岡県', 'シズオカケン', '浜松市北区', 'ハママツシキタク', '引佐町白岩', 'イナサチョウシライワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市北区引佐町田畑', '22', '22135', '4312221', '静岡県', 'シズオカケン', '浜松市北区', 'ハママツシキタク', '引佐町田畑', 'イナサチョウタバタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市北区引佐町黒渕', '22', '22135', '4312222', '静岡県', 'シズオカケン', '浜松市北区', 'ハママツシキタク', '引佐町黒渕', 'イナサチョウクロブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市北区引佐町栃窪', '22', '22135', '4312223', '静岡県', 'シズオカケン', '浜松市北区', 'ハママツシキタク', '引佐町栃窪', 'イナサチョウトチクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市北区引佐町奥山', '22', '22135', '4312224', '静岡県', 'シズオカケン', '浜松市北区', 'ハママツシキタク', '引佐町奥山', 'イナサチョウオクヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市北区引佐町狩宿', '22', '22135', '4312225', '静岡県', 'シズオカケン', '浜松市北区', 'ハママツシキタク', '引佐町狩宿', 'イナサチョウカリシュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市北区引佐町谷沢', '22', '22135', '4312226', '静岡県', 'シズオカケン', '浜松市北区', 'ハママツシキタク', '引佐町谷沢', 'イナサチョウヤザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道檜山郡厚沢部町共和', '01', '01363', '0431231', '北海道', 'ホッカイドウ', '檜山郡厚沢部町', 'ヒヤマグンアッサブチョウ', '共和', 'キョウワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道檜山郡厚沢部町相生', '01', '01363', '0431232', '北海道', 'ホッカイドウ', '檜山郡厚沢部町', 'ヒヤマグンアッサブチョウ', '相生', 'アイオイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道檜山郡厚沢部町旭丘', '01', '01363', '0431233', '北海道', 'ホッカイドウ', '檜山郡厚沢部町', 'ヒヤマグンアッサブチョウ', '旭丘', 'アサヒオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('39999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道檜山郡厚沢部町木間内', '01', '01363', '0431234', '北海道', 'ホッカイドウ', '檜山郡厚沢部町', 'ヒヤマグンアッサブチョウ', '木間内', 'キマナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道檜山郡厚沢部町峠下', '01', '01363', '0431235', '北海道', 'ホッカイドウ', '檜山郡厚沢部町', 'ヒヤマグンアッサブチョウ', '峠下', 'トウゲシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道檜山郡厚沢部町社の山', '01', '01363', '0431236', '北海道', 'ホッカイドウ', '檜山郡厚沢部町', 'ヒヤマグンアッサブチョウ', '社の山', 'シャノヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道檜山郡厚沢部町鶉町', '01', '01363', '0431237', '北海道', 'ホッカイドウ', '檜山郡厚沢部町', 'ヒヤマグンアッサブチョウ', '鶉町', 'ウズラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道檜山郡厚沢部町鶉', '01', '01363', '0431238', '北海道', 'ホッカイドウ', '檜山郡厚沢部町', 'ヒヤマグンアッサブチョウ', '鶉', 'ウズラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市北区引佐町東久留女木', '22', '22135', '4312531', '静岡県', 'シズオカケン', '浜松市北区', 'ハママツシキタク', '引佐町東久留女木', 'イナサチョウヒガシクルメキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市北区引佐町西久留女木', '22', '22135', '4312532', '静岡県', 'シズオカケン', '浜松市北区', 'ハママツシキタク', '引佐町西久留女木', 'イナサチョウニシクルメキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市北区引佐町四方浄', '22', '22135', '4312533', '静岡県', 'シズオカケン', '浜松市北区', 'ハママツシキタク', '引佐町四方浄', 'イナサチョウシホウジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市北区引佐町別所', '22', '22135', '4312534', '静岡県', 'シズオカケン', '浜松市北区', 'ハママツシキタク', '引佐町別所', 'イナサチョウベッシヨ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市北区引佐町的場', '22', '22135', '4312535', '静岡県', 'シズオカケン', '浜松市北区', 'ハママツシキタク', '引佐町的場', 'イナサチョウマトバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市北区引佐町田沢', '22', '22135', '4312536', '静岡県', 'シズオカケン', '浜松市北区', 'ハママツシキタク', '引佐町田沢', 'イナサチョウタザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市北区引佐町渋川', '22', '22135', '4312537', '静岡県', 'シズオカケン', '浜松市北区', 'ハママツシキタク', '引佐町渋川', 'イナサチョウシブカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市東区豊町', '22', '22132', '4313101', '静岡県', 'シズオカケン', '浜松市東区', 'ハママツシヒガシク', '豊町', 'ユタカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市東区豊西町', '22', '22132', '4313102', '静岡県', 'シズオカケン', '浜松市東区', 'ハママツシヒガシク', '豊西町', 'トヨニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市東区常光町', '22', '22132', '4313103', '静岡県', 'シズオカケン', '浜松市東区', 'ハママツシヒガシク', '常光町', 'ジョウコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市東区貴平町', '22', '22132', '4313104', '静岡県', 'シズオカケン', '浜松市東区', 'ハママツシヒガシク', '貴平町', 'キヘイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市東区笠井新田町', '22', '22132', '4313105', '静岡県', 'シズオカケン', '浜松市東区', 'ハママツシヒガシク', '笠井新田町', 'カサイシンデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市東区笠井上町', '22', '22132', '4313106', '静岡県', 'シズオカケン', '浜松市東区', 'ハママツシヒガシク', '笠井上町', 'カサイカミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市東区笠井町', '22', '22132', '4313107', '静岡県', 'シズオカケン', '浜松市東区', 'ハママツシヒガシク', '笠井町', 'カサイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市東区恒武町', '22', '22132', '4313108', '静岡県', 'シズオカケン', '浜松市東区', 'ハママツシヒガシク', '恒武町', 'ツネタケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市東区中郡町', '22', '22132', '4313111', '静岡県', 'シズオカケン', '浜松市東区', 'ハママツシヒガシク', '中郡町', 'ナカゴオリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市東区大島町', '22', '22132', '4313112', '静岡県', 'シズオカケン', '浜松市東区', 'ハママツシヒガシク', '大島町', 'オオシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市東区大瀬町', '22', '22132', '4313113', '静岡県', 'シズオカケン', '浜松市東区', 'ハママツシヒガシク', '大瀬町', 'オオセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市東区積志町', '22', '22132', '4313114', '静岡県', 'シズオカケン', '浜松市東区', 'ハママツシヒガシク', '積志町', 'セキシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市東区西ケ崎町', '22', '22132', '4313115', '静岡県', 'シズオカケン', '浜松市東区', 'ハママツシヒガシク', '西ケ崎町', 'ニシガサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市東区有玉北町', '22', '22132', '4313121', '静岡県', 'シズオカケン', '浜松市東区', 'ハママツシヒガシク', '有玉北町', 'アリタマキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市東区有玉南町', '22', '22132', '4313122', '静岡県', 'シズオカケン', '浜松市東区', 'ハママツシヒガシク', '有玉南町', 'アリタマミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市東区有玉西町', '22', '22132', '4313123', '静岡県', 'シズオカケン', '浜松市東区', 'ハママツシヒガシク', '有玉西町', 'アリタマニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市東区半田町', '22', '22132', '4313124', '静岡県', 'シズオカケン', '浜松市東区', 'ハママツシヒガシク', '半田町', 'ハンダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市東区半田山', '22', '22132', '4313125', '静岡県', 'シズオカケン', '浜松市東区', 'ハママツシヒガシク', '半田山', 'ハンダヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市東区有玉台', '22', '22132', '4313126', '静岡県', 'シズオカケン', '浜松市東区', 'ハママツシヒガシク', '有玉台', 'アリタマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市天竜区横川', '22', '22137', '4313301', '静岡県', 'シズオカケン', '浜松市天竜区', 'ハママツシテンリュウク', '横川', 'ヨコカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市天竜区只来', '22', '22137', '4313302', '静岡県', 'シズオカケン', '浜松市天竜区', 'ハママツシテンリュウク', '只来', 'タダライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市天竜区山東', '22', '22137', '4313303', '静岡県', 'シズオカケン', '浜松市天竜区', 'ハママツシテンリュウク', '山東', 'ヤマヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市天竜区次郎八新田', '22', '22137', '4313304', '静岡県', 'シズオカケン', '浜松市天竜区', 'ハママツシテンリュウク', '次郎八新田', 'ジロウハチシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市天竜区大谷', '22', '22137', '4313305', '静岡県', 'シズオカケン', '浜松市天竜区', 'ハママツシテンリュウク', '大谷', 'オオヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市天竜区船明', '22', '22137', '4313306', '静岡県', 'シズオカケン', '浜松市天竜区', 'ハママツシテンリュウク', '船明', 'フナギラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市天竜区二俣町阿蔵', '22', '22137', '4313311', '静岡県', 'シズオカケン', '浜松市天竜区', 'ハママツシテンリュウク', '二俣町阿蔵', 'フタマタチョウアクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市天竜区二俣町南鹿島', '22', '22137', '4313312', '静岡県', 'シズオカケン', '浜松市天竜区', 'ハママツシテンリュウク', '二俣町南鹿島', 'フタマタチョウミナミカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市天竜区二俣町鹿島', '22', '22137', '4313313', '静岡県', 'シズオカケン', '浜松市天竜区', 'ハママツシテンリュウク', '二俣町鹿島', 'フタマタチョウカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市天竜区二俣町二俣', '22', '22137', '4313314', '静岡県', 'シズオカケン', '浜松市天竜区', 'ハママツシテンリュウク', '二俣町二俣', 'フタマタチョウフタマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市天竜区二俣町大園', '22', '22137', '4313315', '静岡県', 'シズオカケン', '浜松市天竜区', 'ハママツシテンリュウク', '二俣町大園', 'フタマタチョウオオソノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市天竜区日明', '22', '22137', '4313421', '静岡県', 'シズオカケン', '浜松市天竜区', 'ハママツシテンリュウク', '日明', 'ヒアリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市天竜区米沢', '22', '22137', '4313422', '静岡県', 'シズオカケン', '浜松市天竜区', 'ハママツシテンリュウク', '米沢', 'ミナザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市天竜区渡ケ島', '22', '22137', '4313423', '静岡県', 'シズオカケン', '浜松市天竜区', 'ハママツシテンリュウク', '渡ケ島', 'ワタガシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市天竜区緑恵台', '22', '22137', '4313424', '静岡県', 'シズオカケン', '浜松市天竜区', 'ハママツシテンリュウク', '緑恵台', 'リョクケイダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市天竜区青谷', '22', '22137', '4313425', '静岡県', 'シズオカケン', '浜松市天竜区', 'ハママツシテンリュウク', '青谷', 'アオヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市天竜区両島', '22', '22137', '4313426', '静岡県', 'シズオカケン', '浜松市天竜区', 'ハママツシテンリュウク', '両島', 'リョウシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市天竜区上野', '22', '22137', '4313427', '静岡県', 'シズオカケン', '浜松市天竜区', 'ハママツシテンリュウク', '上野', 'カミノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市天竜区石神', '22', '22137', '4313428', '静岡県', 'シズオカケン', '浜松市天竜区', 'ハママツシテンリュウク', '石神', 'イシガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道檜山郡厚沢部町館町', '01', '01363', '0431351', '北海道', 'ホッカイドウ', '檜山郡厚沢部町', 'ヒヤマグンアッサブチョウ', '館町', 'タテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市天竜区東藤平', '22', '22137', '4313531', '静岡県', 'シズオカケン', '浜松市天竜区', 'ハママツシテンリュウク', '東藤平', 'ヒガシフジダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市天竜区西藤平', '22', '22137', '4313532', '静岡県', 'シズオカケン', '浜松市天竜区', 'ハママツシテンリュウク', '西藤平', 'ニシフジダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市天竜区長沢', '22', '22137', '4313533', '静岡県', 'シズオカケン', '浜松市天竜区', 'ハママツシテンリュウク', '長沢', 'ナガサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市天竜区懐山', '22', '22137', '4313534', '静岡県', 'シズオカケン', '浜松市天竜区', 'ハママツシテンリュウク', '懐山', 'フトコロヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市天竜区芦窪', '22', '22137', '4313535', '静岡県', 'シズオカケン', '浜松市天竜区', 'ハママツシテンリュウク', '芦窪', 'アシクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市天竜区阿寺', '22', '22137', '4313536', '静岡県', 'シズオカケン', '浜松市天竜区', 'ハママツシテンリュウク', '阿寺', 'アテラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道檜山郡厚沢部町社の山中の沢', '01', '01363', '0431361', '北海道', 'ホッカイドウ', '檜山郡厚沢部町', 'ヒヤマグンアッサブチョウ', '社の山', 'シャノヤマ', null, null, '中の沢', 'ナカノサワ');
INSERT INTO `ms_addresses` VALUES ('40065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道檜山郡厚沢部町須賀', '01', '01363', '0431362', '北海道', 'ホッカイドウ', '檜山郡厚沢部町', 'ヒヤマグンアッサブチョウ', '須賀', 'スガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道檜山郡厚沢部町富里', '01', '01363', '0431363', '北海道', 'ホッカイドウ', '檜山郡厚沢部町', 'ヒヤマグンアッサブチョウ', '富里', 'トミサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道檜山郡厚沢部町城丘', '01', '01363', '0431364', '北海道', 'ホッカイドウ', '檜山郡厚沢部町', 'ヒヤマグンアッサブチョウ', '城丘', 'シロオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市天竜区熊', '22', '22137', '4313641', '静岡県', 'シズオカケン', '浜松市天竜区', 'ハママツシテンリュウク', '熊', 'クマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市天竜区大栗安', '22', '22137', '4313642', '静岡県', 'シズオカケン', '浜松市天竜区', 'ハママツシテンリュウク', '大栗安', 'オオグリヤス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市天竜区神沢', '22', '22137', '4313643', '静岡県', 'シズオカケン', '浜松市天竜区', 'ハママツシテンリュウク', '神沢', 'カンザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道檜山郡厚沢部町南館町', '01', '01363', '0431365', '北海道', 'ホッカイドウ', '檜山郡厚沢部町', 'ヒヤマグンアッサブチョウ', '南館町', 'ミナミタテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道檜山郡厚沢部町当路', '01', '01363', '0431366', '北海道', 'ホッカイドウ', '檜山郡厚沢部町', 'ヒヤマグンアッサブチョウ', '当路', 'トウロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道檜山郡厚沢部町新栄', '01', '01363', '0431367', '北海道', 'ホッカイドウ', '檜山郡厚沢部町', 'ヒヤマグンアッサブチョウ', '新栄', 'シンエイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道檜山郡厚沢部町中館', '01', '01363', '0431368', '北海道', 'ホッカイドウ', '檜山郡厚沢部町', 'ヒヤマグンアッサブチョウ', '中館', 'ナカタテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市天竜区東雲名', '22', '22137', '4313751', '静岡県', 'シズオカケン', '浜松市天竜区', 'ハママツシテンリュウク', '東雲名', 'ヒガシウンナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市天竜区小川', '22', '22137', '4313752', '静岡県', 'シズオカケン', '浜松市天竜区', 'ハママツシテンリュウク', '小川', 'オガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市天竜区佐久', '22', '22137', '4313753', '静岡県', 'シズオカケン', '浜松市天竜区', 'ハママツシテンリュウク', '佐久', 'サク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市天竜区相津', '22', '22137', '4313754', '静岡県', 'シズオカケン', '浜松市天竜区', 'ハママツシテンリュウク', '相津', 'ソウヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市天竜区大川', '22', '22137', '4313755', '静岡県', 'シズオカケン', '浜松市天竜区', 'ハママツシテンリュウク', '大川', 'オオカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市天竜区谷山', '22', '22137', '4313756', '静岡県', 'シズオカケン', '浜松市天竜区', 'ハママツシテンリュウク', '谷山', 'ヤヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市天竜区西雲名', '22', '22137', '4313761', '静岡県', 'シズオカケン', '浜松市天竜区', 'ハママツシテンリュウク', '西雲名', 'ニシウンナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市天竜区伊砂', '22', '22137', '4313762', '静岡県', 'シズオカケン', '浜松市天竜区', 'ハママツシテンリュウク', '伊砂', 'イスカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市天竜区月', '22', '22137', '4313763', '静岡県', 'シズオカケン', '浜松市天竜区', 'ハママツシテンリュウク', '月', 'ツキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市天竜区横山町', '22', '22137', '4313764', '静岡県', 'シズオカケン', '浜松市天竜区', 'ハママツシテンリュウク', '横山町', 'ヨコヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市天竜区龍山町瀬尻', '22', '22137', '4313801', '静岡県', 'シズオカケン', '浜松市天竜区', 'ハママツシテンリュウク', '龍山町瀬尻', 'タツヤマチョウセジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市天竜区龍山町下平山', '22', '22137', '4313802', '静岡県', 'シズオカケン', '浜松市天竜区', 'ハママツシテンリュウク', '龍山町下平山', 'タツヤマチョウシモヒラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市天竜区龍山町戸倉', '22', '22137', '4313803', '静岡県', 'シズオカケン', '浜松市天竜区', 'ハママツシテンリュウク', '龍山町戸倉', 'タツヤマチョウトクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市天竜区龍山町大嶺', '22', '22137', '4313804', '静岡県', 'シズオカケン', '浜松市天竜区', 'ハママツシテンリュウク', '龍山町大嶺', 'タツヤマチョウオオミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市天竜区佐久間町佐久間', '22', '22137', '4313901', '静岡県', 'シズオカケン', '浜松市天竜区', 'ハママツシテンリュウク', '佐久間町佐久間', 'サクマチョウサクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市天竜区佐久間町大井', '22', '22137', '4313902', '静岡県', 'シズオカケン', '浜松市天竜区', 'ハママツシテンリュウク', '佐久間町大井', 'サクマチョウオオイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市天竜区佐久間町上平山', '22', '22137', '4313903', '静岡県', 'シズオカケン', '浜松市天竜区', 'ハママツシテンリュウク', '佐久間町上平山', 'サクマチョウカミヒラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市天竜区佐久間町戸口', '22', '22137', '4313904', '静岡県', 'シズオカケン', '浜松市天竜区', 'ハママツシテンリュウク', '佐久間町戸口', 'サクマチョウトグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市天竜区佐久間町半場', '22', '22137', '4313905', '静岡県', 'シズオカケン', '浜松市天竜区', 'ハママツシテンリュウク', '佐久間町半場', 'サクマチョウハンバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市天竜区佐久間町浦川', '22', '22137', '4313906', '静岡県', 'シズオカケン', '浜松市天竜区', 'ハママツシテンリュウク', '佐久間町浦川', 'サクマチョウウラカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市天竜区佐久間町川合', '22', '22137', '4313907', '静岡県', 'シズオカケン', '浜松市天竜区', 'ハママツシテンリュウク', '佐久間町川合', 'サクマチョウカワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市天竜区佐久間町中部', '22', '22137', '4313908', '静岡県', 'シズオカケン', '浜松市天竜区', 'ハママツシテンリュウク', '佐久間町中部', 'サクマチョウナカベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道奥尻郡奥尻町', '01', '01367', '0431400', '北海道', 'ホッカイドウ', '奥尻郡奥尻町', 'オクシリグンオクシリチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('40098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道奥尻郡奥尻町奥尻', '01', '01367', '0431401', '北海道', 'ホッカイドウ', '奥尻郡奥尻町', 'オクシリグンオクシリチョウ', '奥尻', 'オクシリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道奥尻郡奥尻町赤石', '01', '01367', '0431402', '北海道', 'ホッカイドウ', '奥尻郡奥尻町', 'オクシリグンオクシリチョウ', '赤石', 'アカイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道奥尻郡奥尻町球浦', '01', '01367', '0431403', '北海道', 'ホッカイドウ', '奥尻郡奥尻町', 'オクシリグンオクシリチョウ', '球浦', 'タマウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道奥尻郡奥尻町宮津', '01', '01367', '0431404', '北海道', 'ホッカイドウ', '奥尻郡奥尻町', 'オクシリグンオクシリチョウ', '宮津', 'ミヤツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道奥尻郡奥尻町稲穂', '01', '01367', '0431405', '北海道', 'ホッカイドウ', '奥尻郡奥尻町', 'オクシリグンオクシリチョウ', '稲穂', 'イナホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道奥尻郡奥尻町湯浜', '01', '01367', '0431406', '北海道', 'ホッカイドウ', '奥尻郡奥尻町', 'オクシリグンオクシリチョウ', '湯浜', 'ユノハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市天竜区水窪町奥領家', '22', '22137', '4314101', '静岡県', 'シズオカケン', '浜松市天竜区', 'ハママツシテンリュウク', '水窪町奥領家', 'ミサクボチョウオクリョウケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市天竜区水窪町地頭方', '22', '22137', '4314102', '静岡県', 'シズオカケン', '浜松市天竜区', 'ハママツシテンリュウク', '水窪町地頭方', 'ミサクボチョウジトウガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市天竜区水窪町山住', '22', '22137', '4314103', '静岡県', 'シズオカケン', '浜松市天竜区', 'ハママツシテンリュウク', '水窪町山住', 'ミサクボチョウヤマズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市天竜区佐久間町相月', '22', '22137', '4314111', '静岡県', 'シズオカケン', '浜松市天竜区', 'ハママツシテンリュウク', '佐久間町相月', 'サクマチョウアイヅキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市天竜区佐久間町奥領家', '22', '22137', '4314112', '静岡県', 'シズオカケン', '浜松市天竜区', 'ハママツシテンリュウク', '佐久間町奥領家', 'サクマチョウオクリョウケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県北設楽郡豊根村富山', '23', '23563', '4314121', '愛知県', 'アイチケン', '北設楽郡豊根村', 'キタシタラグントヨネムラ', '富山', 'トミヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道奥尻郡奥尻町青苗', '01', '01367', '0431521', '北海道', 'ホッカイドウ', '奥尻郡奥尻町', 'オクシリグンオクシリチョウ', '青苗', 'アオナエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道奥尻郡奥尻町富里', '01', '01367', '0431522', '北海道', 'ホッカイドウ', '奥尻郡奥尻町', 'オクシリグンオクシリチョウ', '富里', 'トミサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道奥尻郡奥尻町松江', '01', '01367', '0431523', '北海道', 'ホッカイドウ', '奥尻郡奥尻町', 'オクシリグンオクシリチョウ', '松江', 'マツエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道奥尻郡奥尻町米岡', '01', '01367', '0431524', '北海道', 'ホッカイドウ', '奥尻郡奥尻町', 'オクシリグンオクシリチョウ', '米岡', 'ヨネオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道奥尻郡奥尻町湯浜神威脇', '01', '01367', '0431525', '北海道', 'ホッカイドウ', '奥尻郡奥尻町', 'オクシリグンオクシリチョウ', '湯浜', 'ユノハマ', null, null, '神威脇', 'カムイワキ');
INSERT INTO `ms_addresses` VALUES ('40117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道奥尻郡奥尻町湯浜幌内', '01', '01367', '0431525', '北海道', 'ホッカイドウ', '奥尻郡奥尻町', 'オクシリグンオクシリチョウ', '湯浜', 'ユノハマ', null, null, '幌内', 'ホロナイ');
INSERT INTO `ms_addresses` VALUES ('40118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区', '22', '22131', '4320000', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('40119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市東区', '22', '22132', '4320000', '静岡県', 'シズオカケン', '浜松市東区', 'ハママツシヒガシク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('40120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市西区', '22', '22133', '4320000', '静岡県', 'シズオカケン', '浜松市西区', 'ハママツシニシク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('40121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市南区', '22', '22134', '4320000', '静岡県', 'シズオカケン', '浜松市南区', 'ハママツシミナミク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('40122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市北区', '22', '22135', '4320000', '静岡県', 'シズオカケン', '浜松市北区', 'ハママツシキタク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('40123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市天竜区', '22', '22137', '4320000', '静岡県', 'シズオカケン', '浜松市天竜区', 'ハママツシテンリュウク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('40124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市西区西山町', '22', '22133', '4328001', '静岡県', 'シズオカケン', '浜松市西区', 'ハママツシニシク', '西山町', 'ニシヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区富塚町', '22', '22131', '4328002', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '富塚町', 'トミツカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区和地山', '22', '22131', '4328003', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '和地山', 'ワジヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区文丘町', '22', '22131', '4328004', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '文丘町', 'フミオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市西区神ケ谷町', '22', '22133', '4328005', '静岡県', 'シズオカケン', '浜松市西区', 'ハママツシニシク', '神ケ谷町', 'カミガヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市西区大久保町', '22', '22133', '4328006', '静岡県', 'シズオカケン', '浜松市西区', 'ハママツシニシク', '大久保町', 'オオクボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市西区神原町', '22', '22133', '4328007', '静岡県', 'シズオカケン', '浜松市西区', 'ハママツシニシク', '神原町', 'カミハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区城北', '22', '22131', '4328011', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '城北', 'ジョウホク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区布橋', '22', '22131', '4328012', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '布橋', 'ヌノハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区広沢', '22', '22131', '4328013', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '広沢', 'ヒロサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区鹿谷町', '22', '22131', '4328014', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '鹿谷町', 'シカタニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区高町', '22', '22131', '4328015', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '高町', 'タカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区中山町', '22', '22131', '4328016', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '中山町', 'ナカヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区三組町', '22', '22131', '4328017', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '三組町', 'ミクミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区蜆塚', '22', '22131', '4328018', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '蜆塚', 'シジミヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区佐鳴台', '22', '22131', '4328021', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '佐鳴台', 'サナルダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区山手町', '22', '22131', '4328022', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '山手町', 'ヤマテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区鴨江', '22', '22131', '4328023', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '鴨江', 'カモエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区鴨江町', '22', '22131', '4328024', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '鴨江町', 'カモエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区栄町', '22', '22131', '4328025', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区元魚町', '22', '22131', '4328026', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '元魚町', 'モトウオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区旅籠町', '22', '22131', '4328027', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '旅籠町', 'ハタゴマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区平田町', '22', '22131', '4328031', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '平田町', 'ナメダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区海老塚町', '22', '22131', '4328032', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '海老塚町', 'エビツカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区海老塚', '22', '22131', '4328033', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '海老塚', 'エビツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区塩町', '22', '22131', '4328034', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '塩町', 'シオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区成子町', '22', '22131', '4328035', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '成子町', 'ナルコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区東伊場', '22', '22131', '4328036', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '東伊場', 'ヒガシイバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区南伊場町', '22', '22131', '4328037', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '南伊場町', 'ミナミイバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区西伊場町', '22', '22131', '4328038', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '西伊場町', 'ニシイバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区菅原町', '22', '22131', '4328041', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '菅原町', 'スガワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区上浅田', '22', '22131', '4328042', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '上浅田', 'カミアサダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区浅田町', '22', '22131', '4328043', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '浅田町', 'アサダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区南浅田', '22', '22131', '4328044', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '南浅田', 'ミナミアサダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区西浅田', '22', '22131', '4328045', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '西浅田', 'ニシアサダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区春日町', '22', '22131', '4328046', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '春日町', 'カスガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区神田町', '22', '22131', '4328047', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '神田町', 'カミダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区森田町', '22', '22131', '4328048', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '森田町', 'モリタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市南区若林町', '22', '22134', '4328051', '静岡県', 'シズオカケン', '浜松市南区', 'ハママツシミナミク', '若林町', 'ワカバヤシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市南区東若林町', '22', '22134', '4328052', '静岡県', 'シズオカケン', '浜松市南区', 'ハママツシミナミク', '東若林町', 'ヒガシワカバヤシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区法枝町', '22', '22131', '4328053', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '法枝町', 'ノリエダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市南区法枝町', '22', '22134', '4328053', '静岡県', 'シズオカケン', '浜松市南区', 'ハママツシミナミク', '法枝町', 'ノリエダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市南区田尻町', '22', '22134', '4328054', '静岡県', 'シズオカケン', '浜松市南区', 'ハママツシミナミク', '田尻町', 'タジリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市南区卸本町', '22', '22134', '4328055', '静岡県', 'シズオカケン', '浜松市南区', 'ハママツシミナミク', '卸本町', 'オロシホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市南区米津町', '22', '22134', '4328056', '静岡県', 'シズオカケン', '浜松市南区', 'ハママツシミナミク', '米津町', 'ヨネヅチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市南区堤町', '22', '22134', '4328057', '静岡県', 'シズオカケン', '浜松市南区', 'ハママツシミナミク', '堤町', 'ツツミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市南区新橋町', '22', '22134', '4328058', '静岡県', 'シズオカケン', '浜松市南区', 'ハママツシミナミク', '新橋町', 'ニッパシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市西区入野町', '22', '22133', '4328061', '静岡県', 'シズオカケン', '浜松市西区', 'ハママツシニシク', '入野町', 'イリノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市南区増楽町', '22', '22134', '4328062', '静岡県', 'シズオカケン', '浜松市南区', 'ハママツシミナミク', '増楽町', 'ゾウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市南区小沢渡町', '22', '22134', '4328063', '静岡県', 'シズオカケン', '浜松市南区', 'ハママツシミナミク', '小沢渡町', 'コザワタリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市南区倉松町', '22', '22134', '4328064', '静岡県', 'シズオカケン', '浜松市南区', 'ハママツシミナミク', '倉松町', 'クラマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市南区高塚町', '22', '22134', '4328065', '静岡県', 'シズオカケン', '浜松市南区', 'ハママツシミナミク', '高塚町', 'タカツカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市西区志都呂町', '22', '22133', '4328066', '静岡県', 'シズオカケン', '浜松市西区', 'ハママツシニシク', '志都呂町', 'シトロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市西区西鴨江町', '22', '22133', '4328067', '静岡県', 'シズオカケン', '浜松市西区', 'ハママツシニシク', '西鴨江町', 'ニシカモエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市西区大平台', '22', '22133', '4328068', '静岡県', 'シズオカケン', '浜松市西区', 'ハママツシニシク', '大平台', 'オオヒラダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市北区三幸町', '22', '22135', '4338101', '静岡県', 'シズオカケン', '浜松市北区', 'ハママツシキタク', '三幸町', 'ミユキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市北区大原町', '22', '22135', '4338102', '静岡県', 'シズオカケン', '浜松市北区', 'ハママツシキタク', '大原町', 'オオハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市北区豊岡町', '22', '22135', '4338103', '静岡県', 'シズオカケン', '浜松市北区', 'ハママツシキタク', '豊岡町', 'トヨオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市北区東三方町', '22', '22135', '4338104', '静岡県', 'シズオカケン', '浜松市北区', 'ハママツシキタク', '東三方町', 'ヒガシミカタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市北区三方原町', '22', '22135', '4338105', '静岡県', 'シズオカケン', '浜松市北区', 'ハママツシキタク', '三方原町', 'ミカタハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市北区根洗町', '22', '22135', '4338108', '静岡県', 'シズオカケン', '浜松市北区', 'ハママツシキタク', '根洗町', 'ネアライチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区花川町', '22', '22131', '4338109', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '花川町', 'ハナカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区葵西', '22', '22131', '4338111', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '葵西', 'アオイニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市北区初生町', '22', '22135', '4338112', '静岡県', 'シズオカケン', '浜松市北区', 'ハママツシキタク', '初生町', 'ハツオイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区小豆餅', '22', '22131', '4338113', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '小豆餅', 'アズキモチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区葵東', '22', '22131', '4338114', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '葵東', 'アオイヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区西丘町', '22', '22131', '4338116', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '西丘町', 'ニシオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区高丘東', '22', '22131', '4338117', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '高丘東', 'タカオカヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区高丘西', '22', '22131', '4338118', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '高丘西', 'タカオカニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区高丘北', '22', '22131', '4338119', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '高丘北', 'タカオカキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区萩丘', '22', '22131', '4338121', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '萩丘', 'ハギオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区上島', '22', '22131', '4338122', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '上島', 'カミジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区幸', '22', '22131', '4338123', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '幸', 'サイワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区泉', '22', '22131', '4338124', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '泉', 'イズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区和合町', '22', '22131', '4338125', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '和合町', 'ワゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区泉町', '22', '22131', '4338126', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '泉町', 'イズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市浜北区', '22', '22136', '4340000', '静岡県', 'シズオカケン', '浜松市浜北区', 'ハママツシハマキタク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('40236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市浜北区堀谷', '22', '22136', '4340001', '静岡県', 'シズオカケン', '浜松市浜北区', 'ハママツシハマキタク', '堀谷', 'ホリヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市浜北区尾野', '22', '22136', '4340002', '静岡県', 'シズオカケン', '浜松市浜北区', 'ハママツシハマキタク', '尾野', 'オノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市浜北区新原', '22', '22136', '4340003', '静岡県', 'シズオカケン', '浜松市浜北区', 'ハママツシハマキタク', '新原', 'シンパラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市浜北区宮口', '22', '22136', '4340004', '静岡県', 'シズオカケン', '浜松市浜北区', 'ハママツシハマキタク', '宮口', 'ミヤグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市浜北区大平', '22', '22136', '4340005', '静岡県', 'シズオカケン', '浜松市浜北区', 'ハママツシハマキタク', '大平', 'オイダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市浜北区四大地', '22', '22136', '4340006', '静岡県', 'シズオカケン', '浜松市浜北区', 'ハママツシハマキタク', '四大地', 'ヨンダイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市浜北区灰木', '22', '22136', '4340007', '静岡県', 'シズオカケン', '浜松市浜北区', 'ハママツシハマキタク', '灰木', 'ハイノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市浜北区上島', '22', '22136', '4340011', '静岡県', 'シズオカケン', '浜松市浜北区', 'ハママツシハマキタク', '上島', 'カミジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市浜北区中瀬', '22', '22136', '4340012', '静岡県', 'シズオカケン', '浜松市浜北区', 'ハママツシハマキタク', '中瀬', 'ナカゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市浜北区永島', '22', '22136', '4340013', '静岡県', 'シズオカケン', '浜松市浜北区', 'ハママツシハマキタク', '永島', 'ナガシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市浜北区本沢合', '22', '22136', '4340014', '静岡県', 'シズオカケン', '浜松市浜北区', 'ハママツシハマキタク', '本沢合', 'ホンザワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市浜北区於呂', '22', '22136', '4340015', '静岡県', 'シズオカケン', '浜松市浜北区', 'ハママツシハマキタク', '於呂', 'オロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市浜北区根堅', '22', '22136', '4340016', '静岡県', 'シズオカケン', '浜松市浜北区', 'ハママツシハマキタク', '根堅', 'ネガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市浜北区豊保', '22', '22136', '4340017', '静岡県', 'シズオカケン', '浜松市浜北区', 'ハママツシハマキタク', '豊保', 'トヨヤス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市浜北区八幡', '22', '22136', '4340021', '静岡県', 'シズオカケン', '浜松市浜北区', 'ハママツシハマキタク', '八幡', 'ヤワタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市浜北区新堀', '22', '22136', '4340022', '静岡県', 'シズオカケン', '浜松市浜北区', 'ハママツシハマキタク', '新堀', 'ニイボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市浜北区高薗', '22', '22136', '4340023', '静岡県', 'シズオカケン', '浜松市浜北区', 'ハママツシハマキタク', '高薗', 'タカソノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市浜北区竜南', '22', '22136', '4340024', '静岡県', 'シズオカケン', '浜松市浜北区', 'ハママツシハマキタク', '竜南', 'リュウナン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市浜北区善地', '22', '22136', '4340025', '静岡県', 'シズオカケン', '浜松市浜北区', 'ハママツシハマキタク', '善地', 'ゼンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市浜北区東美薗', '22', '22136', '4340026', '静岡県', 'シズオカケン', '浜松市浜北区', 'ハママツシハマキタク', '東美薗', 'ヒガシミソノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市浜北区油一色', '22', '22136', '4340027', '静岡県', 'シズオカケン', '浜松市浜北区', 'ハママツシハマキタク', '油一色', 'アブライシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市浜北区上善地', '22', '22136', '4340028', '静岡県', 'シズオカケン', '浜松市浜北区', 'ハママツシハマキタク', '上善地', 'カミゼンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市浜北区新野', '22', '22136', '4340029', '静岡県', 'シズオカケン', '浜松市浜北区', 'ハママツシハマキタク', '新野', 'ニイノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市浜北区小林', '22', '22136', '4340031', '静岡県', 'シズオカケン', '浜松市浜北区', 'ハママツシハマキタク', '小林', 'コバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市浜北区道本', '22', '22136', '4340032', '静岡県', 'シズオカケン', '浜松市浜北区', 'ハママツシハマキタク', '道本', 'ドウホン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市浜北区西美薗', '22', '22136', '4340033', '静岡県', 'シズオカケン', '浜松市浜北区', 'ハママツシハマキタク', '西美薗', 'ニシミソノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市浜北区高畑', '22', '22136', '4340034', '静岡県', 'シズオカケン', '浜松市浜北区', 'ハママツシハマキタク', '高畑', 'タカバタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市浜北区寺島', '22', '22136', '4340035', '静岡県', 'シズオカケン', '浜松市浜北区', 'ハママツシハマキタク', '寺島', 'テラジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市浜北区横須賀', '22', '22136', '4340036', '静岡県', 'シズオカケン', '浜松市浜北区', 'ハママツシハマキタク', '横須賀', 'ヨコスカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市浜北区沼', '22', '22136', '4340037', '静岡県', 'シズオカケン', '浜松市浜北区', 'ハママツシハマキタク', '沼', 'ヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市浜北区貴布祢', '22', '22136', '4340038', '静岡県', 'シズオカケン', '浜松市浜北区', 'ハママツシハマキタク', '貴布祢', 'キブネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市浜北区平口', '22', '22136', '4340041', '静岡県', 'シズオカケン', '浜松市浜北区', 'ハママツシハマキタク', '平口', 'ヒラクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市浜北区小松', '22', '22136', '4340042', '静岡県', 'シズオカケン', '浜松市浜北区', 'ハママツシハマキタク', '小松', 'コマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市浜北区中条', '22', '22136', '4340043', '静岡県', 'シズオカケン', '浜松市浜北区', 'ハママツシハマキタク', '中条', 'ナカジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市浜北区内野', '22', '22136', '4340044', '静岡県', 'シズオカケン', '浜松市浜北区', 'ハママツシハマキタク', '内野', 'ウチノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市浜北区内野台', '22', '22136', '4340045', '静岡県', 'シズオカケン', '浜松市浜北区', 'ハママツシハマキタク', '内野台', 'ウチノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市浜北区染地台', '22', '22136', '4340046', '静岡県', 'シズオカケン', '浜松市浜北区', 'ハママツシハマキタク', '染地台', 'ソメジダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市東区上石田町', '22', '22132', '4350001', '静岡県', 'シズオカケン', '浜松市東区', 'ハママツシヒガシク', '上石田町', 'カミイシダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市東区白鳥町', '22', '22132', '4350002', '静岡県', 'シズオカケン', '浜松市東区', 'ハママツシヒガシク', '白鳥町', 'シロトリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市東区中里町', '22', '22132', '4350003', '静岡県', 'シズオカケン', '浜松市東区', 'ハママツシヒガシク', '中里町', 'ナカサトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市東区中野町', '22', '22132', '4350004', '静岡県', 'シズオカケン', '浜松市東区', 'ハママツシヒガシク', '中野町', 'ナカノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市東区安新町', '22', '22132', '4350005', '静岡県', 'シズオカケン', '浜松市東区', 'ハママツシヒガシク', '安新町', 'アンシンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市東区下石田町', '22', '22132', '4350006', '静岡県', 'シズオカケン', '浜松市東区', 'ハママツシヒガシク', '下石田町', 'シモイシダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市東区流通元町', '22', '22132', '4350007', '静岡県', 'シズオカケン', '浜松市東区', 'ハママツシヒガシク', '流通元町', 'リュウツウモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市東区松小池町', '22', '22132', '4350008', '静岡県', 'シズオカケン', '浜松市東区', 'ハママツシヒガシク', '松小池町', 'マツコイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市東区国吉町', '22', '22132', '4350011', '静岡県', 'シズオカケン', '浜松市東区', 'ハママツシヒガシク', '国吉町', 'クニヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市東区安間町', '22', '22132', '4350012', '静岡県', 'シズオカケン', '浜松市東区', 'ハママツシヒガシク', '安間町', 'アンマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市東区天龍川町', '22', '22132', '4350013', '静岡県', 'シズオカケン', '浜松市東区', 'ハママツシヒガシク', '天龍川町', 'テンリュウガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市東区大蒲町', '22', '22132', '4350014', '静岡県', 'シズオカケン', '浜松市東区', 'ハママツシヒガシク', '大蒲町', 'オオカバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市東区子安町', '22', '22132', '4350015', '静岡県', 'シズオカケン', '浜松市東区', 'ハママツシヒガシク', '子安町', 'コヤスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市東区和田町', '22', '22132', '4350016', '静岡県', 'シズオカケン', '浜松市東区', 'ハママツシヒガシク', '和田町', 'ワダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市東区薬師町', '22', '22132', '4350017', '静岡県', 'シズオカケン', '浜松市東区', 'ハママツシヒガシク', '薬師町', 'ヤクシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市東区薬新町', '22', '22132', '4350018', '静岡県', 'シズオカケン', '浜松市東区', 'ハママツシヒガシク', '薬新町', 'ヤクシンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市東区材木町', '22', '22132', '4350021', '静岡県', 'シズオカケン', '浜松市東区', 'ハママツシヒガシク', '材木町', 'ザイモクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市南区鶴見町', '22', '22134', '4350022', '静岡県', 'シズオカケン', '浜松市南区', 'ハママツシミナミク', '鶴見町', 'ツルミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市南区新貝町', '22', '22134', '4350023', '静岡県', 'シズオカケン', '浜松市南区', 'ハママツシミナミク', '新貝町', 'シンガイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市南区大塚町', '22', '22134', '4350024', '静岡県', 'シズオカケン', '浜松市南区', 'ハママツシミナミク', '大塚町', 'オオツカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市南区老間町', '22', '22134', '4350025', '静岡県', 'シズオカケン', '浜松市南区', 'ハママツシミナミク', '老間町', 'オイマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市南区金折町', '22', '22134', '4350026', '静岡県', 'シズオカケン', '浜松市南区', 'ハママツシミナミク', '金折町', 'カナオリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市南区下飯田町', '22', '22134', '4350027', '静岡県', 'シズオカケン', '浜松市南区', 'ハママツシミナミク', '下飯田町', 'シモイイダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市南区飯田町', '22', '22134', '4350028', '静岡県', 'シズオカケン', '浜松市南区', 'ハママツシミナミク', '飯田町', 'イイダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市東区龍光町', '22', '22132', '4350029', '静岡県', 'シズオカケン', '浜松市東区', 'ハママツシヒガシク', '龍光町', 'リュウコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市東区長鶴町', '22', '22132', '4350031', '静岡県', 'シズオカケン', '浜松市東区', 'ハママツシヒガシク', '長鶴町', 'ナガツルチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市南区古川町', '22', '22134', '4350032', '静岡県', 'シズオカケン', '浜松市南区', 'ハママツシミナミク', '古川町', 'フルカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市南区石原町', '22', '22134', '4350033', '静岡県', 'シズオカケン', '浜松市南区', 'ハママツシミナミク', '石原町', 'イシハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市南区安松町', '22', '22134', '4350034', '静岡県', 'シズオカケン', '浜松市南区', 'ハママツシミナミク', '安松町', 'ヤスマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市南区西伝寺町', '22', '22134', '4350035', '静岡県', 'シズオカケン', '浜松市南区', 'ハママツシミナミク', '西伝寺町', 'セイデンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市南区渡瀬町', '22', '22134', '4350036', '静岡県', 'シズオカケン', '浜松市南区', 'ハママツシミナミク', '渡瀬町', 'ワタセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市南区青屋町', '22', '22134', '4350037', '静岡県', 'シズオカケン', '浜松市南区', 'ハママツシミナミク', '青屋町', 'アオヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市南区三和町', '22', '22134', '4350038', '静岡県', 'シズオカケン', '浜松市南区', 'ハママツシミナミク', '三和町', 'サンワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市東区北島町', '22', '22132', '4350041', '静岡県', 'シズオカケン', '浜松市東区', 'ハママツシヒガシク', '北島町', 'キタジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市東区篠ケ瀬町', '22', '22132', '4350042', '静岡県', 'シズオカケン', '浜松市東区', 'ハママツシヒガシク', '篠ケ瀬町', 'ササガセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市東区宮竹町', '22', '22132', '4350043', '静岡県', 'シズオカケン', '浜松市東区', 'ハママツシヒガシク', '宮竹町', 'ミヤタケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市東区西塚町', '22', '22132', '4350044', '静岡県', 'シズオカケン', '浜松市東区', 'ハママツシヒガシク', '西塚町', 'ニシヅカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区細島町', '22', '22131', '4350045', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '細島町', 'ホソジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市東区丸塚町', '22', '22132', '4350046', '静岡県', 'シズオカケン', '浜松市東区', 'ハママツシヒガシク', '丸塚町', 'マルヅカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市東区原島町', '22', '22132', '4350047', '静岡県', 'シズオカケン', '浜松市東区', 'ハママツシヒガシク', '原島町', 'バラジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市東区上西町', '22', '22132', '4350048', '静岡県', 'シズオカケン', '浜松市東区', 'ハママツシヒガシク', '上西町', 'カミニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市東区市野町', '22', '22132', '4350051', '静岡県', 'シズオカケン', '浜松市東区', 'ハママツシヒガシク', '市野町', 'イチノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市東区天王町', '22', '22132', '4350052', '静岡県', 'シズオカケン', '浜松市東区', 'ハママツシヒガシク', '天王町', 'テンノウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市東区上新屋町', '22', '22132', '4350053', '静岡県', 'シズオカケン', '浜松市東区', 'ハママツシヒガシク', '上新屋町', 'カミアラヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区早出町', '22', '22131', '4350054', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '早出町', 'ソウデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市中区十軒町', '22', '22131', '4350055', '静岡県', 'シズオカケン', '浜松市中区', 'ハママツシナカク', '十軒町', 'ジッケンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市東区小池町', '22', '22132', '4350056', '静岡県', 'シズオカケン', '浜松市東区', 'ハママツシヒガシク', '小池町', 'コイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市東区中田町', '22', '22132', '4350057', '静岡県', 'シズオカケン', '浜松市東区', 'ハママツシヒガシク', '中田町', 'ナカダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市', '22', '22213', '4360000', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('40354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市東山', '22', '22213', '4360001', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '東山', 'ヒガシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市佐夜鹿', '22', '22213', '4360002', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '佐夜鹿', 'サヨシカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市日坂', '22', '22213', '4360003', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '日坂', 'ニッサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市八坂', '22', '22213', '4360004', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '八坂', 'ヤサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市伊達方', '22', '22213', '4360005', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '伊達方', 'ダテガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市本所', '22', '22213', '4360006', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '本所', 'ホンジョ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市小原子', '22', '22213', '4360007', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '小原子', 'コバラコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市千羽', '22', '22213', '4360008', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '千羽', 'センバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市大野', '22', '22213', '4360009', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '大野', 'オオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市満水', '22', '22213', '4360011', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '満水', 'タマリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市上内田', '22', '22213', '4360012', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '上内田', 'カミウチダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市子隣', '22', '22213', '4360013', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '子隣', 'コトナリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市岩井寺', '22', '22213', '4360014', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '岩井寺', 'ガンショウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市和田', '22', '22213', '4360015', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '和田', 'ワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市板沢', '22', '22213', '4360016', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '板沢', 'イタサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市杉谷', '22', '22213', '4360017', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '杉谷', 'スギヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市葵町', '22', '22213', '4360018', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '葵町', 'アオイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市青葉台', '22', '22213', '4360019', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '青葉台', 'アオバダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市矢崎町', '22', '22213', '4360020', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '矢崎町', 'ヤサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市緑ケ丘', '22', '22213', '4360021', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '緑ケ丘', 'ミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市上張', '22', '22213', '4360022', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '上張', 'アゲハリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市結縁寺', '22', '22213', '4360023', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '結縁寺', 'ケツエンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市南西郷', '22', '22213', '4360024', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '南西郷', 'ミナミサイゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市下俣', '22', '22213', '4360025', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '下俣', 'シモマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市下俣南', '22', '22213', '4360026', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '下俣南', 'シモマタミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市久保', '22', '22213', '4360027', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '久保', 'クボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市亀の甲', '22', '22213', '4360028', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '亀の甲', 'カメノコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市南', '22', '22213', '4360029', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '南', 'ミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市杉谷南', '22', '22213', '4360030', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '杉谷南', 'スギヤミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市高御所', '22', '22213', '4360031', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '高御所', 'コウゴショ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市平野', '22', '22213', '4360032', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '平野', 'ヒラノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市篠場', '22', '22213', '4360033', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '篠場', 'シノンバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市梅橋', '22', '22213', '4360034', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '梅橋', 'ウメバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市徳泉', '22', '22213', '4360035', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '徳泉', 'トクイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市原川', '22', '22213', '4360036', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '原川', 'ハラガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市岡津', '22', '22213', '4360037', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '岡津', 'オカツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市領家', '22', '22213', '4360038', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '領家', 'リョウケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市沢田', '22', '22213', '4360039', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '沢田', 'サワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市秋葉路', '22', '22213', '4360041', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '秋葉路', 'アキハミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市二瀬川', '22', '22213', '4360042', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '二瀬川', 'フタセガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市大池', '22', '22213', '4360043', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '大池', 'オオイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市清崎', '22', '22213', '4360044', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '清崎', 'キヨサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市小鷹町', '22', '22213', '4360045', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '小鷹町', 'オダカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市中央高町', '22', '22213', '4360046', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '中央高町', 'チュウオウタカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市長谷', '22', '22213', '4360047', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '長谷', 'ナガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市細田', '22', '22213', '4360048', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '細田', 'サイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市上屋敷', '22', '22213', '4360049', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '上屋敷', 'カミヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市中宿', '22', '22213', '4360051', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '中宿', 'ナカジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市柳町', '22', '22213', '4360052', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '柳町', 'ヤナギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市弥生町', '22', '22213', '4360053', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '弥生町', 'ヤヨイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市城西', '22', '22213', '4360054', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '城西', 'シロニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市紺屋町', '22', '22213', '4360055', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '紺屋町', 'コウヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市中央', '22', '22213', '4360056', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市十九首', '22', '22213', '4360057', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '十九首', 'ジュウクシュ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市七日町', '22', '22213', '4360058', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '七日町', 'ナノカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市城北', '22', '22213', '4360059', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '城北', 'ジョウホク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市水垂', '22', '22213', '4360061', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '水垂', 'ミズタリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市旭ケ丘', '22', '22213', '4360062', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '旭ケ丘', 'アサヒガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市北池新田', '22', '22213', '4360063', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '北池新田', 'キタイケシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市北門', '22', '22213', '4360064', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '北門', 'キタモン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市天王町', '22', '22213', '4360065', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '天王町', 'テンノウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市谷の口町', '22', '22213', '4360066', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '谷の口町', 'ヤノクチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市下西郷', '22', '22213', '4360067', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '下西郷', 'シモサイゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市御所原', '22', '22213', '4360068', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '御所原', 'ゴショバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市旭台', '22', '22213', '4360069', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '旭台', 'アサヒダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市仁藤', '22', '22213', '4360071', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '仁藤', 'ニトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市印内', '22', '22213', '4360072', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '印内', 'インナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市金城', '22', '22213', '4360073', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '金城', 'カネシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市葛川', '22', '22213', '4360074', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '葛川', 'クズカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市仁藤町', '22', '22213', '4360075', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '仁藤町', 'ニトウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市塩町', '22', '22213', '4360076', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '塩町', 'シオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市駅前', '22', '22213', '4360077', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '駅前', 'エキマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市肴町', '22', '22213', '4360078', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '肴町', 'サカナマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市掛川', '22', '22213', '4360079', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '掛川', 'カケガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市初馬', '22', '22213', '4360081', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '初馬', 'ハツマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市淡陽', '22', '22213', '4360082', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '淡陽', 'タンヨウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市薗ケ谷', '22', '22213', '4360083', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '薗ケ谷', 'ソノガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市逆川', '22', '22213', '4360084', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '逆川', 'サカガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市成滝', '22', '22213', '4360085', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '成滝', 'ナルタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市宮脇', '22', '22213', '4360086', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '宮脇', 'ミヤワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市大多郎', '22', '22213', '4360087', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '大多郎', 'オオタロウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市葛ケ丘', '22', '22213', '4360088', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '葛ケ丘', 'カツラガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市安養寺', '22', '22213', '4360089', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '安養寺', 'アンヨウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市光陽', '22', '22213', '4360090', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '光陽', 'コウヨウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市城下', '22', '22213', '4360091', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '城下', 'シロシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市中町', '22', '22213', '4360092', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '中町', 'ナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市連雀', '22', '22213', '4360093', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '連雀', 'レンジャク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市喜町', '22', '22213', '4360094', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '喜町', 'キマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市上西之谷', '22', '22213', '4360101', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '上西之谷', 'カミニシノヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市中西之谷', '22', '22213', '4360102', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '中西之谷', 'ナカニシノヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市久居島', '22', '22213', '4360103', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '久居島', 'ヒサイジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市平島', '22', '22213', '4360104', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '平島', 'ヒラシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市原里', '22', '22213', '4360105', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '原里', 'ハラサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市寺島', '22', '22213', '4360106', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '寺島', 'テラシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市本郷', '22', '22213', '4360111', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '本郷', 'ホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市細谷', '22', '22213', '4360112', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '細谷', 'ホソヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市各和', '22', '22213', '4360113', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '各和', 'カクワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市高田', '22', '22213', '4360114', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '高田', 'タカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市吉岡', '22', '22213', '4360115', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '吉岡', 'ヨシオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市西山', '22', '22213', '4360116', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '西山', 'ニシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市幡鎌', '22', '22213', '4360117', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '幡鎌', 'ハタカマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市上垂木', '22', '22213', '4360221', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '上垂木', 'カミタルキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市下垂木', '22', '22213', '4360222', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '下垂木', 'シモタルキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市黒田', '22', '22213', '4360223', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '黒田', 'クロダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市富部', '22', '22213', '4360224', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '富部', 'トンベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市家代', '22', '22213', '4360225', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '家代', 'イエシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市遊家', '22', '22213', '4360226', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '遊家', 'ユケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市家代の里', '22', '22213', '4360227', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '家代の里', 'イエシロノサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市黒俣', '22', '22213', '4360331', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '黒俣', 'クロマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市居尻', '22', '22213', '4360332', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '居尻', 'イジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市丹間', '22', '22213', '4360333', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '丹間', 'タンマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市孕石', '22', '22213', '4360334', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '孕石', 'ハラミイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市大和田', '22', '22213', '4360335', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '大和田', 'オオワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市萩間', '22', '22213', '4360336', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '萩間', 'ハギマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市炭焼', '22', '22213', '4360337', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '炭焼', 'スミヤキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市和光', '22', '22213', '4360338', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '和光', 'ワコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市倉真', '22', '22213', '4360341', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '倉真', 'クラミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市上西郷', '22', '22213', '4360342', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '上西郷', 'カミサイゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市五明', '22', '22213', '4360343', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '五明', 'ゴミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県袋井市', '22', '22216', '4370000', '静岡県', 'シズオカケン', '袋井市', 'フクロイシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('40481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県袋井市山田', '22', '22216', '4370001', '静岡県', 'シズオカケン', '袋井市', 'フクロイシ', '山田', 'ヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県袋井市川会', '22', '22216', '4370002', '静岡県', 'シズオカケン', '袋井市', 'フクロイシ', '川会', 'カワエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県袋井市萱間', '22', '22216', '4370003', '静岡県', 'シズオカケン', '袋井市', 'フクロイシ', '萱間', 'カヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県袋井市友永', '22', '22216', '4370004', '静岡県', 'シズオカケン', '袋井市', 'フクロイシ', '友永', 'トモナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県袋井市見取', '22', '22216', '4370005', '静岡県', 'シズオカケン', '袋井市', 'フクロイシ', '見取', 'ミドリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県袋井市大谷', '22', '22216', '4370006', '静岡県', 'シズオカケン', '袋井市', 'フクロイシ', '大谷', 'オオヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県袋井市村松', '22', '22216', '4370011', '静岡県', 'シズオカケン', '袋井市', 'フクロイシ', '村松', 'ムラマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県袋井市国本', '22', '22216', '4370012', '静岡県', 'シズオカケン', '袋井市', 'フクロイシ', '国本', 'クニモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県袋井市新屋', '22', '22216', '4370013', '静岡県', 'シズオカケン', '袋井市', 'フクロイシ', '新屋', 'アラヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県袋井市永楽町', '22', '22216', '4370014', '静岡県', 'シズオカケン', '袋井市', 'フクロイシ', '永楽町', 'エイラクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県袋井市旭町', '22', '22216', '4370015', '静岡県', 'シズオカケン', '袋井市', 'フクロイシ', '旭町', 'アサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県袋井市葵町', '22', '22216', '4370016', '静岡県', 'シズオカケン', '袋井市', 'フクロイシ', '葵町', 'アオイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県袋井市鷲巣', '22', '22216', '4370017', '静岡県', 'シズオカケン', '袋井市', 'フクロイシ', '鷲巣', 'ワシズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県袋井市広岡', '22', '22216', '4370021', '静岡県', 'シズオカケン', '袋井市', 'フクロイシ', '広岡', 'ヒロオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県袋井市方丈', '22', '22216', '4370022', '静岡県', 'シズオカケン', '袋井市', 'フクロイシ', '方丈', 'ホウジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県袋井市高尾', '22', '22216', '4370023', '静岡県', 'シズオカケン', '袋井市', 'フクロイシ', '高尾', 'タカオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県袋井市三門町', '22', '22216', '4370024', '静岡県', 'シズオカケン', '袋井市', 'フクロイシ', '三門町', 'ミカドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県袋井市栄町', '22', '22216', '4370025', '静岡県', 'シズオカケン', '袋井市', 'フクロイシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県袋井市袋井', '22', '22216', '4370026', '静岡県', 'シズオカケン', '袋井市', 'フクロイシ', '袋井', 'フクロイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県袋井市高尾町', '22', '22216', '4370027', '静岡県', 'シズオカケン', '袋井市', 'フクロイシ', '高尾町', 'タカオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県袋井市神長', '22', '22216', '4370028', '静岡県', 'シズオカケン', '袋井市', 'フクロイシ', '神長', 'カミナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県袋井市愛野', '22', '22216', '4370031', '静岡県', 'シズオカケン', '袋井市', 'フクロイシ', '愛野', 'アイノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県袋井市豊沢', '22', '22216', '4370032', '静岡県', 'シズオカケン', '袋井市', 'フクロイシ', '豊沢', 'トヨサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県袋井市上田町', '22', '22216', '4370033', '静岡県', 'シズオカケン', '袋井市', 'フクロイシ', '上田町', 'ウエダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県袋井市青木町', '22', '22216', '4370034', '静岡県', 'シズオカケン', '袋井市', 'フクロイシ', '青木町', 'アオキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県袋井市砂本町', '22', '22216', '4370035', '静岡県', 'シズオカケン', '袋井市', 'フクロイシ', '砂本町', 'スナモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県袋井市小川町', '22', '22216', '4370036', '静岡県', 'シズオカケン', '袋井市', 'フクロイシ', '小川町', 'オガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県袋井市清水町', '22', '22216', '4370037', '静岡県', 'シズオカケン', '袋井市', 'フクロイシ', '清水町', 'シミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県袋井市大門', '22', '22216', '4370038', '静岡県', 'シズオカケン', '袋井市', 'フクロイシ', '大門', 'ダイモン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県袋井市愛野東', '22', '22216', '4370039', '静岡県', 'シズオカケン', '袋井市', 'フクロイシ', '愛野東', 'アイノヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県袋井市睦町', '22', '22216', '4370041', '静岡県', 'シズオカケン', '袋井市', 'フクロイシ', '睦町', 'ムツミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県袋井市山名町', '22', '22216', '4370042', '静岡県', 'シズオカケン', '袋井市', 'フクロイシ', '山名町', 'ヤマナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県袋井市新池', '22', '22216', '4370043', '静岡県', 'シズオカケン', '袋井市', 'フクロイシ', '新池', 'ニイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県袋井市松袋井', '22', '22216', '4370044', '静岡県', 'シズオカケン', '袋井市', 'フクロイシ', '松袋井', 'マツブクロイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県袋井市彦島', '22', '22216', '4370045', '静岡県', 'シズオカケン', '袋井市', 'フクロイシ', '彦島', 'ヒコジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県袋井市木原', '22', '22216', '4370046', '静岡県', 'シズオカケン', '袋井市', 'フクロイシ', '木原', 'キワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県袋井市西田', '22', '22216', '4370047', '静岡県', 'シズオカケン', '袋井市', 'フクロイシ', '西田', 'ニシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県袋井市深見', '22', '22216', '4370051', '静岡県', 'シズオカケン', '袋井市', 'フクロイシ', '深見', 'フカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県袋井市太田', '22', '22216', '4370052', '静岡県', 'シズオカケン', '袋井市', 'フクロイシ', '太田', 'オオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県袋井市延久', '22', '22216', '4370053', '静岡県', 'シズオカケン', '袋井市', 'フクロイシ', '延久', 'ノベヒサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県袋井市徳光', '22', '22216', '4370054', '静岡県', 'シズオカケン', '袋井市', 'フクロイシ', '徳光', 'トクミツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県袋井市土橋', '22', '22216', '4370055', '静岡県', 'シズオカケン', '袋井市', 'フクロイシ', '土橋', 'ツチハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県袋井市小山', '22', '22216', '4370056', '静岡県', 'シズオカケン', '袋井市', 'フクロイシ', '小山', 'オヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県袋井市横井', '22', '22216', '4370057', '静岡県', 'シズオカケン', '袋井市', 'フクロイシ', '横井', 'ヨコイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県袋井市久能', '22', '22216', '4370061', '静岡県', 'シズオカケン', '袋井市', 'フクロイシ', '久能', 'クノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県袋井市泉町', '22', '22216', '4370062', '静岡県', 'シズオカケン', '袋井市', 'フクロイシ', '泉町', 'イズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県袋井市田町', '22', '22216', '4370063', '静岡県', 'シズオカケン', '袋井市', 'フクロイシ', '田町', 'タマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県袋井市川井', '22', '22216', '4370064', '静岡県', 'シズオカケン', '袋井市', 'フクロイシ', '川井', 'カワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県袋井市堀越', '22', '22216', '4370065', '静岡県', 'シズオカケン', '袋井市', 'フクロイシ', '堀越', 'ホリコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県袋井市山科', '22', '22216', '4370066', '静岡県', 'シズオカケン', '袋井市', 'フクロイシ', '山科', 'ヤマシナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県袋井市天神町', '22', '22216', '4370067', '静岡県', 'シズオカケン', '袋井市', 'フクロイシ', '天神町', 'テンジンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県袋井市宇刈', '22', '22216', '4370121', '静岡県', 'シズオカケン', '袋井市', 'フクロイシ', '宇刈', 'ウガリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県袋井市春岡', '22', '22216', '4370122', '静岡県', 'シズオカケン', '袋井市', 'フクロイシ', '春岡', 'ハルオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県袋井市下山梨', '22', '22216', '4370123', '静岡県', 'シズオカケン', '袋井市', 'フクロイシ', '下山梨', 'シモヤマナシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県袋井市沖山梨', '22', '22216', '4370124', '静岡県', 'シズオカケン', '袋井市', 'フクロイシ', '沖山梨', 'オキヤマナシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県袋井市上山梨', '22', '22216', '4370125', '静岡県', 'シズオカケン', '袋井市', 'フクロイシ', '上山梨', 'カミヤマナシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県袋井市月見町', '22', '22216', '4370126', '静岡県', 'シズオカケン', '袋井市', 'フクロイシ', '月見町', 'ツキミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県袋井市可睡の杜', '22', '22216', '4370127', '静岡県', 'シズオカケン', '袋井市', 'フクロイシ', '可睡の杜', 'カスイノモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県周智郡森町', '22', '22461', '4370200', '静岡県', 'シズオカケン', '周智郡森町', 'シュウチグンモリマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('40540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県周智郡森町嵯塚', '22', '22461', '4370201', '静岡県', 'シズオカケン', '周智郡森町', 'シュウチグンモリマチ', '嵯塚', 'サヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県周智郡森町亀久保', '22', '22461', '4370202', '静岡県', 'シズオカケン', '周智郡森町', 'シュウチグンモリマチ', '亀久保', 'カメクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県周智郡森町鍛冶島', '22', '22461', '4370203', '静岡県', 'シズオカケン', '周智郡森町', 'シュウチグンモリマチ', '鍛冶島', 'カジシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県周智郡森町問詰', '22', '22461', '4370204', '静岡県', 'シズオカケン', '周智郡森町', 'シュウチグンモリマチ', '問詰', 'トイヅメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県周智郡森町大鳥居', '22', '22461', '4370205', '静岡県', 'シズオカケン', '周智郡森町', 'シュウチグンモリマチ', '大鳥居', 'オオトリイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県周智郡森町葛布', '22', '22461', '4370206', '静岡県', 'シズオカケン', '周智郡森町', 'シュウチグンモリマチ', '葛布', 'カツブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県周智郡森町西俣', '22', '22461', '4370207', '静岡県', 'シズオカケン', '周智郡森町', 'シュウチグンモリマチ', '西俣', 'ニシマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県周智郡森町三倉', '22', '22461', '4370208', '静岡県', 'シズオカケン', '周智郡森町', 'シュウチグンモリマチ', '三倉', 'ミクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県周智郡森町城下', '22', '22461', '4370211', '静岡県', 'シズオカケン', '周智郡森町', 'シュウチグンモリマチ', '城下', 'シロシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県周智郡森町向天方', '22', '22461', '4370212', '静岡県', 'シズオカケン', '周智郡森町', 'シュウチグンモリマチ', '向天方', 'ムカイアマガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県周智郡森町睦実', '22', '22461', '4370213', '静岡県', 'シズオカケン', '周智郡森町', 'シュウチグンモリマチ', '睦実', 'ムツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県周智郡森町草ケ谷', '22', '22461', '4370214', '静岡県', 'シズオカケン', '周智郡森町', 'シュウチグンモリマチ', '草ケ谷', 'クサガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県周智郡森町森', '22', '22461', '4370215', '静岡県', 'シズオカケン', '周智郡森町', 'シュウチグンモリマチ', '森', 'モリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県周智郡森町天宮', '22', '22461', '4370216', '静岡県', 'シズオカケン', '周智郡森町', 'シュウチグンモリマチ', '天宮', 'アメノミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県周智郡森町薄場', '22', '22461', '4370217', '静岡県', 'シズオカケン', '周智郡森町', 'シュウチグンモリマチ', '薄場', 'ウスバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県周智郡森町円田', '22', '22461', '4370221', '静岡県', 'シズオカケン', '周智郡森町', 'シュウチグンモリマチ', '円田', 'エンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県周智郡森町飯田', '22', '22461', '4370222', '静岡県', 'シズオカケン', '周智郡森町', 'シュウチグンモリマチ', '飯田', 'イイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県周智郡森町中川', '22', '22461', '4370223', '静岡県', 'シズオカケン', '周智郡森町', 'シュウチグンモリマチ', '中川', 'ナカガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県周智郡森町牛飼', '22', '22461', '4370224', '静岡県', 'シズオカケン', '周智郡森町', 'シュウチグンモリマチ', '牛飼', 'ウシカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県周智郡森町谷中', '22', '22461', '4370225', '静岡県', 'シズオカケン', '周智郡森町', 'シュウチグンモリマチ', '谷中', 'ヤナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県周智郡森町一宮', '22', '22461', '4370226', '静岡県', 'シズオカケン', '周智郡森町', 'シュウチグンモリマチ', '一宮', 'イチミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県周智郡森町橘', '22', '22461', '4370227', '静岡県', 'シズオカケン', '周智郡森町', 'シュウチグンモリマチ', '橘', 'タチバナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市天竜区春野町川上', '22', '22137', '4370601', '静岡県', 'シズオカケン', '浜松市天竜区', 'ハママツシテンリュウク', '春野町川上', 'ハルノチョウカワカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市天竜区春野町杉', '22', '22137', '4370602', '静岡県', 'シズオカケン', '浜松市天竜区', 'ハママツシテンリュウク', '春野町杉', 'ハルノチョウスギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市天竜区春野町五和', '22', '22137', '4370603', '静岡県', 'シズオカケン', '浜松市天竜区', 'ハママツシテンリュウク', '春野町五和', 'ハルノチョウゴワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市天竜区春野町宮川', '22', '22137', '4370604', '静岡県', 'シズオカケン', '浜松市天竜区', 'ハママツシテンリュウク', '春野町宮川', 'ハルノチョウミヤガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市天竜区春野町気田', '22', '22137', '4370605', '静岡県', 'シズオカケン', '浜松市天竜区', 'ハママツシテンリュウク', '春野町気田', 'ハルノチョウケタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市天竜区春野町豊岡', '22', '22137', '4370606', '静岡県', 'シズオカケン', '浜松市天竜区', 'ハママツシテンリュウク', '春野町豊岡', 'ハルノチョウトヨオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市天竜区春野町石切', '22', '22137', '4370607', '静岡県', 'シズオカケン', '浜松市天竜区', 'ハママツシテンリュウク', '春野町石切', 'ハルノチョウイシキリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市天竜区春野町小俣京丸', '22', '22137', '4370608', '静岡県', 'シズオカケン', '浜松市天竜区', 'ハママツシテンリュウク', '春野町小俣京丸', 'ハルノチョウオマタキョウマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市天竜区春野町田河内', '22', '22137', '4370611', '静岡県', 'シズオカケン', '浜松市天竜区', 'ハママツシテンリュウク', '春野町田河内', 'ハルノチョウタゴウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市天竜区春野町花島', '22', '22137', '4370612', '静岡県', 'シズオカケン', '浜松市天竜区', 'ハママツシテンリュウク', '春野町花島', 'ハルノチョウハナジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市天竜区春野町牧野', '22', '22137', '4370613', '静岡県', 'シズオカケン', '浜松市天竜区', 'ハママツシテンリュウク', '春野町牧野', 'ハルノチョウマキノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市天竜区春野町長蔵寺', '22', '22137', '4370614', '静岡県', 'シズオカケン', '浜松市天竜区', 'ハママツシテンリュウク', '春野町長蔵寺', 'ハルノチョウチョウゾウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市天竜区春野町石打松下', '22', '22137', '4370615', '静岡県', 'シズオカケン', '浜松市天竜区', 'ハママツシテンリュウク', '春野町石打松下', 'ハルノチョウイシウチマツシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市天竜区春野町田黒', '22', '22137', '4370616', '静岡県', 'シズオカケン', '浜松市天竜区', 'ハママツシテンリュウク', '春野町田黒', 'ハルノチョウタグロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市天竜区春野町筏戸大上', '22', '22137', '4370617', '静岡県', 'シズオカケン', '浜松市天竜区', 'ハママツシテンリュウク', '春野町筏戸大上', 'ハルノチョウイカンドオオカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市天竜区春野町越木平', '22', '22137', '4370618', '静岡県', 'シズオカケン', '浜松市天竜区', 'ハママツシテンリュウク', '春野町越木平', 'ハルノチョウコシキダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市天竜区春野町砂川', '22', '22137', '4370621', '静岡県', 'シズオカケン', '浜松市天竜区', 'ハママツシテンリュウク', '春野町砂川', 'ハルノチョウイサガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市天竜区春野町大時', '22', '22137', '4370622', '静岡県', 'シズオカケン', '浜松市天竜区', 'ハママツシテンリュウク', '春野町大時', 'ハルノチョウオオトキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市天竜区春野町胡桃平', '22', '22137', '4370623', '静岡県', 'シズオカケン', '浜松市天竜区', 'ハママツシテンリュウク', '春野町胡桃平', 'ハルノチョウクルミダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市天竜区春野町和泉平', '22', '22137', '4370624', '静岡県', 'シズオカケン', '浜松市天竜区', 'ハママツシテンリュウク', '春野町和泉平', 'ハルノチョウイズミダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市天竜区春野町堀之内', '22', '22137', '4370625', '静岡県', 'シズオカケン', '浜松市天竜区', 'ハママツシテンリュウク', '春野町堀之内', 'ハルノチョウホリノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県浜松市天竜区春野町領家', '22', '22137', '4370626', '静岡県', 'シズオカケン', '浜松市天竜区', 'ハママツシテンリュウク', '春野町領家', 'ハルノチョウリョウケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県袋井市浅羽', '22', '22216', '4371101', '静岡県', 'シズオカケン', '袋井市', 'フクロイシ', '浅羽', 'アサバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県袋井市浅名', '22', '22216', '4371102', '静岡県', 'シズオカケン', '袋井市', 'フクロイシ', '浅名', 'アサナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県袋井市豊住', '22', '22216', '4371103', '静岡県', 'シズオカケン', '袋井市', 'フクロイシ', '豊住', 'トヨズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県袋井市新堀', '22', '22216', '4371104', '静岡県', 'シズオカケン', '袋井市', 'フクロイシ', '新堀', 'ニイボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県袋井市梅山', '22', '22216', '4371105', '静岡県', 'シズオカケン', '袋井市', 'フクロイシ', '梅山', 'ウメヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県袋井市中新田', '22', '22216', '4371111', '静岡県', 'シズオカケン', '袋井市', 'フクロイシ', '中新田', 'ナカシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県袋井市大野', '22', '22216', '4371112', '静岡県', 'シズオカケン', '袋井市', 'フクロイシ', '大野', 'オオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県袋井市東同笠', '22', '22216', '4371113', '静岡県', 'シズオカケン', '袋井市', 'フクロイシ', '東同笠', 'ヒガシドウリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県袋井市西同笠', '22', '22216', '4371114', '静岡県', 'シズオカケン', '袋井市', 'フクロイシ', '西同笠', 'ニシドウリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県袋井市湊', '22', '22216', '4371115', '静岡県', 'シズオカケン', '袋井市', 'フクロイシ', '湊', 'ミナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県袋井市太郎助', '22', '22216', '4371116', '静岡県', 'シズオカケン', '袋井市', 'フクロイシ', '太郎助', 'タロスケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県袋井市松原', '22', '22216', '4371117', '静岡県', 'シズオカケン', '袋井市', 'フクロイシ', '松原', 'マツバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県袋井市西ケ崎', '22', '22216', '4371118', '静岡県', 'シズオカケン', '袋井市', 'フクロイシ', '西ケ崎', 'ニシガサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県袋井市初越', '22', '22216', '4371119', '静岡県', 'シズオカケン', '袋井市', 'フクロイシ', '初越', 'ハヅコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県袋井市諸井', '22', '22216', '4371121', '静岡県', 'シズオカケン', '袋井市', 'フクロイシ', '諸井', 'モロイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県袋井市浅岡', '22', '22216', '4371122', '静岡県', 'シズオカケン', '袋井市', 'フクロイシ', '浅岡', 'アサオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県袋井市浅羽一色', '22', '22216', '4371123', '静岡県', 'シズオカケン', '袋井市', 'フクロイシ', '浅羽一色', 'アサバイシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県袋井市富里', '22', '22216', '4371124', '静岡県', 'シズオカケン', '袋井市', 'フクロイシ', '富里', 'トミサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県袋井市中', '22', '22216', '4371125', '静岡県', 'シズオカケン', '袋井市', 'フクロイシ', '中', 'ナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県袋井市長溝', '22', '22216', '4371126', '静岡県', 'シズオカケン', '袋井市', 'フクロイシ', '長溝', 'ナガミゾ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市豊浜中野', '22', '22211', '4371201', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '豊浜中野', 'トヨハマナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市豊浜', '22', '22211', '4371202', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '豊浜', 'トヨハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市福田', '22', '22211', '4371203', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '福田', 'フクデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市福田中島', '22', '22211', '4371204', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '福田中島', 'フクデナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市下太', '22', '22211', '4371205', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '下太', 'シモフト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市五十子', '22', '22211', '4371206', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '五十子', 'イカゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市蛭池', '22', '22211', '4371207', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '蛭池', 'ヒルイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市東小島', '22', '22211', '4371208', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '東小島', 'ヒガシコジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市南島', '22', '22211', '4371209', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '南島', 'ミナミシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市大原', '22', '22211', '4371211', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '大原', 'オオワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市南田', '22', '22211', '4371212', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '南田', 'ミナミダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市塩新田', '22', '22211', '4371213', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '塩新田', 'シオシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市清庵新田', '22', '22211', '4371214', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '清庵新田', 'セイアンシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市太郎馬新田', '22', '22211', '4371215', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '太郎馬新田', 'タロマシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市一色', '22', '22211', '4371216', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '一色', 'イッシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市宇兵衛新田', '22', '22211', '4371217', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '宇兵衛新田', 'ウヘエシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市南田伊兵衛新田', '22', '22211', '4371218', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '南田伊兵衛新田', 'ミナミダイヘエシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市横須賀', '22', '22213', '4371301', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '横須賀', 'ヨコスカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市大渕', '22', '22213', '4371302', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '大渕', 'オオブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市沖之須', '22', '22213', '4371303', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '沖之須', 'オキノス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市西大渕', '22', '22213', '4371304', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '西大渕', 'ニシオオブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市山崎', '22', '22213', '4371305', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '山崎', 'ヤマザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県袋井市山崎', '22', '22216', '4371311', '静岡県', 'シズオカケン', '袋井市', 'フクロイシ', '山崎', 'ヤマザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県袋井市岡崎', '22', '22216', '4371312', '静岡県', 'シズオカケン', '袋井市', 'フクロイシ', '岡崎', 'オカザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市高瀬', '22', '22213', '4371401', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '高瀬', 'タカセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市中方', '22', '22213', '4371402', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '中方', 'ナカホウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市岩滑', '22', '22213', '4371403', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '岩滑', 'イワナメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市西之谷', '22', '22213', '4371404', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '西之谷', 'ニシノヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市中', '22', '22213', '4371405', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '中', 'ナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市川久保', '22', '22213', '4371406', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '川久保', 'カワクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市小貫', '22', '22213', '4371407', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '小貫', 'オヌキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市坂里', '22', '22213', '4371411', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '坂里', 'サカサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市千浜', '22', '22213', '4371412', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '千浜', 'チハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市国安', '22', '22213', '4371413', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '国安', 'クニヤス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市国包', '22', '22213', '4371414', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '国包', 'クニカネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市菊浜', '22', '22213', '4371415', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '菊浜', 'キクハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市三俣', '22', '22213', '4371416', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '三俣', 'ミツマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市大坂', '22', '22213', '4371421', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '大坂', 'オオサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市海戸', '22', '22213', '4371422', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '海戸', 'カイト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市浜川新田', '22', '22213', '4371423', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '浜川新田', 'ハマガワシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市浜野', '22', '22213', '4371424', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '浜野', 'ハマノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市浜野新田', '22', '22213', '4371425', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '浜野新田', 'ハマノシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市上土方落合', '22', '22213', '4371431', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '上土方落合', 'カミヒジカタオチアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市上土方工業団地', '22', '22213', '4371432', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '上土方工業団地', 'カミヒジカタコウギョウダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市上土方', '22', '22213', '4371433', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '上土方', 'カミヒジカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市下土方', '22', '22213', '4371434', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '下土方', 'シモヒジカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市上土方嶺向', '22', '22213', '4371435', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '上土方嶺向', 'カミヒジカタミネムカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市今滝', '22', '22213', '4371436', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '今滝', 'イマタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市上土方旦付新田', '22', '22213', '4371437', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '上土方旦付新田', 'カミヒジカタダンヅクシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市入山瀬', '22', '22213', '4371438', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '入山瀬', 'イリヤマセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県掛川市大坪台', '22', '22213', '4371439', '静岡県', 'シズオカケン', '掛川市', 'カケガワシ', '大坪台', 'オオツボダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県菊川市丹野', '22', '22224', '4371501', '静岡県', 'シズオカケン', '菊川市', 'キクガワシ', '丹野', 'タンノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県菊川市古谷', '22', '22224', '4371502', '静岡県', 'シズオカケン', '菊川市', 'キクガワシ', '古谷', 'フルヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県菊川市川上', '22', '22224', '4371503', '静岡県', 'シズオカケン', '菊川市', 'キクガワシ', '川上', 'カワカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県菊川市花水木', '22', '22224', '4371504', '静岡県', 'シズオカケン', '菊川市', 'キクガワシ', '花水木', 'ハナミズキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県菊川市高橋', '22', '22224', '4371505', '静岡県', 'シズオカケン', '菊川市', 'キクガワシ', '高橋', 'タカハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県菊川市河東', '22', '22224', '4371506', '静岡県', 'シズオカケン', '菊川市', 'キクガワシ', '河東', 'カトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県菊川市赤土', '22', '22224', '4371507', '静岡県', 'シズオカケン', '菊川市', 'キクガワシ', '赤土', 'アカツチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県菊川市目木', '22', '22224', '4371511', '静岡県', 'シズオカケン', '菊川市', 'キクガワシ', '目木', 'モッキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県菊川市猿渡', '22', '22224', '4371512', '静岡県', 'シズオカケン', '菊川市', 'キクガワシ', '猿渡', 'サルワタリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県菊川市棚草', '22', '22224', '4371513', '静岡県', 'シズオカケン', '菊川市', 'キクガワシ', '棚草', 'タナクサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県菊川市下平川', '22', '22224', '4371514', '静岡県', 'シズオカケン', '菊川市', 'キクガワシ', '下平川', 'シモヒラカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県菊川市上平川', '22', '22224', '4371521', '静岡県', 'シズオカケン', '菊川市', 'キクガワシ', '上平川', 'カミヒラカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県菊川市嶺田', '22', '22224', '4371522', '静岡県', 'シズオカケン', '菊川市', 'キクガワシ', '嶺田', 'ミネダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県菊川市堂山新田', '22', '22224', '4371523', '静岡県', 'シズオカケン', '菊川市', 'キクガワシ', '堂山新田', 'ドウヤマシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県菊川市大石', '22', '22224', '4371524', '静岡県', 'シズオカケン', '菊川市', 'キクガワシ', '大石', 'オオイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県御前崎市', '22', '22223', '4371600', '静岡県', 'シズオカケン', '御前崎市', 'オマエザキシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('40692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県御前崎市上朝比奈', '22', '22223', '4371601', '静岡県', 'シズオカケン', '御前崎市', 'オマエザキシ', '上朝比奈', 'カミアサヒナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県御前崎市比木', '22', '22223', '4371602', '静岡県', 'シズオカケン', '御前崎市', 'オマエザキシ', '比木', 'ヒキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県御前崎市宮内', '22', '22223', '4371603', '静岡県', 'シズオカケン', '御前崎市', 'オマエザキシ', '宮内', 'ミヤウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県御前崎市佐倉', '22', '22223', '4371604', '静岡県', 'シズオカケン', '御前崎市', 'オマエザキシ', '佐倉', 'サクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県御前崎市下朝比奈', '22', '22223', '4371605', '静岡県', 'シズオカケン', '御前崎市', 'オマエザキシ', '下朝比奈', 'シモアサヒナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県御前崎市新野', '22', '22223', '4371611', '静岡県', 'シズオカケン', '御前崎市', 'オマエザキシ', '新野', 'ニイノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県御前崎市池新田', '22', '22223', '4371612', '静岡県', 'シズオカケン', '御前崎市', 'オマエザキシ', '池新田', 'イケシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県御前崎市合戸', '22', '22223', '4371613', '静岡県', 'シズオカケン', '御前崎市', 'オマエザキシ', '合戸', 'ゴウド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県御前崎市塩原新田', '22', '22223', '4371614', '静岡県', 'シズオカケン', '御前崎市', 'オマエザキシ', '塩原新田', 'シオバラシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県御前崎市門屋', '22', '22223', '4371615', '静岡県', 'シズオカケン', '御前崎市', 'オマエザキシ', '門屋', 'カドヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県御前崎市御前崎', '22', '22223', '4371621', '静岡県', 'シズオカケン', '御前崎市', 'オマエザキシ', '御前崎', 'オマエザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県御前崎市白羽', '22', '22223', '4371622', '静岡県', 'シズオカケン', '御前崎市', 'オマエザキシ', '白羽', 'シロワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県御前崎市港', '22', '22223', '4371623', '静岡県', 'シズオカケン', '御前崎市', 'オマエザキシ', '港', 'ミナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市', '22', '22211', '4380000', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('40724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市藤上原', '22', '22211', '4380001', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '藤上原', 'フジカンバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市大久保', '22', '22211', '4380002', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '大久保', 'オオクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市匂坂新', '22', '22211', '4380003', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '匂坂新', 'サギサカシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市匂坂中', '22', '22211', '4380004', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '匂坂中', 'サギサカナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市匂坂上', '22', '22211', '4380005', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '匂坂上', 'サギサカカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市寺谷', '22', '22211', '4380006', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '寺谷', 'テラダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市寺谷新田', '22', '22211', '4380007', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '寺谷新田', 'テラダニシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市平松掛下入作', '22', '22211', '4380008', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '平松掛下入作', 'ヒラマツカケシタイリサク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市笠梅', '22', '22211', '4380011', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '笠梅', 'カサウメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市向笠新屋', '22', '22211', '4380012', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '向笠新屋', 'ムカサアラヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市向笠竹之内', '22', '22211', '4380013', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '向笠竹之内', 'ムカサタケノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市向笠西', '22', '22211', '4380014', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '向笠西', 'ムカサニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市篠原', '22', '22211', '4380015', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '篠原', 'シノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市岩井', '22', '22211', '4380016', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '岩井', 'イワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市安久路', '22', '22211', '4380017', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '安久路', 'アクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市三ケ野台', '22', '22211', '4380018', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '三ケ野台', 'ミカノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市明ケ島原', '22', '22211', '4380019', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '明ケ島原', 'ミョウガジマハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市玉越', '22', '22211', '4380021', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '玉越', 'タマコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市西島', '22', '22211', '4380022', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '西島', 'ニシジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市彦島', '22', '22211', '4380023', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '彦島', 'ヒコジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市明ケ島', '22', '22211', '4380024', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '明ケ島', 'ミョウガジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市新貝', '22', '22211', '4380025', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '新貝', 'シンガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市西貝塚', '22', '22211', '4380026', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '西貝塚', 'ニシカイヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市三ケ野', '22', '22211', '4380027', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '三ケ野', 'ミカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市東山', '22', '22211', '4380028', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '東山', 'ヒガシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市稗原', '22', '22211', '4380031', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '稗原', 'ヒエバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市東脇', '22', '22211', '4380032', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '東脇', 'ヒガシワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市新出', '22', '22211', '4380033', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '新出', 'シンデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市和口', '22', '22211', '4380034', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '和口', 'ワグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市東新屋', '22', '22211', '4380035', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '東新屋', 'ヒガシアラヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市大立野', '22', '22211', '4380036', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '大立野', 'オオダテノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市東貝塚', '22', '22211', '4380037', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '東貝塚', 'ヒガシカイヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市鎌田', '22', '22211', '4380038', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '鎌田', 'カマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市東新町', '22', '22211', '4380039', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '東新町', 'トウシンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市西之島', '22', '22211', '4380041', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '西之島', 'ニシノシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市上南田', '22', '22211', '4380042', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '上南田', 'カミミナミダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市大原', '22', '22211', '4380043', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '大原', 'オオワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市大泉町', '22', '22211', '4380044', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '大泉町', 'オオイズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市上岡田', '22', '22211', '4380045', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '上岡田', 'カミオカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市下岡田', '22', '22211', '4380046', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '下岡田', 'シモオカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市豊島', '22', '22211', '4380047', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '豊島', 'トヨシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市上大之郷', '22', '22211', '4380051', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '上大之郷', 'カミオオノゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市下大之郷', '22', '22211', '4380052', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '下大之郷', 'シモオオノゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市中野', '22', '22211', '4380053', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '中野', 'ナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市浜部', '22', '22211', '4380054', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '浜部', 'ハマベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市鮫島', '22', '22211', '4380055', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '鮫島', 'サメジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市小島', '22', '22211', '4380056', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '小島', 'コジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市千手堂', '22', '22211', '4380057', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '千手堂', 'センズドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市万正寺', '22', '22211', '4380058', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '万正寺', 'マンショウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市刑部島', '22', '22211', '4380061', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '刑部島', 'ギョウブジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市新島', '22', '22211', '4380062', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '新島', 'アラシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市真光寺', '22', '22211', '4380063', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '真光寺', 'シンコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市北島', '22', '22211', '4380064', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '北島', 'キタジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市野箱', '22', '22211', '4380065', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '野箱', 'ノバコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市白拍子', '22', '22211', '4380066', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '白拍子', 'シラビョウシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市草崎', '22', '22211', '4380067', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '草崎', 'クササキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市前野', '22', '22211', '4380068', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '前野', 'マエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市長須賀', '22', '22211', '4380069', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '長須賀', 'ナガスカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市今之浦', '22', '22211', '4380071', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '今之浦', 'イマノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市鳥之瀬', '22', '22211', '4380072', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '鳥之瀬', 'トリノセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市二之宮東', '22', '22211', '4380073', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '二之宮東', 'ニノミヤヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市二之宮', '22', '22211', '4380074', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '二之宮', 'ニノミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市天竜', '22', '22211', '4380075', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '天竜', 'テンリュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市国府台', '22', '22211', '4380077', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '国府台', 'コウノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市旭ケ丘', '22', '22211', '4380078', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '旭ケ丘', 'アサヒガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市石原町', '22', '22211', '4380078', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '石原町', 'イシワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市泉町', '22', '22211', '4380078', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '泉町', 'イズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市久保町', '22', '22211', '4380078', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '久保町', 'クボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市御殿', '22', '22211', '4380078', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '御殿', 'ゴテン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市坂上町', '22', '22211', '4380078', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '坂上町', 'サカウエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市栄町', '22', '22211', '4380078', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '栄町', 'サカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市桜ケ丘', '22', '22211', '4380078', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '桜ケ丘', 'サクラガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市七軒町', '22', '22211', '4380078', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '七軒町', 'シチケンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市田町', '22', '22211', '4380078', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '田町', 'タマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市中央町', '22', '22211', '4380078', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '中央町', 'チュウオウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市中泉', '22', '22211', '4380078', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '中泉', 'ナカイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市中町', '22', '22211', '4380078', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '中町', 'ナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市西新町', '22', '22211', '4380078', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '西新町', 'ニシシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市西町', '22', '22211', '4380078', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '西町', 'ニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市東町', '22', '22211', '4380078', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '東町', 'ヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市本町', '22', '22211', '4380078', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市緑ケ丘', '22', '22211', '4380081', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '緑ケ丘', 'ミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市元天神町', '22', '22211', '4380082', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '元天神町', 'モトテンジンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市富士見町', '22', '22211', '4380083', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '富士見町', 'フジミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市城之崎', '22', '22211', '4380084', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '城之崎', 'キノサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市水堀', '22', '22211', '4380085', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '水堀', 'ミズホリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市一番町', '22', '22211', '4380086', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '一番町', 'イチバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市梅屋町', '22', '22211', '4380086', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '梅屋町', 'ウメヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市加茂川通', '22', '22211', '4380086', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '加茂川通', 'カモガワドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市河原町', '22', '22211', '4380086', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '河原町', 'カワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市北見町', '22', '22211', '4380086', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '北見町', 'キタミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市権現町', '22', '22211', '4380086', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '権現町', 'ゴンゲンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市幸町', '22', '22211', '4380086', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市清水町', '22', '22211', '4380086', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '清水町', 'シミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市宿町', '22', '22211', '4380086', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '宿町', 'シュクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市地脇町', '22', '22211', '4380086', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '地脇町', 'ジワキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市新通町', '22', '22211', '4380086', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '新通町', 'シンドオリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市住吉町', '22', '22211', '4380086', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '住吉町', 'スミヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市天王町', '22', '22211', '4380086', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '天王町', 'テンノウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市中川町', '22', '22211', '4380086', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '中川町', 'ナカガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市西坂町', '22', '22211', '4380086', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '西坂町', 'ニシザカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市二番町', '22', '22211', '4380086', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '二番町', 'ニバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市馬場町', '22', '22211', '4380086', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '馬場町', 'ババチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市東坂町', '22', '22211', '4380086', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '東坂町', 'ヒガシザカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市見付', '22', '22211', '4380086', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '見付', 'ミツケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市美登里町', '22', '22211', '4380086', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '美登里町', 'ミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市元倉町', '22', '22211', '4380086', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '元倉町', 'モトクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市元宮町', '22', '22211', '4380086', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '元宮町', 'モトミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市富士見台', '22', '22211', '4380088', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '富士見台', 'フジミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市万瀬', '22', '22211', '4380101', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '万瀬', 'マンゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市虫生', '22', '22211', '4380102', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '虫生', 'ムシュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市大平', '22', '22211', '4380103', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '大平', 'オオダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市岩室', '22', '22211', '4380104', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '岩室', 'イワムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市家田', '22', '22211', '4380105', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '家田', 'イエタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市敷地', '22', '22211', '4380106', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '敷地', 'シキジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市大当所', '22', '22211', '4380107', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '大当所', 'オオトウショ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市社山', '22', '22211', '4380108', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '社山', 'ヤシロヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市上野部', '22', '22211', '4380111', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '上野部', 'カミノベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市下野部', '22', '22211', '4380112', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '下野部', 'シモノベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市新開', '22', '22211', '4380113', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '新開', 'シンカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市合代島', '22', '22211', '4380114', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '合代島', 'ゴウダイジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市上神増', '22', '22211', '4380115', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '上神増', 'カミカンゾ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市壱貫地', '22', '22211', '4380116', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '壱貫地', 'イッカンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市神増', '22', '22211', '4380121', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '神増', 'カンゾ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市惣兵衛下新田', '22', '22211', '4380122', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '惣兵衛下新田', 'ソウベエシモシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市平松', '22', '22211', '4380123', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '平松', 'ヒラマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市掛下', '22', '22211', '4380124', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '掛下', 'カケシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市松之木島', '22', '22211', '4380125', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '松之木島', 'マツノキジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市下神増', '22', '22211', '4380126', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '下神増', 'シモカンゾ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市三家', '22', '22211', '4380127', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '三家', 'ミツエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市竜洋中島', '22', '22211', '4380201', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '竜洋中島', 'リュウヨウナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市高木', '22', '22211', '4380202', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '高木', 'タカギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市平間', '22', '22211', '4380203', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '平間', 'ヒラマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市岡', '22', '22211', '4380204', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '岡', 'オカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市堀之内', '22', '22211', '4380205', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '堀之内', 'ホリノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市松本', '22', '22211', '4380206', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '松本', 'マツモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市宮本', '22', '22211', '4380207', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '宮本', 'ミヤモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市東平松', '22', '22211', '4380211', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '東平松', 'ヒガシヒラマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市海老島', '22', '22211', '4380212', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '海老島', 'エビジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市竜洋稗原', '22', '22211', '4380213', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '竜洋稗原', 'リュウヨウヒエバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市大中瀬', '22', '22211', '4380214', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '大中瀬', 'オオナカゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市小中瀬', '22', '22211', '4380215', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '小中瀬', 'コナカゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市飛平松', '22', '22211', '4380216', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '飛平松', 'トビヒラマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市西平松', '22', '22211', '4380217', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '西平松', 'ニシヒラマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市中平松', '22', '22211', '4380218', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '中平松', 'ナカヒラマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市南平松', '22', '22211', '4380221', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '南平松', 'ミナミヒラマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市須恵新田', '22', '22211', '4380222', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '須恵新田', 'スエシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市請負新田', '22', '22211', '4380223', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '請負新田', 'ウケオイシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市浜新田', '22', '22211', '4380224', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '浜新田', 'ハマシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市豊岡', '22', '22211', '4380231', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '豊岡', 'トヨオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市川袋', '22', '22211', '4380232', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '川袋', 'カワブクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市駒場', '22', '22211', '4380233', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '駒場', 'コマバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市掛塚', '22', '22211', '4380234', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '掛塚', 'カケツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市白羽', '22', '22211', '4380235', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '白羽', 'シロワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市十郎島', '22', '22211', '4380236', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '十郎島', 'ジュウロウジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市高見丘', '22', '22211', '4380801', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '高見丘', 'タカミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市東原', '22', '22211', '4380802', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '東原', 'ヒガシバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市富丘', '22', '22211', '4380803', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '富丘', 'トミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市加茂', '22', '22211', '4380804', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '加茂', 'カモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市池田', '22', '22211', '4380805', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '池田', 'イケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市東名', '22', '22211', '4380806', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '東名', 'トウメイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市富里', '22', '22211', '4380807', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '富里', 'トミサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市豊田', '22', '22211', '4380808', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '豊田', 'トヨダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市一言', '22', '22211', '4380811', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '一言', 'ヒトコト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市海老塚', '22', '22211', '4380812', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '海老塚', 'エビツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市笹原島', '22', '22211', '4380813', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '笹原島', 'ササハラジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市気子島', '22', '22211', '4380814', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '気子島', 'ケゴジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市中田', '22', '22211', '4380815', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '中田', 'ナカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市宮之一色', '22', '22211', '4380816', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '宮之一色', 'ミヤノイシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市上万能', '22', '22211', '4380817', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '上万能', 'カミマンノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市下万能', '22', '22211', '4380818', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '下万能', 'シモマンノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市立野', '22', '22211', '4380821', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '立野', 'タテノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市上本郷', '22', '22211', '4380822', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '上本郷', 'カミホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市下本郷', '22', '22211', '4380823', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '下本郷', 'シモホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市赤池', '22', '22211', '4380824', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '赤池', 'アカイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市森本', '22', '22211', '4380825', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '森本', 'モリモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市上新屋', '22', '22211', '4380831', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '上新屋', 'カミアラヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市森岡', '22', '22211', '4380832', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '森岡', 'モリオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市弥藤太島', '22', '22211', '4380833', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '弥藤太島', 'ヤトウタジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市森下', '22', '22211', '4380834', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '森下', 'モリシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市豊田西之島', '22', '22211', '4380835', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '豊田西之島', 'トヨダニシノシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市長森', '22', '22211', '4380836', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '長森', 'ナガモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市源平新田', '22', '22211', '4380837', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '源平新田', 'ゲンペイシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県磐田市小立野', '22', '22211', '4380838', '静岡県', 'シズオカケン', '磐田市', 'イワタシ', '小立野', 'コダテノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県菊川市', '22', '22224', '4390000', '静岡県', 'シズオカケン', '菊川市', 'キクガワシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('40932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県菊川市富田', '22', '22224', '4390001', '静岡県', 'シズオカケン', '菊川市', 'キクガワシ', '富田', 'トミタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県菊川市倉沢', '22', '22224', '4390002', '静岡県', 'シズオカケン', '菊川市', 'キクガワシ', '倉沢', 'クラサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県菊川市沢水加', '22', '22224', '4390003', '静岡県', 'シズオカケン', '菊川市', 'キクガワシ', '沢水加', 'サバカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県菊川市和田', '22', '22224', '4390004', '静岡県', 'シズオカケン', '菊川市', 'キクガワシ', '和田', 'ワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県菊川市潮海寺', '22', '22224', '4390005', '静岡県', 'シズオカケン', '菊川市', 'キクガワシ', '潮海寺', 'チョウカイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県菊川市堀之内', '22', '22224', '4390006', '静岡県', 'シズオカケン', '菊川市', 'キクガワシ', '堀之内', 'ホリノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県菊川市柳', '22', '22224', '4390007', '静岡県', 'シズオカケン', '菊川市', 'キクガワシ', '柳', 'ヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県菊川市友田', '22', '22224', '4390008', '静岡県', 'シズオカケン', '菊川市', 'キクガワシ', '友田', 'トモダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県菊川市吉沢', '22', '22224', '4390009', '静岡県', 'シズオカケン', '菊川市', 'キクガワシ', '吉沢', 'ヨシサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県菊川市仲島', '22', '22224', '4390011', '静岡県', 'シズオカケン', '菊川市', 'キクガワシ', '仲島', 'ナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県菊川市青葉台', '22', '22224', '4390012', '静岡県', 'シズオカケン', '菊川市', 'キクガワシ', '青葉台', 'アオバダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県菊川市牛渕', '22', '22224', '4390013', '静岡県', 'シズオカケン', '菊川市', 'キクガワシ', '牛渕', 'ウシブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県菊川市小沢', '22', '22224', '4390014', '静岡県', 'シズオカケン', '菊川市', 'キクガワシ', '小沢', 'コザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県菊川市牧之原', '22', '22224', '4390015', '静岡県', 'シズオカケン', '菊川市', 'キクガワシ', '牧之原', 'マキノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県菊川市神尾', '22', '22224', '4390016', '静岡県', 'シズオカケン', '菊川市', 'キクガワシ', '神尾', 'カンノオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県菊川市朝日', '22', '22224', '4390017', '静岡県', 'シズオカケン', '菊川市', 'キクガワシ', '朝日', 'アサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県菊川市本所', '22', '22224', '4390018', '静岡県', 'シズオカケン', '菊川市', 'キクガワシ', '本所', 'ホンジョ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県菊川市半済', '22', '22224', '4390019', '静岡県', 'シズオカケン', '菊川市', 'キクガワシ', '半済', 'ハンセイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県菊川市小出', '22', '22224', '4390021', '静岡県', 'シズオカケン', '菊川市', 'キクガワシ', '小出', 'オイデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県菊川市東横地', '22', '22224', '4390022', '静岡県', 'シズオカケン', '菊川市', 'キクガワシ', '東横地', 'ヒガシヨコジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県菊川市三沢', '22', '22224', '4390023', '静岡県', 'シズオカケン', '菊川市', 'キクガワシ', '三沢', 'ミサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県菊川市奈良野', '22', '22224', '4390024', '静岡県', 'シズオカケン', '菊川市', 'キクガワシ', '奈良野', 'ナラノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県菊川市土橋', '22', '22224', '4390025', '静岡県', 'シズオカケン', '菊川市', 'キクガワシ', '土橋', 'ツチハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県菊川市西横地', '22', '22224', '4390026', '静岡県', 'シズオカケン', '菊川市', 'キクガワシ', '西横地', 'ニシヨコジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県菊川市加茂', '22', '22224', '4390031', '静岡県', 'シズオカケン', '菊川市', 'キクガワシ', '加茂', 'カモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県菊川市月岡', '22', '22224', '4390032', '静岡県', 'シズオカケン', '菊川市', 'キクガワシ', '月岡', 'ツキオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県菊川市耳川', '22', '22224', '4390033', '静岡県', 'シズオカケン', '菊川市', 'キクガワシ', '耳川', 'ミミガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県菊川市下内田', '22', '22224', '4390034', '静岡県', 'シズオカケン', '菊川市', 'キクガワシ', '下内田', 'シモウチダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県菊川市平尾', '22', '22224', '4390035', '静岡県', 'シズオカケン', '菊川市', 'キクガワシ', '平尾', 'ヒラオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県菊川市中内田', '22', '22224', '4390036', '静岡県', 'シズオカケン', '菊川市', 'キクガワシ', '中内田', 'ナカウチダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '静岡県菊川市西方', '22', '22224', '4390037', '静岡県', 'シズオカケン', '菊川市', 'キクガワシ', '西方', 'ニシカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡倶知安町', '01', '01400', '0440000', '北海道', 'ホッカイドウ', '虻田郡倶知安町', 'アブタグンクッチャンチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('40966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市下条西町', '23', '23201', '4400001', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '下条西町', 'ゲジョウニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市下条東町', '23', '23201', '4400002', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '下条東町', 'ゲジョウヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市浪の上町', '23', '23201', '4400003', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '浪の上町', 'ナミノウエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市忠興', '23', '23201', '4400004', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '忠興', 'タダコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市緑ケ丘', '23', '23201', '4400005', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '緑ケ丘', 'ミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市牛川町池下', '23', '23201', '4400006', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '牛川町', 'ウシカワチョウ', null, null, '池下', 'イケシタ');
INSERT INTO `ms_addresses` VALUES ('40972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市牛川町押川', '23', '23201', '4400006', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '牛川町', 'ウシカワチョウ', null, null, '押川', 'オシカワ');
INSERT INTO `ms_addresses` VALUES ('40973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市牛川町西仲田', '23', '23201', '4400006', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '牛川町', 'ウシカワチョウ', null, null, '西仲田', 'ニシナカダ');
INSERT INTO `ms_addresses` VALUES ('40974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市牛川町乗小路', '23', '23201', '4400006', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '牛川町', 'ウシカワチョウ', null, null, '乗小路', 'ノリコウジ');
INSERT INTO `ms_addresses` VALUES ('40975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市牛川町東仲田', '23', '23201', '4400006', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '牛川町', 'ウシカワチョウ', null, null, '東仲田', 'ヒガシナカダ');
INSERT INTO `ms_addresses` VALUES ('40976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡倶知安町北1条東', '01', '01400', '0440001', '北海道', 'ホッカイドウ', '虻田郡倶知安町', 'アブタグンクッチャンチョウ', '北1条東', 'キタ01ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市牛川通', '23', '23201', '4400011', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '牛川通', 'ウシカワドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市東小鷹野', '23', '23201', '4400012', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '東小鷹野', 'ヒガシオダカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市西小鷹野', '23', '23201', '4400013', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '西小鷹野', 'ニシオダカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市南牛川', '23', '23201', '4400014', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '南牛川', 'ミナミウシカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市牛川薬師町', '23', '23201', '4400015', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '牛川薬師町', 'ウシカワヤクシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市牛川町', '23', '23201', '4400016', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '牛川町', 'ウシカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡倶知安町北2条東', '01', '01400', '0440002', '北海道', 'ホッカイドウ', '虻田郡倶知安町', 'アブタグンクッチャンチョウ', '北2条東', 'キタ02ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市多米町', '23', '23201', '4400021', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '多米町', 'タメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市岩崎町', '23', '23201', '4400022', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '岩崎町', 'イワサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市岩田町影岩', '23', '23201', '4400023', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '岩田町', 'イワタチョウ', null, null, '影岩', 'カゲイワ');
INSERT INTO `ms_addresses` VALUES ('40987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市東田町井原', '23', '23201', '4400024', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '東田町', 'アズマダチョウ', null, null, '井原', 'イハラ');
INSERT INTO `ms_addresses` VALUES ('40988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市井原町', '23', '23201', '4400025', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '井原町', 'イハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市多米西町', '23', '23201', '4400026', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '多米西町', 'タメニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市多米中町', '23', '23201', '4400027', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '多米中町', 'タメナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市多米東町', '23', '23201', '4400028', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '多米東町', 'タメヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡倶知安町北3条東', '01', '01400', '0440003', '北海道', 'ホッカイドウ', '虻田郡倶知安町', 'アブタグンクッチャンチョウ', '北3条東', 'キタ03ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市北岩田', '23', '23201', '4400031', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '北岩田', 'キタイワタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市岩田町居村', '23', '23201', '4400032', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '岩田町', 'イワタチョウ', null, null, '居村', 'イムラ');
INSERT INTO `ms_addresses` VALUES ('40995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市岩田町北郷中', '23', '23201', '4400032', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '岩田町', 'イワタチョウ', null, null, '北郷中', 'キタゴウナカ');
INSERT INTO `ms_addresses` VALUES ('40996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市東岩田', '23', '23201', '4400033', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '東岩田', 'ヒガシイワタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市豊岡町', '23', '23201', '4400034', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '豊岡町', 'トヨオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市平川南町', '23', '23201', '4400035', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '平川南町', 'ヒラカワミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('40999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市東光町', '23', '23201', '4400036', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '東光町', 'トウコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市平川町', '23', '23201', '4400037', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '平川町', 'ヒラカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市平川本町', '23', '23201', '4400038', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '平川本町', 'ヒラカワホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡倶知安町北4条東', '01', '01400', '0440004', '北海道', 'ホッカイドウ', '虻田郡倶知安町', 'アブタグンクッチャンチョウ', '北4条東', 'キタ04ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市岩田町道合', '23', '23201', '4400041', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '岩田町', 'イワタチョウ', null, null, '道合', 'ミチアイ');
INSERT INTO `ms_addresses` VALUES ('41004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市岩田町宮下', '23', '23201', '4400041', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '岩田町', 'イワタチョウ', null, null, '宮下', 'ミヤシタ');
INSERT INTO `ms_addresses` VALUES ('41005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市栄町', '23', '23201', '4400042', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市朝丘町', '23', '23201', '4400043', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '朝丘町', 'アサオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市宮下町', '23', '23201', '4400044', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '宮下町', 'ミヤシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市吾妻町', '23', '23201', '4400045', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '吾妻町', 'アヅマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市仲ノ町', '23', '23201', '4400046', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '仲ノ町', 'ナカノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市東田仲の町', '23', '23201', '4400047', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '東田仲の町', 'アズマダナカノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市東田町', '23', '23201', '4400048', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '東田町', 'アズマダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡倶知安町北5条東', '01', '01400', '0440005', '北海道', 'ホッカイドウ', '虻田郡倶知安町', 'アブタグンクッチャンチョウ', '北5条東', 'キタ05ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市東雲町', '23', '23201', '4400051', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '東雲町', 'シノノメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市住吉町', '23', '23201', '4400052', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '住吉町', 'スミヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市老松町', '23', '23201', '4400053', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '老松町', 'オイマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市東田町北蓮田', '23', '23201', '4400054', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '東田町', 'アズマダチョウ', null, null, '北蓮田', 'キタレンダ');
INSERT INTO `ms_addresses` VALUES ('41017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市東田町西前山', '23', '23201', '4400054', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '東田町', 'アズマダチョウ', null, null, '西前山', 'ニシマエヤマ');
INSERT INTO `ms_addresses` VALUES ('41018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市東田町東前山', '23', '23201', '4400054', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '東田町', 'アズマダチョウ', null, null, '東前山', 'ヒガシマエヤマ');
INSERT INTO `ms_addresses` VALUES ('41019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市前畑町', '23', '23201', '4400055', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '前畑町', 'マエハタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市南旭町', '23', '23201', '4400056', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '南旭町', 'ミナミアサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市旭町', '23', '23201', '4400057', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '旭町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市旭本町', '23', '23201', '4400058', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '旭本町', 'アサヒホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡倶知安町北6条東', '01', '01400', '0440006', '北海道', 'ホッカイドウ', '虻田郡倶知安町', 'アブタグンクッチャンチョウ', '北6条東', 'キタ06ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市飽海町', '23', '23201', '4400061', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '飽海町', 'アクミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市東田町西郷', '23', '23201', '4400062', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '東田町', 'アズマダチョウ', null, null, '西郷', 'サイゴウ');
INSERT INTO `ms_addresses` VALUES ('41026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市東田町中郷', '23', '23201', '4400062', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '東田町', 'アズマダチョウ', null, null, '中郷', 'ナカゴウ');
INSERT INTO `ms_addresses` VALUES ('41027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市東田町西脇', '23', '23201', '4400062', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '東田町', 'アズマダチョウ', null, null, '西脇', 'ニシワキ');
INSERT INTO `ms_addresses` VALUES ('41028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市東田中郷町', '23', '23201', '4400063', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '東田中郷町', 'アズマダナカゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市西郷町', '23', '23201', '4400064', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '西郷町', 'サイゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市仁連木町', '23', '23201', '4400065', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '仁連木町', 'ニレンギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市東田町', '23', '23201', '4400066', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '東田町', 'アズマダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市上地町', '23', '23201', '4400067', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '上地町', 'ウエジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市東郷町', '23', '23201', '4400068', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '東郷町', 'トウゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市御園町', '23', '23201', '4400069', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '御園町', 'ミソノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡倶知安町北7条東', '01', '01400', '0440007', '北海道', 'ホッカイドウ', '虻田郡倶知安町', 'アブタグンクッチャンチョウ', '北7条東', 'キタ07ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市北島町', '23', '23201', '4400071', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '北島町', 'キタジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市船町', '23', '23201', '4400072', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '船町', 'フナマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市湊町', '23', '23201', '4400073', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '湊町', 'ミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市上伝馬町', '23', '23201', '4400074', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '上伝馬町', 'カミデンマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市花田町', '23', '23201', '4400075', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '花田町', 'ハナダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市花田町石塚', '23', '23201', '4400075', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '花田町', 'ハナダチョウ', null, null, '石塚', 'イシヅカ');
INSERT INTO `ms_addresses` VALUES ('41042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市花田町官有地', '23', '23201', '4400075', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '花田町官有地', 'ハナダチョウカンユウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市花田町西宿', '23', '23201', '4400075', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '花田町西宿', 'ハナダチョウニシジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市大橋通', '23', '23201', '4400076', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '大橋通', 'オオハシドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市南島町', '23', '23201', '4400077', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '南島町', 'ミナミジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市絹田町', '23', '23201', '4400078', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '絹田町', 'キヌタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市大村町', '23', '23201', '4400081', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '大村町', 'オオムラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市長瀬町', '23', '23201', '4400082', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '長瀬町', 'ナガセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市下地町大圦', '23', '23201', '4400083', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '下地町', 'シモジチョウ', null, null, '大圦', 'オオイリ');
INSERT INTO `ms_addresses` VALUES ('41050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市下地町北村', '23', '23201', '4400083', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '下地町', 'シモジチョウ', null, null, '北村', 'キタムラ');
INSERT INTO `ms_addresses` VALUES ('41051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市下地町操穴', '23', '23201', '4400083', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '下地町', 'シモジチョウ', null, null, '操穴', 'クリアナ');
INSERT INTO `ms_addresses` VALUES ('41052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市下地町五貫', '23', '23201', '4400083', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '下地町', 'シモジチョウ', null, null, '五貫', 'ゴカン');
INSERT INTO `ms_addresses` VALUES ('41053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市下地町境田', '23', '23201', '4400083', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '下地町', 'シモジチョウ', null, null, '境田', 'サカイダ');
INSERT INTO `ms_addresses` VALUES ('41054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市下地町天神', '23', '23201', '4400083', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '下地町', 'シモジチョウ', null, null, '天神', 'テンジン');
INSERT INTO `ms_addresses` VALUES ('41055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市下地町野箱', '23', '23201', '4400083', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '下地町', 'シモジチョウ', null, null, '野箱', 'ノバコ');
INSERT INTO `ms_addresses` VALUES ('41056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市下地町柳目', '23', '23201', '4400083', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '下地町', 'シモジチョウ', null, null, '柳目', 'ヤナメ');
INSERT INTO `ms_addresses` VALUES ('41057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市下地町横山', '23', '23201', '4400083', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '下地町', 'シモジチョウ', null, null, '横山', 'ヨコヤマ');
INSERT INTO `ms_addresses` VALUES ('41058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市下地町若宮', '23', '23201', '4400083', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '下地町', 'シモジチョウ', null, null, '若宮', 'ワカミヤ');
INSERT INTO `ms_addresses` VALUES ('41059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市下地町神田', '23', '23201', '4400084', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '下地町', 'シモジチョウ', null, null, '神田', 'カンダ');
INSERT INTO `ms_addresses` VALUES ('41060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市下地町瀬上', '23', '23201', '4400084', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '下地町', 'シモジチョウ', null, null, '瀬上', 'セガミ');
INSERT INTO `ms_addresses` VALUES ('41061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市下地町緑', '23', '23201', '4400084', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '下地町', 'シモジチョウ', null, null, '緑', 'ミドリ');
INSERT INTO `ms_addresses` VALUES ('41062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市下地町宮腰', '23', '23201', '4400084', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '下地町', 'シモジチョウ', null, null, '宮腰', 'ミヤコシ');
INSERT INTO `ms_addresses` VALUES ('41063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市下地町', '23', '23201', '4400085', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '下地町', 'シモジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市下地町', '23', '23201', '4400086', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '下地町', 'シモジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市下五井町', '23', '23201', '4400091', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '下五井町', 'シモゴイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市瓜郷町', '23', '23201', '4400092', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '瓜郷町', 'ウリゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市横須賀町', '23', '23201', '4400093', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '横須賀町', 'ヨコスカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市川崎町', '23', '23201', '4400094', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '川崎町', 'カワサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市清須町', '23', '23201', '4400095', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '清須町', 'キヨスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡倶知安町南1条東', '01', '01400', '0440011', '北海道', 'ホッカイドウ', '虻田郡倶知安町', 'アブタグンクッチャンチョウ', '南1条東', 'ミナミ01ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡倶知安町南2条東', '01', '01400', '0440012', '北海道', 'ホッカイドウ', '虻田郡倶知安町', 'アブタグンクッチャンチョウ', '南2条東', 'ミナミ02ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡倶知安町南3条東', '01', '01400', '0440013', '北海道', 'ホッカイドウ', '虻田郡倶知安町', 'アブタグンクッチャンチョウ', '南3条東', 'ミナミ03ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡倶知安町南4条東', '01', '01400', '0440014', '北海道', 'ホッカイドウ', '虻田郡倶知安町', 'アブタグンクッチャンチョウ', '南4条東', 'ミナミ04ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡倶知安町南5条東', '01', '01400', '0440015', '北海道', 'ホッカイドウ', '虻田郡倶知安町', 'アブタグンクッチャンチョウ', '南5条東', 'ミナミ05ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡倶知安町南6条東', '01', '01400', '0440016', '北海道', 'ホッカイドウ', '虻田郡倶知安町', 'アブタグンクッチャンチョウ', '南6条東', 'ミナミ06ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡倶知安町南7条東', '01', '01400', '0440021', '北海道', 'ホッカイドウ', '虻田郡倶知安町', 'アブタグンクッチャンチョウ', '南7条東', 'ミナミ07ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡倶知安町南8条東', '01', '01400', '0440022', '北海道', 'ホッカイドウ', '虻田郡倶知安町', 'アブタグンクッチャンチョウ', '南8条東', 'ミナミ08ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡倶知安町南9条東', '01', '01400', '0440023', '北海道', 'ホッカイドウ', '虻田郡倶知安町', 'アブタグンクッチャンチョウ', '南9条東', 'ミナミ09ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡倶知安町南10条東', '01', '01400', '0440024', '北海道', 'ホッカイドウ', '虻田郡倶知安町', 'アブタグンクッチャンチョウ', '南10条東', 'ミナミ10ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡倶知安町南11条東', '01', '01400', '0440025', '北海道', 'ホッカイドウ', '虻田郡倶知安町', 'アブタグンクッチャンチョウ', '南11条東', 'ミナミ11ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡倶知安町南1条西', '01', '01400', '0440031', '北海道', 'ホッカイドウ', '虻田郡倶知安町', 'アブタグンクッチャンチョウ', '南1条西', 'ミナミ01ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡倶知安町南2条西', '01', '01400', '0440032', '北海道', 'ホッカイドウ', '虻田郡倶知安町', 'アブタグンクッチャンチョウ', '南2条西', 'ミナミ02ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡倶知安町南3条西', '01', '01400', '0440033', '北海道', 'ホッカイドウ', '虻田郡倶知安町', 'アブタグンクッチャンチョウ', '南3条西', 'ミナミ03ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡倶知安町南4条西', '01', '01400', '0440034', '北海道', 'ホッカイドウ', '虻田郡倶知安町', 'アブタグンクッチャンチョウ', '南4条西', 'ミナミ04ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡倶知安町南5条西', '01', '01400', '0440035', '北海道', 'ホッカイドウ', '虻田郡倶知安町', 'アブタグンクッチャンチョウ', '南5条西', 'ミナミ05ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡倶知安町南6条西', '01', '01400', '0440036', '北海道', 'ホッカイドウ', '虻田郡倶知安町', 'アブタグンクッチャンチョウ', '南6条西', 'ミナミ06ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡倶知安町南7条西', '01', '01400', '0440041', '北海道', 'ホッカイドウ', '虻田郡倶知安町', 'アブタグンクッチャンチョウ', '南7条西', 'ミナミ07ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡倶知安町南8条西', '01', '01400', '0440042', '北海道', 'ホッカイドウ', '虻田郡倶知安町', 'アブタグンクッチャンチョウ', '南8条西', 'ミナミ08ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡倶知安町南9条西', '01', '01400', '0440043', '北海道', 'ホッカイドウ', '虻田郡倶知安町', 'アブタグンクッチャンチョウ', '南9条西', 'ミナミ09ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡倶知安町南10条西', '01', '01400', '0440044', '北海道', 'ホッカイドウ', '虻田郡倶知安町', 'アブタグンクッチャンチョウ', '南10条西', 'ミナミ10ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡倶知安町南11条西', '01', '01400', '0440045', '北海道', 'ホッカイドウ', '虻田郡倶知安町', 'アブタグンクッチャンチョウ', '南11条西', 'ミナミ11ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡倶知安町北1条西', '01', '01400', '0440051', '北海道', 'ホッカイドウ', '虻田郡倶知安町', 'アブタグンクッチャンチョウ', '北1条西', 'キタ01ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡倶知安町北2条西', '01', '01400', '0440052', '北海道', 'ホッカイドウ', '虻田郡倶知安町', 'アブタグンクッチャンチョウ', '北2条西', 'キタ02ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡倶知安町北3条西', '01', '01400', '0440053', '北海道', 'ホッカイドウ', '虻田郡倶知安町', 'アブタグンクッチャンチョウ', '北3条西', 'キタ03ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡倶知安町北4条西', '01', '01400', '0440054', '北海道', 'ホッカイドウ', '虻田郡倶知安町', 'アブタグンクッチャンチョウ', '北4条西', 'キタ04ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡倶知安町北5条西', '01', '01400', '0440055', '北海道', 'ホッカイドウ', '虻田郡倶知安町', 'アブタグンクッチャンチョウ', '北5条西', 'キタ05ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡倶知安町北6条西', '01', '01400', '0440056', '北海道', 'ホッカイドウ', '虻田郡倶知安町', 'アブタグンクッチャンチョウ', '北6条西', 'キタ06ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡倶知安町北7条西', '01', '01400', '0440057', '北海道', 'ホッカイドウ', '虻田郡倶知安町', 'アブタグンクッチャンチョウ', '北7条西', 'キタ07ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡倶知安町大和', '01', '01400', '0440061', '北海道', 'ホッカイドウ', '虻田郡倶知安町', 'アブタグンクッチャンチョウ', '大和', 'ヤマト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡倶知安町扶桑', '01', '01400', '0440062', '北海道', 'ホッカイドウ', '虻田郡倶知安町', 'アブタグンクッチャンチョウ', '扶桑', 'フソウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡倶知安町末広', '01', '01400', '0440063', '北海道', 'ホッカイドウ', '虻田郡倶知安町', 'アブタグンクッチャンチョウ', '末広', 'スエヒロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡倶知安町出雲', '01', '01400', '0440064', '北海道', 'ホッカイドウ', '虻田郡倶知安町', 'アブタグンクッチャンチョウ', '出雲', 'イズモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡倶知安町高見', '01', '01400', '0440065', '北海道', 'ホッカイドウ', '虻田郡倶知安町', 'アブタグンクッチャンチョウ', '高見', 'タカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡倶知安町琴平', '01', '01400', '0440066', '北海道', 'ホッカイドウ', '虻田郡倶知安町', 'アブタグンクッチャンチョウ', '琴平', 'コトヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡倶知安町瑞穂', '01', '01400', '0440067', '北海道', 'ホッカイドウ', '虻田郡倶知安町', 'アブタグンクッチャンチョウ', '瑞穂', 'ミズホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡倶知安町緑', '01', '01400', '0440068', '北海道', 'ホッカイドウ', '虻田郡倶知安町', 'アブタグンクッチャンチョウ', '緑', 'ミドリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡倶知安町寒別', '01', '01400', '0440071', '北海道', 'ホッカイドウ', '虻田郡倶知安町', 'アブタグンクッチャンチョウ', '寒別', 'カンベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡倶知安町八幡', '01', '01400', '0440072', '北海道', 'ホッカイドウ', '虻田郡倶知安町', 'アブタグンクッチャンチョウ', '八幡', 'ヤハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡倶知安町豊岡', '01', '01400', '0440073', '北海道', 'ホッカイドウ', '虻田郡倶知安町', 'アブタグンクッチャンチョウ', '豊岡', 'トヨオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡倶知安町巽', '01', '01400', '0440074', '北海道', 'ホッカイドウ', '虻田郡倶知安町', 'アブタグンクッチャンチョウ', '巽', 'タツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡倶知安町富士見', '01', '01400', '0440075', '北海道', 'ホッカイドウ', '虻田郡倶知安町', 'アブタグンクッチャンチョウ', '富士見', 'フジミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡倶知安町高砂', '01', '01400', '0440076', '北海道', 'ホッカイドウ', '虻田郡倶知安町', 'アブタグンクッチャンチョウ', '高砂', 'タカサゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡倶知安町比羅夫', '01', '01400', '0440077', '北海道', 'ホッカイドウ', '虻田郡倶知安町', 'アブタグンクッチャンチョウ', '比羅夫', 'ヒラフ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡倶知安町樺山', '01', '01400', '0440078', '北海道', 'ホッカイドウ', '虻田郡倶知安町', 'アブタグンクッチャンチョウ', '樺山', 'カバヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市今橋町', '23', '23201', '4400801', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '今橋町', 'イマハシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市鍛冶町', '23', '23201', '4400802', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '鍛冶町', 'カジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市曲尺手町', '23', '23201', '4400803', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '曲尺手町', 'カネンテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市呉服町', '23', '23201', '4400804', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '呉服町', 'ゴフクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市大手町', '23', '23201', '4400805', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '大手町', 'オオテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市八町通', '23', '23201', '4400806', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '八町通', 'ハッチョウドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡倶知安町山田', '01', '01400', '0440081', '北海道', 'ホッカイドウ', '虻田郡倶知安町', 'アブタグンクッチャンチョウ', '山田', 'ヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市西新町', '23', '23201', '4400811', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '西新町', 'ニシシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市東新町', '23', '23201', '4400812', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '東新町', 'ヒガシシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市舟原町', '23', '23201', '4400813', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '舟原町', 'フナハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市前田町', '23', '23201', '4400814', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '前田町', 'マエダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市中世古町', '23', '23201', '4400815', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '中世古町', 'ナカセコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市談合町', '23', '23201', '4400816', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '談合町', 'ダンゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡倶知安町岩尾別', '01', '01400', '0440082', '北海道', 'ホッカイドウ', '虻田郡倶知安町', 'アブタグンクッチャンチョウ', '岩尾別', 'イワオベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市春日町', '23', '23201', '4400821', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '春日町', 'カスガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市伝馬町', '23', '23201', '4400822', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '伝馬町', 'デンマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市南瓦町', '23', '23201', '4400823', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '南瓦町', 'ミナミカワラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市瓦町通', '23', '23201', '4400824', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '瓦町通', 'カワラマチドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市瓦町', '23', '23201', '4400825', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '瓦町', 'カワラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市大井町', '23', '23201', '4400826', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '大井町', 'オオイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市池見町', '23', '23201', '4400827', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '池見町', 'イケミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡倶知安町旭', '01', '01400', '0440083', '北海道', 'ホッカイドウ', '虻田郡倶知安町', 'アブタグンクッチャンチョウ', '旭', 'アサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市西岩田', '23', '23201', '4400831', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '西岩田', 'ニシイワタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市岩田町', '23', '23201', '4400832', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '岩田町', 'イワタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市中岩田', '23', '23201', '4400832', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '中岩田', 'ナカイワタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市飯村町高山', '23', '23201', '4400833', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '飯村町', 'イムレチョウ', null, null, '高山', 'タカヤマ');
INSERT INTO `ms_addresses` VALUES ('41141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市飯村町西山', '23', '23201', '4400833', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '飯村町', 'イムレチョウ', null, null, '西山', 'ニシヤマ');
INSERT INTO `ms_addresses` VALUES ('41142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市飯村北', '23', '23201', '4400834', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '飯村北', 'イムレキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市飯村南', '23', '23201', '4400835', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '飯村南', 'イムレミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市飯村町', '23', '23201', '4400836', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '飯村町', 'イムレチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市三ノ輪町本興寺', '23', '23201', '4400837', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '三ノ輪町本興寺', 'ミノワチョウホンコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市三ノ輪町三ノ輪', '23', '23201', '4400837', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '三ノ輪町三ノ輪', 'ミノワチョウミノワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市三ノ輪町', '23', '23201', '4400838', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '三ノ輪町', 'ミノワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡倶知安町花園', '01', '01400', '0440084', '北海道', 'ホッカイドウ', '虻田郡倶知安町', 'アブタグンクッチャンチョウ', '花園', 'ハナゾノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市西口町', '23', '23201', '4400841', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '西口町', 'ニシグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市岩屋町', '23', '23201', '4400842', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '岩屋町', 'イワヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市東幸町', '23', '23201', '4400843', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '東幸町', 'ヒガシミユキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市高師町奥山田', '23', '23201', '4400844', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '高師町', 'タカシチョウ', null, null, '奥山田', 'オクヤマダ');
INSERT INTO `ms_addresses` VALUES ('41153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市高師町清水', '23', '23201', '4400844', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '高師町', 'タカシチョウ', null, null, '清水', 'シミズ');
INSERT INTO `ms_addresses` VALUES ('41154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市高師町水神', '23', '23201', '4400844', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '高師町', 'タカシチョウ', null, null, '水神', 'スイジン');
INSERT INTO `ms_addresses` VALUES ('41155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市高師町丸田', '23', '23201', '4400844', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '高師町', 'タカシチョウ', null, null, '丸田', 'マルダ');
INSERT INTO `ms_addresses` VALUES ('41156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市高師町', '23', '23201', '4400845', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '高師町', 'タカシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市高師町北原', '23', '23201', '4400845', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '高師町', 'タカシチョウ', null, null, '北原', 'キタハラ');
INSERT INTO `ms_addresses` VALUES ('41158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡倶知安町峠下', '01', '01400', '0440085', '北海道', 'ホッカイドウ', '虻田郡倶知安町', 'アブタグンクッチャンチョウ', '峠下', 'トウゲシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市前田南町', '23', '23201', '4400851', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '前田南町', 'マエダミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市佐藤', '23', '23201', '4400853', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '佐藤', 'サトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市佐藤町', '23', '23201', '4400853', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '佐藤町', 'サトウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市山田町', '23', '23201', '4400854', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '山田町', 'ヤマダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市東小池町', '23', '23201', '4400855', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '東小池町', 'ヒガシコイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市鍵田町', '23', '23201', '4400856', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '鍵田町', 'カギタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市堂浦町', '23', '23201', '4400857', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '堂浦町', 'ドウウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市つつじが丘', '23', '23201', '4400858', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', 'つつじが丘', 'ツツジガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市向山西町', '23', '23201', '4400861', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '向山西町', 'ムカイヤマニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市向山大池町', '23', '23201', '4400862', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '向山大池町', 'ムカイヤマオオイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市向山東町', '23', '23201', '4400863', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '向山東町', 'ムカイヤマヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市向山町', '23', '23201', '4400864', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '向山町', 'ムカイヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市向山台町', '23', '23201', '4400865', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '向山台町', 'ムカイヤマダイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市新吉町', '23', '23201', '4400871', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '新吉町', 'シンヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市前田中町', '23', '23201', '4400872', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '前田中町', 'マエダナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市小畷町', '23', '23201', '4400873', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '小畷町', 'コナワテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市東松山町', '23', '23201', '4400874', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '東松山町', 'ヒガシマツヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市中松山町', '23', '23201', '4400875', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '中松山町', 'ナカマツヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市西松山町', '23', '23201', '4400876', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '西松山町', 'ニシマツヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市南松山町', '23', '23201', '4400877', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '南松山町', 'ミナミマツヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市広小路', '23', '23201', '4400881', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '広小路', 'ヒロコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市神明町', '23', '23201', '4400882', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '神明町', 'シンメイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市新川町', '23', '23201', '4400883', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '新川町', 'シンカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市大国町', '23', '23201', '4400884', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '大国町', 'ダイコクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市中柴町', '23', '23201', '4400885', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '中柴町', 'ナカシバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市東小田原町', '23', '23201', '4400886', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '東小田原町', 'ヒガシオダワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市西小田原町', '23', '23201', '4400887', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '西小田原町', 'ニシオダワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市駅前大通', '23', '23201', '4400888', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '駅前大通', 'エキマエオオドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市関屋町', '23', '23201', '4400891', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '関屋町', 'セキヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市新本町', '23', '23201', '4400892', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '新本町', 'シンホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市札木町', '23', '23201', '4400893', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '札木町', 'フダギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市魚町', '23', '23201', '4400894', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '魚町', 'ウオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市花園町', '23', '23201', '4400895', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '花園町', 'ハナゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市萱町', '23', '23201', '4400896', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '萱町', 'カヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市松葉町', '23', '23201', '4400897', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '松葉町', 'マツバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡京極町', '01', '01399', '0440100', '北海道', 'ホッカイドウ', '虻田郡京極町', 'アブタグンキョウゴクチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('41195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡京極町京極', '01', '01399', '0440101', '北海道', 'ホッカイドウ', '虻田郡京極町', 'アブタグンキョウゴクチョウ', '京極', 'キョウゴク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡京極町北岡', '01', '01399', '0440111', '北海道', 'ホッカイドウ', '虻田郡京極町', 'アブタグンキョウゴクチョウ', '北岡', 'キタオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡京極町春日', '01', '01399', '0440112', '北海道', 'ホッカイドウ', '虻田郡京極町', 'アブタグンキョウゴクチョウ', '春日', 'カスガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡京極町松川', '01', '01399', '0440113', '北海道', 'ホッカイドウ', '虻田郡京極町', 'アブタグンキョウゴクチョウ', '松川', 'マツカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡京極町三崎', '01', '01399', '0440121', '北海道', 'ホッカイドウ', '虻田郡京極町', 'アブタグンキョウゴクチョウ', '三崎', 'ミサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡京極町大富', '01', '01399', '0440122', '北海道', 'ホッカイドウ', '虻田郡京極町', 'アブタグンキョウゴクチョウ', '大富', 'オオトミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡京極町脇方', '01', '01399', '0440123', '北海道', 'ホッカイドウ', '虻田郡京極町', 'アブタグンキョウゴクチョウ', '脇方', 'ワキカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡京極町錦', '01', '01399', '0440124', '北海道', 'ホッカイドウ', '虻田郡京極町', 'アブタグンキョウゴクチョウ', '錦', 'ニシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡京極町東花', '01', '01399', '0440125', '北海道', 'ホッカイドウ', '虻田郡京極町', 'アブタグンキョウゴクチョウ', '東花', 'トウカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡京極町川西', '01', '01399', '0440131', '北海道', 'ホッカイドウ', '虻田郡京極町', 'アブタグンキョウゴクチョウ', '川西', 'カワニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡京極町更進', '01', '01399', '0440132', '北海道', 'ホッカイドウ', '虻田郡京極町', 'アブタグンキョウゴクチョウ', '更進', 'コウシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡喜茂別町', '01', '01398', '0440200', '北海道', 'ホッカイドウ', '虻田郡喜茂別町', 'アブタグンキモベツチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('41207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡喜茂別町旭町', '01', '01398', '0440201', '北海道', 'ホッカイドウ', '虻田郡喜茂別町', 'アブタグンキモベツチョウ', '旭町', 'アサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡喜茂別町大町', '01', '01398', '0440201', '北海道', 'ホッカイドウ', '虻田郡喜茂別町', 'アブタグンキモベツチョウ', '大町', 'オオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡喜茂別町喜茂別', '01', '01398', '0440201', '北海道', 'ホッカイドウ', '虻田郡喜茂別町', 'アブタグンキモベツチョウ', '喜茂別', 'キモベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡喜茂別町幸町', '01', '01398', '0440201', '北海道', 'ホッカイドウ', '虻田郡喜茂別町', 'アブタグンキモベツチョウ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡喜茂別町末広町', '01', '01398', '0440201', '北海道', 'ホッカイドウ', '虻田郡喜茂別町', 'アブタグンキモベツチョウ', '末広町', 'スエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡喜茂別町本町', '01', '01398', '0440201', '北海道', 'ホッカイドウ', '虻田郡喜茂別町', 'アブタグンキモベツチョウ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡喜茂別町緑町', '01', '01398', '0440201', '北海道', 'ホッカイドウ', '虻田郡喜茂別町', 'アブタグンキモベツチョウ', '緑町', 'ミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡喜茂別町富士見台', '01', '01398', '0440211', '北海道', 'ホッカイドウ', '虻田郡喜茂別町', 'アブタグンキモベツチョウ', '富士見台', 'フジミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡喜茂別町留産', '01', '01398', '0440212', '北海道', 'ホッカイドウ', '虻田郡喜茂別町', 'アブタグンキモベツチョウ', '留産', 'ルサン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡喜茂別町比羅岡', '01', '01398', '0440213', '北海道', 'ホッカイドウ', '虻田郡喜茂別町', 'アブタグンキモベツチョウ', '比羅岡', 'ヒラオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡喜茂別町尻別', '01', '01398', '0440214', '北海道', 'ホッカイドウ', '虻田郡喜茂別町', 'アブタグンキモベツチョウ', '尻別', 'シリベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡喜茂別町相川', '01', '01398', '0440215', '北海道', 'ホッカイドウ', '虻田郡喜茂別町', 'アブタグンキモベツチョウ', '相川', 'アイカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡喜茂別町伏見', '01', '01398', '0440221', '北海道', 'ホッカイドウ', '虻田郡喜茂別町', 'アブタグンキモベツチョウ', '伏見', 'フシミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡喜茂別町栄', '01', '01398', '0440222', '北海道', 'ホッカイドウ', '虻田郡喜茂別町', 'アブタグンキモベツチョウ', '栄', 'サカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡喜茂別町川上', '01', '01398', '0440223', '北海道', 'ホッカイドウ', '虻田郡喜茂別町', 'アブタグンキモベツチョウ', '川上', 'カワカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡喜茂別町知来別', '01', '01398', '0440224', '北海道', 'ホッカイドウ', '虻田郡喜茂別町', 'アブタグンキモベツチョウ', '知来別', 'チライベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡喜茂別町福島', '01', '01398', '0440225', '北海道', 'ホッカイドウ', '虻田郡喜茂別町', 'アブタグンキモベツチョウ', '福島', 'フクシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道伊達市大滝区愛地町', '01', '01233', '0440441', '北海道', 'ホッカイドウ', '伊達市', 'ダテシ', '大滝区愛地町', 'オオタキクアイチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道伊達市大滝区宮城町', '01', '01233', '0440442', '北海道', 'ホッカイドウ', '伊達市', 'ダテシ', '大滝区宮城町', 'オオタキクミヤギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道伊達市大滝区清原町', '01', '01233', '0440443', '北海道', 'ホッカイドウ', '伊達市', 'ダテシ', '大滝区清原町', 'オオタキクキヨハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道伊達市大滝区豊里町', '01', '01233', '0440444', '北海道', 'ホッカイドウ', '伊達市', 'ダテシ', '大滝区豊里町', 'オオタキクトヨサトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡喜茂別町上尻別', '01', '01398', '0440451', '北海道', 'ホッカイドウ', '虻田郡喜茂別町', 'アブタグンキモベツチョウ', '上尻別', 'カミシリベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡喜茂別町鈴川', '01', '01398', '0440451', '北海道', 'ホッカイドウ', '虻田郡喜茂別町', 'アブタグンキモベツチョウ', '鈴川', 'スズカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡喜茂別町福丘', '01', '01398', '0440452', '北海道', 'ホッカイドウ', '虻田郡喜茂別町', 'アブタグンキモベツチョウ', '福丘', 'フクオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡喜茂別町共栄', '01', '01398', '0440453', '北海道', 'ホッカイドウ', '虻田郡喜茂別町', 'アブタグンキモベツチョウ', '共栄', 'キョウサカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡喜茂別町御園', '01', '01398', '0440453', '北海道', 'ホッカイドウ', '虻田郡喜茂別町', 'アブタグンキモベツチョウ', '御園', 'ミソノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡喜茂別町金山', '01', '01398', '0440454', '北海道', 'ホッカイドウ', '虻田郡喜茂別町', 'アブタグンキモベツチョウ', '金山', 'カナヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡喜茂別町中里', '01', '01398', '0440461', '北海道', 'ホッカイドウ', '虻田郡喜茂別町', 'アブタグンキモベツチョウ', '中里', 'ナカサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡喜茂別町福里', '01', '01398', '0440461', '北海道', 'ホッカイドウ', '虻田郡喜茂別町', 'アブタグンキモベツチョウ', '福里', 'フクサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡喜茂別町花丘', '01', '01398', '0440462', '北海道', 'ホッカイドウ', '虻田郡喜茂別町', 'アブタグンキモベツチョウ', '花丘', 'ハナオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡喜茂別町双葉', '01', '01398', '0440463', '北海道', 'ホッカイドウ', '虻田郡喜茂別町', 'アブタグンキモベツチョウ', '双葉', 'フタバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市', '23', '23201', '4410000', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('41275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県宝飯郡小坂井町', '23', '23603', '4410100', '愛知県', 'アイチケン', '宝飯郡小坂井町', 'ホイグンコザカイチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('41276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県宝飯郡小坂井町宿', '23', '23603', '4410101', '愛知県', 'アイチケン', '宝飯郡小坂井町', 'ホイグンコザカイチョウ', '宿', 'シュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県宝飯郡小坂井町篠束', '23', '23603', '4410102', '愛知県', 'アイチケン', '宝飯郡小坂井町', 'ホイグンコザカイチョウ', '篠束', 'シノヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県宝飯郡小坂井町小坂井', '23', '23603', '4410103', '愛知県', 'アイチケン', '宝飯郡小坂井町', 'ホイグンコザカイチョウ', '小坂井', 'コザカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県宝飯郡小坂井町平井', '23', '23603', '4410104', '愛知県', 'アイチケン', '宝飯郡小坂井町', 'ホイグンコザカイチョウ', '平井', 'ヒライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県宝飯郡小坂井町伊奈', '23', '23603', '4410105', '愛知県', 'アイチケン', '宝飯郡小坂井町', 'ホイグンコザカイチョウ', '伊奈', 'イナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県宝飯郡小坂井町美園', '23', '23603', '4410106', '愛知県', 'アイチケン', '宝飯郡小坂井町', 'ホイグンコザカイチョウ', '美園', 'ミソノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市日色野町', '23', '23201', '4410151', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '日色野町', 'ヒシキノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市前芝町', '23', '23201', '4410152', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '前芝町', 'マエシバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市新西浜町', '23', '23201', '4410153', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '新西浜町', 'シンニシハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市梅薮西町', '23', '23201', '4410154', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '梅薮西町', 'ウメヤブニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市梅薮町', '23', '23201', '4410155', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '梅薮町', 'ウメヤブチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市西浜町', '23', '23201', '4410156', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '西浜町', 'ニシハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市萩町', '23', '23207', '4410201', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '萩町', 'ハギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市赤坂町', '23', '23207', '4410202', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '赤坂町', 'アカサカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市長沢町', '23', '23207', '4410203', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '長沢町', 'ナガサワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市赤坂台', '23', '23207', '4410204', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '赤坂台', 'アカサカダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御油町', '23', '23207', '4410211', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御油町', 'ゴユチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御油町長谷山', '23', '23207', '4410212', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御油町', 'ゴユチョウ', null, null, '長谷山', 'ハセヤマ');
INSERT INTO `ms_addresses` VALUES ('41298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御油町汲ケ谷', '23', '23207', '4410213', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御油町', 'ゴユチョウ', null, null, '汲ケ谷', 'クミガタニ');
INSERT INTO `ms_addresses` VALUES ('41299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御油町東山', '23', '23207', '4410214', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御油町', 'ゴユチョウ', null, null, '東山', 'ヒガシヤマ');
INSERT INTO `ms_addresses` VALUES ('41300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御油町炮六土', '23', '23207', '4410215', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御油町', 'ゴユチョウ', null, null, '炮六土', 'ホウロクド');
INSERT INTO `ms_addresses` VALUES ('41304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町上佐脇', '23', '23207', '4410301', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町上佐脇', 'ミトチョウカミサワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町上佐脇雨田', '23', '23207', '4410301', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町上佐脇雨田', 'ミトチョウカミサワキアメダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町上佐脇犬田', '23', '23207', '4410301', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町上佐脇犬田', 'ミトチョウカミサワキイヌタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町上佐脇大郡', '23', '23207', '4410301', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町上佐脇大郡', 'ミトチョウカミサワキオオゴオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町上佐脇河原田', '23', '23207', '4410301', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町上佐脇河原田', 'ミトチョウカミサワキカワハラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町上佐脇観音堂', '23', '23207', '4410301', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町上佐脇観音堂', 'ミトチョウカミサワキカンノンドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町上佐脇北区', '23', '23207', '4410301', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町上佐脇北区', 'ミトチョウカミサワキキタク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町上佐脇中区', '23', '23207', '4410301', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町上佐脇中区', 'ミトチョウカミサワキナカク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町上佐脇西区', '23', '23207', '4410301', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町上佐脇西区', 'ミトチョウカミサワキニシク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町上佐脇西ノ貝津', '23', '23207', '4410301', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町上佐脇西ノ貝津', 'ミトチョウカミサワキニシノガイツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町上佐脇二本松', '23', '23207', '4410301', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町上佐脇二本松', 'ミトチョウカミサワキニホンマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町上佐脇野川', '23', '23207', '4410301', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町上佐脇野川', 'ミトチョウカミサワキノガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町上佐脇野添', '23', '23207', '4410301', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町上佐脇野添', 'ミトチョウカミサワキノゾエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町上佐脇花ノ木', '23', '23207', '4410301', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町上佐脇花ノ木', 'ミトチョウカミサワキハナノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町上佐脇東区', '23', '23207', '4410301', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町上佐脇東区', 'ミトチョウカミサワキヒガシク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町上佐脇深田', '23', '23207', '4410301', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町上佐脇深田', 'ミトチョウカミサワキフカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町上佐脇松下', '23', '23207', '4410301', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町上佐脇松下', 'ミトチョウカミサワキマツシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町上佐脇南区', '23', '23207', '4410301', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町上佐脇南区', 'ミトチョウカミサワキミナミク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町上佐脇屋敷', '23', '23207', '4410301', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町上佐脇屋敷', 'ミトチョウカミサワキヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町上佐脇六反畑', '23', '23207', '4410301', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町上佐脇六反畑', 'ミトチョウカミサワキロクタンバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町下佐脇', '23', '23207', '4410302', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町下佐脇', 'ミトチョウシモサワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町下佐脇洗出', '23', '23207', '4410302', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町下佐脇洗出', 'ミトチョウシモサワキアライダシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町下佐脇荒古', '23', '23207', '4410302', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町下佐脇荒古', 'ミトチョウシモサワキアラコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町下佐脇新屋', '23', '23207', '4410302', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町下佐脇新屋', 'ミトチョウシモサワキアラヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町下佐脇市場', '23', '23207', '4410302', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町下佐脇市場', 'ミトチョウシモサワキイチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町下佐脇院田', '23', '23207', '4410302', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町下佐脇院田', 'ミトチョウシモサワキインデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町下佐脇梅田', '23', '23207', '4410302', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町下佐脇梅田', 'ミトチョウシモサワキウメダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町下佐脇籠畑', '23', '23207', '4410302', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町下佐脇籠畑', 'ミトチョウシモサワキカゴバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町下佐脇鎌田', '23', '23207', '4410302', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町下佐脇鎌田', 'ミトチョウシモサワキカマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町下佐脇河田', '23', '23207', '4410302', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町下佐脇河田', 'ミトチョウシモサワキカワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町下佐脇北浦', '23', '23207', '4410302', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町下佐脇北浦', 'ミトチョウシモサワキキタウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町下佐脇義郎', '23', '23207', '4410302', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町下佐脇義郎', 'ミトチョウシモサワキギロウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町下佐脇九作', '23', '23207', '4410302', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町下佐脇九作', 'ミトチョウシモサワキクサク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町下佐脇郷中', '23', '23207', '4410302', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町下佐脇郷中', 'ミトチョウシモサワキゴウナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町下佐脇御所', '23', '23207', '4410302', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町下佐脇御所', 'ミトチョウシモサワキゴショ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町下佐脇佐脇原', '23', '23207', '4410302', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町下佐脇佐脇原', 'ミトチョウシモサワキサワキバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町下佐脇新洗出', '23', '23207', '4410302', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町下佐脇新洗出', 'ミトチョウシモサワキシンアライダシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町下佐脇新梅田', '23', '23207', '4410302', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町下佐脇新梅田', 'ミトチョウシモサワキシンウメダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町下佐脇新畑', '23', '23207', '4410302', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町下佐脇新畑', 'ミトチョウシモサワキシンバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町下佐脇是願', '23', '23207', '4410302', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町下佐脇是願', 'ミトチョウシモサワキゼガン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町下佐脇高畑', '23', '23207', '4410302', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町下佐脇高畑', 'ミトチョウシモサワキタカバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町下佐脇田熊', '23', '23207', '4410302', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町下佐脇田熊', 'ミトチョウシモサワキタグマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町下佐脇玉袋', '23', '23207', '4410302', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町下佐脇玉袋', 'ミトチョウシモサワキタマフクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町下佐脇出口', '23', '23207', '4410302', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町下佐脇出口', 'ミトチョウシモサワキデグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町下佐脇天神', '23', '23207', '4410302', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町下佐脇天神', 'ミトチョウシモサワキテンジン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町下佐脇仲荒', '23', '23207', '4410302', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町下佐脇仲荒', 'ミトチョウシモサワキナカアレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町下佐脇仲ノ坪', '23', '23207', '4410302', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町下佐脇仲ノ坪', 'ミトチョウシモサワキナカノツボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町下佐脇縄口', '23', '23207', '4410302', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町下佐脇縄口', 'ミトチョウシモサワキナワグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町下佐脇縄手', '23', '23207', '4410302', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町下佐脇縄手', 'ミトチョウシモサワキナワテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町下佐脇野口', '23', '23207', '4410302', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町下佐脇野口', 'ミトチョウシモサワキノグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町下佐脇野先', '23', '23207', '4410302', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町下佐脇野先', 'ミトチョウシモサワキノザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町下佐脇八尻', '23', '23207', '4410302', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町下佐脇八尻', 'ミトチョウシモサワキハチジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町下佐脇八反田', '23', '23207', '4410302', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町下佐脇八反田', 'ミトチョウシモサワキハッタンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町下佐脇羽鳥', '23', '23207', '4410302', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町下佐脇羽鳥', 'ミトチョウシモサワキハトリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町下佐脇花ノ木', '23', '23207', '4410302', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町下佐脇花ノ木', 'ミトチョウシモサワキハナノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町下佐脇浜道', '23', '23207', '4410302', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町下佐脇浜道', 'ミトチョウシモサワキハマミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町下佐脇引通', '23', '23207', '4410302', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町下佐脇引通', 'ミトチョウシモサワキヒキトオシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町下佐脇広野', '23', '23207', '4410302', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町下佐脇広野', 'ミトチョウシモサワキヒロノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町下佐脇平次', '23', '23207', '4410302', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町下佐脇平次', 'ミトチョウシモサワキヘイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町下佐脇堀合', '23', '23207', '4410302', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町下佐脇堀合', 'ミトチョウシモサワキホリアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町下佐脇待井', '23', '23207', '4410302', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町下佐脇待井', 'ミトチョウシモサワキマチイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町下佐脇都', '23', '23207', '4410302', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町下佐脇都', 'ミトチョウシモサワキミヤコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町下佐脇宮前', '23', '23207', '4410302', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町下佐脇宮前', 'ミトチョウシモサワキミヤマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町下佐脇宮本', '23', '23207', '4410302', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町下佐脇宮本', 'ミトチョウシモサワキミヤモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町下佐脇村上', '23', '23207', '4410302', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町下佐脇村上', 'ミトチョウシモサワキムラカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町下佐脇山崎', '23', '23207', '4410302', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町下佐脇山崎', 'ミトチョウシモサワキヤマザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町新田', '23', '23207', '4410303', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町新田', 'ミトチョウシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町新田洗出', '23', '23207', '4410303', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町新田洗出', 'ミトチョウシンデンアライダシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町新田新砂山', '23', '23207', '4410303', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町新田新砂山', 'ミトチョウシンデンシンスナヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町新田砂山', '23', '23207', '4410303', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町新田砂山', 'ミトチョウシンデンスナヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町佐脇浜', '23', '23207', '4410304', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町佐脇浜', 'ミトチョウサワキハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町佐脇浜一号地', '23', '23207', '4410304', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町佐脇浜一号地', 'ミトチョウサワキハマ01ゴウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町佐脇浜二号地', '23', '23207', '4410304', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町佐脇浜二号地', 'ミトチョウサワキハマ02ゴウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町佐脇浜三号地', '23', '23207', '4410304', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町佐脇浜三号地', 'ミトチョウサワキハマ03ゴウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町御馬', '23', '23207', '4410311', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町御馬', 'ミトチョウオンマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町御馬梅田', '23', '23207', '4410311', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町御馬梅田', 'ミトチョウオンマウメダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町御馬加美', '23', '23207', '4410311', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町御馬加美', 'ミトチョウオンマカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町御馬川端', '23', '23207', '4410311', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町御馬川端', 'ミトチョウオンマカワバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町御馬塩入', '23', '23207', '4410311', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町御馬塩入', 'ミトチョウオンマシオイリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町御馬塩浜', '23', '23207', '4410311', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町御馬塩浜', 'ミトチョウオンマシオハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町御馬膳田', '23', '23207', '4410311', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町御馬膳田', 'ミトチョウオンマゼンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町御馬玉袋', '23', '23207', '4410311', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町御馬玉袋', 'ミトチョウオンマタマフクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町御馬剱', '23', '23207', '4410311', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町御馬剱', 'ミトチョウオンマツルギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町御馬中島', '23', '23207', '4410311', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町御馬中島', 'ミトチョウオンマナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町御馬仲田', '23', '23207', '4410311', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町御馬仲田', 'ミトチョウオンマナカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町御馬長床', '23', '23207', '4410311', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町御馬長床', 'ミトチョウオンマナガトコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町御馬流田', '23', '23207', '4410311', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町御馬流田', 'ミトチョウオンマナガレダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町御馬西', '23', '23207', '4410311', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町御馬西', 'ミトチョウオンマニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町御馬西梅', '23', '23207', '4410311', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町御馬西梅', 'ミトチョウオンマニシウメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町御馬野添', '23', '23207', '4410311', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町御馬野添', 'ミトチョウオンマノゾエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町御馬浜田', '23', '23207', '4410311', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町御馬浜田', 'ミトチョウオンマハマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町御馬東', '23', '23207', '4410311', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町御馬東', 'ミトチョウオンマヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町御馬宮浦', '23', '23207', '4410311', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町御馬宮浦', 'ミトチョウオンマミヤウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町御馬向道', '23', '23207', '4410311', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町御馬向道', 'ミトチョウオンマムカイミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町西方', '23', '23207', '4410312', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町西方', 'ミトチョウニシガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町西方揚浜', '23', '23207', '4410312', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町西方揚浜', 'ミトチョウニシガタアゲハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町西方入浜', '23', '23207', '4410312', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町西方入浜', 'ミトチョウニシガタイリハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町西方井領田', '23', '23207', '4410312', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町西方井領田', 'ミトチョウニシガタイリョウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町西方狐塚', '23', '23207', '4410312', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町西方狐塚', 'ミトチョウニシガタキツネヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町西方九策', '23', '23207', '4410312', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町西方九策', 'ミトチョウニシガタクサク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町西方源農', '23', '23207', '4410312', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町西方源農', 'ミトチョウニシガタゲンノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町西方小貝津', '23', '23207', '4410312', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町西方小貝津', 'ミトチョウニシガタコガイツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町西方下浜道', '23', '23207', '4410312', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町西方下浜道', 'ミトチョウニシガタシモハマミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町西方常ノ口', '23', '23207', '4410312', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町西方常ノ口', 'ミトチョウニシガタジョウノクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町西方長田', '23', '23207', '4410312', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町西方長田', 'ミトチョウニシガタチョウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町西方樋田', '23', '23207', '4410312', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町西方樋田', 'ミトチョウニシガタトイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町西方中道', '23', '23207', '4410312', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町西方中道', 'ミトチョウニシガタナカミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町西方中屋敷', '23', '23207', '4410312', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町西方中屋敷', 'ミトチョウニシガタナカヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町西方梨野', '23', '23207', '4410312', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町西方梨野', 'ミトチョウニシガタナシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町西方浜田', '23', '23207', '4410312', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町西方浜田', 'ミトチョウニシガタハマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町西方日暮', '23', '23207', '4410312', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町西方日暮', 'ミトチョウニシガタヒグラシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町西方広田', '23', '23207', '4410312', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町西方広田', 'ミトチョウニシガタヒロタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町西方松本', '23', '23207', '4410312', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町西方松本', 'ミトチョウニシガタマツモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町西方宮長', '23', '23207', '4410312', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町西方宮長', 'ミトチョウニシガタミヤナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町泙野', '23', '23207', '4410313', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町泙野', 'ミトチョウナギノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町泙野楠木', '23', '23207', '4410313', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町泙野楠木', 'ミトチョウナギノクスノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町泙野久呂下', '23', '23207', '4410313', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町泙野久呂下', 'ミトチョウナギノクロシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町泙野新屋敷', '23', '23207', '4410313', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町泙野新屋敷', 'ミトチョウナギノシンヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町泙野高畑', '23', '23207', '4410313', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町泙野高畑', 'ミトチョウナギノタカバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町泙野丁田', '23', '23207', '4410313', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町泙野丁田', 'ミトチョウナギノチョウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町泙野仲田', '23', '23207', '4410313', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町泙野仲田', 'ミトチョウナギノナカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町泙野仲ノ坪', '23', '23207', '4410313', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町泙野仲ノ坪', 'ミトチョウナギノナカノツボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町泙野浜新田', '23', '23207', '4410313', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町泙野浜新田', 'ミトチョウナギノハマシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町泙野堀合', '23', '23207', '4410313', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町泙野堀合', 'ミトチョウナギノホリアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町泙野宮永', '23', '23207', '4410313', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町泙野宮永', 'ミトチョウナギノミヤナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町泙野村崎', '23', '23207', '4410313', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町泙野村崎', 'ミトチョウナギノムラサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町泙野餅田', '23', '23207', '4410313', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町泙野餅田', 'ミトチョウナギノモチダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町泙野柳原', '23', '23207', '4410313', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町泙野柳原', 'ミトチョウナギノヤナギハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町泙野山下', '23', '23207', '4410313', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町泙野山下', 'ミトチョウナギノヤマシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町泙野六角', '23', '23207', '4410313', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町泙野六角', 'ミトチョウナギノロクカク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町泙野六反田', '23', '23207', '4410313', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町泙野六反田', 'ミトチョウナギノロクタンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町御幸浜', '23', '23207', '4410314', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町御幸浜', 'ミトチョウミユキハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町御幸浜一号地', '23', '23207', '4410314', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町御幸浜一号地', 'ミトチョウミユキハマ01ゴウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町大草', '23', '23207', '4410315', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町大草', 'ミトチョウオオクサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町大草上竹', '23', '23207', '4410315', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町大草上竹', 'ミトチョウオオクサウエタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町大草大森', '23', '23207', '4410315', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町大草大森', 'ミトチョウオオクサオオモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町大草神場', '23', '23207', '4410315', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町大草神場', 'ミトチョウオオクサカンバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町大草西郷', '23', '23207', '4410315', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町大草西郷', 'ミトチョウオオクササイゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町大草新田', '23', '23207', '4410315', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町大草新田', 'ミトチョウオオクサシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町大草神田', '23', '23207', '4410315', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町大草神田', 'ミトチョウオオクサジンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町大草外新田', '23', '23207', '4410315', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町大草外新田', 'ミトチョウオオクサソトシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町大草東郷', '23', '23207', '4410315', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町大草東郷', 'ミトチョウオオクサトウゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町大草西浜', '23', '23207', '4410315', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町大草西浜', 'ミトチョウオオクサニシハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町大草西分莚', '23', '23207', '4410315', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町大草西分莚', 'ミトチョウオオクサニシフンムシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町大草分莚', '23', '23207', '4410315', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町大草分莚', 'ミトチョウオオクサフンムシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町大草向野', '23', '23207', '4410315', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町大草向野', 'ミトチョウオオクサムカイノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町赤根', '23', '23207', '4410316', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町赤根', 'ミトチョウアカネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町赤根角田', '23', '23207', '4410316', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町赤根角田', 'ミトチョウアカネカドタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町赤根神場', '23', '23207', '4410316', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町赤根神場', 'ミトチョウアカネカンバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町赤根柑子', '23', '23207', '4410316', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町赤根柑子', 'ミトチョウアカネコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町赤根下川', '23', '23207', '4410316', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町赤根下川', 'ミトチョウアカネシモカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町赤根水神', '23', '23207', '4410316', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町赤根水神', 'ミトチョウアカネスイジン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町赤根堤下', '23', '23207', '4410316', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町赤根堤下', 'ミトチョウアカネツツミシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町赤根天王', '23', '23207', '4410316', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町赤根天王', 'ミトチョウアカネテンノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町赤根百々', '23', '23207', '4410316', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町赤根百々', 'ミトチョウアカネドウドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町赤根仲田', '23', '23207', '4410316', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町赤根仲田', 'ミトチョウアカネナカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町赤根西半郷', '23', '23207', '4410316', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町赤根西半郷', 'ミトチョウアカネニシハンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町赤根野竹', '23', '23207', '4410316', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町赤根野竹', 'ミトチョウアカネノタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町赤根半郷', '23', '23207', '4410316', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町赤根半郷', 'ミトチョウアカネハンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町赤根前浜', '23', '23207', '4410316', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町赤根前浜', 'ミトチョウアカネマエハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町赤根松葉', '23', '23207', '4410316', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町赤根松葉', 'ミトチョウアカネマツバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町赤根宮前', '23', '23207', '4410316', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町赤根宮前', 'ミトチョウアカネミヤマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町赤根屋敷', '23', '23207', '4410316', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町赤根屋敷', 'ミトチョウアカネヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町赤根谷田入', '23', '23207', '4410316', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町赤根谷田入', 'ミトチョウアカネヤダイリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町赤根山田', '23', '23207', '4410316', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町赤根山田', 'ミトチョウアカネヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町安礼の崎', '23', '23207', '4410316', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町安礼の崎', 'ミトチョウアレノサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町広石', '23', '23207', '4410321', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町広石', 'ミトチョウヒロイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町広石石堂野', '23', '23207', '4410321', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町広石石堂野', 'ミトチョウヒロイシイシドウノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町広石市場', '23', '23207', '4410321', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町広石市場', 'ミトチョウヒロイシイチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町広石後畠', '23', '23207', '4410321', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町広石後畠', 'ミトチョウヒロイシウシロバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町広石越川', '23', '23207', '4410321', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町広石越川', 'ミトチョウヒロイシオッカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町広石金堂', '23', '23207', '4410321', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町広石金堂', 'ミトチョウヒロイシカナドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町広石蛇塚', '23', '23207', '4410321', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町広石蛇塚', 'ミトチョウヒロイシクチナワヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町広石高坂', '23', '23207', '4410321', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町広石高坂', 'ミトチョウヒロイシコウザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町広石小城前', '23', '23207', '4410321', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町広石小城前', 'ミトチョウヒロイシコジロマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町広石五反田', '23', '23207', '4410321', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町広石五反田', 'ミトチョウヒロイシゴタンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町広石小前', '23', '23207', '4410321', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町広石小前', 'ミトチョウヒロイシコマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町広石新宮山', '23', '23207', '4410321', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町広石新宮山', 'ミトチョウヒロイシシングウサン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町広石千路', '23', '23207', '4410321', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町広石千路', 'ミトチョウヒロイシセンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町広石竹本', '23', '23207', '4410321', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町広石竹本', 'ミトチョウヒロイシタケモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町広石枋ケ坪', '23', '23207', '4410321', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町広石枋ケ坪', 'ミトチョウヒロイシトチガツボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町広石永井田', '23', '23207', '4410321', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町広石永井田', 'ミトチョウヒロイシナガイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町広石祢宜田', '23', '23207', '4410321', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町広石祢宜田', 'ミトチョウヒロイシネギデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町広石祓田', '23', '23207', '4410321', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町広石祓田', 'ミトチョウヒロイシハライデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町広石日暮', '23', '23207', '4410321', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町広石日暮', 'ミトチョウヒロイシヒグラシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町広石広国', '23', '23207', '4410321', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町広石広国', 'ミトチョウヒロイシヒロクニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町広石船津', '23', '23207', '4410321', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町広石船津', 'ミトチョウヒロイシフナツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町広石船山', '23', '23207', '4410321', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町広石船山', 'ミトチョウヒロイシフナヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町広石神子田', '23', '23207', '4410321', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町広石神子田', 'ミトチョウヒロイシミコデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町広石御津山', '23', '23207', '4410321', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町広石御津山', 'ミトチョウヒロイシミトヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町広石横町', '23', '23207', '4410321', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町広石横町', 'ミトチョウヒロイシヨコマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町豊沢', '23', '23207', '4410322', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町豊沢', 'ミトチョウトヨサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町豊沢赤羽根', '23', '23207', '4410322', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町豊沢赤羽根', 'ミトチョウトヨサワアカバネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町豊沢石堂野', '23', '23207', '4410322', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町豊沢石堂野', 'ミトチョウトヨサワイシドウノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町豊沢入ノ口', '23', '23207', '4410322', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町豊沢入ノ口', 'ミトチョウトヨサワイリノクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町豊沢上野山', '23', '23207', '4410322', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町豊沢上野山', 'ミトチョウトヨサワウエノヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町豊沢後田', '23', '23207', '4410322', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町豊沢後田', 'ミトチョウトヨサワウシロダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町豊沢大蔵', '23', '23207', '4410322', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町豊沢大蔵', 'ミトチョウトヨサワオオクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町豊沢大沢', '23', '23207', '4410322', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町豊沢大沢', 'ミトチョウトヨサワオオサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町豊沢大坪', '23', '23207', '4410322', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町豊沢大坪', 'ミトチョウトヨサワオオツボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町豊沢川原', '23', '23207', '4410322', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町豊沢川原', 'ミトチョウトヨサワカワハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町豊沢久蔵', '23', '23207', '4410322', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町豊沢久蔵', 'ミトチョウトヨサワキュウゾウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町豊沢蔵下', '23', '23207', '4410322', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町豊沢蔵下', 'ミトチョウトヨサワクラシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町豊沢小沢', '23', '23207', '4410322', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町豊沢小沢', 'ミトチョウトヨサワコザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町豊沢小山', '23', '23207', '4410322', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町豊沢小山', 'ミトチョウトヨサワコヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町豊沢沢渡', '23', '23207', '4410322', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町豊沢沢渡', 'ミトチョウトヨサワサワタリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町豊沢篠川', '23', '23207', '4410322', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町豊沢篠川', 'ミトチョウトヨサワシノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町豊沢新小山', '23', '23207', '4410322', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町豊沢新小山', 'ミトチョウトヨサワシンコヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町豊沢新杉下', '23', '23207', '4410322', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町豊沢新杉下', 'ミトチョウトヨサワシンスギシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町豊沢杉下', '23', '23207', '4410322', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町豊沢杉下', 'ミトチョウトヨサワスギシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町豊沢樽美', '23', '23207', '4410322', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町豊沢樽美', 'ミトチョウトヨサワタルミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町豊沢払田', '23', '23207', '4410322', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町豊沢払田', 'ミトチョウトヨサワハライデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町豊沢引釣', '23', '23207', '4410322', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町豊沢引釣', 'ミトチョウトヨサワヒキツリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町豊沢松田', '23', '23207', '4410322', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町豊沢松田', 'ミトチョウトヨサワマツダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町豊沢松ノ下', '23', '23207', '4410322', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町豊沢松ノ下', 'ミトチョウトヨサワマツノシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町豊沢三沢', '23', '23207', '4410322', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町豊沢三沢', 'ミトチョウトヨサワミサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町豊沢弥勒寺', '23', '23207', '4410322', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町豊沢弥勒寺', 'ミトチョウトヨサワミロクジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町豊沢薬堂', '23', '23207', '4410322', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町豊沢薬堂', 'ミトチョウトヨサワヤクドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町金野', '23', '23207', '4410323', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町金野', 'ミトチョウカネノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町金野青木', '23', '23207', '4410323', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町金野青木', 'ミトチョウカネノアオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町金野油田', '23', '23207', '4410323', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町金野油田', 'ミトチョウカネノアブラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町金野石田', '23', '23207', '4410323', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町金野石田', 'ミトチョウカネノイシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町金野稲場', '23', '23207', '4410323', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町金野稲場', 'ミトチョウカネノイナバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町金野岩本', '23', '23207', '4410323', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町金野岩本', 'ミトチョウカネノイワモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町金野上野', '23', '23207', '4410323', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町金野上野', 'ミトチョウカネノウエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町金野籠田', '23', '23207', '4410323', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町金野籠田', 'ミトチョウカネノカゴタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町金野上沢', '23', '23207', '4410323', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町金野上沢', 'ミトチョウカネノカミサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町金野観音寺', '23', '23207', '4410323', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町金野観音寺', 'ミトチョウカネノカンノンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町金野国坂', '23', '23207', '4410323', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町金野国坂', 'ミトチョウカネノクニザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町金野郷作', '23', '23207', '4410323', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町金野郷作', 'ミトチョウカネノゴウサク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町金野五反田', '23', '23207', '4410323', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町金野五反田', 'ミトチョウカネノゴタンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町金野小根沢', '23', '23207', '4410323', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町金野小根沢', 'ミトチョウカネノコネザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町金野猿沢', '23', '23207', '4410323', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町金野猿沢', 'ミトチョウカネノサルサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町金野下', '23', '23207', '4410323', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町金野下', 'ミトチョウカネノシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町金野下ノ前', '23', '23207', '4410323', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町金野下ノ前', 'ミトチョウカネノシモノマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町金野新砂田', '23', '23207', '4410323', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町金野新砂田', 'ミトチョウカネノシンスナタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町金野新山影', '23', '23207', '4410323', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町金野新山影', 'ミトチョウカネノシンヤマカゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町金野砂田', '23', '23207', '4410323', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町金野砂田', 'ミトチョウカネノスナタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町金野竹入', '23', '23207', '4410323', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町金野竹入', 'ミトチョウカネノタケイリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町金野足見', '23', '23207', '4410323', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町金野足見', 'ミトチョウカネノタルミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町金野徳寒', '23', '23207', '4410323', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町金野徳寒', 'ミトチョウカネノトクサブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町金野中切', '23', '23207', '4410323', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町金野中切', 'ミトチョウカネノナカギリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町金野中畑', '23', '23207', '4410323', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町金野中畑', 'ミトチョウカネノナカバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町金野西沢', '23', '23207', '4410323', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町金野西沢', 'ミトチョウカネノニシザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町金野灰野坂', '23', '23207', '4410323', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町金野灰野坂', 'ミトチョウカネノハイノザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町金野長谷沢', '23', '23207', '4410323', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町金野長谷沢', 'ミトチョウカネノハセザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町金野東河津', '23', '23207', '4410323', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町金野東河津', 'ミトチョウカネノヒガシカワヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町金野東田', '23', '23207', '4410323', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町金野東田', 'ミトチョウカネノヒガシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町金野東畑', '23', '23207', '4410323', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町金野東畑', 'ミトチョウカネノヒガシバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町金野桧河津', '23', '23207', '4410323', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町金野桧河津', 'ミトチョウカネノヒノキカワヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町金野深沢', '23', '23207', '4410323', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町金野深沢', 'ミトチョウカネノフカザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町金野深田', '23', '23207', '4410323', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町金野深田', 'ミトチョウカネノフカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町金野袋田', '23', '23207', '4410323', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町金野袋田', 'ミトチョウカネノフクロダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町金野藤ケ山', '23', '23207', '4410323', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町金野藤ケ山', 'ミトチョウカネノフジガヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町金野藤久保', '23', '23207', '4410323', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町金野藤久保', 'ミトチョウカネノフジクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町金野見竹', '23', '23207', '4410323', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町金野見竹', 'ミトチョウカネノミタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町金野山影', '23', '23207', '4410323', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町金野山影', 'ミトチョウカネノヤマカゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町金野山本', '23', '23207', '4410323', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町金野山本', 'ミトチョウカネノヤマモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市御津町金野横手', '23', '23207', '4410323', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '御津町金野横手', 'ミトチョウカネノヨコテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市賀茂町', '23', '23201', '4411101', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '賀茂町', 'カモチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市石巻西川町', '23', '23201', '4411102', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '石巻西川町', 'イシマキニシガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市石巻萩平町', '23', '23201', '4411103', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '石巻萩平町', 'イシマキハギヒラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市石巻中山町', '23', '23201', '4411104', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '石巻中山町', 'イシマキナカヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市石巻平野町', '23', '23201', '4411105', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '石巻平野町', 'イシマキヒラノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市石巻小野田町', '23', '23201', '4411106', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '石巻小野田町', 'イシマキオノダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市嵩山町', '23', '23201', '4411111', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '嵩山町', 'スセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市石巻町', '23', '23201', '4411112', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '石巻町', 'イシマキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市東森岡', '23', '23201', '4411113', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '東森岡', 'ヒガシモリオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市森岡町', '23', '23201', '4411114', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '森岡町', 'モリオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市石巻本町', '23', '23201', '4411115', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '石巻本町', 'イシマキホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市東上町', '23', '23207', '4411201', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '東上町', 'トウジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市上長山町', '23', '23207', '4411202', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '上長山町', 'カミナガヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市足山田町', '23', '23207', '4411203', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '足山田町', 'アシヤマダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市西原町', '23', '23207', '4411204', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '西原町', 'ニシバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市大木町', '23', '23207', '4411205', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '大木町', 'オオギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市篠田町', '23', '23207', '4411206', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '篠田町', 'シノダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市江島町', '23', '23207', '4411211', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '江島町', 'エジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市金沢町', '23', '23207', '4411212', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '金沢町', 'カナザワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市松原町', '23', '23207', '4411221', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '松原町', 'マツバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市豊津町', '23', '23207', '4411222', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '豊津町', 'トヨツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市橋尾町', '23', '23207', '4411223', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '橋尾町', 'ハシオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市一宮町', '23', '23207', '4411231', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '一宮町', 'イチノミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市', '23', '23221', '4411300', '愛知県', 'アイチケン', '新城市', 'シンシロシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('41592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市矢部', '23', '23221', '4411301', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '矢部', 'ヤベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市富永', '23', '23221', '4411302', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '富永', 'トミナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市牛倉', '23', '23221', '4411303', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '牛倉', 'ウシグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市大宮', '23', '23221', '4411304', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '大宮', 'オオミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市竹広', '23', '23221', '4411305', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '竹広', 'タケヒロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市川路', '23', '23221', '4411306', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '川路', 'カワジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市富沢', '23', '23221', '4411307', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '富沢', 'トミザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市須長', '23', '23221', '4411311', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '須長', 'スナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市浅谷', '23', '23221', '4411312', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '浅谷', 'アサヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市出沢', '23', '23221', '4411313', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '出沢', 'スザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市横川', '23', '23221', '4411314', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '横川', 'ヨコガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市大海', '23', '23221', '4411315', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '大海', 'オオミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市緑が丘', '23', '23221', '4411316', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '緑が丘', 'ミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市有海', '23', '23221', '4411317', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '有海', 'アルミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市八束穂', '23', '23221', '4411318', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '八束穂', 'ヤツカホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市市川', '23', '23221', '4411321', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '市川', 'イチカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市日吉', '23', '23221', '4411322', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '日吉', 'ヒヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市吉川', '23', '23221', '4411323', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '吉川', 'ヨシカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市井道', '23', '23221', '4411324', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '井道', 'イミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市内井道', '23', '23221', '4411324', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '内井道', 'ウチイミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市奥井道', '23', '23221', '4411324', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '奥井道', 'オクイミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市二本松', '23', '23221', '4411325', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '二本松', 'ニホンマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市中野', '23', '23221', '4411326', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '中野', 'ナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市鰹淵', '23', '23221', '4411327', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '鰹淵', 'カツオブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市桜淵', '23', '23221', '4411328', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '桜淵', 'サクラブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市笠岩', '23', '23221', '4411329', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '笠岩', 'カサイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市庭野', '23', '23221', '4411331', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '庭野', 'ニワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市黒田', '23', '23221', '4411332', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '黒田', 'クロダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市小畑', '23', '23221', '4411333', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '小畑', 'オバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市中宇利', '23', '23221', '4411334', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '中宇利', 'ナカウリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市富岡', '23', '23221', '4411335', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '富岡', 'トミオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市富岡', '23', '23221', '4411336', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '富岡', 'トミオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市八名井', '23', '23221', '4411337', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '八名井', 'ヤナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市一鍬田', '23', '23221', '4411338', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '一鍬田', 'ヒトクワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市杉山', '23', '23221', '4411341', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '杉山', 'スギヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市石田', '23', '23221', '4411342', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '石田', 'イシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市野田', '23', '23221', '4411343', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '野田', 'ノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市野田上市場', '23', '23221', '4411344', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '野田', 'ノダ', null, null, '上市場', 'ウエイチバ');
INSERT INTO `ms_addresses` VALUES ('41630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市豊島', '23', '23221', '4411345', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '豊島', 'トヨシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市川田', '23', '23221', '4411346', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '川田', 'カワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市川田本宮道', '23', '23221', '4411347', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '川田', 'カワダ', null, null, '本宮道', 'ホングウドウ');
INSERT INTO `ms_addresses` VALUES ('41633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市市場台', '23', '23221', '4411348', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '市場台', 'イチバダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市稲木', '23', '23221', '4411351', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '稲木', 'イナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市豊栄', '23', '23221', '4411352', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '豊栄', 'トヨサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市徳定', '23', '23221', '4411353', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '徳定', 'トクサダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市片山', '23', '23221', '4411354', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '片山', 'カタヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市上平井', '23', '23221', '4411355', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '上平井', 'カミヒライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市平井', '23', '23221', '4411361', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '平井', 'ヒライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市平井西原', '23', '23221', '4411362', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '平井', 'ヒライ', null, null, '西原', 'ニシハラ');
INSERT INTO `ms_addresses` VALUES ('41641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市平井原', '23', '23221', '4411362', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '平井', 'ヒライ', null, null, '原', 'ハラ');
INSERT INTO `ms_addresses` VALUES ('41642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市平井東原', '23', '23221', '4411362', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '平井', 'ヒライ', null, null, '東原', 'ヒガシハラ');
INSERT INTO `ms_addresses` VALUES ('41643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市東沖野', '23', '23221', '4411363', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '東沖野', 'ヒガシオキノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市沖野', '23', '23221', '4411364', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '沖野', 'オキノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市石名号', '23', '23221', '4411365', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '石名号', 'イシナゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市向野', '23', '23221', '4411366', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '向野', 'ムカイノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市札木', '23', '23221', '4411367', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '札木', 'フダギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市屋敷', '23', '23221', '4411368', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '屋敷', 'ヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市城北', '23', '23221', '4411371', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '城北', 'ジョウホク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市裏野', '23', '23221', '4411372', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '裏野', 'ウラノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市西新町', '23', '23221', '4411373', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '西新町', 'ニシシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市町並', '23', '23221', '4411374', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '町並', 'マチナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市的場', '23', '23221', '4411375', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '的場', 'マトバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市宮ノ前', '23', '23221', '4411376', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '宮ノ前', 'ミヤノマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市宮ノ西', '23', '23221', '4411377', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '宮ノ西', 'ミヤノニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市宮ノ後', '23', '23221', '4411378', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '宮ノ後', 'ミヤノウシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市下川', '23', '23221', '4411381', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '下川', 'シタガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市滝ノ上', '23', '23221', '4411382', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '滝ノ上', 'タキノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市東入船', '23', '23221', '4411383', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '東入船', 'ヒガシイリフネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市西入船', '23', '23221', '4411384', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '西入船', 'ニシイリフネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市八幡', '23', '23221', '4411385', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '八幡', 'ハチマン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市南畑', '23', '23221', '4411386', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '南畑', 'ミナミバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市北畑', '23', '23221', '4411387', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '北畑', 'キタバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市橋向', '23', '23221', '4411388', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '橋向', 'ハシムコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市作手守義', '23', '23221', '4411401', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '作手守義', 'ツクデモリヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市作手木和田', '23', '23221', '4411402', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '作手木和田', 'ツクデキワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市作手善夫', '23', '23221', '4411403', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '作手善夫', 'ツクデゼンブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市作手菅沼', '23', '23221', '4411404', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '作手菅沼', 'ツクデスガヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市作手岩波', '23', '23221', '4411411', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '作手岩波', 'ツクデイワナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市作手鴨ケ谷', '23', '23221', '4411412', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '作手鴨ケ谷', 'ツクデカモガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市作手白鳥', '23', '23221', '4411413', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '作手白鳥', 'ツクデシラトリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市作手清岳', '23', '23221', '4411414', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '作手清岳', 'ツクデキヨオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市作手黒瀬', '23', '23221', '4411421', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '作手黒瀬', 'ツクデクロセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市作手田原', '23', '23221', '4411422', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '作手田原', 'ツクデタバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市作手高里', '23', '23221', '4411423', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '作手高里', 'ツクデタカサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市作手中河内', '23', '23221', '4411424', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '作手中河内', 'ツクデナカゴウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市作手大和田', '23', '23221', '4411531', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '作手大和田', 'ツクデオオワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市作手高松', '23', '23221', '4411532', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '作手高松', 'ツクデタカマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市作手荒原', '23', '23221', '4411533', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '作手荒原', 'ツクデアワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市作手田代', '23', '23221', '4411534', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '作手田代', 'ツクデタシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市作手杉平', '23', '23221', '4411535', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '作手杉平', 'ツクデスギダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市作手保永', '23', '23221', '4411536', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '作手保永', 'ツクデヤスナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市川合', '23', '23221', '4411601', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '川合', 'カワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市池場', '23', '23221', '4411602', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '池場', 'イケバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市名号', '23', '23221', '4411603', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '名号', 'ミョウゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市名越', '23', '23221', '4411604', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '名越', 'ナコエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市能登瀬', '23', '23221', '4411605', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '能登瀬', 'ノトセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市七郷一色', '23', '23221', '4411611', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '七郷一色', 'ナナサトイッシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市巣山', '23', '23221', '4411612', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '巣山', 'スヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市細川', '23', '23221', '4411613', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '細川', 'ホソカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市睦平', '23', '23221', '4411614', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '睦平', 'ムツダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市大野', '23', '23221', '4411615', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '大野', 'オオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市井代', '23', '23221', '4411616', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '井代', 'イシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市下吉田', '23', '23221', '4411621', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '下吉田', 'シモヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市上吉田', '23', '23221', '4411622', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '上吉田', 'カミヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市黄柳野', '23', '23221', '4411623', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '黄柳野', 'ツゲノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市竹ノ輪', '23', '23221', '4411624', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '竹ノ輪', 'タケノワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市豊岡', '23', '23221', '4411631', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '豊岡', 'トヨオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市富栄', '23', '23221', '4411632', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '富栄', 'トミサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市乗本', '23', '23221', '4411633', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '乗本', 'ノリモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市長篠', '23', '23221', '4411634', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '長篠', 'ナガシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市富保', '23', '23221', '4411636', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '富保', 'トミヤス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市門谷', '23', '23221', '4411693', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '門谷', 'カドヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市連合', '23', '23221', '4411941', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '連合', 'レンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市四谷', '23', '23221', '4411942', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '四谷', 'ヨツヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市海老', '23', '23221', '4411943', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '海老', 'エビ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市門谷', '23', '23221', '4411944', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '門谷', 'カドヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市玖老勢', '23', '23221', '4411945', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '玖老勢', 'クロゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市副川', '23', '23221', '4411946', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '副川', 'フクガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市愛郷', '23', '23221', '4411951', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '愛郷', 'アイゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市中島', '23', '23221', '4411952', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '中島', 'ナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市一色', '23', '23221', '4411953', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '一色', 'イッシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市只持', '23', '23221', '4411954', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '只持', 'タダモチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市布里', '23', '23221', '4411955', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '布里', 'フリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県新城市塩瀬', '23', '23221', '4411956', '愛知県', 'アイチケン', '新城市', 'シンシロシ', '塩瀬', 'シオセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県北設楽郡設楽町田峯', '23', '23561', '4412221', '愛知県', 'アイチケン', '北設楽郡設楽町', 'キタシタラグンシタラチョウ', '田峯', 'ダミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県北設楽郡設楽町田内', '23', '23561', '4412222', '愛知県', 'アイチケン', '北設楽郡設楽町', 'キタシタラグンシタラチョウ', '田内', 'タナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県北設楽郡設楽町三都橋', '23', '23561', '4412223', '愛知県', 'アイチケン', '北設楽郡設楽町', 'キタシタラグンシタラチョウ', '三都橋', 'ミツハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県北設楽郡設楽町豊邦', '23', '23561', '4412224', '愛知県', 'アイチケン', '北設楽郡設楽町', 'キタシタラグンシタラチョウ', '豊邦', 'トヨクニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県北設楽郡設楽町', '23', '23561', '4412300', '愛知県', 'アイチケン', '北設楽郡設楽町', 'キタシタラグンシタラチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('41724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県北設楽郡設楽町田口', '23', '23561', '4412301', '愛知県', 'アイチケン', '北設楽郡設楽町', 'キタシタラグンシタラチョウ', '田口', 'タグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県北設楽郡設楽町清崎', '23', '23561', '4412302', '愛知県', 'アイチケン', '北設楽郡設楽町', 'キタシタラグンシタラチョウ', '清崎', 'キヨサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県北設楽郡設楽町松戸', '23', '23561', '4412303', '愛知県', 'アイチケン', '北設楽郡設楽町', 'キタシタラグンシタラチョウ', '松戸', 'マツド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県北設楽郡設楽町八橋', '23', '23561', '4412311', '愛知県', 'アイチケン', '北設楽郡設楽町', 'キタシタラグンシタラチョウ', '八橋', 'ヤツハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県北設楽郡設楽町長江', '23', '23561', '4412312', '愛知県', 'アイチケン', '北設楽郡設楽町', 'キタシタラグンシタラチョウ', '長江', 'ナガエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県北設楽郡設楽町和市', '23', '23561', '4412313', '愛知県', 'アイチケン', '北設楽郡設楽町', 'キタシタラグンシタラチョウ', '和市', 'ワイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県北設楽郡設楽町平山', '23', '23561', '4412314', '愛知県', 'アイチケン', '北設楽郡設楽町', 'キタシタラグンシタラチョウ', '平山', 'ヒラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県北設楽郡設楽町神田', '23', '23561', '4412315', '愛知県', 'アイチケン', '北設楽郡設楽町', 'キタシタラグンシタラチョウ', '神田', 'カダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県北設楽郡設楽町荒尾', '23', '23561', '4412316', '愛知県', 'アイチケン', '北設楽郡設楽町', 'キタシタラグンシタラチョウ', '荒尾', 'アロオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県北設楽郡設楽町小松', '23', '23561', '4412317', '愛知県', 'アイチケン', '北設楽郡設楽町', 'キタシタラグンシタラチョウ', '小松', 'コマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県北設楽郡設楽町西納庫', '23', '23561', '4412431', '愛知県', 'アイチケン', '北設楽郡設楽町', 'キタシタラグンシタラチョウ', '西納庫', 'ニシナグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県北設楽郡設楽町東納庫', '23', '23561', '4412432', '愛知県', 'アイチケン', '北設楽郡設楽町', 'キタシタラグンシタラチョウ', '東納庫', 'ヒガシナグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県北設楽郡設楽町川向', '23', '23561', '4412433', '愛知県', 'アイチケン', '北設楽郡設楽町', 'キタシタラグンシタラチョウ', '川向', 'カワムキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県北設楽郡設楽町大名倉', '23', '23561', '4412434', '愛知県', 'アイチケン', '北設楽郡設楽町', 'キタシタラグンシタラチョウ', '大名倉', 'オオナグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市大野瀬町', '23', '23211', '4412511', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '大野瀬町', 'オオノセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市野入町', '23', '23211', '4412512', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '野入町', 'ノイリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市稲武町', '23', '23211', '4412513', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '稲武町', 'イナブチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市中当町', '23', '23211', '4412514', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '中当町', 'ナカトウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市夏焼町', '23', '23211', '4412515', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '夏焼町', 'ナツヤケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市押山町', '23', '23211', '4412516', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '押山町', 'オシヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市川手町', '23', '23211', '4412517', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '川手町', 'カワテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市桑原町', '23', '23211', '4412521', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '桑原町', 'クワバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市武節町', '23', '23211', '4412522', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '武節町', 'ブセツマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市御所貝津町', '23', '23211', '4412523', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '御所貝津町', 'ゴショガイツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市黒田町', '23', '23211', '4412524', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '黒田町', 'クロダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市小田木町', '23', '23211', '4412525', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '小田木町', 'オタギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市富永町', '23', '23211', '4412526', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '富永町', 'トミナガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県北設楽郡設楽町西納庫沖ノ平', '23', '23561', '4412531', '愛知県', 'アイチケン', '北設楽郡設楽町', 'キタシタラグンシタラチョウ', '西納庫', 'ニシナグラ', null, null, '沖ノ平', 'オキノタイラ');
INSERT INTO `ms_addresses` VALUES ('41752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県北設楽郡設楽町津具', '23', '23561', '4412601', '愛知県', 'アイチケン', '北設楽郡設楽町', 'キタシタラグンシタラチョウ', '津具', 'ツグ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市大脇町大脇', '23', '23201', '4413101', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '大脇町', 'オオワキチョウ', null, null, '大脇', 'オオワキ');
INSERT INTO `ms_addresses` VALUES ('41754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市大脇町大脇ノ谷', '23', '23201', '4413102', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '大脇町', 'オオワキチョウ', null, null, '大脇ノ谷', 'オオワキノヤ');
INSERT INTO `ms_addresses` VALUES ('41755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市雲谷町上ノ山', '23', '23201', '4413103', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '雲谷町', 'ウノヤチョウ', null, null, '上ノ山', 'ウエノヤマ');
INSERT INTO `ms_addresses` VALUES ('41756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市雲谷町', '23', '23201', '4413104', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '雲谷町', 'ウノヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市中原町南', '23', '23201', '4413105', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '中原町', 'ナカハラチョウ', null, null, '南', 'ミナミ');
INSERT INTO `ms_addresses` VALUES ('41758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市中原町', '23', '23201', '4413106', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '中原町', 'ナカハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市原町', '23', '23201', '4413111', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '原町', 'ハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市東細谷町', '23', '23201', '4413112', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '東細谷町', 'ヒガシホソヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市細谷町', '23', '23201', '4413113', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '細谷町', 'ホソヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市三弥町', '23', '23201', '4413114', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '三弥町', 'ミツヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市豊清町', '23', '23201', '4413115', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '豊清町', 'ホウセイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市西山町', '23', '23201', '4413121', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '西山町', 'ニシヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市小島町', '23', '23201', '4413122', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '小島町', 'コジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市小松原町', '23', '23201', '4413123', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '小松原町', 'コマツバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市寺沢町', '23', '23201', '4413124', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '寺沢町', 'テラサワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市豊栄町', '23', '23201', '4413125', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '豊栄町', 'ホウエイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市富士見町', '23', '23201', '4413126', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '富士見町', 'フジミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市大岩町小山塚', '23', '23201', '4413131', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '大岩町', 'オオイワチョウ', null, null, '小山塚', 'オヤマヅカ');
INSERT INTO `ms_addresses` VALUES ('41771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市大岩町東荒田', '23', '23201', '4413132', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '大岩町', 'オオイワチョウ', null, null, '東荒田', 'ヒガシアラタ');
INSERT INTO `ms_addresses` VALUES ('41772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市大岩町西荒田', '23', '23201', '4413133', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '大岩町', 'オオイワチョウ', null, null, '西荒田', 'ニシアラタ');
INSERT INTO `ms_addresses` VALUES ('41773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市大岩町久保田', '23', '23201', '4413134', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '大岩町', 'オオイワチョウ', null, null, '久保田', 'クボタ');
INSERT INTO `ms_addresses` VALUES ('41774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市大岩町北山', '23', '23201', '4413141', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '大岩町', 'オオイワチョウ', null, null, '北山', 'キタヤマ');
INSERT INTO `ms_addresses` VALUES ('41775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市大岩町東郷内', '23', '23201', '4413142', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '大岩町', 'オオイワチョウ', null, null, '東郷内', 'ヒガシゴウナイ');
INSERT INTO `ms_addresses` VALUES ('41776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市大岩町西郷内', '23', '23201', '4413143', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '大岩町', 'オオイワチョウ', null, null, '西郷内', 'ニシゴウナイ');
INSERT INTO `ms_addresses` VALUES ('41777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市大岩町南元屋敷', '23', '23201', '4413144', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '大岩町', 'オオイワチョウ', null, null, '南元屋敷', 'ミナミモトヤシキ');
INSERT INTO `ms_addresses` VALUES ('41778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市大岩町北元屋敷', '23', '23201', '4413145', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '大岩町', 'オオイワチョウ', null, null, '北元屋敷', 'キタモトヤシキ');
INSERT INTO `ms_addresses` VALUES ('41779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市大岩町', '23', '23201', '4413146', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '大岩町', 'オオイワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市大岩町', '23', '23201', '4413147', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '大岩町', 'オオイワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市二川町北裏', '23', '23201', '4413151', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '二川町', 'フタガワチョウ', null, null, '北裏', 'キタウラ');
INSERT INTO `ms_addresses` VALUES ('41782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市二川町南裏', '23', '23201', '4413152', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '二川町', 'フタガワチョウ', null, null, '南裏', 'ミナミウラ');
INSERT INTO `ms_addresses` VALUES ('41783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市二川町東向山', '23', '23201', '4413153', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '二川町', 'フタガワチョウ', null, null, '東向山', 'ヒガシムカイヤマ');
INSERT INTO `ms_addresses` VALUES ('41784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市二川町西向山', '23', '23201', '4413154', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '二川町', 'フタガワチョウ', null, null, '西向山', 'ニシムカイヤマ');
INSERT INTO `ms_addresses` VALUES ('41785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市二川町', '23', '23201', '4413155', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '二川町', 'フタガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市東七根町', '23', '23201', '4413201', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '東七根町', 'ヒガシナナネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市西七根町', '23', '23201', '4413202', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '西七根町', 'ニシナナネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市高塚町', '23', '23201', '4413203', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '高塚町', 'タカツカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市伊古部町', '23', '23201', '4413211', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '伊古部町', 'イコベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市東赤沢町', '23', '23201', '4413212', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '東赤沢町', 'ヒガシアカサワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市西赤沢町', '23', '23201', '4413213', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '西赤沢町', 'ニシアカサワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市城下町', '23', '23201', '4413214', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '城下町', 'シロシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市老津町', '23', '23201', '4413301', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '老津町', 'オイツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市杉山町', '23', '23201', '4413302', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '杉山町', 'スギヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県田原市', '23', '23231', '4413400', '愛知県', 'アイチケン', '田原市', 'タハラシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('41801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県田原市緑が浜', '23', '23231', '4413401', '愛知県', 'アイチケン', '田原市', 'タハラシ', '緑が浜', 'ミドリガハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県田原市吉胡町', '23', '23231', '4413402', '愛知県', 'アイチケン', '田原市', 'タハラシ', '吉胡町', 'ヨシゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県田原市浦町', '23', '23231', '4413403', '愛知県', 'アイチケン', '田原市', 'タハラシ', '浦町', 'ウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県田原市片浜町', '23', '23231', '4413404', '愛知県', 'アイチケン', '田原市', 'タハラシ', '片浜町', 'カタハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県田原市姫見台', '23', '23231', '4413405', '愛知県', 'アイチケン', '田原市', 'タハラシ', '姫見台', 'ヒメミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県田原市波瀬町', '23', '23231', '4413406', '愛知県', 'アイチケン', '田原市', 'タハラシ', '波瀬町', 'ハゼチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県田原市光崎', '23', '23231', '4413407', '愛知県', 'アイチケン', '田原市', 'タハラシ', '光崎', 'コウサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県田原市吉胡台', '23', '23231', '4413408', '愛知県', 'アイチケン', '田原市', 'タハラシ', '吉胡台', 'ヨシゴダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県田原市片西', '23', '23231', '4413409', '愛知県', 'アイチケン', '田原市', 'タハラシ', '片西', 'カタニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県田原市やぐま台', '23', '23231', '4413411', '愛知県', 'アイチケン', '田原市', 'タハラシ', 'やぐま台', 'ヤグマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県田原市谷熊町', '23', '23231', '4413412', '愛知県', 'アイチケン', '田原市', 'タハラシ', '谷熊町', 'ヤグマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県田原市六連町', '23', '23231', '4413413', '愛知県', 'アイチケン', '田原市', 'タハラシ', '六連町', 'ムツレチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県田原市東神戸町', '23', '23231', '4413414', '愛知県', 'アイチケン', '田原市', 'タハラシ', '東神戸町', 'ヒガシカンベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県田原市神戸町', '23', '23231', '4413415', '愛知県', 'アイチケン', '田原市', 'タハラシ', '神戸町', 'カンベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県田原市東赤石', '23', '23231', '4413416', '愛知県', 'アイチケン', '田原市', 'タハラシ', '東赤石', 'ヒガシアカイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県田原市豊島町', '23', '23231', '4413417', '愛知県', 'アイチケン', '田原市', 'タハラシ', '豊島町', 'トシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県田原市相川町', '23', '23231', '4413418', '愛知県', 'アイチケン', '田原市', 'タハラシ', '相川町', 'アイカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県田原市御殿山', '23', '23231', '4413419', '愛知県', 'アイチケン', '田原市', 'タハラシ', '御殿山', 'ゴテンヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県田原市田原町', '23', '23231', '4413421', '愛知県', 'アイチケン', '田原市', 'タハラシ', '田原町', 'タハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県田原市赤石', '23', '23231', '4413422', '愛知県', 'アイチケン', '田原市', 'タハラシ', '赤石', 'アカイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県田原市西神戸町', '23', '23231', '4413423', '愛知県', 'アイチケン', '田原市', 'タハラシ', '西神戸町', 'ニシカンベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県田原市南神戸町', '23', '23231', '4413424', '愛知県', 'アイチケン', '田原市', 'タハラシ', '南神戸町', 'ミナミカンベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県田原市大草町', '23', '23231', '4413425', '愛知県', 'アイチケン', '田原市', 'タハラシ', '大草町', 'オオクサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県田原市大久保町', '23', '23231', '4413426', '愛知県', 'アイチケン', '田原市', 'タハラシ', '大久保町', 'オオクボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県田原市加治町', '23', '23231', '4413427', '愛知県', 'アイチケン', '田原市', 'タハラシ', '加治町', 'カジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県田原市白谷町', '23', '23231', '4413431', '愛知県', 'アイチケン', '田原市', 'タハラシ', '白谷町', 'シロヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県田原市野田町', '23', '23231', '4413432', '愛知県', 'アイチケン', '田原市', 'タハラシ', '野田町', 'ノダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県田原市芦町', '23', '23231', '4413433', '愛知県', 'アイチケン', '田原市', 'タハラシ', '芦町', 'アシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県田原市ほると台', '23', '23231', '4413434', '愛知県', 'アイチケン', '田原市', 'タハラシ', 'ほると台', 'ホルトダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県田原市仁崎町', '23', '23231', '4413435', '愛知県', 'アイチケン', '田原市', 'タハラシ', '仁崎町', 'ニサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県田原市白浜', '23', '23231', '4413436', '愛知県', 'アイチケン', '田原市', 'タハラシ', '白浜', 'シラハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県田原市高松町', '23', '23231', '4413501', '愛知県', 'アイチケン', '田原市', 'タハラシ', '高松町', 'タカマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県田原市赤羽根町', '23', '23231', '4413502', '愛知県', 'アイチケン', '田原市', 'タハラシ', '赤羽根町', 'アカバネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県田原市若見町', '23', '23231', '4413503', '愛知県', 'アイチケン', '田原市', 'タハラシ', '若見町', 'ワカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県田原市越戸町', '23', '23231', '4413504', '愛知県', 'アイチケン', '田原市', 'タハラシ', '越戸町', 'オットチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県田原市池尻町', '23', '23231', '4413505', '愛知県', 'アイチケン', '田原市', 'タハラシ', '池尻町', 'イケシリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県田原市宇津江町', '23', '23231', '4413601', '愛知県', 'アイチケン', '田原市', 'タハラシ', '宇津江町', 'ウヅエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県田原市八王子町', '23', '23231', '4413602', '愛知県', 'アイチケン', '田原市', 'タハラシ', '八王子町', 'ハチオウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県田原市村松町', '23', '23231', '4413603', '愛知県', 'アイチケン', '田原市', 'タハラシ', '村松町', 'ムラマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県田原市伊川津町', '23', '23231', '4413604', '愛知県', 'アイチケン', '田原市', 'タハラシ', '伊川津町', 'イカワヅチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県田原市江比間町', '23', '23231', '4413605', '愛知県', 'アイチケン', '田原市', 'タハラシ', '江比間町', 'エヒマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県田原市馬伏町', '23', '23231', '4413606', '愛知県', 'アイチケン', '田原市', 'タハラシ', '馬伏町', 'バブシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県田原市夕陽が浜', '23', '23231', '4413607', '愛知県', 'アイチケン', '田原市', 'タハラシ', '夕陽が浜', 'ユウヒガハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県田原市折立町', '23', '23231', '4413608', '愛知県', 'アイチケン', '田原市', 'タハラシ', '折立町', 'オリタチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県田原市長沢町', '23', '23231', '4413609', '愛知県', 'アイチケン', '田原市', 'タハラシ', '長沢町', 'ナガサワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県田原市石神町', '23', '23231', '4413611', '愛知県', 'アイチケン', '田原市', 'タハラシ', '石神町', 'イシガミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県田原市高木町', '23', '23231', '4413612', '愛知県', 'アイチケン', '田原市', 'タハラシ', '高木町', 'タカキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県田原市古田町', '23', '23231', '4413613', '愛知県', 'アイチケン', '田原市', 'タハラシ', '古田町', 'コダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県田原市保美町', '23', '23231', '4413614', '愛知県', 'アイチケン', '田原市', 'タハラシ', '保美町', 'ホビチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県田原市中山町', '23', '23231', '4413615', '愛知県', 'アイチケン', '田原市', 'タハラシ', '中山町', 'ナカヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県田原市向山町', '23', '23231', '4413616', '愛知県', 'アイチケン', '田原市', 'タハラシ', '向山町', 'ムカイヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県田原市福江町', '23', '23231', '4413617', '愛知県', 'アイチケン', '田原市', 'タハラシ', '福江町', 'フクエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県田原市小中山町', '23', '23231', '4413618', '愛知県', 'アイチケン', '田原市', 'タハラシ', '小中山町', 'コナカヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県田原市西山町', '23', '23231', '4413619', '愛知県', 'アイチケン', '田原市', 'タハラシ', '西山町', 'ニシヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県田原市山田町', '23', '23231', '4413621', '愛知県', 'アイチケン', '田原市', 'タハラシ', '山田町', 'ヤマダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県田原市和地町', '23', '23231', '4413622', '愛知県', 'アイチケン', '田原市', 'タハラシ', '和地町', 'ワジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県田原市日出町', '23', '23231', '4413623', '愛知県', 'アイチケン', '田原市', 'タハラシ', '日出町', 'ヒイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県田原市伊良湖町', '23', '23231', '4413624', '愛知県', 'アイチケン', '田原市', 'タハラシ', '伊良湖町', 'イラゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県田原市亀山町', '23', '23231', '4413625', '愛知県', 'アイチケン', '田原市', 'タハラシ', '亀山町', 'カメヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県田原市小塩津町', '23', '23231', '4413626', '愛知県', 'アイチケン', '田原市', 'タハラシ', '小塩津町', 'コシオヅチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県田原市堀切町', '23', '23231', '4413627', '愛知県', 'アイチケン', '田原市', 'タハラシ', '堀切町', 'ホリキリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市野田町', '23', '23201', '4418001', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '野田町', 'ノダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市吉川町', '23', '23201', '4418002', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '吉川町', 'ヨシカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市小向町', '23', '23201', '4418003', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '小向町', 'コムカイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市吉前町', '23', '23201', '4418004', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '吉前町', 'ヨシザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市富久縞町', '23', '23201', '4418005', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '富久縞町', 'フクシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市高洲町', '23', '23201', '4418006', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '高洲町', 'タカスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市馬見塚町', '23', '23201', '4418007', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '馬見塚町', 'マミヅカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市三ツ相町', '23', '23201', '4418008', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '三ツ相町', 'ミツアイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市菰口町', '23', '23201', '4418011', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '菰口町', 'コモグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市羽田町', '23', '23201', '4418012', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '羽田町', 'ハダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市花田一番町', '23', '23201', '4418013', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '花田一番町', 'ハナダ01バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市花田二番町', '23', '23201', '4418014', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '花田二番町', 'ハナダ02バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市築地町', '23', '23201', '4418015', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '築地町', 'ツキジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市新栄町', '23', '23201', '4418016', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '新栄町', 'シンサカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市北側町', '23', '23201', '4418017', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '北側町', 'キタガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市花田三番町', '23', '23201', '4418018', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '花田三番町', 'ハナダ03バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市花田町', '23', '23201', '4418019', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '花田町', 'ハナダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市白河町', '23', '23201', '4418021', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '白河町', 'シラカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市野黒町', '23', '23201', '4418022', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '野黒町', 'ノグロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市八通町', '23', '23201', '4418023', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '八通町', 'ヤトオリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市花田町後田', '23', '23201', '4418024', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '花田町', 'ハナダチョウ', null, null, '後田', 'ウシロダ');
INSERT INTO `ms_addresses` VALUES ('41885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市花田町西郷', '23', '23201', '4418024', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '花田町', 'ハナダチョウ', null, null, '西郷', 'サイゴウ');
INSERT INTO `ms_addresses` VALUES ('41886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市花田町中郷', '23', '23201', '4418024', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '花田町', 'ハナダチョウ', null, null, '中郷', 'ナカゴウ');
INSERT INTO `ms_addresses` VALUES ('41887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市羽根井町', '23', '23201', '4418025', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '羽根井町', 'ハネイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市羽根井西町', '23', '23201', '4418026', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '羽根井西町', 'ハネイニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市錦町', '23', '23201', '4418027', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '錦町', 'ニシキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市立花町', '23', '23201', '4418028', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '立花町', 'タチバナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市羽根井本町', '23', '23201', '4418029', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '羽根井本町', 'ハネイホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市中郷町', '23', '23201', '4418031', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '中郷町', 'ナカゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市花中町', '23', '23201', '4418032', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '花中町', 'ハナナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市入船町', '23', '23201', '4418033', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '入船町', 'イリフネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市松村町', '23', '23201', '4418034', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '松村町', 'マツムラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市有楽町', '23', '23201', '4418035', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '有楽町', 'ユウラクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市東橋良町', '23', '23201', '4418036', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '東橋良町', 'ヒガシハシラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市中橋良町', '23', '23201', '4418037', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '中橋良町', 'ナカハシラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市堂坂町', '23', '23201', '4418038', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '堂坂町', 'ドウザカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市西橋良町', '23', '23201', '4418039', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '西橋良町', 'ニシハシラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市柳生町', '23', '23201', '4418041', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '柳生町', 'ヤギュウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市小池町', '23', '23201', '4418042', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '小池町', 'コイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市高師石塚町', '23', '23201', '4418043', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '高師石塚町', 'タカシイシヅカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市南小池町', '23', '23201', '4418044', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '南小池町', 'ミナミコイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市北丘町', '23', '23201', '4418045', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '北丘町', 'キタオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市福岡町', '23', '23201', '4418046', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '福岡町', 'フクオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市鴨田町', '23', '23201', '4418047', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '鴨田町', 'カモダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市西小池町', '23', '23201', '4418048', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '西小池町', 'ニシコイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市柱四番町', '23', '23201', '4418051', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '柱四番町', 'ハシラ04バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市柱三番町', '23', '23201', '4418052', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '柱三番町', 'ハシラ03バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市柱二番町', '23', '23201', '4418053', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '柱二番町', 'ハシラ02バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市柱一番町', '23', '23201', '4418054', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '柱一番町', 'ハシラ01バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市柱九番町', '23', '23201', '4418055', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '柱九番町', 'ハシラ09バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市柱八番町', '23', '23201', '4418056', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '柱八番町', 'ハシラ08バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市柱七番町', '23', '23201', '4418057', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '柱七番町', 'ハシラ07バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市柱六番町', '23', '23201', '4418058', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '柱六番町', 'ハシラ06バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市柱五番町', '23', '23201', '4418059', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '柱五番町', 'ハシラ05バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市藤沢町', '23', '23201', '4418061', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '藤沢町', 'フジサワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市東小浜町', '23', '23201', '4418062', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '東小浜町', 'ヒガシコハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市橋良町', '23', '23201', '4418063', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '橋良町', 'ハシラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市富本町', '23', '23201', '4418064', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '富本町', 'トミモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市中浜町', '23', '23201', '4418065', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '中浜町', 'ナカハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市王ケ崎町', '23', '23201', '4418066', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '王ケ崎町', 'オガサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市小浜町', '23', '23201', '4418067', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '小浜町', 'コハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市神ノ輪町', '23', '23201', '4418068', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '神ノ輪町', 'カミノワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市潮崎町', '23', '23201', '4418069', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '潮崎町', 'シオザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市大山町', '23', '23201', '4418071', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '大山町', 'オオヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市船渡町', '23', '23201', '4418072', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '船渡町', 'フナトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市大崎町', '23', '23201', '4418073', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '大崎町', 'オオサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市明海町', '23', '23201', '4418074', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '明海町', 'アケミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市神野ふ頭町', '23', '23201', '4418075', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '神野ふ頭町', 'ジンノフトウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市神野西町', '23', '23201', '4418076', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '神野西町', 'ジンノニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市神野新田町', '23', '23201', '4418077', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '神野新田町', 'ジンノシンデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市西羽田町', '23', '23201', '4418081', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '西羽田町', 'ニシハダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市往完町', '23', '23201', '4418082', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '往完町', 'オウカンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市東脇', '23', '23201', '4418083', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '東脇', 'ヒガシワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市市場', '23', '23201', '4418084', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '市場', 'イチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市青竹町', '23', '23201', '4418085', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '青竹町', 'アオタケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市問屋町', '23', '23201', '4418086', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '問屋町', 'トンヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市牟呂町', '23', '23201', '4418087', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '牟呂町', 'ムロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市牟呂市場町', '23', '23201', '4418088', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '牟呂市場町', 'ムロイチバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市牟呂大西町', '23', '23201', '4418089', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '牟呂大西町', 'ムロオオニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市牟呂公文町', '23', '23201', '4418090', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '牟呂公文町', 'ムロクモンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市牟呂水神町', '23', '23201', '4418091', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '牟呂水神町', 'ムロスイジンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市牟呂外神町', '23', '23201', '4418092', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '牟呂外神町', 'ムロトガミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市牟呂中村町', '23', '23201', '4418093', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '牟呂中村町', 'ムロナカムラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市山田町郷', '23', '23201', '4418101', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '山田町', 'ヤマダチョウ', null, null, '郷', 'ゴウ');
INSERT INTO `ms_addresses` VALUES ('41948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市山田町瀬戸', '23', '23201', '4418101', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '山田町', 'ヤマダチョウ', null, null, '瀬戸', 'セト');
INSERT INTO `ms_addresses` VALUES ('41949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市山田町西山', '23', '23201', '4418101', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '山田町', 'ヤマダチョウ', null, null, '西山', 'ニシヤマ');
INSERT INTO `ms_addresses` VALUES ('41950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市山田一番町', '23', '23201', '4418102', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '山田一番町', 'ヤマダ01バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市山田三番町', '23', '23201', '4418103', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '山田三番町', 'ヤマダ03バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市山田二番町', '23', '23201', '4418104', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '山田二番町', 'ヤマダ02バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市北山町', '23', '23201', '4418105', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '北山町', 'キタヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市弥生町', '23', '23201', '4418106', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '弥生町', 'ヤヨイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市南栄町', '23', '23201', '4418107', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '南栄町', 'ミナミサカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市町畑町', '23', '23201', '4418108', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '町畑町', 'マチハタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市小松町', '23', '23201', '4418109', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '小松町', 'コマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市江島町', '23', '23201', '4418111', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '江島町', 'エジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市牧野町', '23', '23201', '4418112', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '牧野町', 'マキノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市西幸町', '23', '23201', '4418113', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '西幸町', 'ニシミユキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市藤並町', '23', '23201', '4418114', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '藤並町', 'フジナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市東高田町', '23', '23201', '4418115', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '東高田町', 'ヒガシタカダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市高田町', '23', '23201', '4418116', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '高田町', 'タカダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市浜道町', '23', '23201', '4418117', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '浜道町', 'ハマミチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市畑ケ田町', '23', '23201', '4418121', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '畑ケ田町', 'ハタケダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市天伯町', '23', '23201', '4418122', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '天伯町', 'テンパクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市若松町', '23', '23201', '4418123', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '若松町', 'ワカマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市野依町', '23', '23201', '4418124', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '野依町', 'ノヨリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市野依台', '23', '23201', '4418125', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '野依台', 'ノヨリダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市東大清水町', '23', '23201', '4418131', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '東大清水町', 'ヒガシオオシミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市南大清水町', '23', '23201', '4418132', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '南大清水町', 'ミナミオオシミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市大清水町', '23', '23201', '4418133', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '大清水町', 'オオシミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市植田町', '23', '23201', '4418134', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '植田町', 'ウエタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市富士見台', '23', '23201', '4418135', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '富士見台', 'フジミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市草間町', '23', '23201', '4418141', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '草間町', 'クサマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市向草間町', '23', '23201', '4418142', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '向草間町', 'ムコウクサマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市松井町', '23', '23201', '4418143', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '松井町', 'マツイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市磯辺下地町', '23', '23201', '4418144', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '磯辺下地町', 'イソベシタジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市駒形町', '23', '23201', '4418145', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '駒形町', 'コマガタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市城山町', '23', '23201', '4418146', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '城山町', 'シロヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市内張町', '23', '23201', '4418147', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '内張町', 'ウチバリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市一色町', '23', '23201', '4418148', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '一色町', 'イッシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市中野町', '23', '23201', '4418149', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '中野町', 'ナカノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市曙町', '23', '23201', '4418151', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '曙町', 'アケボノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市三本木町', '23', '23201', '4418152', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '三本木町', 'サンボンギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市高師本郷町', '23', '23201', '4418153', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '高師本郷町', 'タカシホンゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市西高師町', '23', '23201', '4418154', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '西高師町', 'ニシタカシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市芦原町', '23', '23201', '4418155', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '芦原町', 'アシハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('41989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市高師町小野', '23', '23201', '4418156', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '高師町', 'タカシチョウ', null, null, '小野', 'オノ');
INSERT INTO `ms_addresses` VALUES ('41990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市高師町北新切', '23', '23201', '4418156', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '高師町', 'タカシチョウ', null, null, '北新切', 'キタシンキリ');
INSERT INTO `ms_addresses` VALUES ('41991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市高師町北原', '23', '23201', '4418156', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '高師町', 'タカシチョウ', null, null, '北原', 'キタハラ');
INSERT INTO `ms_addresses` VALUES ('41992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市高師町西沢', '23', '23201', '4418156', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '高師町', 'タカシチョウ', null, null, '西沢', 'ニシザワ');
INSERT INTO `ms_addresses` VALUES ('41993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊橋市上野町', '23', '23201', '4418157', '愛知県', 'アイチケン', '豊橋市', 'トヨハシシ', '上野町', 'ウエノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市', '23', '23207', '4420000', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('42029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市千両町', '23', '23207', '4420001', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '千両町', 'チギリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市六角町', '23', '23207', '4420002', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '六角町', 'ロッカクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市長草町', '23', '23207', '4420003', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '長草町', 'ナガクサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市樽井町', '23', '23207', '4420004', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '樽井町', 'タルイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市本野ケ原', '23', '23207', '4420005', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '本野ケ原', 'ホンノガハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市三蔵子町', '23', '23207', '4420006', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '三蔵子町', 'サンゾウゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市大崎町', '23', '23207', '4420007', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '大崎町', 'オオサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市南千両', '23', '23207', '4420008', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '南千両', 'ミナミチギリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市東曙町', '23', '23207', '4420011', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '東曙町', 'ヒガシアケボノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市新豊町', '23', '23207', '4420012', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '新豊町', 'シンユタカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市大堀町', '23', '23207', '4420013', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '大堀町', 'オオボリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市豊栄町', '23', '23207', '4420014', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '豊栄町', 'ホウエイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市曙町', '23', '23207', '4420015', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '曙町', 'アケボノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市美幸町', '23', '23207', '4420016', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '美幸町', 'ミユキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市佐土町', '23', '23207', '4420017', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '佐土町', 'サドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市白雲町', '23', '23207', '4420018', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '白雲町', 'シラクモチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市東名町', '23', '23207', '4420019', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '東名町', 'トウメイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市小桜町', '23', '23207', '4420021', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '小桜町', 'コザクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市東光町', '23', '23207', '4420022', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '東光町', 'トウコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市稲荷通', '23', '23207', '4420023', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '稲荷通', 'イナリドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市西豊町', '23', '23207', '4420024', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '西豊町', 'ニシユタカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市東豊町', '23', '23207', '4420025', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '東豊町', 'ヒガシユタカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市東新町', '23', '23207', '4420026', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '東新町', 'トウシンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市桜木通', '23', '23207', '4420027', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '桜木通', 'サクラギドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市東桜木町', '23', '23207', '4420028', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '東桜木町', 'ヒガシサクラギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市末広通', '23', '23207', '4420029', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '末広通', 'スエヒロドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市豊川西町', '23', '23207', '4420031', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '豊川西町', 'トヨカワニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市豊川仲町', '23', '23207', '4420032', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '豊川仲町', 'トヨカワナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市豊川町', '23', '23207', '4420033', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '豊川町', 'トヨカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市西本町', '23', '23207', '4420034', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '西本町', 'ニシホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市豊川元町', '23', '23207', '4420035', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '豊川元町', 'トヨカワモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市豊川栄町', '23', '23207', '4420036', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '豊川栄町', 'トヨカワサカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市門前町', '23', '23207', '4420037', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '門前町', 'モンゼンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市光陽町', '23', '23207', '4420038', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '光陽町', 'コウヨウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市天神町', '23', '23207', '4420039', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '天神町', 'テンジンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市旭町', '23', '23207', '4420041', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '旭町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市北浦町', '23', '23207', '4420042', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '北浦町', 'キタウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市新宿町', '23', '23207', '4420043', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '新宿町', 'シンジュクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市二見町', '23', '23207', '4420044', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '二見町', 'フタミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市駅前通', '23', '23207', '4420045', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '駅前通', 'エキマエドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市幸町', '23', '23207', '4420046', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市若宮町', '23', '23207', '4420047', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '若宮町', 'ワカミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市開運通', '23', '23207', '4420048', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '開運通', 'カイウンドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市緑町', '23', '23207', '4420049', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '緑町', 'ミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市中央通', '23', '23207', '4420051', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '中央通', 'チュウオウドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市金屋本町', '23', '23207', '4420052', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '金屋本町', 'カナヤホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市金屋町', '23', '23207', '4420053', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '金屋町', 'カナヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市赤代町', '23', '23207', '4420054', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '赤代町', 'アカシロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市金屋橋町', '23', '23207', '4420055', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '金屋橋町', 'カナヤバシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市穂ノ原', '23', '23207', '4420061', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '穂ノ原', 'ホノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市本野町', '23', '23207', '4420062', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '本野町', 'ホンノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市西桜木町', '23', '23207', '4420063', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '西桜木町', 'ニシサクラギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市桜ケ丘町', '23', '23207', '4420064', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '桜ケ丘町', 'サクラガオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市若鳩町', '23', '23207', '4420065', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '若鳩町', 'ワカバトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市金屋元町', '23', '23207', '4420066', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '金屋元町', 'カナヤモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市金屋西町', '23', '23207', '4420067', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '金屋西町', 'カナヤニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市諏訪', '23', '23207', '4420068', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '諏訪', 'スワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市諏訪西町', '23', '23207', '4420069', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '諏訪西町', 'スワニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市上野', '23', '23207', '4420801', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '上野', 'ウエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市麻生田町', '23', '23207', '4420802', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '麻生田町', 'アソウダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市向河原町', '23', '23207', '4420803', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '向河原町', 'ムコウガワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市二葉町', '23', '23207', '4420804', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '二葉町', 'フタバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市三谷原町', '23', '23207', '4420805', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '三谷原町', 'ミヤハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市牧野町', '23', '23207', '4420806', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '牧野町', 'マキノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市谷川町', '23', '23207', '4420807', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '谷川町', 'ヤガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市豊ケ丘町', '23', '23207', '4420808', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '豊ケ丘町', 'ユタカガオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市大橋町', '23', '23207', '4420809', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '大橋町', 'オオハシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市馬場町', '23', '23207', '4420811', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '馬場町', 'ババチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市三上町', '23', '23207', '4420812', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '三上町', 'ミカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市土筒町', '23', '23207', '4420813', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '土筒町', 'ドドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市院之子町', '23', '23207', '4420814', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '院之子町', 'インノコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市瀬木町', '23', '23207', '4420815', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '瀬木町', 'セギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市花井町', '23', '23207', '4420816', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '花井町', 'ハナイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市古宿町', '23', '23207', '4420817', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '古宿町', 'フルジュクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市中条町', '23', '23207', '4420818', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '中条町', 'チュウジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市住吉町', '23', '23207', '4420819', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '住吉町', 'スミヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市当古町', '23', '23207', '4420821', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '当古町', 'トウゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市行明町', '23', '23207', '4420822', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '行明町', 'ギョウメイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市正岡町', '23', '23207', '4420823', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '正岡町', 'マサオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市下長山町', '23', '23207', '4420824', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '下長山町', 'シモナガヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市美和通', '23', '23207', '4420825', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '美和通', 'ミワドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市牛久保町', '23', '23207', '4420826', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '牛久保町', 'ウシクボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市西島町', '23', '23207', '4420827', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '西島町', 'ニシジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市柑子町', '23', '23207', '4420828', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '柑子町', 'コウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市弥生町', '23', '23207', '4420831', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '弥生町', 'ヤヨイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市寿通', '23', '23207', '4420832', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '寿通', 'コトブキドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市西口町', '23', '23207', '4420833', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '西口町', 'ニシグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市西香ノ木町', '23', '23207', '4420834', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '西香ノ木町', 'ニシコウノギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市新桜町通', '23', '23207', '4420835', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '新桜町通', 'シンサクラマチドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市堺町', '23', '23207', '4420836', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '堺町', 'サカイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市川花町', '23', '23207', '4420837', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '川花町', 'カワハナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市西塚町', '23', '23207', '4420838', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '西塚町', 'ニシヅカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市四ツ谷町', '23', '23207', '4420839', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '四ツ谷町', 'ヨツヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市代田町', '23', '23207', '4420841', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '代田町', 'ダイダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市蔵子', '23', '23207', '4420842', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '蔵子', 'ゾウシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市桜町', '23', '23207', '4420843', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '桜町', 'サクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市小田渕町', '23', '23207', '4420844', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '小田渕町', 'オダブチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市為当町', '23', '23207', '4420845', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '為当町', 'タメトウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市森', '23', '23207', '4420846', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '森', 'モリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市白鳥', '23', '23207', '4420847', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '白鳥', 'シロトリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市白鳥町', '23', '23207', '4420848', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '白鳥町', 'シロトリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市野口町', '23', '23207', '4420851', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '野口町', 'ノグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市国府南', '23', '23207', '4420852', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '国府南', 'コウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市新青馬町', '23', '23207', '4420853', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '新青馬町', 'シンアオウマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市国府町', '23', '23207', '4420854', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '国府町', 'コウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市新栄町', '23', '23207', '4420855', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '新栄町', 'シンサカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市久保町', '23', '23207', '4420856', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '久保町', 'クボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市八幡町', '23', '23207', '4420857', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '八幡町', 'ヤワタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市財賀町', '23', '23207', '4420861', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '財賀町', 'ザイカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市市田町', '23', '23207', '4420862', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '市田町', 'イチダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市平尾町', '23', '23207', '4420863', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '平尾町', 'ヒラオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市松風町', '23', '23207', '4420871', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '松風町', 'マツカゼチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市金塚町', '23', '23207', '4420872', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '金塚町', 'カナヅカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市山道町', '23', '23207', '4420873', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '山道町', 'ヤマミチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市松久町', '23', '23207', '4420874', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '松久町', 'マツヒサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市佐奈川町', '23', '23207', '4420875', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '佐奈川町', 'サナガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市中部町', '23', '23207', '4420876', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '中部町', 'チュウブチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市下野川町', '23', '23207', '4420877', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '下野川町', 'シモノガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市新道町', '23', '23207', '4420878', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '新道町', 'シンミチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市萩山町', '23', '23207', '4420879', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '萩山町', 'ハギヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市塔ノ木町', '23', '23207', '4420881', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '塔ノ木町', 'トウノギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市光輝町', '23', '23207', '4420882', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '光輝町', 'コウキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市高見町', '23', '23207', '4420883', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '高見町', 'タカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市光明町', '23', '23207', '4420884', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '光明町', 'コウメイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市中野川町', '23', '23207', '4420885', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '中野川町', 'ナカノガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市牛久保駅通', '23', '23207', '4420886', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '牛久保駅通', 'ウシクボエキドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市明野町', '23', '23207', '4420887', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '明野町', 'アケノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市千歳通', '23', '23207', '4420888', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '千歳通', 'チトセドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊川市南大通', '23', '23207', '4420889', '愛知県', 'アイチケン', '豊川市', 'トヨカワシ', '南大通', 'ミナミオオドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県蒲郡市', '23', '23214', '4430000', '愛知県', 'アイチケン', '蒲郡市', 'ガマゴオリシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('42206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県蒲郡市坂本町', '23', '23214', '4430001', '愛知県', 'アイチケン', '蒲郡市', 'ガマゴオリシ', '坂本町', 'サカモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県蒲郡市清田町', '23', '23214', '4430002', '愛知県', 'アイチケン', '蒲郡市', 'ガマゴオリシ', '清田町', 'セイダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県蒲郡市五井町', '23', '23214', '4430003', '愛知県', 'アイチケン', '蒲郡市', 'ガマゴオリシ', '五井町', 'ゴイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県蒲郡市平田町', '23', '23214', '4430004', '愛知県', 'アイチケン', '蒲郡市', 'ガマゴオリシ', '平田町', 'ヒラタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県蒲郡市水竹町', '23', '23214', '4430005', '愛知県', 'アイチケン', '蒲郡市', 'ガマゴオリシ', '水竹町', 'ミズタケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県蒲郡市蒲郡町', '23', '23214', '4430006', '愛知県', 'アイチケン', '蒲郡市', 'ガマゴオリシ', '蒲郡町', 'ガマゴオリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県蒲郡市神ノ郷町', '23', '23214', '4430007', '愛知県', 'アイチケン', '蒲郡市', 'ガマゴオリシ', '神ノ郷町', 'カミノゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県蒲郡市柏原町', '23', '23214', '4430008', '愛知県', 'アイチケン', '蒲郡市', 'ガマゴオリシ', '柏原町', 'カシワバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県蒲郡市豊岡町', '23', '23214', '4430011', '愛知県', 'アイチケン', '蒲郡市', 'ガマゴオリシ', '豊岡町', 'トヨオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県蒲郡市相楽町', '23', '23214', '4430012', '愛知県', 'アイチケン', '蒲郡市', 'ガマゴオリシ', '相楽町', 'サガラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県蒲郡市大塚町', '23', '23214', '4430013', '愛知県', 'アイチケン', '蒲郡市', 'ガマゴオリシ', '大塚町', 'オオツカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県蒲郡市海陽町', '23', '23214', '4430014', '愛知県', 'アイチケン', '蒲郡市', 'ガマゴオリシ', '海陽町', 'カイヨウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県蒲郡市三谷町', '23', '23214', '4430021', '愛知県', 'アイチケン', '蒲郡市', 'ガマゴオリシ', '三谷町', 'ミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県蒲郡市三谷北通', '23', '23214', '4430022', '愛知県', 'アイチケン', '蒲郡市', 'ガマゴオリシ', '三谷北通', 'ミヤキタドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県蒲郡市竹島町', '23', '23214', '4430031', '愛知県', 'アイチケン', '蒲郡市', 'ガマゴオリシ', '竹島町', 'タケシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県蒲郡市丸山町', '23', '23214', '4430032', '愛知県', 'アイチケン', '蒲郡市', 'ガマゴオリシ', '丸山町', 'マルヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県蒲郡市松原町', '23', '23214', '4430033', '愛知県', 'アイチケン', '蒲郡市', 'ガマゴオリシ', '松原町', 'マツバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県蒲郡市港町', '23', '23214', '4430034', '愛知県', 'アイチケン', '蒲郡市', 'ガマゴオリシ', '港町', 'ミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県蒲郡市栄町', '23', '23214', '4430035', '愛知県', 'アイチケン', '蒲郡市', 'ガマゴオリシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県蒲郡市浜町', '23', '23214', '4430036', '愛知県', 'アイチケン', '蒲郡市', 'ガマゴオリシ', '浜町', 'ハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県蒲郡市鹿島町', '23', '23214', '4430037', '愛知県', 'アイチケン', '蒲郡市', 'ガマゴオリシ', '鹿島町', 'カシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県蒲郡市拾石町', '23', '23214', '4430038', '愛知県', 'アイチケン', '蒲郡市', 'ガマゴオリシ', '拾石町', 'ヒロイシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県蒲郡市宮成町', '23', '23214', '4430041', '愛知県', 'アイチケン', '蒲郡市', 'ガマゴオリシ', '宮成町', 'ミヤナリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県蒲郡市御幸町', '23', '23214', '4430042', '愛知県', 'アイチケン', '蒲郡市', 'ガマゴオリシ', '御幸町', 'ミユキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県蒲郡市元町', '23', '23214', '4430043', '愛知県', 'アイチケン', '蒲郡市', 'ガマゴオリシ', '元町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県蒲郡市宝町', '23', '23214', '4430044', '愛知県', 'アイチケン', '蒲郡市', 'ガマゴオリシ', '宝町', 'タカラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県蒲郡市旭町', '23', '23214', '4430045', '愛知県', 'アイチケン', '蒲郡市', 'ガマゴオリシ', '旭町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県蒲郡市竹谷町', '23', '23214', '4430046', '愛知県', 'アイチケン', '蒲郡市', 'ガマゴオリシ', '竹谷町', 'タケノヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県蒲郡市西迫町', '23', '23214', '4430047', '愛知県', 'アイチケン', '蒲郡市', 'ガマゴオリシ', '西迫町', 'ニシハサマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県蒲郡市緑町', '23', '23214', '4430048', '愛知県', 'アイチケン', '蒲郡市', 'ガマゴオリシ', '緑町', 'ミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県蒲郡市新井形町', '23', '23214', '4430051', '愛知県', 'アイチケン', '蒲郡市', 'ガマゴオリシ', '新井形町', 'アライガタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県蒲郡市新井町', '23', '23214', '4430052', '愛知県', 'アイチケン', '蒲郡市', 'ガマゴオリシ', '新井町', 'アライチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県蒲郡市堀込町', '23', '23214', '4430053', '愛知県', 'アイチケン', '蒲郡市', 'ガマゴオリシ', '堀込町', 'ホリゴミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県蒲郡市府相町', '23', '23214', '4430054', '愛知県', 'アイチケン', '蒲郡市', 'ガマゴオリシ', '府相町', 'フソウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県蒲郡市八百富町', '23', '23214', '4430055', '愛知県', 'アイチケン', '蒲郡市', 'ガマゴオリシ', '八百富町', 'ヤオトミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県蒲郡市神明町', '23', '23214', '4430056', '愛知県', 'アイチケン', '蒲郡市', 'ガマゴオリシ', '神明町', 'シンメイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県蒲郡市中央本町', '23', '23214', '4430057', '愛知県', 'アイチケン', '蒲郡市', 'ガマゴオリシ', '中央本町', 'チュウオウホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県蒲郡市上本町', '23', '23214', '4430058', '愛知県', 'アイチケン', '蒲郡市', 'ガマゴオリシ', '上本町', 'ウエホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県蒲郡市本町', '23', '23214', '4430059', '愛知県', 'アイチケン', '蒲郡市', 'ガマゴオリシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県蒲郡市一色町', '23', '23214', '4430101', '愛知県', 'アイチケン', '蒲郡市', 'ガマゴオリシ', '一色町', 'イシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県蒲郡市金平町', '23', '23214', '4430102', '愛知県', 'アイチケン', '蒲郡市', 'ガマゴオリシ', '金平町', 'カネヒラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県蒲郡市形原町北浜', '23', '23214', '4430103', '愛知県', 'アイチケン', '蒲郡市', 'ガマゴオリシ', '形原町北浜', 'カタハラチョウキタハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県蒲郡市形原町', '23', '23214', '4430104', '愛知県', 'アイチケン', '蒲郡市', 'ガマゴオリシ', '形原町', 'カタハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県蒲郡市西浦町', '23', '23214', '4430105', '愛知県', 'アイチケン', '蒲郡市', 'ガマゴオリシ', '西浦町', 'ニシウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県蒲郡市形原町春日浦', '23', '23214', '4430106', '愛知県', 'アイチケン', '蒲郡市', 'ガマゴオリシ', '形原町春日浦', 'カタハラチョウカスガウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市', '23', '23202', '4440000', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('42258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市箱柳町', '23', '23202', '4440001', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '箱柳町', 'ハコヤナギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市高隆寺町', '23', '23202', '4440002', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '高隆寺町', 'コウリュウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市小美町', '23', '23202', '4440003', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '小美町', 'オイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市保母町', '23', '23202', '4440004', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '保母町', 'ホボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市岡町', '23', '23202', '4440005', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '岡町', 'オカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市丸山町', '23', '23202', '4440006', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '丸山町', 'マルヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市大平町', '23', '23202', '4440007', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '大平町', 'オオヒラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市洞町', '23', '23202', '4440008', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '洞町', 'ホラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市小呂町', '23', '23202', '4440009', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '小呂町', 'オロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市欠町', '23', '23202', '4440011', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '欠町', 'カケマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市栄町', '23', '23202', '4440012', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市根石町', '23', '23202', '4440013', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '根石町', 'ネイシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市若宮町', '23', '23202', '4440014', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '若宮町', 'ワカミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市中町', '23', '23202', '4440015', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '中町', 'ナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市元欠町', '23', '23202', '4440016', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '元欠町', 'モトカケマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市蓬莱町', '23', '23202', '4440021', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '蓬莱町', 'ホウライチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市朝日町', '23', '23202', '4440022', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '朝日町', 'アサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市両町', '23', '23202', '4440023', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '両町', 'リョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市西中町', '23', '23202', '4440024', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '西中町', 'ニシナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市曙町', '23', '23202', '4440025', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '曙町', 'アケボノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市梅園町', '23', '23202', '4440031', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '梅園町', 'ウメゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市門前町', '23', '23202', '4440032', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '門前町', 'モンゼンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市久右ヱ門町', '23', '23202', '4440033', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '久右ヱ門町', 'キュウエモンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市十王町', '23', '23202', '4440034', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '十王町', 'ジュウオウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市菅生町', '23', '23202', '4440035', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '菅生町', 'スゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市島町', '23', '23202', '4440036', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '島町', 'シマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市祐金町', '23', '23202', '4440037', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '祐金町', 'ユウキンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市伝馬通', '23', '23202', '4440038', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '伝馬通', 'テンマドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市花崗町', '23', '23202', '4440039', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '花崗町', 'ミカゲチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市籠田町', '23', '23202', '4440041', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '籠田町', 'カゴダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市六地蔵町', '23', '23202', '4440042', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '六地蔵町', 'ロクジゾウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市唐沢町', '23', '23202', '4440043', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '唐沢町', 'カラサワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市康生通南', '23', '23202', '4440044', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '康生通南', 'コウセイドオリミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市康生通東', '23', '23202', '4440045', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '康生通東', 'コウセイドオリヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市連尺通', '23', '23202', '4440046', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '連尺通', 'レンジャクドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市八幡町', '23', '23202', '4440047', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '八幡町', 'ハチマンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市六供本町', '23', '23202', '4440048', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '六供本町', 'ロックホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市亀井町', '23', '23202', '4440049', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '亀井町', 'カメイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市本町通', '23', '23202', '4440051', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '本町通', 'ホンマチドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市康生町', '23', '23202', '4440052', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '康生町', 'コウセイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市板屋町', '23', '23202', '4440053', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '板屋町', 'イタヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市田町', '23', '23202', '4440054', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '田町', 'タマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市西魚町', '23', '23202', '4440055', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '西魚町', 'ニシウオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市福寿町', '23', '23202', '4440056', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '福寿町', 'フクジュチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市材木町', '23', '23202', '4440057', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '材木町', 'ザイモクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市魚町', '23', '23202', '4440058', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '魚町', 'ウオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市康生通西', '23', '23202', '4440059', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '康生通西', 'コウセイドオリニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市能見町', '23', '23202', '4440061', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '能見町', 'ノミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市松本町', '23', '23202', '4440062', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '松本町', 'マツモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市元能見町', '23', '23202', '4440063', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '元能見町', 'モトノミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市城北町', '23', '23202', '4440064', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '城北町', 'ジョウホクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市柿田町', '23', '23202', '4440065', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '柿田町', 'カキタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市広幡町', '23', '23202', '4440066', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '広幡町', 'ヒロハタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市錦町', '23', '23202', '4440067', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '錦町', 'ニシキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市井田南町', '23', '23202', '4440068', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '井田南町', 'イダミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市井田新町', '23', '23202', '4440069', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '井田新町', 'イダシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市稲熊町', '23', '23202', '4440071', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '稲熊町', 'イナグマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市六供町', '23', '23202', '4440072', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '六供町', 'ロックチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市能見通', '23', '23202', '4440073', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '能見通', 'ノミドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市東能見町', '23', '23202', '4440074', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '東能見町', 'ヒガシノミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市伊賀町', '23', '23202', '4440075', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '伊賀町', 'イガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市井田町', '23', '23202', '4440076', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '井田町', 'イダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市井田町茨坪', '23', '23202', '4440077', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '井田町茨坪', 'イダチョウバラツボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市伊賀新町', '23', '23202', '4440078', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '伊賀新町', 'イガシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市石神町', '23', '23202', '4440079', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '石神町', 'イシガミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県額田郡幸田町', '23', '23501', '4440100', '愛知県', 'アイチケン', '額田郡幸田町', 'ヌカタグンコウタチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('42324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県額田郡幸田町長嶺', '23', '23501', '4440101', '愛知県', 'アイチケン', '額田郡幸田町', 'ヌカタグンコウタチョウ', '長嶺', 'ナガミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県額田郡幸田町久保田', '23', '23501', '4440102', '愛知県', 'アイチケン', '額田郡幸田町', 'ヌカタグンコウタチョウ', '久保田', 'クボタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県額田郡幸田町大草', '23', '23501', '4440103', '愛知県', 'アイチケン', '額田郡幸田町', 'ヌカタグンコウタチョウ', '大草', 'オオクサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県額田郡幸田町坂崎', '23', '23501', '4440104', '愛知県', 'アイチケン', '額田郡幸田町', 'ヌカタグンコウタチョウ', '坂崎', 'サカザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県額田郡幸田町高力', '23', '23501', '4440111', '愛知県', 'アイチケン', '額田郡幸田町', 'ヌカタグンコウタチョウ', '高力', 'コウリキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県額田郡幸田町北鷲田', '23', '23501', '4440112', '愛知県', 'アイチケン', '額田郡幸田町', 'ヌカタグンコウタチョウ', '北鷲田', 'キタワシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県額田郡幸田町菱池', '23', '23501', '4440113', '愛知県', 'アイチケン', '額田郡幸田町', 'ヌカタグンコウタチョウ', '菱池', 'ヒシイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県額田郡幸田町横落', '23', '23501', '4440114', '愛知県', 'アイチケン', '額田郡幸田町', 'ヌカタグンコウタチョウ', '横落', 'ヨコオチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県額田郡幸田町荻', '23', '23501', '4440115', '愛知県', 'アイチケン', '額田郡幸田町', 'ヌカタグンコウタチョウ', '荻', 'オギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県額田郡幸田町芦谷', '23', '23501', '4440116', '愛知県', 'アイチケン', '額田郡幸田町', 'ヌカタグンコウタチョウ', '芦谷', 'アシノヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県額田郡幸田町永野', '23', '23501', '4440121', '愛知県', 'アイチケン', '額田郡幸田町', 'ヌカタグンコウタチョウ', '永野', 'ナガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県額田郡幸田町六栗', '23', '23501', '4440122', '愛知県', 'アイチケン', '額田郡幸田町', 'ヌカタグンコウタチョウ', '六栗', 'ムツグリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県額田郡幸田町上六栗', '23', '23501', '4440123', '愛知県', 'アイチケン', '額田郡幸田町', 'ヌカタグンコウタチョウ', '上六栗', 'カミムツグリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県額田郡幸田町深溝', '23', '23501', '4440124', '愛知県', 'アイチケン', '額田郡幸田町', 'ヌカタグンコウタチョウ', '深溝', 'フコウズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県額田郡幸田町逆川', '23', '23501', '4440125', '愛知県', 'アイチケン', '額田郡幸田町', 'ヌカタグンコウタチョウ', '逆川', 'サカサガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県額田郡幸田町桐山', '23', '23501', '4440126', '愛知県', 'アイチケン', '額田郡幸田町', 'ヌカタグンコウタチョウ', '桐山', 'キリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県額田郡幸田町須美', '23', '23501', '4440127', '愛知県', 'アイチケン', '額田郡幸田町', 'ヌカタグンコウタチョウ', '須美', 'スミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県額田郡幸田町野場', '23', '23501', '4440128', '愛知県', 'アイチケン', '額田郡幸田町', 'ヌカタグンコウタチョウ', '野場', 'ノバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市上和田町', '23', '23202', '4440201', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '上和田町', 'カミワダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市宮地町', '23', '23202', '4440202', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '宮地町', 'ミヤジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市井内町', '23', '23202', '4440203', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '井内町', 'イナイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市土井町', '23', '23202', '4440204', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '土井町', 'ドイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市牧御堂町', '23', '23202', '4440205', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '牧御堂町', 'マキミドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市法性寺町', '23', '23202', '4440206', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '法性寺町', 'ホツショウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市野畑町', '23', '23202', '4440211', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '野畑町', 'ノバタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市下和田町', '23', '23202', '4440212', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '下和田町', 'シモワダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市坂左右町', '23', '23202', '4440213', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '坂左右町', 'サカソウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市国正町', '23', '23202', '4440214', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '国正町', 'クニマサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市中村町', '23', '23202', '4440215', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '中村町', 'ナカムラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市定国町', '23', '23202', '4440216', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '定国町', 'サダクニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市正名町', '23', '23202', '4440221', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '正名町', 'ショウナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市二軒屋町', '23', '23202', '4440222', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '二軒屋町', 'ニケンヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市中島東町', '23', '23202', '4440223', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '中島東町', 'ナカジマヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市中島中町', '23', '23202', '4440224', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '中島中町', 'ナカジマナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市中島西町', '23', '23202', '4440225', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '中島西町', 'ナカジマニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市中島町', '23', '23202', '4440226', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '中島町', 'ナカジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市高橋町', '23', '23202', '4440231', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '高橋町', 'タカハシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市合歓木町', '23', '23202', '4440232', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '合歓木町', 'ネムノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市福桶町', '23', '23202', '4440233', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '福桶町', 'フクオケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市安藤町', '23', '23202', '4440234', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '安藤町', 'アンドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市赤渋町', '23', '23202', '4440241', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '赤渋町', 'アカシブチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市中之郷町', '23', '23202', '4440242', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '中之郷町', 'ナカノゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市上青野町', '23', '23202', '4440243', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '上青野町', 'カミアオノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市下青野町', '23', '23202', '4440244', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '下青野町', 'シモアオノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市在家町', '23', '23202', '4440245', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '在家町', 'ザイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市上三ツ木町', '23', '23202', '4440246', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '上三ツ木町', 'カミミツギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市下三ツ木町', '23', '23202', '4440247', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '下三ツ木町', 'シモミツギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市田貫町', '23', '23213', '4440301', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '田貫町', 'タヌキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市田貫', '23', '23213', '4440302', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '田貫', 'タヌキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市中畑町', '23', '23213', '4440303', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '中畑町', 'ナカバタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市中畑', '23', '23213', '4440304', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '中畑', 'ナカバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市平坂町', '23', '23213', '4440305', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '平坂町', 'ヘイサカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市新在家町', '23', '23213', '4440311', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '新在家町', 'シンザイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市国森町', '23', '23213', '4440312', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '国森町', 'クニモリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市上矢田町', '23', '23213', '4440313', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '上矢田町', 'カミヤタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市下矢田町', '23', '23213', '4440314', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '下矢田町', 'シモヤタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市徳永町', '23', '23213', '4440315', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '徳永町', 'トクナガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市羽塚町', '23', '23213', '4440316', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '羽塚町', 'ハツカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市刈宿町', '23', '23213', '4440321', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '刈宿町', 'カリヤドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市巨海町', '23', '23213', '4440322', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '巨海町', 'コミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市中根町', '23', '23213', '4440323', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '中根町', 'ナカネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市寺津町', '23', '23213', '4440324', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '寺津町', 'テラヅチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市楠村町', '23', '23213', '4440325', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '楠村町', 'クスムラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市富山町', '23', '23213', '4440326', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '富山町', 'トミヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市寺津', '23', '23213', '4440327', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '寺津', 'テラヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市西小梛町', '23', '23213', '4440331', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '西小梛町', 'ニシコナギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市小栗町', '23', '23213', '4440332', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '小栗町', 'オグリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市奥田町', '23', '23213', '4440333', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '奥田町', 'オクダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市南奥田町', '23', '23213', '4440334', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '南奥田町', 'ミナミオクダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市港町', '23', '23213', '4440335', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '港町', 'ミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市西奥田町', '23', '23213', '4440336', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '西奥田町', 'ニシオクダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県幡豆郡一色町', '23', '23481', '4440400', '愛知県', 'アイチケン', '幡豆郡一色町', 'ハズグンイッシキチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('42408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県幡豆郡一色町池田', '23', '23481', '4440401', '愛知県', 'アイチケン', '幡豆郡一色町', 'ハズグンイッシキチョウ', '池田', 'イケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県幡豆郡一色町大塚', '23', '23481', '4440402', '愛知県', 'アイチケン', '幡豆郡一色町', 'ハズグンイッシキチョウ', '大塚', 'オオツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県幡豆郡一色町松木島', '23', '23481', '4440403', '愛知県', 'アイチケン', '幡豆郡一色町', 'ハズグンイッシキチョウ', '松木島', 'マツキジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県幡豆郡一色町野田', '23', '23481', '4440404', '愛知県', 'アイチケン', '幡豆郡一色町', 'ハズグンイッシキチョウ', '野田', 'ノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県幡豆郡一色町惣五郎', '23', '23481', '4440405', '愛知県', 'アイチケン', '幡豆郡一色町', 'ハズグンイッシキチョウ', '惣五郎', 'ソウゴロウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県幡豆郡一色町対米', '23', '23481', '4440406', '愛知県', 'アイチケン', '幡豆郡一色町', 'ハズグンイッシキチョウ', '対米', 'ツイゴメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県幡豆郡一色町前野', '23', '23481', '4440407', '愛知県', 'アイチケン', '幡豆郡一色町', 'ハズグンイッシキチョウ', '前野', 'マエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県幡豆郡一色町千間', '23', '23481', '4440411', '愛知県', 'アイチケン', '幡豆郡一色町', 'ハズグンイッシキチョウ', '千間', 'センゲン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県幡豆郡一色町生田', '23', '23481', '4440412', '愛知県', 'アイチケン', '幡豆郡一色町', 'ハズグンイッシキチョウ', '生田', 'イクタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県幡豆郡一色町坂田新田', '23', '23481', '4440413', '愛知県', 'アイチケン', '幡豆郡一色町', 'ハズグンイッシキチョウ', '坂田新田', 'サカタシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県幡豆郡一色町藤江', '23', '23481', '4440414', '愛知県', 'アイチケン', '幡豆郡一色町', 'ハズグンイッシキチョウ', '藤江', 'フジエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県幡豆郡一色町酒手島', '23', '23481', '4440415', '愛知県', 'アイチケン', '幡豆郡一色町', 'ハズグンイッシキチョウ', '酒手島', 'サカテジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県幡豆郡一色町佐久島', '23', '23481', '4440416', '愛知県', 'アイチケン', '幡豆郡一色町', 'ハズグンイッシキチョウ', '佐久島', 'サクシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県幡豆郡一色町開正', '23', '23481', '4440421', '愛知県', 'アイチケン', '幡豆郡一色町', 'ハズグンイッシキチョウ', '開正', 'カイショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県幡豆郡一色町味浜', '23', '23481', '4440422', '愛知県', 'アイチケン', '幡豆郡一色町', 'ハズグンイッシキチョウ', '味浜', 'アジハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県幡豆郡一色町一色', '23', '23481', '4440423', '愛知県', 'アイチケン', '幡豆郡一色町', 'ハズグンイッシキチョウ', '一色', 'イッシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県幡豆郡一色町小薮', '23', '23481', '4440424', '愛知県', 'アイチケン', '幡豆郡一色町', 'ハズグンイッシキチョウ', '小薮', 'コヤブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県幡豆郡一色町細川', '23', '23481', '4440425', '愛知県', 'アイチケン', '幡豆郡一色町', 'ハズグンイッシキチョウ', '細川', 'ホソカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県幡豆郡一色町治明', '23', '23481', '4440426', '愛知県', 'アイチケン', '幡豆郡一色町', 'ハズグンイッシキチョウ', '治明', 'ジメイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県幡豆郡一色町赤羽', '23', '23481', '4440427', '愛知県', 'アイチケン', '幡豆郡一色町', 'ハズグンイッシキチョウ', '赤羽', 'アカバネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県幡豆郡一色町中外沢', '23', '23481', '4440428', '愛知県', 'アイチケン', '幡豆郡一色町', 'ハズグンイッシキチョウ', '中外沢', 'ナカトザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県幡豆郡一色町養ケ島', '23', '23481', '4440429', '愛知県', 'アイチケン', '幡豆郡一色町', 'ハズグンイッシキチョウ', '養ケ島', 'ヨガシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県幡豆郡吉良町', '23', '23482', '4440500', '愛知県', 'アイチケン', '幡豆郡吉良町', 'ハズグンキラチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('42436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県幡豆郡吉良町駮馬', '23', '23482', '4440501', '愛知県', 'アイチケン', '幡豆郡吉良町', 'ハズグンキラチョウ', '駮馬', 'マダラメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県幡豆郡吉良町宮迫', '23', '23482', '4440502', '愛知県', 'アイチケン', '幡豆郡吉良町', 'ハズグンキラチョウ', '宮迫', 'ミヤバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県幡豆郡吉良町津平', '23', '23482', '4440503', '愛知県', 'アイチケン', '幡豆郡吉良町', 'ハズグンキラチョウ', '津平', 'ツヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県幡豆郡吉良町友国', '23', '23482', '4440504', '愛知県', 'アイチケン', '幡豆郡吉良町', 'ハズグンキラチョウ', '友国', 'トモクニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県幡豆郡吉良町小山田', '23', '23482', '4440511', '愛知県', 'アイチケン', '幡豆郡吉良町', 'ハズグンキラチョウ', '小山田', 'オヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県幡豆郡吉良町乙川', '23', '23482', '4440512', '愛知県', 'アイチケン', '幡豆郡吉良町', 'ハズグンキラチョウ', '乙川', 'オツカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県幡豆郡吉良町宮崎', '23', '23482', '4440513', '愛知県', 'アイチケン', '幡豆郡吉良町', 'ハズグンキラチョウ', '宮崎', 'ミヤザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県幡豆郡吉良町白浜新田', '23', '23482', '4440514', '愛知県', 'アイチケン', '幡豆郡吉良町', 'ハズグンキラチョウ', '白浜新田', 'シラハマシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県幡豆郡吉良町富好新田', '23', '23482', '4440515', '愛知県', 'アイチケン', '幡豆郡吉良町', 'ハズグンキラチョウ', '富好新田', 'トミヨシシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県幡豆郡吉良町吉田', '23', '23482', '4440516', '愛知県', 'アイチケン', '幡豆郡吉良町', 'ハズグンキラチョウ', '吉田', 'ヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県幡豆郡吉良町大島', '23', '23482', '4440517', '愛知県', 'アイチケン', '幡豆郡吉良町', 'ハズグンキラチョウ', '大島', 'オオジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県幡豆郡吉良町上横須賀', '23', '23482', '4440521', '愛知県', 'アイチケン', '幡豆郡吉良町', 'ハズグンキラチョウ', '上横須賀', 'カミヨコスカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県幡豆郡吉良町下横須賀', '23', '23482', '4440522', '愛知県', 'アイチケン', '幡豆郡吉良町', 'ハズグンキラチョウ', '下横須賀', 'シモヨコスカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県幡豆郡吉良町饗庭', '23', '23482', '4440523', '愛知県', 'アイチケン', '幡豆郡吉良町', 'ハズグンキラチョウ', '饗庭', 'アイバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県幡豆郡吉良町荻原', '23', '23482', '4440524', '愛知県', 'アイチケン', '幡豆郡吉良町', 'ハズグンキラチョウ', '荻原', 'オギワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県幡豆郡吉良町富田', '23', '23482', '4440525', '愛知県', 'アイチケン', '幡豆郡吉良町', 'ハズグンキラチョウ', '富田', 'トミダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県幡豆郡吉良町八幡川田', '23', '23482', '4440526', '愛知県', 'アイチケン', '幡豆郡吉良町', 'ハズグンキラチョウ', '八幡川田', 'ハチマンカワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県幡豆郡吉良町岡山', '23', '23482', '4440531', '愛知県', 'アイチケン', '幡豆郡吉良町', 'ハズグンキラチョウ', '岡山', 'オカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県幡豆郡吉良町瀬戸', '23', '23482', '4440532', '愛知県', 'アイチケン', '幡豆郡吉良町', 'ハズグンキラチョウ', '瀬戸', 'セト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県幡豆郡吉良町寺嶋', '23', '23482', '4440533', '愛知県', 'アイチケン', '幡豆郡吉良町', 'ハズグンキラチョウ', '寺嶋', 'テラジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県幡豆郡吉良町木田', '23', '23482', '4440534', '愛知県', 'アイチケン', '幡豆郡吉良町', 'ハズグンキラチョウ', '木田', 'キダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県幡豆郡吉良町小牧', '23', '23482', '4440535', '愛知県', 'アイチケン', '幡豆郡吉良町', 'ハズグンキラチョウ', '小牧', 'コマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県幡豆郡吉良町中野', '23', '23482', '4440536', '愛知県', 'アイチケン', '幡豆郡吉良町', 'ハズグンキラチョウ', '中野', 'ナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県幡豆郡吉良町酒井', '23', '23482', '4440537', '愛知県', 'アイチケン', '幡豆郡吉良町', 'ハズグンキラチョウ', '酒井', 'サカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県幡豆郡幡豆町', '23', '23483', '4440700', '愛知県', 'アイチケン', '幡豆郡幡豆町', 'ハズグンハズチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('42465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県幡豆郡幡豆町東幡豆', '23', '23483', '4440701', '愛知県', 'アイチケン', '幡豆郡幡豆町', 'ハズグンハズチョウ', '東幡豆', 'ヒガシハズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県幡豆郡幡豆町寺部', '23', '23483', '4440702', '愛知県', 'アイチケン', '幡豆郡幡豆町', 'ハズグンハズチョウ', '寺部', 'テラベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県幡豆郡幡豆町西幡豆', '23', '23483', '4440703', '愛知県', 'アイチケン', '幡豆郡幡豆町', 'ハズグンハズチョウ', '西幡豆', 'ニシハズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県幡豆郡幡豆町鳥羽', '23', '23483', '4440704', '愛知県', 'アイチケン', '幡豆郡幡豆町', 'ハズグンハズチョウ', '鳥羽', 'トバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市美合新町', '23', '23202', '4440801', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '美合新町', 'ミアイシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市美合町', '23', '23202', '4440802', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '美合町', 'ミアイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市美合町入込', '23', '23202', '4440803', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '美合町入込', 'ミアイチョウイリコミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市美合町生田', '23', '23202', '4440804', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '美合町生田', 'ミアイチョウショウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市美合町地蔵野', '23', '23202', '4440805', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '美合町地蔵野', 'ミアイチョウジゾウノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市緑丘', '23', '23202', '4440806', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '緑丘', 'ミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市美合西町', '23', '23202', '4440807', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '美合西町', 'ミアイニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市大西町', '23', '23202', '4440811', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '大西町', 'オオニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市大西町南ケ原', '23', '23202', '4440812', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '大西町南ケ原', 'オオニシチョウミナミガハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市羽根町', '23', '23202', '4440813', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '羽根町', 'ハネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市羽根町小豆坂', '23', '23202', '4440814', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '羽根町小豆坂', 'ハネチョウアズキサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市羽根町陣場', '23', '23202', '4440815', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '羽根町陣場', 'ハネチョウジンバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市羽根町大池', '23', '23202', '4440816', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '羽根町大池', 'ハネチョウオオイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市不吹町', '23', '23202', '4440817', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '不吹町', 'フブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市庄司田', '23', '23202', '4440821', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '庄司田', 'ショウジダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市若松東', '23', '23202', '4440822', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '若松東', 'ワカマツヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市上地', '23', '23202', '4440823', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '上地', 'ウエジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市上地町', '23', '23202', '4440824', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '上地町', 'ウエジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市福岡町', '23', '23202', '4440825', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '福岡町', 'フクオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市若松町', '23', '23202', '4440826', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '若松町', 'ワカマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市針崎町', '23', '23202', '4440827', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '針崎町', 'ハリサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市針崎', '23', '23202', '4440828', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '針崎', 'ハリサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市羽根北町', '23', '23202', '4440831', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '羽根北町', 'ハネキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市羽根東町', '23', '23202', '4440832', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '羽根東町', 'ハネヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市柱曙', '23', '23202', '4440833', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '柱曙', 'ハシラアケボノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市柱町', '23', '23202', '4440834', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '柱町', 'ハシラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市城南町', '23', '23202', '4440835', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '城南町', 'ジョウナンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市中田町', '23', '23202', '4440836', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '中田町', 'ナカダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市柱', '23', '23202', '4440837', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '柱', 'ハシラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市羽根西', '23', '23202', '4440838', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '羽根西', 'ハネニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市羽根西新町', '23', '23202', '4440839', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '羽根西新町', 'ハネニシシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市戸崎町', '23', '23202', '4440840', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '戸崎町', 'トサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市戸崎町藤狭', '23', '23202', '4440841', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '戸崎町藤狭', 'トサキチョウフジバサミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市戸崎元町', '23', '23202', '4440842', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '戸崎元町', 'トサキモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市江口', '23', '23202', '4440843', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '江口', 'エグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市天白町', '23', '23202', '4440844', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '天白町', 'テンパクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市六名南', '23', '23202', '4440845', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '六名南', 'ムツナミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市六名新町', '23', '23202', '4440846', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '六名新町', 'ムツナシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市六名東町', '23', '23202', '4440847', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '六名東町', 'ムツナヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市向山町', '23', '23202', '4440848', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '向山町', 'ムカイヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市戸崎新町', '23', '23202', '4440849', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '戸崎新町', 'トサキシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市久後崎町', '23', '23202', '4440851', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '久後崎町', 'クゴサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市南明大寺町', '23', '23202', '4440852', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '南明大寺町', 'ミナミミョウダイジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市三崎町', '23', '23202', '4440853', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '三崎町', 'ミサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市六名本町', '23', '23202', '4440854', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '六名本町', 'ムツナホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市真宮町', '23', '23202', '4440855', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '真宮町', 'シングウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市六名', '23', '23202', '4440856', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '六名', 'ムツナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市六名町', '23', '23202', '4440857', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '六名町', 'ムツナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市上六名', '23', '23202', '4440858', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '上六名', 'カミムツナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市上六名町', '23', '23202', '4440859', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '上六名町', 'カミムツナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市明大寺本町', '23', '23202', '4440860', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '明大寺本町', 'ミョウダイジホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市上明大寺町', '23', '23202', '4440861', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '上明大寺町', 'カミミョウダイジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市吹矢町', '23', '23202', '4440862', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '吹矢町', 'フキヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市東明大寺町', '23', '23202', '4440863', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '東明大寺町', 'ヒガシミョウダイジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市明大寺町', '23', '23202', '4440864', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '明大寺町', 'ミョウダイジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市明大寺町大圦', '23', '23202', '4440865', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '明大寺町大圦', 'ミョウダイジチョウオオイリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市明大寺町仲ケ入', '23', '23202', '4440866', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '明大寺町', 'ミョウダイジチョウ', null, null, '仲ケ入', 'ナカガイリ');
INSERT INTO `ms_addresses` VALUES ('42527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市明大寺町西郷中', '23', '23202', '4440867', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '明大寺町', 'ミョウダイジチョウ', null, null, '西郷中', 'ニシゴウナカ');
INSERT INTO `ms_addresses` VALUES ('42528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市明大寺町馬場東', '23', '23202', '4440868', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '明大寺町', 'ミョウダイジチョウ', null, null, '馬場東', 'ババヒガシ');
INSERT INTO `ms_addresses` VALUES ('42529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市明大寺町出口', '23', '23202', '4440869', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '明大寺町', 'ミョウダイジチョウ', null, null, '出口', 'デグチ');
INSERT INTO `ms_addresses` VALUES ('42530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市竜美大入町', '23', '23202', '4440870', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '竜美大入町', 'タツミオオイリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市大西', '23', '23202', '4440871', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '大西', 'オオニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市竜美新町', '23', '23202', '4440872', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '竜美新町', 'タツミシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市竜美台', '23', '23202', '4440873', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '竜美台', 'タツミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市竜美南', '23', '23202', '4440874', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '竜美南', 'タツミミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市竜美西', '23', '23202', '4440875', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '竜美西', 'タツミニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市竜美北', '23', '23202', '4440876', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '竜美北', 'タツミキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市竜美旭町', '23', '23202', '4440877', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '竜美旭町', 'タツミアサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市竜美東', '23', '23202', '4440878', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '竜美東', 'タツミヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市竜美中', '23', '23202', '4440879', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '竜美中', 'タツミナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市森越町', '23', '23202', '4440901', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '森越町', 'モリコシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市舳越町', '23', '23202', '4440902', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '舳越町', 'ヘゴシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市東大友町', '23', '23202', '4440903', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '東大友町', 'ヒガシオオドモチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市西大友町', '23', '23202', '4440904', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '西大友町', 'ニシオオドモチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市宇頭町', '23', '23202', '4440905', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '宇頭町', 'ウトウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市宇頭北町', '23', '23202', '4440906', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '宇頭北町', 'ウトウキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市小針町', '23', '23202', '4440907', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '小針町', 'コバリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市橋目町', '23', '23202', '4440908', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '橋目町', 'ハシメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市橋目町御小屋西', '23', '23202', '4440909', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '橋目町御小屋西', 'ハシメチョウオコヤニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市日名北町', '23', '23202', '4440911', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '日名北町', 'ヒナキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市井田西町', '23', '23202', '4440912', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '井田西町', 'イダニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市葵町', '23', '23202', '4440913', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '葵町', 'アオイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市末広町', '23', '23202', '4440914', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '末広町', 'スエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市日名南町', '23', '23202', '4440915', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '日名南町', 'ヒナミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市日名本町', '23', '23202', '4440916', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '日名本町', 'ヒナホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市日名西町', '23', '23202', '4440917', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '日名西町', 'ヒナニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市日名中町', '23', '23202', '4440918', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '日名中町', 'ヒナナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市中岡崎町', '23', '23202', '4440921', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '中岡崎町', 'ナカオカザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市八帖南町', '23', '23202', '4440922', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '八帖南町', 'ハッチョウミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市八帖町', '23', '23202', '4440923', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '八帖町', 'ハッチョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市八帖北町', '23', '23202', '4440924', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '八帖北町', 'ハッチョウキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市大和町', '23', '23202', '4440931', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '大和町', 'ダイワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市筒針町', '23', '23202', '4440932', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '筒針町', 'ツツバリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市渡町', '23', '23202', '4440933', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '渡町', 'ワタリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市東牧内町', '23', '23202', '4440934', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '東牧内町', 'ヒガシマキウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市下佐々木町', '23', '23202', '4440935', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '下佐々木町', 'シモササキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市上佐々木町', '23', '23202', '4440936', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '上佐々木町', 'カミササキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市島坂町', '23', '23202', '4440937', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '島坂町', 'シマサカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市昭和町', '23', '23202', '4440938', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '昭和町', 'ショウワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市新堀町', '23', '23202', '4440939', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '新堀町', 'ニイボリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市暮戸町', '23', '23202', '4440941', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '暮戸町', 'クレドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市中園町', '23', '23202', '4440942', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '中園町', 'ナカゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市矢作町', '23', '23202', '4440943', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '矢作町', 'ヤハギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市北本郷町', '23', '23202', '4440944', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '北本郷町', 'キタホンゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市東本郷町', '23', '23202', '4440945', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '東本郷町', 'ヒガシホンゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市富永町', '23', '23202', '4440946', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '富永町', 'トミナガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市西本郷町', '23', '23202', '4440947', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '西本郷町', 'ニシホンゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市西本郷町和志山', '23', '23202', '4440948', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '西本郷町和志山', 'ニシホンゴウチョウワシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市宇頭南町', '23', '23202', '4440949', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '宇頭南町', 'ウトウミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市宇頭東町', '23', '23202', '4440950', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '宇頭東町', 'ウトウヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市北野町', '23', '23202', '4440951', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '北野町', 'キタノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県安城市村高町', '23', '23212', '4441151', '愛知県', 'アイチケン', '安城市', 'アンジョウシ', '村高町', 'ムラダカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県安城市川島町', '23', '23212', '4441152', '愛知県', 'アイチケン', '安城市', 'アンジョウシ', '川島町', 'カワシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県安城市東町', '23', '23212', '4441153', '愛知県', 'アイチケン', '安城市', 'アンジョウシ', '東町', 'ヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県安城市桜井町', '23', '23212', '4441154', '愛知県', 'アイチケン', '安城市', 'アンジョウシ', '桜井町', 'サクライチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県安城市堀内町', '23', '23212', '4441155', '愛知県', 'アイチケン', '安城市', 'アンジョウシ', '堀内町', 'ホリウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県安城市姫小川町', '23', '23212', '4441161', '愛知県', 'アイチケン', '安城市', 'アンジョウシ', '姫小川町', 'ヒメオガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県安城市小川町', '23', '23212', '4441162', '愛知県', 'アイチケン', '安城市', 'アンジョウシ', '小川町', 'オガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県安城市木戸町', '23', '23212', '4441163', '愛知県', 'アイチケン', '安城市', 'アンジョウシ', '木戸町', 'キドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県安城市藤井町', '23', '23212', '4441164', '愛知県', 'アイチケン', '安城市', 'アンジョウシ', '藤井町', 'フジイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県安城市野寺町', '23', '23212', '4441165', '愛知県', 'アイチケン', '安城市', 'アンジョウシ', '野寺町', 'ノデラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県安城市寺領町', '23', '23212', '4441166', '愛知県', 'アイチケン', '安城市', 'アンジョウシ', '寺領町', 'ジリョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県安城市石井町', '23', '23212', '4441201', '愛知県', 'アイチケン', '安城市', 'アンジョウシ', '石井町', 'イシイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県安城市城ケ入町団戸', '23', '23212', '4441202', '愛知県', 'アイチケン', '安城市', 'アンジョウシ', '城ケ入町', 'ジョウガイリチョウ', null, null, '団戸', 'ダンド');
INSERT INTO `ms_addresses` VALUES ('42598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県安城市城ケ入町立出', '23', '23212', '4441203', '愛知県', 'アイチケン', '安城市', 'アンジョウシ', '城ケ入町', 'ジョウガイリチョウ', null, null, '立出', 'タテダシ');
INSERT INTO `ms_addresses` VALUES ('42599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県安城市城ケ入町北立出', '23', '23212', '4441204', '愛知県', 'アイチケン', '安城市', 'アンジョウシ', '城ケ入町', 'ジョウガイリチョウ', null, null, '北立出', 'キタタテダシ');
INSERT INTO `ms_addresses` VALUES ('42600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県安城市城ケ入町広見', '23', '23212', '4441205', '愛知県', 'アイチケン', '安城市', 'アンジョウシ', '城ケ入町', 'ジョウガイリチョウ', null, null, '広見', 'ヒロミ');
INSERT INTO `ms_addresses` VALUES ('42601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県安城市城ケ入町', '23', '23212', '4441206', '愛知県', 'アイチケン', '安城市', 'アンジョウシ', '城ケ入町', 'ジョウガイリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県安城市根崎町', '23', '23212', '4441211', '愛知県', 'アイチケン', '安城市', 'アンジョウシ', '根崎町', 'ネサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県安城市根崎町北根', '23', '23212', '4441212', '愛知県', 'アイチケン', '安城市', 'アンジョウシ', '根崎町', 'ネサキチョウ', null, null, '北根', 'キタネ');
INSERT INTO `ms_addresses` VALUES ('42604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県安城市東端町', '23', '23212', '4441213', '愛知県', 'アイチケン', '安城市', 'アンジョウシ', '東端町', 'ヒガシバタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県安城市榎前町', '23', '23212', '4441214', '愛知県', 'アイチケン', '安城市', 'アンジョウシ', '榎前町', 'エノキマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県安城市榎前町井杭山', '23', '23212', '4441215', '愛知県', 'アイチケン', '安城市', 'アンジョウシ', '榎前町', 'エノキマエチョウ', null, null, '井杭山', 'イグイヤマ');
INSERT INTO `ms_addresses` VALUES ('42607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県安城市和泉町', '23', '23212', '4441221', '愛知県', 'アイチケン', '安城市', 'アンジョウシ', '和泉町', 'イズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県安城市和泉町大海古', '23', '23212', '4441222', '愛知県', 'アイチケン', '安城市', 'アンジョウシ', '和泉町', 'イズミチョウ', null, null, '大海古', 'オオウミコ');
INSERT INTO `ms_addresses` VALUES ('42609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県安城市和泉町北大木', '23', '23212', '4441223', '愛知県', 'アイチケン', '安城市', 'アンジョウシ', '和泉町', 'イズミチョウ', null, null, '北大木', 'キタオオギ');
INSERT INTO `ms_addresses` VALUES ('42610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県安城市和泉町八兵エ', '23', '23212', '4441224', '愛知県', 'アイチケン', '安城市', 'アンジョウシ', '和泉町', 'イズミチョウ', null, null, '八兵エ', 'ハチベエ');
INSERT INTO `ms_addresses` VALUES ('42611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県安城市和泉町井上', '23', '23212', '4441225', '愛知県', 'アイチケン', '安城市', 'アンジョウシ', '和泉町', 'イズミチョウ', null, null, '井上', 'イノウエ');
INSERT INTO `ms_addresses` VALUES ('42616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県高浜市', '23', '23227', '4441300', '愛知県', 'アイチケン', '高浜市', 'タカハマシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('42617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県高浜市新田町', '23', '23227', '4441301', '愛知県', 'アイチケン', '高浜市', 'タカハマシ', '新田町', 'シンデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県高浜市八幡町', '23', '23227', '4441302', '愛知県', 'アイチケン', '高浜市', 'タカハマシ', '八幡町', 'ハチマンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県高浜市小池町', '23', '23227', '4441303', '愛知県', 'アイチケン', '高浜市', 'タカハマシ', '小池町', 'コイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県高浜市豊田町', '23', '23227', '4441304', '愛知県', 'アイチケン', '高浜市', 'タカハマシ', '豊田町', 'トヨダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県高浜市神明町', '23', '23227', '4441305', '愛知県', 'アイチケン', '高浜市', 'タカハマシ', '神明町', 'シンメイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県高浜市本郷町', '23', '23227', '4441311', '愛知県', 'アイチケン', '高浜市', 'タカハマシ', '本郷町', 'ホンゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県高浜市清水町', '23', '23227', '4441312', '愛知県', 'アイチケン', '高浜市', 'タカハマシ', '清水町', 'シミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県高浜市向山町', '23', '23227', '4441313', '愛知県', 'アイチケン', '高浜市', 'タカハマシ', '向山町', 'ムカイヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県高浜市論地町', '23', '23227', '4441314', '愛知県', 'アイチケン', '高浜市', 'タカハマシ', '論地町', 'ロンチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県高浜市稗田町', '23', '23227', '4441321', '愛知県', 'アイチケン', '高浜市', 'タカハマシ', '稗田町', 'ヒエダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県高浜市二池町', '23', '23227', '4441322', '愛知県', 'アイチケン', '高浜市', 'タカハマシ', '二池町', 'フタツイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県高浜市田戸町', '23', '23227', '4441323', '愛知県', 'アイチケン', '高浜市', 'タカハマシ', '田戸町', 'タドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県高浜市碧海町', '23', '23227', '4441324', '愛知県', 'アイチケン', '高浜市', 'タカハマシ', '碧海町', 'アオミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県高浜市青木町', '23', '23227', '4441325', '愛知県', 'アイチケン', '高浜市', 'タカハマシ', '青木町', 'アオキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県高浜市屋敷町', '23', '23227', '4441331', '愛知県', 'アイチケン', '高浜市', 'タカハマシ', '屋敷町', 'ヤシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県高浜市湯山町', '23', '23227', '4441332', '愛知県', 'アイチケン', '高浜市', 'タカハマシ', '湯山町', 'ユヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県高浜市沢渡町', '23', '23227', '4441333', '愛知県', 'アイチケン', '高浜市', 'タカハマシ', '沢渡町', 'サワタリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県高浜市春日町', '23', '23227', '4441334', '愛知県', 'アイチケン', '高浜市', 'タカハマシ', '春日町', 'カスガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県高浜市芳川町', '23', '23227', '4441335', '愛知県', 'アイチケン', '高浜市', 'タカハマシ', '芳川町', 'ヨシカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県高浜市呉竹町', '23', '23227', '4441336', '愛知県', 'アイチケン', '高浜市', 'タカハマシ', '呉竹町', 'クレタケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市川向町', '23', '23202', '4442101', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '川向町', 'カワムキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市日影町', '23', '23202', '4442102', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '日影町', 'ヒカゲチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市渡通津町', '23', '23202', '4442103', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '渡通津町', 'ワツヅチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市駒立町', '23', '23202', '4442104', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '駒立町', 'コマダチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市丹坂町', '23', '23202', '4442105', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '丹坂町', 'タンザカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市真福寺町', '23', '23202', '4442106', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '真福寺町', 'シンプクジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市恵田町', '23', '23202', '4442107', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '恵田町', 'エタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市奥殿町', '23', '23202', '4442108', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '奥殿町', 'オクトノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市宮石町', '23', '23202', '4442109', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '宮石町', 'ミヤイシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市西阿知和町', '23', '23202', '4442111', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '西阿知和町', 'ニシアチワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市東阿知和町', '23', '23202', '4442112', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '東阿知和町', 'ヒガシアチワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市松橋町', '23', '23202', '4442113', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '松橋町', 'マツハシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市堂前町', '23', '23202', '4442114', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '堂前町', 'ドウマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市百々町', '23', '23202', '4442115', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '百々町', 'ドウドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市寿町', '23', '23202', '4442116', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '寿町', 'コトブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市百々西町', '23', '23202', '4442117', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '百々西町', 'ドウドニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市河原町', '23', '23202', '4442118', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '河原町', 'カワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市鴨田町', '23', '23202', '4442121', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '鴨田町', 'カモダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市鴨田本町', '23', '23202', '4442122', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '鴨田本町', 'カモダホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市鴨田南町', '23', '23202', '4442123', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '鴨田南町', 'カモダミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市青木町', '23', '23202', '4442131', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '青木町', 'アオキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市井ノ口新町', '23', '23202', '4442132', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '井ノ口新町', 'イノクチシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市井ノ口町', '23', '23202', '4442133', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '井ノ口町', 'イノクチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市大樹寺', '23', '23202', '4442134', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '大樹寺', 'ダイジュウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市大門', '23', '23202', '4442135', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '大門', 'ダイモン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市上里', '23', '23202', '4442136', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '上里', 'カミサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市薮田', '23', '23202', '4442137', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '薮田', 'ヤブタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市桑原町', '23', '23202', '4442141', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '桑原町', 'クワバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市奥山田町', '23', '23202', '4442142', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '奥山田町', 'オクヤマダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市八ツ木町', '23', '23202', '4442143', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '八ツ木町', 'ヤツギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市岩津町', '23', '23202', '4442144', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '岩津町', 'イワヅチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市東蔵前', '23', '23202', '4442145', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '東蔵前', 'ヒガシクラマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市東蔵前町', '23', '23202', '4442146', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '東蔵前町', 'ヒガシクラマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市西蔵前町', '23', '23202', '4442147', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '西蔵前町', 'ニシクラマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市仁木町', '23', '23202', '4442148', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '仁木町', 'ニッキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市細川町', '23', '23202', '4442149', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '細川町', 'ホソカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市坂上町', '23', '23211', '4442201', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '坂上町', 'サカウエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市松平町', '23', '23211', '4442202', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '松平町', 'マツダイラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市豊松町', '23', '23211', '4442203', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '豊松町', 'トヨマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市鵜ケ瀬町', '23', '23211', '4442204', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '鵜ケ瀬町', 'ウガセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市鍋田町', '23', '23211', '4442205', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '鍋田町', 'ナベタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市王滝町', '23', '23211', '4442206', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '王滝町', 'オウタキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市石楠町', '23', '23211', '4442207', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '石楠町', 'セキナンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市長沢町', '23', '23211', '4442211', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '長沢町', 'ナガサワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市滝脇町', '23', '23211', '4442212', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '滝脇町', 'タキワキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市加茂川町', '23', '23211', '4442213', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '加茂川町', 'カモガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市桂野町', '23', '23211', '4442214', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '桂野町', 'カツラノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市中垣内町', '23', '23211', '4442215', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '中垣内町', 'ナカガイトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市九久平町', '23', '23211', '4442216', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '九久平町', 'クギュウダイラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市大内町', '23', '23211', '4442217', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '大内町', 'オオウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市林添町', '23', '23211', '4442218', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '林添町', 'ハヤシゾレチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市幸海町', '23', '23211', '4442221', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '幸海町', 'コウカイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市穂積町', '23', '23211', '4442222', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '穂積町', 'ホヅミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市松平志賀町', '23', '23211', '4442223', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '松平志賀町', 'マツダイラシガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市巴町', '23', '23211', '4442224', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '巴町', 'トモエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市岩倉町', '23', '23211', '4442225', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '岩倉町', 'イワクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市幸穂台', '23', '23211', '4442226', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '幸穂台', 'サチホダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市東川端町', '23', '23211', '4442301', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '東川端町', 'ヒガシカワバタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市戸中町', '23', '23211', '4442302', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '戸中町', 'トチュウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市野林町', '23', '23211', '4442303', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '野林町', 'ノバヤシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市沢ノ堂町', '23', '23211', '4442311', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '沢ノ堂町', 'サワノドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市四ツ松町', '23', '23211', '4442312', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '四ツ松町', 'ヨツマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市冷田町', '23', '23211', '4442313', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '冷田町', 'ヒエダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市上小田町', '23', '23211', '4442314', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '上小田町', 'カミコダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市下国谷町', '23', '23211', '4442321', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '下国谷町', 'シモクニヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市栃本町', '23', '23211', '4442324', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '栃本町', 'トチモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市桑原田町', '23', '23211', '4442325', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '桑原田町', 'クワハラダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市国谷町', '23', '23211', '4442326', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '国谷町', 'クニヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市白倉町', '23', '23211', '4442327', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '白倉町', 'シラクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市岩谷町', '23', '23211', '4442331', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '岩谷町', 'イワヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市下平町', '23', '23211', '4442332', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '下平町', 'シモダイラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市平折町', '23', '23211', '4442333', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '平折町', 'ヒロリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市国閑町', '23', '23211', '4442334', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '国閑町', 'カイゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市上脇町', '23', '23211', '4442335', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '上脇町', 'カミワキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市下佐切町', '23', '23211', '4442336', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '下佐切町', 'シモサギリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市上佐切町', '23', '23211', '4442337', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '上佐切町', 'カミサギリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市則定町', '23', '23211', '4442342', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '則定町', 'ノリサダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市霧山町', '23', '23211', '4442343', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '霧山町', 'キリヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市東大島町', '23', '23211', '4442344', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '東大島町', 'ヒガシオオシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市岩神町', '23', '23211', '4442351', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '岩神町', 'ヤガミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市篭林町', '23', '23211', '4442352', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '篭林町', 'カゴハヤシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市田振町', '23', '23211', '4442353', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '田振町', 'タブリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市井ノ口町', '23', '23211', '4442354', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '井ノ口町', 'イノクチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市近岡町', '23', '23211', '4442355', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '近岡町', 'チカオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市二タ宮町', '23', '23211', '4442401', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '二タ宮町', 'フタミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市竜岡町', '23', '23211', '4442402', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '竜岡町', 'タツオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市川面町', '23', '23211', '4442403', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '川面町', 'カワオモテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市怒田沢町', '23', '23211', '4442404', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '怒田沢町', 'ヌタザワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市大蔵連町', '23', '23211', '4442405', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '大蔵連町', 'オオゾウレンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市漆畑町', '23', '23211', '4442406', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '漆畑町', 'ウルシバタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市桑田和町', '23', '23211', '4442407', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '桑田和町', 'クワダワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市菅生町', '23', '23211', '4442409', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '菅生町', 'スゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市御内町', '23', '23211', '4442411', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '御内町', 'ミウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市山ノ中立町', '23', '23211', '4442412', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '山ノ中立町', 'ヤマノナカダチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市東大見町', '23', '23211', '4442413', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '東大見町', 'ヒガシオオミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市葛沢町', '23', '23211', '4442414', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '葛沢町', 'ツヅラサワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市山谷町', '23', '23211', '4442415', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '山谷町', 'ヤマガイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市有洞町', '23', '23211', '4442416', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '有洞町', 'ウトウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市室口町', '23', '23211', '4442417', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '室口町', 'ムログチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市綾渡町', '23', '23211', '4442418', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '綾渡町', 'アヤドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市椿立町', '23', '23211', '4442419', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '椿立町', 'ツバキダチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市安実京町', '23', '23211', '4442423', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '安実京町', 'アジキョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市足助町', '23', '23211', '4442424', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '足助町', 'アスケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市岩神町足助高等学校', '23', '23211', '4442451', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '岩神町', 'ヤガミチョウ', null, null, '足助高等学校', 'アスケコウトウガッコウ');
INSERT INTO `ms_addresses` VALUES ('42752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市大井町', '23', '23211', '4442501', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '大井町', 'オオイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市北小田町', '23', '23211', '4442502', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '北小田町', 'キタコダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市細田町', '23', '23211', '4442503', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '細田町', 'ホソダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市永野町', '23', '23211', '4442504', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '永野町', 'ナガノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市新盛町', '23', '23211', '4442505', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '新盛町', 'シンモリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市久木町', '23', '23211', '4442506', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '久木町', 'ヒサギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市富岡町', '23', '23211', '4442510', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '富岡町', 'トミオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市大蔵町', '23', '23211', '4442511', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '大蔵町', 'オオクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市東中山町', '23', '23211', '4442512', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '東中山町', 'ヒガシナカヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市足助白山町', '23', '23211', '4442513', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '足助白山町', 'アスケシラヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市栃ノ沢町', '23', '23211', '4442514', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '栃ノ沢町', 'トチノサワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市大塚町', '23', '23211', '4442515', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '大塚町', 'オオツカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市塩ノ沢町', '23', '23211', '4442516', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '塩ノ沢町', 'シオノサワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市中立町', '23', '23211', '4442517', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '中立町', 'ナカダチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市小町', '23', '23211', '4442521', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '小町', 'コチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市御蔵町', '23', '23211', '4442522', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '御蔵町', 'ミクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市実栗町', '23', '23211', '4442523', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '実栗町', 'ミグリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市摺町', '23', '23211', '4442524', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '摺町', 'スリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市大河原町', '23', '23211', '4442525', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '大河原町', 'オオカワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市葛町', '23', '23211', '4442526', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '葛町', 'ツヅラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市月原町', '23', '23211', '4442527', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '月原町', 'ワチバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市東渡合町', '23', '23211', '4442528', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '東渡合町', 'ヒガシドアイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市上切山町', '23', '23211', '4442531', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '上切山町', 'カミキリヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市西樫尾町', '23', '23211', '4442532', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '西樫尾町', 'ニシガシオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市小手沢町', '23', '23211', '4442533', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '小手沢町', 'コテノサワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市明川町', '23', '23211', '4442601', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '明川町', 'アスガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市連谷町', '23', '23211', '4442602', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '連谷町', 'レンダニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市大多賀町', '23', '23211', '4442603', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '大多賀町', 'オオタガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市上八木町', '23', '23211', '4442604', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '上八木町', 'ウバヤギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市玉野町', '23', '23211', '4442605', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '玉野町', 'タマノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市千田町', '23', '23211', '4442606', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '千田町', 'センダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市平沢町', '23', '23211', '4442607', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '平沢町', 'ヒラサワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市五反田町', '23', '23211', '4442608', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '五反田町', 'ゴタンダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市牛地町', '23', '23211', '4442801', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '牛地町', 'ウシジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市田津原町', '23', '23211', '4442802', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '田津原町', 'タツハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市坪崎町', '23', '23211', '4442803', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '坪崎町', 'ツボサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市日下部町', '23', '23211', '4442804', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '日下部町', 'クサカベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市小畑町', '23', '23211', '4442805', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '小畑町', 'コバタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市惣田町', '23', '23211', '4442806', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '惣田町', 'ソウダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市伊熊町', '23', '23211', '4442807', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '伊熊町', 'イクマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市槇本町', '23', '23211', '4442808', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '槇本町', 'マキモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市小滝野町', '23', '23211', '4442809', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '小滝野町', 'オタギノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市太田町', '23', '23211', '4442811', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '太田町', 'オオダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市押井町', '23', '23211', '4442812', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '押井町', 'オシイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市加塩町', '23', '23211', '4442813', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '加塩町', 'カシオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市榊野町', '23', '23211', '4442814', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '榊野町', 'サカキノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市万根町', '23', '23211', '4442815', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '万根町', 'マンネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市杉本町', '23', '23211', '4442816', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '杉本町', 'スギモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市明賀町', '23', '23211', '4442817', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '明賀町', 'アスガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市小田町', '23', '23211', '4442821', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '小田町', 'コダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市大坪町', '23', '23211', '4442822', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '大坪町', 'オオツボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市東萩平町', '23', '23211', '4442823', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '東萩平町', 'ヒガシハギヒラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市池島町', '23', '23211', '4442824', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '池島町', 'イケジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市市平町', '23', '23211', '4442825', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '市平町', 'イチダイラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市笹戸町', '23', '23211', '4442826', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '笹戸町', 'ササドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市有間町', '23', '23211', '4442827', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '有間町', 'アンマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市須渕町', '23', '23211', '4442831', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '須渕町', 'スブチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市浅谷町', '23', '23211', '4442832', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '浅谷町', 'アザカイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市下切町', '23', '23211', '4442833', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '下切町', 'シモギリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市島崎町', '23', '23211', '4442834', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '島崎町', 'シマサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市上中町', '23', '23211', '4442835', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '上中町', 'カミナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市上切町', '23', '23211', '4442836', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '上切町', 'カミギリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市一色町', '23', '23211', '4442837', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '一色町', 'イシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市下中町', '23', '23211', '4442838', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '下中町', 'シモナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市三分山町', '23', '23211', '4442839', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '三分山町', 'サンブヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市閑羅瀬町', '23', '23211', '4442841', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '閑羅瀬町', 'シズラセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市余平町', '23', '23211', '4442842', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '余平町', 'ヨダイラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市旭八幡町', '23', '23211', '4442843', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '旭八幡町', 'アサヒヤワタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市伯母沢町', '23', '23211', '4442844', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '伯母沢町', 'オバザワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市万町町', '23', '23211', '4442845', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '万町町', 'マンヂヨウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市小渡町', '23', '23211', '4442846', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '小渡町', 'オドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市時瀬町', '23', '23211', '4442847', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '時瀬町', 'トキゼチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市箱柳町中立', '23', '23202', '4443151', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '箱柳町', 'ハコヤナギチョウ', null, null, '中立', 'ナカダチ');
INSERT INTO `ms_addresses` VALUES ('42827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市大柳町', '23', '23202', '4443161', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '大柳町', 'オオヤナギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市新居町', '23', '23202', '4443162', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '新居町', 'アライチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市小丸町', '23', '23202', '4443163', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '小丸町', 'コマルチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市蔵次町', '23', '23202', '4443164', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '蔵次町', 'クラナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市岩中町', '23', '23202', '4443165', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '岩中町', 'イワナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市大井野町', '23', '23202', '4443166', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '大井野町', 'オオイノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市米河内町', '23', '23202', '4443167', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '米河内町', 'ヨナゴウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市安戸町', '23', '23202', '4443168', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '安戸町', 'ヤスドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市板田町', '23', '23202', '4443171', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '板田町', 'イタダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市田口町', '23', '23202', '4443172', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '田口町', 'タグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市滝町', '23', '23202', '4443173', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '滝町', 'タキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市真伝町', '23', '23202', '4443174', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '真伝町', 'シンデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市真伝', '23', '23202', '4443175', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '真伝', 'シンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市梨野町', '23', '23211', '4443201', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '梨野町', 'ナシノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市阿蔵町', '23', '23211', '4443202', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '阿蔵町', 'アゾウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市宇連野町', '23', '23211', '4443203', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '宇連野町', 'ウレノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市野原町', '23', '23211', '4443205', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '野原町', 'ノワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市羽布町', '23', '23211', '4443206', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '羽布町', 'ハブチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市大桑町', '23', '23211', '4443207', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '大桑町', 'オオクワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市高野町', '23', '23211', '4443208', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '高野町', 'タカノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市和合町', '23', '23211', '4443211', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '和合町', 'ワゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市黒坂町', '23', '23211', '4443212', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '黒坂町', 'クロサカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市小松野町', '23', '23211', '4443213', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '小松野町', 'コマツノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市蘭町', '23', '23211', '4443216', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '蘭町', 'アララギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市田折町', '23', '23211', '4443221', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '田折町', 'タオリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市下山田代町', '23', '23211', '4443222', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '下山田代町', 'シモヤマタシロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市蕪木町', '23', '23211', '4443223', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '蕪木町', 'カブラキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市花沢町', '23', '23211', '4443231', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '花沢町', 'ハナザワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市大沼町', '23', '23211', '4443242', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '大沼町', 'オオヌマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市平瀬町', '23', '23211', '4443251', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '平瀬町', 'ヒラセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市神殿町', '23', '23211', '4443252', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '神殿町', 'カンドノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市東大林町', '23', '23211', '4443261', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '東大林町', 'ヒガシオオバヤシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市立岩町', '23', '23211', '4443262', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '立岩町', 'タテイワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市栃立町', '23', '23211', '4443264', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '栃立町', 'トチダチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市田平沢町', '23', '23211', '4443265', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '田平沢町', 'タヒラザワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市古部町', '23', '23202', '4443331', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '古部町', 'コブチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市切越町', '23', '23202', '4443332', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '切越町', 'キリコシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市蓬生町', '23', '23202', '4443333', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '蓬生町', 'ヨモギュウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市生平町', '23', '23202', '4443334', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '生平町', 'オイダイラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市茅原沢町', '23', '23202', '4443335', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '茅原沢町', 'チハラザワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市須渕町', '23', '23202', '4443341', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '須渕町', 'スブチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市才栗町', '23', '23202', '4443342', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '才栗町', 'サイクリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市秦梨町', '23', '23202', '4443343', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '秦梨町', 'ハダナシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市岩戸町', '23', '23202', '4443344', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '岩戸町', 'イワトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市切山町', '23', '23202', '4443431', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '切山町', 'キリヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市千万町町', '23', '23202', '4443432', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '千万町町', 'ゼマンヂョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市木下町', '23', '23202', '4443433', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '木下町', 'キクダシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市井沢町', '23', '23202', '4443434', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '井沢町', 'イザワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市桜形町', '23', '23202', '4443435', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '桜形町', 'サクラガタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市小久田町', '23', '23202', '4443436', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '小久田町', 'オクダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市毛呂町', '23', '23202', '4443437', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '毛呂町', 'ケロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市冨尾町', '23', '23202', '4443441', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '冨尾町', 'トンビュウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市保久町', '23', '23202', '4443442', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '保久町', 'ホッキュウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市鍛埜町', '23', '23202', '4443443', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '鍛埜町', 'カジノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市南大須町', '23', '23202', '4443444', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '南大須町', 'ミナミオオスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市大高味町', '23', '23202', '4443445', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '大高味町', 'オオタカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市中伊町', '23', '23202', '4443446', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '中伊町', 'ナカイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市一色町', '23', '23202', '4443447', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '一色町', 'イッシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市外山町', '23', '23202', '4443448', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '外山町', 'ソトヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市中伊西町', '23', '23202', '4443449', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '中伊西町', 'ナカイニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市池金町', '23', '23202', '4443501', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '池金町', 'イケガネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市大幡町', '23', '23202', '4443502', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '大幡町', 'オオバタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市鶇巣町', '23', '23202', '4443503', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '鶇巣町', 'トウノスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市上衣文町', '23', '23202', '4443504', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '上衣文町', 'カミソブミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市本宿町', '23', '23202', '4443505', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '本宿町', 'モトジュクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市本宿西', '23', '23202', '4443506', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '本宿西', 'モトジュクニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市本宿台', '23', '23202', '4443507', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '本宿台', 'モトジュクダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市本宿茜', '23', '23202', '4443508', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '本宿茜', 'モトジュクアカネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市舞木町', '23', '23202', '4443511', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '舞木町', 'マイギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市鉢地町', '23', '23202', '4443512', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '鉢地町', 'ハツチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市山綱町', '23', '23202', '4443513', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '山綱町', 'ヤマツナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市羽栗町', '23', '23202', '4443514', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '羽栗町', 'ハグリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市桑谷町', '23', '23202', '4443515', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '桑谷町', 'クワガイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市山綱町', '23', '23202', '4443516', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '山綱町', 'ヤマツナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市市場町', '23', '23202', '4443521', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '市場町', 'イチバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市藤川台', '23', '23202', '4443522', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '藤川台', 'フジカワダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市藤川町', '23', '23202', '4443523', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '藤川町', 'フジカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市竜泉寺町', '23', '23202', '4443524', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '竜泉寺町', 'リュウセンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市蓑川町', '23', '23202', '4443525', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '蓑川町', 'ミノガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市蓑川新町', '23', '23202', '4443526', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '蓑川新町', 'ミノカワシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市藤川荒古', '23', '23202', '4443527', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '藤川荒古', 'フジカワアラコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市石原町', '23', '23202', '4443601', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '石原町', 'イシハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市東河原町', '23', '23202', '4443602', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '東河原町', 'ヒガシカワハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市雨山町', '23', '23202', '4443603', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '雨山町', 'アメヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市大代町', '23', '23202', '4443604', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '大代町', 'オオジロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市中金町', '23', '23202', '4443605', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '中金町', 'ナカガネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市宮崎町', '23', '23202', '4443611', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '宮崎町', 'ミヤザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市明見町', '23', '23202', '4443612', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '明見町', 'ミョウケンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市滝尻町', '23', '23202', '4443613', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '滝尻町', 'タキジリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市鳥川町', '23', '23202', '4443614', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '鳥川町', 'トリカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市細光町', '23', '23202', '4443615', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '細光町', 'ホソミツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市片寄町', '23', '23202', '4443616', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '片寄町', 'カタヨセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市淡渕町', '23', '23202', '4443617', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '淡渕町', 'アワブチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市夏山町', '23', '23202', '4443621', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '夏山町', 'ナツヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市樫山町', '23', '23202', '4443622', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '樫山町', 'カシヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市鹿勝川町', '23', '23202', '4443623', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '鹿勝川町', 'カカツガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市牧平町', '23', '23202', '4443624', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '牧平町', 'マキヒラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市下衣文町', '23', '23202', '4443625', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '下衣文町', 'シモソブミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岡崎市桜井寺町', '23', '23202', '4443626', '愛知県', 'アイチケン', '岡崎市', 'オカザキシ', '桜井寺町', 'サクライジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市', '23', '23213', '4450000', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('42974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市高落町', '23', '23213', '4450001', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '高落町', 'タカオチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市新村町', '23', '23213', '4450002', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '新村町', 'シンムラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市東浅井町', '23', '23213', '4450003', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '東浅井町', 'ヒガシアザイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市西浅井町', '23', '23213', '4450004', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '西浅井町', 'ニシアザイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市米野町', '23', '23213', '4450005', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '米野町', 'コメノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市小島町', '23', '23213', '4450006', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '小島町', 'オジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市上羽角町', '23', '23213', '4450011', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '上羽角町', 'カミハスミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市下羽角町', '23', '23213', '4450012', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '下羽角町', 'シモハスミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市貝吹町', '23', '23213', '4450013', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '貝吹町', 'カイフクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市つくしが丘', '23', '23213', '4450014', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', 'つくしが丘', 'ツクシガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市竹山町', '23', '23213', '4450015', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '竹山町', 'タケヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市下永良町', '23', '23213', '4450016', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '下永良町', 'シモナガラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市上永良町', '23', '23213', '4450017', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '上永良町', 'カミナガラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市駒場町', '23', '23213', '4450021', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '駒場町', 'コマンバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市岡島町', '23', '23213', '4450022', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '岡島町', 'オカジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市高河原町', '23', '23213', '4450023', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '高河原町', 'タカガワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市大和田町', '23', '23213', '4450024', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '大和田町', 'オオワダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市和気町', '23', '23213', '4450025', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '和気町', 'ワキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市江原町', '23', '23213', '4450026', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '江原町', 'エワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市尾花町', '23', '23213', '4450027', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '尾花町', 'オバナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市家武町', '23', '23213', '4450031', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '家武町', 'エタケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市平原町', '23', '23213', '4450032', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '平原町', 'ヒラハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市室町', '23', '23213', '4450033', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '室町', 'ムロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市善明町', '23', '23213', '4450034', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '善明町', 'ゼンミョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市花蔵寺町', '23', '23213', '4450035', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '花蔵寺町', 'ケゾウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('42999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市小焼野町', '23', '23213', '4450041', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '小焼野町', 'コヤケノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市宅野島町', '23', '23213', '4450042', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '宅野島町', 'タクノシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市鵜ケ池町', '23', '23213', '4450043', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '鵜ケ池町', 'ウガイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市鎌谷町', '23', '23213', '4450044', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '鎌谷町', 'カマヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市十郎島町', '23', '23213', '4450045', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '十郎島町', 'ジュウロウシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市須脇町', '23', '23213', '4450046', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '須脇町', 'スワキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市細池町', '23', '23213', '4450047', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '細池町', 'ホソイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市天竹町', '23', '23213', '4450051', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '天竹町', 'テンジクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市横手町', '23', '23213', '4450052', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '横手町', 'ヨコテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市笹曽根町', '23', '23213', '4450053', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '笹曽根町', 'ササゾネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市平口町', '23', '23213', '4450054', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '平口町', 'ヒラクチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市市子町', '23', '23213', '4450055', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '市子町', 'イチゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市斉藤町', '23', '23213', '4450056', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '斉藤町', 'サイトウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市野々宮町', '23', '23213', '4450057', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '野々宮町', 'ノノミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市寄近町', '23', '23213', '4450061', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '寄近町', 'ヨリチカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市丁田町', '23', '23213', '4450062', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '丁田町', 'チョウダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市今川町', '23', '23213', '4450063', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '今川町', 'イマガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市高畠町', '23', '23213', '4450064', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '高畠町', 'タカバタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市城崎町', '23', '23213', '4450065', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '城崎町', 'シロサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市熊味町', '23', '23213', '4450071', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '熊味町', 'クマミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市徳次町', '23', '23213', '4450072', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '徳次町', 'トクツギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市寄住町', '23', '23213', '4450073', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '寄住町', 'ヨリズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市戸ケ崎町', '23', '23213', '4450074', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '戸ケ崎町', 'トガサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市戸ケ崎', '23', '23213', '4450075', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '戸ケ崎', 'トガサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市新渡場', '23', '23213', '4450076', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '新渡場', 'シンドバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市新渡場町', '23', '23213', '4450077', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '新渡場町', 'シンドバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市志籠谷町', '23', '23213', '4450081', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '志籠谷町', 'シコヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市八ツ面町', '23', '23213', '4450082', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '八ツ面町', 'ヤツオモテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市中原町', '23', '23213', '4450083', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '中原町', 'ナカハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市志貴野町', '23', '23213', '4450084', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '志貴野町', 'シキノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市南中根町', '23', '23213', '4450801', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '南中根町', 'ミナミナカネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市米津町', '23', '23213', '4450802', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '米津町', 'ヨネヅチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市桜町', '23', '23213', '4450803', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '桜町', 'サクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市緑町', '23', '23213', '4450804', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '緑町', 'ミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市鶴城町', '23', '23213', '4450805', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '鶴城町', 'ツルシロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市伊藤町', '23', '23213', '4450806', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '伊藤町', 'イトウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市伊藤', '23', '23213', '4450807', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '伊藤', 'イトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市道光寺町', '23', '23213', '4450811', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '道光寺町', 'ドウコウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市道光寺', '23', '23213', '4450812', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '道光寺', 'ドウコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市若松町', '23', '23213', '4450813', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '若松町', 'ワカマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市新屋敷町', '23', '23213', '4450814', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '新屋敷町', 'シンヤシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市菅原町', '23', '23213', '4450815', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '菅原町', 'スガワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市宮町', '23', '23213', '4450816', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '宮町', 'ミヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市矢場町', '23', '23213', '4450821', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '矢場町', 'ヤバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市伊文町', '23', '23213', '4450822', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '伊文町', 'イブンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市神下町', '23', '23213', '4450823', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '神下町', 'カミシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市和泉町', '23', '23213', '4450824', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '和泉町', 'イズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市会生町', '23', '23213', '4450825', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '会生町', 'カイセイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市満全町', '23', '23213', '4450826', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '満全町', 'マンゼンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市幸町', '23', '23213', '4450827', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市大給町', '23', '23213', '4450831', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '大給町', 'オギュウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市瓦町', '23', '23213', '4450832', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '瓦町', 'カワラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市天王町', '23', '23213', '4450833', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '天王町', 'テンノウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市順海町', '23', '23213', '4450834', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '順海町', 'ジュンカイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市肴町', '23', '23213', '4450835', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '肴町', 'サカナマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市中町', '23', '23213', '4450836', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '中町', 'ナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市鶴ケ崎町', '23', '23213', '4450837', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '鶴ケ崎町', 'ツルガサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市馬場町', '23', '23213', '4450841', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '馬場町', 'ババチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市弥生町', '23', '23213', '4450842', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '弥生町', 'ヤヨイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市天神町', '23', '23213', '4450843', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '天神町', 'テンジンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市末広町', '23', '23213', '4450844', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '末広町', 'スエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市鶴舞町', '23', '23213', '4450845', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '鶴舞町', 'ツルマイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市千歳町', '23', '23213', '4450846', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '千歳町', 'チトセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市亀沢町', '23', '23213', '4450847', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '亀沢町', 'カメザワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市住吉町', '23', '23213', '4450851', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '住吉町', 'スミヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市花ノ木町', '23', '23213', '4450852', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '花ノ木町', 'ハナノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市桜木町', '23', '23213', '4450853', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '桜木町', 'サクラギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市永楽町', '23', '23213', '4450854', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '永楽町', 'エイラクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市南旭町', '23', '23213', '4450855', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '南旭町', 'ミナミアサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市高砂町', '23', '23213', '4450856', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '高砂町', 'タカサゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市北旭町', '23', '23213', '4450857', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '北旭町', 'キタアサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市吾妻町', '23', '23213', '4450861', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '吾妻町', 'アヅマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市須田町', '23', '23213', '4450862', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '須田町', 'スダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市葵町', '23', '23213', '4450863', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '葵町', 'アオイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市錦城町', '23', '23213', '4450864', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '錦城町', 'キンジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市本町', '23', '23213', '4450865', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市塩町', '23', '23213', '4450866', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '塩町', 'シオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市永吉', '23', '23213', '4450870', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '永吉', 'ナガヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市永吉町', '23', '23213', '4450871', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '永吉町', 'ナガヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市矢曽根町', '23', '23213', '4450872', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '矢曽根町', 'ヤゾネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市川口町', '23', '23213', '4450873', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '川口町', 'カワグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市菱池町', '23', '23213', '4450874', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '菱池町', 'ヒシイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市深池町', '23', '23213', '4450875', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '深池町', 'フカイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市住崎町', '23', '23213', '4450876', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '住崎町', 'スミサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市山下町', '23', '23213', '4450877', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '山下町', 'ヤマシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市新在家', '23', '23213', '4450878', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '新在家', 'シンザイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市住崎', '23', '23213', '4450879', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '住崎', 'スミサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市熱池町', '23', '23213', '4450881', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '熱池町', 'ニイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市上道目記町', '23', '23213', '4450882', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '上道目記町', 'カミドウメキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市下道目記町', '23', '23213', '4450883', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '下道目記町', 'シモドウメキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市八ケ尻町', '23', '23213', '4450884', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '八ケ尻町', 'ハチガシリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市行用町', '23', '23213', '4450885', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '行用町', 'ギョウヨウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市針曽根町', '23', '23213', '4450886', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '針曽根町', 'ハリゾネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市長縄町', '23', '23213', '4450887', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '長縄町', 'ナガナワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市下町', '23', '23213', '4450891', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '下町', 'シモマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市法光寺町', '23', '23213', '4450892', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '法光寺町', 'ホウコウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市小間町', '23', '23213', '4450893', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '小間町', 'オマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西尾市上町', '23', '23213', '4450894', '愛知県', 'アイチケン', '西尾市', 'ニシオシ', '上町', 'カミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県安城市', '23', '23212', '4460000', '愛知県', 'アイチケン', '安城市', 'アンジョウシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('43107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県安城市里町', '23', '23212', '4460001', '愛知県', 'アイチケン', '安城市', 'アンジョウシ', '里町', 'サトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県安城市橋目町', '23', '23212', '4460002', '愛知県', 'アイチケン', '安城市', 'アンジョウシ', '橋目町', 'ハシメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県安城市柿さき町', '23', '23212', '4460003', '愛知県', 'アイチケン', '安城市', 'アンジョウシ', '柿さき町', 'カキサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県安城市尾崎町', '23', '23212', '4460004', '愛知県', 'アイチケン', '安城市', 'アンジョウシ', '尾崎町', 'オザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県安城市宇頭茶屋町', '23', '23212', '4460005', '愛知県', 'アイチケン', '安城市', 'アンジョウシ', '宇頭茶屋町', 'ウトウチャヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県安城市浜屋町', '23', '23212', '4460006', '愛知県', 'アイチケン', '安城市', 'アンジョウシ', '浜屋町', 'ハマヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県安城市東栄町', '23', '23212', '4460007', '愛知県', 'アイチケン', '安城市', 'アンジョウシ', '東栄町', 'トウエイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県安城市今本町', '23', '23212', '4460008', '愛知県', 'アイチケン', '安城市', 'アンジョウシ', '今本町', 'イマホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県安城市北山崎町', '23', '23212', '4460011', '愛知県', 'アイチケン', '安城市', 'アンジョウシ', '北山崎町', 'キタヤマザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県安城市西別所町', '23', '23212', '4460012', '愛知県', 'アイチケン', '安城市', 'アンジョウシ', '西別所町', 'ニシベッショチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県安城市東別所町', '23', '23212', '4460013', '愛知県', 'アイチケン', '安城市', 'アンジョウシ', '東別所町', 'ヒガシベッショチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県安城市別郷町', '23', '23212', '4460014', '愛知県', 'アイチケン', '安城市', 'アンジョウシ', '別郷町', 'ベツゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県安城市高木町', '23', '23212', '4460015', '愛知県', 'アイチケン', '安城市', 'アンジョウシ', '高木町', 'タカギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県安城市山崎町', '23', '23212', '4460016', '愛知県', 'アイチケン', '安城市', 'アンジョウシ', '山崎町', 'ヤマザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県安城市大岡町', '23', '23212', '4460017', '愛知県', 'アイチケン', '安城市', 'アンジョウシ', '大岡町', 'オオオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県安城市東新町', '23', '23212', '4460018', '愛知県', 'アイチケン', '安城市', 'アンジョウシ', '東新町', 'トウシンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県安城市新明町', '23', '23212', '4460019', '愛知県', 'アイチケン', '安城市', 'アンジョウシ', '新明町', 'シンメイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県安城市法連町', '23', '23212', '4460021', '愛知県', 'アイチケン', '安城市', 'アンジョウシ', '法連町', 'ホウレンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県安城市浜富町', '23', '23212', '4460022', '愛知県', 'アイチケン', '安城市', 'アンジョウシ', '浜富町', 'ハマトミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県安城市上条町', '23', '23212', '4460023', '愛知県', 'アイチケン', '安城市', 'アンジョウシ', '上条町', 'ジョウジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県安城市河野町', '23', '23212', '4460024', '愛知県', 'アイチケン', '安城市', 'アンジョウシ', '河野町', 'カワノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県安城市古井町', '23', '23212', '4460025', '愛知県', 'アイチケン', '安城市', 'アンジョウシ', '古井町', 'フルイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県安城市安城町', '23', '23212', '4460026', '愛知県', 'アイチケン', '安城市', 'アンジョウシ', '安城町', 'アンジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県安城市東明町', '23', '23212', '4460027', '愛知県', 'アイチケン', '安城市', 'アンジョウシ', '東明町', 'トウメイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県安城市朝日町', '23', '23212', '4460031', '愛知県', 'アイチケン', '安城市', 'アンジョウシ', '朝日町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県安城市御幸本町', '23', '23212', '4460032', '愛知県', 'アイチケン', '安城市', 'アンジョウシ', '御幸本町', 'ミユキホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県安城市日の出町', '23', '23212', '4460033', '愛知県', 'アイチケン', '安城市', 'アンジョウシ', '日の出町', 'ヒノデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県安城市南町', '23', '23212', '4460034', '愛知県', 'アイチケン', '安城市', 'アンジョウシ', '南町', 'ミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県安城市錦町', '23', '23212', '4460035', '愛知県', 'アイチケン', '安城市', 'アンジョウシ', '錦町', 'ニシキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県安城市小堤町', '23', '23212', '4460036', '愛知県', 'アイチケン', '安城市', 'アンジョウシ', '小堤町', 'コヅツミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県安城市相生町', '23', '23212', '4460037', '愛知県', 'アイチケン', '安城市', 'アンジョウシ', '相生町', 'アイオイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県安城市末広町', '23', '23212', '4460038', '愛知県', 'アイチケン', '安城市', 'アンジョウシ', '末広町', 'スエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県安城市花ノ木町', '23', '23212', '4460039', '愛知県', 'アイチケン', '安城市', 'アンジョウシ', '花ノ木町', 'ハナノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県安城市桜町', '23', '23212', '4460041', '愛知県', 'アイチケン', '安城市', 'アンジョウシ', '桜町', 'サクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県安城市大山町', '23', '23212', '4460042', '愛知県', 'アイチケン', '安城市', 'アンジョウシ', '大山町', 'オオヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県安城市城南町', '23', '23212', '4460043', '愛知県', 'アイチケン', '安城市', 'アンジョウシ', '城南町', 'ジョウナンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県安城市百石町', '23', '23212', '4460044', '愛知県', 'アイチケン', '安城市', 'アンジョウシ', '百石町', 'ヒャッコクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県安城市横山町', '23', '23212', '4460045', '愛知県', 'アイチケン', '安城市', 'アンジョウシ', '横山町', 'ヨコヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県安城市赤松町', '23', '23212', '4460046', '愛知県', 'アイチケン', '安城市', 'アンジョウシ', '赤松町', 'アカマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県安城市箕輪町', '23', '23212', '4460051', '愛知県', 'アイチケン', '安城市', 'アンジョウシ', '箕輪町', 'ミノワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県安城市福釜町', '23', '23212', '4460052', '愛知県', 'アイチケン', '安城市', 'アンジョウシ', '福釜町', 'フカマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県安城市高棚町', '23', '23212', '4460053', '愛知県', 'アイチケン', '安城市', 'アンジョウシ', '高棚町', 'タカタナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県安城市二本木町', '23', '23212', '4460054', '愛知県', 'アイチケン', '安城市', 'アンジョウシ', '二本木町', 'ニホンギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県安城市緑町', '23', '23212', '4460055', '愛知県', 'アイチケン', '安城市', 'アンジョウシ', '緑町', 'ミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県安城市三河安城町', '23', '23212', '4460056', '愛知県', 'アイチケン', '安城市', 'アンジョウシ', '三河安城町', 'ミカワアンジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県安城市三河安城東町', '23', '23212', '4460057', '愛知県', 'アイチケン', '安城市', 'アンジョウシ', '三河安城東町', 'ミカワアンジョウヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県安城市三河安城南町', '23', '23212', '4460058', '愛知県', 'アイチケン', '安城市', 'アンジョウシ', '三河安城南町', 'ミカワアンジョウミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県安城市三河安城本町', '23', '23212', '4460059', '愛知県', 'アイチケン', '安城市', 'アンジョウシ', '三河安城本町', 'ミカワアンジョウホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県安城市新田町', '23', '23212', '4460061', '愛知県', 'アイチケン', '安城市', 'アンジョウシ', '新田町', 'シンデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県安城市明治本町', '23', '23212', '4460062', '愛知県', 'アイチケン', '安城市', 'アンジョウシ', '明治本町', 'メイジホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県安城市昭和町', '23', '23212', '4460063', '愛知県', 'アイチケン', '安城市', 'アンジョウシ', '昭和町', 'ショウワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県安城市弁天町', '23', '23212', '4460064', '愛知県', 'アイチケン', '安城市', 'アンジョウシ', '弁天町', 'ベンテンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県安城市大東町', '23', '23212', '4460065', '愛知県', 'アイチケン', '安城市', 'アンジョウシ', '大東町', 'ダイトウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県安城市池浦町', '23', '23212', '4460066', '愛知県', 'アイチケン', '安城市', 'アンジョウシ', '池浦町', 'イケウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県安城市今池町', '23', '23212', '4460071', '愛知県', 'アイチケン', '安城市', 'アンジョウシ', '今池町', 'イマイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県安城市住吉町', '23', '23212', '4460072', '愛知県', 'アイチケン', '安城市', 'アンジョウシ', '住吉町', 'スミヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県安城市篠目町', '23', '23212', '4460073', '愛知県', 'アイチケン', '安城市', 'アンジョウシ', '篠目町', 'ササメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県安城市井杭山町', '23', '23212', '4460074', '愛知県', 'アイチケン', '安城市', 'アンジョウシ', '井杭山町', 'イグイヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県安城市二本木新町', '23', '23212', '4460075', '愛知県', 'アイチケン', '安城市', 'アンジョウシ', '二本木新町', 'ニホンギシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県安城市美園町', '23', '23212', '4460076', '愛知県', 'アイチケン', '安城市', 'アンジョウシ', '美園町', 'ミソノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市', '23', '23209', '4470000', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('43198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市北町', '23', '23209', '4470001', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '北町', 'キタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市井口町', '23', '23209', '4470002', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '井口町', 'イグチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市雁道町', '23', '23209', '4470003', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '雁道町', 'ガンミチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市用久町', '23', '23209', '4470004', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '用久町', 'ヨウキュウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市若水町', '23', '23209', '4470005', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '若水町', 'ワカミズマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市宝町', '23', '23209', '4470006', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '宝町', 'タカラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市竹原町', '23', '23209', '4470007', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '竹原町', 'タケハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市大久手町', '23', '23209', '4470008', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '大久手町', 'オオクテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市平山町', '23', '23209', '4470011', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '平山町', 'ヒラヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市大坪町', '23', '23209', '4470012', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '大坪町', 'オオツボマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市白沢町', '23', '23209', '4470013', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '白沢町', 'シロサワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市長田町', '23', '23209', '4470014', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '長田町', 'オサダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市半崎町', '23', '23209', '4470015', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '半崎町', 'ハンザキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市神田町', '23', '23209', '4470016', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '神田町', 'カンダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市奥沢町', '23', '23209', '4470017', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '奥沢町', 'オクサワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市縄手町', '23', '23209', '4470021', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '縄手町', 'ナワテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市旭町', '23', '23209', '4470022', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '旭町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市池下町', '23', '23209', '4470023', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '池下町', 'イケシタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市亀穴町', '23', '23209', '4470024', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '亀穴町', 'カメアナマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市大堤町', '23', '23209', '4470025', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '大堤町', 'オオヅツミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市三宅町', '23', '23209', '4470026', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '三宅町', 'ミヤケマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市照光町', '23', '23209', '4470027', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '照光町', 'ショウコウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市神有町', '23', '23209', '4470028', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '神有町', 'カミアリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市二本木町', '23', '23209', '4470029', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '二本木町', 'ニホンギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市見合町', '23', '23209', '4470031', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '見合町', 'ミアイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市北浦町', '23', '23209', '4470032', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '北浦町', 'キタウラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市天神町', '23', '23209', '4470033', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '天神町', 'テンジンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市鴻島町', '23', '23209', '4470034', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '鴻島町', 'コウジママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市中山町', '23', '23209', '4470035', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '中山町', 'ナカヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市尾城町', '23', '23209', '4470036', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '尾城町', 'オジロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市城山町', '23', '23209', '4470037', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '城山町', 'シロヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市荒子町', '23', '23209', '4470038', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '荒子町', 'アラコマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市緑町', '23', '23209', '4470041', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '緑町', 'ミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市中後町', '23', '23209', '4470042', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '中後町', 'ナカゴマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市幸町', '23', '23209', '4470043', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '幸町', 'サイワイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市末広町', '23', '23209', '4470044', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '末広町', 'スエヒロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市篭田町', '23', '23209', '4470045', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '篭田町', 'カゴタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市堀方町', '23', '23209', '4470046', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '堀方町', 'ホリカタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市植出町', '23', '23209', '4470047', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '植出町', 'ウエダシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市福清水町', '23', '23209', '4470048', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '福清水町', 'フクシミズマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市東山町', '23', '23209', '4470051', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '東山町', 'ヒガシヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市新道町', '23', '23209', '4470052', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '新道町', 'シンミチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市笹山町', '23', '23209', '4470053', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '笹山町', 'ササヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市踏分町', '23', '23209', '4470054', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '踏分町', 'フミワケマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市浜尾町', '23', '23209', '4470055', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '浜尾町', 'ハマオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市千福町', '23', '23209', '4470056', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '千福町', 'センブクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市鶴見町', '23', '23209', '4470057', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '鶴見町', 'ツルミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市住吉町', '23', '23209', '4470058', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '住吉町', 'スミヨシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市三度山町', '23', '23209', '4470061', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '三度山町', 'サンドヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市古川町', '23', '23209', '4470062', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '古川町', 'フルカワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市山下町', '23', '23209', '4470063', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '山下町', 'ヤマシタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市西山町', '23', '23209', '4470064', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '西山町', 'ニシヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市久沓町', '23', '23209', '4470065', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '久沓町', 'クグツマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市丸山町', '23', '23209', '4470066', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '丸山町', 'マルヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市広見町', '23', '23209', '4470067', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '広見町', 'ヒロミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市荒居町', '23', '23209', '4470068', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '荒居町', 'アライマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市桃山町', '23', '23209', '4470071', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '桃山町', 'モモヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市清水町', '23', '23209', '4470072', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '清水町', 'シミズマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市鳥追町', '23', '23209', '4470073', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '鳥追町', 'トリオイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市上町', '23', '23209', '4470074', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '上町', 'カミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市立山町', '23', '23209', '4470075', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '立山町', 'タテヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市白砂町', '23', '23209', '4470076', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '白砂町', 'シロスナマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市屋敷町', '23', '23209', '4470077', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '屋敷町', 'ヤシキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市島池町', '23', '23209', '4470078', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '島池町', 'シマイケマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市松原町', '23', '23209', '4470079', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '松原町', 'マツバラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市吹上町', '23', '23209', '4470081', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '吹上町', 'フキアゲマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市湖西町', '23', '23209', '4470082', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '湖西町', 'コセイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市油渕町', '23', '23209', '4470083', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '油渕町', 'アブラフチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市平和町', '23', '23209', '4470084', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '平和町', 'ヘイワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市金山町', '23', '23209', '4470085', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '金山町', 'カナヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市洲先町', '23', '23209', '4470086', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '洲先町', 'スサキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市坂口町', '23', '23209', '4470087', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '坂口町', 'サカグチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市札木町', '23', '23209', '4470088', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '札木町', 'フダキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市野銭町', '23', '23209', '4470801', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '野銭町', 'ノセンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市鷲林町', '23', '23209', '4470802', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '鷲林町', 'ワシバヤシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市三角町', '23', '23209', '4470803', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '三角町', 'サンカクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市流作町', '23', '23209', '4470804', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '流作町', 'リュウサクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市矢縄町', '23', '23209', '4470805', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '矢縄町', 'ヤナワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市三間町', '23', '23209', '4470806', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '三間町', 'サンゲンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市伏見町', '23', '23209', '4470807', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '伏見町', 'フシミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市鷲塚町', '23', '23209', '4470808', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '鷲塚町', 'ワシヅカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市小屋下町', '23', '23209', '4470809', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '小屋下町', 'コヤシタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市舟江町', '23', '23209', '4470811', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '舟江町', 'フナエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市中江町', '23', '23209', '4470812', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '中江町', 'ナカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市雨池町', '23', '23209', '4470813', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '雨池町', 'アマイケマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市弥生町', '23', '23209', '4470814', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '弥生町', 'ヤヨイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市棚尾本町', '23', '23209', '4470815', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '棚尾本町', 'タナオホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市志貴崎町', '23', '23209', '4470816', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '志貴崎町', 'シキサキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市川端町', '23', '23209', '4470817', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '川端町', 'カワバタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市若宮町', '23', '23209', '4470818', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '若宮町', 'ワカミヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市稲荷町', '23', '23209', '4470821', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '稲荷町', 'イナリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市河方町', '23', '23209', '4470822', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '河方町', 'カワカタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市川口町', '23', '23209', '4470823', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '川口町', 'カワグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市港南町', '23', '23209', '4470824', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '港南町', 'コウナンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市江口町', '23', '23209', '4470825', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '江口町', 'エグチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市葭生町', '23', '23209', '4470826', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '葭生町', 'ヨシオイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市前浜町', '23', '23209', '4470827', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '前浜町', 'マエハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市潮見町', '23', '23209', '4470828', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '潮見町', 'シオミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市中田町', '23', '23209', '4470829', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '中田町', 'ナカタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市入船町', '23', '23209', '4470831', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '入船町', 'イリフネマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市岬町', '23', '23209', '4470832', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '岬町', 'ミサキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市権現町', '23', '23209', '4470833', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '権現町', 'ゴンゲンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市玉津浦町', '23', '23209', '4470834', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '玉津浦町', 'タマツウラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市宮町', '23', '23209', '4470835', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '宮町', 'ミヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市若松町', '23', '23209', '4470836', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '若松町', 'ワカマツマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市伊勢町', '23', '23209', '4470837', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '伊勢町', 'イセマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市権田町', '23', '23209', '4470838', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '権田町', 'ゴンダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市塩浜町', '23', '23209', '4470841', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '塩浜町', 'シオハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市浜田町', '23', '23209', '4470842', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '浜田町', 'ハマダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市西浜町', '23', '23209', '4470843', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '西浜町', 'ニシハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市港本町', '23', '23209', '4470844', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '港本町', 'ミナトホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市浜寺町', '23', '23209', '4470845', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '浜寺町', 'ハマデラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市中町', '23', '23209', '4470846', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '中町', 'ナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市音羽町', '23', '23209', '4470847', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '音羽町', 'オトハマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市錦町', '23', '23209', '4470848', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '錦町', 'ニシキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市築山町', '23', '23209', '4470849', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '築山町', 'ツキヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市羽根町', '23', '23209', '4470851', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '羽根町', 'ハネマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市本郷町', '23', '23209', '4470852', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '本郷町', 'ホンゴウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市浜町', '23', '23209', '4470853', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '浜町', 'ハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市須磨町', '23', '23209', '4470854', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '須磨町', 'スママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市天王町', '23', '23209', '4470855', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '天王町', 'テンノウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市宮後町', '23', '23209', '4470856', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '宮後町', 'ミヤゴマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市大浜上町', '23', '23209', '4470857', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '大浜上町', 'オオハマカミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市石橋町', '23', '23209', '4470858', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '石橋町', 'イシバシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市中松町', '23', '23209', '4470859', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '中松町', 'ナカマツマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市六軒町', '23', '23209', '4470861', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '六軒町', 'ロッケンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市相生町', '23', '23209', '4470862', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '相生町', 'アイオイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市新川町', '23', '23209', '4470863', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '新川町', 'シンカワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市道場山町', '23', '23209', '4470864', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '道場山町', 'ドウジョウヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市浅間町', '23', '23209', '4470865', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '浅間町', 'アサママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市明石町', '23', '23209', '4470866', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '明石町', 'アカシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市田尻町', '23', '23209', '4470867', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '田尻町', 'タジリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市松江町', '23', '23209', '4470868', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '松江町', 'マツエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市山神町', '23', '23209', '4470869', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '山神町', 'ヤマガミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市向陽町', '23', '23209', '4470871', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '向陽町', 'コウヨウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市源氏神明町', '23', '23209', '4470872', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '源氏神明町', 'ゲンジシンメイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市栗山町', '23', '23209', '4470873', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '栗山町', 'クリヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市作塚町', '23', '23209', '4470874', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '作塚町', 'サクヅカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市善明町', '23', '23209', '4470875', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '善明町', 'ゼンメイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市野田町', '23', '23209', '4470876', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '野田町', 'ノダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市栄町', '23', '23209', '4470877', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市松本町', '23', '23209', '4470878', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '松本町', 'マツモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市沢渡町', '23', '23209', '4470879', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '沢渡町', 'サワタリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市霞浦町', '23', '23209', '4470881', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '霞浦町', 'カスミウラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市日進町', '23', '23209', '4470882', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '日進町', 'ニッシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市下洲町', '23', '23209', '4470883', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '下洲町', 'シモスマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市平七町', '23', '23209', '4470884', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '平七町', 'ヘイシチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市志貴町', '23', '23209', '4470885', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '志貴町', 'シキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市源氏町', '23', '23209', '4470886', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '源氏町', 'ゲンジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市汐田町', '23', '23209', '4470887', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '汐田町', 'シオタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市春日町', '23', '23209', '4470888', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '春日町', 'カスガマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県碧南市東浦町', '23', '23209', '4470889', '愛知県', 'アイチケン', '碧南市', 'ヘキナンシ', '東浦町', 'ヒガシウラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県刈谷市', '23', '23210', '4480000', '愛知県', 'アイチケン', '刈谷市', 'カリヤシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('43366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県刈谷市井ケ谷町', '23', '23210', '4480001', '愛知県', 'アイチケン', '刈谷市', 'カリヤシ', '井ケ谷町', 'イガヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県刈谷市一里山町', '23', '23210', '4480002', '愛知県', 'アイチケン', '刈谷市', 'カリヤシ', '一里山町', 'イチリヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県刈谷市一ツ木町', '23', '23210', '4480003', '愛知県', 'アイチケン', '刈谷市', 'カリヤシ', '一ツ木町', 'ヒトツギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県刈谷市泉田町', '23', '23210', '4480004', '愛知県', 'アイチケン', '刈谷市', 'カリヤシ', '泉田町', 'イズミダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県刈谷市今川町', '23', '23210', '4480005', '愛知県', 'アイチケン', '刈谷市', 'カリヤシ', '今川町', 'イマガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県刈谷市西境町', '23', '23210', '4480006', '愛知県', 'アイチケン', '刈谷市', 'カリヤシ', '西境町', 'ニシザカイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県刈谷市東境町', '23', '23210', '4480007', '愛知県', 'アイチケン', '刈谷市', 'カリヤシ', '東境町', 'ヒガシザカイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県刈谷市今岡町', '23', '23210', '4480008', '愛知県', 'アイチケン', '刈谷市', 'カリヤシ', '今岡町', 'イマオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県刈谷市築地町', '23', '23210', '4480011', '愛知県', 'アイチケン', '刈谷市', 'カリヤシ', '築地町', 'ツイジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県刈谷市上重原町', '23', '23210', '4480012', '愛知県', 'アイチケン', '刈谷市', 'カリヤシ', '上重原町', 'カミシゲハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県刈谷市恩田町', '23', '23210', '4480013', '愛知県', 'アイチケン', '刈谷市', 'カリヤシ', '恩田町', 'オンダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県刈谷市青山町', '23', '23210', '4480014', '愛知県', 'アイチケン', '刈谷市', 'カリヤシ', '青山町', 'アオヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県刈谷市新田町', '23', '23210', '4480015', '愛知県', 'アイチケン', '刈谷市', 'カリヤシ', '新田町', 'シンデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県刈谷市八軒町', '23', '23210', '4480021', '愛知県', 'アイチケン', '刈谷市', 'カリヤシ', '八軒町', 'ハチケンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県刈谷市一色町', '23', '23210', '4480022', '愛知県', 'アイチケン', '刈谷市', 'カリヤシ', '一色町', 'イシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県刈谷市重原本町', '23', '23210', '4480023', '愛知県', 'アイチケン', '刈谷市', 'カリヤシ', '重原本町', 'シゲハラホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県刈谷市下重原町', '23', '23210', '4480024', '愛知県', 'アイチケン', '刈谷市', 'カリヤシ', '下重原町', 'シモシゲハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県刈谷市幸町', '23', '23210', '4480025', '愛知県', 'アイチケン', '刈谷市', 'カリヤシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県刈谷市中山町', '23', '23210', '4480026', '愛知県', 'アイチケン', '刈谷市', 'カリヤシ', '中山町', 'ナカヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県刈谷市相生町', '23', '23210', '4480027', '愛知県', 'アイチケン', '刈谷市', 'カリヤシ', '相生町', 'アイオイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県刈谷市桜町', '23', '23210', '4480028', '愛知県', 'アイチケン', '刈谷市', 'カリヤシ', '桜町', 'サクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県刈谷市昭和町', '23', '23210', '4480029', '愛知県', 'アイチケン', '刈谷市', 'カリヤシ', '昭和町', 'ショウワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県刈谷市東新町', '23', '23210', '4480031', '愛知県', 'アイチケン', '刈谷市', 'カリヤシ', '東新町', 'トウシンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県刈谷市朝日町', '23', '23210', '4480032', '愛知県', 'アイチケン', '刈谷市', 'カリヤシ', '朝日町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県刈谷市丸田町', '23', '23210', '4480033', '愛知県', 'アイチケン', '刈谷市', 'カリヤシ', '丸田町', 'マルタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県刈谷市神明町', '23', '23210', '4480034', '愛知県', 'アイチケン', '刈谷市', 'カリヤシ', '神明町', 'シンメイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県刈谷市矢場町', '23', '23210', '4480035', '愛知県', 'アイチケン', '刈谷市', 'カリヤシ', '矢場町', 'ヤバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県刈谷市山池町', '23', '23210', '4480036', '愛知県', 'アイチケン', '刈谷市', 'カリヤシ', '山池町', 'ヤマイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県刈谷市高倉町', '23', '23210', '4480037', '愛知県', 'アイチケン', '刈谷市', 'カリヤシ', '高倉町', 'タカクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県刈谷市稲場町', '23', '23210', '4480038', '愛知県', 'アイチケン', '刈谷市', 'カリヤシ', '稲場町', 'イナバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県刈谷市原崎町', '23', '23210', '4480039', '愛知県', 'アイチケン', '刈谷市', 'カリヤシ', '原崎町', 'ハラサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県刈谷市一番町', '23', '23210', '4480041', '愛知県', 'アイチケン', '刈谷市', 'カリヤシ', '一番町', 'イチバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県刈谷市広見町', '23', '23210', '4480042', '愛知県', 'アイチケン', '刈谷市', 'カリヤシ', '広見町', 'ヒロミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県刈谷市小山町', '23', '23210', '4480043', '愛知県', 'アイチケン', '刈谷市', 'カリヤシ', '小山町', 'オヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県刈谷市池田町', '23', '23210', '4480044', '愛知県', 'アイチケン', '刈谷市', 'カリヤシ', '池田町', 'イケダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県刈谷市新富町', '23', '23210', '4480045', '愛知県', 'アイチケン', '刈谷市', 'カリヤシ', '新富町', 'シントミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県刈谷市日高町', '23', '23210', '4480046', '愛知県', 'アイチケン', '刈谷市', 'カリヤシ', '日高町', 'ヒダカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県刈谷市高津波町', '23', '23210', '4480047', '愛知県', 'アイチケン', '刈谷市', 'カリヤシ', '高津波町', 'タカツナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県刈谷市三田町', '23', '23210', '4480048', '愛知県', 'アイチケン', '刈谷市', 'カリヤシ', '三田町', 'ミタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県刈谷市中手町', '23', '23210', '4480049', '愛知県', 'アイチケン', '刈谷市', 'カリヤシ', '中手町', 'ナカテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県刈谷市板倉町', '23', '23210', '4480801', '愛知県', 'アイチケン', '刈谷市', 'カリヤシ', '板倉町', 'イタクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県刈谷市末広町', '23', '23210', '4480802', '愛知県', 'アイチケン', '刈谷市', 'カリヤシ', '末広町', 'スエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県刈谷市野田町', '23', '23210', '4480803', '愛知県', 'アイチケン', '刈谷市', 'カリヤシ', '野田町', 'ノダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県刈谷市半城土町', '23', '23210', '4480804', '愛知県', 'アイチケン', '刈谷市', 'カリヤシ', '半城土町', 'ハジョウドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県刈谷市半城土中町', '23', '23210', '4480805', '愛知県', 'アイチケン', '刈谷市', 'カリヤシ', '半城土中町', 'ハジョウドナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県刈谷市松栄町', '23', '23210', '4480806', '愛知県', 'アイチケン', '刈谷市', 'カリヤシ', '松栄町', 'ショウエイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県刈谷市東刈谷町', '23', '23210', '4480807', '愛知県', 'アイチケン', '刈谷市', 'カリヤシ', '東刈谷町', 'ヒガシカリヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県刈谷市沖野町', '23', '23210', '4480808', '愛知県', 'アイチケン', '刈谷市', 'カリヤシ', '沖野町', 'オキノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県刈谷市南沖野町', '23', '23210', '4480809', '愛知県', 'アイチケン', '刈谷市', 'カリヤシ', '南沖野町', 'ミナミオキノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県刈谷市場割町', '23', '23210', '4480810', '愛知県', 'アイチケン', '刈谷市', 'カリヤシ', '場割町', 'バワリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県刈谷市田町', '23', '23210', '4480811', '愛知県', 'アイチケン', '刈谷市', 'カリヤシ', '田町', 'タマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県刈谷市高須町', '23', '23210', '4480812', '愛知県', 'アイチケン', '刈谷市', 'カリヤシ', '高須町', 'タカスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県刈谷市小垣江町', '23', '23210', '4480813', '愛知県', 'アイチケン', '刈谷市', 'カリヤシ', '小垣江町', 'オガキエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県刈谷市荒井町', '23', '23210', '4480814', '愛知県', 'アイチケン', '刈谷市', 'カリヤシ', '荒井町', 'アライチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県刈谷市中島町', '23', '23210', '4480815', '愛知県', 'アイチケン', '刈谷市', 'カリヤシ', '中島町', 'ナカジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県刈谷市御幸町', '23', '23210', '4480821', '愛知県', 'アイチケン', '刈谷市', 'カリヤシ', '御幸町', 'ミユキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県刈谷市松坂町', '23', '23210', '4480822', '愛知県', 'アイチケン', '刈谷市', 'カリヤシ', '松坂町', 'マツザカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県刈谷市中川町', '23', '23210', '4480823', '愛知県', 'アイチケン', '刈谷市', 'カリヤシ', '中川町', 'ナカガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県刈谷市天王町', '23', '23210', '4480824', '愛知県', 'アイチケン', '刈谷市', 'カリヤシ', '天王町', 'テンノウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県刈谷市元町', '23', '23210', '4480825', '愛知県', 'アイチケン', '刈谷市', 'カリヤシ', '元町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県刈谷市熊野町', '23', '23210', '4480831', '愛知県', 'アイチケン', '刈谷市', 'カリヤシ', '熊野町', 'クマノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県刈谷市八幡町', '23', '23210', '4480832', '愛知県', 'アイチケン', '刈谷市', 'カリヤシ', '八幡町', 'ハチマンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県刈谷市城町', '23', '23210', '4480833', '愛知県', 'アイチケン', '刈谷市', 'カリヤシ', '城町', 'シロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県刈谷市司町', '23', '23210', '4480834', '愛知県', 'アイチケン', '刈谷市', 'カリヤシ', '司町', 'ツカサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県刈谷市港町', '23', '23210', '4480835', '愛知県', 'アイチケン', '刈谷市', 'カリヤシ', '港町', 'ミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県刈谷市浜町', '23', '23210', '4480836', '愛知県', 'アイチケン', '刈谷市', 'カリヤシ', '浜町', 'ハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県刈谷市衣崎町', '23', '23210', '4480837', '愛知県', 'アイチケン', '刈谷市', 'カリヤシ', '衣崎町', 'コロモザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県刈谷市逢妻町', '23', '23210', '4480838', '愛知県', 'アイチケン', '刈谷市', 'カリヤシ', '逢妻町', 'アイヅマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県刈谷市南桜町', '23', '23210', '4480841', '愛知県', 'アイチケン', '刈谷市', 'カリヤシ', '南桜町', 'ミナミサクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県刈谷市東陽町', '23', '23210', '4480842', '愛知県', 'アイチケン', '刈谷市', 'カリヤシ', '東陽町', 'トウヨウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県刈谷市新栄町', '23', '23210', '4480843', '愛知県', 'アイチケン', '刈谷市', 'カリヤシ', '新栄町', 'シンサカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県刈谷市広小路', '23', '23210', '4480844', '愛知県', 'アイチケン', '刈谷市', 'カリヤシ', '広小路', 'ヒロコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県刈谷市銀座', '23', '23210', '4480845', '愛知県', 'アイチケン', '刈谷市', 'カリヤシ', '銀座', 'ギンザ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県刈谷市寺横町', '23', '23210', '4480846', '愛知県', 'アイチケン', '刈谷市', 'カリヤシ', '寺横町', 'テラヨコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県刈谷市宝町', '23', '23210', '4480847', '愛知県', 'アイチケン', '刈谷市', 'カリヤシ', '宝町', 'タカラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県刈谷市豊田町', '23', '23210', '4480848', '愛知県', 'アイチケン', '刈谷市', 'カリヤシ', '豊田町', 'トヨダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県刈谷市神田町', '23', '23210', '4480851', '愛知県', 'アイチケン', '刈谷市', 'カリヤシ', '神田町', 'カンダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県刈谷市住吉町', '23', '23210', '4480852', '愛知県', 'アイチケン', '刈谷市', 'カリヤシ', '住吉町', 'スミヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県刈谷市高松町', '23', '23210', '4480853', '愛知県', 'アイチケン', '刈谷市', 'カリヤシ', '高松町', 'タカマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県刈谷市富士見町', '23', '23210', '4480854', '愛知県', 'アイチケン', '刈谷市', 'カリヤシ', '富士見町', 'フジミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県刈谷市大正町', '23', '23210', '4480855', '愛知県', 'アイチケン', '刈谷市', 'カリヤシ', '大正町', 'タイショウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県刈谷市寿町', '23', '23210', '4480856', '愛知県', 'アイチケン', '刈谷市', 'カリヤシ', '寿町', 'コトブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県刈谷市大手町', '23', '23210', '4480857', '愛知県', 'アイチケン', '刈谷市', 'カリヤシ', '大手町', 'オオテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県刈谷市若松町', '23', '23210', '4480858', '愛知県', 'アイチケン', '刈谷市', 'カリヤシ', '若松町', 'ワカマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県刈谷市半城土北町', '23', '23210', '4480861', '愛知県', 'アイチケン', '刈谷市', 'カリヤシ', '半城土北町', 'ハジョウドキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県刈谷市野田新町', '23', '23210', '4480862', '愛知県', 'アイチケン', '刈谷市', 'カリヤシ', '野田新町', 'ノダシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県北設楽郡東栄町', '23', '23562', '4490200', '愛知県', 'アイチケン', '北設楽郡東栄町', 'キタシタラグントウエイチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('43482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県北設楽郡東栄町御園', '23', '23562', '4490201', '愛知県', 'アイチケン', '北設楽郡東栄町', 'キタシタラグントウエイチョウ', '御園', 'ミソノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県北設楽郡東栄町足込', '23', '23562', '4490202', '愛知県', 'アイチケン', '北設楽郡東栄町', 'キタシタラグントウエイチョウ', '足込', 'アシコメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県北設楽郡東栄町東薗目', '23', '23562', '4490203', '愛知県', 'アイチケン', '北設楽郡東栄町', 'キタシタラグントウエイチョウ', '東薗目', 'ヒガシソノメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県北設楽郡東栄町西薗目', '23', '23562', '4490204', '愛知県', 'アイチケン', '北設楽郡東栄町', 'キタシタラグントウエイチョウ', '西薗目', 'ニシソノメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県北設楽郡東栄町川角', '23', '23562', '4490205', '愛知県', 'アイチケン', '北設楽郡東栄町', 'キタシタラグントウエイチョウ', '川角', 'カワカド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県北設楽郡東栄町下田', '23', '23562', '4490206', '愛知県', 'アイチケン', '北設楽郡東栄町', 'キタシタラグントウエイチョウ', '下田', 'シモダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県北設楽郡東栄町中設楽', '23', '23562', '4490211', '愛知県', 'アイチケン', '北設楽郡東栄町', 'キタシタラグントウエイチョウ', '中設楽', 'ナカシタラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県北設楽郡東栄町月', '23', '23562', '4490212', '愛知県', 'アイチケン', '北設楽郡東栄町', 'キタシタラグントウエイチョウ', '月', 'ツキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県北設楽郡東栄町振草', '23', '23562', '4490213', '愛知県', 'アイチケン', '北設楽郡東栄町', 'キタシタラグントウエイチョウ', '振草', 'フリクサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県北設楽郡東栄町本郷', '23', '23562', '4490214', '愛知県', 'アイチケン', '北設楽郡東栄町', 'キタシタラグントウエイチョウ', '本郷', 'ホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県北設楽郡東栄町奈根', '23', '23562', '4490215', '愛知県', 'アイチケン', '北設楽郡東栄町', 'キタシタラグントウエイチョウ', '奈根', 'ナネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県北設楽郡東栄町三輪', '23', '23562', '4490216', '愛知県', 'アイチケン', '北設楽郡東栄町', 'キタシタラグントウエイチョウ', '三輪', 'ミワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県北設楽郡豊根村', '23', '23563', '4490400', '愛知県', 'アイチケン', '北設楽郡豊根村', 'キタシタラグントヨネムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('43498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県北設楽郡豊根村三沢', '23', '23563', '4490401', '愛知県', 'アイチケン', '北設楽郡豊根村', 'キタシタラグントヨネムラ', '三沢', 'ミサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県北設楽郡豊根村古真立', '23', '23563', '4490402', '愛知県', 'アイチケン', '北設楽郡豊根村', 'キタシタラグントヨネムラ', '古真立', 'コマダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県北設楽郡豊根村下黒川', '23', '23563', '4490403', '愛知県', 'アイチケン', '北設楽郡豊根村', 'キタシタラグントヨネムラ', '下黒川', 'シモクロガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県北設楽郡豊根村上黒川', '23', '23563', '4490404', '愛知県', 'アイチケン', '北設楽郡豊根村', 'キタシタラグントヨネムラ', '上黒川', 'カミクロガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県北設楽郡豊根村坂宇場', '23', '23563', '4490405', '愛知県', 'アイチケン', '北設楽郡豊根村', 'キタシタラグントヨネムラ', '坂宇場', 'サカウバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩内郡岩内町', '01', '01402', '0450000', '北海道', 'ホッカイドウ', '岩内郡岩内町', 'イワナイグンイワナイチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('43504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区那古野', '23', '23105', '4500001', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '那古野', 'ナゴノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名駅', '23', '23105', '4500002', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名駅', 'メイエキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名駅南', '23', '23105', '4500003', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名駅南', 'メイエキミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区松重町', '23', '23105', '4500004', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '松重町', 'マツシゲチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区西日置', '23', '23105', '4500005', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '西日置', 'ニシヒオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区下広井町', '23', '23105', '4500006', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '下広井町', 'シモヒロイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区笹島町', '23', '23105', '4500007', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '笹島町', 'ササシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩内郡岩内町大浜', '01', '01402', '0450001', '北海道', 'ホッカイドウ', '岩内郡岩内町', 'イワナイグンイワナイチョウ', '大浜', 'オオハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩内郡岩内町東山', '01', '01402', '0450002', '北海道', 'ホッカイドウ', '岩内郡岩内町', 'イワナイグンイワナイチョウ', '東山', 'ヒガシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩内郡岩内町万代', '01', '01402', '0450003', '北海道', 'ホッカイドウ', '岩内郡岩内町', 'イワナイグンイワナイチョウ', '万代', 'マンダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩内郡岩内町栄', '01', '01402', '0450011', '北海道', 'ホッカイドウ', '岩内郡岩内町', 'イワナイグンイワナイチョウ', '栄', 'サカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩内郡岩内町宮園', '01', '01402', '0450012', '北海道', 'ホッカイドウ', '岩内郡岩内町', 'イワナイグンイワナイチョウ', '宮園', 'ミヤゾノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩内郡岩内町高台', '01', '01402', '0450013', '北海道', 'ホッカイドウ', '岩内郡岩内町', 'イワナイグンイワナイチョウ', '高台', 'タカダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩内郡岩内町大和', '01', '01402', '0450021', '北海道', 'ホッカイドウ', '岩内郡岩内町', 'イワナイグンイワナイチョウ', '大和', 'ヤマト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩内郡岩内町清住', '01', '01402', '0450022', '北海道', 'ホッカイドウ', '岩内郡岩内町', 'イワナイグンイワナイチョウ', '清住', 'キヨズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩内郡岩内町相生', '01', '01402', '0450023', '北海道', 'ホッカイドウ', '岩内郡岩内町', 'イワナイグンイワナイチョウ', '相生', 'アイオイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩内郡岩内町野束', '01', '01402', '0450024', '北海道', 'ホッカイドウ', '岩内郡岩内町', 'イワナイグンイワナイチョウ', '野束', 'ノヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩内郡岩内町敷島内', '01', '01402', '0450025', '北海道', 'ホッカイドウ', '岩内郡岩内町', 'イワナイグンイワナイチョウ', '敷島内', 'シキシマナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩内郡岩内町御崎', '01', '01402', '0450026', '北海道', 'ホッカイドウ', '岩内郡岩内町', 'イワナイグンイワナイチョウ', '御崎', 'ミサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩内郡共和町梨野舞納', '01', '01401', '0450031', '北海道', 'ホッカイドウ', '岩内郡共和町', 'イワナイグンキョウワチョウ', '梨野舞納', 'リヤムナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩内郡共和町老古美', '01', '01401', '0450032', '北海道', 'ホッカイドウ', '岩内郡共和町', 'イワナイグンキョウワチョウ', '老古美', 'オイコミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩内郡共和町幌似', '01', '01401', '0450121', '北海道', 'ホッカイドウ', '岩内郡共和町', 'イワナイグンキョウワチョウ', '幌似', 'ホロニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩内郡共和町発足', '01', '01401', '0450122', '北海道', 'ホッカイドウ', '岩内郡共和町', 'イワナイグンキョウワチョウ', '発足', 'ハッタリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩内郡共和町宮丘', '01', '01401', '0450123', '北海道', 'ホッカイドウ', '岩内郡共和町', 'イワナイグンキョウワチョウ', '宮丘', 'ミヤオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道古宇郡泊村', '01', '01403', '0450200', '北海道', 'ホッカイドウ', '古宇郡泊村', 'フルウグントマリムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('43529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道古宇郡泊村堀株村', '01', '01403', '0450201', '北海道', 'ホッカイドウ', '古宇郡泊村', 'フルウグントマリムラ', '堀株村', 'ホリカップムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道古宇郡泊村茅沼村', '01', '01403', '0450202', '北海道', 'ホッカイドウ', '古宇郡泊村', 'フルウグントマリムラ', '茅沼村', 'カヤヌマムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道古宇郡泊村泊村', '01', '01403', '0450203', '北海道', 'ホッカイドウ', '古宇郡泊村', 'フルウグントマリムラ', '泊村', 'トマリムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道古宇郡泊村盃村', '01', '01403', '0450204', '北海道', 'ホッカイドウ', '古宇郡泊村', 'フルウグントマリムラ', '盃村', 'サカズキムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道古宇郡泊村興志内村', '01', '01403', '0450205', '北海道', 'ホッカイドウ', '古宇郡泊村', 'フルウグントマリムラ', '興志内村', 'オキシナイムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道古宇郡神恵内村', '01', '01404', '0450300', '北海道', 'ホッカイドウ', '古宇郡神恵内村', 'フルウグンカモエナイムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('43535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道古宇郡神恵内村神恵内村', '01', '01404', '0450301', '北海道', 'ホッカイドウ', '古宇郡神恵内村', 'フルウグンカモエナイムラ', '神恵内村', 'カモエナイムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道古宇郡神恵内村赤石村', '01', '01404', '0450302', '北海道', 'ホッカイドウ', '古宇郡神恵内村', 'フルウグンカモエナイムラ', '赤石村', 'アカイシムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道古宇郡神恵内村珊内村', '01', '01404', '0450303', '北海道', 'ホッカイドウ', '古宇郡神恵内村', 'フルウグンカモエナイムラ', '珊内村', 'サンナイムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名駅JRセントラルタワーズ　1階', '23', '23105', '4506001', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名駅', 'メイエキ', null, null, 'JRセントラルタワーズ　1階', 'ジェイアールセントラルタワーズ　01カイ');
INSERT INTO `ms_addresses` VALUES ('43539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名駅JRセントラルタワーズ　2階', '23', '23105', '4506002', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名駅', 'メイエキ', null, null, 'JRセントラルタワーズ　2階', 'ジェイアールセントラルタワーズ　02カイ');
INSERT INTO `ms_addresses` VALUES ('43540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名駅JRセントラルタワーズ　3階', '23', '23105', '4506003', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名駅', 'メイエキ', null, null, 'JRセントラルタワーズ　3階', 'ジェイアールセントラルタワーズ　03カイ');
INSERT INTO `ms_addresses` VALUES ('43541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名駅JRセントラルタワーズ　4階', '23', '23105', '4506004', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名駅', 'メイエキ', null, null, 'JRセントラルタワーズ　4階', 'ジェイアールセントラルタワーズ　04カイ');
INSERT INTO `ms_addresses` VALUES ('43542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名駅JRセントラルタワーズ　5階', '23', '23105', '4506005', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名駅', 'メイエキ', null, null, 'JRセントラルタワーズ　5階', 'ジェイアールセントラルタワーズ　05カイ');
INSERT INTO `ms_addresses` VALUES ('43543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名駅JRセントラルタワーズ　6階', '23', '23105', '4506006', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名駅', 'メイエキ', null, null, 'JRセントラルタワーズ　6階', 'ジェイアールセントラルタワーズ　06カイ');
INSERT INTO `ms_addresses` VALUES ('43544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名駅JRセントラルタワーズ　7階', '23', '23105', '4506007', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名駅', 'メイエキ', null, null, 'JRセントラルタワーズ　7階', 'ジェイアールセントラルタワーズ　07カイ');
INSERT INTO `ms_addresses` VALUES ('43545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名駅JRセントラルタワーズ　8階', '23', '23105', '4506008', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名駅', 'メイエキ', null, null, 'JRセントラルタワーズ　8階', 'ジェイアールセントラルタワーズ　08カイ');
INSERT INTO `ms_addresses` VALUES ('43546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名駅JRセントラルタワーズ　9階', '23', '23105', '4506009', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名駅', 'メイエキ', null, null, 'JRセントラルタワーズ　9階', 'ジェイアールセントラルタワーズ　09カイ');
INSERT INTO `ms_addresses` VALUES ('43547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名駅JRセントラルタワーズ　10階', '23', '23105', '4506010', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名駅', 'メイエキ', null, null, 'JRセントラルタワーズ　10階', 'ジェイアールセントラルタワーズ　10カイ');
INSERT INTO `ms_addresses` VALUES ('43548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名駅JRセントラルタワーズ　11階', '23', '23105', '4506011', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名駅', 'メイエキ', null, null, 'JRセントラルタワーズ　11階', 'ジェイアールセントラルタワーズ　11カイ');
INSERT INTO `ms_addresses` VALUES ('43549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名駅JRセントラルタワーズ　12階', '23', '23105', '4506012', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名駅', 'メイエキ', null, null, 'JRセントラルタワーズ　12階', 'ジェイアールセントラルタワーズ　12カイ');
INSERT INTO `ms_addresses` VALUES ('43550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名駅JRセントラルタワーズ　13階', '23', '23105', '4506013', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名駅', 'メイエキ', null, null, 'JRセントラルタワーズ　13階', 'ジェイアールセントラルタワーズ　13カイ');
INSERT INTO `ms_addresses` VALUES ('43551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名駅JRセントラルタワーズ　14階', '23', '23105', '4506014', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名駅', 'メイエキ', null, null, 'JRセントラルタワーズ　14階', 'ジェイアールセントラルタワーズ　14カイ');
INSERT INTO `ms_addresses` VALUES ('43552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名駅JRセントラルタワーズ　15階', '23', '23105', '4506015', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名駅', 'メイエキ', null, null, 'JRセントラルタワーズ　15階', 'ジェイアールセントラルタワーズ　15カイ');
INSERT INTO `ms_addresses` VALUES ('43553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名駅JRセントラルタワーズ　16階', '23', '23105', '4506016', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名駅', 'メイエキ', null, null, 'JRセントラルタワーズ　16階', 'ジェイアールセントラルタワーズ　16カイ');
INSERT INTO `ms_addresses` VALUES ('43554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名駅JRセントラルタワーズ　17階', '23', '23105', '4506017', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名駅', 'メイエキ', null, null, 'JRセントラルタワーズ　17階', 'ジェイアールセントラルタワーズ　17カイ');
INSERT INTO `ms_addresses` VALUES ('43555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名駅JRセントラルタワーズ　18階', '23', '23105', '4506018', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名駅', 'メイエキ', null, null, 'JRセントラルタワーズ　18階', 'ジェイアールセントラルタワーズ　18カイ');
INSERT INTO `ms_addresses` VALUES ('43556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名駅JRセントラルタワーズ　19階', '23', '23105', '4506019', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名駅', 'メイエキ', null, null, 'JRセントラルタワーズ　19階', 'ジェイアールセントラルタワーズ　19カイ');
INSERT INTO `ms_addresses` VALUES ('43557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名駅JRセントラルタワーズ　20階', '23', '23105', '4506020', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名駅', 'メイエキ', null, null, 'JRセントラルタワーズ　20階', 'ジェイアールセントラルタワーズ　20カイ');
INSERT INTO `ms_addresses` VALUES ('43558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名駅JRセントラルタワーズ　21階', '23', '23105', '4506021', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名駅', 'メイエキ', null, null, 'JRセントラルタワーズ　21階', 'ジェイアールセントラルタワーズ　21カイ');
INSERT INTO `ms_addresses` VALUES ('43559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名駅JRセントラルタワーズ　22階', '23', '23105', '4506022', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名駅', 'メイエキ', null, null, 'JRセントラルタワーズ　22階', 'ジェイアールセントラルタワーズ　22カイ');
INSERT INTO `ms_addresses` VALUES ('43560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名駅JRセントラルタワーズ　23階', '23', '23105', '4506023', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名駅', 'メイエキ', null, null, 'JRセントラルタワーズ　23階', 'ジェイアールセントラルタワーズ　23カイ');
INSERT INTO `ms_addresses` VALUES ('43561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名駅JRセントラルタワーズ　24階', '23', '23105', '4506024', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名駅', 'メイエキ', null, null, 'JRセントラルタワーズ　24階', 'ジェイアールセントラルタワーズ　24カイ');
INSERT INTO `ms_addresses` VALUES ('43562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名駅JRセントラルタワーズ　25階', '23', '23105', '4506025', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名駅', 'メイエキ', null, null, 'JRセントラルタワーズ　25階', 'ジェイアールセントラルタワーズ　25カイ');
INSERT INTO `ms_addresses` VALUES ('43563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名駅JRセントラルタワーズ　26階', '23', '23105', '4506026', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名駅', 'メイエキ', null, null, 'JRセントラルタワーズ　26階', 'ジェイアールセントラルタワーズ　26カイ');
INSERT INTO `ms_addresses` VALUES ('43564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名駅JRセントラルタワーズ　27階', '23', '23105', '4506027', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名駅', 'メイエキ', null, null, 'JRセントラルタワーズ　27階', 'ジェイアールセントラルタワーズ　27カイ');
INSERT INTO `ms_addresses` VALUES ('43565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名駅JRセントラルタワーズ　28階', '23', '23105', '4506028', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名駅', 'メイエキ', null, null, 'JRセントラルタワーズ　28階', 'ジェイアールセントラルタワーズ　28カイ');
INSERT INTO `ms_addresses` VALUES ('43566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名駅JRセントラルタワーズ　29階', '23', '23105', '4506029', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名駅', 'メイエキ', null, null, 'JRセントラルタワーズ　29階', 'ジェイアールセントラルタワーズ　29カイ');
INSERT INTO `ms_addresses` VALUES ('43567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名駅JRセントラルタワーズ　30階', '23', '23105', '4506030', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名駅', 'メイエキ', null, null, 'JRセントラルタワーズ　30階', 'ジェイアールセントラルタワーズ　30カイ');
INSERT INTO `ms_addresses` VALUES ('43568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名駅JRセントラルタワーズ　31階', '23', '23105', '4506031', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名駅', 'メイエキ', null, null, 'JRセントラルタワーズ　31階', 'ジェイアールセントラルタワーズ　31カイ');
INSERT INTO `ms_addresses` VALUES ('43569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名駅JRセントラルタワーズ　32階', '23', '23105', '4506032', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名駅', 'メイエキ', null, null, 'JRセントラルタワーズ　32階', 'ジェイアールセントラルタワーズ　32カイ');
INSERT INTO `ms_addresses` VALUES ('43570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名駅JRセントラルタワーズ　33階', '23', '23105', '4506033', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名駅', 'メイエキ', null, null, 'JRセントラルタワーズ　33階', 'ジェイアールセントラルタワーズ　33カイ');
INSERT INTO `ms_addresses` VALUES ('43571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名駅JRセントラルタワーズ　34階', '23', '23105', '4506034', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名駅', 'メイエキ', null, null, 'JRセントラルタワーズ　34階', 'ジェイアールセントラルタワーズ　34カイ');
INSERT INTO `ms_addresses` VALUES ('43572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名駅JRセントラルタワーズ　35階', '23', '23105', '4506035', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名駅', 'メイエキ', null, null, 'JRセントラルタワーズ　35階', 'ジェイアールセントラルタワーズ　35カイ');
INSERT INTO `ms_addresses` VALUES ('43573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名駅JRセントラルタワーズ　36階', '23', '23105', '4506036', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名駅', 'メイエキ', null, null, 'JRセントラルタワーズ　36階', 'ジェイアールセントラルタワーズ　36カイ');
INSERT INTO `ms_addresses` VALUES ('43574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名駅JRセントラルタワーズ　37階', '23', '23105', '4506037', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名駅', 'メイエキ', null, null, 'JRセントラルタワーズ　37階', 'ジェイアールセントラルタワーズ　37カイ');
INSERT INTO `ms_addresses` VALUES ('43575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名駅JRセントラルタワーズ　38階', '23', '23105', '4506038', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名駅', 'メイエキ', null, null, 'JRセントラルタワーズ　38階', 'ジェイアールセントラルタワーズ　38カイ');
INSERT INTO `ms_addresses` VALUES ('43576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名駅JRセントラルタワーズ　39階', '23', '23105', '4506039', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名駅', 'メイエキ', null, null, 'JRセントラルタワーズ　39階', 'ジェイアールセントラルタワーズ　39カイ');
INSERT INTO `ms_addresses` VALUES ('43577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名駅JRセントラルタワーズ　40階', '23', '23105', '4506040', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名駅', 'メイエキ', null, null, 'JRセントラルタワーズ　40階', 'ジェイアールセントラルタワーズ　40カイ');
INSERT INTO `ms_addresses` VALUES ('43578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名駅JRセントラルタワーズ　41階', '23', '23105', '4506041', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名駅', 'メイエキ', null, null, 'JRセントラルタワーズ　41階', 'ジェイアールセントラルタワーズ　41カイ');
INSERT INTO `ms_addresses` VALUES ('43579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名駅JRセントラルタワーズ　42階', '23', '23105', '4506042', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名駅', 'メイエキ', null, null, 'JRセントラルタワーズ　42階', 'ジェイアールセントラルタワーズ　42カイ');
INSERT INTO `ms_addresses` VALUES ('43580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名駅JRセントラルタワーズ　43階', '23', '23105', '4506043', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名駅', 'メイエキ', null, null, 'JRセントラルタワーズ　43階', 'ジェイアールセントラルタワーズ　43カイ');
INSERT INTO `ms_addresses` VALUES ('43581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名駅JRセントラルタワーズ　44階', '23', '23105', '4506044', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名駅', 'メイエキ', null, null, 'JRセントラルタワーズ　44階', 'ジェイアールセントラルタワーズ　44カイ');
INSERT INTO `ms_addresses` VALUES ('43582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名駅JRセントラルタワーズ　45階', '23', '23105', '4506045', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名駅', 'メイエキ', null, null, 'JRセントラルタワーズ　45階', 'ジェイアールセントラルタワーズ　45カイ');
INSERT INTO `ms_addresses` VALUES ('43583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名駅JRセントラルタワーズ　46階', '23', '23105', '4506046', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名駅', 'メイエキ', null, null, 'JRセントラルタワーズ　46階', 'ジェイアールセントラルタワーズ　46カイ');
INSERT INTO `ms_addresses` VALUES ('43584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名駅JRセントラルタワーズ　47階', '23', '23105', '4506047', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名駅', 'メイエキ', null, null, 'JRセントラルタワーズ　47階', 'ジェイアールセントラルタワーズ　47カイ');
INSERT INTO `ms_addresses` VALUES ('43585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名駅JRセントラルタワーズ　48階', '23', '23105', '4506048', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名駅', 'メイエキ', null, null, 'JRセントラルタワーズ　48階', 'ジェイアールセントラルタワーズ　48カイ');
INSERT INTO `ms_addresses` VALUES ('43586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名駅JRセントラルタワーズ　49階', '23', '23105', '4506049', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名駅', 'メイエキ', null, null, 'JRセントラルタワーズ　49階', 'ジェイアールセントラルタワーズ　49カイ');
INSERT INTO `ms_addresses` VALUES ('43587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名駅JRセントラルタワーズ　50階', '23', '23105', '4506050', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名駅', 'メイエキ', null, null, 'JRセントラルタワーズ　50階', 'ジェイアールセントラルタワーズ　50カイ');
INSERT INTO `ms_addresses` VALUES ('43588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名駅JRセントラルタワーズ　51階', '23', '23105', '4506051', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名駅', 'メイエキ', null, null, 'JRセントラルタワーズ　51階', 'ジェイアールセントラルタワーズ　51カイ');
INSERT INTO `ms_addresses` VALUES ('43589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名駅JRセントラルタワーズ　', '23', '23105', '4506090', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名駅', 'メイエキ', null, null, 'JRセントラルタワーズ　', 'ジェイアールセントラルタワーズ　');
INSERT INTO `ms_addresses` VALUES ('43590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名駅ミッドランドスクエア　（高層棟）（1階）', '23', '23105', '4506201', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名駅', 'メイエキ', null, null, 'ミッドランドスクエア　（高層棟）（1階）', 'ミッドランドスクエア　（コウソウトウ）（01カイ）');
INSERT INTO `ms_addresses` VALUES ('43591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名駅ミッドランドスクエア　（高層棟）（2階）', '23', '23105', '4506202', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名駅', 'メイエキ', null, null, 'ミッドランドスクエア　（高層棟）（2階）', 'ミッドランドスクエア　（コウソウトウ）（02カイ）');
INSERT INTO `ms_addresses` VALUES ('43592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名駅ミッドランドスクエア　（高層棟）（3階）', '23', '23105', '4506203', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名駅', 'メイエキ', null, null, 'ミッドランドスクエア　（高層棟）（3階）', 'ミッドランドスクエア　（コウソウトウ）（03カイ）');
INSERT INTO `ms_addresses` VALUES ('43593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名駅ミッドランドスクエア　（高層棟）（4階）', '23', '23105', '4506204', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名駅', 'メイエキ', null, null, 'ミッドランドスクエア　（高層棟）（4階）', 'ミッドランドスクエア　（コウソウトウ）（04カイ）');
INSERT INTO `ms_addresses` VALUES ('43594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名駅ミッドランドスクエア　（高層棟）（5階）', '23', '23105', '4506205', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名駅', 'メイエキ', null, null, 'ミッドランドスクエア　（高層棟）（5階）', 'ミッドランドスクエア　（コウソウトウ）（05カイ）');
INSERT INTO `ms_addresses` VALUES ('43595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名駅ミッドランドスクエア　（高層棟）（6階）', '23', '23105', '4506206', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名駅', 'メイエキ', null, null, 'ミッドランドスクエア　（高層棟）（6階）', 'ミッドランドスクエア　（コウソウトウ）（06カイ）');
INSERT INTO `ms_addresses` VALUES ('43596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名駅ミッドランドスクエア　（高層棟）（7階）', '23', '23105', '4506207', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名駅', 'メイエキ', null, null, 'ミッドランドスクエア　（高層棟）（7階）', 'ミッドランドスクエア　（コウソウトウ）（07カイ）');
INSERT INTO `ms_addresses` VALUES ('43597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名駅ミッドランドスクエア　（高層棟）（8階）', '23', '23105', '4506208', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名駅', 'メイエキ', null, null, 'ミッドランドスクエア　（高層棟）（8階）', 'ミッドランドスクエア　（コウソウトウ）（08カイ）');
INSERT INTO `ms_addresses` VALUES ('43598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名駅ミッドランドスクエア　（高層棟）（9階）', '23', '23105', '4506209', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名駅', 'メイエキ', null, null, 'ミッドランドスクエア　（高層棟）（9階）', 'ミッドランドスクエア　（コウソウトウ）（09カイ）');
INSERT INTO `ms_addresses` VALUES ('43599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名駅ミッドランドスクエア　（高層棟）（10階）', '23', '23105', '4506210', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名駅', 'メイエキ', null, null, 'ミッドランドスクエア　（高層棟）（10階）', 'ミッドランドスクエア　（コウソウトウ）（10カイ）');
INSERT INTO `ms_addresses` VALUES ('43600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名駅ミッドランドスクエア　（高層棟）（11階）', '23', '23105', '4506211', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名駅', 'メイエキ', null, null, 'ミッドランドスクエア　（高層棟）（11階）', 'ミッドランドスクエア　（コウソウトウ）（11カイ）');
INSERT INTO `ms_addresses` VALUES ('43601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名駅ミッドランドスクエア　（高層棟）（12階）', '23', '23105', '4506212', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名駅', 'メイエキ', null, null, 'ミッドランドスクエア　（高層棟）（12階）', 'ミッドランドスクエア　（コウソウトウ）（12カイ）');
INSERT INTO `ms_addresses` VALUES ('43602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名駅ミッドランドスクエア　（高層棟）（13階）', '23', '23105', '4506213', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名駅', 'メイエキ', null, null, 'ミッドランドスクエア　（高層棟）（13階）', 'ミッドランドスクエア　（コウソウトウ）（13カイ）');
INSERT INTO `ms_addresses` VALUES ('43603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名駅ミッドランドスクエア　（高層棟）（14階）', '23', '23105', '4506214', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名駅', 'メイエキ', null, null, 'ミッドランドスクエア　（高層棟）（14階）', 'ミッドランドスクエア　（コウソウトウ）（14カイ）');
INSERT INTO `ms_addresses` VALUES ('43604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名駅ミッドランドスクエア　（高層棟）（15階）', '23', '23105', '4506215', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名駅', 'メイエキ', null, null, 'ミッドランドスクエア　（高層棟）（15階）', 'ミッドランドスクエア　（コウソウトウ）（15カイ）');
INSERT INTO `ms_addresses` VALUES ('43605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名駅ミッドランドスクエア　（高層棟）（16階）', '23', '23105', '4506216', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名駅', 'メイエキ', null, null, 'ミッドランドスクエア　（高層棟）（16階）', 'ミッドランドスクエア　（コウソウトウ）（16カイ）');
INSERT INTO `ms_addresses` VALUES ('43606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名駅ミッドランドスクエア　（高層棟）（17階）', '23', '23105', '4506217', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名駅', 'メイエキ', null, null, 'ミッドランドスクエア　（高層棟）（17階）', 'ミッドランドスクエア　（コウソウトウ）（17カイ）');
INSERT INTO `ms_addresses` VALUES ('43607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名駅ミッドランドスクエア　（高層棟）（18階）', '23', '23105', '4506218', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名駅', 'メイエキ', null, null, 'ミッドランドスクエア　（高層棟）（18階）', 'ミッドランドスクエア　（コウソウトウ）（18カイ）');
INSERT INTO `ms_addresses` VALUES ('43608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名駅ミッドランドスクエア　（高層棟）（19階）', '23', '23105', '4506219', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名駅', 'メイエキ', null, null, 'ミッドランドスクエア　（高層棟）（19階）', 'ミッドランドスクエア　（コウソウトウ）（19カイ）');
INSERT INTO `ms_addresses` VALUES ('43609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名駅ミッドランドスクエア　（高層棟）（20階）', '23', '23105', '4506220', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名駅', 'メイエキ', null, null, 'ミッドランドスクエア　（高層棟）（20階）', 'ミッドランドスクエア　（コウソウトウ）（20カイ）');
INSERT INTO `ms_addresses` VALUES ('43610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名駅ミッドランドスクエア　（高層棟）（21階）', '23', '23105', '4506221', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名駅', 'メイエキ', null, null, 'ミッドランドスクエア　（高層棟）（21階）', 'ミッドランドスクエア　（コウソウトウ）（21カイ）');
INSERT INTO `ms_addresses` VALUES ('43611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名駅ミッドランドスクエア　（高層棟）（22階）', '23', '23105', '4506222', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名駅', 'メイエキ', null, null, 'ミッドランドスクエア　（高層棟）（22階）', 'ミッドランドスクエア　（コウソウトウ）（22カイ）');
INSERT INTO `ms_addresses` VALUES ('43612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名駅ミッドランドスクエア　（高層棟）（23階）', '23', '23105', '4506223', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名駅', 'メイエキ', null, null, 'ミッドランドスクエア　（高層棟）（23階）', 'ミッドランドスクエア　（コウソウトウ）（23カイ）');
INSERT INTO `ms_addresses` VALUES ('43613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名駅ミッドランドスクエア　（高層棟）（24階）', '23', '23105', '4506224', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名駅', 'メイエキ', null, null, 'ミッドランドスクエア　（高層棟）（24階）', 'ミッドランドスクエア　（コウソウトウ）（24カイ）');
INSERT INTO `ms_addresses` VALUES ('43614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名駅ミッドランドスクエア　（高層棟）（25階）', '23', '23105', '4506225', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名駅', 'メイエキ', null, null, 'ミッドランドスクエア　（高層棟）（25階）', 'ミッドランドスクエア　（コウソウトウ）（25カイ）');
INSERT INTO `ms_addresses` VALUES ('43615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名駅ミッドランドスクエア　（高層棟）（26階）', '23', '23105', '4506226', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名駅', 'メイエキ', null, null, 'ミッドランドスクエア　（高層棟）（26階）', 'ミッドランドスクエア　（コウソウトウ）（26カイ）');
INSERT INTO `ms_addresses` VALUES ('43616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名駅ミッドランドスクエア　（高層棟）（27階）', '23', '23105', '4506227', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名駅', 'メイエキ', null, null, 'ミッドランドスクエア　（高層棟）（27階）', 'ミッドランドスクエア　（コウソウトウ）（27カイ）');
INSERT INTO `ms_addresses` VALUES ('43617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名駅ミッドランドスクエア　（高層棟）（28階）', '23', '23105', '4506228', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名駅', 'メイエキ', null, null, 'ミッドランドスクエア　（高層棟）（28階）', 'ミッドランドスクエア　（コウソウトウ）（28カイ）');
INSERT INTO `ms_addresses` VALUES ('43618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名駅ミッドランドスクエア　（高層棟）（29階）', '23', '23105', '4506229', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名駅', 'メイエキ', null, null, 'ミッドランドスクエア　（高層棟）（29階）', 'ミッドランドスクエア　（コウソウトウ）（29カイ）');
INSERT INTO `ms_addresses` VALUES ('43619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名駅ミッドランドスクエア　（高層棟）（30階）', '23', '23105', '4506230', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名駅', 'メイエキ', null, null, 'ミッドランドスクエア　（高層棟）（30階）', 'ミッドランドスクエア　（コウソウトウ）（30カイ）');
INSERT INTO `ms_addresses` VALUES ('43620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名駅ミッドランドスクエア　（高層棟）（31階）', '23', '23105', '4506231', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名駅', 'メイエキ', null, null, 'ミッドランドスクエア　（高層棟）（31階）', 'ミッドランドスクエア　（コウソウトウ）（31カイ）');
INSERT INTO `ms_addresses` VALUES ('43621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名駅ミッドランドスクエア　（高層棟）（32階）', '23', '23105', '4506232', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名駅', 'メイエキ', null, null, 'ミッドランドスクエア　（高層棟）（32階）', 'ミッドランドスクエア　（コウソウトウ）（32カイ）');
INSERT INTO `ms_addresses` VALUES ('43622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名駅ミッドランドスクエア　（高層棟）（33階）', '23', '23105', '4506233', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名駅', 'メイエキ', null, null, 'ミッドランドスクエア　（高層棟）（33階）', 'ミッドランドスクエア　（コウソウトウ）（33カイ）');
INSERT INTO `ms_addresses` VALUES ('43623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名駅ミッドランドスクエア　（高層棟）（34階）', '23', '23105', '4506234', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名駅', 'メイエキ', null, null, 'ミッドランドスクエア　（高層棟）（34階）', 'ミッドランドスクエア　（コウソウトウ）（34カイ）');
INSERT INTO `ms_addresses` VALUES ('43624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名駅ミッドランドスクエア　（高層棟）（35階）', '23', '23105', '4506235', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名駅', 'メイエキ', null, null, 'ミッドランドスクエア　（高層棟）（35階）', 'ミッドランドスクエア　（コウソウトウ）（35カイ）');
INSERT INTO `ms_addresses` VALUES ('43625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名駅ミッドランドスクエア　（高層棟）（36階）', '23', '23105', '4506236', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名駅', 'メイエキ', null, null, 'ミッドランドスクエア　（高層棟）（36階）', 'ミッドランドスクエア　（コウソウトウ）（36カイ）');
INSERT INTO `ms_addresses` VALUES ('43626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名駅ミッドランドスクエア　（高層棟）（37階）', '23', '23105', '4506237', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名駅', 'メイエキ', null, null, 'ミッドランドスクエア　（高層棟）（37階）', 'ミッドランドスクエア　（コウソウトウ）（37カイ）');
INSERT INTO `ms_addresses` VALUES ('43627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名駅ミッドランドスクエア　（高層棟）（38階）', '23', '23105', '4506238', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名駅', 'メイエキ', null, null, 'ミッドランドスクエア　（高層棟）（38階）', 'ミッドランドスクエア　（コウソウトウ）（38カイ）');
INSERT INTO `ms_addresses` VALUES ('43628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名駅ミッドランドスクエア　（高層棟）（39階）', '23', '23105', '4506239', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名駅', 'メイエキ', null, null, 'ミッドランドスクエア　（高層棟）（39階）', 'ミッドランドスクエア　（コウソウトウ）（39カイ）');
INSERT INTO `ms_addresses` VALUES ('43629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名駅ミッドランドスクエア　（高層棟）（40階）', '23', '23105', '4506240', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名駅', 'メイエキ', null, null, 'ミッドランドスクエア　（高層棟）（40階）', 'ミッドランドスクエア　（コウソウトウ）（40カイ）');
INSERT INTO `ms_addresses` VALUES ('43630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名駅ミッドランドスクエア　（高層棟）（41階）', '23', '23105', '4506241', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名駅', 'メイエキ', null, null, 'ミッドランドスクエア　（高層棟）（41階）', 'ミッドランドスクエア　（コウソウトウ）（41カイ）');
INSERT INTO `ms_addresses` VALUES ('43631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名駅ミッドランドスクエア　（高層棟）（42階）', '23', '23105', '4506242', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名駅', 'メイエキ', null, null, 'ミッドランドスクエア　（高層棟）（42階）', 'ミッドランドスクエア　（コウソウトウ）（42カイ）');
INSERT INTO `ms_addresses` VALUES ('43632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名駅ミッドランドスクエア　（高層棟）（43階）', '23', '23105', '4506243', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名駅', 'メイエキ', null, null, 'ミッドランドスクエア　（高層棟）（43階）', 'ミッドランドスクエア　（コウソウトウ）（43カイ）');
INSERT INTO `ms_addresses` VALUES ('43633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名駅ミッドランドスクエア　（高層棟）（44階）', '23', '23105', '4506244', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名駅', 'メイエキ', null, null, 'ミッドランドスクエア　（高層棟）（44階）', 'ミッドランドスクエア　（コウソウトウ）（44カイ）');
INSERT INTO `ms_addresses` VALUES ('43634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名駅ミッドランドスクエア　（高層棟）（45階）', '23', '23105', '4506245', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名駅', 'メイエキ', null, null, 'ミッドランドスクエア　（高層棟）（45階）', 'ミッドランドスクエア　（コウソウトウ）（45カイ）');
INSERT INTO `ms_addresses` VALUES ('43635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名駅ミッドランドスクエア　（高層棟）（46階）', '23', '23105', '4506246', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名駅', 'メイエキ', null, null, 'ミッドランドスクエア　（高層棟）（46階）', 'ミッドランドスクエア　（コウソウトウ）（46カイ）');
INSERT INTO `ms_addresses` VALUES ('43636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名駅ミッドランドスクエア　（高層棟）（47階）', '23', '23105', '4506247', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名駅', 'メイエキ', null, null, 'ミッドランドスクエア　（高層棟）（47階）', 'ミッドランドスクエア　（コウソウトウ）（47カイ）');
INSERT INTO `ms_addresses` VALUES ('43637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名駅ミッドランドスクエア　', '23', '23105', '4506290', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名駅', 'メイエキ', null, null, 'ミッドランドスクエア　', 'ミッドランドスクエア　');
INSERT INTO `ms_addresses` VALUES ('43672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区', '23', '23104', '4510000', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('43673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区桝形町', '23', '23104', '4510011', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '桝形町', 'マスガタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区稲生町', '23', '23104', '4510012', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '稲生町', 'イノウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区江向町', '23', '23104', '4510013', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '江向町', 'エムカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区又穂町', '23', '23104', '4510014', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '又穂町', 'マタホチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区香呑町', '23', '23104', '4510015', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '香呑町', 'コウノミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区庄内通', '23', '23104', '4510016', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '庄内通', 'ショウナイトオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区天塚町', '23', '23104', '4510021', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '天塚町', 'アマヅカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区貝田町', '23', '23104', '4510022', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '貝田町', 'カイダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区城北町', '23', '23104', '4510023', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '城北町', 'ジョウホクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区秩父通', '23', '23104', '4510024', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '秩父通', 'チチブトオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区上名古屋', '23', '23104', '4510025', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '上名古屋', 'カミナゴヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区田幡町', '23', '23104', '4510026', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '田幡町', 'タバタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区西志賀町', '23', '23104', '4510027', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '西志賀町', 'ニシシガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区城西', '23', '23104', '4510031', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '城西', 'ジョウサイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区数寄屋町', '23', '23104', '4510032', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '数寄屋町', 'スキヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区堀端町', '23', '23104', '4510033', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '堀端町', 'ホリバタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区樋の口町', '23', '23104', '4510034', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '樋の口町', 'ヒノクチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区浅間', '23', '23104', '4510035', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '浅間', 'センゲン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区幅下', '23', '23104', '4510041', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '幅下', 'ハバシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区那古野', '23', '23104', '4510042', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '那古野', 'ナゴノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区新道', '23', '23104', '4510043', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '新道', 'シンミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区菊井', '23', '23104', '4510044', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '菊井', 'キクイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区名駅', '23', '23104', '4510045', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '名駅', 'メイエキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区牛島町', '23', '23104', '4510046', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '牛島町', 'ウシジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区則武新町', '23', '23104', '4510051', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '則武新町', 'ノリタケシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区栄生', '23', '23104', '4510052', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '栄生', 'サコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区枇杷島', '23', '23104', '4510053', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '枇杷島', 'ビワジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区南堀越', '23', '23104', '4510054', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '南堀越', 'ミナミホリコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区堀越', '23', '23104', '4510055', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '堀越', 'ホリコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区浄心', '23', '23104', '4510061', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '浄心', 'ジョウシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区花の木', '23', '23104', '4510062', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '花の木', 'ハナノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区押切', '23', '23104', '4510063', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '押切', 'オシキリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区名西', '23', '23104', '4510064', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '名西', 'メイセイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区天神山町', '23', '23104', '4510065', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '天神山町', 'テンジンヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区児玉', '23', '23104', '4510066', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '児玉', 'コダマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区鳥見町', '23', '23104', '4510071', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '鳥見町', 'トリミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区笠取町', '23', '23104', '4510072', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '笠取町', 'カサトリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区浄心本通', '23', '23104', '4510073', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '浄心本通', 'ジョウシンホントオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区万代町', '23', '23104', '4510074', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '万代町', 'マンダイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区康生通', '23', '23104', '4510075', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '康生通', 'コウセイトオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区東岸町', '23', '23104', '4510076', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '東岸町', 'トウガンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区笹塚町', '23', '23104', '4510077', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '笹塚町', 'ササヅカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区名塚町', '23', '23104', '4510081', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '名塚町', 'ナヅカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区大金町', '23', '23104', '4510082', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '大金町', 'オオカネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区新福寺町', '23', '23104', '4510083', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '新福寺町', 'シンプクジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区上堀越町', '23', '23104', '4510084', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '上堀越町', 'カミホリコシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区牛島町名古屋ルーセントタワー　1階', '23', '23104', '4516001', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '牛島町', 'ウシジマチョウ', null, null, '名古屋ルーセントタワー　1階', 'ナゴヤルーセントタワー　01カイ');
INSERT INTO `ms_addresses` VALUES ('43720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区牛島町名古屋ルーセントタワー　2階', '23', '23104', '4516002', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '牛島町', 'ウシジマチョウ', null, null, '名古屋ルーセントタワー　2階', 'ナゴヤルーセントタワー　02カイ');
INSERT INTO `ms_addresses` VALUES ('43721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区牛島町名古屋ルーセントタワー　3階', '23', '23104', '4516003', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '牛島町', 'ウシジマチョウ', null, null, '名古屋ルーセントタワー　3階', 'ナゴヤルーセントタワー　03カイ');
INSERT INTO `ms_addresses` VALUES ('43722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区牛島町名古屋ルーセントタワー　4階', '23', '23104', '4516004', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '牛島町', 'ウシジマチョウ', null, null, '名古屋ルーセントタワー　4階', 'ナゴヤルーセントタワー　04カイ');
INSERT INTO `ms_addresses` VALUES ('43723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区牛島町名古屋ルーセントタワー　5階', '23', '23104', '4516005', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '牛島町', 'ウシジマチョウ', null, null, '名古屋ルーセントタワー　5階', 'ナゴヤルーセントタワー　05カイ');
INSERT INTO `ms_addresses` VALUES ('43724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区牛島町名古屋ルーセントタワー　6階', '23', '23104', '4516006', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '牛島町', 'ウシジマチョウ', null, null, '名古屋ルーセントタワー　6階', 'ナゴヤルーセントタワー　06カイ');
INSERT INTO `ms_addresses` VALUES ('43725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区牛島町名古屋ルーセントタワー　7階', '23', '23104', '4516007', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '牛島町', 'ウシジマチョウ', null, null, '名古屋ルーセントタワー　7階', 'ナゴヤルーセントタワー　07カイ');
INSERT INTO `ms_addresses` VALUES ('43726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区牛島町名古屋ルーセントタワー　8階', '23', '23104', '4516008', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '牛島町', 'ウシジマチョウ', null, null, '名古屋ルーセントタワー　8階', 'ナゴヤルーセントタワー　08カイ');
INSERT INTO `ms_addresses` VALUES ('43727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区牛島町名古屋ルーセントタワー　9階', '23', '23104', '4516009', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '牛島町', 'ウシジマチョウ', null, null, '名古屋ルーセントタワー　9階', 'ナゴヤルーセントタワー　09カイ');
INSERT INTO `ms_addresses` VALUES ('43728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区牛島町名古屋ルーセントタワー　10階', '23', '23104', '4516010', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '牛島町', 'ウシジマチョウ', null, null, '名古屋ルーセントタワー　10階', 'ナゴヤルーセントタワー　10カイ');
INSERT INTO `ms_addresses` VALUES ('43729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区牛島町名古屋ルーセントタワー　11階', '23', '23104', '4516011', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '牛島町', 'ウシジマチョウ', null, null, '名古屋ルーセントタワー　11階', 'ナゴヤルーセントタワー　11カイ');
INSERT INTO `ms_addresses` VALUES ('43730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区牛島町名古屋ルーセントタワー　12階', '23', '23104', '4516012', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '牛島町', 'ウシジマチョウ', null, null, '名古屋ルーセントタワー　12階', 'ナゴヤルーセントタワー　12カイ');
INSERT INTO `ms_addresses` VALUES ('43731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区牛島町名古屋ルーセントタワー　13階', '23', '23104', '4516013', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '牛島町', 'ウシジマチョウ', null, null, '名古屋ルーセントタワー　13階', 'ナゴヤルーセントタワー　13カイ');
INSERT INTO `ms_addresses` VALUES ('43732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区牛島町名古屋ルーセントタワー　14階', '23', '23104', '4516014', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '牛島町', 'ウシジマチョウ', null, null, '名古屋ルーセントタワー　14階', 'ナゴヤルーセントタワー　14カイ');
INSERT INTO `ms_addresses` VALUES ('43733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区牛島町名古屋ルーセントタワー　15階', '23', '23104', '4516015', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '牛島町', 'ウシジマチョウ', null, null, '名古屋ルーセントタワー　15階', 'ナゴヤルーセントタワー　15カイ');
INSERT INTO `ms_addresses` VALUES ('43734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区牛島町名古屋ルーセントタワー　16階', '23', '23104', '4516016', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '牛島町', 'ウシジマチョウ', null, null, '名古屋ルーセントタワー　16階', 'ナゴヤルーセントタワー　16カイ');
INSERT INTO `ms_addresses` VALUES ('43735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区牛島町名古屋ルーセントタワー　17階', '23', '23104', '4516017', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '牛島町', 'ウシジマチョウ', null, null, '名古屋ルーセントタワー　17階', 'ナゴヤルーセントタワー　17カイ');
INSERT INTO `ms_addresses` VALUES ('43736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区牛島町名古屋ルーセントタワー　18階', '23', '23104', '4516018', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '牛島町', 'ウシジマチョウ', null, null, '名古屋ルーセントタワー　18階', 'ナゴヤルーセントタワー　18カイ');
INSERT INTO `ms_addresses` VALUES ('43737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区牛島町名古屋ルーセントタワー　19階', '23', '23104', '4516019', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '牛島町', 'ウシジマチョウ', null, null, '名古屋ルーセントタワー　19階', 'ナゴヤルーセントタワー　19カイ');
INSERT INTO `ms_addresses` VALUES ('43738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区牛島町名古屋ルーセントタワー　20階', '23', '23104', '4516020', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '牛島町', 'ウシジマチョウ', null, null, '名古屋ルーセントタワー　20階', 'ナゴヤルーセントタワー　20カイ');
INSERT INTO `ms_addresses` VALUES ('43739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区牛島町名古屋ルーセントタワー　21階', '23', '23104', '4516021', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '牛島町', 'ウシジマチョウ', null, null, '名古屋ルーセントタワー　21階', 'ナゴヤルーセントタワー　21カイ');
INSERT INTO `ms_addresses` VALUES ('43740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区牛島町名古屋ルーセントタワー　22階', '23', '23104', '4516022', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '牛島町', 'ウシジマチョウ', null, null, '名古屋ルーセントタワー　22階', 'ナゴヤルーセントタワー　22カイ');
INSERT INTO `ms_addresses` VALUES ('43741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区牛島町名古屋ルーセントタワー　23階', '23', '23104', '4516023', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '牛島町', 'ウシジマチョウ', null, null, '名古屋ルーセントタワー　23階', 'ナゴヤルーセントタワー　23カイ');
INSERT INTO `ms_addresses` VALUES ('43742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区牛島町名古屋ルーセントタワー　24階', '23', '23104', '4516024', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '牛島町', 'ウシジマチョウ', null, null, '名古屋ルーセントタワー　24階', 'ナゴヤルーセントタワー　24カイ');
INSERT INTO `ms_addresses` VALUES ('43743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区牛島町名古屋ルーセントタワー　25階', '23', '23104', '4516025', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '牛島町', 'ウシジマチョウ', null, null, '名古屋ルーセントタワー　25階', 'ナゴヤルーセントタワー　25カイ');
INSERT INTO `ms_addresses` VALUES ('43744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区牛島町名古屋ルーセントタワー　26階', '23', '23104', '4516026', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '牛島町', 'ウシジマチョウ', null, null, '名古屋ルーセントタワー　26階', 'ナゴヤルーセントタワー　26カイ');
INSERT INTO `ms_addresses` VALUES ('43745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区牛島町名古屋ルーセントタワー　27階', '23', '23104', '4516027', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '牛島町', 'ウシジマチョウ', null, null, '名古屋ルーセントタワー　27階', 'ナゴヤルーセントタワー　27カイ');
INSERT INTO `ms_addresses` VALUES ('43746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区牛島町名古屋ルーセントタワー　28階', '23', '23104', '4516028', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '牛島町', 'ウシジマチョウ', null, null, '名古屋ルーセントタワー　28階', 'ナゴヤルーセントタワー　28カイ');
INSERT INTO `ms_addresses` VALUES ('43747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区牛島町名古屋ルーセントタワー　29階', '23', '23104', '4516029', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '牛島町', 'ウシジマチョウ', null, null, '名古屋ルーセントタワー　29階', 'ナゴヤルーセントタワー　29カイ');
INSERT INTO `ms_addresses` VALUES ('43748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区牛島町名古屋ルーセントタワー　30階', '23', '23104', '4516030', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '牛島町', 'ウシジマチョウ', null, null, '名古屋ルーセントタワー　30階', 'ナゴヤルーセントタワー　30カイ');
INSERT INTO `ms_addresses` VALUES ('43749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区牛島町名古屋ルーセントタワー　31階', '23', '23104', '4516031', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '牛島町', 'ウシジマチョウ', null, null, '名古屋ルーセントタワー　31階', 'ナゴヤルーセントタワー　31カイ');
INSERT INTO `ms_addresses` VALUES ('43750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区牛島町名古屋ルーセントタワー　32階', '23', '23104', '4516032', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '牛島町', 'ウシジマチョウ', null, null, '名古屋ルーセントタワー　32階', 'ナゴヤルーセントタワー　32カイ');
INSERT INTO `ms_addresses` VALUES ('43751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区牛島町名古屋ルーセントタワー　33階', '23', '23104', '4516033', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '牛島町', 'ウシジマチョウ', null, null, '名古屋ルーセントタワー　33階', 'ナゴヤルーセントタワー　33カイ');
INSERT INTO `ms_addresses` VALUES ('43752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区牛島町名古屋ルーセントタワー　34階', '23', '23104', '4516034', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '牛島町', 'ウシジマチョウ', null, null, '名古屋ルーセントタワー　34階', 'ナゴヤルーセントタワー　34カイ');
INSERT INTO `ms_addresses` VALUES ('43753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区牛島町名古屋ルーセントタワー　35階', '23', '23104', '4516035', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '牛島町', 'ウシジマチョウ', null, null, '名古屋ルーセントタワー　35階', 'ナゴヤルーセントタワー　35カイ');
INSERT INTO `ms_addresses` VALUES ('43754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区牛島町名古屋ルーセントタワー　36階', '23', '23104', '4516036', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '牛島町', 'ウシジマチョウ', null, null, '名古屋ルーセントタワー　36階', 'ナゴヤルーセントタワー　36カイ');
INSERT INTO `ms_addresses` VALUES ('43755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区牛島町名古屋ルーセントタワー　37階', '23', '23104', '4516037', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '牛島町', 'ウシジマチョウ', null, null, '名古屋ルーセントタワー　37階', 'ナゴヤルーセントタワー　37カイ');
INSERT INTO `ms_addresses` VALUES ('43756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区牛島町名古屋ルーセントタワー　38階', '23', '23104', '4516038', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '牛島町', 'ウシジマチョウ', null, null, '名古屋ルーセントタワー　38階', 'ナゴヤルーセントタワー　38カイ');
INSERT INTO `ms_addresses` VALUES ('43757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区牛島町名古屋ルーセントタワー　39階', '23', '23104', '4516039', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '牛島町', 'ウシジマチョウ', null, null, '名古屋ルーセントタワー　39階', 'ナゴヤルーセントタワー　39カイ');
INSERT INTO `ms_addresses` VALUES ('43758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区牛島町名古屋ルーセントタワー　40階', '23', '23104', '4516040', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '牛島町', 'ウシジマチョウ', null, null, '名古屋ルーセントタワー　40階', 'ナゴヤルーセントタワー　40カイ');
INSERT INTO `ms_addresses` VALUES ('43759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区牛島町名古屋ルーセントタワー　', '23', '23104', '4516090', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '牛島町', 'ウシジマチョウ', null, null, '名古屋ルーセントタワー　', 'ナゴヤルーセントタワー　');
INSERT INTO `ms_addresses` VALUES ('43785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県清須市', '23', '23233', '4520000', '愛知県', 'アイチケン', '清須市', 'キヨスシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('43786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西春日井郡春日町', '23', '23345', '4520000', '愛知県', 'アイチケン', '西春日井郡春日町', 'ニシカスガイグンハルヒチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('43787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県清須市西枇杷島町古城', '23', '23233', '4520001', '愛知県', 'アイチケン', '清須市', 'キヨスシ', '西枇杷島町古城', 'ニシビワジマチョウコジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県清須市西枇杷島町花咲', '23', '23233', '4520002', '愛知県', 'アイチケン', '清須市', 'キヨスシ', '西枇杷島町花咲', 'ニシビワジマチョウハナサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県清須市西枇杷島町末広', '23', '23233', '4520003', '愛知県', 'アイチケン', '清須市', 'キヨスシ', '西枇杷島町末広', 'ニシビワジマチョウスエヒロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県清須市西枇杷島町大黒', '23', '23233', '4520004', '愛知県', 'アイチケン', '清須市', 'キヨスシ', '西枇杷島町大黒', 'ニシビワジマチョウダイコク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県清須市西枇杷島町恵比須', '23', '23233', '4520005', '愛知県', 'アイチケン', '清須市', 'キヨスシ', '西枇杷島町恵比須', 'ニシビワジマチョウエビス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県清須市西枇杷島町弁天', '23', '23233', '4520006', '愛知県', 'アイチケン', '清須市', 'キヨスシ', '西枇杷島町弁天', 'ニシビワジマチョウベンテン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県清須市西枇杷島町一反五畝割', '23', '23233', '4520007', '愛知県', 'アイチケン', '清須市', 'キヨスシ', '西枇杷島町一反五畝割', 'ニシビワジマチョウイッタンゴセワリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県清須市西枇杷島町地領', '23', '23233', '4520008', '愛知県', 'アイチケン', '清須市', 'キヨスシ', '西枇杷島町地領', 'ニシビワジマチョウチリョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県清須市西枇杷島町西八丁', '23', '23233', '4520009', '愛知県', 'アイチケン', '清須市', 'キヨスシ', '西枇杷島町西八丁', 'ニシビワジマチョウニシハッチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県清須市西枇杷島町稲株', '23', '23233', '4520010', '愛知県', 'アイチケン', '清須市', 'キヨスシ', '西枇杷島町稲株', 'ニシビワジマチョウイナカブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県清須市西枇杷島町城並', '23', '23233', '4520011', '愛知県', 'アイチケン', '清須市', 'キヨスシ', '西枇杷島町城並', 'ニシビワジマチョウジョウナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県清須市西枇杷島町北大和', '23', '23233', '4520012', '愛知県', 'アイチケン', '清須市', 'キヨスシ', '西枇杷島町北大和', 'ニシビワジマチョウキタヤマト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県清須市西枇杷島町南大和', '23', '23233', '4520013', '愛知県', 'アイチケン', '清須市', 'キヨスシ', '西枇杷島町南大和', 'ニシビワジマチョウミナミヤマト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県清須市西枇杷島町押花', '23', '23233', '4520014', '愛知県', 'アイチケン', '清須市', 'キヨスシ', '西枇杷島町押花', 'ニシビワジマチョウオシバナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県清須市西枇杷島町泉', '23', '23233', '4520015', '愛知県', 'アイチケン', '清須市', 'キヨスシ', '西枇杷島町泉', 'ニシビワジマチョウイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県清須市西枇杷島町砂入', '23', '23233', '4520016', '愛知県', 'アイチケン', '清須市', 'キヨスシ', '西枇杷島町砂入', 'ニシビワジマチョウスイリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県清須市西枇杷島町下砂入', '23', '23233', '4520017', '愛知県', 'アイチケン', '清須市', 'キヨスシ', '西枇杷島町下砂入', 'ニシビワジマチョウシモスイリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県清須市西枇杷島町住吉', '23', '23233', '4520018', '愛知県', 'アイチケン', '清須市', 'キヨスシ', '西枇杷島町住吉', 'ニシビワジマチョウスミヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県清須市西枇杷島町小田井', '23', '23233', '4520021', '愛知県', 'アイチケン', '清須市', 'キヨスシ', '西枇杷島町小田井', 'ニシビワジマチョウオタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県清須市西枇杷島町上新', '23', '23233', '4520022', '愛知県', 'アイチケン', '清須市', 'キヨスシ', '西枇杷島町上新', 'ニシビワジマチョウカミシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県清須市西枇杷島町下新', '23', '23233', '4520023', '愛知県', 'アイチケン', '清須市', 'キヨスシ', '西枇杷島町下新', 'ニシビワジマチョウシモシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県清須市西枇杷島町片町', '23', '23233', '4520024', '愛知県', 'アイチケン', '清須市', 'キヨスシ', '西枇杷島町片町', 'ニシビワジマチョウカタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県清須市西枇杷島町十軒裏', '23', '23233', '4520025', '愛知県', 'アイチケン', '清須市', 'キヨスシ', '西枇杷島町十軒裏', 'ニシビワジマチョウジュツケンウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県清須市西枇杷島町橋詰', '23', '23233', '4520026', '愛知県', 'アイチケン', '清須市', 'キヨスシ', '西枇杷島町橋詰', 'ニシビワジマチョウハシヅメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県清須市西枇杷島町宮前', '23', '23233', '4520031', '愛知県', 'アイチケン', '清須市', 'キヨスシ', '西枇杷島町宮前', 'ニシビワジマチョウミヤマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県清須市西枇杷島町養和', '23', '23233', '4520032', '愛知県', 'アイチケン', '清須市', 'キヨスシ', '西枇杷島町養和', 'ニシビワジマチョウヨウワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県清須市西枇杷島町二見', '23', '23233', '4520033', '愛知県', 'アイチケン', '清須市', 'キヨスシ', '西枇杷島町二見', 'ニシビワジマチョウフタミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県清須市西枇杷島町日之出', '23', '23233', '4520034', '愛知県', 'アイチケン', '清須市', 'キヨスシ', '西枇杷島町日之出', 'ニシビワジマチョウヒノデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県清須市西枇杷島町問屋', '23', '23233', '4520035', '愛知県', 'アイチケン', '清須市', 'キヨスシ', '西枇杷島町問屋', 'ニシビワジマチョウトンヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県清須市西枇杷島町南問屋', '23', '23233', '4520036', '愛知県', 'アイチケン', '清須市', 'キヨスシ', '西枇杷島町南問屋', 'ニシビワジマチョウミナミトンヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県清須市枇杷島駅前東', '23', '23233', '4520037', '愛知県', 'アイチケン', '清須市', 'キヨスシ', '枇杷島駅前東', 'ビワジマエキマエヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県清須市西枇杷島町小野田', '23', '23233', '4520041', '愛知県', 'アイチケン', '清須市', 'キヨスシ', '西枇杷島町小野田', 'ニシビワジマチョウオノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県清須市西枇杷島町川口', '23', '23233', '4520042', '愛知県', 'アイチケン', '清須市', 'キヨスシ', '西枇杷島町川口', 'ニシビワジマチョウカワグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県清須市西枇杷島町東六軒', '23', '23233', '4520043', '愛知県', 'アイチケン', '清須市', 'キヨスシ', '西枇杷島町東六軒', 'ニシビワジマチョウヒガシロッケン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県清須市西枇杷島町南六軒', '23', '23233', '4520044', '愛知県', 'アイチケン', '清須市', 'キヨスシ', '西枇杷島町南六軒', 'ニシビワジマチョウミナミロッケン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県清須市西枇杷島町西六軒', '23', '23233', '4520045', '愛知県', 'アイチケン', '清須市', 'キヨスシ', '西枇杷島町西六軒', 'ニシビワジマチョウニシロッケン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県清須市西枇杷島町西笹子原', '23', '23233', '4520046', '愛知県', 'アイチケン', '清須市', 'キヨスシ', '西枇杷島町西笹子原', 'ニシビワジマチョウニシササコハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県清須市西枇杷島町東笹子原', '23', '23233', '4520047', '愛知県', 'アイチケン', '清須市', 'キヨスシ', '西枇杷島町東笹子原', 'ニシビワジマチョウヒガシササコハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県清須市西枇杷島町大野', '23', '23233', '4520051', '愛知県', 'アイチケン', '清須市', 'キヨスシ', '西枇杷島町大野', 'ニシビワジマチョウオオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県清須市西枇杷島町辰新田', '23', '23233', '4520052', '愛知県', 'アイチケン', '清須市', 'キヨスシ', '西枇杷島町辰新田', 'ニシビワジマチョウタツシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県清須市西枇杷島町南松原', '23', '23233', '4520053', '愛知県', 'アイチケン', '清須市', 'キヨスシ', '西枇杷島町南松原', 'ニシビワジマチョウミナミマツバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県清須市西枇杷島町南二ツ杁', '23', '23233', '4520054', '愛知県', 'アイチケン', '清須市', 'キヨスシ', '西枇杷島町南二ツ杁', 'ニシビワジマチョウミナミフタツイリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県清須市西枇杷島町北二ツ杁', '23', '23233', '4520055', '愛知県', 'アイチケン', '清須市', 'キヨスシ', '西枇杷島町北二ツ杁', 'ニシビワジマチョウキタフタツイリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県清須市西枇杷島町小場塚', '23', '23233', '4520061', '愛知県', 'アイチケン', '清須市', 'キヨスシ', '西枇杷島町小場塚', 'ニシビワジマチョウコバヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県清須市西枇杷島町五畝割', '23', '23233', '4520062', '愛知県', 'アイチケン', '清須市', 'キヨスシ', '西枇杷島町五畝割', 'ニシビワジマチョウゴセワリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県清須市西枇杷島町七畝割', '23', '23233', '4520063', '愛知県', 'アイチケン', '清須市', 'キヨスシ', '西枇杷島町七畝割', 'ニシビワジマチョウナナセワリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県清須市西枇杷島町旭', '23', '23233', '4520064', '愛知県', 'アイチケン', '清須市', 'キヨスシ', '西枇杷島町旭', 'ニシビワジマチョウアサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県清須市西枇杷島町芳野', '23', '23233', '4520065', '愛知県', 'アイチケン', '清須市', 'キヨスシ', '西枇杷島町芳野', 'ニシビワジマチョウヨシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県清須市西枇杷島町芝野新田', '23', '23233', '4520066', '愛知県', 'アイチケン', '清須市', 'キヨスシ', '西枇杷島町芝野新田', 'ニシビワジマチョウシバノシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県清須市西枇杷島町替地', '23', '23233', '4520067', '愛知県', 'アイチケン', '清須市', 'キヨスシ', '西枇杷島町替地', 'ニシビワジマチョウカエチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県清須市西枇杷島町子新田', '23', '23233', '4520068', '愛知県', 'アイチケン', '清須市', 'キヨスシ', '西枇杷島町子新田', 'ニシビワジマチョウネシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区清里町', '23', '23104', '4520801', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '清里町', 'キヨサトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区比良', '23', '23104', '4520802', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '比良', 'ヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区大野木', '23', '23104', '4520803', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '大野木', 'オオノギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区坂井戸町', '23', '23104', '4520804', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '坂井戸町', 'サカイドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区市場木町', '23', '23104', '4520805', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '市場木町', 'イチバギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区五才美町', '23', '23104', '4520806', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '五才美町', 'ゴサイビチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区歌里町', '23', '23104', '4520807', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '歌里町', 'ウタサトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区宝地町', '23', '23104', '4520808', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '宝地町', 'ホウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区花原町', '23', '23104', '4520809', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '花原町', 'ハナハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区砂原町', '23', '23104', '4520811', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '砂原町', 'スナハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区玉池町', '23', '23104', '4520812', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '玉池町', 'タマイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区赤城町', '23', '23104', '4520813', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '赤城町', 'アカシロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区南川町', '23', '23104', '4520814', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '南川町', 'ミナミカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区八筋町', '23', '23104', '4520815', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '八筋町', 'ヤスジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区貴生町', '23', '23104', '4520816', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '貴生町', 'キセイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区二方町', '23', '23104', '4520817', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '二方町', 'フタカタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区山田町', '23', '23104', '4520818', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '山田町', 'ヤマダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区上小田井', '23', '23104', '4520821', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '上小田井', 'カミオタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区中小田井', '23', '23104', '4520822', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '中小田井', 'ナカオタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区あし原町', '23', '23104', '4520823', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', 'あし原町', 'アシハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区こも原町', '23', '23104', '4520824', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', 'こも原町', 'コモハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区円明町', '23', '23104', '4520831', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '円明町', 'エンメイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区平出町', '23', '23104', '4520832', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '平出町', 'ヒラデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区山木', '23', '23104', '4520833', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '山木', 'ヤマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区木前町', '23', '23104', '4520834', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '木前町', 'キマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区丸野', '23', '23104', '4520835', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '丸野', 'マルノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区新木町', '23', '23104', '4520836', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '新木町', 'アラキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区十方町', '23', '23104', '4520837', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '十方町', 'トホウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区長先町', '23', '23104', '4520838', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '長先町', 'ナガサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区見寄町', '23', '23104', '4520839', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '見寄町', 'ミヨリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区城西町', '23', '23104', '4520841', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '城西町', 'シロニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区城町', '23', '23104', '4520842', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '城町', 'シロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区平中町', '23', '23104', '4520843', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '平中町', 'ヒラナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区上橋町', '23', '23104', '4520844', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '上橋町', 'カミバシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区中沼町', '23', '23104', '4520845', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '中沼町', 'ナカヌマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区浮野町', '23', '23104', '4520846', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '浮野町', 'ウキノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区野南町', '23', '23104', '4520847', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '野南町', 'ノミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市西区西原町', '23', '23104', '4520848', '愛知県', 'アイチケン', '名古屋市西区', 'ナゴヤシニシク', '西原町', 'ニシハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県清須市阿原', '23', '23233', '4520901', '愛知県', 'アイチケン', '清須市', 'キヨスシ', '阿原', 'アワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県清須市助七', '23', '23233', '4520902', '愛知県', 'アイチケン', '清須市', 'キヨスシ', '助七', 'スケシチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県清須市助七1丁目', '23', '23233', '4520903', '愛知県', 'アイチケン', '清須市', 'キヨスシ', '助七', 'スケシチ', null, null, '1丁目', '01チョウメ');
INSERT INTO `ms_addresses` VALUES ('43879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県清須市助七2丁目', '23', '23233', '4520903', '愛知県', 'アイチケン', '清須市', 'キヨスシ', '助七', 'スケシチ', null, null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('43880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県清須市東須ケ口', '23', '23233', '4520904', '愛知県', 'アイチケン', '清須市', 'キヨスシ', '東須ケ口', 'ヒガシスカグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県清須市須ケ口', '23', '23233', '4520905', '愛知県', 'アイチケン', '清須市', 'キヨスシ', '須ケ口', 'スカグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県清須市東外町', '23', '23233', '4520906', '愛知県', 'アイチケン', '清須市', 'キヨスシ', '東外町', 'ヒガシソトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県清須市鍋片', '23', '23233', '4520907', '愛知県', 'アイチケン', '清須市', 'キヨスシ', '鍋片', 'ナベカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県清須市寺野', '23', '23233', '4520908', '愛知県', 'アイチケン', '清須市', 'キヨスシ', '寺野', 'テラノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県清須市西須ケ口', '23', '23233', '4520911', '愛知県', 'アイチケン', '清須市', 'キヨスシ', '西須ケ口', 'ニシスカグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県清須市須ケ口駅前', '23', '23233', '4520912', '愛知県', 'アイチケン', '清須市', 'キヨスシ', '須ケ口駅前', 'スカグチエキマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県清須市上河原', '23', '23233', '4520913', '愛知県', 'アイチケン', '清須市', 'キヨスシ', '上河原', 'カミガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県清須市土器野', '23', '23233', '4520914', '愛知県', 'アイチケン', '清須市', 'キヨスシ', '土器野', 'ドキノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県清須市中河原', '23', '23233', '4520915', '愛知県', 'アイチケン', '清須市', 'キヨスシ', '中河原', 'ナカガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県清須市下河原', '23', '23233', '4520916', '愛知県', 'アイチケン', '清須市', 'キヨスシ', '下河原', 'シモガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県清須市西堀江', '23', '23233', '4520917', '愛知県', 'アイチケン', '清須市', 'キヨスシ', '西堀江', 'ニシホリエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県清須市桃栄', '23', '23233', '4520918', '愛知県', 'アイチケン', '清須市', 'キヨスシ', '桃栄', 'トウエイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県清須市萩野', '23', '23233', '4520919', '愛知県', 'アイチケン', '清須市', 'キヨスシ', '萩野', 'ハギノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県清須市一場', '23', '23233', '4520931', '愛知県', 'アイチケン', '清須市', 'キヨスシ', '一場', 'イチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県清須市朝日', '23', '23233', '4520932', '愛知県', 'アイチケン', '清須市', 'キヨスシ', '朝日', 'アサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県清須市西田中', '23', '23233', '4520933', '愛知県', 'アイチケン', '清須市', 'キヨスシ', '西田中', 'ニシタナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県清須市大嶋', '23', '23233', '4520934', '愛知県', 'アイチケン', '清須市', 'キヨスシ', '大嶋', 'オオシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県清須市北市場本町', '23', '23233', '4520935', '愛知県', 'アイチケン', '清須市', 'キヨスシ', '北市場本町', 'キタイチバホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県清須市西市場', '23', '23233', '4520941', '愛知県', 'アイチケン', '清須市', 'キヨスシ', '西市場', 'ニシイチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県清須市清洲', '23', '23233', '4520942', '愛知県', 'アイチケン', '清須市', 'キヨスシ', '清洲', 'キヨス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県清須市新清洲', '23', '23233', '4520943', '愛知県', 'アイチケン', '清須市', 'キヨスシ', '新清洲', 'シンキヨス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県清須市上条', '23', '23233', '4520944', '愛知県', 'アイチケン', '清須市', 'キヨスシ', '上条', 'ジョウジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県清須市土田', '23', '23233', '4520945', '愛知県', 'アイチケン', '清須市', 'キヨスシ', '土田', 'ツチダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県清須市廻間', '23', '23233', '4520946', '愛知県', 'アイチケン', '清須市', 'キヨスシ', '廻間', 'ハザマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西春日井郡春日町落合', '23', '23345', '4520961', '愛知県', 'アイチケン', '西春日井郡春日町', 'ニシカスガイグンハルヒチョウ', '落合', 'オチアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西春日井郡春日町下之郷', '23', '23345', '4520962', '愛知県', 'アイチケン', '西春日井郡春日町', 'ニシカスガイグンハルヒチョウ', '下之郷', 'シモノゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区', '23', '23105', '4530000', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('43926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名駅', '23', '23105', '4530002', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名駅', 'メイエキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区千原町', '23', '23105', '4530011', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '千原町', 'チハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区井深町', '23', '23105', '4530012', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '井深町', 'イブカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区亀島', '23', '23105', '4530013', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '亀島', 'カメジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区則武', '23', '23105', '4530014', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '則武', 'ノリタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区椿町', '23', '23105', '4530015', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '椿町', 'ツバキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区竹橋町', '23', '23105', '4530016', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '竹橋町', 'タケバシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区則武本通', '23', '23105', '4530017', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '則武本通', 'ノリタケホントオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区佐古前町', '23', '23105', '4530018', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '佐古前町', 'サコマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区松原町', '23', '23105', '4530021', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '松原町', 'マツバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区中島町', '23', '23105', '4530022', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '中島町', 'ナカジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区若宮町', '23', '23105', '4530023', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '若宮町', 'ワカミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名楽町', '23', '23105', '4530024', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名楽町', 'メイラクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区賑町', '23', '23105', '4530025', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '賑町', 'ニギワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区羽衣町', '23', '23105', '4530026', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '羽衣町', 'ハゴロモチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区大門町', '23', '23105', '4530027', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '大門町', 'オオモンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区寿町', '23', '23105', '4530028', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '寿町', 'コトブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区日吉町', '23', '23105', '4530029', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '日吉町', 'ヒヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区新富町', '23', '23105', '4530031', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '新富町', 'シントミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区塩池町', '23', '23105', '4530032', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '塩池町', 'シオイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区栄生町', '23', '23105', '4530033', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '栄生町', 'サコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区大日町', '23', '23105', '4530034', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '大日町', 'ダイニチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区十王町', '23', '23105', '4530035', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '十王町', 'ジュウオウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区森田町', '23', '23105', '4530036', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '森田町', 'モリタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区高道町', '23', '23105', '4530037', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '高道町', 'タカミチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区猪之越町', '23', '23105', '4530038', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '猪之越町', 'イノコシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区本陣通', '23', '23105', '4530041', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '本陣通', 'ホンジントオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区大秋町', '23', '23105', '4530042', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '大秋町', 'オオアキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区上ノ宮町', '23', '23105', '4530043', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '上ノ宮町', 'カミノミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区鳥居通', '23', '23105', '4530044', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '鳥居通', 'トリイトオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区藤江町', '23', '23105', '4530045', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '藤江町', 'フジエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区道下町', '23', '23105', '4530046', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '道下町', 'ミチシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区元中村町', '23', '23105', '4530047', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '元中村町', 'モトナカムラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区豊幡町', '23', '23105', '4530051', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '豊幡町', 'トヨバタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区森末町', '23', '23105', '4530052', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '森末町', 'モリスエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区中村町', '23', '23105', '4530053', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '中村町', 'ナカムラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区鳥居西通', '23', '23105', '4530054', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '鳥居西通', 'トリイニシトオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区香取町', '23', '23105', '4530055', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '香取町', 'カトリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区砂田町', '23', '23105', '4530056', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '砂田町', 'スナダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区稲葉地本通', '23', '23105', '4530057', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '稲葉地本通', 'イナバジホントオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区城屋敷町', '23', '23105', '4530058', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '城屋敷町', 'シロヤシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区日比津町', '23', '23105', '4530061', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '日比津町', 'ヒビツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区諏訪町', '23', '23105', '4530062', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '諏訪町', 'スワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区東宿町', '23', '23105', '4530063', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '東宿町', 'ヒガシジュクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区草薙町', '23', '23105', '4530064', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '草薙町', 'クサナギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区靖国町', '23', '23105', '4530065', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '靖国町', 'ヤスクニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区稲上町', '23', '23105', '4530066', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '稲上町', 'イナカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区宿跡町', '23', '23105', '4530067', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '宿跡町', 'シュクアトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区菊水町', '23', '23105', '4530068', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '菊水町', 'キクスイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区橋下町', '23', '23105', '4530069', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '橋下町', 'ハシシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区太閤', '23', '23105', '4530801', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '太閤', 'タイコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区下米野町', '23', '23105', '4530802', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '下米野町', 'シモコメノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区長戸井町', '23', '23105', '4530803', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '長戸井町', 'ナガトイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区黄金通', '23', '23105', '4530804', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '黄金通', 'オウゴンドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区深川町', '23', '23105', '4530805', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '深川町', 'フカガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区大正町', '23', '23105', '4530806', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '大正町', 'タイショウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区権現通', '23', '23105', '4530807', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '権現通', 'ゴンゲントオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区郷前町', '23', '23105', '4530808', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '郷前町', 'ゴウマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区上米野町', '23', '23105', '4530809', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '上米野町', 'カミコメノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区太閤通', '23', '23105', '4530811', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '太閤通', 'タイコウトオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区西米野町', '23', '23105', '4530812', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '西米野町', 'ニシコメノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区二ツ橋町', '23', '23105', '4530813', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '二ツ橋町', 'フタツバシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区熊野町', '23', '23105', '4530814', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '熊野町', 'クマノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区北畑町', '23', '23105', '4530815', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '北畑町', 'キタハタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区京田町', '23', '23105', '4530816', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '京田町', 'キョウデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区白子町', '23', '23105', '4530817', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '白子町', 'シラコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区千成通', '23', '23105', '4530818', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '千成通', 'センナリトオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区城主町', '23', '23105', '4530819', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '城主町', 'ジョウシュチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区大宮町', '23', '23105', '4530821', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '大宮町', 'オオミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区名西通', '23', '23105', '4530822', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '名西通', 'メイセイトオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区日ノ宮町', '23', '23105', '4530823', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '日ノ宮町', 'ヒノミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区北浦町', '23', '23105', '4530824', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '北浦町', 'キタウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区沖田町', '23', '23105', '4530825', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '沖田町', 'オキタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('43999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区鈍池町', '23', '23105', '4530826', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '鈍池町', 'ニブイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区下中村町', '23', '23105', '4530827', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '下中村町', 'シモナカムラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区中村本町', '23', '23105', '4530828', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '中村本町', 'ナカムラホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区中村中町', '23', '23105', '4530831', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '中村中町', 'ナカムラナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区乾出町', '23', '23105', '4530832', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '乾出町', 'イヌイデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区押木田町', '23', '23105', '4530833', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '押木田町', 'オシキダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区豊国通', '23', '23105', '4530834', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '豊国通', 'トヨクニトオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区上石川町', '23', '23105', '4530835', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '上石川町', 'カミイシカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区五反城町', '23', '23105', '4530836', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '五反城町', 'ゴタンジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区二瀬町', '23', '23105', '4530837', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '二瀬町', 'フタセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区向島町', '23', '23105', '4530838', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '向島町', 'ムコウジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区長筬町', '23', '23105', '4530839', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '長筬町', 'ナガオサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区稲葉地町', '23', '23105', '4530841', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '稲葉地町', 'イナバジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区剣町', '23', '23105', '4530842', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '剣町', 'ツルギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区鴨付町', '23', '23105', '4530843', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '鴨付町', 'カモツキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区小鴨町', '23', '23105', '4530844', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '小鴨町', 'コカモチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区宮塚町', '23', '23105', '4530845', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '宮塚町', 'ミヤツカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区西栄町', '23', '23105', '4530846', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '西栄町', 'ニシサカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区岩上町', '23', '23105', '4530847', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '岩上町', 'イワカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区荒輪井町', '23', '23105', '4530848', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '荒輪井町', 'アラワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区稲西町', '23', '23105', '4530849', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '稲西町', 'イナニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区畑江通', '23', '23105', '4530851', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '畑江通', 'ハタエトオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区角割町', '23', '23105', '4530852', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '角割町', 'カクワリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区牛田通', '23', '23105', '4530853', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '牛田通', 'ウシダトオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区高須賀町', '23', '23105', '4530854', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '高須賀町', 'タカスカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区烏森町', '23', '23105', '4530855', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '烏森町', 'カスモリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区並木', '23', '23105', '4530856', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '並木', 'ナミキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区長草町', '23', '23105', '4530857', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '長草町', 'ナガクサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区野田町', '23', '23105', '4530858', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '野田町', 'ノダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区野上町', '23', '23105', '4530859', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '野上町', 'ノガミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区岩塚本通', '23', '23105', '4530861', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '岩塚本通', 'イワツカホントオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区岩塚町', '23', '23105', '4530862', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '岩塚町', 'イワツカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区八社', '23', '23105', '4530863', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '八社', 'ハッシャ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区横前町', '23', '23105', '4530864', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '横前町', 'ヨコマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区川前町', '23', '23105', '4530865', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '川前町', 'カワマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区横井', '23', '23105', '4530866', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '横井', 'ヨコイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区横井町', '23', '23105', '4530867', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '横井町', 'ヨコイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区牧野町', '23', '23105', '4530871', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '牧野町', 'マキノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中村区平池町', '23', '23105', '4530872', '愛知県', 'アイチケン', '名古屋市中村区', 'ナゴヤシナカムラク', '平池町', 'ヒライケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区', '23', '23110', '4540000', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('44068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区運河町', '23', '23110', '4540001', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '運河町', 'ウンガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区運河通', '23', '23110', '4540002', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '運河通', 'ウンガトオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区松重町', '23', '23110', '4540003', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '松重町', 'マツシゲチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区西日置', '23', '23110', '4540004', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '西日置', 'ニシヒオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区西日置町', '23', '23110', '4540005', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '西日置町', 'ニシヒオキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区柳堀町', '23', '23110', '4540006', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '柳堀町', 'ヤナギボリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区広住町', '23', '23110', '4540007', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '広住町', 'ヒロスミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区山王', '23', '23110', '4540011', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '山王', 'サンノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区尾頭橋', '23', '23110', '4540012', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '尾頭橋', 'オトウバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区八熊', '23', '23110', '4540013', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '八熊', 'ヤグマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区柳川町', '23', '23110', '4540014', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '柳川町', 'ヤナガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区南八熊町', '23', '23110', '4540015', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '南八熊町', 'ミナミヤグマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区幡野町', '23', '23110', '4540016', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '幡野町', 'ハタノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区横堀町', '23', '23110', '4540021', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '横堀町', 'ヨコボリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区露橋', '23', '23110', '4540022', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '露橋', 'ツユハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区石場町', '23', '23110', '4540023', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '石場町', 'イシバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区柳島町', '23', '23110', '4540024', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '柳島町', 'ヤナギシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区前並町', '23', '23110', '4540025', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '前並町', 'マエナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区笈瀬町', '23', '23110', '4540026', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '笈瀬町', 'オイセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区広川町', '23', '23110', '4540027', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '広川町', 'ヒロカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区露橋町', '23', '23110', '4540028', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '露橋町', 'ツユハシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区八幡本通', '23', '23110', '4540031', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '八幡本通', 'ヤハタホントオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区荒江町', '23', '23110', '4540032', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '荒江町', 'アラエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区五女子', '23', '23110', '4540033', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '五女子', 'ゴニョウシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区五女子町', '23', '23110', '4540034', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '五女子町', 'ゴニョシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区八熊通', '23', '23110', '4540035', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '八熊通', 'ヤグマドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区二女子町', '23', '23110', '4540036', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '二女子町', 'ニニョシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区富川町', '23', '23110', '4540037', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '富川町', 'トミカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区八神町', '23', '23110', '4540041', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '八神町', 'ヤガミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区応仁町', '23', '23110', '4540042', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '応仁町', 'オウジンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区牛立町', '23', '23110', '4540043', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '牛立町', 'ウシダテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区荒越町', '23', '23110', '4540044', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '荒越町', 'アラコシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区丹後町', '23', '23110', '4540045', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '丹後町', 'タンゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区神郷町', '23', '23110', '4540046', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '神郷町', 'シンゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区中野本町', '23', '23110', '4540047', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '中野本町', 'ナカノホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区元中野町', '23', '23110', '4540048', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '元中野町', 'モトナカノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区清川町', '23', '23110', '4540049', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '清川町', 'キヨカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区大山町', '23', '23110', '4540051', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '大山町', 'オオヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区花塚町', '23', '23110', '4540052', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '花塚町', 'ハナヅカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区外新町', '23', '23110', '4540053', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '外新町', 'ソトシンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区八剱町', '23', '23110', '4540054', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '八剱町', 'ハチケンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区十番町', '23', '23110', '4540055', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '十番町', 'ジュウバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区十一番町', '23', '23110', '4540056', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '十一番町', 'ジュウイチバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区熱田新田東組', '23', '23110', '4540057', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '熱田新田東組', 'アツタシンデンヒガシグミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区玉川町', '23', '23110', '4540058', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '玉川町', 'タマカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区福川町', '23', '23110', '4540059', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '福川町', 'フクカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区百船町', '23', '23110', '4540801', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '百船町', 'モモフネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区福住町', '23', '23110', '4540802', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '福住町', 'フクズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区豊成町', '23', '23110', '4540803', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '豊成町', 'ホウセイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区月島町', '23', '23110', '4540804', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '月島町', 'ツキシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区舟戸町', '23', '23110', '4540805', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '舟戸町', 'フナトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区澄池町', '23', '23110', '4540806', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '澄池町', 'スミイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区愛知町', '23', '23110', '4540807', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '愛知町', 'アイチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区九重町', '23', '23110', '4540808', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '九重町', 'ココノエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区三ツ池町', '23', '23110', '4540811', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '三ツ池町', 'ミツイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区五月通', '23', '23110', '4540812', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '五月通', 'サツキトオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区乗越町', '23', '23110', '4540813', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '乗越町', 'ノリコシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区五月南通', '23', '23110', '4540814', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '五月南通', 'サツキミナミトオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区長良町', '23', '23110', '4540815', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '長良町', 'ナガラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区中京南通', '23', '23110', '4540816', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '中京南通', 'チュウキョウミナミトオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区南脇町', '23', '23110', '4540817', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '南脇町', 'ミナミワキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区松葉町', '23', '23110', '4540818', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '松葉町', 'マツバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区烏森町', '23', '23110', '4540819', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '烏森町', 'カスモリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区宗円町', '23', '23110', '4540821', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '宗円町', 'ソウエンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区四女子町', '23', '23110', '4540822', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '四女子町', 'シニョシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区富船町', '23', '23110', '4540823', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '富船町', 'トミフネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区蔦元町', '23', '23110', '4540824', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '蔦元町', 'ツタモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区好本町', '23', '23110', '4540825', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '好本町', 'ヨシモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区小本本町', '23', '23110', '4540826', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '小本本町', 'コモトホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区辻畑町', '23', '23110', '4540827', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '辻畑町', 'ツジバタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区小本', '23', '23110', '4540828', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '小本', 'コモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区小本町', '23', '23110', '4540829', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '小本町', 'オモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区三ツ屋町', '23', '23110', '4540831', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '三ツ屋町', 'ミツヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区清船町', '23', '23110', '4540832', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '清船町', 'キヨフネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区上脇町', '23', '23110', '4540833', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '上脇町', 'カミワキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区丸米町', '23', '23110', '4540834', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '丸米町', 'マルコメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区八家町', '23', '23110', '4540835', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '八家町', 'ヤツヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区福船町', '23', '23110', '4540836', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '福船町', 'フクフネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区中野新町', '23', '23110', '4540837', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '中野新町', 'ナカノシンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区太平通', '23', '23110', '4540838', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '太平通', 'タイヘイトオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区篠原橋通', '23', '23110', '4540839', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '篠原橋通', 'シノハラバシトオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区押元町', '23', '23110', '4540841', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '押元町', 'オシモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区宮脇町', '23', '23110', '4540842', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '宮脇町', 'ミヤワキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区大畑町', '23', '23110', '4540843', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '大畑町', 'オオハタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区葉池町', '23', '23110', '4540844', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '葉池町', 'ハイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区馬手町', '23', '23110', '4540845', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '馬手町', 'ウマテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区上流町', '23', '23110', '4540846', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '上流町', 'カミナガレチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区細米町', '23', '23110', '4540847', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '細米町', 'ホソコメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区松ノ木町', '23', '23110', '4540848', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '松ノ木町', 'マツノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区小塚町', '23', '23110', '4540849', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '小塚町', 'コヅカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区北江町', '23', '23110', '4540851', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '北江町', 'キタエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区昭和橋通', '23', '23110', '4540852', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '昭和橋通', 'ショウワバシトオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区玉船町', '23', '23110', '4540853', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '玉船町', 'タマフネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区松年町', '23', '23110', '4540854', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '松年町', 'ショウネンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区昭明町', '23', '23110', '4540855', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '昭明町', 'ショウメイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区小碓通', '23', '23110', '4540856', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '小碓通', 'コウスドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区明徳町', '23', '23110', '4540857', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '明徳町', 'メイトクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区正徳町', '23', '23110', '4540858', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '正徳町', 'ショウトクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区法蔵町', '23', '23110', '4540859', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '法蔵町', 'ホウゾウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区畑田町', '23', '23110', '4540860', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '畑田町', 'ハタダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区荒子町', '23', '23110', '4540861', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '荒子町', 'アラコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区的場町', '23', '23110', '4540862', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '的場町', 'マトバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区大塩町', '23', '23110', '4540863', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '大塩町', 'オオシオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区平戸町', '23', '23110', '4540864', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '平戸町', 'ヒラトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区掛入町', '23', '23110', '4540865', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '掛入町', 'カケイリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区東中島町', '23', '23110', '4540866', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '東中島町', 'ヒガシナカジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区広田町', '23', '23110', '4540867', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '広田町', 'ヒロタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区草平町', '23', '23110', '4540868', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '草平町', 'クサヒラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区荒子', '23', '23110', '4540869', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '荒子', 'アラコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区柳森町', '23', '23110', '4540871', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '柳森町', 'ヤナモリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区万町', '23', '23110', '4540872', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '万町', 'マンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区上高畑', '23', '23110', '4540873', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '上高畑', 'カミタカバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区吉良町', '23', '23110', '4540874', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '吉良町', 'キラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区小城町', '23', '23110', '4540875', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '小城町', 'コシロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区若山町', '23', '23110', '4540876', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '若山町', 'ワカヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区八田町', '23', '23110', '4540877', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '八田町', 'ハッタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区岩塚町本地', '23', '23110', '4540901', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '岩塚町', 'イワツカチョウ', null, null, '本地', 'ホンヂ');
INSERT INTO `ms_addresses` VALUES ('44185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区花池町', '23', '23110', '4540902', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '花池町', 'ハナイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区柳瀬町', '23', '23110', '4540903', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '柳瀬町', 'ヤナセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区八田本町', '23', '23110', '4540904', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '八田本町', 'ハッタホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区一柳通', '23', '23110', '4540905', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '一柳通', 'イチヤナギドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区開平町', '23', '23110', '4540906', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '開平町', 'カイヘイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区柳田町', '23', '23110', '4540907', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '柳田町', 'ヤナギダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区高畑', '23', '23110', '4540911', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '高畑', 'タカバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区野田', '23', '23110', '4540912', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '野田', 'ノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区土野町', '23', '23110', '4540913', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '土野町', 'ツチノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区本前田町', '23', '23110', '4540914', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '本前田町', 'ホンマエダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区横井', '23', '23110', '4540915', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '横井', 'ヨコイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区川前町', '23', '23110', '4540916', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '川前町', 'カワマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区横前町', '23', '23110', '4540917', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '横前町', 'ヨコマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区中郷', '23', '23110', '4540921', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '中郷', 'チュウゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区荒中町', '23', '23110', '4540922', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '荒中町', 'アラナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区打出本町', '23', '23110', '4540923', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '打出本町', 'ウチデホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区打出町', '23', '23110', '4540924', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '打出町', 'ウチデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区中須町', '23', '23110', '4540925', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '中須町', 'ナカスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区打出', '23', '23110', '4540926', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '打出', 'ウチデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区打中', '23', '23110', '4540927', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '打中', 'ウチナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区中花町', '23', '23110', '4540931', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '中花町', 'ナカハナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区中島新町', '23', '23110', '4540932', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '中島新町', 'ナカジマシンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区法華', '23', '23110', '4540933', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '法華', 'ホッケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区西中島', '23', '23110', '4540934', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '西中島', 'ニシナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区東起町', '23', '23110', '4540935', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '東起町', 'ヒガシオコシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区高杉町', '23', '23110', '4540936', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '高杉町', 'タカスギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区法華西町', '23', '23110', '4540937', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '法華西町', 'ホッケニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区前田西町', '23', '23110', '4540941', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '前田西町', 'マエダニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区富田町前田', '23', '23110', '4540942', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '富田町前田', 'トミダチョウマエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区大当郎', '23', '23110', '4540943', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '大当郎', 'ダイトウロウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区大蟷螂町', '23', '23110', '4540944', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '大蟷螂町', 'ダイトウロウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区下之一色町', '23', '23110', '4540945', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '下之一色町', 'シモノイッシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区一色新町', '23', '23110', '4540946', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '一色新町', 'イシキシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区助光', '23', '23110', '4540947', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '助光', 'スケミツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区榎津西町', '23', '23110', '4540951', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '榎津西町', 'エノキヅニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区榎松町', '23', '23110', '4540952', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '榎松町', 'エノキマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区富田町榎津', '23', '23110', '4540953', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '富田町榎津', 'トミダチョウヨノキヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区江松', '23', '23110', '4540954', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '江松', 'エマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区富田町江松', '23', '23110', '4540954', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '富田町江松', 'トミダチョウエマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区富田町包里', '23', '23110', '4540955', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '富田町包里', 'トミダチョウカノサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区富田町供米田', '23', '23110', '4540956', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '富田町供米田', 'トミダチョウクマイデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区かの里', '23', '23110', '4540957', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', 'かの里', 'カノサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区東かの里町', '23', '23110', '4540958', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '東かの里町', 'ヒガシカノサトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区江松西町', '23', '23110', '4540959', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '江松西町', 'エマツニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区富田町戸田', '23', '23110', '4540961', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '富田町戸田', 'トミダチョウトダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区戸田', '23', '23110', '4540962', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '戸田', 'トダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区水里', '23', '23110', '4540963', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '水里', 'ミズサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区富永', '23', '23110', '4540964', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '富永', 'トミナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区福島', '23', '23110', '4540965', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '福島', 'フクシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区戸田ゆたか', '23', '23110', '4540966', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '戸田ゆたか', 'トダユタカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区戸田西', '23', '23110', '4540967', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '戸田西', 'トダニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区富田町千音寺', '23', '23110', '4540971', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '富田町千音寺', 'トミダチョウセンノンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区新家', '23', '23110', '4540972', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '新家', 'ニイエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区富田町服部', '23', '23110', '4540973', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '富田町服部', 'トミダチョウハットリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区島井町', '23', '23110', '4540974', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '島井町', 'シマイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区七反田町', '23', '23110', '4540975', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '七反田町', 'ヒチタンダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区服部', '23', '23110', '4540976', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '服部', 'ハットリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区吉津', '23', '23110', '4540981', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '吉津', 'ヨシヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区西伏屋', '23', '23110', '4540982', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '西伏屋', 'ニシフシヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区東春田', '23', '23110', '4540983', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '東春田', 'ヒガシハルタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区供米田', '23', '23110', '4540984', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '供米田', 'クマイデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区春田', '23', '23110', '4540985', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '春田', 'ハルタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区富田町春田', '23', '23110', '4540986', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '富田町春田', 'トミダチョウハルタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区大地', '23', '23110', '4540991', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '大地', 'ダイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区富田町万場', '23', '23110', '4540992', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '富田町万場', 'トミダチョウマンバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区富田町松下', '23', '23110', '4540993', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '富田町松下', 'トミダチョウマツシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区長須賀', '23', '23110', '4540994', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '長須賀', 'ナガスカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区富田町伏屋', '23', '23110', '4540995', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '富田町伏屋', 'トミダチョウフシヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区伏屋', '23', '23110', '4540996', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '伏屋', 'フシヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中川区万場', '23', '23110', '4540997', '愛知県', 'アイチケン', '名古屋市中川区', 'ナゴヤシナカガワク', '万場', 'マンバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区', '23', '23111', '4550000', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('44288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区七番町', '23', '23111', '4550001', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '七番町', 'シチバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区東海通', '23', '23111', '4550002', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '東海通', 'トウカイドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区辰巳町', '23', '23111', '4550003', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '辰巳町', 'タツミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区津金', '23', '23111', '4550004', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '津金', 'ツカネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区新川町', '23', '23111', '4550005', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '新川町', 'シンカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区南十一番町', '23', '23111', '4550006', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '南十一番町', 'ミナミ11バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区南十番町', '23', '23111', '4550007', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '南十番町', 'ミナミ10バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区九番町', '23', '23111', '4550008', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '九番町', 'クバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区千年', '23', '23111', '4550011', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '千年', 'チトセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区作倉町', '23', '23111', '4550012', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '作倉町', 'サクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区港陽', '23', '23111', '4550013', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '港陽', 'コウヨウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区港楽', '23', '23111', '4550014', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '港楽', 'コウラク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区港栄', '23', '23111', '4550015', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '港栄', 'コウエイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区河口町', '23', '23111', '4550016', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '河口町', 'カワクチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区金川町', '23', '23111', '4550017', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '金川町', 'カネカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区港明', '23', '23111', '4550018', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '港明', 'コウメイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区木場町', '23', '23111', '4550021', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '木場町', 'キバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区竜宮町', '23', '23111', '4550022', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '竜宮町', 'リュウグウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区東築地町', '23', '23111', '4550023', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '東築地町', 'ヒガシツキジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区大江町', '23', '23111', '4550024', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '大江町', 'オオエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区本星崎町', '23', '23111', '4550025', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '本星崎町', 'モトホシザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区昭和町', '23', '23111', '4550026', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '昭和町', 'ショウワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区船見町', '23', '23111', '4550027', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '船見町', 'フナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区潮見町', '23', '23111', '4550028', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '潮見町', 'シオミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区千鳥', '23', '23111', '4550031', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '千鳥', 'チドリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区入船', '23', '23111', '4550032', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '入船', 'イリフネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区港町', '23', '23111', '4550033', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '港町', 'ミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区西倉町', '23', '23111', '4550034', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '西倉町', 'ニシクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区熱田前新田', '23', '23111', '4550035', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '熱田前新田', 'アツタマエシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区浜', '23', '23111', '4550036', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '浜', 'ハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区名港', '23', '23111', '4550037', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '名港', 'メイコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区幸町', '23', '23111', '4550041', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区佐野町', '23', '23111', '4550042', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '佐野町', 'サノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区魁町', '23', '23111', '4550043', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '魁町', 'サキガケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区築三町', '23', '23111', '4550044', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '築三町', 'ツキサンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区築地町', '23', '23111', '4550045', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '築地町', 'ツキジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区大手町', '23', '23111', '4550046', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '大手町', 'オオテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区中之島通', '23', '23111', '4550047', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '中之島通', 'ナカノジマトオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区中川本町', '23', '23111', '4550051', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '中川本町', 'ナカガワホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区いろは町', '23', '23111', '4550052', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', 'いろは町', 'イロハチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区名四町', '23', '23111', '4550053', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '名四町', 'メイシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区遠若町', '23', '23111', '4550054', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '遠若町', 'エンジャクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区品川町', '23', '23111', '4550055', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '品川町', 'シナガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区砂美町', '23', '23111', '4550056', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '砂美町', 'スナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区築盛町', '23', '23111', '4550057', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '築盛町', 'チクモリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区東土古町', '23', '23111', '4550061', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '東土古町', 'ヒガシドンゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区小碓町', '23', '23111', '4550062', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '小碓町', 'オウスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区金船町', '23', '23111', '4550063', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '金船町', 'カネフネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区本宮町', '23', '23111', '4550064', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '本宮町', 'ホングウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区本宮新町', '23', '23111', '4550065', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '本宮新町', 'ホングウシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区寛政町', '23', '23111', '4550066', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '寛政町', 'カンセイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区港北町', '23', '23111', '4550067', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '港北町', 'コウホクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区土古町', '23', '23111', '4550068', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '土古町', 'ドンゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区泰明町', '23', '23111', '4550069', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '泰明町', 'タイメイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区新船町', '23', '23111', '4550071', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '新船町', 'シンフネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区須成町', '23', '23111', '4550072', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '須成町', 'スナリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区川西通', '23', '23111', '4550073', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '川西通', 'カワニシドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区正保町', '23', '23111', '4550074', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '正保町', 'ショウホウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区正徳町', '23', '23111', '4550075', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '正徳町', 'ショウトクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区川間町', '23', '23111', '4550076', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '川間町', 'カワマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区小割通', '23', '23111', '4550077', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '小割通', 'コワリドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区丸池町', '23', '23111', '4550078', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '丸池町', 'マルイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区小碓', '23', '23111', '4550801', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '小碓', 'オウス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区入場町', '23', '23111', '4550802', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '入場町', 'イリバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区入場', '23', '23111', '4550803', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '入場', 'イリバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区当知', '23', '23111', '4550804', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '当知', 'トウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区当知町', '23', '23111', '4550805', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '当知町', 'トウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区明正', '23', '23111', '4550806', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '明正', 'メイショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区善進町', '23', '23111', '4550811', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '善進町', 'ゼンシンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区善北町', '23', '23111', '4550812', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '善北町', 'ゼンホクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区善進本町', '23', '23111', '4550813', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '善進本町', 'ゼンシンホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区善南町', '23', '23111', '4550814', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '善南町', 'ゼンナンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区油屋町', '23', '23111', '4550815', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '油屋町', 'アブラヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区高木町', '23', '23111', '4550821', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '高木町', 'タカギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区甚兵衛通', '23', '23111', '4550822', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '甚兵衛通', 'ジンベエトオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区惟信町', '23', '23111', '4550823', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '惟信町', 'イシンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区西川町', '23', '23111', '4550824', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '西川町', 'ニシカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区多加良浦町', '23', '23111', '4550825', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '多加良浦町', 'タカラウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区十一屋', '23', '23111', '4550831', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '十一屋', 'ジュウイチヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区宝神', '23', '23111', '4550832', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '宝神', 'ホウジン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区宝神町', '23', '23111', '4550833', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '宝神町', 'ホウジンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区神宮寺', '23', '23111', '4550834', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '神宮寺', 'ジングウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区十一屋町', '23', '23111', '4550835', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '十一屋町', 'ジュウイチヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区一州町', '23', '23111', '4550841', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '一州町', 'イッシュウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区稲永', '23', '23111', '4550842', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '稲永', 'イナエイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区錦町', '23', '23111', '4550843', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '錦町', 'ニシキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区潮凪町', '23', '23111', '4550844', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '潮凪町', 'シオナギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区野跡', '23', '23111', '4550845', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '野跡', 'ノセキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区汐止町', '23', '23111', '4550846', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '汐止町', 'シオトメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区空見町', '23', '23111', '4550847', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '空見町', 'ソラミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区金城ふ頭', '23', '23111', '4550848', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '金城ふ頭', 'キンジョウフトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区東茶屋', '23', '23111', '4550851', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '東茶屋', 'ヒガシチャヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区七島', '23', '23111', '4550852', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '七島', 'ナナシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区南陽町七島新田', '23', '23111', '4550853', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '南陽町七島新田', 'ナンヨウチョウナナシマシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区藤高', '23', '23111', '4550854', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '藤高', 'フジタカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区藤前', '23', '23111', '4550855', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '藤前', 'フジマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区川園', '23', '23111', '4550856', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '川園', 'カワソノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区秋葉', '23', '23111', '4550857', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '秋葉', 'アキハ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区西茶屋', '23', '23111', '4550858', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '西茶屋', 'ニシチャヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区大西', '23', '23111', '4550861', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '大西', 'オオニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区南陽町茶屋新田', '23', '23111', '4550862', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '南陽町茶屋新田', 'ナンヨウチョウチャヤシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区新茶屋', '23', '23111', '4550863', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '新茶屋', 'シンチャヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区小川', '23', '23111', '4550864', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '小川', 'オガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区天目町', '23', '23111', '4550865', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '天目町', 'テンモクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区南陽町茶屋後新田', '23', '23111', '4550866', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '南陽町茶屋後新田', 'ナンヨウチョウチャヤノチシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区南陽町福田前新田', '23', '23111', '4550867', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '南陽町福田前新田', 'ナンヨウチョウフクダマエシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区南陽町西福田', '23', '23111', '4550868', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '南陽町西福田', 'ナンヨウチョウニシフクタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区南陽町福田', '23', '23111', '4550871', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '南陽町福田', 'ナンヨウチョウフクタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区西蟹田', '23', '23111', '4550872', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '西蟹田', 'ニシカニタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区春田野', '23', '23111', '4550873', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '春田野', 'ハルタノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区西福田', '23', '23111', '4550874', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '西福田', 'ニシフクタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区寺前町', '23', '23111', '4550875', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '寺前町', 'テラマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区福屋', '23', '23111', '4550876', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '福屋', 'フクヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区船頭場', '23', '23111', '4550881', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '船頭場', 'センドウバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区小賀須', '23', '23111', '4550882', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '小賀須', 'コガス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区知多', '23', '23111', '4550883', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '知多', 'チタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区七反野', '23', '23111', '4550884', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '七反野', 'シチタンノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区八百島', '23', '23111', '4550885', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '八百島', 'ハッピャクジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区東蟹田', '23', '23111', '4550886', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '東蟹田', 'ヒガシカニタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市港区福田', '23', '23111', '4550887', '愛知県', 'アイチケン', '名古屋市港区', 'ナゴヤシミナトク', '福田', 'フクタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市熱田区', '23', '23109', '4560000', '愛知県', 'アイチケン', '名古屋市熱田区', 'ナゴヤシアツタク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('44423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市熱田区金山', '23', '23109', '4560001', '愛知県', 'アイチケン', '名古屋市熱田区', 'ナゴヤシアツタク', '金山', 'カナヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市熱田区金山町', '23', '23109', '4560002', '愛知県', 'アイチケン', '名古屋市熱田区', 'ナゴヤシアツタク', '金山町', 'カナヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市熱田区波寄町', '23', '23109', '4560003', '愛知県', 'アイチケン', '名古屋市熱田区', 'ナゴヤシアツタク', '波寄町', 'ナミヨセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市熱田区桜田町', '23', '23109', '4560004', '愛知県', 'アイチケン', '名古屋市熱田区', 'ナゴヤシアツタク', '桜田町', 'サクラダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市熱田区池内町', '23', '23109', '4560005', '愛知県', 'アイチケン', '名古屋市熱田区', 'ナゴヤシアツタク', '池内町', 'イケウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市熱田区沢下町', '23', '23109', '4560006', '愛知県', 'アイチケン', '名古屋市熱田区', 'ナゴヤシアツタク', '沢下町', 'サワシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市熱田区花町', '23', '23109', '4560011', '愛知県', 'アイチケン', '名古屋市熱田区', 'ナゴヤシアツタク', '花町', 'ハナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市熱田区沢上', '23', '23109', '4560012', '愛知県', 'アイチケン', '名古屋市熱田区', 'ナゴヤシアツタク', '沢上', 'サワカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市熱田区外土居町', '23', '23109', '4560013', '愛知県', 'アイチケン', '名古屋市熱田区', 'ナゴヤシアツタク', '外土居町', 'ソトドイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市熱田区中田町', '23', '23109', '4560014', '愛知県', 'アイチケン', '名古屋市熱田区', 'ナゴヤシアツタク', '中田町', 'ナカタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市熱田区高蔵町', '23', '23109', '4560015', '愛知県', 'アイチケン', '名古屋市熱田区', 'ナゴヤシアツタク', '高蔵町', 'タカクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市熱田区五本松町', '23', '23109', '4560016', '愛知県', 'アイチケン', '名古屋市熱田区', 'ナゴヤシアツタク', '五本松町', 'ゴホンマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市熱田区尾頭町', '23', '23109', '4560017', '愛知県', 'アイチケン', '名古屋市熱田区', 'ナゴヤシアツタク', '尾頭町', 'オトウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市熱田区新尾頭', '23', '23109', '4560018', '愛知県', 'アイチケン', '名古屋市熱田区', 'ナゴヤシアツタク', '新尾頭', 'シンオトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市熱田区夜寒町', '23', '23109', '4560021', '愛知県', 'アイチケン', '名古屋市熱田区', 'ナゴヤシアツタク', '夜寒町', 'ヨサムチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市熱田区横田', '23', '23109', '4560022', '愛知県', 'アイチケン', '名古屋市熱田区', 'ナゴヤシアツタク', '横田', 'ヨコタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市熱田区六野', '23', '23109', '4560023', '愛知県', 'アイチケン', '名古屋市熱田区', 'ナゴヤシアツタク', '六野', 'ムツノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市熱田区森後町', '23', '23109', '4560024', '愛知県', 'アイチケン', '名古屋市熱田区', 'ナゴヤシアツタク', '森後町', 'モリゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市熱田区玉の井町', '23', '23109', '4560025', '愛知県', 'アイチケン', '名古屋市熱田区', 'ナゴヤシアツタク', '玉の井町', 'タマノイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市熱田区旗屋町', '23', '23109', '4560026', '愛知県', 'アイチケン', '名古屋市熱田区', 'ナゴヤシアツタク', '旗屋町', 'ハタヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市熱田区旗屋', '23', '23109', '4560027', '愛知県', 'アイチケン', '名古屋市熱田区', 'ナゴヤシアツタク', '旗屋', 'ハタヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市熱田区神宮', '23', '23109', '4560031', '愛知県', 'アイチケン', '名古屋市熱田区', 'ナゴヤシアツタク', '神宮', 'ジングウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市熱田区三本松町', '23', '23109', '4560032', '愛知県', 'アイチケン', '名古屋市熱田区', 'ナゴヤシアツタク', '三本松町', 'サンボンマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市熱田区花表町', '23', '23109', '4560033', '愛知県', 'アイチケン', '名古屋市熱田区', 'ナゴヤシアツタク', '花表町', 'ハナオモテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市熱田区伝馬', '23', '23109', '4560034', '愛知県', 'アイチケン', '名古屋市熱田区', 'ナゴヤシアツタク', '伝馬', 'テンマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市熱田区白鳥', '23', '23109', '4560035', '愛知県', 'アイチケン', '名古屋市熱田区', 'ナゴヤシアツタク', '白鳥', 'シロトリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市熱田区熱田西町', '23', '23109', '4560036', '愛知県', 'アイチケン', '名古屋市熱田区', 'ナゴヤシアツタク', '熱田西町', 'アツタニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市熱田区熱田新田東組', '23', '23109', '4560037', '愛知県', 'アイチケン', '名古屋市熱田区', 'ナゴヤシアツタク', '熱田新田東組', 'アツタシンデンヒガシグミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市熱田区中瀬町', '23', '23109', '4560041', '愛知県', 'アイチケン', '名古屋市熱田区', 'ナゴヤシアツタク', '中瀬町', 'ナカセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市熱田区須賀町', '23', '23109', '4560042', '愛知県', 'アイチケン', '名古屋市熱田区', 'ナゴヤシアツタク', '須賀町', 'スカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市熱田区神戸町', '23', '23109', '4560043', '愛知県', 'アイチケン', '名古屋市熱田区', 'ナゴヤシアツタク', '神戸町', 'ゴウドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市熱田区内田町', '23', '23109', '4560044', '愛知県', 'アイチケン', '名古屋市熱田区', 'ナゴヤシアツタク', '内田町', 'ウチダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市熱田区大瀬子町', '23', '23109', '4560045', '愛知県', 'アイチケン', '名古屋市熱田区', 'ナゴヤシアツタク', '大瀬子町', 'オオセコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市熱田区木之免町', '23', '23109', '4560046', '愛知県', 'アイチケン', '名古屋市熱田区', 'ナゴヤシアツタク', '木之免町', 'キノメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市熱田区田中町', '23', '23109', '4560047', '愛知県', 'アイチケン', '名古屋市熱田区', 'ナゴヤシアツタク', '田中町', 'タナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市熱田区白鳥町', '23', '23109', '4560048', '愛知県', 'アイチケン', '名古屋市熱田区', 'ナゴヤシアツタク', '白鳥町', 'シロトリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市熱田区四番', '23', '23109', '4560051', '愛知県', 'アイチケン', '名古屋市熱田区', 'ナゴヤシアツタク', '四番', 'ヨンバン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市熱田区二番', '23', '23109', '4560052', '愛知県', 'アイチケン', '名古屋市熱田区', 'ナゴヤシアツタク', '二番', 'ニバン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市熱田区一番', '23', '23109', '4560053', '愛知県', 'アイチケン', '名古屋市熱田区', 'ナゴヤシアツタク', '一番', 'イチバン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市熱田区千年', '23', '23109', '4560054', '愛知県', 'アイチケン', '名古屋市熱田区', 'ナゴヤシアツタク', '千年', 'チトセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市熱田区南一番町', '23', '23109', '4560055', '愛知県', 'アイチケン', '名古屋市熱田区', 'ナゴヤシアツタク', '南一番町', 'ミナミイチバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市熱田区三番町', '23', '23109', '4560056', '愛知県', 'アイチケン', '名古屋市熱田区', 'ナゴヤシアツタク', '三番町', 'サンバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市熱田区五番町', '23', '23109', '4560057', '愛知県', 'アイチケン', '名古屋市熱田区', 'ナゴヤシアツタク', '五番町', 'ゴバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市熱田区六番', '23', '23109', '4560058', '愛知県', 'アイチケン', '名古屋市熱田区', 'ナゴヤシアツタク', '六番', 'ロクバン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市熱田区八番', '23', '23109', '4560059', '愛知県', 'アイチケン', '名古屋市熱田区', 'ナゴヤシアツタク', '八番', 'ハチバン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市熱田区西郊通', '23', '23109', '4560061', '愛知県', 'アイチケン', '名古屋市熱田区', 'ナゴヤシアツタク', '西郊通', 'サイコウトオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市熱田区大宝', '23', '23109', '4560062', '愛知県', 'アイチケン', '名古屋市熱田区', 'ナゴヤシアツタク', '大宝', 'タイホウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市熱田区西野町', '23', '23109', '4560063', '愛知県', 'アイチケン', '名古屋市熱田区', 'ナゴヤシアツタク', '西野町', 'ニシノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市熱田区古新町', '23', '23109', '4560064', '愛知県', 'アイチケン', '名古屋市熱田区', 'ナゴヤシアツタク', '古新町', 'コシンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市熱田区河田町', '23', '23109', '4560065', '愛知県', 'アイチケン', '名古屋市熱田区', 'ナゴヤシアツタク', '河田町', 'カワダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市熱田区野立町', '23', '23109', '4560066', '愛知県', 'アイチケン', '名古屋市熱田区', 'ナゴヤシアツタク', '野立町', 'ノダテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市熱田区中出町', '23', '23109', '4560067', '愛知県', 'アイチケン', '名古屋市熱田区', 'ナゴヤシアツタク', '中出町', 'ナカデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市熱田区神野町', '23', '23109', '4560068', '愛知県', 'アイチケン', '名古屋市熱田区', 'ナゴヤシアツタク', '神野町', 'ジンノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市熱田区中野新町', '23', '23109', '4560069', '愛知県', 'アイチケン', '名古屋市熱田区', 'ナゴヤシアツタク', '中野新町', 'ナカノシンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市熱田区明野町', '23', '23109', '4560071', '愛知県', 'アイチケン', '名古屋市熱田区', 'ナゴヤシアツタク', '明野町', 'アケノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市熱田区川並町', '23', '23109', '4560072', '愛知県', 'アイチケン', '名古屋市熱田区', 'ナゴヤシアツタク', '川並町', 'カワナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市熱田区千代田町', '23', '23109', '4560073', '愛知県', 'アイチケン', '名古屋市熱田区', 'ナゴヤシアツタク', '千代田町', 'チヨダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市熱田区比々野町', '23', '23109', '4560074', '愛知県', 'アイチケン', '名古屋市熱田区', 'ナゴヤシアツタク', '比々野町', 'ヒビノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市熱田区青池町', '23', '23109', '4560075', '愛知県', 'アイチケン', '名古屋市熱田区', 'ナゴヤシアツタク', '青池町', 'アオイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市熱田区切戸町', '23', '23109', '4560076', '愛知県', 'アイチケン', '名古屋市熱田区', 'ナゴヤシアツタク', '切戸町', 'キレトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市熱田区幡野町', '23', '23109', '4560077', '愛知県', 'アイチケン', '名古屋市熱田区', 'ナゴヤシアツタク', '幡野町', 'ハタノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市熱田区南八熊町', '23', '23109', '4560078', '愛知県', 'アイチケン', '名古屋市熱田区', 'ナゴヤシアツタク', '南八熊町', 'ミナミヤグマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区', '23', '23112', '4570000', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('44512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区平子', '23', '23112', '4570001', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '平子', 'ヒラコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区大堀町', '23', '23112', '4570002', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '大堀町', 'オオホリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区鶴田', '23', '23112', '4570003', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '鶴田', 'ツルタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区中江', '23', '23112', '4570004', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '中江', 'ナカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区桜台', '23', '23112', '4570005', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '桜台', 'サクラダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区鳥栖', '23', '23112', '4570006', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '鳥栖', 'トリス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区駈上', '23', '23112', '4570007', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '駈上', 'カケアゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区外山', '23', '23112', '4570008', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '外山', 'ソトヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区呼続元町', '23', '23112', '4570011', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '呼続元町', 'ヨビツギモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区菊住', '23', '23112', '4570012', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '菊住', 'キクスミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区寺崎町', '23', '23112', '4570013', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '寺崎町', 'テラサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区呼続', '23', '23112', '4570014', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '呼続', 'ヨビツギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区岩戸町', '23', '23112', '4570015', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '岩戸町', 'イワトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区汐田町', '23', '23112', '4570016', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '汐田町', 'シオダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区鶴里町', '23', '23112', '4570021', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '鶴里町', 'ツルサトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区明円町', '23', '23112', '4570022', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '明円町', 'ミョウエンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区芝町', '23', '23112', '4570023', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '芝町', 'シバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区赤坪町', '23', '23112', '4570024', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '赤坪町', 'アカツボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区白雲町', '23', '23112', '4570025', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '白雲町', 'ハクウンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区見晴町', '23', '23112', '4570026', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '見晴町', 'ミハラシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区弥生町', '23', '23112', '4570027', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '弥生町', 'ヤヨイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区楠町', '23', '23112', '4570028', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '楠町', 'クスノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区鯛取通', '23', '23112', '4570031', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '鯛取通', 'タイトリトオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区元桜田町', '23', '23112', '4570032', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '元桜田町', 'モトサクラダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区霞町', '23', '23112', '4570033', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '霞町', 'カスミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区春日野町', '23', '23112', '4570034', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '春日野町', 'カスガノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区貝塚町', '23', '23112', '4570035', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '貝塚町', 'カイヅカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区若草町', '23', '23112', '4570036', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '若草町', 'ワカクサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区扇田町', '23', '23112', '4570037', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '扇田町', 'オウギダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区桜本町', '23', '23112', '4570038', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '桜本町', 'サクラホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区西桜町', '23', '23112', '4570039', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '西桜町', 'ニシサクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区薬師通', '23', '23112', '4570041', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '薬師通', 'ヤクシドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区曽池町', '23', '23112', '4570042', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '曽池町', 'ソイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区戸部町', '23', '23112', '4570043', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '戸部町', 'トベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区柵下町', '23', '23112', '4570044', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '柵下町', 'サクシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区松城町', '23', '23112', '4570045', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '松城町', 'マツシロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区松池町', '23', '23112', '4570046', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '松池町', 'マツイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区城下町', '23', '23112', '4570047', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '城下町', 'シロシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区大磯通', '23', '23112', '4570048', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '大磯通', 'オオイソトオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区北内町', '23', '23112', '4570049', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '北内町', 'キタウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区笠寺町', '23', '23112', '4570051', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '笠寺町', 'カサデラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区粕畠町', '23', '23112', '4570052', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '粕畠町', 'カスバタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区本城町', '23', '23112', '4570053', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '本城町', 'ホンジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区砂口町', '23', '23112', '4570054', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '砂口町', 'スナクチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区星宮町', '23', '23112', '4570055', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '星宮町', 'ホシミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区本星崎町', '23', '23112', '4570056', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '本星崎町', 'モトホシザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区鳥山町', '23', '23112', '4570057', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '鳥山町', 'トリヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区前浜通', '23', '23112', '4570058', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '前浜通', 'マエハマドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区星崎町殿海道', '23', '23112', '4570061', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '星崎町', 'ホシザキチョウ', null, null, '殿海道', 'トノカイドウ');
INSERT INTO `ms_addresses` VALUES ('44561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区星崎町阿原', '23', '23112', '4570062', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '星崎町', 'ホシザキチョウ', null, null, '阿原', 'アハラ');
INSERT INTO `ms_addresses` VALUES ('44562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区阿原町', '23', '23112', '4570063', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '阿原町', 'アハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区星崎', '23', '23112', '4570064', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '星崎', 'ホシザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区元鳴尾町', '23', '23112', '4570065', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '元鳴尾町', 'モトナルオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区鳴尾', '23', '23112', '4570066', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '鳴尾', 'ナルオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区上浜町', '23', '23112', '4570067', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '上浜町', 'カミハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区南野', '23', '23112', '4570068', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '南野', 'ミナミノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区星園町', '23', '23112', '4570069', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '星園町', 'ホシゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区千竈通', '23', '23112', '4570071', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '千竈通', 'チカマトオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区寺部通', '23', '23112', '4570072', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '寺部通', 'テラベドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区西田町', '23', '23112', '4570073', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '西田町', 'ニシダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区本地通', '23', '23112', '4570074', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '本地通', 'ホンジドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区石元町', '23', '23112', '4570075', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '石元町', 'イシモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区道全町', '23', '23112', '4570076', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '道全町', 'ドウゼンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区立脇町', '23', '23112', '4570077', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '立脇町', 'タテワキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区塩屋町', '23', '23112', '4570078', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '塩屋町', 'シオヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区丹後通', '23', '23112', '4570801', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '丹後通', 'タンゴトオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区要町', '23', '23112', '4570802', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '要町', 'カナメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区天白町', '23', '23112', '4570803', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '天白町', 'テンパクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区源兵衛町', '23', '23112', '4570804', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '源兵衛町', 'ゲンベエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区三吉町', '23', '23112', '4570805', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '三吉町', 'ミヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区鳴浜町', '23', '23112', '4570806', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '鳴浜町', 'ナルハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区鶴見通', '23', '23112', '4570807', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '鶴見通', 'ツルミトオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区松下町', '23', '23112', '4570808', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '松下町', 'マツシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区大同町', '23', '23112', '4570811', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '大同町', 'ダイドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区星崎町', '23', '23112', '4570812', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '星崎町', 'ホシザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区鳴尾町丹後江', '23', '23112', '4570813', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '鳴尾町', 'ナルオチョウ', null, null, '丹後江', 'タンゴエ');
INSERT INTO `ms_addresses` VALUES ('44588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区柴田本通', '23', '23112', '4570814', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '柴田本通', 'シバタホンドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区柴田町', '23', '23112', '4570815', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '柴田町', 'シバタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区元柴田東町', '23', '23112', '4570816', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '元柴田東町', 'モトシバタヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区元柴田西町', '23', '23112', '4570817', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '元柴田西町', 'モトシバタニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区白水町', '23', '23112', '4570818', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '白水町', 'ハクスイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区滝春町', '23', '23112', '4570819', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '滝春町', 'タキハルチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区弥次ヱ町', '23', '23112', '4570821', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '弥次ヱ町', 'ヤジエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区浜田町', '23', '23112', '4570822', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '浜田町', 'ハマダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区元塩町', '23', '23112', '4570823', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '元塩町', 'モトシオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区神松町', '23', '23112', '4570824', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '神松町', 'カミマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区堤起町', '23', '23112', '4570825', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '堤起町', 'ツツミオコシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区中割町', '23', '23112', '4570826', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '中割町', 'ナカワリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区北頭町', '23', '23112', '4570827', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '北頭町', 'キタガシラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区宝生町', '23', '23112', '4570828', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '宝生町', 'ホウショウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区荒浜町', '23', '23112', '4570831', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '荒浜町', 'アラハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区浜中町', '23', '23112', '4570832', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '浜中町', 'ハマナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区東又兵ヱ町', '23', '23112', '4570833', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '東又兵ヱ町', 'ヒガシマタベエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区港東通', '23', '23112', '4570834', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '港東通', 'コウトウドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区西又兵ヱ町', '23', '23112', '4570835', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '西又兵ヱ町', 'ニシマタベエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区加福本通', '23', '23112', '4570836', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '加福本通', 'カフクホントオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区加福町', '23', '23112', '4570837', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '加福町', 'カフクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区豊田', '23', '23112', '4570841', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '豊田', 'トヨダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区戸部下', '23', '23112', '4570842', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '戸部下', 'トベシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区忠次', '23', '23112', '4570843', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '忠次', 'チュウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区堤町', '23', '23112', '4570844', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '堤町', 'ツツミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区観音町', '23', '23112', '4570845', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '観音町', 'カンノンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区道徳通', '23', '23112', '4570846', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '道徳通', 'ドウトクトオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区道徳新町', '23', '23112', '4570847', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '道徳新町', 'ドウトクシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区五条町', '23', '23112', '4570851', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '五条町', 'ゴジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区泉楽通', '23', '23112', '4570852', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '泉楽通', 'センラクトオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区六条町', '23', '23112', '4570853', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '六条町', 'ロクジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区七条町', '23', '23112', '4570854', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '七条町', 'シチジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区豊田町', '23', '23112', '4570855', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '豊田町', 'トヨダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区南陽通', '23', '23112', '4570856', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '南陽通', 'ナンヨウドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区明治', '23', '23112', '4570861', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '明治', 'メイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区内田橋', '23', '23112', '4570862', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '内田橋', 'ウチダバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区豊', '23', '23112', '4570863', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '豊', 'ユタカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区道徳北町', '23', '23112', '4570864', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '道徳北町', 'ドウトクキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区氷室町', '23', '23112', '4570865', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '氷室町', 'ヒムロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市南区三条', '23', '23112', '4570866', '愛知県', 'アイチケン', '名古屋市南区', 'ナゴヤシミナミク', '三条', 'サンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市緑区', '23', '23114', '4580000', '愛知県', 'アイチケン', '名古屋市緑区', 'ナゴヤシミドリク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('44657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市緑区梅里', '23', '23114', '4580001', '愛知県', 'アイチケン', '名古屋市緑区', 'ナゴヤシミドリク', '梅里', 'ウメサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市緑区桃山', '23', '23114', '4580002', '愛知県', 'アイチケン', '名古屋市緑区', 'ナゴヤシミドリク', '桃山', 'モモヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市緑区黒沢台', '23', '23114', '4580003', '愛知県', 'アイチケン', '名古屋市緑区', 'ナゴヤシミドリク', '黒沢台', 'クロサワダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市緑区乗鞍', '23', '23114', '4580004', '愛知県', 'アイチケン', '名古屋市緑区', 'ナゴヤシミドリク', '乗鞍', 'ノリクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市緑区鳴丘', '23', '23114', '4580005', '愛知県', 'アイチケン', '名古屋市緑区', 'ナゴヤシミドリク', '鳴丘', 'ナルオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市緑区細口', '23', '23114', '4580006', '愛知県', 'アイチケン', '名古屋市緑区', 'ナゴヤシミドリク', '細口', 'ホソグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市緑区篭山', '23', '23114', '4580007', '愛知県', 'アイチケン', '名古屋市緑区', 'ナゴヤシミドリク', '篭山', 'カゴヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市緑区平手北', '23', '23114', '4580008', '愛知県', 'アイチケン', '名古屋市緑区', 'ナゴヤシミドリク', '平手北', 'ヒラテキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市緑区平手南', '23', '23114', '4580009', '愛知県', 'アイチケン', '名古屋市緑区', 'ナゴヤシミドリク', '平手南', 'ヒラテミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市緑区相川', '23', '23114', '4580011', '愛知県', 'アイチケン', '名古屋市緑区', 'ナゴヤシミドリク', '相川', 'アイカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市緑区久方', '23', '23114', '4580012', '愛知県', 'アイチケン', '名古屋市緑区', 'ナゴヤシミドリク', '久方', 'ヒサカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市緑区ほら貝', '23', '23114', '4580013', '愛知県', 'アイチケン', '名古屋市緑区', 'ナゴヤシミドリク', 'ほら貝', 'ホラガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市緑区神沢', '23', '23114', '4580014', '愛知県', 'アイチケン', '名古屋市緑区', 'ナゴヤシミドリク', '神沢', 'カミサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市緑区篠の風', '23', '23114', '4580015', '愛知県', 'アイチケン', '名古屋市緑区', 'ナゴヤシミドリク', '篠の風', 'シノノカゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市緑区上旭', '23', '23114', '4580016', '愛知県', 'アイチケン', '名古屋市緑区', 'ナゴヤシミドリク', '上旭', 'カミアサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市緑区滝ノ水', '23', '23114', '4580021', '愛知県', 'アイチケン', '名古屋市緑区', 'ナゴヤシミドリク', '滝ノ水', 'タキノミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市緑区小坂', '23', '23114', '4580022', '愛知県', 'アイチケン', '名古屋市緑区', 'ナゴヤシミドリク', '小坂', 'コサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市緑区鴻仏目', '23', '23114', '4580023', '愛知県', 'アイチケン', '名古屋市緑区', 'ナゴヤシミドリク', '鴻仏目', 'コウブツメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市緑区尾崎山', '23', '23114', '4580024', '愛知県', 'アイチケン', '名古屋市緑区', 'ナゴヤシミドリク', '尾崎山', 'オザキヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市緑区鳥澄', '23', '23114', '4580025', '愛知県', 'アイチケン', '名古屋市緑区', 'ナゴヤシミドリク', '鳥澄', 'トリスミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市緑区旭出', '23', '23114', '4580031', '愛知県', 'アイチケン', '名古屋市緑区', 'ナゴヤシミドリク', '旭出', 'アサヒデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市緑区大形山', '23', '23114', '4580032', '愛知県', 'アイチケン', '名古屋市緑区', 'ナゴヤシミドリク', '大形山', 'オオガタヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市緑区相原郷', '23', '23114', '4580033', '愛知県', 'アイチケン', '名古屋市緑区', 'ナゴヤシミドリク', '相原郷', 'アイバラゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市緑区若田', '23', '23114', '4580034', '愛知県', 'アイチケン', '名古屋市緑区', 'ナゴヤシミドリク', '若田', 'ワカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市緑区曽根', '23', '23114', '4580035', '愛知県', 'アイチケン', '名古屋市緑区', 'ナゴヤシミドリク', '曽根', 'ソネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市緑区六田', '23', '23114', '4580036', '愛知県', 'アイチケン', '名古屋市緑区', 'ナゴヤシミドリク', '六田', 'ロクデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市緑区潮見が丘', '23', '23114', '4580037', '愛知県', 'アイチケン', '名古屋市緑区', 'ナゴヤシミドリク', '潮見が丘', 'シオミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市緑区作の山町', '23', '23114', '4580038', '愛知県', 'アイチケン', '名古屋市緑区', 'ナゴヤシミドリク', '作の山町', 'サクノヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市緑区四本木', '23', '23114', '4580039', '愛知県', 'アイチケン', '名古屋市緑区', 'ナゴヤシミドリク', '四本木', 'シホンギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市緑区鳴子町', '23', '23114', '4580041', '愛知県', 'アイチケン', '名古屋市緑区', 'ナゴヤシミドリク', '鳴子町', 'ナルコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市緑区高根台', '23', '23114', '4580042', '愛知県', 'アイチケン', '名古屋市緑区', 'ナゴヤシミドリク', '高根台', 'タカネダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市緑区万場山', '23', '23114', '4580043', '愛知県', 'アイチケン', '名古屋市緑区', 'ナゴヤシミドリク', '万場山', 'マンバヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市緑区池上台', '23', '23114', '4580044', '愛知県', 'アイチケン', '名古屋市緑区', 'ナゴヤシミドリク', '池上台', 'イケガミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市緑区鹿山', '23', '23114', '4580045', '愛知県', 'アイチケン', '名古屋市緑区', 'ナゴヤシミドリク', '鹿山', 'シカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市緑区長根町', '23', '23114', '4580046', '愛知県', 'アイチケン', '名古屋市緑区', 'ナゴヤシミドリク', '長根町', 'ナガネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市緑区古鳴海', '23', '23114', '4580047', '愛知県', 'アイチケン', '名古屋市緑区', 'ナゴヤシミドリク', '古鳴海', 'コナルミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市緑区鳴海町', '23', '23114', '4580801', '愛知県', 'アイチケン', '名古屋市緑区', 'ナゴヤシミドリク', '鳴海町', 'ナルミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市緑区兵庫', '23', '23114', '4580802', '愛知県', 'アイチケン', '名古屋市緑区', 'ナゴヤシミドリク', '兵庫', 'ヒョウゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市緑区鏡田', '23', '23114', '4580803', '愛知県', 'アイチケン', '名古屋市緑区', 'ナゴヤシミドリク', '鏡田', 'カガミダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市緑区亀が洞', '23', '23114', '4580804', '愛知県', 'アイチケン', '名古屋市緑区', 'ナゴヤシミドリク', '亀が洞', 'カメガホラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市緑区大清水', '23', '23114', '4580805', '愛知県', 'アイチケン', '名古屋市緑区', 'ナゴヤシミドリク', '大清水', 'オオシミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市緑区大清水西', '23', '23114', '4580806', '愛知県', 'アイチケン', '名古屋市緑区', 'ナゴヤシミドリク', '大清水西', 'オオシミズニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市緑区砂田', '23', '23114', '4580807', '愛知県', 'アイチケン', '名古屋市緑区', 'ナゴヤシミドリク', '砂田', 'スナダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市緑区東神の倉', '23', '23114', '4580808', '愛知県', 'アイチケン', '名古屋市緑区', 'ナゴヤシミドリク', '東神の倉', 'ヒガシカミノクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市緑区西神の倉', '23', '23114', '4580809', '愛知県', 'アイチケン', '名古屋市緑区', 'ナゴヤシミドリク', '西神の倉', 'ニシカミノクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市緑区八つ松', '23', '23114', '4580810', '愛知県', 'アイチケン', '名古屋市緑区', 'ナゴヤシミドリク', '八つ松', 'ヤツマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市緑区鳴海町神ノ倉', '23', '23114', '4580811', '愛知県', 'アイチケン', '名古屋市緑区', 'ナゴヤシミドリク', '鳴海町', 'ナルミチョウ', null, null, '神ノ倉', 'カンノクラ');
INSERT INTO `ms_addresses` VALUES ('44704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市緑区神の倉', '23', '23114', '4580812', '愛知県', 'アイチケン', '名古屋市緑区', 'ナゴヤシミドリク', '神の倉', 'カミノクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市緑区藤塚', '23', '23114', '4580813', '愛知県', 'アイチケン', '名古屋市緑区', 'ナゴヤシミドリク', '藤塚', 'フジヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市緑区鶴が沢', '23', '23114', '4580814', '愛知県', 'アイチケン', '名古屋市緑区', 'ナゴヤシミドリク', '鶴が沢', 'ツルガサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市緑区徳重', '23', '23114', '4580815', '愛知県', 'アイチケン', '名古屋市緑区', 'ナゴヤシミドリク', '徳重', 'トクシゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市緑区横吹町', '23', '23114', '4580816', '愛知県', 'アイチケン', '名古屋市緑区', 'ナゴヤシミドリク', '横吹町', 'ヨコブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市緑区鳴海町諸の木', '23', '23114', '4580817', '愛知県', 'アイチケン', '名古屋市緑区', 'ナゴヤシミドリク', '鳴海町', 'ナルミチョウ', null, null, '諸の木', 'モロノキ');
INSERT INTO `ms_addresses` VALUES ('44710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市緑区諸の木', '23', '23114', '4580817', '愛知県', 'アイチケン', '名古屋市緑区', 'ナゴヤシミドリク', '諸の木', 'モロノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市緑区鳴海町大清水', '23', '23114', '4580818', '愛知県', 'アイチケン', '名古屋市緑区', 'ナゴヤシミドリク', '鳴海町', 'ナルミチョウ', null, null, '大清水', 'オオシミズ');
INSERT INTO `ms_addresses` VALUES ('44712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市緑区鳴海町八ツ松', '23', '23114', '4580819', '愛知県', 'アイチケン', '名古屋市緑区', 'ナゴヤシミドリク', '鳴海町', 'ナルミチョウ', null, null, '八ツ松', 'ヤツマツ');
INSERT INTO `ms_addresses` VALUES ('44713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市緑区境松', '23', '23114', '4580820', '愛知県', 'アイチケン', '名古屋市緑区', 'ナゴヤシミドリク', '境松', 'サカイマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市緑区鳴海町尾崎山', '23', '23114', '4580821', '愛知県', 'アイチケン', '名古屋市緑区', 'ナゴヤシミドリク', '鳴海町', 'ナルミチョウ', null, null, '尾崎山', 'オザキヤマ');
INSERT INTO `ms_addresses` VALUES ('44715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市緑区大将ケ根', '23', '23114', '4580822', '愛知県', 'アイチケン', '名古屋市緑区', 'ナゴヤシミドリク', '大将ケ根', 'タイショウガネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市緑区太子', '23', '23114', '4580823', '愛知県', 'アイチケン', '名古屋市緑区', 'ナゴヤシミドリク', '太子', 'タイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市緑区鳴海町有松裏', '23', '23114', '4580824', '愛知県', 'アイチケン', '名古屋市緑区', 'ナゴヤシミドリク', '鳴海町', 'ナルミチョウ', null, null, '有松裏', 'アリマツウラ');
INSERT INTO `ms_addresses` VALUES ('44718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市緑区左京山', '23', '23114', '4580825', '愛知県', 'アイチケン', '名古屋市緑区', 'ナゴヤシミドリク', '左京山', 'サキョウヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市緑区平子が丘', '23', '23114', '4580826', '愛知県', 'アイチケン', '名古屋市緑区', 'ナゴヤシミドリク', '平子が丘', 'ヒラコガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市緑区鳴海町細根', '23', '23114', '4580827', '愛知県', 'アイチケン', '名古屋市緑区', 'ナゴヤシミドリク', '鳴海町', 'ナルミチョウ', null, null, '細根', 'ホソネ');
INSERT INTO `ms_addresses` VALUES ('44721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市緑区鳴海町姥子山', '23', '23114', '4580828', '愛知県', 'アイチケン', '名古屋市緑区', 'ナゴヤシミドリク', '鳴海町', 'ナルミチョウ', null, null, '姥子山', 'ウバコヤマ');
INSERT INTO `ms_addresses` VALUES ('44722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市緑区鎌倉台', '23', '23114', '4580829', '愛知県', 'アイチケン', '名古屋市緑区', 'ナゴヤシミドリク', '鎌倉台', 'カマクラダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市緑区姥子山', '23', '23114', '4580830', '愛知県', 'アイチケン', '名古屋市緑区', 'ナゴヤシミドリク', '姥子山', 'ウバコヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市緑区鳴海町向田', '23', '23114', '4580831', '愛知県', 'アイチケン', '名古屋市緑区', 'ナゴヤシミドリク', '鳴海町', 'ナルミチョウ', null, null, '向田', 'ムカエダ');
INSERT INTO `ms_addresses` VALUES ('44725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市緑区漆山', '23', '23114', '4580832', '愛知県', 'アイチケン', '名古屋市緑区', 'ナゴヤシミドリク', '漆山', 'ウルシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市緑区青山', '23', '23114', '4580833', '愛知県', 'アイチケン', '名古屋市緑区', 'ナゴヤシミドリク', '青山', 'アオヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市緑区鳴海町前之輪', '23', '23114', '4580834', '愛知県', 'アイチケン', '名古屋市緑区', 'ナゴヤシミドリク', '鳴海町', 'ナルミチョウ', null, null, '前之輪', 'ゼンノワ');
INSERT INTO `ms_addresses` VALUES ('44728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市緑区鳴海町上汐田', '23', '23114', '4580835', '愛知県', 'アイチケン', '名古屋市緑区', 'ナゴヤシミドリク', '鳴海町', 'ナルミチョウ', null, null, '上汐田', 'カミシオタ');
INSERT INTO `ms_addresses` VALUES ('44729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市緑区白土', '23', '23114', '4580836', '愛知県', 'アイチケン', '名古屋市緑区', 'ナゴヤシミドリク', '白土', 'シロツチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市緑区赤松', '23', '23114', '4580837', '愛知県', 'アイチケン', '名古屋市緑区', 'ナゴヤシミドリク', '赤松', 'アカマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市緑区鳴海町小森', '23', '23114', '4580841', '愛知県', 'アイチケン', '名古屋市緑区', 'ナゴヤシミドリク', '鳴海町', 'ナルミチョウ', null, null, '小森', 'コモリ');
INSERT INTO `ms_addresses` VALUES ('44732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市緑区鳴海町上ノ山', '23', '23114', '4580842', '愛知県', 'アイチケン', '名古屋市緑区', 'ナゴヤシミドリク', '鳴海町', 'ナルミチョウ', null, null, '上ノ山', 'ウエノヤマ');
INSERT INTO `ms_addresses` VALUES ('44733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市緑区松が根台', '23', '23114', '4580843', '愛知県', 'アイチケン', '名古屋市緑区', 'ナゴヤシミドリク', '松が根台', 'マツガネダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市緑区鳴海町伝治山', '23', '23114', '4580844', '愛知県', 'アイチケン', '名古屋市緑区', 'ナゴヤシミドリク', '鳴海町', 'ナルミチョウ', null, null, '伝治山', 'デンジヤマ');
INSERT INTO `ms_addresses` VALUES ('44735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市緑区鳴海町赤塚', '23', '23114', '4580845', '愛知県', 'アイチケン', '名古屋市緑区', 'ナゴヤシミドリク', '鳴海町', 'ナルミチョウ', null, null, '赤塚', 'アカツカ');
INSERT INTO `ms_addresses` VALUES ('44736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市緑区鳴海町薬師山', '23', '23114', '4580846', '愛知県', 'アイチケン', '名古屋市緑区', 'ナゴヤシミドリク', '鳴海町', 'ナルミチョウ', null, null, '薬師山', 'ヤクシヤマ');
INSERT INTO `ms_addresses` VALUES ('44737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市緑区浦里', '23', '23114', '4580847', '愛知県', 'アイチケン', '名古屋市緑区', 'ナゴヤシミドリク', '浦里', 'ウラサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市緑区有松町有松', '23', '23114', '4580901', '愛知県', 'アイチケン', '名古屋市緑区', 'ナゴヤシミドリク', '有松町有松', 'アリマツチョウアリマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市緑区有松三丁山', '23', '23114', '4580902', '愛知県', 'アイチケン', '名古屋市緑区', 'ナゴヤシミドリク', '有松三丁山', 'アリマツサンチョウヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市緑区有松愛宕', '23', '23114', '4580903', '愛知県', 'アイチケン', '名古屋市緑区', 'ナゴヤシミドリク', '有松愛宕', 'アリマツアタゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市緑区有松町桶狭間', '23', '23114', '4580911', '愛知県', 'アイチケン', '名古屋市緑区', 'ナゴヤシミドリク', '有松町桶狭間', 'アリマツチョウオケハザマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市緑区有松町桶狭間生山', '23', '23114', '4580912', '愛知県', 'アイチケン', '名古屋市緑区', 'ナゴヤシミドリク', '有松町桶狭間', 'アリマツチョウオケハザマ', null, null, '生山', 'ハエヤマ');
INSERT INTO `ms_addresses` VALUES ('44743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市緑区桶狭間北', '23', '23114', '4580913', '愛知県', 'アイチケン', '名古屋市緑区', 'ナゴヤシミドリク', '桶狭間北', 'オケハザマキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市緑区有松町桶狭間平坪', '23', '23114', '4580914', '愛知県', 'アイチケン', '名古屋市緑区', 'ナゴヤシミドリク', '有松町桶狭間', 'アリマツチョウオケハザマ', null, null, '平坪', 'ヒラツボ');
INSERT INTO `ms_addresses` VALUES ('44745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市緑区野末町', '23', '23114', '4580915', '愛知県', 'アイチケン', '名古屋市緑区', 'ナゴヤシミドリク', '野末町', 'ノズエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市緑区有松町桶狭間愛宕西', '23', '23114', '4580916', '愛知県', 'アイチケン', '名古屋市緑区', 'ナゴヤシミドリク', '有松町桶狭間', 'アリマツチョウオケハザマ', null, null, '愛宕西', 'アタゴニシ');
INSERT INTO `ms_addresses` VALUES ('44747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市緑区武路町', '23', '23114', '4580917', '愛知県', 'アイチケン', '名古屋市緑区', 'ナゴヤシミドリク', '武路町', 'タケジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市緑区大高町', '23', '23114', '4598001', '愛知県', 'アイチケン', '名古屋市緑区', 'ナゴヤシミドリク', '大高町', 'オオダカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市緑区森の里', '23', '23114', '4598002', '愛知県', 'アイチケン', '名古屋市緑区', 'ナゴヤシミドリク', '森の里', 'モリノサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市緑区大高台', '23', '23114', '4598003', '愛知県', 'アイチケン', '名古屋市緑区', 'ナゴヤシミドリク', '大高台', 'オオダカダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市緑区有松南', '23', '23114', '4598004', '愛知県', 'アイチケン', '名古屋市緑区', 'ナゴヤシミドリク', '有松南', 'アリマツミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市緑区緑花台', '23', '23114', '4598005', '愛知県', 'アイチケン', '名古屋市緑区', 'ナゴヤシミドリク', '緑花台', 'リョッカダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市緑区倉坂', '23', '23114', '4598006', '愛知県', 'アイチケン', '名古屋市緑区', 'ナゴヤシミドリク', '倉坂', 'クラサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市緑区大根山', '23', '23114', '4598007', '愛知県', 'アイチケン', '名古屋市緑区', 'ナゴヤシミドリク', '大根山', 'オオネヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道余市郡余市町', '01', '01408', '0460000', '北海道', 'ホッカイドウ', '余市郡余市町', 'ヨイチグンヨイチチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('44776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中区', '23', '23106', '4600000', '愛知県', 'アイチケン', '名古屋市中区', 'ナゴヤシナカク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('44777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中区三の丸', '23', '23106', '4600001', '愛知県', 'アイチケン', '名古屋市中区', 'ナゴヤシナカク', '三の丸', 'サンノマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中区丸の内', '23', '23106', '4600002', '愛知県', 'アイチケン', '名古屋市中区', 'ナゴヤシナカク', '丸の内', 'マルノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中区錦', '23', '23106', '4600003', '愛知県', 'アイチケン', '名古屋市中区', 'ナゴヤシナカク', '錦', 'ニシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中区新栄町', '23', '23106', '4600004', '愛知県', 'アイチケン', '名古屋市中区', 'ナゴヤシナカク', '新栄町', 'シンサカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中区東桜', '23', '23106', '4600005', '愛知県', 'アイチケン', '名古屋市中区', 'ナゴヤシナカク', '東桜', 'ヒガシサクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中区葵', '23', '23106', '4600006', '愛知県', 'アイチケン', '名古屋市中区', 'ナゴヤシナカク', '葵', 'アオイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中区新栄', '23', '23106', '4600007', '愛知県', 'アイチケン', '名古屋市中区', 'ナゴヤシナカク', '新栄', 'シンサカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中区栄', '23', '23106', '4600008', '愛知県', 'アイチケン', '名古屋市中区', 'ナゴヤシナカク', '栄', 'サカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道余市郡余市町栄町', '01', '01408', '0460001', '北海道', 'ホッカイドウ', '余市郡余市町', 'ヨイチグンヨイチチョウ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中区大須', '23', '23106', '4600011', '愛知県', 'アイチケン', '名古屋市中区', 'ナゴヤシナカク', '大須', 'オオス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中区千代田', '23', '23106', '4600012', '愛知県', 'アイチケン', '名古屋市中区', 'ナゴヤシナカク', '千代田', 'チヨダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中区上前津', '23', '23106', '4600013', '愛知県', 'アイチケン', '名古屋市中区', 'ナゴヤシナカク', '上前津', 'カミマエヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中区富士見町', '23', '23106', '4600014', '愛知県', 'アイチケン', '名古屋市中区', 'ナゴヤシナカク', '富士見町', 'フジミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中区大井町', '23', '23106', '4600015', '愛知県', 'アイチケン', '名古屋市中区', 'ナゴヤシナカク', '大井町', 'オオイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中区橘', '23', '23106', '4600016', '愛知県', 'アイチケン', '名古屋市中区', 'ナゴヤシナカク', '橘', 'タチバナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中区松原', '23', '23106', '4600017', '愛知県', 'アイチケン', '名古屋市中区', 'ナゴヤシナカク', '松原', 'マツバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中区門前町', '23', '23106', '4600018', '愛知県', 'アイチケン', '名古屋市中区', 'ナゴヤシナカク', '門前町', 'モンゼンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道余市郡余市町登町', '01', '01408', '0460002', '北海道', 'ホッカイドウ', '余市郡余市町', 'ヨイチグンヨイチチョウ', '登町', 'ノボリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中区平和', '23', '23106', '4600021', '愛知県', 'アイチケン', '名古屋市中区', 'ナゴヤシナカク', '平和', 'ヘイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中区金山', '23', '23106', '4600022', '愛知県', 'アイチケン', '名古屋市中区', 'ナゴヤシナカク', '金山', 'カナヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中区金山町', '23', '23106', '4600023', '愛知県', 'アイチケン', '名古屋市中区', 'ナゴヤシナカク', '金山町', 'カナヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中区正木', '23', '23106', '4600024', '愛知県', 'アイチケン', '名古屋市中区', 'ナゴヤシナカク', '正木', 'マサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中区古渡町', '23', '23106', '4600025', '愛知県', 'アイチケン', '名古屋市中区', 'ナゴヤシナカク', '古渡町', 'フルワタリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中区伊勢山', '23', '23106', '4600026', '愛知県', 'アイチケン', '名古屋市中区', 'ナゴヤシナカク', '伊勢山', 'イセヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道余市郡余市町黒川町', '01', '01408', '0460003', '北海道', 'ホッカイドウ', '余市郡余市町', 'ヨイチグンヨイチチョウ', '黒川町', 'クロカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中区本丸', '23', '23106', '4600031', '愛知県', 'アイチケン', '名古屋市中区', 'ナゴヤシナカク', '本丸', 'ホンマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市中区二の丸', '23', '23106', '4600032', '愛知県', 'アイチケン', '名古屋市中区', 'ナゴヤシナカク', '二の丸', 'ニノマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道余市郡余市町大川町', '01', '01408', '0460004', '北海道', 'ホッカイドウ', '余市郡余市町', 'ヨイチグンヨイチチョウ', '大川町', 'オオカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道余市郡余市町入舟町', '01', '01408', '0460011', '北海道', 'ホッカイドウ', '余市郡余市町', 'ヨイチグンヨイチチョウ', '入舟町', 'イリフネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道余市郡余市町山田町', '01', '01408', '0460012', '北海道', 'ホッカイドウ', '余市郡余市町', 'ヨイチグンヨイチチョウ', '山田町', 'ヤマダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道余市郡余市町豊丘町', '01', '01408', '0460013', '北海道', 'ホッカイドウ', '余市郡余市町', 'ヨイチグンヨイチチョウ', '豊丘町', 'トヨオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道余市郡余市町美園町', '01', '01408', '0460014', '北海道', 'ホッカイドウ', '余市郡余市町', 'ヨイチグンヨイチチョウ', '美園町', 'ミソノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道余市郡余市町朝日町', '01', '01408', '0460015', '北海道', 'ホッカイドウ', '余市郡余市町', 'ヨイチグンヨイチチョウ', '朝日町', 'アサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道余市郡余市町浜中町', '01', '01408', '0460021', '北海道', 'ホッカイドウ', '余市郡余市町', 'ヨイチグンヨイチチョウ', '浜中町', 'ハマナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道余市郡余市町沢町', '01', '01408', '0460022', '北海道', 'ホッカイドウ', '余市郡余市町', 'ヨイチグンヨイチチョウ', '沢町', 'サワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道余市郡余市町梅川町', '01', '01408', '0460023', '北海道', 'ホッカイドウ', '余市郡余市町', 'ヨイチグンヨイチチョウ', '梅川町', 'ウメカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道余市郡余市町港町', '01', '01408', '0460024', '北海道', 'ホッカイドウ', '余市郡余市町', 'ヨイチグンヨイチチョウ', '港町', 'ミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道余市郡余市町富沢町', '01', '01408', '0460025', '北海道', 'ホッカイドウ', '余市郡余市町', 'ヨイチグンヨイチチョウ', '富沢町', 'トミサワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道余市郡余市町白岩町', '01', '01408', '0460031', '北海道', 'ホッカイドウ', '余市郡余市町', 'ヨイチグンヨイチチョウ', '白岩町', 'シロイワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道余市郡余市町豊浜町', '01', '01408', '0460032', '北海道', 'ホッカイドウ', '余市郡余市町', 'ヨイチグンヨイチチョウ', '豊浜町', 'トヨハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道余市郡余市町潮見町', '01', '01408', '0460033', '北海道', 'ホッカイドウ', '余市郡余市町', 'ヨイチグンヨイチチョウ', '潮見町', 'シオミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道古平郡古平町', '01', '01406', '0460100', '北海道', 'ホッカイドウ', '古平郡古平町', 'フルビラグンフルビラチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('44819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道古平郡古平町御崎町', '01', '01406', '0460101', '北海道', 'ホッカイドウ', '古平郡古平町', 'フルビラグンフルビラチョウ', '御崎町', 'ミサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道古平郡古平町丸山町', '01', '01406', '0460102', '北海道', 'ホッカイドウ', '古平郡古平町', 'フルビラグンフルビラチョウ', '丸山町', 'マルヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道古平郡古平町本町', '01', '01406', '0460103', '北海道', 'ホッカイドウ', '古平郡古平町', 'フルビラグンフルビラチョウ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道古平郡古平町入船町', '01', '01406', '0460104', '北海道', 'ホッカイドウ', '古平郡古平町', 'フルビラグンフルビラチョウ', '入船町', 'イリフネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道古平郡古平町群来町', '01', '01406', '0460111', '北海道', 'ホッカイドウ', '古平郡古平町', 'フルビラグンフルビラチョウ', '群来町', 'クキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道古平郡古平町新地町', '01', '01406', '0460112', '北海道', 'ホッカイドウ', '古平郡古平町', 'フルビラグンフルビラチョウ', '新地町', 'シンチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道古平郡古平町港町', '01', '01406', '0460113', '北海道', 'ホッカイドウ', '古平郡古平町', 'フルビラグンフルビラチョウ', '港町', 'ミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道古平郡古平町浜町', '01', '01406', '0460121', '北海道', 'ホッカイドウ', '古平郡古平町', 'フルビラグンフルビラチョウ', '浜町', 'ハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道古平郡古平町沢江町', '01', '01406', '0460131', '北海道', 'ホッカイドウ', '古平郡古平町', 'フルビラグンフルビラチョウ', '沢江町', 'サワエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道古平郡古平町歌棄町', '01', '01406', '0460132', '北海道', 'ホッカイドウ', '古平郡古平町', 'フルビラグンフルビラチョウ', '歌棄町', 'ウタスツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道古平郡古平町沖町', '01', '01406', '0460133', '北海道', 'ホッカイドウ', '古平郡古平町', 'フルビラグンフルビラチョウ', '沖町', 'オキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道積丹郡積丹町', '01', '01405', '0460200', '北海道', 'ホッカイドウ', '積丹郡積丹町', 'シャコタングンシャコタンチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('44833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道積丹郡積丹町美国町', '01', '01405', '0460201', '北海道', 'ホッカイドウ', '積丹郡積丹町', 'シャコタングンシャコタンチョウ', '美国町', 'ビクニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道積丹郡積丹町婦美町', '01', '01405', '0460202', '北海道', 'ホッカイドウ', '積丹郡積丹町', 'シャコタングンシャコタンチョウ', '婦美町', 'フミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道積丹郡積丹町神岬町', '01', '01405', '0460321', '北海道', 'ホッカイドウ', '積丹郡積丹町', 'シャコタングンシャコタンチョウ', '神岬町', 'コウザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道積丹郡積丹町余別町', '01', '01405', '0460322', '北海道', 'ホッカイドウ', '積丹郡積丹町', 'シャコタングンシャコタンチョウ', '余別町', 'ヨベツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道積丹郡積丹町来岸町', '01', '01405', '0460323', '北海道', 'ホッカイドウ', '積丹郡積丹町', 'シャコタングンシャコタンチョウ', '来岸町', 'ライキシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道積丹郡積丹町西河町', '01', '01405', '0460324', '北海道', 'ホッカイドウ', '積丹郡積丹町', 'シャコタングンシャコタンチョウ', '西河町', 'ニシカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道積丹郡積丹町野塚町', '01', '01405', '0460325', '北海道', 'ホッカイドウ', '積丹郡積丹町', 'シャコタングンシャコタンチョウ', '野塚町', 'ノヅカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道積丹郡積丹町日司町', '01', '01405', '0460326', '北海道', 'ホッカイドウ', '積丹郡積丹町', 'シャコタングンシャコタンチョウ', '日司町', 'ヒヅカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道積丹郡積丹町入舸町', '01', '01405', '0460327', '北海道', 'ホッカイドウ', '積丹郡積丹町', 'シャコタングンシャコタンチョウ', '入舸町', 'イリカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道積丹郡積丹町幌武意町', '01', '01405', '0460328', '北海道', 'ホッカイドウ', '積丹郡積丹町', 'シャコタングンシャコタンチョウ', '幌武意町', 'ホロムイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道余市郡赤井川村', '01', '01409', '0460500', '北海道', 'ホッカイドウ', '余市郡赤井川村', 'ヨイチグンアカイガワムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('44845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道余市郡赤井川村赤井川', '01', '01409', '0460501', '北海道', 'ホッカイドウ', '余市郡赤井川村', 'ヨイチグンアカイガワムラ', '赤井川', 'アカイガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道余市郡赤井川村日ノ出', '01', '01409', '0460511', '北海道', 'ホッカイドウ', '余市郡赤井川村', 'ヨイチグンアカイガワムラ', '日ノ出', 'ヒノデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道余市郡赤井川村山梨', '01', '01409', '0460512', '北海道', 'ホッカイドウ', '余市郡赤井川村', 'ヨイチグンアカイガワムラ', '山梨', 'ヤマナシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道余市郡赤井川村池田', '01', '01409', '0460521', '北海道', 'ホッカイドウ', '余市郡赤井川村', 'ヨイチグンアカイガワムラ', '池田', 'イケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道余市郡赤井川村旭丘', '01', '01409', '0460531', '北海道', 'ホッカイドウ', '余市郡赤井川村', 'ヨイチグンアカイガワムラ', '旭丘', 'アサヒオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道余市郡赤井川村富田', '01', '01409', '0460532', '北海道', 'ホッカイドウ', '余市郡赤井川村', 'ヨイチグンアカイガワムラ', '富田', 'トミタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道余市郡赤井川村都', '01', '01409', '0460541', '北海道', 'ホッカイドウ', '余市郡赤井川村', 'ヨイチグンアカイガワムラ', '都', 'ミヤコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道余市郡赤井川村曲川', '01', '01409', '0460542', '北海道', 'ホッカイドウ', '余市郡赤井川村', 'ヨイチグンアカイガワムラ', '曲川', 'マガリカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道余市郡赤井川村轟', '01', '01409', '0460551', '北海道', 'ホッカイドウ', '余市郡赤井川村', 'ヨイチグンアカイガワムラ', '轟', 'トドロキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道余市郡赤井川村明治', '01', '01409', '0460552', '北海道', 'ホッカイドウ', '余市郡赤井川村', 'ヨイチグンアカイガワムラ', '明治', 'メイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道余市郡赤井川村落合', '01', '01409', '0460561', '北海道', 'ホッカイドウ', '余市郡赤井川村', 'ヨイチグンアカイガワムラ', '落合', 'オチアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('44856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道余市郡赤井川村常盤', '01', '01409', '0460571', '北海道', 'ホッカイドウ', '余市郡赤井川村', 'ヨイチグンアカイガワムラ', '常盤', 'トキワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市東区', '23', '23102', '4610000', '愛知県', 'アイチケン', '名古屋市東区', 'ナゴヤシヒガシク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('45052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市東区泉', '23', '23102', '4610001', '愛知県', 'アイチケン', '名古屋市東区', 'ナゴヤシヒガシク', '泉', 'イズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市東区代官町', '23', '23102', '4610002', '愛知県', 'アイチケン', '名古屋市東区', 'ナゴヤシヒガシク', '代官町', 'ダイカンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市東区筒井', '23', '23102', '4610003', '愛知県', 'アイチケン', '名古屋市東区', 'ナゴヤシヒガシク', '筒井', 'ツツイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市東区筒井町', '23', '23102', '4610003', '愛知県', 'アイチケン', '名古屋市東区', 'ナゴヤシヒガシク', '筒井町', 'ツツイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市東区葵', '23', '23102', '4610004', '愛知県', 'アイチケン', '名古屋市東区', 'ナゴヤシヒガシク', '葵', 'アオイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市東区東桜', '23', '23102', '4610005', '愛知県', 'アイチケン', '名古屋市東区', 'ナゴヤシヒガシク', '東桜', 'ヒガシサクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市東区東新町', '23', '23102', '4610006', '愛知県', 'アイチケン', '名古屋市東区', 'ナゴヤシヒガシク', '東新町', 'ヒガシシンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市東区西新町', '23', '23102', '4610007', '愛知県', 'アイチケン', '名古屋市東区', 'ナゴヤシヒガシク', '西新町', 'ニシシンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市東区武平町', '23', '23102', '4610008', '愛知県', 'アイチケン', '名古屋市東区', 'ナゴヤシヒガシク', '武平町', 'ブヘイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市東区久屋町', '23', '23102', '4610009', '愛知県', 'アイチケン', '名古屋市東区', 'ナゴヤシヒガシク', '久屋町', 'ヒサヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市東区白壁', '23', '23102', '4610011', '愛知県', 'アイチケン', '名古屋市東区', 'ナゴヤシヒガシク', '白壁', 'シラカベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市東区相生町', '23', '23102', '4610012', '愛知県', 'アイチケン', '名古屋市東区', 'ナゴヤシヒガシク', '相生町', 'アイオイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市東区飯田町', '23', '23102', '4610013', '愛知県', 'アイチケン', '名古屋市東区', 'ナゴヤシヒガシク', '飯田町', 'イイダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市東区橦木町', '23', '23102', '4610014', '愛知県', 'アイチケン', '名古屋市東区', 'ナゴヤシヒガシク', '橦木町', 'シュモクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市東区東片端町', '23', '23102', '4610015', '愛知県', 'アイチケン', '名古屋市東区', 'ナゴヤシヒガシク', '東片端町', 'ヒガシカタハマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市東区上竪杉町', '23', '23102', '4610016', '愛知県', 'アイチケン', '名古屋市東区', 'ナゴヤシヒガシク', '上竪杉町', 'カミタテスギノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市東区東外堀町', '23', '23102', '4610017', '愛知県', 'アイチケン', '名古屋市東区', 'ナゴヤシヒガシク', '東外堀町', 'ヒガシソトボリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市東区主税町', '23', '23102', '4610018', '愛知県', 'アイチケン', '名古屋市東区', 'ナゴヤシヒガシク', '主税町', 'チカラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市東区三の丸', '23', '23102', '4610019', '愛知県', 'アイチケン', '名古屋市東区', 'ナゴヤシヒガシク', '三の丸', 'サンノマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市東区大曽根', '23', '23102', '4610021', '愛知県', 'アイチケン', '名古屋市東区', 'ナゴヤシヒガシク', '大曽根', 'オオゾネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市東区東大曽根町', '23', '23102', '4610022', '愛知県', 'アイチケン', '名古屋市東区', 'ナゴヤシヒガシク', '東大曽根町', 'ヒガシオオゾネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市東区徳川町', '23', '23102', '4610023', '愛知県', 'アイチケン', '名古屋市東区', 'ナゴヤシヒガシク', '徳川町', 'トクガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市東区山口町', '23', '23102', '4610024', '愛知県', 'アイチケン', '名古屋市東区', 'ナゴヤシヒガシク', '山口町', 'ヤマグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市東区徳川', '23', '23102', '4610025', '愛知県', 'アイチケン', '名古屋市東区', 'ナゴヤシヒガシク', '徳川', 'トクガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市東区赤塚町', '23', '23102', '4610026', '愛知県', 'アイチケン', '名古屋市東区', 'ナゴヤシヒガシク', '赤塚町', 'アカツカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市東区芳野', '23', '23102', '4610027', '愛知県', 'アイチケン', '名古屋市東区', 'ナゴヤシヒガシク', '芳野', 'ヨシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市東区明倫町', '23', '23102', '4610031', '愛知県', 'アイチケン', '名古屋市東区', 'ナゴヤシヒガシク', '明倫町', 'メイリンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市東区出来町', '23', '23102', '4610032', '愛知県', 'アイチケン', '名古屋市東区', 'ナゴヤシヒガシク', '出来町', 'デキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市東区大松町', '23', '23102', '4610033', '愛知県', 'アイチケン', '名古屋市東区', 'ナゴヤシヒガシク', '大松町', 'オオマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市東区豊前町', '23', '23102', '4610034', '愛知県', 'アイチケン', '名古屋市東区', 'ナゴヤシヒガシク', '豊前町', 'トヨマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市東区黒門町', '23', '23102', '4610035', '愛知県', 'アイチケン', '名古屋市東区', 'ナゴヤシヒガシク', '黒門町', 'クロモンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市東区車道町', '23', '23102', '4610036', '愛知県', 'アイチケン', '名古屋市東区', 'ナゴヤシヒガシク', '車道町', 'クルマミチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市東区百人町', '23', '23102', '4610037', '愛知県', 'アイチケン', '名古屋市東区', 'ナゴヤシヒガシク', '百人町', 'ヒャクニンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市東区新出来', '23', '23102', '4610038', '愛知県', 'アイチケン', '名古屋市東区', 'ナゴヤシヒガシク', '新出来', 'シンデキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市東区矢田', '23', '23102', '4610040', '愛知県', 'アイチケン', '名古屋市東区', 'ナゴヤシヒガシク', '矢田', 'ヤダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市東区大幸', '23', '23102', '4610043', '愛知県', 'アイチケン', '名古屋市東区', 'ナゴヤシヒガシク', '大幸', 'ダイコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市東区矢田東', '23', '23102', '4610044', '愛知県', 'アイチケン', '名古屋市東区', 'ナゴヤシヒガシク', '矢田東', 'ヤダヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市東区砂田橋', '23', '23102', '4610045', '愛知県', 'アイチケン', '名古屋市東区', 'ナゴヤシヒガシク', '砂田橋', 'スナダバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市東区前浪町', '23', '23102', '4610046', '愛知県', 'アイチケン', '名古屋市東区', 'ナゴヤシヒガシク', '前浪町', 'マエナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市東区大幸南', '23', '23102', '4610047', '愛知県', 'アイチケン', '名古屋市東区', 'ナゴヤシヒガシク', '大幸南', 'ダイコウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市東区矢田南', '23', '23102', '4610048', '愛知県', 'アイチケン', '名古屋市東区', 'ナゴヤシヒガシク', '矢田南', 'ヤダミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市東区古出来', '23', '23102', '4610049', '愛知県', 'アイチケン', '名古屋市東区', 'ナゴヤシヒガシク', '古出来', 'コデキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区', '23', '23103', '4620000', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('45170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区北久手町', '23', '23103', '4620001', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '北久手町', 'キタクテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区六が池町', '23', '23103', '4620002', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '六が池町', 'ロクガイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区桐畑町', '23', '23103', '4620003', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '桐畑町', 'キリハタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区三軒町', '23', '23103', '4620004', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '三軒町', 'サンゲンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区池花町', '23', '23103', '4620005', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '池花町', 'イケハナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区若鶴町', '23', '23103', '4620006', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '若鶴町', 'ワカヅルチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区如意', '23', '23103', '4620007', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '如意', 'ニョイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区如来町', '23', '23103', '4620008', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '如来町', 'ニョライチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区苗田町', '23', '23103', '4620009', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '苗田町', 'ナエダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区五反田町', '23', '23103', '4620011', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '五反田町', 'ゴタンダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区楠', '23', '23103', '4620012', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '楠', 'クスノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区東味鋺', '23', '23103', '4620013', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '東味鋺', 'ヒガシアジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区楠味鋺', '23', '23103', '4620014', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '楠味鋺', 'クスノキアジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区中味鋺', '23', '23103', '4620015', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '中味鋺', 'ナカアジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区西味鋺', '23', '23103', '4620016', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '西味鋺', 'ニシアジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区落合町', '23', '23103', '4620017', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '落合町', 'オチアイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区玄馬町', '23', '23103', '4620018', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '玄馬町', 'ゲンバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区成願寺', '23', '23103', '4620021', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '成願寺', 'ジョウガンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区川中町', '23', '23103', '4620022', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '川中町', 'カワナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区安井', '23', '23103', '4620023', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '安井', 'ヤスイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区鳩岡', '23', '23103', '4620024', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '鳩岡', 'ハトオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区鳩岡町', '23', '23103', '4620025', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '鳩岡町', 'ハトオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区萩野通', '23', '23103', '4620026', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '萩野通', 'ハギノトオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区米が瀬町', '23', '23103', '4620031', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '米が瀬町', 'コメガセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区辻町', '23', '23103', '4620032', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '辻町', 'ツジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区金田町', '23', '23103', '4620033', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '金田町', 'カネダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区天道町', '23', '23103', '4620034', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '天道町', 'テンドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区大野町', '23', '23103', '4620035', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '大野町', 'オオノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区長喜町', '23', '23103', '4620036', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '長喜町', 'ナガキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区志賀町', '23', '23103', '4620037', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '志賀町', 'シガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区稚児宮通', '23', '23103', '4620038', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '稚児宮通', 'チゴノミヤトオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区浪打町', '23', '23103', '4620041', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '浪打町', 'ナミウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区水草町', '23', '23103', '4620042', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '水草町', 'ミズクサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区八代町', '23', '23103', '4620043', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '八代町', 'ヤシロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区元志賀町', '23', '23103', '4620044', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '元志賀町', 'モトシガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区敷島町', '23', '23103', '4620045', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '敷島町', 'シキシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区城見通', '23', '23103', '4620046', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '城見通', 'シロミトオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区金城町', '23', '23103', '4620047', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '金城町', 'キンジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区中切町', '23', '23103', '4620051', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '中切町', 'ナカギリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区福徳町', '23', '23103', '4620052', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '福徳町', 'フクトクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区光音寺町', '23', '23103', '4620053', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '光音寺町', 'コウオンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区野方通', '23', '23103', '4620054', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '野方通', 'ノカタトオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区桝形町', '23', '23103', '4620055', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '桝形町', 'マスガタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区中丸町', '23', '23103', '4620056', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '中丸町', 'チュウマルチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区平手町', '23', '23103', '4620057', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '平手町', 'ヒラテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区西志賀町', '23', '23103', '4620058', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '西志賀町', 'ニシシガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区駒止町', '23', '23103', '4620059', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '駒止町', 'コマドメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区会所町', '23', '23103', '4620061', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '会所町', 'カイショチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区新沼町', '23', '23103', '4620062', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '新沼町', 'シンヌマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区丸新町', '23', '23103', '4620063', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '丸新町', 'マルシンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区大我麻町', '23', '23103', '4620064', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '大我麻町', 'オオガマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区喜惣治', '23', '23103', '4620065', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '喜惣治', 'キソウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区楠町喜惣治新田', '23', '23103', '4620066', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '楠町喜惣治新田', 'クスノキチョウキソウジシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区新堀町', '23', '23103', '4620801', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '新堀町', 'シンボリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区上飯田北町', '23', '23103', '4620802', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '上飯田北町', 'カミイイダキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区上飯田東町', '23', '23103', '4620803', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '上飯田東町', 'カミイイダヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区上飯田南町', '23', '23103', '4620804', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '上飯田南町', 'カミイイダミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区八龍町', '23', '23103', '4620805', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '八龍町', 'ハチリュウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区御成通', '23', '23103', '4620807', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '御成通', 'オナリトオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区上飯田通', '23', '23103', '4620808', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '上飯田通', 'カミイイダトオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区上飯田西町', '23', '23103', '4620809', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '上飯田西町', 'カミイイダニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区山田', '23', '23103', '4620810', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '山田', 'ヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区山田北町', '23', '23103', '4620811', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '山田北町', 'ヤマダキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区矢田町', '23', '23103', '4620812', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '矢田町', 'ヤダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区山田町', '23', '23103', '4620813', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '山田町', 'ヤマダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区山田西町', '23', '23103', '4620814', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '山田西町', 'ヤマダニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区平安通', '23', '23103', '4620816', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '平安通', 'ヘイアントオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区彩紅橋通', '23', '23103', '4620818', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '彩紅橋通', 'サイコウバシトオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区平安', '23', '23103', '4620819', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '平安', 'ヘイアン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区東大曽根町中', '23', '23103', '4620821', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '東大曽根町中', 'ヒガシオオゾネチョウナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区東大曽根町本通', '23', '23103', '4620822', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '東大曽根町本通', 'ヒガシオオゾネチョウホントオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区東大曽根町上', '23', '23103', '4620823', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '東大曽根町上', 'ヒガシオオゾネチョウカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区芳野', '23', '23103', '4620824', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '芳野', 'ヨシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区大曽根', '23', '23103', '4620825', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '大曽根', 'オオゾネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区東大杉町', '23', '23103', '4620826', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '東大杉町', 'ヒガシオオスギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区東長田町', '23', '23103', '4620827', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '東長田町', 'ヒガシチョウダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区東水切町', '23', '23103', '4620828', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '東水切町', 'ヒガシミズキリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区杉栄町', '23', '23103', '4620829', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '杉栄町', 'スギサカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区城東町', '23', '23103', '4620831', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '城東町', 'ジョウトウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区生駒町', '23', '23103', '4620832', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '生駒町', 'イコマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区水切町', '23', '23103', '4620833', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '水切町', 'ミズキリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区長田町', '23', '23103', '4620834', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '長田町', 'チョウダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区杉村', '23', '23103', '4620835', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '杉村', 'スギムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区大杉町', '23', '23103', '4620836', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '大杉町', 'オオスギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区大杉', '23', '23103', '4620837', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '大杉', 'オオスギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区中杉町', '23', '23103', '4620838', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '中杉町', 'ナカスギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区黒川本通', '23', '23103', '4620841', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '黒川本通', 'クロカワホントオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区志賀南通', '23', '23103', '4620842', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '志賀南通', 'シガミナミトオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区田幡', '23', '23103', '4620843', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '田幡', 'タバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区清水', '23', '23103', '4620844', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '清水', 'シミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区柳原', '23', '23103', '4620845', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '柳原', 'ヤナギハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区名城', '23', '23103', '4620846', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '名城', 'メイジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区金城', '23', '23103', '4620847', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '金城', 'キンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区木津根町', '23', '23103', '4620851', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '木津根町', 'キヅネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区猿投町', '23', '23103', '4620852', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '猿投町', 'サナゲチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区志賀本通', '23', '23103', '4620853', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '志賀本通', 'シガホントオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区若葉通', '23', '23103', '4620854', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '若葉通', 'ワカバトオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区石園町', '23', '23103', '4620855', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '石園町', 'イソノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区芦辺町', '23', '23103', '4620856', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '芦辺町', 'アシベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区紅雲町', '23', '23103', '4620857', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '紅雲町', 'コウウンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区大蔵町', '23', '23103', '4620858', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '大蔵町', 'オオクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区神明町', '23', '23103', '4620859', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '神明町', 'シンメイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区辻本通', '23', '23103', '4620861', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '辻本通', 'ツジホンドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区真畔町', '23', '23103', '4620862', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '真畔町', 'マグロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区尾上町', '23', '23103', '4620863', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '尾上町', 'オノエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区織部町', '23', '23103', '4620864', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '織部町', 'オベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区下飯田町', '23', '23103', '4620865', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '下飯田町', 'シモイイダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区瑠璃光町', '23', '23103', '4620866', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '瑠璃光町', 'ルリコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区垣戸町', '23', '23103', '4620867', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '垣戸町', 'ガイドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区憧旛町', '23', '23103', '4620868', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '憧旛町', 'ドウバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市北区龍ノ口町', '23', '23103', '4620869', '愛知県', 'アイチケン', '名古屋市北区', 'ナゴヤシキタク', '龍ノ口町', 'タツノクチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市守山区', '23', '23113', '4630000', '愛知県', 'アイチケン', '名古屋市守山区', 'ナゴヤシモリヤマク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('45302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市守山区上志段味', '23', '23113', '4630001', '愛知県', 'アイチケン', '名古屋市守山区', 'ナゴヤシモリヤマク', '上志段味', 'カミシダミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市守山区中志段味', '23', '23113', '4630002', '愛知県', 'アイチケン', '名古屋市守山区', 'ナゴヤシモリヤマク', '中志段味', 'ナカシダミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市守山区下志段味', '23', '23113', '4630003', '愛知県', 'アイチケン', '名古屋市守山区', 'ナゴヤシモリヤマク', '下志段味', 'シモシダミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市守山区吉根', '23', '23113', '4630004', '愛知県', 'アイチケン', '名古屋市守山区', 'ナゴヤシモリヤマク', '吉根', 'キッコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市守山区川', '23', '23113', '4630005', '愛知県', 'アイチケン', '名古屋市守山区', 'ナゴヤシモリヤマク', '川', 'カワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市守山区川東山', '23', '23113', '4630006', '愛知県', 'アイチケン', '名古屋市守山区', 'ナゴヤシモリヤマク', '川東山', 'カワヒガシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市守山区松坂町', '23', '23113', '4630007', '愛知県', 'アイチケン', '名古屋市守山区', 'ナゴヤシモリヤマク', '松坂町', 'マツサカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市守山区小幡北', '23', '23113', '4630008', '愛知県', 'アイチケン', '名古屋市守山区', 'ナゴヤシモリヤマク', '小幡北', 'オバタキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市守山区緑ケ丘', '23', '23113', '4630009', '愛知県', 'アイチケン', '名古屋市守山区', 'ナゴヤシモリヤマク', '緑ケ丘', 'ミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市守山区翠松園', '23', '23113', '4630010', '愛知県', 'アイチケン', '名古屋市守山区', 'ナゴヤシモリヤマク', '翠松園', 'スイショウエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市守山区小幡', '23', '23113', '4630011', '愛知県', 'アイチケン', '名古屋市守山区', 'ナゴヤシモリヤマク', '小幡', 'オバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市守山区茶臼前', '23', '23113', '4630012', '愛知県', 'アイチケン', '名古屋市守山区', 'ナゴヤシモリヤマク', '茶臼前', 'チャウスマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市守山区小幡中', '23', '23113', '4630013', '愛知県', 'アイチケン', '名古屋市守山区', 'ナゴヤシモリヤマク', '小幡中', 'オバタナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市守山区城南町', '23', '23113', '4630014', '愛知県', 'アイチケン', '名古屋市守山区', 'ナゴヤシモリヤマク', '城南町', 'ジョウナンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市守山区西島町', '23', '23113', '4630015', '愛知県', 'アイチケン', '名古屋市守山区', 'ナゴヤシモリヤマク', '西島町', 'ニシジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市守山区大屋敷', '23', '23113', '4630016', '愛知県', 'アイチケン', '名古屋市守山区', 'ナゴヤシモリヤマク', '大屋敷', 'オオヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市守山区喜多山', '23', '23113', '4630017', '愛知県', 'アイチケン', '名古屋市守山区', 'ナゴヤシモリヤマク', '喜多山', 'キタヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市守山区大森', '23', '23113', '4630021', '愛知県', 'アイチケン', '名古屋市守山区', 'ナゴヤシモリヤマク', '大森', 'オオモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市守山区八剣', '23', '23113', '4630022', '愛知県', 'アイチケン', '名古屋市守山区', 'ナゴヤシモリヤマク', '八剣', 'ヤツルギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市守山区今尻町', '23', '23113', '4630023', '愛知県', 'アイチケン', '名古屋市守山区', 'ナゴヤシモリヤマク', '今尻町', 'イマジリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市守山区脇田町', '23', '23113', '4630024', '愛知県', 'アイチケン', '名古屋市守山区', 'ナゴヤシモリヤマク', '脇田町', 'ワキタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市守山区元郷', '23', '23113', '4630025', '愛知県', 'アイチケン', '名古屋市守山区', 'ナゴヤシモリヤマク', '元郷', 'モトゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市守山区藪田町', '23', '23113', '4630026', '愛知県', 'アイチケン', '名古屋市守山区', 'ナゴヤシモリヤマク', '藪田町', 'ヤブタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市守山区弁天が丘', '23', '23113', '4630027', '愛知県', 'アイチケン', '名古屋市守山区', 'ナゴヤシモリヤマク', '弁天が丘', 'ベンテンガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市守山区大森八龍', '23', '23113', '4630028', '愛知県', 'アイチケン', '名古屋市守山区', 'ナゴヤシモリヤマク', '大森八龍', 'オオモリハチリュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市守山区御膳洞', '23', '23113', '4630029', '愛知県', 'アイチケン', '名古屋市守山区', 'ナゴヤシモリヤマク', '御膳洞', 'ゴゼンボラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市守山区本地が丘', '23', '23113', '4630031', '愛知県', 'アイチケン', '名古屋市守山区', 'ナゴヤシモリヤマク', '本地が丘', 'ホンジガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市守山区白山', '23', '23113', '4630032', '愛知県', 'アイチケン', '名古屋市守山区', 'ナゴヤシモリヤマク', '白山', 'ハクサン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市守山区森孝東', '23', '23113', '4630033', '愛知県', 'アイチケン', '名古屋市守山区', 'ナゴヤシモリヤマク', '森孝東', 'モリタカヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市守山区四軒家', '23', '23113', '4630034', '愛知県', 'アイチケン', '名古屋市守山区', 'ナゴヤシモリヤマク', '四軒家', 'シケンヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市守山区森孝', '23', '23113', '4630035', '愛知県', 'アイチケン', '名古屋市守山区', 'ナゴヤシモリヤマク', '森孝', 'モリタカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市守山区向台', '23', '23113', '4630036', '愛知県', 'アイチケン', '名古屋市守山区', 'ナゴヤシモリヤマク', '向台', 'ムカエダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市守山区天子田', '23', '23113', '4630037', '愛知県', 'アイチケン', '名古屋市守山区', 'ナゴヤシモリヤマク', '天子田', 'アマコダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市守山区原境町', '23', '23113', '4630038', '愛知県', 'アイチケン', '名古屋市守山区', 'ナゴヤシモリヤマク', '原境町', 'ハラザカイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市守山区大谷町', '23', '23113', '4630041', '愛知県', 'アイチケン', '名古屋市守山区', 'ナゴヤシモリヤマク', '大谷町', 'オオタニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市守山区野萩町', '23', '23113', '4630042', '愛知県', 'アイチケン', '名古屋市守山区', 'ナゴヤシモリヤマク', '野萩町', 'ヤハギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市守山区喜多山南', '23', '23113', '4630043', '愛知県', 'アイチケン', '名古屋市守山区', 'ナゴヤシモリヤマク', '喜多山南', 'キタヤマミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市守山区太田井', '23', '23113', '4630044', '愛知県', 'アイチケン', '名古屋市守山区', 'ナゴヤシモリヤマク', '太田井', 'オオタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市守山区菱池町', '23', '23113', '4630045', '愛知県', 'アイチケン', '名古屋市守山区', 'ナゴヤシモリヤマク', '菱池町', 'ヒシイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市守山区苗代', '23', '23113', '4630046', '愛知県', 'アイチケン', '名古屋市守山区', 'ナゴヤシモリヤマク', '苗代', 'ナエシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市守山区小幡常燈', '23', '23113', '4630047', '愛知県', 'アイチケン', '名古屋市守山区', 'ナゴヤシモリヤマク', '小幡常燈', 'オバタジョウトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市守山区小幡南', '23', '23113', '4630048', '愛知県', 'アイチケン', '名古屋市守山区', 'ナゴヤシモリヤマク', '小幡南', 'オバタミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市守山区小幡太田', '23', '23113', '4630051', '愛知県', 'アイチケン', '名古屋市守山区', 'ナゴヤシモリヤマク', '小幡太田', 'オバタオオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市守山区小幡宮ノ腰', '23', '23113', '4630052', '愛知県', 'アイチケン', '名古屋市守山区', 'ナゴヤシモリヤマク', '小幡宮ノ腰', 'オバタミヤノコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市守山区小幡千代田', '23', '23113', '4630053', '愛知県', 'アイチケン', '名古屋市守山区', 'ナゴヤシモリヤマク', '小幡千代田', 'オバタチヨダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市守山区小六町', '23', '23113', '4630054', '愛知県', 'アイチケン', '名古屋市守山区', 'ナゴヤシモリヤマク', '小六町', 'コロクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市守山区西新', '23', '23113', '4630055', '愛知県', 'アイチケン', '名古屋市守山区', 'ナゴヤシモリヤマク', '西新', 'ニシシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市守山区新城', '23', '23113', '4630056', '愛知県', 'アイチケン', '名古屋市守山区', 'ナゴヤシモリヤマク', '新城', 'シンシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市守山区中新', '23', '23113', '4630057', '愛知県', 'アイチケン', '名古屋市守山区', 'ナゴヤシモリヤマク', '中新', 'ナカシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市守山区東山町', '23', '23113', '4630061', '愛知県', 'アイチケン', '名古屋市守山区', 'ナゴヤシモリヤマク', '東山町', 'ヒガシヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市守山区長栄', '23', '23113', '4630062', '愛知県', 'アイチケン', '名古屋市守山区', 'ナゴヤシモリヤマク', '長栄', 'チョウエイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市守山区八反', '23', '23113', '4630063', '愛知県', 'アイチケン', '名古屋市守山区', 'ナゴヤシモリヤマク', '八反', 'ハッタン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市守山区更屋敷', '23', '23113', '4630064', '愛知県', 'アイチケン', '名古屋市守山区', 'ナゴヤシモリヤマク', '更屋敷', 'サラヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市守山区廿軒家', '23', '23113', '4630065', '愛知県', 'アイチケン', '名古屋市守山区', 'ナゴヤシモリヤマク', '廿軒家', 'ニジッケンヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市守山区町南', '23', '23113', '4630066', '愛知県', 'アイチケン', '名古屋市守山区', 'ナゴヤシモリヤマク', '町南', 'マチミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市守山区守山', '23', '23113', '4630067', '愛知県', 'アイチケン', '名古屋市守山区', 'ナゴヤシモリヤマク', '守山', 'モリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市守山区瀬古', '23', '23113', '4630068', '愛知県', 'アイチケン', '名古屋市守山区', 'ナゴヤシモリヤマク', '瀬古', 'セコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市守山区新守西', '23', '23113', '4630069', '愛知県', 'アイチケン', '名古屋市守山区', 'ナゴヤシモリヤマク', '新守西', 'シンモリニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市守山区新守山', '23', '23113', '4630070', '愛知県', 'アイチケン', '名古屋市守山区', 'ナゴヤシモリヤマク', '新守山', 'シンモリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市守山区新守町', '23', '23113', '4630071', '愛知県', 'アイチケン', '名古屋市守山区', 'ナゴヤシモリヤマク', '新守町', 'シンモリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市守山区金屋', '23', '23113', '4630072', '愛知県', 'アイチケン', '名古屋市守山区', 'ナゴヤシモリヤマク', '金屋', 'カナヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市守山区守牧町', '23', '23113', '4630073', '愛知県', 'アイチケン', '名古屋市守山区', 'ナゴヤシモリヤマク', '守牧町', 'モリマキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市守山区町北', '23', '23113', '4630074', '愛知県', 'アイチケン', '名古屋市守山区', 'ナゴヤシモリヤマク', '町北', 'マチキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市守山区市場', '23', '23113', '4630075', '愛知県', 'アイチケン', '名古屋市守山区', 'ナゴヤシモリヤマク', '市場', 'イチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市守山区鳥羽見', '23', '23113', '4630076', '愛知県', 'アイチケン', '名古屋市守山区', 'ナゴヤシモリヤマク', '鳥羽見', 'トリバミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市守山区守山', '23', '23113', '4630077', '愛知県', 'アイチケン', '名古屋市守山区', 'ナゴヤシモリヤマク', '守山', 'モリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市守山区瀬古', '23', '23113', '4630078', '愛知県', 'アイチケン', '名古屋市守山区', 'ナゴヤシモリヤマク', '瀬古', 'セコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市守山区幸心', '23', '23113', '4630079', '愛知県', 'アイチケン', '名古屋市守山区', 'ナゴヤシモリヤマク', '幸心', 'コウシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市守山区川西', '23', '23113', '4630080', '愛知県', 'アイチケン', '名古屋市守山区', 'ナゴヤシモリヤマク', '川西', 'カワニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市守山区川宮町', '23', '23113', '4630081', '愛知県', 'アイチケン', '名古屋市守山区', 'ナゴヤシモリヤマク', '川宮町', 'カワミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市守山区村前町', '23', '23113', '4630082', '愛知県', 'アイチケン', '名古屋市守山区', 'ナゴヤシモリヤマク', '村前町', 'ムラマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市守山区村合町', '23', '23113', '4630083', '愛知県', 'アイチケン', '名古屋市守山区', 'ナゴヤシモリヤマク', '村合町', 'ムラアイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市守山区西城', '23', '23113', '4630084', '愛知県', 'アイチケン', '名古屋市守山区', 'ナゴヤシモリヤマク', '西城', 'ニシシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市守山区大牧町', '23', '23113', '4630085', '愛知県', 'アイチケン', '名古屋市守山区', 'ナゴヤシモリヤマク', '大牧町', 'オオマキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市守山区永森町', '23', '23113', '4630086', '愛知県', 'アイチケン', '名古屋市守山区', 'ナゴヤシモリヤマク', '永森町', 'ナガモリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市守山区大永寺町', '23', '23113', '4630087', '愛知県', 'アイチケン', '名古屋市守山区', 'ナゴヤシモリヤマク', '大永寺町', 'ダイエイジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市守山区鳥神町', '23', '23113', '4630088', '愛知県', 'アイチケン', '名古屋市守山区', 'ナゴヤシモリヤマク', '鳥神町', 'トリガミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市守山区西川原町', '23', '23113', '4630089', '愛知県', 'アイチケン', '名古屋市守山区', 'ナゴヤシモリヤマク', '西川原町', 'ニシガワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市守山区瀬古東', '23', '23113', '4630090', '愛知県', 'アイチケン', '名古屋市守山区', 'ナゴヤシモリヤマク', '瀬古東', 'セコヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市守山区川上町', '23', '23113', '4630091', '愛知県', 'アイチケン', '名古屋市守山区', 'ナゴヤシモリヤマク', '川上町', 'カワカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市守山区白沢町', '23', '23113', '4630092', '愛知県', 'アイチケン', '名古屋市守山区', 'ナゴヤシモリヤマク', '白沢町', 'シラサワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市守山区城土町', '23', '23113', '4630093', '愛知県', 'アイチケン', '名古屋市守山区', 'ナゴヤシモリヤマク', '城土町', 'シロツチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市守山区牛牧', '23', '23113', '4630094', '愛知県', 'アイチケン', '名古屋市守山区', 'ナゴヤシモリヤマク', '牛牧', 'ウシマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市守山区高島町', '23', '23113', '4630095', '愛知県', 'アイチケン', '名古屋市守山区', 'ナゴヤシモリヤマク', '高島町', 'タカシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市守山区森宮町', '23', '23113', '4630096', '愛知県', 'アイチケン', '名古屋市守山区', 'ナゴヤシモリヤマク', '森宮町', 'モリミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市守山区川村町', '23', '23113', '4630097', '愛知県', 'アイチケン', '名古屋市守山区', 'ナゴヤシモリヤマク', '川村町', 'カワムラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市守山区川北町', '23', '23113', '4630098', '愛知県', 'アイチケン', '名古屋市守山区', 'ナゴヤシモリヤマク', '川北町', 'カワキタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市守山区竜泉寺', '23', '23113', '4630801', '愛知県', 'アイチケン', '名古屋市守山区', 'ナゴヤシモリヤマク', '竜泉寺', 'リュウセンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市守山区大森北', '23', '23113', '4630802', '愛知県', 'アイチケン', '名古屋市守山区', 'ナゴヤシモリヤマク', '大森北', 'オオモリキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市守山区日の後', '23', '23113', '4630803', '愛知県', 'アイチケン', '名古屋市守山区', 'ナゴヤシモリヤマク', '日の後', 'ヒノゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市守山区泉が丘', '23', '23113', '4630804', '愛知県', 'アイチケン', '名古屋市守山区', 'ナゴヤシモリヤマク', '泉が丘', 'イズミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市守山区青山台', '23', '23113', '4630805', '愛知県', 'アイチケン', '名古屋市守山区', 'ナゴヤシモリヤマク', '青山台', 'アオヤマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市守山区百合が丘', '23', '23113', '4630806', '愛知県', 'アイチケン', '名古屋市守山区', 'ナゴヤシモリヤマク', '百合が丘', 'ユリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市守山区鼓が丘', '23', '23113', '4630807', '愛知県', 'アイチケン', '名古屋市守山区', 'ナゴヤシモリヤマク', '鼓が丘', 'ツヅミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市守山区花咲台', '23', '23113', '4630808', '愛知県', 'アイチケン', '名古屋市守山区', 'ナゴヤシモリヤマク', '花咲台', 'ハナサキダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市守山区平池東', '23', '23113', '4630809', '愛知県', 'アイチケン', '名古屋市守山区', 'ナゴヤシモリヤマク', '平池東', 'ヒライケヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市守山区深沢', '23', '23113', '4630811', '愛知県', 'アイチケン', '名古屋市守山区', 'ナゴヤシモリヤマク', '深沢', 'フカサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市守山区笹ヶ根', '23', '23113', '4630812', '愛知県', 'アイチケン', '名古屋市守山区', 'ナゴヤシモリヤマク', '笹ヶ根', 'ササガネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市守山区吉根南', '23', '23113', '4630813', '愛知県', 'アイチケン', '名古屋市守山区', 'ナゴヤシモリヤマク', '吉根南', 'キッコミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市守山区桔梗平', '23', '23113', '4630814', '愛知県', 'アイチケン', '名古屋市守山区', 'ナゴヤシモリヤマク', '桔梗平', 'キキョウダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市守山区青葉台', '23', '23113', '4630815', '愛知県', 'アイチケン', '名古屋市守山区', 'ナゴヤシモリヤマク', '青葉台', 'アオバダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区', '23', '23101', '4640000', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('45434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区東千種台', '23', '23101', '4640001', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '東千種台', 'ヒガシチクサダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区香流橋', '23', '23101', '4640002', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '香流橋', 'カナレバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区新西', '23', '23101', '4640003', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '新西', 'シンニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区京命', '23', '23101', '4640004', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '京命', 'キョウメイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区千代が丘', '23', '23101', '4640005', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '千代が丘', 'チヨガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区光が丘', '23', '23101', '4640006', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '光が丘', 'ヒカリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区竹越', '23', '23101', '4640007', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '竹越', 'タケコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区宮根台', '23', '23101', '4640008', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '宮根台', 'ミヤネダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区千代田橋', '23', '23101', '4640011', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '千代田橋', 'チヨダバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区猪高町猪子石猪々道', '23', '23101', '4640012', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '猪高町猪子石猪々道', 'イタカチョウイノコイシシシミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区汁谷町', '23', '23101', '4640013', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '汁谷町', 'シルタニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区御影町', '23', '23101', '4640014', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '御影町', 'ミカゲチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区富士見台', '23', '23101', '4640015', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '富士見台', 'フジミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区希望ケ丘', '23', '23101', '4640016', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '希望ケ丘', 'キボウガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区鍋屋上野町汁谷', '23', '23101', '4640017', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '鍋屋上野町', 'ナベヤウエノチョウ', null, null, '汁谷', 'シルタニ');
INSERT INTO `ms_addresses` VALUES ('45449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区鍋屋上野町北山', '23', '23101', '4640018', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '鍋屋上野町', 'ナベヤウエノチョウ', null, null, '北山', 'キタヤマ');
INSERT INTO `ms_addresses` VALUES ('45450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区揚羽町', '23', '23101', '4640019', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '揚羽町', 'アゲハチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区鹿子殿', '23', '23101', '4640021', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '鹿子殿', 'カノコデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区平和公園', '23', '23101', '4640022', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '平和公園', 'ヘイワコウエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区田代町鹿子殿', '23', '23101', '4640023', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '田代町', 'タシロチョウ', null, null, '鹿子殿', 'カノコデン');
INSERT INTO `ms_addresses` VALUES ('45454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区平和が丘', '23', '23101', '4640024', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '平和が丘', 'ヘイワガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区桜が丘', '23', '23101', '4640025', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '桜が丘', 'サクラガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区井上町', '23', '23101', '4640026', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '井上町', 'イノウエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区新池町', '23', '23101', '4640027', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '新池町', 'シンイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区東明町', '23', '23101', '4640028', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '東明町', 'トウメイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区池上町', '23', '23101', '4640029', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '池上町', 'イケガミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区徳川山町', '23', '23101', '4640031', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '徳川山町', 'トクガワヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区猫洞通', '23', '23101', '4640032', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '猫洞通', 'ネコガホラトオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区鹿子町', '23', '23101', '4640033', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '鹿子町', 'カノコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区清住町', '23', '23101', '4640034', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '清住町', 'キヨズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区橋本町', '23', '23101', '4640035', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '橋本町', 'ハシモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区本山町', '23', '23101', '4640036', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '本山町', 'ホンヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区楠元町', '23', '23101', '4640037', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '楠元町', 'クスモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区春里町', '23', '23101', '4640038', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '春里町', 'ハルサトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区日和町', '23', '23101', '4640039', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '日和町', 'ヒヨリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区霞ケ丘', '23', '23101', '4640041', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '霞ケ丘', 'カスミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区南ケ丘', '23', '23101', '4640042', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '南ケ丘', 'ミナミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区月ケ丘', '23', '23101', '4640043', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '月ケ丘', 'ツキガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区自由ケ丘', '23', '23101', '4640044', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '自由ケ丘', 'ジユウガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区城山町', '23', '23101', '4640045', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '城山町', 'シロヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区城山新町', '23', '23101', '4640046', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '城山新町', 'シロヤマシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区田代町四観音道東', '23', '23101', '4640051', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '田代町', 'タシロチョウ', null, null, '四観音道東', 'シカンノンミチヒガシ');
INSERT INTO `ms_addresses` VALUES ('45476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区田代町四観音道西', '23', '23101', '4640052', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '田代町', 'タシロチョウ', null, null, '四観音道西', 'シカンノンミチニシ');
INSERT INTO `ms_addresses` VALUES ('45477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区田代町岩谷', '23', '23101', '4640053', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '田代町', 'タシロチョウ', null, null, '岩谷', 'イワヤ');
INSERT INTO `ms_addresses` VALUES ('45478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区田代町蝮ケ池上', '23', '23101', '4640054', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '田代町', 'タシロチョウ', null, null, '蝮ケ池上', 'マムシガイケガミ');
INSERT INTO `ms_addresses` VALUES ('45479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区姫池通', '23', '23101', '4640055', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '姫池通', 'ヒメイケドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区月見坂町', '23', '23101', '4640056', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '月見坂町', 'ツキミザカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区法王町', '23', '23101', '4640057', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '法王町', 'ホウオウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区向陽', '23', '23101', '4640061', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '向陽', 'コウヨウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区向陽町', '23', '23101', '4640062', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '向陽町', 'コウヨウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区西山元町', '23', '23101', '4640063', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '西山元町', 'ニシヤマモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区山門町', '23', '23101', '4640064', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '山門町', 'サンモンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区堀割町', '23', '23101', '4640065', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '堀割町', 'ホリワリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区池下町', '23', '23101', '4640066', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '池下町', 'イケシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区池下', '23', '23101', '4640067', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '池下', 'イケシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区若水', '23', '23101', '4640071', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '若水', 'ワカミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区振甫町', '23', '23101', '4640072', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '振甫町', 'シンポチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区高見', '23', '23101', '4640073', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '高見', 'タカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区仲田', '23', '23101', '4640074', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '仲田', 'ナカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区内山', '23', '23101', '4640075', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '内山', 'ウチヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区豊年町', '23', '23101', '4640076', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '豊年町', 'ホウネンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区神田町', '23', '23101', '4640077', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '神田町', 'カンダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区谷口町', '23', '23101', '4640081', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '谷口町', 'タニグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区上野', '23', '23101', '4640082', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '上野', 'ウエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区北千種', '23', '23101', '4640083', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '北千種', 'キタチクサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区松軒', '23', '23101', '4640084', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '松軒', 'ショウケン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区古出来', '23', '23101', '4640085', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '古出来', 'コデキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区萱場', '23', '23101', '4640086', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '萱場', 'カヤバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区清明山', '23', '23101', '4640087', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '清明山', 'セイメイヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区宮の腰町', '23', '23101', '4640091', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '宮の腰町', 'ミヤノコシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区茶屋が坂', '23', '23101', '4640092', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '茶屋が坂', 'チャヤガサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区茶屋坂通', '23', '23101', '4640093', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '茶屋坂通', 'チャヤサカトオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区赤坂町', '23', '23101', '4640094', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '赤坂町', 'アカサカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区天満通', '23', '23101', '4640095', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '天満通', 'テンマドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区下方町', '23', '23101', '4640096', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '下方町', 'シモカタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区鍋屋上野町東脇', '23', '23101', '4640097', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '鍋屋上野町', 'ナベヤウエノチョウ', null, null, '東脇', 'ヒガシワキ');
INSERT INTO `ms_addresses` VALUES ('45510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区星ケ丘', '23', '23101', '4640801', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '星ケ丘', 'ホシガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区星が丘元町', '23', '23101', '4640802', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '星が丘元町', 'ホシガオカモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区田代町瓶杁', '23', '23101', '4640803', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '田代町', 'タシロチョウ', null, null, '瓶杁', 'カメイリ');
INSERT INTO `ms_addresses` VALUES ('45513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区東山元町', '23', '23101', '4640804', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '東山元町', 'ヒガシヤマモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区萩岡町', '23', '23101', '4640805', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '萩岡町', 'ハギオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区唐山町', '23', '23101', '4640806', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '唐山町', 'カラヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区東山通', '23', '23101', '4640807', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '東山通', 'ヒガシヤマトオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区星が丘山手', '23', '23101', '4640808', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '星が丘山手', 'ホシガオカヤマテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区朝岡町', '23', '23101', '4640811', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '朝岡町', 'アサオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区園山町', '23', '23101', '4640812', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '園山町', 'ソノヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区仁座町', '23', '23101', '4640813', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '仁座町', 'ニザチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区不老町', '23', '23101', '4640814', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '不老町', 'フロウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区幸川町', '23', '23101', '4640815', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '幸川町', 'コウガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区鏡池通', '23', '23101', '4640816', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '鏡池通', 'カガミイケトオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区見附町', '23', '23101', '4640817', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '見附町', 'ミツケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区池園町', '23', '23101', '4640818', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '池園町', 'イケソノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区四谷通', '23', '23101', '4640819', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '四谷通', 'ヨツヤトオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区末盛通', '23', '23101', '4640821', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '末盛通', 'スエモリトオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区穂波町', '23', '23101', '4640822', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '穂波町', 'ホナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区松竹町', '23', '23101', '4640823', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '松竹町', 'ショウチクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区稲舟通', '23', '23101', '4640824', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '稲舟通', 'イナフネトオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区西崎町', '23', '23101', '4640825', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '西崎町', 'ニシサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区川崎町', '23', '23101', '4640826', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '川崎町', 'カワサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区田代本通', '23', '23101', '4640827', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '田代本通', 'タシロホントオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区観月町', '23', '23101', '4640831', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '観月町', 'カンゲツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区山添町', '23', '23101', '4640832', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '山添町', 'ヤマゾエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区大島町', '23', '23101', '4640833', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '大島町', 'オオシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区日岡町', '23', '23101', '4640834', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '日岡町', 'ヒノオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区御棚町', '23', '23101', '4640835', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '御棚町', 'オタナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区菊坂町', '23', '23101', '4640836', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '菊坂町', 'キクザカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区丘上町', '23', '23101', '4640837', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '丘上町', 'オカウエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区覚王山通', '23', '23101', '4640841', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '覚王山通', 'カクオウザントオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区桐林町', '23', '23101', '4640842', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '桐林町', 'キリバヤシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区丸山町', '23', '23101', '4640843', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '丸山町', 'マルヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区日進通', '23', '23101', '4640844', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '日進通', 'ニッシントオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区南明町', '23', '23101', '4640845', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '南明町', 'ナンメイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区城木町', '23', '23101', '4640846', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '城木町', 'シロキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区春岡通', '23', '23101', '4640847', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '春岡通', 'ハルオカトオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区春岡', '23', '23101', '4640848', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '春岡', 'ハルオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区今池', '23', '23101', '4640850', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '今池', 'イマイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区今池南', '23', '23101', '4640851', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '今池南', 'イマイケミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区青柳町', '23', '23101', '4640852', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '青柳町', 'アオヤギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区小松町', '23', '23101', '4640853', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '小松町', 'コマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区大久手町', '23', '23101', '4640854', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '大久手町', 'オオクテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区千種通', '23', '23101', '4640855', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '千種通', 'チクサトオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区吹上', '23', '23101', '4640856', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '吹上', 'フキアゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区花田町', '23', '23101', '4640857', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '花田町', 'ハナダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区千種', '23', '23101', '4640858', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '千種', 'チクサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区新栄3丁目', '23', '23101', '4640859', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '新栄', 'シンサカエ', null, null, '3丁目', '03チョウメ');
INSERT INTO `ms_addresses` VALUES ('45559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市千種区天白町植田', '23', '23101', '4640871', '愛知県', 'アイチケン', '名古屋市千種区', 'ナゴヤシチクサク', '天白町植田', 'テンパクチョウウエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市名東区', '23', '23115', '4650000', '愛知県', 'アイチケン', '名古屋市名東区', 'ナゴヤシメイトウク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('45617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市名東区猪高町猪子石原', '23', '23115', '4650001', '愛知県', 'アイチケン', '名古屋市名東区', 'ナゴヤシメイトウク', '猪高町猪子石原', 'イタカチョウイノコイシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市名東区引山', '23', '23115', '4650002', '愛知県', 'アイチケン', '名古屋市名東区', 'ナゴヤシメイトウク', '引山', 'ヒキヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市名東区延珠町', '23', '23115', '4650003', '愛知県', 'アイチケン', '名古屋市名東区', 'ナゴヤシメイトウク', '延珠町', 'エンジュチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市名東区香南', '23', '23115', '4650004', '愛知県', 'アイチケン', '名古屋市名東区', 'ナゴヤシメイトウク', '香南', 'コウナン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市名東区香流', '23', '23115', '4650005', '愛知県', 'アイチケン', '名古屋市名東区', 'ナゴヤシメイトウク', '香流', 'カナレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市名東区神月町', '23', '23115', '4650006', '愛知県', 'アイチケン', '名古屋市名東区', 'ナゴヤシメイトウク', '神月町', 'シンゲツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市名東区香坂', '23', '23115', '4650007', '愛知県', 'アイチケン', '名古屋市名東区', 'ナゴヤシメイトウク', '香坂', 'コウサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市名東区猪子石原', '23', '23115', '4650008', '愛知県', 'アイチケン', '名古屋市名東区', 'ナゴヤシメイトウク', '猪子石原', 'イノコイシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市名東区天神下', '23', '23115', '4650009', '愛知県', 'アイチケン', '名古屋市名東区', 'ナゴヤシメイトウク', '天神下', 'テンジンシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市名東区山の手', '23', '23115', '4650011', '愛知県', 'アイチケン', '名古屋市名東区', 'ナゴヤシメイトウク', '山の手', 'ヤマノテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市名東区文教台', '23', '23115', '4650012', '愛知県', 'アイチケン', '名古屋市名東区', 'ナゴヤシメイトウク', '文教台', 'ブンキョウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市名東区社口', '23', '23115', '4650013', '愛知県', 'アイチケン', '名古屋市名東区', 'ナゴヤシメイトウク', '社口', 'ヤシログチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市名東区上菅', '23', '23115', '4650014', '愛知県', 'アイチケン', '名古屋市名東区', 'ナゴヤシメイトウク', '上菅', 'カミスゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市名東区若葉台', '23', '23115', '4650015', '愛知県', 'アイチケン', '名古屋市名東区', 'ナゴヤシメイトウク', '若葉台', 'ワカバダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市名東区赤松台', '23', '23115', '4650016', '愛知県', 'アイチケン', '名古屋市名東区', 'ナゴヤシメイトウク', '赤松台', 'アカマツダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市名東区つつじが丘', '23', '23115', '4650017', '愛知県', 'アイチケン', '名古屋市名東区', 'ナゴヤシメイトウク', 'つつじが丘', 'ツツジガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市名東区八前', '23', '23115', '4650018', '愛知県', 'アイチケン', '名古屋市名東区', 'ナゴヤシメイトウク', '八前', 'ハチマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市名東区猪子石', '23', '23115', '4650021', '愛知県', 'アイチケン', '名古屋市名東区', 'ナゴヤシメイトウク', '猪子石', 'イノコイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市名東区藤森西町', '23', '23115', '4650022', '愛知県', 'アイチケン', '名古屋市名東区', 'ナゴヤシメイトウク', '藤森西町', 'フジモリニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市名東区石が根町', '23', '23115', '4650023', '愛知県', 'アイチケン', '名古屋市名東区', 'ナゴヤシメイトウク', '石が根町', 'イシガネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市名東区本郷', '23', '23115', '4650024', '愛知県', 'アイチケン', '名古屋市名東区', 'ナゴヤシメイトウク', '本郷', 'ホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市名東区上社', '23', '23115', '4650025', '愛知県', 'アイチケン', '名古屋市名東区', 'ナゴヤシメイトウク', '上社', 'カミヤシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市名東区藤森', '23', '23115', '4650026', '愛知県', 'アイチケン', '名古屋市名東区', 'ナゴヤシメイトウク', '藤森', 'フジモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市名東区丁田町', '23', '23115', '4650027', '愛知県', 'アイチケン', '名古屋市名東区', 'ナゴヤシメイトウク', '丁田町', 'チョウダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市名東区猪高台', '23', '23115', '4650028', '愛知県', 'アイチケン', '名古屋市名東区', 'ナゴヤシメイトウク', '猪高台', 'イダカダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市名東区富が丘', '23', '23115', '4650031', '愛知県', 'アイチケン', '名古屋市名東区', 'ナゴヤシメイトウク', '富が丘', 'トミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市名東区藤が丘', '23', '23115', '4650032', '愛知県', 'アイチケン', '名古屋市名東区', 'ナゴヤシメイトウク', '藤が丘', 'フジガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市名東区明が丘', '23', '23115', '4650033', '愛知県', 'アイチケン', '名古屋市名東区', 'ナゴヤシメイトウク', '明が丘', 'アケガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市名東区高柳町', '23', '23115', '4650034', '愛知県', 'アイチケン', '名古屋市名東区', 'ナゴヤシメイトウク', '高柳町', 'タカヤナギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市名東区豊が丘', '23', '23115', '4650035', '愛知県', 'アイチケン', '名古屋市名東区', 'ナゴヤシメイトウク', '豊が丘', 'ユタカガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市名東区藤里町', '23', '23115', '4650036', '愛知県', 'アイチケン', '名古屋市名東区', 'ナゴヤシメイトウク', '藤里町', 'フジサトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市名東区藤香町', '23', '23115', '4650037', '愛知県', 'アイチケン', '名古屋市名東区', 'ナゴヤシメイトウク', '藤香町', 'フジカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市名東区朝日が丘', '23', '23115', '4650041', '愛知県', 'アイチケン', '名古屋市名東区', 'ナゴヤシメイトウク', '朝日が丘', 'アサヒガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市名東区照が丘', '23', '23115', '4650042', '愛知県', 'アイチケン', '名古屋市名東区', 'ナゴヤシメイトウク', '照が丘', 'テルガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市名東区宝が丘', '23', '23115', '4650043', '愛知県', 'アイチケン', '名古屋市名東区', 'ナゴヤシメイトウク', '宝が丘', 'タカラガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市名東区小井堀町', '23', '23115', '4650044', '愛知県', 'アイチケン', '名古屋市名東区', 'ナゴヤシメイトウク', '小井堀町', 'コイボリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市名東区姫若町', '23', '23115', '4650045', '愛知県', 'アイチケン', '名古屋市名東区', 'ナゴヤシメイトウク', '姫若町', 'ヒメワカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市名東区望が丘', '23', '23115', '4650046', '愛知県', 'アイチケン', '名古屋市名東区', 'ナゴヤシメイトウク', '望が丘', 'ノゾミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市名東区小池町', '23', '23115', '4650047', '愛知県', 'アイチケン', '名古屋市名東区', 'ナゴヤシメイトウク', '小池町', 'コイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市名東区藤見が丘', '23', '23115', '4650048', '愛知県', 'アイチケン', '名古屋市名東区', 'ナゴヤシメイトウク', '藤見が丘', 'フジミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市名東区社が丘', '23', '23115', '4650051', '愛知県', 'アイチケン', '名古屋市名東区', 'ナゴヤシメイトウク', '社が丘', 'ヤシロガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市名東区猪高町上社', '23', '23115', '4650052', '愛知県', 'アイチケン', '名古屋市名東区', 'ナゴヤシメイトウク', '猪高町上社', 'イタカチョウカミヤシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市名東区極楽', '23', '23115', '4650053', '愛知県', 'アイチケン', '名古屋市名東区', 'ナゴヤシメイトウク', '極楽', 'ゴクラク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市名東区高針台', '23', '23115', '4650054', '愛知県', 'アイチケン', '名古屋市名東区', 'ナゴヤシメイトウク', '高針台', 'タカバリダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市名東区勢子坊', '23', '23115', '4650055', '愛知県', 'アイチケン', '名古屋市名東区', 'ナゴヤシメイトウク', '勢子坊', 'セコボウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市名東区野間町', '23', '23115', '4650056', '愛知県', 'アイチケン', '名古屋市名東区', 'ナゴヤシメイトウク', '野間町', 'ノマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市名東区陸前町', '23', '23115', '4650057', '愛知県', 'アイチケン', '名古屋市名東区', 'ナゴヤシメイトウク', '陸前町', 'リクマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市名東区貴船', '23', '23115', '4650058', '愛知県', 'アイチケン', '名古屋市名東区', 'ナゴヤシメイトウク', '貴船', 'キフネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市名東区高針', '23', '23115', '4650061', '愛知県', 'アイチケン', '名古屋市名東区', 'ナゴヤシメイトウク', '高針', 'タカバリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市名東区松井町', '23', '23115', '4650062', '愛知県', 'アイチケン', '名古屋市名東区', 'ナゴヤシメイトウク', '松井町', 'マツイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市名東区新宿', '23', '23115', '4650063', '愛知県', 'アイチケン', '名古屋市名東区', 'ナゴヤシメイトウク', '新宿', 'シンジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市名東区大針', '23', '23115', '4650064', '愛知県', 'アイチケン', '名古屋市名東区', 'ナゴヤシメイトウク', '大針', 'オオバリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市名東区梅森坂', '23', '23115', '4650065', '愛知県', 'アイチケン', '名古屋市名東区', 'ナゴヤシメイトウク', '梅森坂', 'ウメモリザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市名東区梅森坂西', '23', '23115', '4650066', '愛知県', 'アイチケン', '名古屋市名東区', 'ナゴヤシメイトウク', '梅森坂西', 'ウメモリザカニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市名東区猪高町高針', '23', '23115', '4650067', '愛知県', 'アイチケン', '名古屋市名東区', 'ナゴヤシメイトウク', '猪高町高針', 'イタカチョウタカバリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市名東区牧の里', '23', '23115', '4650068', '愛知県', 'アイチケン', '名古屋市名東区', 'ナゴヤシメイトウク', '牧の里', 'マキノサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市名東区西山台', '23', '23115', '4650071', '愛知県', 'アイチケン', '名古屋市名東区', 'ナゴヤシメイトウク', '西山台', 'ニシヤマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市名東区牧の原', '23', '23115', '4650072', '愛知県', 'アイチケン', '名古屋市名東区', 'ナゴヤシメイトウク', '牧の原', 'マキノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市名東区高針原', '23', '23115', '4650073', '愛知県', 'アイチケン', '名古屋市名東区', 'ナゴヤシメイトウク', '高針原', 'タカバリハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市名東区山香町', '23', '23115', '4650074', '愛知県', 'アイチケン', '名古屋市名東区', 'ナゴヤシメイトウク', '山香町', 'サンコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市名東区藤巻町', '23', '23115', '4650075', '愛知県', 'アイチケン', '名古屋市名東区', 'ナゴヤシメイトウク', '藤巻町', 'フジマキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市名東区扇町', '23', '23115', '4650076', '愛知県', 'アイチケン', '名古屋市名東区', 'ナゴヤシメイトウク', '扇町', 'オウギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市名東区植園町', '23', '23115', '4650077', '愛知県', 'アイチケン', '名古屋市名東区', 'ナゴヤシメイトウク', '植園町', 'ウエソノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市名東区にじが丘', '23', '23115', '4650078', '愛知県', 'アイチケン', '名古屋市名東区', 'ナゴヤシメイトウク', 'にじが丘', 'ニジガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市名東区高間町', '23', '23115', '4650081', '愛知県', 'アイチケン', '名古屋市名東区', 'ナゴヤシメイトウク', '高間町', 'タカマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市名東区神里', '23', '23115', '4650082', '愛知県', 'アイチケン', '名古屋市名東区', 'ナゴヤシメイトウク', '神里', 'カミサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市名東区神丘町', '23', '23115', '4650083', '愛知県', 'アイチケン', '名古屋市名東区', 'ナゴヤシメイトウク', '神丘町', 'カミオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市名東区西里町', '23', '23115', '4650084', '愛知県', 'アイチケン', '名古屋市名東区', 'ナゴヤシメイトウク', '西里町', 'ニシサトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市名東区西山本通', '23', '23115', '4650085', '愛知県', 'アイチケン', '名古屋市名東区', 'ナゴヤシメイトウク', '西山本通', 'ニシヤマホントオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市名東区代万町', '23', '23115', '4650086', '愛知県', 'アイチケン', '名古屋市名東区', 'ナゴヤシメイトウク', '代万町', 'ダイマンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市名東区名東本通', '23', '23115', '4650087', '愛知県', 'アイチケン', '名古屋市名東区', 'ナゴヤシメイトウク', '名東本通', 'メイトウホンドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市名東区名東本町', '23', '23115', '4650088', '愛知県', 'アイチケン', '名古屋市名東区', 'ナゴヤシメイトウク', '名東本町', 'メイトウホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市名東区よもぎ台', '23', '23115', '4650091', '愛知県', 'アイチケン', '名古屋市名東区', 'ナゴヤシメイトウク', 'よもぎ台', 'ヨモギダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市名東区社台', '23', '23115', '4650092', '愛知県', 'アイチケン', '名古屋市名東区', 'ナゴヤシメイトウク', '社台', 'ヤシロダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市名東区一社', '23', '23115', '4650093', '愛知県', 'アイチケン', '名古屋市名東区', 'ナゴヤシメイトウク', '一社', 'イッシャ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市名東区亀の井', '23', '23115', '4650094', '愛知県', 'アイチケン', '名古屋市名東区', 'ナゴヤシメイトウク', '亀の井', 'カメノイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市名東区高社', '23', '23115', '4650095', '愛知県', 'アイチケン', '名古屋市名東区', 'ナゴヤシメイトウク', '高社', 'タカヤシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市名東区桜が丘', '23', '23115', '4650096', '愛知県', 'アイチケン', '名古屋市名東区', 'ナゴヤシメイトウク', '桜が丘', 'サクラガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市名東区平和が丘', '23', '23115', '4650097', '愛知県', 'アイチケン', '名古屋市名東区', 'ナゴヤシメイトウク', '平和が丘', 'ヘイワガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市昭和区', '23', '23107', '4660000', '愛知県', 'アイチケン', '名古屋市昭和区', 'ナゴヤシショウワク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('45725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市昭和区車田町', '23', '23107', '4660001', '愛知県', 'アイチケン', '名古屋市昭和区', 'ナゴヤシショウワク', '車田町', 'クルマダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市昭和区吹上町', '23', '23107', '4660002', '愛知県', 'アイチケン', '名古屋市昭和区', 'ナゴヤシショウワク', '吹上町', 'フキアゲチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市昭和区曙町', '23', '23107', '4660003', '愛知県', 'アイチケン', '名古屋市昭和区', 'ナゴヤシショウワク', '曙町', 'アケボノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市昭和区広瀬町', '23', '23107', '4660004', '愛知県', 'アイチケン', '名古屋市昭和区', 'ナゴヤシショウワク', '広瀬町', 'ヒロセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市昭和区雪見町', '23', '23107', '4660005', '愛知県', 'アイチケン', '名古屋市昭和区', 'ナゴヤシショウワク', '雪見町', 'ユキミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市昭和区北山町', '23', '23107', '4660006', '愛知県', 'アイチケン', '名古屋市昭和区', 'ナゴヤシショウワク', '北山町', 'キタヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市昭和区鶴羽町', '23', '23107', '4660011', '愛知県', 'アイチケン', '名古屋市昭和区', 'ナゴヤシショウワク', '鶴羽町', 'ツルハチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市昭和区小桜町', '23', '23107', '4660012', '愛知県', 'アイチケン', '名古屋市昭和区', 'ナゴヤシショウワク', '小桜町', 'コサクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市昭和区緑町', '23', '23107', '4660013', '愛知県', 'アイチケン', '名古屋市昭和区', 'ナゴヤシショウワク', '緑町', 'ミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市昭和区東畑町', '23', '23107', '4660014', '愛知県', 'アイチケン', '名古屋市昭和区', 'ナゴヤシショウワク', '東畑町', 'トウハタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市昭和区御器所通', '23', '23107', '4660015', '愛知県', 'アイチケン', '名古屋市昭和区', 'ナゴヤシショウワク', '御器所通', 'ゴキソトオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市昭和区北山本町', '23', '23107', '4660016', '愛知県', 'アイチケン', '名古屋市昭和区', 'ナゴヤシショウワク', '北山本町', 'キタヤマホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市昭和区小坂町', '23', '23107', '4660021', '愛知県', 'アイチケン', '名古屋市昭和区', 'ナゴヤシショウワク', '小坂町', 'コサカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市昭和区塩付通', '23', '23107', '4660022', '愛知県', 'アイチケン', '名古屋市昭和区', 'ナゴヤシショウワク', '塩付通', 'シオツケトオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市昭和区石仏町', '23', '23107', '4660023', '愛知県', 'アイチケン', '名古屋市昭和区', 'ナゴヤシショウワク', '石仏町', 'イシボトケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市昭和区大和町', '23', '23107', '4660024', '愛知県', 'アイチケン', '名古屋市昭和区', 'ナゴヤシショウワク', '大和町', 'ヤマトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市昭和区下構町', '23', '23107', '4660025', '愛知県', 'アイチケン', '名古屋市昭和区', 'ナゴヤシショウワク', '下構町', 'シモガマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市昭和区陶生町', '23', '23107', '4660026', '愛知県', 'アイチケン', '名古屋市昭和区', 'ナゴヤシショウワク', '陶生町', 'トウセイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市昭和区阿由知通', '23', '23107', '4660027', '愛知県', 'アイチケン', '名古屋市昭和区', 'ナゴヤシショウワク', '阿由知通', 'アユチトオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市昭和区紅梅町', '23', '23107', '4660031', '愛知県', 'アイチケン', '名古屋市昭和区', 'ナゴヤシショウワク', '紅梅町', 'コウバイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市昭和区天神町', '23', '23107', '4660032', '愛知県', 'アイチケン', '名古屋市昭和区', 'ナゴヤシショウワク', '天神町', 'テンジンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市昭和区台町', '23', '23107', '4660033', '愛知県', 'アイチケン', '名古屋市昭和区', 'ナゴヤシショウワク', '台町', 'ダイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市昭和区明月町', '23', '23107', '4660034', '愛知県', 'アイチケン', '名古屋市昭和区', 'ナゴヤシショウワク', '明月町', 'メイゲツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市昭和区松風町', '23', '23107', '4660035', '愛知県', 'アイチケン', '名古屋市昭和区', 'ナゴヤシショウワク', '松風町', 'マツカゼチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市昭和区若柳町', '23', '23107', '4660036', '愛知県', 'アイチケン', '名古屋市昭和区', 'ナゴヤシショウワク', '若柳町', 'ワカヤギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市昭和区恵方町', '23', '23107', '4660037', '愛知県', 'アイチケン', '名古屋市昭和区', 'ナゴヤシショウワク', '恵方町', 'エホウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市昭和区出口町', '23', '23107', '4660041', '愛知県', 'アイチケン', '名古屋市昭和区', 'ナゴヤシショウワク', '出口町', 'デグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市昭和区広池町', '23', '23107', '4660042', '愛知県', 'アイチケン', '名古屋市昭和区', 'ナゴヤシショウワク', '広池町', 'ヒロイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市昭和区池端町', '23', '23107', '4660043', '愛知県', 'アイチケン', '名古屋市昭和区', 'ナゴヤシショウワク', '池端町', 'イケバタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市昭和区桜山町', '23', '23107', '4660044', '愛知県', 'アイチケン', '名古屋市昭和区', 'ナゴヤシショウワク', '桜山町', 'サクラヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市昭和区丸屋町', '23', '23107', '4660045', '愛知県', 'アイチケン', '名古屋市昭和区', 'ナゴヤシショウワク', '丸屋町', 'マルヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市昭和区広見町', '23', '23107', '4660046', '愛知県', 'アイチケン', '名古屋市昭和区', 'ナゴヤシショウワク', '広見町', 'ヒロミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市昭和区永金町', '23', '23107', '4660047', '愛知県', 'アイチケン', '名古屋市昭和区', 'ナゴヤシショウワク', '永金町', 'エイキンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市昭和区御器所', '23', '23107', '4660051', '愛知県', 'アイチケン', '名古屋市昭和区', 'ナゴヤシショウワク', '御器所', 'ゴキソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市昭和区村雲町', '23', '23107', '4660052', '愛知県', 'アイチケン', '名古屋市昭和区', 'ナゴヤシショウワク', '村雲町', 'ムラクモチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市昭和区滝子町', '23', '23107', '4660053', '愛知県', 'アイチケン', '名古屋市昭和区', 'ナゴヤシショウワク', '滝子町', 'タキコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市昭和区円上町', '23', '23107', '4660054', '愛知県', 'アイチケン', '名古屋市昭和区', 'ナゴヤシショウワク', '円上町', 'エンジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市昭和区滝子通', '23', '23107', '4660055', '愛知県', 'アイチケン', '名古屋市昭和区', 'ナゴヤシショウワク', '滝子通', 'タキゴトオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市昭和区東郊通', '23', '23107', '4660056', '愛知県', 'アイチケン', '名古屋市昭和区', 'ナゴヤシショウワク', '東郊通', 'トウコウトオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市昭和区高辻町', '23', '23107', '4660057', '愛知県', 'アイチケン', '名古屋市昭和区', 'ナゴヤシショウワク', '高辻町', 'タカツジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市昭和区白金', '23', '23107', '4660058', '愛知県', 'アイチケン', '名古屋市昭和区', 'ナゴヤシショウワク', '白金', 'シラカネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市昭和区福江', '23', '23107', '4660059', '愛知県', 'アイチケン', '名古屋市昭和区', 'ナゴヤシショウワク', '福江', 'フクエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市昭和区御器所町', '23', '23107', '4660061', '愛知県', 'アイチケン', '名古屋市昭和区', 'ナゴヤシショウワク', '御器所町', 'ゴキソチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市昭和区狭間町', '23', '23107', '4660062', '愛知県', 'アイチケン', '名古屋市昭和区', 'ナゴヤシショウワク', '狭間町', 'ハザマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市昭和区山脇町', '23', '23107', '4660063', '愛知県', 'アイチケン', '名古屋市昭和区', 'ナゴヤシショウワク', '山脇町', 'ヤマワキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市昭和区鶴舞', '23', '23107', '4660064', '愛知県', 'アイチケン', '名古屋市昭和区', 'ナゴヤシショウワク', '鶴舞', 'ツルマイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市昭和区鶴舞町', '23', '23107', '4660065', '愛知県', 'アイチケン', '名古屋市昭和区', 'ナゴヤシショウワク', '鶴舞町', 'ツルマイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市昭和区田面町', '23', '23107', '4660801', '愛知県', 'アイチケン', '名古屋市昭和区', 'ナゴヤシショウワク', '田面町', 'タオモチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市昭和区神村町', '23', '23107', '4660802', '愛知県', 'アイチケン', '名古屋市昭和区', 'ナゴヤシショウワク', '神村町', 'カミムラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市昭和区福原町', '23', '23107', '4660803', '愛知県', 'アイチケン', '名古屋市昭和区', 'ナゴヤシショウワク', '福原町', 'フクハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市昭和区宮東町', '23', '23107', '4660804', '愛知県', 'アイチケン', '名古屋市昭和区', 'ナゴヤシショウワク', '宮東町', 'ミヤヒガシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市昭和区伊勝町', '23', '23107', '4660805', '愛知県', 'アイチケン', '名古屋市昭和区', 'ナゴヤシショウワク', '伊勝町', 'イカツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市昭和区西畑町', '23', '23107', '4660806', '愛知県', 'アイチケン', '名古屋市昭和区', 'ナゴヤシショウワク', '西畑町', 'ニシバタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市昭和区山花町', '23', '23107', '4660807', '愛知県', 'アイチケン', '名古屋市昭和区', 'ナゴヤシショウワク', '山花町', 'ヤマハナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市昭和区高峯町', '23', '23107', '4660811', '愛知県', 'アイチケン', '名古屋市昭和区', 'ナゴヤシショウワク', '高峯町', 'タカミネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市昭和区八事富士見', '23', '23107', '4660812', '愛知県', 'アイチケン', '名古屋市昭和区', 'ナゴヤシショウワク', '八事富士見', 'ヤゴトフジミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市昭和区妙見町', '23', '23107', '4660814', '愛知県', 'アイチケン', '名古屋市昭和区', 'ナゴヤシショウワク', '妙見町', 'ミョウケンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市昭和区山手通', '23', '23107', '4660815', '愛知県', 'アイチケン', '名古屋市昭和区', 'ナゴヤシショウワク', '山手通', 'ヤマノテトオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市昭和区前山町', '23', '23107', '4660821', '愛知県', 'アイチケン', '名古屋市昭和区', 'ナゴヤシショウワク', '前山町', 'マエヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市昭和区楽園町', '23', '23107', '4660822', '愛知県', 'アイチケン', '名古屋市昭和区', 'ナゴヤシショウワク', '楽園町', 'ラクエンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市昭和区八雲町', '23', '23107', '4660823', '愛知県', 'アイチケン', '名古屋市昭和区', 'ナゴヤシショウワク', '八雲町', 'ヤクモチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市昭和区山里町', '23', '23107', '4660824', '愛知県', 'アイチケン', '名古屋市昭和区', 'ナゴヤシショウワク', '山里町', 'ヤマザトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市昭和区八事本町', '23', '23107', '4660825', '愛知県', 'アイチケン', '名古屋市昭和区', 'ナゴヤシショウワク', '八事本町', 'ヤゴトホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市昭和区滝川町', '23', '23107', '4660826', '愛知県', 'アイチケン', '名古屋市昭和区', 'ナゴヤシショウワク', '滝川町', 'タキカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市昭和区川名山町', '23', '23107', '4660827', '愛知県', 'アイチケン', '名古屋市昭和区', 'ナゴヤシショウワク', '川名山町', 'カワナヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市昭和区山中町', '23', '23107', '4660828', '愛知県', 'アイチケン', '名古屋市昭和区', 'ナゴヤシショウワク', '山中町', 'ヤマナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市昭和区向山町', '23', '23107', '4660829', '愛知県', 'アイチケン', '名古屋市昭和区', 'ナゴヤシショウワク', '向山町', 'ムカイヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市昭和区花見通', '23', '23107', '4660831', '愛知県', 'アイチケン', '名古屋市昭和区', 'ナゴヤシショウワク', '花見通', 'ハナミトオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市昭和区駒方町', '23', '23107', '4660832', '愛知県', 'アイチケン', '名古屋市昭和区', 'ナゴヤシショウワク', '駒方町', 'コマガタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市昭和区隼人町', '23', '23107', '4660833', '愛知県', 'アイチケン', '名古屋市昭和区', 'ナゴヤシショウワク', '隼人町', 'ハヤトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市昭和区広路町', '23', '23107', '4660834', '愛知県', 'アイチケン', '名古屋市昭和区', 'ナゴヤシショウワク', '広路町', 'ヒロジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市昭和区南山町', '23', '23107', '4660835', '愛知県', 'アイチケン', '名古屋市昭和区', 'ナゴヤシショウワク', '南山町', 'ミナミヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市昭和区上山町', '23', '23107', '4660836', '愛知県', 'アイチケン', '名古屋市昭和区', 'ナゴヤシショウワク', '上山町', 'カミヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市昭和区汐見町', '23', '23107', '4660837', '愛知県', 'アイチケン', '名古屋市昭和区', 'ナゴヤシショウワク', '汐見町', 'シオミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市昭和区五軒家町', '23', '23107', '4660838', '愛知県', 'アイチケン', '名古屋市昭和区', 'ナゴヤシショウワク', '五軒家町', 'ゴケンヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市昭和区広路本町', '23', '23107', '4660841', '愛知県', 'アイチケン', '名古屋市昭和区', 'ナゴヤシショウワク', '広路本町', 'ヒロジホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市昭和区檀溪通', '23', '23107', '4660842', '愛知県', 'アイチケン', '名古屋市昭和区', 'ナゴヤシショウワク', '檀溪通', 'ダンケイトオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市昭和区菊園町', '23', '23107', '4660843', '愛知県', 'アイチケン', '名古屋市昭和区', 'ナゴヤシショウワク', '菊園町', 'キクゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市昭和区荒田町', '23', '23107', '4660844', '愛知県', 'アイチケン', '名古屋市昭和区', 'ナゴヤシショウワク', '荒田町', 'アラタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市昭和区藤成通', '23', '23107', '4660845', '愛知県', 'アイチケン', '名古屋市昭和区', 'ナゴヤシショウワク', '藤成通', 'フジナリトオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市昭和区戸田町', '23', '23107', '4660846', '愛知県', 'アイチケン', '名古屋市昭和区', 'ナゴヤシショウワク', '戸田町', 'トダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市昭和区長池町', '23', '23107', '4660847', '愛知県', 'アイチケン', '名古屋市昭和区', 'ナゴヤシショウワク', '長池町', 'ナガイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市昭和区長戸町', '23', '23107', '4660848', '愛知県', 'アイチケン', '名古屋市昭和区', 'ナゴヤシショウワク', '長戸町', 'ナガトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市昭和区南分町', '23', '23107', '4660849', '愛知県', 'アイチケン', '名古屋市昭和区', 'ナゴヤシショウワク', '南分町', 'ミナミワケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市昭和区元宮町', '23', '23107', '4660851', '愛知県', 'アイチケン', '名古屋市昭和区', 'ナゴヤシショウワク', '元宮町', 'モトミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市昭和区萩原町', '23', '23107', '4660852', '愛知県', 'アイチケン', '名古屋市昭和区', 'ナゴヤシショウワク', '萩原町', 'ハギワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市昭和区川原通', '23', '23107', '4660853', '愛知県', 'アイチケン', '名古屋市昭和区', 'ナゴヤシショウワク', '川原通', 'カワハラトオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市昭和区広路通', '23', '23107', '4660854', '愛知県', 'アイチケン', '名古屋市昭和区', 'ナゴヤシショウワク', '広路通', 'ヒロジトオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市昭和区川名本町', '23', '23107', '4660855', '愛知県', 'アイチケン', '名古屋市昭和区', 'ナゴヤシショウワク', '川名本町', 'カワナホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市昭和区川名町', '23', '23107', '4660856', '愛知県', 'アイチケン', '名古屋市昭和区', 'ナゴヤシショウワク', '川名町', 'カワナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市昭和区安田通', '23', '23107', '4660857', '愛知県', 'アイチケン', '名古屋市昭和区', 'ナゴヤシショウワク', '安田通', 'ヤスダトオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市昭和区折戸町', '23', '23107', '4660858', '愛知県', 'アイチケン', '名古屋市昭和区', 'ナゴヤシショウワク', '折戸町', 'オリドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区', '23', '23108', '4670000', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('45856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区瑞穂町川澄', '23', '23108', '4670001', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '瑞穂町', 'ミズホチョウ', null, null, '川澄', 'カワスミ');
INSERT INTO `ms_addresses` VALUES ('45857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区川澄町', '23', '23108', '4670002', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '川澄町', 'カワスミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区汐路町', '23', '23108', '4670003', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '汐路町', 'シオジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区松月町', '23', '23108', '4670004', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '松月町', 'ショウゲツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区石川町', '23', '23108', '4670005', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '石川町', 'イシカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区御莨町', '23', '23108', '4670006', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '御莨町', 'オタバコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区大殿町', '23', '23108', '4670007', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '大殿町', 'オトドマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区村上町', '23', '23108', '4670008', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '村上町', 'ムラカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区萩山町', '23', '23108', '4670011', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '萩山町', 'ハギヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区豊岡通', '23', '23108', '4670012', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '豊岡通', 'トヨオカドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区膳棚町', '23', '23108', '4670013', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '膳棚町', 'ゼンダナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区白羽根町', '23', '23108', '4670014', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '白羽根町', 'シラハネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区十六町', '23', '23108', '4670015', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '十六町', 'ソロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区佐渡町', '23', '23108', '4670016', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '佐渡町', 'サワタリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区東栄町', '23', '23108', '4670017', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '東栄町', 'トウエイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区檀渓通', '23', '23108', '4670021', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '檀渓通', 'ダンケイトオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区上山町', '23', '23108', '4670022', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '上山町', 'カミヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区南山町', '23', '23108', '4670023', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '南山町', 'ミナミヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区春山町', '23', '23108', '4670024', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '春山町', 'ハルヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区松栄町', '23', '23108', '4670025', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '松栄町', 'マツサカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区陽明町', '23', '23108', '4670026', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '陽明町', 'ヨウメイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区田辺通', '23', '23108', '4670027', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '田辺通', 'タナベトオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区初日町', '23', '23108', '4670028', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '初日町', 'ハツヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区弥富町緑ケ岡', '23', '23108', '4670031', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '弥富町緑ケ岡', 'ヤトミチョウミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区弥富町紅葉園', '23', '23108', '4670032', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '弥富町紅葉園', 'ヤトミチョウコウヨウエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区弥富町円山', '23', '23108', '4670033', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '弥富町円山', 'ヤトミチョウマルヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区弥富町桜ケ岡', '23', '23108', '4670034', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '弥富町桜ケ岡', 'ヤトミチョウサクラガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区弥富町月見ケ岡', '23', '23108', '4670035', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '弥富町月見ケ岡', 'ヤトミチョウツキミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区弥富町密柑山', '23', '23108', '4670036', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '弥富町密柑山', 'ヤトミチョウミカンヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区弥富町上山', '23', '23108', '4670037', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '弥富町上山', 'ヤトミチョウカミヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区弥富町清水ケ岡', '23', '23108', '4670038', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '弥富町清水ケ岡', 'ヤトミチョウシミズガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区弥富町茨山', '23', '23108', '4670039', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '弥富町茨山', 'ヤトミチョウイバラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区密柑山町', '23', '23108', '4670041', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '密柑山町', 'ミカンヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区八勝通', '23', '23108', '4670042', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '八勝通', 'ハッショウトオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区岳見町', '23', '23108', '4670043', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '岳見町', 'タケミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区柏木町', '23', '23108', '4670044', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '柏木町', 'カシワギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区茨木町', '23', '23108', '4670045', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '茨木町', 'イバラギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区玉水町', '23', '23108', '4670046', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '玉水町', 'タマミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区日向町', '23', '23108', '4670047', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '日向町', 'ヒナタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区弥富ケ丘町', '23', '23108', '4670048', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '弥富ケ丘町', 'ヤトミガオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区下山町', '23', '23108', '4670049', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '下山町', 'シモヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区釜塚町', '23', '23108', '4670051', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '釜塚町', 'カマヅカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区片坂町', '23', '23108', '4670052', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '片坂町', 'カタサカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区仁所町', '23', '23108', '4670053', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '仁所町', 'ニショチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区丸根町', '23', '23108', '4670054', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '丸根町', 'マルネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区中根町', '23', '23108', '4670055', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '中根町', 'ナカネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区白砂町', '23', '23108', '4670056', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '白砂町', 'シラスナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区井の元町', '23', '23108', '4670057', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '井の元町', 'イノモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区関取町', '23', '23108', '4670058', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '関取町', 'セキトリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区軍水町', '23', '23108', '4670059', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '軍水町', 'グンスイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区師長町', '23', '23108', '4670061', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '師長町', 'モロナガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区山下通', '23', '23108', '4670062', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '山下通', 'ヤマシタドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区市丘町', '23', '23108', '4670063', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '市丘町', 'イチオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区弥富通', '23', '23108', '4670064', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '弥富通', 'ヤトミドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区松園町', '23', '23108', '4670065', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '松園町', 'マツソノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区洲山町', '23', '23108', '4670066', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '洲山町', 'スヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区石田町', '23', '23108', '4670067', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '石田町', 'イシダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区内方町', '23', '23108', '4670068', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '内方町', 'ウチカタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区瑞穂町西藤塚', '23', '23108', '4670801', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '瑞穂町', 'ミズホチョウ', null, null, '西藤塚', 'ニシフジツカ');
INSERT INTO `ms_addresses` VALUES ('45915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区瑞穂町山の畑', '23', '23108', '4670802', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '瑞穂町', 'ミズホチョウ', null, null, '山の畑', 'ヤマノバタ');
INSERT INTO `ms_addresses` VALUES ('45916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区中山町', '23', '23108', '4670803', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '中山町', 'ナカヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区洲雲町', '23', '23108', '4670804', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '洲雲町', 'スグモチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区桜見町', '23', '23108', '4670805', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '桜見町', 'サクラミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区瑞穂通', '23', '23108', '4670806', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '瑞穂通', 'ミズホトオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区駒場町', '23', '23108', '4670807', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '駒場町', 'コマバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区高田町', '23', '23108', '4670808', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '高田町', 'タカタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区北原町', '23', '23108', '4670811', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '北原町', 'キタハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区薩摩町', '23', '23108', '4670812', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '薩摩町', 'サツマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区西ノ割町', '23', '23108', '4670813', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '西ノ割町', 'ニシノワリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区本願寺町', '23', '23108', '4670814', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '本願寺町', 'ホンガンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区前田町', '23', '23108', '4670815', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '前田町', 'マエダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区牧町', '23', '23108', '4670816', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '牧町', 'マキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区上坂町', '23', '23108', '4670821', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '上坂町', 'カミサカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区大喜町', '23', '23108', '4670822', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '大喜町', 'ダイギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区津賀田町', '23', '23108', '4670823', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '津賀田町', 'ツカタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区甲山町', '23', '23108', '4670824', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '甲山町', 'カブトヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区柳ケ枝町', '23', '23108', '4670825', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '柳ケ枝町', 'ヤナガエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区白龍町', '23', '23108', '4670826', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '白龍町', 'ハクリュウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区下坂町', '23', '23108', '4670827', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '下坂町', 'シモサカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区田光町', '23', '23108', '4670828', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '田光町', 'タコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区惣作町', '23', '23108', '4670831', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '惣作町', 'ソウサクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区神前町', '23', '23108', '4670832', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '神前町', 'カミマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区鍵田町', '23', '23108', '4670833', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '鍵田町', 'カギタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区姫宮町', '23', '23108', '4670834', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '姫宮町', 'ヒメミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区井戸田町', '23', '23108', '4670835', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '井戸田町', 'イドタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区佃町', '23', '23108', '4670836', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '佃町', 'ツクダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区花目町', '23', '23108', '4670837', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '花目町', 'ハナメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区苗代町', '23', '23108', '4670841', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '苗代町', 'ナエシロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区妙音通', '23', '23108', '4670842', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '妙音通', 'ミョウオントオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区土市町', '23', '23108', '4670843', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '土市町', 'ドイチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区河岸町', '23', '23108', '4670844', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '河岸町', 'カワギシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区河岸', '23', '23108', '4670845', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '河岸', 'カワギシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区荒崎町', '23', '23108', '4670846', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '荒崎町', 'アラサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区神穂町', '23', '23108', '4670847', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '神穂町', 'カミホチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区塩入町', '23', '23108', '4670851', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '塩入町', 'シオイリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区明前町', '23', '23108', '4670852', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '明前町', 'メイゼンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区内浜町', '23', '23108', '4670853', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '内浜町', 'ウチハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区浮島町', '23', '23108', '4670854', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '浮島町', 'ウキシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区桃園町', '23', '23108', '4670855', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '桃園町', 'モモゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区新開町', '23', '23108', '4670856', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '新開町', 'シンカイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区二野町', '23', '23108', '4670861', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '二野町', 'フタノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区堀田通', '23', '23108', '4670862', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '堀田通', 'ホリタトオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区牛巻町', '23', '23108', '4670863', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '牛巻町', 'ウシマキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区豆田町', '23', '23108', '4670864', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '豆田町', 'マメダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区直来町', '23', '23108', '4670865', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '直来町', 'ナオライチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区宝田町', '23', '23108', '4670866', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '宝田町', 'ホウデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区春敲町', '23', '23108', '4670867', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '春敲町', 'シュンコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区大喜新町', '23', '23108', '4670868', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '大喜新町', 'ダイギシンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区須田町', '23', '23108', '4670871', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '須田町', 'スダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区高辻町', '23', '23108', '4670872', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '高辻町', 'タカツジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区竹田町', '23', '23108', '4670873', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '竹田町', 'タケダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区太田町', '23', '23108', '4670874', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '太田町', 'オオタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区御劔町', '23', '23108', '4670875', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '御劔町', 'ミツルギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区亀城町', '23', '23108', '4670876', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '亀城町', 'カメシロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区雁道町', '23', '23108', '4670877', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '雁道町', 'ガンミチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区船原町', '23', '23108', '4670878', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '船原町', 'フナバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('45972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市瑞穂区平郷町', '23', '23108', '4670879', '愛知県', 'アイチケン', '名古屋市瑞穂区', 'ナゴヤシミズホク', '平郷町', 'ヘイゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市天白区', '23', '23116', '4680000', '愛知県', 'アイチケン', '名古屋市天白区', 'ナゴヤシテンパクク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('46010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市天白区植田山', '23', '23116', '4680001', '愛知県', 'アイチケン', '名古屋市天白区', 'ナゴヤシテンパクク', '植田山', 'ウエダヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市天白区焼山', '23', '23116', '4680002', '愛知県', 'アイチケン', '名古屋市天白区', 'ナゴヤシテンパクク', '焼山', 'ヤキヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市天白区鴻の巣', '23', '23116', '4680003', '愛知県', 'アイチケン', '名古屋市天白区', 'ナゴヤシテンパクク', '鴻の巣', 'コウノス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市天白区梅が丘', '23', '23116', '4680004', '愛知県', 'アイチケン', '名古屋市天白区', 'ナゴヤシテンパクク', '梅が丘', 'ウメガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市天白区天白町植田', '23', '23116', '4680005', '愛知県', 'アイチケン', '名古屋市天白区', 'ナゴヤシテンパクク', '天白町植田', 'テンパクチョウウエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市天白区植田東', '23', '23116', '4680006', '愛知県', 'アイチケン', '名古屋市天白区', 'ナゴヤシテンパクク', '植田東', 'ウエダヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市天白区植田本町', '23', '23116', '4680007', '愛知県', 'アイチケン', '名古屋市天白区', 'ナゴヤシテンパクク', '植田本町', 'ウエダホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市天白区一本松', '23', '23116', '4680008', '愛知県', 'アイチケン', '名古屋市天白区', 'ナゴヤシテンパクク', '一本松', 'イッポンマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市天白区元植田', '23', '23116', '4680009', '愛知県', 'アイチケン', '名古屋市天白区', 'ナゴヤシテンパクク', '元植田', 'モトウエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市天白区平針', '23', '23116', '4680011', '愛知県', 'アイチケン', '名古屋市天白区', 'ナゴヤシテンパクク', '平針', 'ヒラバリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市天白区向が丘', '23', '23116', '4680012', '愛知県', 'アイチケン', '名古屋市天白区', 'ナゴヤシテンパクク', '向が丘', 'ムカイガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市天白区荒池', '23', '23116', '4680013', '愛知県', 'アイチケン', '名古屋市天白区', 'ナゴヤシテンパクク', '荒池', 'アライケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市天白区中平', '23', '23116', '4680014', '愛知県', 'アイチケン', '名古屋市天白区', 'ナゴヤシテンパクク', '中平', 'ナカヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市天白区原', '23', '23116', '4680015', '愛知県', 'アイチケン', '名古屋市天白区', 'ナゴヤシテンパクク', '原', 'ハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市天白区平針南', '23', '23116', '4680020', '愛知県', 'アイチケン', '名古屋市天白区', 'ナゴヤシテンパクク', '平針南', 'ヒラバリミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市天白区天白町平針', '23', '23116', '4680021', '愛知県', 'アイチケン', '名古屋市天白区', 'ナゴヤシテンパクク', '天白町平針', 'テンパクチョウヒラバリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市天白区高島', '23', '23116', '4680022', '愛知県', 'アイチケン', '名古屋市天白区', 'ナゴヤシテンパクク', '高島', 'タカシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市天白区御前場町', '23', '23116', '4680023', '愛知県', 'アイチケン', '名古屋市天白区', 'ナゴヤシテンパクク', '御前場町', 'ゴゼンバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市天白区大根町', '23', '23116', '4680024', '愛知県', 'アイチケン', '名古屋市天白区', 'ナゴヤシテンパクク', '大根町', 'オオネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市天白区高坂町', '23', '23116', '4680025', '愛知県', 'アイチケン', '名古屋市天白区', 'ナゴヤシテンパクク', '高坂町', 'タカサカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市天白区土原', '23', '23116', '4680026', '愛知県', 'アイチケン', '名古屋市天白区', 'ナゴヤシテンパクク', '土原', 'ツチハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市天白区天白町島田', '23', '23116', '4680027', '愛知県', 'アイチケン', '名古屋市天白区', 'ナゴヤシテンパクク', '天白町島田', 'テンパクチョウシマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市天白区島田黒石', '23', '23116', '4680028', '愛知県', 'アイチケン', '名古屋市天白区', 'ナゴヤシテンパクク', '島田黒石', 'シマダクロイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市天白区島田が丘', '23', '23116', '4680029', '愛知県', 'アイチケン', '名古屋市天白区', 'ナゴヤシテンパクク', '島田が丘', 'シマダガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市天白区平針台', '23', '23116', '4680030', '愛知県', 'アイチケン', '名古屋市天白区', 'ナゴヤシテンパクク', '平針台', 'ヒラバリダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市天白区高宮町', '23', '23116', '4680031', '愛知県', 'アイチケン', '名古屋市天白区', 'ナゴヤシテンパクク', '高宮町', 'タカミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市天白区山郷町', '23', '23116', '4680032', '愛知県', 'アイチケン', '名古屋市天白区', 'ナゴヤシテンパクク', '山郷町', 'サンゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市天白区一つ山', '23', '23116', '4680033', '愛知県', 'アイチケン', '名古屋市天白区', 'ナゴヤシテンパクク', '一つ山', 'ヒトツヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市天白区久方', '23', '23116', '4680034', '愛知県', 'アイチケン', '名古屋市天白区', 'ナゴヤシテンパクク', '久方', 'ヒサカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市天白区境根町', '23', '23116', '4680035', '愛知県', 'アイチケン', '名古屋市天白区', 'ナゴヤシテンパクク', '境根町', 'サカイネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市天白区天白町野並', '23', '23116', '4680037', '愛知県', 'アイチケン', '名古屋市天白区', 'ナゴヤシテンパクク', '天白町野並', 'テンパクチョウノナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市天白区山根町', '23', '23116', '4680038', '愛知県', 'アイチケン', '名古屋市天白区', 'ナゴヤシテンパクク', '山根町', 'ヤマネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市天白区西入町', '23', '23116', '4680039', '愛知県', 'アイチケン', '名古屋市天白区', 'ナゴヤシテンパクク', '西入町', 'ニシイリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市天白区保呂町', '23', '23116', '4680041', '愛知県', 'アイチケン', '名古屋市天白区', 'ナゴヤシテンパクク', '保呂町', 'ホロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市天白区海老山町', '23', '23116', '4680042', '愛知県', 'アイチケン', '名古屋市天白区', 'ナゴヤシテンパクク', '海老山町', 'エビヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市天白区菅田', '23', '23116', '4680043', '愛知県', 'アイチケン', '名古屋市天白区', 'ナゴヤシテンパクク', '菅田', 'スゲタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市天白区笹原町', '23', '23116', '4680044', '愛知県', 'アイチケン', '名古屋市天白区', 'ナゴヤシテンパクク', '笹原町', 'ササハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市天白区野並', '23', '23116', '4680045', '愛知県', 'アイチケン', '名古屋市天白区', 'ナゴヤシテンパクク', '野並', 'ノナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市天白区古川町', '23', '23116', '4680046', '愛知県', 'アイチケン', '名古屋市天白区', 'ナゴヤシテンパクク', '古川町', 'フルカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市天白区井の森町', '23', '23116', '4680047', '愛知県', 'アイチケン', '名古屋市天白区', 'ナゴヤシテンパクク', '井の森町', 'イノモリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市天白区中坪町', '23', '23116', '4680048', '愛知県', 'アイチケン', '名古屋市天白区', 'ナゴヤシテンパクク', '中坪町', 'ナカツボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市天白区福池', '23', '23116', '4680049', '愛知県', 'アイチケン', '名古屋市天白区', 'ナゴヤシテンパクク', '福池', 'フクイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市天白区植田', '23', '23116', '4680051', '愛知県', 'アイチケン', '名古屋市天白区', 'ナゴヤシテンパクク', '植田', 'ウエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市天白区井口', '23', '23116', '4680052', '愛知県', 'アイチケン', '名古屋市天白区', 'ナゴヤシテンパクク', '井口', 'イグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市天白区植田南', '23', '23116', '4680053', '愛知県', 'アイチケン', '名古屋市天白区', 'ナゴヤシテンパクク', '植田南', 'ウエダミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市天白区横町', '23', '23116', '4680054', '愛知県', 'アイチケン', '名古屋市天白区', 'ナゴヤシテンパクク', '横町', 'ヨコマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市天白区池場', '23', '23116', '4680055', '愛知県', 'アイチケン', '名古屋市天白区', 'ナゴヤシテンパクク', '池場', 'イケバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市天白区島田', '23', '23116', '4680056', '愛知県', 'アイチケン', '名古屋市天白区', 'ナゴヤシテンパクク', '島田', 'シマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市天白区植田西', '23', '23116', '4680058', '愛知県', 'アイチケン', '名古屋市天白区', 'ナゴヤシテンパクク', '植田西', 'ウエダニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市天白区八事天道', '23', '23116', '4680061', '愛知県', 'アイチケン', '名古屋市天白区', 'ナゴヤシテンパクク', '八事天道', 'ヤゴトテンドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市天白区弥生が岡', '23', '23116', '4680062', '愛知県', 'アイチケン', '名古屋市天白区', 'ナゴヤシテンパクク', '弥生が岡', 'ヤヨイガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市天白区音聞山', '23', '23116', '4680063', '愛知県', 'アイチケン', '名古屋市天白区', 'ナゴヤシテンパクク', '音聞山', 'オトキキヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市天白区道明町', '23', '23116', '4680064', '愛知県', 'アイチケン', '名古屋市天白区', 'ナゴヤシテンパクク', '道明町', 'ドウミョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市天白区中砂町', '23', '23116', '4680065', '愛知県', 'アイチケン', '名古屋市天白区', 'ナゴヤシテンパクク', '中砂町', 'ナカスナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市天白区元八事', '23', '23116', '4680066', '愛知県', 'アイチケン', '名古屋市天白区', 'ナゴヤシテンパクク', '元八事', 'モトヤゴト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市天白区池見', '23', '23116', '4680067', '愛知県', 'アイチケン', '名古屋市天白区', 'ナゴヤシテンパクク', '池見', 'イケミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市天白区表台', '23', '23116', '4680068', '愛知県', 'アイチケン', '名古屋市天白区', 'ナゴヤシテンパクク', '表台', 'オモテダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市天白区表山', '23', '23116', '4680069', '愛知県', 'アイチケン', '名古屋市天白区', 'ナゴヤシテンパクク', '表山', 'オモテヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市天白区天白町八事', '23', '23116', '4680071', '愛知県', 'アイチケン', '名古屋市天白区', 'ナゴヤシテンパクク', '天白町八事', 'テンパクチョウヤゴト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市天白区大坪', '23', '23116', '4680072', '愛知県', 'アイチケン', '名古屋市天白区', 'ナゴヤシテンパクク', '大坪', 'オオツボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市天白区塩釜口', '23', '23116', '4680073', '愛知県', 'アイチケン', '名古屋市天白区', 'ナゴヤシテンパクク', '塩釜口', 'シオガマグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市天白区八幡山', '23', '23116', '4680074', '愛知県', 'アイチケン', '名古屋市天白区', 'ナゴヤシテンパクク', '八幡山', 'ハチマンヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市天白区御幸山', '23', '23116', '4680075', '愛知県', 'アイチケン', '名古屋市天白区', 'ナゴヤシテンパクク', '御幸山', 'ミユキヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市天白区八事石坂', '23', '23116', '4680076', '愛知県', 'アイチケン', '名古屋市天白区', 'ナゴヤシテンパクク', '八事石坂', 'ヤゴトイシザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市天白区八事山', '23', '23116', '4680077', '愛知県', 'アイチケン', '名古屋市天白区', 'ナゴヤシテンパクク', '八事山', 'ヤゴトヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県名古屋市天白区相川', '23', '23116', '4680836', '愛知県', 'アイチケン', '名古屋市天白区', 'ナゴヤシテンパクク', '相川', 'アイカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道小樽市', '01', '01203', '0470000', '北海道', 'ホッカイドウ', '小樽市', 'オタルシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('46108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道小樽市若竹町', '01', '01203', '0470001', '北海道', 'ホッカイドウ', '小樽市', 'オタルシ', '若竹町', 'ワカタケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道小樽市潮見台', '01', '01203', '0470002', '北海道', 'ホッカイドウ', '小樽市', 'オタルシ', '潮見台', 'シオミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道小樽市真栄', '01', '01203', '0470003', '北海道', 'ホッカイドウ', '小樽市', 'オタルシ', '真栄', 'マサカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道小樽市新富町', '01', '01203', '0470004', '北海道', 'ホッカイドウ', '小樽市', 'オタルシ', '新富町', 'シントミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道小樽市勝納町', '01', '01203', '0470005', '北海道', 'ホッカイドウ', '小樽市', 'オタルシ', '勝納町', 'カツナイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道小樽市有幌町', '01', '01203', '0470006', '北海道', 'ホッカイドウ', '小樽市', 'オタルシ', '有幌町', 'アリホロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道小樽市港町', '01', '01203', '0470007', '北海道', 'ホッカイドウ', '小樽市', 'オタルシ', '港町', 'ミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道小樽市築港', '01', '01203', '0470008', '北海道', 'ホッカイドウ', '小樽市', 'オタルシ', '築港', 'チッコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県日進市', '23', '23230', '4700100', '愛知県', 'アイチケン', '日進市', 'ニッシンシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('46117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛知郡東郷町', '23', '23302', '4700100', '愛知県', 'アイチケン', '愛知郡東郷町', 'アイチグントウゴウチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('46118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県日進市三本木町', '23', '23230', '4700101', '愛知県', 'アイチケン', '日進市', 'ニッシンシ', '三本木町', 'サンボンギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県日進市藤島町', '23', '23230', '4700102', '愛知県', 'アイチケン', '日進市', 'ニッシンシ', '藤島町', 'フジシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県日進市北新町', '23', '23230', '4700103', '愛知県', 'アイチケン', '日進市', 'ニッシンシ', '北新町', 'キタシンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県日進市岩藤町', '23', '23230', '4700104', '愛知県', 'アイチケン', '日進市', 'ニッシンシ', '岩藤町', 'イワフジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県日進市五色園', '23', '23230', '4700105', '愛知県', 'アイチケン', '日進市', 'ニッシンシ', '五色園', 'ゴシキエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道小樽市天神', '01', '01203', '0470011', '北海道', 'ホッカイドウ', '小樽市', 'オタルシ', '天神', 'テンジン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県日進市米野木町', '23', '23230', '4700111', '愛知県', 'アイチケン', '日進市', 'ニッシンシ', '米野木町', 'コメノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県日進市藤枝町', '23', '23230', '4700112', '愛知県', 'アイチケン', '日進市', 'ニッシンシ', '藤枝町', 'フジエダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県日進市栄', '23', '23230', '4700113', '愛知県', 'アイチケン', '日進市', 'ニッシンシ', '栄', 'サカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県日進市南ケ丘', '23', '23230', '4700114', '愛知県', 'アイチケン', '日進市', 'ニッシンシ', '南ケ丘', 'ミナミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県日進市折戸町', '23', '23230', '4700115', '愛知県', 'アイチケン', '日進市', 'ニッシンシ', '折戸町', 'オリドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県日進市東山', '23', '23230', '4700116', '愛知県', 'アイチケン', '日進市', 'ニッシンシ', '東山', 'ヒガシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県日進市藤塚', '23', '23230', '4700117', '愛知県', 'アイチケン', '日進市', 'ニッシンシ', '藤塚', 'フジツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道小樽市天狗山', '01', '01203', '0470012', '北海道', 'ホッカイドウ', '小樽市', 'オタルシ', '天狗山', 'テングヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県日進市本郷町', '23', '23230', '4700121', '愛知県', 'アイチケン', '日進市', 'ニッシンシ', '本郷町', 'ホンゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県日進市蟹甲町', '23', '23230', '4700122', '愛知県', 'アイチケン', '日進市', 'ニッシンシ', '蟹甲町', 'カニコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県日進市野方町', '23', '23230', '4700123', '愛知県', 'アイチケン', '日進市', 'ニッシンシ', '野方町', 'ノカタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県日進市浅田町', '23', '23230', '4700124', '愛知県', 'アイチケン', '日進市', 'ニッシンシ', '浅田町', 'アサダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県日進市赤池', '23', '23230', '4700125', '愛知県', 'アイチケン', '日進市', 'ニッシンシ', '赤池', 'アカイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県日進市赤池町', '23', '23230', '4700126', '愛知県', 'アイチケン', '日進市', 'ニッシンシ', '赤池町', 'アカイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県日進市赤池南', '23', '23230', '4700127', '愛知県', 'アイチケン', '日進市', 'ニッシンシ', '赤池南', 'アカイケミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道小樽市奥沢', '01', '01203', '0470013', '北海道', 'ホッカイドウ', '小樽市', 'オタルシ', '奥沢', 'オクサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県日進市岩崎町', '23', '23230', '4700131', '愛知県', 'アイチケン', '日進市', 'ニッシンシ', '岩崎町', 'イワサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県日進市梅森町', '23', '23230', '4700132', '愛知県', 'アイチケン', '日進市', 'ニッシンシ', '梅森町', 'ウメモリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県日進市梅森台', '23', '23230', '4700133', '愛知県', 'アイチケン', '日進市', 'ニッシンシ', '梅森台', 'ウメモリダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県日進市香久山', '23', '23230', '4700134', '愛知県', 'アイチケン', '日進市', 'ニッシンシ', '香久山', 'カグヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県日進市岩崎台', '23', '23230', '4700135', '愛知県', 'アイチケン', '日進市', 'ニッシンシ', '岩崎台', 'イワサキダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県日進市竹の山', '23', '23230', '4700136', '愛知県', 'アイチケン', '日進市', 'ニッシンシ', '竹の山', 'タケノヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道小樽市住ノ江', '01', '01203', '0470014', '北海道', 'ホッカイドウ', '小樽市', 'オタルシ', '住ノ江', 'スミノエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道小樽市住吉町', '01', '01203', '0470015', '北海道', 'ホッカイドウ', '小樽市', 'オタルシ', '住吉町', 'スミヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛知郡東郷町諸輪', '23', '23302', '4700151', '愛知県', 'アイチケン', '愛知郡東郷町', 'アイチグントウゴウチョウ', '諸輪', 'モロワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛知郡東郷町北山台', '23', '23302', '4700152', '愛知県', 'アイチケン', '愛知郡東郷町', 'アイチグントウゴウチョウ', '北山台', 'キタヤマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛知郡東郷町和合', '23', '23302', '4700153', '愛知県', 'アイチケン', '愛知郡東郷町', 'アイチグントウゴウチョウ', '和合', 'ワゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛知郡東郷町和合ケ丘', '23', '23302', '4700154', '愛知県', 'アイチケン', '愛知郡東郷町', 'アイチグントウゴウチョウ', '和合ケ丘', 'ワゴウガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛知郡東郷町白鳥', '23', '23302', '4700155', '愛知県', 'アイチケン', '愛知郡東郷町', 'アイチグントウゴウチョウ', '白鳥', 'シラトリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛知郡東郷町御岳', '23', '23302', '4700156', '愛知県', 'アイチケン', '愛知郡東郷町', 'アイチグントウゴウチョウ', '御岳', 'ミタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道小樽市信香町', '01', '01203', '0470016', '北海道', 'ホッカイドウ', '小樽市', 'オタルシ', '信香町', 'ノブカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛知郡東郷町春木台', '23', '23302', '4700161', '愛知県', 'アイチケン', '愛知郡東郷町', 'アイチグントウゴウチョウ', '春木台', 'ハルキダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛知郡東郷町春木', '23', '23302', '4700162', '愛知県', 'アイチケン', '愛知郡東郷町', 'アイチグントウゴウチョウ', '春木', 'ハルキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛知郡東郷町涼松', '23', '23302', '4700163', '愛知県', 'アイチケン', '愛知郡東郷町', 'アイチグントウゴウチョウ', '涼松', 'スズミマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛知郡東郷町三ツ池', '23', '23302', '4700164', '愛知県', 'アイチケン', '愛知郡東郷町', 'アイチグントウゴウチョウ', '三ツ池', 'ミツイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛知郡東郷町清水', '23', '23302', '4700165', '愛知県', 'アイチケン', '愛知郡東郷町', 'アイチグントウゴウチョウ', '清水', 'シミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛知郡東郷町兵庫', '23', '23302', '4700166', '愛知県', 'アイチケン', '愛知郡東郷町', 'アイチグントウゴウチョウ', '兵庫', 'ヒョウゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道小樽市若松', '01', '01203', '0470017', '北海道', 'ホッカイドウ', '小樽市', 'オタルシ', '若松', 'ワカマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西加茂郡三好町', '23', '23521', '4700200', '愛知県', 'アイチケン', '西加茂郡三好町', 'ニシカモグンミヨシチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('46169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西加茂郡三好町黒笹', '23', '23521', '4700201', '愛知県', 'アイチケン', '西加茂郡三好町', 'ニシカモグンミヨシチョウ', '黒笹', 'クロザサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西加茂郡三好町三好丘', '23', '23521', '4700202', '愛知県', 'アイチケン', '西加茂郡三好町', 'ニシカモグンミヨシチョウ', '三好丘', 'ミヨシガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西加茂郡三好町三好丘旭', '23', '23521', '4700203', '愛知県', 'アイチケン', '西加茂郡三好町', 'ニシカモグンミヨシチョウ', '三好丘旭', 'ミヨシガオカアサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西加茂郡三好町三好丘桜', '23', '23521', '4700204', '愛知県', 'アイチケン', '西加茂郡三好町', 'ニシカモグンミヨシチョウ', '三好丘桜', 'ミヨシガオカサクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西加茂郡三好町三好丘緑', '23', '23521', '4700205', '愛知県', 'アイチケン', '西加茂郡三好町', 'ニシカモグンミヨシチョウ', '三好丘緑', 'ミヨシガオカミドリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西加茂郡三好町莇生', '23', '23521', '4700206', '愛知県', 'アイチケン', '西加茂郡三好町', 'ニシカモグンミヨシチョウ', '莇生', 'アザブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西加茂郡三好町福谷', '23', '23521', '4700207', '愛知県', 'アイチケン', '西加茂郡三好町', 'ニシカモグンミヨシチョウ', '福谷', 'ウキガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西加茂郡三好町ひばりケ丘', '23', '23521', '4700208', '愛知県', 'アイチケン', '西加茂郡三好町', 'ニシカモグンミヨシチョウ', 'ひばりケ丘', 'ヒバリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西加茂郡三好町潮見', '23', '23521', '4700209', '愛知県', 'アイチケン', '西加茂郡三好町', 'ニシカモグンミヨシチョウ', '潮見', 'シオミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道小樽市入船', '01', '01203', '0470021', '北海道', 'ホッカイドウ', '小樽市', 'オタルシ', '入船', 'イリフネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西加茂郡三好町天王台', '23', '23521', '4700211', '愛知県', 'アイチケン', '西加茂郡三好町', 'ニシカモグンミヨシチョウ', '天王台', 'テンノウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西加茂郡三好町東山台', '23', '23521', '4700212', '愛知県', 'アイチケン', '西加茂郡三好町', 'ニシカモグンミヨシチョウ', '東山台', 'ヒガシヤマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西加茂郡三好町打越', '23', '23521', '4700213', '愛知県', 'アイチケン', '西加茂郡三好町', 'ニシカモグンミヨシチョウ', '打越', 'ウチコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西加茂郡三好町明知', '23', '23521', '4700214', '愛知県', 'アイチケン', '西加茂郡三好町', 'ニシカモグンミヨシチョウ', '明知', 'ミョウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西加茂郡三好町明知みなよし台', '23', '23521', '4700215', '愛知県', 'アイチケン', '西加茂郡三好町', 'ニシカモグンミヨシチョウ', '明知みなよし台', 'ミョウチミナヨシダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道小樽市松ケ枝', '01', '01203', '0470022', '北海道', 'ホッカイドウ', '小樽市', 'オタルシ', '松ケ枝', 'マツガエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西加茂郡三好町西陣取山', '23', '23521', '4700221', '愛知県', 'アイチケン', '西加茂郡三好町', 'ニシカモグンミヨシチョウ', '西陣取山', 'ニシジントリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西加茂郡三好町東陣取山', '23', '23521', '4700222', '愛知県', 'アイチケン', '西加茂郡三好町', 'ニシカモグンミヨシチョウ', '東陣取山', 'ヒガシジントリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西加茂郡三好町東蜂ケ池', '23', '23521', '4700223', '愛知県', 'アイチケン', '西加茂郡三好町', 'ニシカモグンミヨシチョウ', '東蜂ケ池', 'ヒガシハチガイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西加茂郡三好町三好', '23', '23521', '4700224', '愛知県', 'アイチケン', '西加茂郡三好町', 'ニシカモグンミヨシチョウ', '三好', 'ミヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西加茂郡三好町福田', '23', '23521', '4700225', '愛知県', 'アイチケン', '西加茂郡三好町', 'ニシカモグンミヨシチョウ', '福田', 'フクタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西加茂郡三好町西一色', '23', '23521', '4700226', '愛知県', 'アイチケン', '西加茂郡三好町', 'ニシカモグンミヨシチョウ', '西一色', 'ニシイシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西加茂郡三好町園原', '23', '23521', '4700227', '愛知県', 'アイチケン', '西加茂郡三好町', 'ニシカモグンミヨシチョウ', '園原', 'ソノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道小樽市最上', '01', '01203', '0470023', '北海道', 'ホッカイドウ', '小樽市', 'オタルシ', '最上', 'モガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道小樽市花園', '01', '01203', '0470024', '北海道', 'ホッカイドウ', '小樽市', 'オタルシ', '花園', 'ハナゾノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道小樽市山田町', '01', '01203', '0470025', '北海道', 'ホッカイドウ', '小樽市', 'オタルシ', '山田町', 'ヤマダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道小樽市東雲町', '01', '01203', '0470026', '北海道', 'ホッカイドウ', '小樽市', 'オタルシ', '東雲町', 'シノノメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道小樽市堺町', '01', '01203', '0470027', '北海道', 'ホッカイドウ', '小樽市', 'オタルシ', '堺町', 'サカイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道小樽市相生町', '01', '01203', '0470028', '北海道', 'ホッカイドウ', '小樽市', 'オタルシ', '相生町', 'アイオイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市松嶺町', '23', '23211', '4700301', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '松嶺町', 'マツミネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市藤沢町', '23', '23211', '4700302', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '藤沢町', 'フジサワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市押沢町', '23', '23211', '4700303', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '押沢町', 'オシザワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市富田町', '23', '23211', '4700304', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '富田町', 'トミダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市国附町', '23', '23211', '4700305', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '国附町', 'クニツキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市小峯町', '23', '23211', '4700306', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '小峯町', 'コミネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市東広瀬町', '23', '23211', '4700307', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '東広瀬町', 'ヒガシヒロセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市枝下町', '23', '23211', '4700308', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '枝下町', 'シダレチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市西広瀬町', '23', '23211', '4700309', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '西広瀬町', 'ニシヒロセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道小樽市色内', '01', '01203', '0470031', '北海道', 'ホッカイドウ', '小樽市', 'オタルシ', '色内', 'イロナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市芳友町', '23', '23211', '4700311', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '芳友町', 'ホウユウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市中金町', '23', '23211', '4700312', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '中金町', 'ナカガネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市城見町', '23', '23211', '4700313', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '城見町', 'シロミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市野口町', '23', '23211', '4700314', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '野口町', 'ノグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市中切町', '23', '23211', '4700315', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '中切町', 'ナカギリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市千鳥町', '23', '23211', '4700316', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '千鳥町', 'チドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市成合町', '23', '23211', '4700317', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '成合町', 'ナライチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市力石町', '23', '23211', '4700318', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '力石町', 'チカライシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市下室町', '23', '23211', '4700319', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '下室町', 'シモムロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道小樽市稲穂', '01', '01203', '0470032', '北海道', 'ホッカイドウ', '小樽市', 'オタルシ', '稲穂', 'イナホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市山中町', '23', '23211', '4700321', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '山中町', 'ヤマナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市上高町', '23', '23211', '4700322', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '上高町', 'カミタカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市小呂町', '23', '23211', '4700323', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '小呂町', 'オロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市滝見町', '23', '23211', '4700324', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '滝見町', 'タキミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市手呂町', '23', '23211', '4700325', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '手呂町', 'テロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市手呂町樋田', '23', '23211', '4700326', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '手呂町樋田', 'テロチョウトイタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市寺下町', '23', '23211', '4700327', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '寺下町', 'テラシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市勘八町', '23', '23211', '4700328', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '勘八町', 'カンパチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市石野町', '23', '23211', '4700329', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '石野町', 'イシノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道小樽市富岡', '01', '01203', '0470033', '北海道', 'ホッカイドウ', '小樽市', 'オタルシ', '富岡', 'トミオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市平戸橋町', '23', '23211', '4700331', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '平戸橋町', 'ヒラトバシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市越戸町', '23', '23211', '4700332', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '越戸町', 'コシドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市荒井町', '23', '23211', '4700333', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '荒井町', 'アライチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市花本町', '23', '23211', '4700334', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '花本町', 'ハナモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市青木町', '23', '23211', '4700335', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '青木町', 'アオキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道小樽市緑', '01', '01203', '0470034', '北海道', 'ホッカイドウ', '小樽市', 'オタルシ', '緑', 'ミドリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市上原町', '23', '23211', '4700341', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '上原町', 'ウワハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市大清水町', '23', '23211', '4700342', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '大清水町', 'オオシミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市浄水町', '23', '23211', '4700343', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '浄水町', 'ジョウスイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市保見町', '23', '23211', '4700344', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '保見町', 'ホミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市東保見町', '23', '23211', '4700345', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '東保見町', 'ヒガシホミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市乙部ケ丘', '23', '23211', '4700346', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '乙部ケ丘', 'オトベガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市乙部町', '23', '23211', '4700347', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '乙部町', 'オトベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市貝津町', '23', '23211', '4700348', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '貝津町', 'カイヅチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道小樽市旭町', '01', '01203', '0470035', '北海道', 'ホッカイドウ', '小樽市', 'オタルシ', '旭町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市広幡町', '23', '23211', '4700351', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '広幡町', 'ヒロハタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市篠原町', '23', '23211', '4700352', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '篠原町', 'ササバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市保見ケ丘', '23', '23211', '4700353', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '保見ケ丘', 'ホミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市田籾町', '23', '23211', '4700354', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '田籾町', 'タモミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市大畑町', '23', '23211', '4700355', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '大畑町', 'オオバタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市八草町', '23', '23211', '4700356', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '八草町', 'ヤクサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道小樽市長橋', '01', '01203', '0470036', '北海道', 'ホッカイドウ', '小樽市', 'オタルシ', '長橋', 'ナガハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市猿投町', '23', '23211', '4700361', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '猿投町', 'サナゲチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市舞木町', '23', '23211', '4700362', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '舞木町', 'マイギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市本徳町', '23', '23211', '4700363', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '本徳町', 'ホントクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市加納町', '23', '23211', '4700364', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '加納町', 'カノウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道小樽市幸', '01', '01203', '0470037', '北海道', 'ホッカイドウ', '小樽市', 'オタルシ', '幸', 'サイワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市御船町', '23', '23211', '4700371', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '御船町', 'ミフネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市井上町', '23', '23211', '4700372', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '井上町', 'イノウエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市四郷町', '23', '23211', '4700373', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '四郷町', 'シゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市伊保町', '23', '23211', '4700374', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '伊保町', 'イボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市亀首町', '23', '23211', '4700375', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '亀首町', 'カメクビチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市高町', '23', '23211', '4700376', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '高町', 'タカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道小樽市石山町', '01', '01203', '0470038', '北海道', 'ホッカイドウ', '小樽市', 'オタルシ', '石山町', 'イシヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道小樽市錦町', '01', '01203', '0470039', '北海道', 'ホッカイドウ', '小樽市', 'オタルシ', '錦町', 'ニシキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市大岩町', '23', '23211', '4700401', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '大岩町', 'オオイワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市三箇町', '23', '23211', '4700402', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '三箇町', 'サンガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市白川町', '23', '23211', '4700403', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '白川町', 'シラカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市西市野々町', '23', '23211', '4700404', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '西市野々町', 'ニシイチノノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道小樽市手宮', '01', '01203', '0470041', '北海道', 'ホッカイドウ', '小樽市', 'オタルシ', '手宮', 'テミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市木瀬町', '23', '23211', '4700411', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '木瀬町', 'キセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道小樽市末広町', '01', '01203', '0470042', '北海道', 'ホッカイドウ', '小樽市', 'オタルシ', '末広町', 'スエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市上川口町', '23', '23211', '4700421', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '上川口町', 'カミカワグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市下川口町', '23', '23211', '4700422', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '下川口町', 'シモカワグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市田茂平町', '23', '23211', '4700423', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '田茂平町', 'タモダイラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市御作町', '23', '23211', '4700424', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '御作町', 'ミツクリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道小樽市豊川町', '01', '01203', '0470043', '北海道', 'ホッカイドウ', '小樽市', 'オタルシ', '豊川町', 'トヨカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市西中山町', '23', '23211', '4700431', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '西中山町', 'ニシナカヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道小樽市梅ケ枝町', '01', '01203', '0470044', '北海道', 'ホッカイドウ', '小樽市', 'オタルシ', '梅ケ枝町', 'ウメガエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市深見町', '23', '23211', '4700441', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '深見町', 'フカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道小樽市清水町', '01', '01203', '0470045', '北海道', 'ホッカイドウ', '小樽市', 'オタルシ', '清水町', 'シミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市藤岡飯野町', '23', '23211', '4700451', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '藤岡飯野町', 'フジオカイイノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市迫町', '23', '23211', '4700452', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '迫町', 'ハサマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市北一色町', '23', '23211', '4700453', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '北一色町', 'キタイシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道小樽市赤岩', '01', '01203', '0470046', '北海道', 'ホッカイドウ', '小樽市', 'オタルシ', '赤岩', 'アカイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市北曽木町', '23', '23211', '4700461', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '北曽木町', 'ホクソギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市上渡合町', '23', '23211', '4700462', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '上渡合町', 'カミドアイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市石飛町', '23', '23211', '4700463', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '石飛町', 'イシトビチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市折平町', '23', '23211', '4700464', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '折平町', 'オリダイラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道小樽市祝津', '01', '01203', '0470047', '北海道', 'ホッカイドウ', '小樽市', 'オタルシ', '祝津', 'シュクツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市石畳町', '23', '23211', '4700471', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '石畳町', 'イシダタミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道小樽市高島', '01', '01203', '0470048', '北海道', 'ホッカイドウ', '小樽市', 'オタルシ', '高島', 'タカシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市小原田代町', '23', '23211', '4700501', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '小原田代町', 'オバラタシロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市小原北町', '23', '23211', '4700502', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '小原北町', 'オバラキタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市前洞町', '23', '23211', '4700503', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '前洞町', 'マエボラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市雑敷町', '23', '23211', '4700504', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '雑敷町', 'ザツシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市柏ケ洞町', '23', '23211', '4700505', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '柏ケ洞町', 'カシガホラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市川見町', '23', '23211', '4700506', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '川見町', 'センミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市大ケ蔵連町', '23', '23211', '4700511', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '大ケ蔵連町', 'オオガゾレチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市東郷町', '23', '23211', '4700512', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '東郷町', 'トウゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市苅萱町', '23', '23211', '4700513', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '苅萱町', 'カルカヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市平岩町', '23', '23211', '4700514', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '平岩町', 'ヒライワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市岩下町', '23', '23211', '4700515', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '岩下町', 'イワシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市宮代町', '23', '23211', '4700516', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '宮代町', 'ミヤシロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市西丹波町', '23', '23211', '4700521', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '西丹波町', 'ニシタンバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市榑俣町', '23', '23211', '4700522', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '榑俣町', 'クレマタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市平畑町', '23', '23211', '4700523', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '平畑町', 'ヒラハタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市日面町', '23', '23211', '4700524', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '日面町', 'ヒオモチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市簗平町', '23', '23211', '4700525', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '簗平町', 'ヤナダイラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市西細田町', '23', '23211', '4700526', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '西細田町', 'ニシホソダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市小原町', '23', '23211', '4700531', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '小原町', 'オバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市大坂町', '23', '23211', '4700532', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '大坂町', 'オオサカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市鍛治屋敷町', '23', '23211', '4700533', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '鍛治屋敷町', 'カジヤシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市李町', '23', '23211', '4700534', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '李町', 'スモモチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市百月町', '23', '23211', '4700535', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '百月町', 'ドウヅキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市西萩平町', '23', '23211', '4700541', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '西萩平町', 'ニシハギノヒラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市喜佐平町', '23', '23211', '4700542', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '喜佐平町', 'キサダイラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市北篠平町', '23', '23211', '4700543', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '北篠平町', 'キタササダイラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市寺平町', '23', '23211', '4700544', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '寺平町', 'テラダイラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市千洗町', '23', '23211', '4700545', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '千洗町', 'チアライチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市三ツ久保町', '23', '23211', '4700551', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '三ツ久保町', 'ミツクボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市乙ケ林町', '23', '23211', '4700552', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '乙ケ林町', 'オカバヤシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市大洞町', '23', '23211', '4700553', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '大洞町', 'オオボラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市荷掛町', '23', '23211', '4700554', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '荷掛町', 'ニカケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市大平町', '23', '23211', '4700555', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '大平町', 'オオダイラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市上仁木町', '23', '23211', '4700561', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '上仁木町', 'カミニギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市永太郎町', '23', '23211', '4700562', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '永太郎町', 'エイタロウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市遊屋町', '23', '23211', '4700563', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '遊屋町', 'ユヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市沢田町', '23', '23211', '4700564', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '沢田町', 'サワダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市下仁木町', '23', '23211', '4700565', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '下仁木町', 'シモニギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市松名町', '23', '23211', '4700571', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '松名町', 'マツナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市小原大倉町', '23', '23211', '4700572', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '小原大倉町', 'オバラオオクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市北大野町', '23', '23211', '4700573', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '北大野町', 'キタオオノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市市場町', '23', '23211', '4700574', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '市場町', 'イチバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市川下町', '23', '23211', '4700575', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '川下町', 'カワシモチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊明市', '23', '23229', '4701100', '愛知県', 'アイチケン', '豊明市', 'トヨアケシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('46349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊明市沓掛町', '23', '23229', '4701101', '愛知県', 'アイチケン', '豊明市', 'トヨアケシ', '沓掛町', 'クツカケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊明市沓掛町勅使', '23', '23229', '4701102', '愛知県', 'アイチケン', '豊明市', 'トヨアケシ', '沓掛町', 'クツカケチョウ', null, null, '勅使', 'チョクシ');
INSERT INTO `ms_addresses` VALUES ('46351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊明市沓掛町小廻間', '23', '23229', '4701103', '愛知県', 'アイチケン', '豊明市', 'トヨアケシ', '沓掛町', 'クツカケチョウ', null, null, '小廻間', 'コハザマ');
INSERT INTO `ms_addresses` VALUES ('46352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊明市沓掛町五反田', '23', '23229', '4701104', '愛知県', 'アイチケン', '豊明市', 'トヨアケシ', '沓掛町', 'クツカケチョウ', null, null, '五反田', 'ゴタンダ');
INSERT INTO `ms_addresses` VALUES ('46353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊明市沓掛町上高根', '23', '23229', '4701105', '愛知県', 'アイチケン', '豊明市', 'トヨアケシ', '沓掛町', 'クツカケチョウ', null, null, '上高根', 'カミタカネ');
INSERT INTO `ms_addresses` VALUES ('46354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊明市沓掛町下高根', '23', '23229', '4701106', '愛知県', 'アイチケン', '豊明市', 'トヨアケシ', '沓掛町', 'クツカケチョウ', null, null, '下高根', 'シモタカネ');
INSERT INTO `ms_addresses` VALUES ('46355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊明市沓掛町泉', '23', '23229', '4701107', '愛知県', 'アイチケン', '豊明市', 'トヨアケシ', '沓掛町', 'クツカケチョウ', null, null, '泉', 'イズミ');
INSERT INTO `ms_addresses` VALUES ('46356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊明市沓掛町荒井', '23', '23229', '4701108', '愛知県', 'アイチケン', '豊明市', 'トヨアケシ', '沓掛町', 'クツカケチョウ', null, null, '荒井', 'アライ');
INSERT INTO `ms_addresses` VALUES ('46357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊明市沓掛町宿', '23', '23229', '4701109', '愛知県', 'アイチケン', '豊明市', 'トヨアケシ', '沓掛町', 'クツカケチョウ', null, null, '宿', 'シュク');
INSERT INTO `ms_addresses` VALUES ('46358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊明市大久伝町', '23', '23229', '4701111', '愛知県', 'アイチケン', '豊明市', 'トヨアケシ', '大久伝町', 'オオクテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊明市新田町', '23', '23229', '4701112', '愛知県', 'アイチケン', '豊明市', 'トヨアケシ', '新田町', 'シンデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊明市新田町錦', '23', '23229', '4701113', '愛知県', 'アイチケン', '豊明市', 'トヨアケシ', '新田町', 'シンデンチョウ', null, null, '錦', 'ニシキ');
INSERT INTO `ms_addresses` VALUES ('46361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊明市新田町広長', '23', '23229', '4701114', '愛知県', 'アイチケン', '豊明市', 'トヨアケシ', '新田町', 'シンデンチョウ', null, null, '広長', 'ヒロナガ');
INSERT INTO `ms_addresses` VALUES ('46362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊明市新田町前原', '23', '23229', '4701115', '愛知県', 'アイチケン', '豊明市', 'トヨアケシ', '新田町', 'シンデンチョウ', null, null, '前原', 'マエバラ');
INSERT INTO `ms_addresses` VALUES ('46363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊明市新田町吉池', '23', '23229', '4701116', '愛知県', 'アイチケン', '豊明市', 'トヨアケシ', '新田町', 'シンデンチョウ', null, null, '吉池', 'ヨシイケ');
INSERT INTO `ms_addresses` VALUES ('46364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊明市西川町', '23', '23229', '4701121', '愛知県', 'アイチケン', '豊明市', 'トヨアケシ', '西川町', 'ニシガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊明市西川町長田', '23', '23229', '4701122', '愛知県', 'アイチケン', '豊明市', 'トヨアケシ', '西川町', 'ニシガワチョウ', null, null, '長田', 'オサダ');
INSERT INTO `ms_addresses` VALUES ('46366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊明市西川町笹原', '23', '23229', '4701123', '愛知県', 'アイチケン', '豊明市', 'トヨアケシ', '西川町', 'ニシガワチョウ', null, null, '笹原', 'ササハラ');
INSERT INTO `ms_addresses` VALUES ('46367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊明市三崎町', '23', '23229', '4701124', '愛知県', 'アイチケン', '豊明市', 'トヨアケシ', '三崎町', 'ミサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊明市三崎町中ノ坪', '23', '23229', '4701125', '愛知県', 'アイチケン', '豊明市', 'トヨアケシ', '三崎町', 'ミサキチョウ', null, null, '中ノ坪', 'ナカノツボ');
INSERT INTO `ms_addresses` VALUES ('46369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊明市三崎町高鴨', '23', '23229', '4701126', '愛知県', 'アイチケン', '豊明市', 'トヨアケシ', '三崎町', 'ミサキチョウ', null, null, '高鴨', 'タカガモ');
INSERT INTO `ms_addresses` VALUES ('46370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊明市三崎町ゆたか台', '23', '23229', '4701127', '愛知県', 'アイチケン', '豊明市', 'トヨアケシ', '三崎町', 'ミサキチョウ', null, null, 'ゆたか台', 'ユタカダイ');
INSERT INTO `ms_addresses` VALUES ('46371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊明市二村台', '23', '23229', '4701131', '愛知県', 'アイチケン', '豊明市', 'トヨアケシ', '二村台', 'フタムラダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊明市間米町', '23', '23229', '4701132', '愛知県', 'アイチケン', '豊明市', 'トヨアケシ', '間米町', 'マゴメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊明市間米町鶴根', '23', '23229', '4701133', '愛知県', 'アイチケン', '豊明市', 'トヨアケシ', '間米町', 'マゴメチョウ', null, null, '鶴根', 'ツルネ');
INSERT INTO `ms_addresses` VALUES ('46374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊明市阿野町', '23', '23229', '4701141', '愛知県', 'アイチケン', '豊明市', 'トヨアケシ', '阿野町', 'アノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊明市阿野町東阿野', '23', '23229', '4701142', '愛知県', 'アイチケン', '豊明市', 'トヨアケシ', '阿野町', 'アノチョウ', null, null, '東阿野', 'ヒガシアノ');
INSERT INTO `ms_addresses` VALUES ('46376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊明市阿野町上納', '23', '23229', '4701143', '愛知県', 'アイチケン', '豊明市', 'トヨアケシ', '阿野町', 'アノチョウ', null, null, '上納', 'ジョウノウ');
INSERT INTO `ms_addresses` VALUES ('46377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊明市阿野町稲葉', '23', '23229', '4701144', '愛知県', 'アイチケン', '豊明市', 'トヨアケシ', '阿野町', 'アノチョウ', null, null, '稲葉', 'イナバ');
INSERT INTO `ms_addresses` VALUES ('46378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊明市阿野町北上ノ山', '23', '23229', '4701145', '愛知県', 'アイチケン', '豊明市', 'トヨアケシ', '阿野町', 'アノチョウ', null, null, '北上ノ山', 'キタウエノヤマ');
INSERT INTO `ms_addresses` VALUES ('46379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊明市阿野町黒部', '23', '23229', '4701146', '愛知県', 'アイチケン', '豊明市', 'トヨアケシ', '阿野町', 'アノチョウ', null, null, '黒部', 'クロベ');
INSERT INTO `ms_addresses` VALUES ('46380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊明市阿野町坂部', '23', '23229', '4701147', '愛知県', 'アイチケン', '豊明市', 'トヨアケシ', '阿野町', 'アノチョウ', null, null, '坂部', 'サカベ');
INSERT INTO `ms_addresses` VALUES ('46381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊明市阿野町滑', '23', '23229', '4701148', '愛知県', 'アイチケン', '豊明市', 'トヨアケシ', '阿野町', 'アノチョウ', null, null, '滑', 'ナメリ');
INSERT INTO `ms_addresses` VALUES ('46382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊明市前後町', '23', '23229', '4701151', '愛知県', 'アイチケン', '豊明市', 'トヨアケシ', '前後町', 'ゼンゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊明市前後町仙人塚', '23', '23229', '4701152', '愛知県', 'アイチケン', '豊明市', 'トヨアケシ', '前後町', 'ゼンゴチョウ', null, null, '仙人塚', 'センニンヅカ');
INSERT INTO `ms_addresses` VALUES ('46384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊明市前後町三ツ谷', '23', '23229', '4701153', '愛知県', 'アイチケン', '豊明市', 'トヨアケシ', '前後町', 'ゼンゴチョウ', null, null, '三ツ谷', 'ミツヤ');
INSERT INTO `ms_addresses` VALUES ('46385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊明市新栄町', '23', '23229', '4701154', '愛知県', 'アイチケン', '豊明市', 'トヨアケシ', '新栄町', 'シンサカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊明市栄町', '23', '23229', '4701161', '愛知県', 'アイチケン', '豊明市', 'トヨアケシ', '栄町', 'サカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊明市栄町上姥子', '23', '23229', '4701162', '愛知県', 'アイチケン', '豊明市', 'トヨアケシ', '栄町', 'サカエチョウ', null, null, '上姥子', 'カミウバコ');
INSERT INTO `ms_addresses` VALUES ('46388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊明市栄町姥子', '23', '23229', '4701163', '愛知県', 'アイチケン', '豊明市', 'トヨアケシ', '栄町', 'サカエチョウ', null, null, '姥子', 'ウバコ');
INSERT INTO `ms_addresses` VALUES ('46389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊明市栄町大蔵下', '23', '23229', '4701164', '愛知県', 'アイチケン', '豊明市', 'トヨアケシ', '栄町', 'サカエチョウ', null, null, '大蔵下', 'オオグラシタ');
INSERT INTO `ms_addresses` VALUES ('46390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊明市栄町内山', '23', '23229', '4701165', '愛知県', 'アイチケン', '豊明市', 'トヨアケシ', '栄町', 'サカエチョウ', null, null, '内山', 'ウチヤマ');
INSERT INTO `ms_addresses` VALUES ('46391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊明市栄町大根', '23', '23229', '4701166', '愛知県', 'アイチケン', '豊明市', 'トヨアケシ', '栄町', 'サカエチョウ', null, null, '大根', 'オオネ');
INSERT INTO `ms_addresses` VALUES ('46392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊明市栄町西大根', '23', '23229', '4701167', '愛知県', 'アイチケン', '豊明市', 'トヨアケシ', '栄町', 'サカエチョウ', null, null, '西大根', 'ニシオオネ');
INSERT INTO `ms_addresses` VALUES ('46393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊明市栄町南舘', '23', '23229', '4701168', '愛知県', 'アイチケン', '豊明市', 'トヨアケシ', '栄町', 'サカエチョウ', null, null, '南舘', 'ミナミヤカタ');
INSERT INTO `ms_addresses` VALUES ('46400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市豊栄町', '23', '23211', '4701201', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '豊栄町', 'ホウエイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市渡刈町', '23', '23211', '4701202', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '渡刈町', 'トガリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市幸町', '23', '23211', '4701203', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市配津町', '23', '23211', '4701204', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '配津町', 'ハイヅチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市永覚町', '23', '23211', '4701205', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '永覚町', 'エカクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市永覚新町', '23', '23211', '4701206', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '永覚新町', 'エカクシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市鴛鴨町', '23', '23211', '4701207', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '鴛鴨町', 'オシカモチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市畝部東町', '23', '23211', '4701211', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '畝部東町', 'ウネベヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市桝塚東町', '23', '23211', '4701212', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '桝塚東町', 'マスヅカヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市桝塚西町', '23', '23211', '4701213', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '桝塚西町', 'マスヅカニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市福受町', '23', '23211', '4701214', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '福受町', 'フクジュチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市広美町', '23', '23211', '4701215', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '広美町', 'ヒロミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市和会町', '23', '23211', '4701216', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '和会町', 'カズエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市大成町', '23', '23211', '4701217', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '大成町', 'タイセイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市上郷町', '23', '23211', '4701218', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '上郷町', 'カミゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市畝部西町', '23', '23211', '4701219', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '畝部西町', 'ウネベニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道小樽市朝里', '01', '01203', '0470151', '北海道', 'ホッカイドウ', '小樽市', 'オタルシ', '朝里', 'アサリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道小樽市新光', '01', '01203', '0470152', '北海道', 'ホッカイドウ', '小樽市', 'オタルシ', '新光', 'シンコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道小樽市新光町', '01', '01203', '0470153', '北海道', 'ホッカイドウ', '小樽市', 'オタルシ', '新光町', 'シンコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道小樽市朝里川温泉', '01', '01203', '0470154', '北海道', 'ホッカイドウ', '小樽市', 'オタルシ', '朝里川温泉', 'アサリガワオンセン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道小樽市望洋台', '01', '01203', '0470155', '北海道', 'ホッカイドウ', '小樽市', 'オタルシ', '望洋台', 'ボウヨウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道小樽市桜', '01', '01203', '0470156', '北海道', 'ホッカイドウ', '小樽市', 'オタルシ', '桜', 'サクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道小樽市船浜町', '01', '01203', '0470157', '北海道', 'ホッカイドウ', '小樽市', 'オタルシ', '船浜町', 'フナハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡東浦町', '23', '23442', '4702100', '愛知県', 'アイチケン', '知多郡東浦町', 'チタグンヒガシウラチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('46430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡東浦町森岡', '23', '23442', '4702101', '愛知県', 'アイチケン', '知多郡東浦町', 'チタグンヒガシウラチョウ', '森岡', 'モリオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡東浦町緒川', '23', '23442', '4702102', '愛知県', 'アイチケン', '知多郡東浦町', 'チタグンヒガシウラチョウ', '緒川', 'オガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡東浦町石浜', '23', '23442', '4702103', '愛知県', 'アイチケン', '知多郡東浦町', 'チタグンヒガシウラチョウ', '石浜', 'イシハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡東浦町生路', '23', '23442', '4702104', '愛知県', 'アイチケン', '知多郡東浦町', 'チタグンヒガシウラチョウ', '生路', 'イクジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡東浦町藤江', '23', '23442', '4702105', '愛知県', 'アイチケン', '知多郡東浦町', 'チタグンヒガシウラチョウ', '藤江', 'フジエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡阿久比町', '23', '23441', '4702200', '愛知県', 'アイチケン', '知多郡阿久比町', 'チタグンアグイチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('46441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡阿久比町白沢', '23', '23441', '4702201', '愛知県', 'アイチケン', '知多郡阿久比町', 'チタグンアグイチョウ', '白沢', 'シラサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡阿久比町福住', '23', '23441', '4702202', '愛知県', 'アイチケン', '知多郡阿久比町', 'チタグンアグイチョウ', '福住', 'フクスミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡阿久比町板山', '23', '23441', '4702203', '愛知県', 'アイチケン', '知多郡阿久比町', 'チタグンアグイチョウ', '板山', 'イタヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡阿久比町宮津', '23', '23441', '4702204', '愛知県', 'アイチケン', '知多郡阿久比町', 'チタグンアグイチョウ', '宮津', 'ミヤヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡阿久比町萩', '23', '23441', '4702205', '愛知県', 'アイチケン', '知多郡阿久比町', 'チタグンアグイチョウ', '萩', 'ハギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡阿久比町横松', '23', '23441', '4702206', '愛知県', 'アイチケン', '知多郡阿久比町', 'チタグンアグイチョウ', '横松', 'ヨコマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡阿久比町草木', '23', '23441', '4702211', '愛知県', 'アイチケン', '知多郡阿久比町', 'チタグンアグイチョウ', '草木', 'クサギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡阿久比町卯坂', '23', '23441', '4702212', '愛知県', 'アイチケン', '知多郡阿久比町', 'チタグンアグイチョウ', '卯坂', 'ウサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡阿久比町阿久比', '23', '23441', '4702213', '愛知県', 'アイチケン', '知多郡阿久比町', 'チタグンアグイチョウ', '阿久比', 'アグイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡阿久比町椋岡', '23', '23441', '4702214', '愛知県', 'アイチケン', '知多郡阿久比町', 'チタグンアグイチョウ', '椋岡', 'ムクオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡阿久比町矢高', '23', '23441', '4702215', '愛知県', 'アイチケン', '知多郡阿久比町', 'チタグンアグイチョウ', '矢高', 'ヤタカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡阿久比町植大', '23', '23441', '4702216', '愛知県', 'アイチケン', '知多郡阿久比町', 'チタグンアグイチョウ', '植大', 'ウエダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町', '23', '23447', '4702300', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('46458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町壱町田', '23', '23447', '4702301', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '壱町田', 'イッチョウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町鹿ノ子田', '23', '23447', '4702302', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '鹿ノ子田', 'カノコダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町祠峯', '23', '23447', '4702303', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '祠峯', 'ホコラミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町平井田', '23', '23447', '4702304', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '平井田', 'ヒライダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町下山ノ田', '23', '23447', '4702305', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '下山ノ田', 'シモヤマノタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町上山ノ田', '23', '23447', '4702306', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '上山ノ田', 'カミヤマノタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町蛇ケ谷', '23', '23447', '4702307', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '蛇ケ谷', 'ヂャガタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町二ツ峰', '23', '23447', '4702308', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '二ツ峰', 'フタツミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町梨子ノ木', '23', '23447', '4702309', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '梨子ノ木', 'ナシノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町石川', '23', '23447', '4702311', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '石川', 'イシカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町北曲輪', '23', '23447', '4702312', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '北曲輪', 'キタグルワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町九号地', '23', '23447', '4702313', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '九号地', 'キュウゴウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町浅水', '23', '23447', '4702314', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '浅水', 'アサミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町中狭', '23', '23447', '4702315', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '中狭', 'ナカバサミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町二ケ崎', '23', '23447', '4702316', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '二ケ崎', 'ニガサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町砂川', '23', '23447', '4702317', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '砂川', 'スナガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町豊成', '23', '23447', '4702318', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '豊成', 'ホウセイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町中蓮', '23', '23447', '4702319', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '中蓮', 'チュウレン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町七号地', '23', '23447', '4702321', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '七号地', 'ナナゴウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町塩田', '23', '23447', '4702322', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '塩田', 'シオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町口田', '23', '23447', '4702323', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '口田', 'クチダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町内鉋', '23', '23447', '4702324', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '内鉋', 'ウチカンナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町若宮', '23', '23447', '4702325', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '若宮', 'ワカミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町平井畑', '23', '23447', '4702326', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '平井畑', 'ヒライバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町天神前', '23', '23447', '4702327', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '天神前', 'テンジンマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町蛇渕', '23', '23447', '4702328', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '蛇渕', 'ヂャブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町池田', '23', '23447', '4702329', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '池田', 'イケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町ヒジリ田', '23', '23447', '4702331', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', 'ヒジリ田', 'ヒジリダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町上ケ', '23', '23447', '4702332', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '上ケ', 'アゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町高野前', '23', '23447', '4702333', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '高野前', 'タカノマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町中根', '23', '23447', '4702334', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '中根', 'ナカネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町谷口', '23', '23447', '4702335', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '谷口', 'タニグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町山ノ神', '23', '23447', '4702336', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '山ノ神', 'ヤマノカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町ヱケ屋敷', '23', '23447', '4702337', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', 'ヱケ屋敷', 'エゲヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町前田', '23', '23447', '4702338', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '前田', 'マエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町下門', '23', '23447', '4702339', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '下門', 'シタモン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町五号地', '23', '23447', '4702341', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '五号地', 'ゴゴウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町沢田新田', '23', '23447', '4702342', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '沢田新田', 'サワダシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町小迎', '23', '23447', '4702343', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '小迎', 'コムカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町金下', '23', '23447', '4702344', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '金下', 'カナゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町西門', '23', '23447', '4702345', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '西門', 'ニシモン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町長尾山', '23', '23447', '4702346', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '長尾山', 'ナガオヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町道崎', '23', '23447', '4702347', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '道崎', 'ドウサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町瀬木', '23', '23447', '4702348', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '瀬木', 'セギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町西田崎', '23', '23447', '4702349', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '西田崎', 'ニシタザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町南中根', '23', '23447', '4702351', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '南中根', 'ミナミナカネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町迎戸', '23', '23447', '4702352', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '迎戸', 'ムカエド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町道崎田', '23', '23447', '4702353', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '道崎田', 'ドウサキダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町川尻', '23', '23447', '4702354', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '川尻', 'カワジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町向田', '23', '23447', '4702355', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '向田', 'ムカイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町下起', '23', '23447', '4702356', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '下起', 'シモオコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町向陽', '23', '23447', '4702357', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '向陽', 'コウヨウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町楠', '23', '23447', '4702358', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '楠', 'クスノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町桜ケ丘', '23', '23447', '4702359', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '桜ケ丘', 'サクラガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町多賀', '23', '23447', '4702361', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '多賀', 'タガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町六貫山', '23', '23447', '4702362', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '六貫山', 'ロッカンヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町旭ケ丘', '23', '23447', '4702363', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '旭ケ丘', 'アサヒガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町上起', '23', '23447', '4702364', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '上起', 'カミオコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町壱畝町', '23', '23447', '4702365', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '壱畝町', 'ヒトセマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町ヲヲガケ', '23', '23447', '4702366', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', 'ヲヲガケ', 'オオガケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町下原', '23', '23447', '4702371', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '下原', 'シモハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町甚田', '23', '23447', '4702372', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '甚田', 'ヂンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町嶋田', '23', '23447', '4702373', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '嶋田', 'シマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町原田', '23', '23447', '4702374', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '原田', 'ハラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町原屋敷', '23', '23447', '4702375', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '原屋敷', 'ハラヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町上原', '23', '23447', '4702376', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '上原', 'カミハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町会下', '23', '23447', '4702377', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '会下', 'エゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町南小松谷', '23', '23447', '4702378', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '南小松谷', 'ミナミコマツダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町北小松谷', '23', '23447', '4702379', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '北小松谷', 'キタコマツダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町平井', '23', '23447', '4702380', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '平井', 'ヒライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町東長宗', '23', '23447', '4702382', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '東長宗', 'ヒガシナガムネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町北長宗', '23', '23447', '4702383', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '北長宗', 'キタナガムネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町青木ケ丘', '23', '23447', '4702384', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '青木ケ丘', 'アオキガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町北中根', '23', '23447', '4702385', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '北中根', 'キタナカネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町緑台', '23', '23447', '4702386', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '緑台', 'ミドリダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町上山', '23', '23447', '4702387', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '上山', 'カミヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町中山', '23', '23447', '4702388', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '中山', 'ナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町長宗', '23', '23447', '4702389', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '長宗', 'ナガムネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡美浜町布土', '23', '23446', '4702401', '愛知県', 'アイチケン', '知多郡美浜町', 'チタグンミハマチョウ', '布土', 'フット', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡美浜町時志', '23', '23446', '4702402', '愛知県', 'アイチケン', '知多郡美浜町', 'チタグンミハマチョウ', '時志', 'トキシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡美浜町北方', '23', '23446', '4702403', '愛知県', 'アイチケン', '知多郡美浜町', 'チタグンミハマチョウ', '北方', 'キタガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡美浜町河和', '23', '23446', '4702404', '愛知県', 'アイチケン', '知多郡美浜町', 'チタグンミハマチョウ', '河和', 'コウワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡美浜町河和台', '23', '23446', '4702405', '愛知県', 'アイチケン', '知多郡美浜町', 'チタグンミハマチョウ', '河和台', 'コウワダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡美浜町河和北田面', '23', '23446', '4702406', '愛知県', 'アイチケン', '知多郡美浜町', 'チタグンミハマチョウ', '河和', 'コウワ', null, null, '北田面', 'キタダメン');
INSERT INTO `ms_addresses` VALUES ('46546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡美浜町河和北屋敷', '23', '23446', '4702407', '愛知県', 'アイチケン', '知多郡美浜町', 'チタグンミハマチョウ', '河和', 'コウワ', null, null, '北屋敷', 'キタヤシキ');
INSERT INTO `ms_addresses` VALUES ('46547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡美浜町河和南屋敷', '23', '23446', '4702408', '愛知県', 'アイチケン', '知多郡美浜町', 'チタグンミハマチョウ', '河和', 'コウワ', null, null, '南屋敷', 'ミナミヤシキ');
INSERT INTO `ms_addresses` VALUES ('46548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡美浜町河和上前田', '23', '23446', '4702409', '愛知県', 'アイチケン', '知多郡美浜町', 'チタグンミハマチョウ', '河和', 'コウワ', null, null, '上前田', 'カミマエダ');
INSERT INTO `ms_addresses` VALUES ('46549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡美浜町新浦戸', '23', '23446', '4702411', '愛知県', 'アイチケン', '知多郡美浜町', 'チタグンミハマチョウ', '新浦戸', 'シンウラト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡美浜町浦戸', '23', '23446', '4702412', '愛知県', 'アイチケン', '知多郡美浜町', 'チタグンミハマチョウ', '浦戸', 'ウラト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡美浜町古布', '23', '23446', '4702413', '愛知県', 'アイチケン', '知多郡美浜町', 'チタグンミハマチョウ', '古布', 'コフ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡美浜町豊丘', '23', '23446', '4702414', '愛知県', 'アイチケン', '知多郡美浜町', 'チタグンミハマチョウ', '豊丘', 'トヨオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町堀割', '23', '23447', '4702501', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '堀割', 'ホリワリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町明神戸', '23', '23447', '4702502', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '明神戸', 'ミョウジンド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町後畑', '23', '23447', '4702503', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '後畑', 'ウシロバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町熊野', '23', '23447', '4702504', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '熊野', 'クマノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町田崎', '23', '23447', '4702505', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '田崎', 'タザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町後田', '23', '23447', '4702506', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '後田', 'ウシロダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町平海道', '23', '23447', '4702507', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '平海道', 'ヘイカイドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町川脇', '23', '23447', '4702508', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '川脇', 'カワワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町道仙田', '23', '23447', '4702511', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '道仙田', 'ドウセンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町忠白田', '23', '23447', '4702512', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '忠白田', 'チュウシロダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町一号地', '23', '23447', '4702513', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '一号地', 'イチゴウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町旭', '23', '23447', '4702514', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '旭', 'アサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町下田', '23', '23447', '4702515', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '下田', 'シモダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町廻間', '23', '23447', '4702516', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '廻間', 'ハザマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町長峰', '23', '23447', '4702517', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '長峰', 'ナガミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町東大高', '23', '23447', '4702521', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '東大高', 'ヒガシオオダカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町冨貴', '23', '23447', '4702531', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '冨貴', 'フキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町竜宮', '23', '23447', '4702532', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '竜宮', 'リュウグウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町目堀', '23', '23447', '4702541', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '目堀', 'メボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町土穴', '23', '23447', '4702542', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '土穴', 'ツチアナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町大屋敷', '23', '23447', '4702543', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '大屋敷', 'オオヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町里中', '23', '23447', '4702544', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '里中', 'サトナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町前畑', '23', '23447', '4702545', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '前畑', 'マエハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町山起', '23', '23447', '4702546', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '山起', 'ヤマオコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町北新田', '23', '23447', '4702547', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '北新田', 'キタシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町石田', '23', '23447', '4702551', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '石田', 'イシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町草口', '23', '23447', '4702552', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '草口', 'クサグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町四畝', '23', '23447', '4702553', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '四畝', 'ヨセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町白山', '23', '23447', '4702554', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '白山', 'ハクサン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町大門田', '23', '23447', '4702555', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '大門田', 'ダイモンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡武豊町南起', '23', '23447', '4702556', '愛知県', 'アイチケン', '知多郡武豊町', 'チタグンタケトヨチョウ', '南起', 'ミナミオコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道小樽市銭函1丁目', '01', '01203', '0470261', '北海道', 'ホッカイドウ', '小樽市', 'オタルシ', '銭函', 'ゼニバコ', null, null, '1丁目', '01チョウメ');
INSERT INTO `ms_addresses` VALUES ('46587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道小樽市銭函2丁目', '01', '01203', '0470261', '北海道', 'ホッカイドウ', '小樽市', 'オタルシ', '銭函', 'ゼニバコ', null, null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('46588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道小樽市銭函3丁目', '01', '01203', '0470261', '北海道', 'ホッカイドウ', '小樽市', 'オタルシ', '銭函', 'ゼニバコ', null, null, '3丁目', '03チョウメ');
INSERT INTO `ms_addresses` VALUES ('46589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道小樽市星野町', '01', '01203', '0470262', '北海道', 'ホッカイドウ', '小樽市', 'オタルシ', '星野町', 'ホシノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道小樽市見晴町', '01', '01203', '0470263', '北海道', 'ホッカイドウ', '小樽市', 'オタルシ', '見晴町', 'ミハラシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道小樽市桂岡町', '01', '01203', '0470264', '北海道', 'ホッカイドウ', '小樽市', 'オタルシ', '桂岡町', 'カツラオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道小樽市春香町', '01', '01203', '0470265', '北海道', 'ホッカイドウ', '小樽市', 'オタルシ', '春香町', 'ハルカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道小樽市張碓町', '01', '01203', '0470266', '北海道', 'ホッカイドウ', '小樽市', 'オタルシ', '張碓町', 'ハリウスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡美浜町', '23', '23446', '4703200', '愛知県', 'アイチケン', '知多郡美浜町', 'チタグンミハマチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('46597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡美浜町上野間', '23', '23446', '4703231', '愛知県', 'アイチケン', '知多郡美浜町', 'チタグンミハマチョウ', '上野間', 'カミノマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡美浜町美浜緑苑', '23', '23446', '4703232', '愛知県', 'アイチケン', '知多郡美浜町', 'チタグンミハマチョウ', '美浜緑苑', 'ミハマリョクエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡美浜町奥田', '23', '23446', '4703233', '愛知県', 'アイチケン', '知多郡美浜町', 'チタグンミハマチョウ', '奥田', 'オクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡美浜町新栄', '23', '23446', '4703234', '愛知県', 'アイチケン', '知多郡美浜町', 'チタグンミハマチョウ', '新栄', 'シンサカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡美浜町野間', '23', '23446', '4703235', '愛知県', 'アイチケン', '知多郡美浜町', 'チタグンミハマチョウ', '野間', 'ノマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡美浜町小野浦', '23', '23446', '4703236', '愛知県', 'アイチケン', '知多郡美浜町', 'チタグンミハマチョウ', '小野浦', 'オノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡南知多町', '23', '23445', '4703300', '愛知県', 'アイチケン', '知多郡南知多町', 'チタグンミナミチタチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('46606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡南知多町内海', '23', '23445', '4703321', '愛知県', 'アイチケン', '知多郡南知多町', 'チタグンミナミチタチョウ', '内海', 'ウツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡南知多町山海', '23', '23445', '4703322', '愛知県', 'アイチケン', '知多郡南知多町', 'チタグンミナミチタチョウ', '山海', 'ヤマミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡南知多町豊丘', '23', '23445', '4703411', '愛知県', 'アイチケン', '知多郡南知多町', 'チタグンミナミチタチョウ', '豊丘', 'トヨオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡南知多町豊浜', '23', '23445', '4703412', '愛知県', 'アイチケン', '知多郡南知多町', 'チタグンミナミチタチョウ', '豊浜', 'トヨハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡南知多町大井', '23', '23445', '4703501', '愛知県', 'アイチケン', '知多郡南知多町', 'チタグンミナミチタチョウ', '大井', 'オオイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡南知多町片名', '23', '23445', '4703502', '愛知県', 'アイチケン', '知多郡南知多町', 'チタグンミナミチタチョウ', '片名', 'カタナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡南知多町師崎', '23', '23445', '4703503', '愛知県', 'アイチケン', '知多郡南知多町', 'チタグンミナミチタチョウ', '師崎', 'モロザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡南知多町日間賀島', '23', '23445', '4703504', '愛知県', 'アイチケン', '知多郡南知多町', 'チタグンミナミチタチョウ', '日間賀島', 'ヒマカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多郡南知多町篠島', '23', '23445', '4703505', '愛知県', 'アイチケン', '知多郡南知多町', 'チタグンミナミチタチョウ', '篠島', 'シノジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市', '23', '23211', '4710000', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('46617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市池田町', '23', '23211', '4710001', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '池田町', 'イケダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市矢並町', '23', '23211', '4710002', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '矢並町', 'ヤナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市岩滝町', '23', '23211', '4710003', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '岩滝町', 'イワタキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市双美町', '23', '23211', '4710004', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '双美町', 'フタミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市京ケ峰', '23', '23211', '4710005', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '京ケ峰', 'キョウガミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市市木町', '23', '23211', '4710006', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '市木町', 'イチギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市美和町', '23', '23211', '4710007', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '美和町', 'ミワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市百々町', '23', '23211', '4710008', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '百々町', 'ドウドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市扶桑町', '23', '23211', '4710009', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '扶桑町', 'フソウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市平井町', '23', '23211', '4710011', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '平井町', 'ヒライチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市水間町', '23', '23211', '4710012', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '水間町', 'ミズマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市高上', '23', '23211', '4710013', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '高上', 'タカガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市東山町', '23', '23211', '4710014', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '東山町', 'ヒガシヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市上野町', '23', '23211', '4710015', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '上野町', 'ウエノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市千石町', '23', '23211', '4710016', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '千石町', 'センゴクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市寺部町', '23', '23211', '4710017', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '寺部町', 'テラベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市社町', '23', '23211', '4710018', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '社町', 'ヤシロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市高橋町', '23', '23211', '4710019', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '高橋町', 'タカハシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市中島町', '23', '23211', '4710021', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '中島町', 'ナカジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市白浜町', '23', '23211', '4710022', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '白浜町', 'シラハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市挙母町', '23', '23211', '4710023', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '挙母町', 'コロモチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市元城町', '23', '23211', '4710024', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '元城町', 'モトシロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市西町', '23', '23211', '4710025', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '西町', 'ニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市若宮町', '23', '23211', '4710026', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '若宮町', 'ワカミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市喜多町', '23', '23211', '4710027', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '喜多町', 'キタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市神明町', '23', '23211', '4710028', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '神明町', 'シンメイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市桜町', '23', '23211', '4710029', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '桜町', 'サクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市朝日町', '23', '23211', '4710031', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '朝日町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市日南町', '23', '23211', '4710032', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '日南町', 'ニチナンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市月見町', '23', '23211', '4710033', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '月見町', 'ツキミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市小坂本町', '23', '23211', '4710034', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '小坂本町', 'コザカホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市小坂町', '23', '23211', '4710035', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '小坂町', 'コザカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市広久手町', '23', '23211', '4710036', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '広久手町', 'ヒロクテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市三軒町', '23', '23211', '4710037', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '三軒町', 'サンゲンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市宮上町', '23', '23211', '4710038', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '宮上町', 'ミヤガミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市汐見町', '23', '23211', '4710041', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '汐見町', 'シオミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市宮口町', '23', '23211', '4710042', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '宮口町', 'ミヤグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市宮町', '23', '23211', '4710043', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '宮町', 'ミヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市新町', '23', '23211', '4710044', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市東新町', '23', '23211', '4710045', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '東新町', 'トウシンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市本新町', '23', '23211', '4710046', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '本新町', 'ホンシンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市西新町', '23', '23211', '4710047', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '西新町', 'ニシシンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市高崎町', '23', '23211', '4710048', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '高崎町', 'タカサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市田町', '23', '23211', '4710049', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '田町', 'タマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市花丘町', '23', '23211', '4710051', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '花丘町', 'ハナオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市逢妻町', '23', '23211', '4710052', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '逢妻町', 'アイヅマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市丸根町', '23', '23211', '4710053', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '丸根町', 'マルネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市天王町', '23', '23211', '4710054', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '天王町', 'テンノウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市久岡町', '23', '23211', '4710055', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '久岡町', 'ヒサオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市白山町', '23', '23211', '4710056', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '白山町', 'ハクサンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市太平町', '23', '23211', '4710057', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '太平町', 'タイヘイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市大池町', '23', '23211', '4710058', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '大池町', 'オオイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市貞宝町', '23', '23211', '4710059', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '貞宝町', 'テイホウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市若草町', '23', '23211', '4710061', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '若草町', 'ワカクサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市西山町', '23', '23211', '4710062', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '西山町', 'ニシヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市京町', '23', '23211', '4710063', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '京町', 'キョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市梅坪町', '23', '23211', '4710064', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '梅坪町', 'ウメツボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市平芝町', '23', '23211', '4710065', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '平芝町', 'ヒラシバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市栄町', '23', '23211', '4710066', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市栄生町', '23', '23211', '4710067', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '栄生町', 'エイセイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市横山町', '23', '23211', '4710068', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '横山町', 'ヨコヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市高原町', '23', '23211', '4710069', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '高原町', 'タカハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市東梅坪町', '23', '23211', '4710071', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '東梅坪町', 'ヒガシウメツボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市落合町', '23', '23211', '4710072', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '落合町', 'オチアイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市川田町', '23', '23211', '4710073', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '川田町', 'カワダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市川端町', '23', '23211', '4710074', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '川端町', 'カワバタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市日之出町', '23', '23211', '4710075', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '日之出町', 'ヒノデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市久保町', '23', '23211', '4710076', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '久保町', 'クボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市竹生町', '23', '23211', '4710077', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '竹生町', 'タキョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市昭和町', '23', '23211', '4710078', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '昭和町', 'ショウワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市陣中町', '23', '23211', '4710079', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '陣中町', 'ジンナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市古瀬間町', '23', '23211', '4710801', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '古瀬間町', 'コセマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市志賀町', '23', '23211', '4710802', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '志賀町', 'シガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市泉町', '23', '23211', '4710803', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '泉町', 'イズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市神池町', '23', '23211', '4710804', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '神池町', 'カミイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市美里', '23', '23211', '4710805', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '美里', 'ミサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市森町', '23', '23211', '4710806', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '森町', 'モリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市広川町', '23', '23211', '4710807', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '広川町', 'ヒロカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市渋谷町', '23', '23211', '4710808', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '渋谷町', 'シブヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市宝来町', '23', '23211', '4710809', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '宝来町', 'ホウライチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市御立町', '23', '23211', '4710811', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '御立町', 'ミタチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市野見町', '23', '23211', '4710812', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '野見町', 'ノミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市野見山町', '23', '23211', '4710813', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '野見山町', 'ノミヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市五ケ丘', '23', '23211', '4710814', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '五ケ丘', 'イツツガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市大見町', '23', '23211', '4710815', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '大見町', 'オオミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市琴平町', '23', '23211', '4710816', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '琴平町', 'コトヒラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市渡合町', '23', '23211', '4710817', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '渡合町', 'ドアイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市室町', '23', '23211', '4710818', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '室町', 'ムロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市宮前町', '23', '23211', '4710819', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '宮前町', 'ミヤマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市平和町', '23', '23211', '4710821', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '平和町', 'ヘイワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市水源町', '23', '23211', '4710822', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '水源町', 'スイゲンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市今町', '23', '23211', '4710823', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '今町', 'イマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市河合町', '23', '23211', '4710824', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '河合町', 'カワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市明和町', '23', '23211', '4710825', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '明和町', 'メイワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市トヨタ町', '23', '23211', '4710826', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', 'トヨタ町', 'トヨタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市平山町', '23', '23211', '4710827', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '平山町', 'ヒラヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市前山町', '23', '23211', '4710828', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '前山町', 'マエヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市司町', '23', '23211', '4710831', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '司町', 'ツカサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市丸山町', '23', '23211', '4710832', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '丸山町', 'マルヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市山之手', '23', '23211', '4710833', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '山之手', 'ヤマノテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市寿町', '23', '23211', '4710834', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '寿町', 'コトブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市曙町', '23', '23211', '4710835', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '曙町', 'アケボノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市鴻ノ巣町', '23', '23211', '4710836', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '鴻ノ巣町', 'コウノスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市新生町', '23', '23211', '4710837', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '新生町', 'シンセイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市緑ケ丘', '23', '23211', '4710838', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '緑ケ丘', 'ミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市深田町', '23', '23211', '4710841', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '深田町', 'フカダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市土橋町', '23', '23211', '4710842', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '土橋町', 'ツチハシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市清水町', '23', '23211', '4710843', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '清水町', 'シミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市聖心町', '23', '23211', '4710844', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '聖心町', 'セイシンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市田中町', '23', '23211', '4710845', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '田中町', 'タナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市田代町', '23', '23211', '4710846', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '田代町', 'タシロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市千足町', '23', '23211', '4710847', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '千足町', 'センゾクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市本地町', '23', '23211', '4710848', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '本地町', 'ホンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市美山町', '23', '23211', '4710849', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '美山町', 'ミヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市樹木町', '23', '23211', '4710851', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '樹木町', 'ジュモクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市御幸町', '23', '23211', '4710852', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '御幸町', 'ミユキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市細谷町', '23', '23211', '4710853', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '細谷町', 'ホソヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市元町', '23', '23211', '4710854', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '元町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市柿本町', '23', '23211', '4710855', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '柿本町', 'カキモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市衣ケ原', '23', '23211', '4710856', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '衣ケ原', 'コロモガハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市小川町', '23', '23211', '4710857', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '小川町', 'オガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市朝日ケ丘', '23', '23211', '4710858', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '朝日ケ丘', 'アサヒガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市八幡町', '23', '23211', '4710861', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '八幡町', 'ハチマンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市砂町', '23', '23211', '4710862', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '砂町', 'スナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市瑞穂町', '23', '23211', '4710863', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '瑞穂町', 'ミズホチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市広路町', '23', '23211', '4710864', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '広路町', 'ヒロジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市松ケ枝町', '23', '23211', '4710865', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '松ケ枝町', 'マツガエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市上挙母', '23', '23211', '4710866', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '上挙母', 'ウワゴロモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市常盤町', '23', '23211', '4710867', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '常盤町', 'トキワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市神田町', '23', '23211', '4710868', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '神田町', 'カンダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市十塚町', '23', '23211', '4710869', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '十塚町', 'トヅカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市元宮町', '23', '23211', '4710871', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '元宮町', 'モトミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市竜宮町', '23', '23211', '4710872', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '竜宮町', 'リュウグウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市秋葉町', '23', '23211', '4710873', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '秋葉町', 'アキバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市前田町', '23', '23211', '4710874', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '前田町', 'マエダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市下市場町', '23', '23211', '4710875', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '下市場町', 'シモイチバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市金谷町', '23', '23211', '4710876', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '金谷町', 'カナヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市錦町', '23', '23211', '4710877', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '錦町', 'ニシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市下林町', '23', '23211', '4710878', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '下林町', 'シモバヤシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市長興寺', '23', '23211', '4710879', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '長興寺', 'チョウコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知立市', '23', '23225', '4720000', '愛知県', 'アイチケン', '知立市', 'チリュウシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('46793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知立市八橋町', '23', '23225', '4720001', '愛知県', 'アイチケン', '知立市', 'チリュウシ', '八橋町', 'ヤツハシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知立市来迎寺町', '23', '23225', '4720002', '愛知県', 'アイチケン', '知立市', 'チリュウシ', '来迎寺町', 'ライコウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知立市牛田', '23', '23225', '4720003', '愛知県', 'アイチケン', '知立市', 'チリュウシ', '牛田', 'ウシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知立市南陽', '23', '23225', '4720004', '愛知県', 'アイチケン', '知立市', 'チリュウシ', '南陽', 'ナンヨウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知立市新池', '23', '23225', '4720005', '愛知県', 'アイチケン', '知立市', 'チリュウシ', '新池', 'シンイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知立市山町', '23', '23225', '4720006', '愛知県', 'アイチケン', '知立市', 'チリュウシ', '山町', 'ヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知立市牛田町', '23', '23225', '4720007', '愛知県', 'アイチケン', '知立市', 'チリュウシ', '牛田町', 'ウシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知立市昭和', '23', '23225', '4720011', '愛知県', 'アイチケン', '知立市', 'チリュウシ', '昭和', 'ショウワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知立市八ツ田町', '23', '23225', '4720012', '愛知県', 'アイチケン', '知立市', 'チリュウシ', '八ツ田町', 'ヤツダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知立市谷田町', '23', '23225', '4720013', '愛知県', 'アイチケン', '知立市', 'チリュウシ', '谷田町', 'ヤタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知立市谷田町西', '23', '23225', '4720014', '愛知県', 'アイチケン', '知立市', 'チリュウシ', '谷田町西', 'ヤタチョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知立市谷田町本林', '23', '23225', '4720015', '愛知県', 'アイチケン', '知立市', 'チリュウシ', '谷田町本林', 'ヤタチョウホンバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知立市西中町', '23', '23225', '4720016', '愛知県', 'アイチケン', '知立市', 'チリュウシ', '西中町', 'ニシナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知立市新林町', '23', '23225', '4720017', '愛知県', 'アイチケン', '知立市', 'チリュウシ', '新林町', 'シンバヤシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知立市逢妻町', '23', '23225', '4720021', '愛知県', 'アイチケン', '知立市', 'チリュウシ', '逢妻町', 'アイヅマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知立市山屋敷町', '23', '23225', '4720022', '愛知県', 'アイチケン', '知立市', 'チリュウシ', '山屋敷町', 'ヤマヤシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知立市西町', '23', '23225', '4720023', '愛知県', 'アイチケン', '知立市', 'チリュウシ', '西町', 'ニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知立市宝町', '23', '23225', '4720024', '愛知県', 'アイチケン', '知立市', 'チリュウシ', '宝町', 'タカラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知立市池端', '23', '23225', '4720025', '愛知県', 'アイチケン', '知立市', 'チリュウシ', '池端', 'イケハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知立市上重原町', '23', '23225', '4720026', '愛知県', 'アイチケン', '知立市', 'チリュウシ', '上重原町', 'カミシゲハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知立市西丘町', '23', '23225', '4720027', '愛知県', 'アイチケン', '知立市', 'チリュウシ', '西丘町', 'ニシオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知立市桜木町', '23', '23225', '4720031', '愛知県', 'アイチケン', '知立市', 'チリュウシ', '桜木町', 'サクラギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知立市中山町', '23', '23225', '4720032', '愛知県', 'アイチケン', '知立市', 'チリュウシ', '中山町', 'ナカヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知立市中町', '23', '23225', '4720033', '愛知県', 'アイチケン', '知立市', 'チリュウシ', '中町', 'ナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知立市弘栄', '23', '23225', '4720034', '愛知県', 'アイチケン', '知立市', 'チリュウシ', '弘栄', 'コウエイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知立市長田', '23', '23225', '4720035', '愛知県', 'アイチケン', '知立市', 'チリュウシ', '長田', 'ナガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知立市堀切', '23', '23225', '4720036', '愛知県', 'アイチケン', '知立市', 'チリュウシ', '堀切', 'ホリキリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知立市栄', '23', '23225', '4720037', '愛知県', 'アイチケン', '知立市', 'チリュウシ', '栄', 'サカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知立市本町', '23', '23225', '4720038', '愛知県', 'アイチケン', '知立市', 'チリュウシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知立市新地町', '23', '23225', '4720041', '愛知県', 'アイチケン', '知立市', 'チリュウシ', '新地町', 'シンチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知立市内幸町', '23', '23225', '4720042', '愛知県', 'アイチケン', '知立市', 'チリュウシ', '内幸町', 'ウチサイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知立市東栄', '23', '23225', '4720043', '愛知県', 'アイチケン', '知立市', 'チリュウシ', '東栄', 'トウエイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知立市広見', '23', '23225', '4720044', '愛知県', 'アイチケン', '知立市', 'チリュウシ', '広見', 'ヒロミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知立市長篠町', '23', '23225', '4720045', '愛知県', 'アイチケン', '知立市', 'チリュウシ', '長篠町', 'ナガシノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知立市弘法町', '23', '23225', '4720046', '愛知県', 'アイチケン', '知立市', 'チリュウシ', '弘法町', 'コウボウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知立市新富', '23', '23225', '4720047', '愛知県', 'アイチケン', '知立市', 'チリュウシ', '新富', 'シントミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知立市東長篠', '23', '23225', '4720051', '愛知県', 'アイチケン', '知立市', 'チリュウシ', '東長篠', 'ヒガシナガシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知立市弘法', '23', '23225', '4720052', '愛知県', 'アイチケン', '知立市', 'チリュウシ', '弘法', 'コウボウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知立市南新地', '23', '23225', '4720053', '愛知県', 'アイチケン', '知立市', 'チリュウシ', '南新地', 'ミナミシンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知立市東上重原', '23', '23225', '4720054', '愛知県', 'アイチケン', '知立市', 'チリュウシ', '東上重原', 'ヒガシカミシゲハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知立市鳥居', '23', '23225', '4720055', '愛知県', 'アイチケン', '知立市', 'チリュウシ', '鳥居', 'トリイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知立市宝', '23', '23225', '4720056', '愛知県', 'アイチケン', '知立市', 'チリュウシ', '宝', 'タカラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知立市西', '23', '23225', '4720057', '愛知県', 'アイチケン', '知立市', 'チリュウシ', '西', 'ニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知立市上重原', '23', '23225', '4720058', '愛知県', 'アイチケン', '知立市', 'チリュウシ', '上重原', 'カミシゲハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市御幸本町', '23', '23211', '4730901', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '御幸本町', 'ミユキホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市大林町', '23', '23211', '4730902', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '大林町', 'オオバヤシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市西田町', '23', '23211', '4730903', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '西田町', 'ニシダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市中町', '23', '23211', '4730904', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '中町', 'ナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市住吉町', '23', '23211', '4730905', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '住吉町', 'スミヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市竹町', '23', '23211', '4730906', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '竹町', 'タケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市竜神町', '23', '23211', '4730907', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '竜神町', 'リュウジンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市宝町', '23', '23211', '4730908', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '宝町', 'タカラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市本町', '23', '23211', '4730911', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市広田町', '23', '23211', '4730912', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '広田町', 'ヒロタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市竹元町', '23', '23211', '4730913', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '竹元町', 'タケモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市若林東町', '23', '23211', '4730914', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '若林東町', 'ワカバヤシヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市若林東町中外根', '23', '23211', '4730915', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '若林東町中外根', 'ワカバヤシヒガシマチナカソトネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市吉原町', '23', '23211', '4730916', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '吉原町', 'ヨシワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市若林西町', '23', '23211', '4730917', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '若林西町', 'ワカバヤシニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市高美町', '23', '23211', '4730918', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '高美町', 'タカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市高丘新町', '23', '23211', '4730921', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '高丘新町', 'タカオカシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市高岡本町', '23', '23211', '4730922', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '高岡本町', 'タカオカホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市中根町', '23', '23211', '4730923', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '中根町', 'ナカネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市花園町', '23', '23211', '4730924', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '花園町', 'ハナゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市駒場町', '23', '23211', '4730925', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '駒場町', 'コマバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市駒新町', '23', '23211', '4730926', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '駒新町', 'コマシンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市中田町', '23', '23211', '4730927', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '中田町', 'ナカダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市生駒町', '23', '23211', '4730928', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '生駒町', 'イコマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市上丘町', '23', '23211', '4730931', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '上丘町', 'カミオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市堤町', '23', '23211', '4730932', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '堤町', 'ツツミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市高岡町', '23', '23211', '4730933', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '高岡町', 'タカオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市前林町', '23', '23211', '4730934', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '前林町', 'マエバヤシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市大島町', '23', '23211', '4730935', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '大島町', 'オオシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市西岡町', '23', '23211', '4730936', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '西岡町', 'ニシオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市西岡町星ケ丘', '23', '23211', '4730937', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '西岡町星ケ丘', 'ニシオカチョウホシガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市本田町', '23', '23211', '4730938', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '本田町', 'ホンダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県豊田市堤本町', '23', '23211', '4730939', '愛知県', 'アイチケン', '豊田市', 'トヨタシ', '堤本町', 'ツツミホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県大府市', '23', '23223', '4740000', '愛知県', 'アイチケン', '大府市', 'オオブシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('46880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県大府市北崎町', '23', '23223', '4740001', '愛知県', 'アイチケン', '大府市', 'オオブシ', '北崎町', 'キタサキマチ', '（－マチ）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('46881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県大府市北崎町', '23', '23223', '4740002', '愛知県', 'アイチケン', '大府市', 'オオブシ', '北崎町', 'キタサキチョウ', '（－チョウ）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('46882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県大府市神田町', '23', '23223', '4740003', '愛知県', 'アイチケン', '大府市', 'オオブシ', '神田町', 'カンダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県大府市横根町', '23', '23223', '4740011', '愛知県', 'アイチケン', '大府市', 'オオブシ', '横根町', 'ヨコネマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県大府市長根町', '23', '23223', '4740021', '愛知県', 'アイチケン', '大府市', 'オオブシ', '長根町', 'ナガネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県大府市若草町', '23', '23223', '4740022', '愛知県', 'アイチケン', '大府市', 'オオブシ', '若草町', 'ワカクサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県大府市大東町', '23', '23223', '4740023', '愛知県', 'アイチケン', '大府市', 'オオブシ', '大東町', 'ダイトウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県大府市朝日町', '23', '23223', '4740024', '愛知県', 'アイチケン', '大府市', 'オオブシ', '朝日町', 'アサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県大府市中央町', '23', '23223', '4740025', '愛知県', 'アイチケン', '大府市', 'オオブシ', '中央町', 'チュウオウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県大府市桃山町', '23', '23223', '4740026', '愛知県', 'アイチケン', '大府市', 'オオブシ', '桃山町', 'モモヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県大府市追分町', '23', '23223', '4740027', '愛知県', 'アイチケン', '大府市', 'オオブシ', '追分町', 'オイワケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県大府市森岡町', '23', '23223', '4740031', '愛知県', 'アイチケン', '大府市', 'オオブシ', '森岡町', 'モリオカマチ', '（－マチ）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('46892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県大府市江端町', '23', '23223', '4740035', '愛知県', 'アイチケン', '大府市', 'オオブシ', '江端町', 'エバタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県大府市月見町', '23', '23223', '4740036', '愛知県', 'アイチケン', '大府市', 'オオブシ', '月見町', 'ツキミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県大府市半月町', '23', '23223', '4740037', '愛知県', 'アイチケン', '大府市', 'オオブシ', '半月町', 'ハンツキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県大府市森岡町', '23', '23223', '4740038', '愛知県', 'アイチケン', '大府市', 'オオブシ', '森岡町', 'モリオカチョウ', '（－チョウ）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('46896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県大府市吉田町', '23', '23223', '4740041', '愛知県', 'アイチケン', '大府市', 'オオブシ', '吉田町', 'ヨシダマチ', '（－マチ）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('46897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県大府市高丘町', '23', '23223', '4740042', '愛知県', 'アイチケン', '大府市', 'オオブシ', '高丘町', 'タカオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県大府市米田町', '23', '23223', '4740043', '愛知県', 'アイチケン', '大府市', 'オオブシ', '米田町', 'コメダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県大府市桜木町', '23', '23223', '4740044', '愛知県', 'アイチケン', '大府市', 'オオブシ', '桜木町', 'サクラギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県大府市馬池町', '23', '23223', '4740045', '愛知県', 'アイチケン', '大府市', 'オオブシ', '馬池町', 'ウマイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県大府市吉川町', '23', '23223', '4740046', '愛知県', 'アイチケン', '大府市', 'オオブシ', '吉川町', 'ヨシカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県大府市宮内町', '23', '23223', '4740047', '愛知県', 'アイチケン', '大府市', 'オオブシ', '宮内町', 'ミヤウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県大府市吉田町1丁目', '23', '23223', '4740048', '愛知県', 'アイチケン', '大府市', 'オオブシ', '吉田町', 'ヨシダチョウ', '（－チョウ）', null, '1丁目', '01チョウメ');
INSERT INTO `ms_addresses` VALUES ('46904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県大府市吉田町2丁目', '23', '23223', '4740048', '愛知県', 'アイチケン', '大府市', 'オオブシ', '吉田町', 'ヨシダチョウ', '（－チョウ）', null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('46905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県大府市吉田町3丁目', '23', '23223', '4740048', '愛知県', 'アイチケン', '大府市', 'オオブシ', '吉田町', 'ヨシダチョウ', '（－チョウ）', null, '3丁目', '03チョウメ');
INSERT INTO `ms_addresses` VALUES ('46906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県大府市吉田町4丁目', '23', '23223', '4740048', '愛知県', 'アイチケン', '大府市', 'オオブシ', '吉田町', 'ヨシダチョウ', '（－チョウ）', null, '4丁目', '04チョウメ');
INSERT INTO `ms_addresses` VALUES ('46907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県大府市吉田町5丁目', '23', '23223', '4740048', '愛知県', 'アイチケン', '大府市', 'オオブシ', '吉田町', 'ヨシダチョウ', '（－チョウ）', null, '5丁目', '05チョウメ');
INSERT INTO `ms_addresses` VALUES ('46908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県大府市吉田町6丁目', '23', '23223', '4740048', '愛知県', 'アイチケン', '大府市', 'オオブシ', '吉田町', 'ヨシダチョウ', '（－チョウ）', null, '6丁目', '06チョウメ');
INSERT INTO `ms_addresses` VALUES ('46909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県大府市大府町', '23', '23223', '4740051', '愛知県', 'アイチケン', '大府市', 'オオブシ', '大府町', 'オオブマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県大府市長草町', '23', '23223', '4740052', '愛知県', 'アイチケン', '大府市', 'オオブシ', '長草町', 'ナガクサマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県大府市柊山町', '23', '23223', '4740053', '愛知県', 'アイチケン', '大府市', 'オオブシ', '柊山町', 'ヒイラギヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県大府市明成町', '23', '23223', '4740056', '愛知県', 'アイチケン', '大府市', 'オオブシ', '明成町', 'メイセイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県大府市共和町', '23', '23223', '4740057', '愛知県', 'アイチケン', '大府市', 'オオブシ', '共和町', 'キョウワマチ', '（－マチ）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('46914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県大府市共和町', '23', '23223', '4740061', '愛知県', 'アイチケン', '大府市', 'オオブシ', '共和町', 'キョウワチョウ', '（－チョウ）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('46915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県大府市共西町', '23', '23223', '4740062', '愛知県', 'アイチケン', '大府市', 'オオブシ', '共西町', 'キョウセイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県大府市梶田町', '23', '23223', '4740071', '愛知県', 'アイチケン', '大府市', 'オオブシ', '梶田町', 'カジタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県大府市北山町', '23', '23223', '4740072', '愛知県', 'アイチケン', '大府市', 'オオブシ', '北山町', 'キタヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県大府市東新町', '23', '23223', '4740073', '愛知県', 'アイチケン', '大府市', 'オオブシ', '東新町', 'トウシンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県大府市共栄町', '23', '23223', '4740074', '愛知県', 'アイチケン', '大府市', 'オオブシ', '共栄町', 'キョウエイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市', '23', '23205', '4750000', '愛知県', 'アイチケン', '半田市', 'ハンダシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('46950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市石塚町', '23', '23205', '4750001', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '石塚町', 'イシヅカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市緑ケ丘', '23', '23205', '4750002', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '緑ケ丘', 'ミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市東大矢知町', '23', '23205', '4750003', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '東大矢知町', 'ヒガシオオヤチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市上池町', '23', '23205', '4750004', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '上池町', 'カミイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市横川町', '23', '23205', '4750005', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '横川町', 'ヨコガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市南大矢知町', '23', '23205', '4750006', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '南大矢知町', 'ミナミオオヤチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市西大矢知町', '23', '23205', '4750007', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '西大矢知町', 'ニシオオヤチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市北大矢知町', '23', '23205', '4750008', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '北大矢知町', 'キタオオヤチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市上定光町', '23', '23205', '4750009', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '上定光町', 'カミジョウコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市稲穂町', '23', '23205', '4750011', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '稲穂町', 'イナホチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市東生見町', '23', '23205', '4750012', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '東生見町', 'ヒガシハエミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市平地馬場町', '23', '23205', '4750013', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '平地馬場町', 'ヒラチバンバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市一本木町', '23', '23205', '4750014', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '一本木町', 'イッポンギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市大高町', '23', '23205', '4750015', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '大高町', 'オオダカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市西生見町', '23', '23205', '4750016', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '西生見町', 'ニシハエミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市有脇町', '23', '23205', '4750017', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '有脇町', 'アリワキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市中生見町', '23', '23205', '4750018', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '中生見町', 'ナカハエミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市のぞみが丘', '23', '23205', '4750019', '愛知県', 'アイチケン', '半田市', 'ハンダシ', 'のぞみが丘', 'ノゾミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市州の崎町', '23', '23205', '4750021', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '州の崎町', 'スノサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市亀崎月見町', '23', '23205', '4750022', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '亀崎月見町', 'カメザキツキミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市亀崎町', '23', '23205', '4750023', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '亀崎町', 'カメザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市亀崎高根町', '23', '23205', '4750024', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '亀崎高根町', 'カメザキタカネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市亀崎大洞町', '23', '23205', '4750025', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '亀崎大洞町', 'カメザキオオボラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市亀崎新田町', '23', '23205', '4750026', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '亀崎新田町', 'カメザキシンデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市亀崎北浦町', '23', '23205', '4750027', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '亀崎北浦町', 'カメザキキタウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市亀崎相生町', '23', '23205', '4750028', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '亀崎相生町', 'カメザキアイオイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市亀崎常盤町', '23', '23205', '4750029', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '亀崎常盤町', 'カメザキトキワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市阿原町', '23', '23205', '4750031', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '阿原町', 'アワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市潮干町', '23', '23205', '4750032', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '潮干町', 'シオヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市日東町', '23', '23205', '4750033', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '日東町', 'ニットウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市東億田町', '23', '23205', '4750034', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '東億田町', 'ヒガシオクダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市中億田町', '23', '23205', '4750035', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '中億田町', 'ナカオクダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市高砂町', '23', '23205', '4750036', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '高砂町', 'タカサゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市中午町', '23', '23205', '4750037', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '中午町', 'ナカウマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市祢宜町', '23', '23205', '4750038', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '祢宜町', 'ネギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市新居町', '23', '23205', '4750039', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '新居町', 'アライチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市乙川太田町', '23', '23205', '4750041', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '乙川太田町', 'オツカワオオタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市乙川向田町', '23', '23205', '4750042', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '乙川向田町', 'オツカワムカイダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市乙川浜側町', '23', '23205', '4750043', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '乙川浜側町', 'オツカワハマガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市乙川八幡町', '23', '23205', '4750044', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '乙川八幡町', 'オツカワハチマンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市乙川殿町', '23', '23205', '4750045', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '乙川殿町', 'オツカワトノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市乙川市場町', '23', '23205', '4750046', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '乙川市場町', 'オツカワイチバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市乙川北側町', '23', '23205', '4750047', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '乙川北側町', 'オツカワキタガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市乙川稗田町', '23', '23205', '4750048', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '乙川稗田町', 'オツカワヒエダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市乙川栄町', '23', '23205', '4750051', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '乙川栄町', 'オツカワサカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市乙川高良町', '23', '23205', '4750052', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '乙川高良町', 'オツカワタカラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市乙川内山町', '23', '23205', '4750053', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '乙川内山町', 'オツカワウチヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市乙川町', '23', '23205', '4750054', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '乙川町', 'オツカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市北浜田町', '23', '23205', '4750055', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '北浜田町', 'キタハマダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('46999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市乙川一色町', '23', '23205', '4750056', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '乙川一色町', 'オツカワイシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市乙川新町', '23', '23205', '4750057', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '乙川新町', 'オツカワシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市乙川吉野町', '23', '23205', '4750058', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '乙川吉野町', 'オツカワヨシノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市一ノ草町', '23', '23205', '4750061', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '一ノ草町', 'イチノクサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市飯森町', '23', '23205', '4750062', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '飯森町', 'イイモリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市乙川若宮町', '23', '23205', '4750063', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '乙川若宮町', 'オツカワワカミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市乙川薬師町', '23', '23205', '4750064', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '乙川薬師町', 'オツカワヤクシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市乙川深田町', '23', '23205', '4750065', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '乙川深田町', 'オツカワフカダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市乙川源内林町', '23', '23205', '4750066', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '乙川源内林町', 'オツカワゲンナイバヤシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市乙川畑田町', '23', '23205', '4750067', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '乙川畑田町', 'オツカワハタダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市乙川西ノ宮町', '23', '23205', '4750068', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '乙川西ノ宮町', 'オツカワニシノミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市大伝根町', '23', '23205', '4750071', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '大伝根町', 'オオデンネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市七本木町', '23', '23205', '4750072', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '七本木町', 'シチホンギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市美原町', '23', '23205', '4750073', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '美原町', 'ミハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市長根町', '23', '23205', '4750074', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '長根町', 'ナガネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市苗代町', '23', '23205', '4750075', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '苗代町', 'ナエシロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市横松上町', '23', '23205', '4750076', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '横松上町', 'ヨコマツカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市兀山町', '23', '23205', '4750077', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '兀山町', 'ハゲヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市新池町', '23', '23205', '4750078', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '新池町', 'シンイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市平地町', '23', '23205', '4750081', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '平地町', 'ヒラチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市前田町', '23', '23205', '4750082', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '前田町', 'マエダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市大松町', '23', '23205', '4750083', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '大松町', 'オオマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市向山町', '23', '23205', '4750084', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '向山町', 'ムカイヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市小神町', '23', '23205', '4750085', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '小神町', 'コシンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市庚申町', '23', '23205', '4750086', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '庚申町', 'コウシンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市大池町', '23', '23205', '4750087', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '大池町', 'オオイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市花田町', '23', '23205', '4750088', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '花田町', 'ハナダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市相賀町', '23', '23205', '4750801', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '相賀町', 'ソウガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市西億田町', '23', '23205', '4750802', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '西億田町', 'ニシオクダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市乙川末広町', '23', '23205', '4750803', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '乙川末広町', 'オツカワスエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市上浜町', '23', '23205', '4750804', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '上浜町', 'カミハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市浜田町', '23', '23205', '4750805', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '浜田町', 'ハマダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市古浜町', '23', '23205', '4750806', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '古浜町', 'コハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市八軒町', '23', '23205', '4750807', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '八軒町', 'ハチケンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市川田町', '23', '23205', '4750808', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '川田町', 'カワダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市東浜町', '23', '23205', '4750813', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '東浜町', 'ヒガシハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市幸町', '23', '23205', '4750814', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市新栄町', '23', '23205', '4750815', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '新栄町', 'シンサカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市源平町', '23', '23205', '4750816', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '源平町', 'ゲンペイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市東洋町', '23', '23205', '4750817', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '東洋町', 'トウヨウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市日ノ出町', '23', '23205', '4750819', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '日ノ出町', 'ヒノデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市船入町', '23', '23205', '4750821', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '船入町', 'フナイリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市浜町', '23', '23205', '4750822', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '浜町', 'ハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市港町', '23', '23205', '4750823', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '港町', 'ミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市新浜町', '23', '23205', '4750824', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '新浜町', 'シンハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市前潟町', '23', '23205', '4750825', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '前潟町', 'マエガタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市神明町', '23', '23205', '4750826', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '神明町', 'シンメイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市港本町', '23', '23205', '4750827', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '港本町', 'ミナトホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市瑞穂町', '23', '23205', '4750828', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '瑞穂町', 'ミズホチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市十一号地', '23', '23205', '4750831', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '十一号地', 'ジュウイチゴウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市川崎町', '23', '23205', '4750832', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '川崎町', 'カワサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市花園町', '23', '23205', '4750833', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '花園町', 'ハナゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市冨士ケ丘', '23', '23205', '4750834', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '冨士ケ丘', 'フジガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市稲荷町', '23', '23205', '4750835', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '稲荷町', 'イナリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市青山', '23', '23205', '4750836', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '青山', 'アオヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市有楽町', '23', '23205', '4750837', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '有楽町', 'ユウラクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市旭町', '23', '23205', '4750838', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '旭町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市大和町', '23', '23205', '4750841', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '大和町', 'ヤマトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市郷中町', '23', '23205', '4750842', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '郷中町', 'ゴウナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市中島町', '23', '23205', '4750843', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '中島町', 'ナカシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市寺町', '23', '23205', '4750844', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '寺町', 'テラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市成岩東町', '23', '23205', '4750845', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '成岩東町', 'ナラワヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市栄町', '23', '23205', '4750846', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市畑合町', '23', '23205', '4750847', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '畑合町', 'ハタアイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市成岩本町', '23', '23205', '4750848', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '成岩本町', 'ナラワホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市堀崎町', '23', '23205', '4750851', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '堀崎町', 'ホリサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市北末広町', '23', '23205', '4750852', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '北末広町', 'キタスエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市南末広町', '23', '23205', '4750853', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '南末広町', 'ミナミスエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市協和町', '23', '23205', '4750854', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '協和町', 'キョウワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市中町', '23', '23205', '4750855', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '中町', 'ナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市更生町', '23', '23205', '4750856', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '更生町', 'コウセイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市広小路町', '23', '23205', '4750857', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '広小路町', 'ヒロコウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市泉町', '23', '23205', '4750858', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '泉町', 'イズミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市天王町', '23', '23205', '4750859', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '天王町', 'テンノウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市東新町', '23', '23205', '4750861', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '東新町', 'ヒガシシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市住吉町', '23', '23205', '4750862', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '住吉町', 'スミヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市前崎東町', '23', '23205', '4750863', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '前崎東町', 'マエザキヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市前崎西町', '23', '23205', '4750864', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '前崎西町', 'マエザキニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市清水西町', '23', '23205', '4750865', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '清水西町', 'シミズニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市清水北町', '23', '23205', '4750866', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '清水北町', 'シミズキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市榎下町', '23', '23205', '4750867', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '榎下町', 'エノキシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市西新町', '23', '23205', '4750868', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '西新町', 'ニシシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市清水東町', '23', '23205', '4750869', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '清水東町', 'シミズヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市本町', '23', '23205', '4750871', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市東雲町', '23', '23205', '4750872', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '東雲町', 'シノノメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市中村町', '23', '23205', '4750873', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '中村町', 'ナカムラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市銀座本町', '23', '23205', '4750874', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '銀座本町', 'ギンザホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市山崎町', '23', '23205', '4750875', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '山崎町', 'ヤマザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市東天王町', '23', '23205', '4750876', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '東天王町', 'ヒガシテンノウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市勘内町', '23', '23205', '4750877', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '勘内町', 'カンナイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市東本町', '23', '23205', '4750878', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '東本町', 'ヒガシホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市荒古町', '23', '23205', '4750881', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '荒古町', 'アラコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市南本町', '23', '23205', '4750882', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '南本町', 'ミナミホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市妙見町', '23', '23205', '4750883', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '妙見町', 'ミョウケンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市西端町', '23', '23205', '4750884', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '西端町', 'ニシバタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市山ノ神町', '23', '23205', '4750885', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '山ノ神町', 'ヤマノカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市新川町', '23', '23205', '4750886', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '新川町', 'シンカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市御幸町', '23', '23205', '4750887', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '御幸町', 'ミユキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市岩滑南浜町', '23', '23205', '4750901', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '岩滑南浜町', 'ヤナベミナミハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市宮路町', '23', '23205', '4750902', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '宮路町', 'ミヤジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市出口町', '23', '23205', '4750903', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '出口町', 'デグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市大坪町', '23', '23205', '4750904', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '大坪町', 'オオツボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市岩滑東町', '23', '23205', '4750905', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '岩滑東町', 'ヤナベヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市岩滑北浜町', '23', '23205', '4750906', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '岩滑北浜町', 'ヤナベキタハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市星崎町', '23', '23205', '4750911', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '星崎町', 'ホシザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市白山町', '23', '23205', '4750912', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '白山町', 'ハクサンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市土井山町', '23', '23205', '4750914', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '土井山町', 'ドイヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市枝山町', '23', '23205', '4750915', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '枝山町', 'エダヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市柊町', '23', '23205', '4750916', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '柊町', 'ヒイラギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市清城町', '23', '23205', '4750917', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '清城町', 'セイシロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市雁宿町', '23', '23205', '4750918', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '雁宿町', 'カリヤドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市天神町', '23', '23205', '4750921', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '天神町', 'テンジンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市昭和町', '23', '23205', '4750922', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '昭和町', 'ショウワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市春日町', '23', '23205', '4750923', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '春日町', 'カスガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市東郷町', '23', '23205', '4750924', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '東郷町', 'トウゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市宮本町', '23', '23205', '4750925', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '宮本町', 'ミヤモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市南二ツ坂町', '23', '23205', '4750926', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '南二ツ坂町', 'ミナミフタツザカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市北二ツ坂町', '23', '23205', '4750927', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '北二ツ坂町', 'キタフタツサカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市桐ケ丘', '23', '23205', '4750928', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '桐ケ丘', 'キリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市仲田町', '23', '23205', '4750929', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '仲田町', 'ナカタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市新宮町', '23', '23205', '4750931', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '新宮町', 'シングウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市鴉根町', '23', '23205', '4750932', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '鴉根町', 'カラスネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市新野町', '23', '23205', '4750933', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '新野町', 'ニイノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市椎ノ木町', '23', '23205', '4750934', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '椎ノ木町', 'シイノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市大湯町', '23', '23205', '4750935', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '大湯町', 'オオユチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市板山町', '23', '23205', '4750936', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '板山町', 'イタヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市神田町', '23', '23205', '4750937', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '神田町', 'カンダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市君ケ橋町', '23', '23205', '4750938', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '君ケ橋町', 'キミガハシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市四方木町', '23', '23205', '4750939', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '四方木町', 'ヨモギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市滑楚町', '23', '23205', '4750941', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '滑楚町', 'ナメソチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市松堀町', '23', '23205', '4750942', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '松堀町', 'マツボリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市高峯町', '23', '23205', '4750943', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '高峯町', 'タカミネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市神代町', '23', '23205', '4750944', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '神代町', 'カミシロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市池田町', '23', '23205', '4750945', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '池田町', 'イケダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市横山町', '23', '23205', '4750946', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '横山町', 'ヨコヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市砂谷町', '23', '23205', '4750947', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '砂谷町', 'スナダニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市田代町', '23', '23205', '4750948', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '田代町', 'タシロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市宝来町', '23', '23205', '4750951', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '宝来町', 'ホウライチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市馬捨町', '23', '23205', '4750952', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '馬捨町', 'ウマステチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市金山町', '23', '23205', '4750953', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '金山町', 'カナヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市十三塚町', '23', '23205', '4750954', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '十三塚町', 'ジュウサンヅカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市行人町', '23', '23205', '4750955', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '行人町', 'ギョウニンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市三ツ池町', '23', '23205', '4750956', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '三ツ池町', 'ミツイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市奥町', '23', '23205', '4750957', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '奥町', 'オクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市鵜ノ池町', '23', '23205', '4750958', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '鵜ノ池町', 'ウノイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市桃山町', '23', '23205', '4750959', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '桃山町', 'モモヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市岩滑中町', '23', '23205', '4750961', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '岩滑中町', 'ヤナベナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市岩滑高山町', '23', '23205', '4750962', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '岩滑高山町', 'ヤナベタカヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市平和町', '23', '23205', '4750963', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '平和町', 'ヘイワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市平井町', '23', '23205', '4750964', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '平井町', 'ヒライチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市新生町', '23', '23205', '4750965', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '新生町', 'シンセイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市岩滑西町', '23', '23205', '4750966', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '岩滑西町', 'ヤナベニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市欠ケ下町', '23', '23205', '4750967', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '欠ケ下町', 'カケガシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市丁田町', '23', '23205', '4750968', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '丁田町', 'チョウダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市深谷町', '23', '23205', '4750971', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '深谷町', 'フカダニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市北滑草町', '23', '23205', '4750972', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '北滑草町', 'キタナメソウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市葭谷町', '23', '23205', '4750973', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '葭谷町', 'ヨシダニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市山代町', '23', '23205', '4750974', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '山代町', 'ヤマシロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市彦洲町', '23', '23205', '4750975', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '彦洲町', 'ヒコズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市黒石町', '23', '23205', '4750976', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '黒石町', 'クロイシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市吉田町', '23', '23205', '4750977', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '吉田町', 'キッタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県半田市福地町', '23', '23205', '4750978', '愛知県', 'アイチケン', '半田市', 'ハンダシ', '福地町', 'フクチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県東海市', '23', '23222', '4760000', '愛知県', 'アイチケン', '東海市', 'トウカイシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('47183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県東海市南柴田町', '23', '23222', '4760001', '愛知県', 'アイチケン', '東海市', 'トウカイシ', '南柴田町', 'ミナミシバタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県東海市名和町', '23', '23222', '4760002', '愛知県', 'アイチケン', '東海市', 'トウカイシ', '名和町', 'ナワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県東海市荒尾町', '23', '23222', '4760003', '愛知県', 'アイチケン', '東海市', 'トウカイシ', '荒尾町', 'アラオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県東海市荒尾町水深', '23', '23222', '4760004', '愛知県', 'アイチケン', '東海市', 'トウカイシ', '荒尾町水深', 'アラオマチミズブカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県東海市新宝町', '23', '23222', '4760005', '愛知県', 'アイチケン', '東海市', 'トウカイシ', '新宝町', 'シンポウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県東海市浅山', '23', '23222', '4760006', '愛知県', 'アイチケン', '東海市', 'トウカイシ', '浅山', 'アサヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県東海市富木島町', '23', '23222', '4760011', '愛知県', 'アイチケン', '東海市', 'トウカイシ', '富木島町', 'フキシママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県東海市富木島町伏見', '23', '23222', '4760012', '愛知県', 'アイチケン', '東海市', 'トウカイシ', '富木島町伏見', 'フキシママチフシミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県東海市中央町', '23', '23222', '4760013', '愛知県', 'アイチケン', '東海市', 'トウカイシ', '中央町', 'チュウオウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県東海市富貴ノ台', '23', '23222', '4760014', '愛知県', 'アイチケン', '東海市', 'トウカイシ', '富貴ノ台', 'フキノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県東海市東海町', '23', '23222', '4760015', '愛知県', 'アイチケン', '東海市', 'トウカイシ', '東海町', 'トウカイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県東海市大田町', '23', '23222', '4770031', '愛知県', 'アイチケン', '東海市', 'トウカイシ', '大田町', 'オオタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県東海市加木屋町', '23', '23222', '4770032', '愛知県', 'アイチケン', '東海市', 'トウカイシ', '加木屋町', 'カギヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県東海市中ノ池', '23', '23222', '4770033', '愛知県', 'アイチケン', '東海市', 'トウカイシ', '中ノ池', 'ナカノイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県東海市養父町', '23', '23222', '4770034', '愛知県', 'アイチケン', '東海市', 'トウカイシ', '養父町', 'ヤブマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県東海市元浜町', '23', '23222', '4770035', '愛知県', 'アイチケン', '東海市', 'トウカイシ', '元浜町', 'モトハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県東海市横須賀町', '23', '23222', '4770036', '愛知県', 'アイチケン', '東海市', 'トウカイシ', '横須賀町', 'ヨコスカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県東海市高横須賀町', '23', '23222', '4770037', '愛知県', 'アイチケン', '東海市', 'トウカイシ', '高横須賀町', 'タカヨコスカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多市', '23', '23224', '4780000', '愛知県', 'アイチケン', '知多市', 'チタシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('47216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多市八幡', '23', '23224', '4780001', '愛知県', 'アイチケン', '知多市', 'チタシ', '八幡', 'ヤワタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多市平野', '23', '23224', '4780002', '愛知県', 'アイチケン', '知多市', 'チタシ', '平野', 'ヒラノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多市寺本台', '23', '23224', '4780003', '愛知県', 'アイチケン', '知多市', 'チタシ', '寺本台', 'テラモトダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多市伊賀坂', '23', '23224', '4780004', '愛知県', 'アイチケン', '知多市', 'チタシ', '伊賀坂', 'イガサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多市阿原', '23', '23224', '4780005', '愛知県', 'アイチケン', '知多市', 'チタシ', '阿原', 'アワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多市三反田', '23', '23224', '4780006', '愛知県', 'アイチケン', '知多市', 'チタシ', '三反田', 'サンタンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多市原', '23', '23224', '4780011', '愛知県', 'アイチケン', '知多市', 'チタシ', '原', 'ハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多市巽が丘', '23', '23224', '4780012', '愛知県', 'アイチケン', '知多市', 'チタシ', '巽が丘', 'タツミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多市南巽が丘', '23', '23224', '4780013', '愛知県', 'アイチケン', '知多市', 'チタシ', '南巽が丘', 'ミナミタツミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多市西巽が丘', '23', '23224', '4780014', '愛知県', 'アイチケン', '知多市', 'チタシ', '西巽が丘', 'ニシタツミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多市佐布里', '23', '23224', '4780015', '愛知県', 'アイチケン', '知多市', 'チタシ', '佐布里', 'ソウリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多市梅が丘', '23', '23224', '4780016', '愛知県', 'アイチケン', '知多市', 'チタシ', '梅が丘', 'ウメガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多市新知', '23', '23224', '4780017', '愛知県', 'アイチケン', '知多市', 'チタシ', '新知', 'シンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多市佐布里台', '23', '23224', '4780018', '愛知県', 'アイチケン', '知多市', 'チタシ', '佐布里台', 'ソウリダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多市岡田', '23', '23224', '4780021', '愛知県', 'アイチケン', '知多市', 'チタシ', '岡田', 'オカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多市大興寺', '23', '23224', '4780022', '愛知県', 'アイチケン', '知多市', 'チタシ', '大興寺', 'ダイコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多市南粕谷東坂', '23', '23224', '4780023', '愛知県', 'アイチケン', '知多市', 'チタシ', '南粕谷東坂', 'ミナミカスヤヒガシザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多市南粕谷', '23', '23224', '4780024', '愛知県', 'アイチケン', '知多市', 'チタシ', '南粕谷', 'ミナミカスヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多市南粕谷本町', '23', '23224', '4780025', '愛知県', 'アイチケン', '知多市', 'チタシ', '南粕谷本町', 'ミナミカスヤホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多市南粕谷新海', '23', '23224', '4780026', '愛知県', 'アイチケン', '知多市', 'チタシ', '南粕谷新海', 'ミナミカスヤシンカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多市新広見', '23', '23224', '4780027', '愛知県', 'アイチケン', '知多市', 'チタシ', '新広見', 'シンヒロミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多市岡田緑が丘', '23', '23224', '4780028', '愛知県', 'アイチケン', '知多市', 'チタシ', '岡田緑が丘', 'オカダミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多市旭', '23', '23224', '4780031', '愛知県', 'アイチケン', '知多市', 'チタシ', '旭', 'アサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多市金沢', '23', '23224', '4780032', '愛知県', 'アイチケン', '知多市', 'チタシ', '金沢', 'カナザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多市神田', '23', '23224', '4780033', '愛知県', 'アイチケン', '知多市', 'チタシ', '神田', 'カンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多市旭南', '23', '23224', '4780034', '愛知県', 'アイチケン', '知多市', 'チタシ', '旭南', 'キョクナン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多市大草', '23', '23224', '4780035', '愛知県', 'アイチケン', '知多市', 'チタシ', '大草', 'オオクサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多市新舞子', '23', '23224', '4780036', '愛知県', 'アイチケン', '知多市', 'チタシ', '新舞子', 'シンマイコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多市新舞子東町', '23', '23224', '4780037', '愛知県', 'アイチケン', '知多市', 'チタシ', '新舞子東町', 'シンマイコヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多市日長', '23', '23224', '4780041', '愛知県', 'アイチケン', '知多市', 'チタシ', '日長', 'ヒナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多市長浦', '23', '23224', '4780042', '愛知県', 'アイチケン', '知多市', 'チタシ', '長浦', 'ナガウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多市日長台', '23', '23224', '4780043', '愛知県', 'アイチケン', '知多市', 'チタシ', '日長台', 'ヒナガダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多市旭桃台', '23', '23224', '4780044', '愛知県', 'アイチケン', '知多市', 'チタシ', '旭桃台', 'キョクトウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多市南浜町', '23', '23224', '4780045', '愛知県', 'アイチケン', '知多市', 'チタシ', '南浜町', 'ミナミハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多市北浜町', '23', '23224', '4780046', '愛知県', 'アイチケン', '知多市', 'チタシ', '北浜町', 'キタハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多市緑町', '23', '23224', '4780047', '愛知県', 'アイチケン', '知多市', 'チタシ', '緑町', 'ミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多市朝倉町', '23', '23224', '4780051', '愛知県', 'アイチケン', '知多市', 'チタシ', '朝倉町', 'アサクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多市八幡新町', '23', '23224', '4780052', '愛知県', 'アイチケン', '知多市', 'チタシ', '八幡新町', 'ヤワタシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多市清水が丘', '23', '23224', '4780053', '愛知県', 'アイチケン', '知多市', 'チタシ', '清水が丘', 'シミズガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多市つつじが丘', '23', '23224', '4780054', '愛知県', 'アイチケン', '知多市', 'チタシ', 'つつじが丘', 'ツツジガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多市にしの台', '23', '23224', '4780055', '愛知県', 'アイチケン', '知多市', 'チタシ', 'にしの台', 'ニシノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多市南谷', '23', '23224', '4780056', '愛知県', 'アイチケン', '知多市', 'チタシ', '南谷', 'ミナミダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多市吹込', '23', '23224', '4780057', '愛知県', 'アイチケン', '知多市', 'チタシ', '吹込', 'フキコミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多市上り戸', '23', '23224', '4780058', '愛知県', 'アイチケン', '知多市', 'チタシ', '上り戸', 'アガリド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多市新長根', '23', '23224', '4780059', '愛知県', 'アイチケン', '知多市', 'チタシ', '新長根', 'シンナガネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多市山屋敷', '23', '23224', '4780060', '愛知県', 'アイチケン', '知多市', 'チタシ', '山屋敷', 'ヤマヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多市東大僧', '23', '23224', '4780061', '愛知県', 'アイチケン', '知多市', 'チタシ', '東大僧', 'ヒガシオオソウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多市岡田美里町', '23', '23224', '4780062', '愛知県', 'アイチケン', '知多市', 'チタシ', '岡田美里町', 'オカダミサトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多市寺本新町', '23', '23224', '4780063', '愛知県', 'アイチケン', '知多市', 'チタシ', '寺本新町', 'テラモトシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多市新知台', '23', '23224', '4780064', '愛知県', 'アイチケン', '知多市', 'チタシ', '新知台', 'シンチダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多市新知東町', '23', '23224', '4780065', '愛知県', 'アイチケン', '知多市', 'チタシ', '新知東町', 'シンチヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多市新知西町', '23', '23224', '4780066', '愛知県', 'アイチケン', '知多市', 'チタシ', '新知西町', 'シンチニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多市大僧', '23', '23224', '4780067', '愛知県', 'アイチケン', '知多市', 'チタシ', '大僧', 'オオソウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多市中原', '23', '23224', '4780068', '愛知県', 'アイチケン', '知多市', 'チタシ', '中原', 'ナカハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県知多市新刀池', '23', '23224', '4780069', '愛知県', 'アイチケン', '知多市', 'チタシ', '新刀池', 'シンカタナイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市', '23', '23216', '4790000', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('47301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市矢田', '23', '23216', '4790001', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '矢田', 'ヤタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市久米', '23', '23216', '4790002', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '久米', 'クメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市金山', '23', '23216', '4790003', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '金山', 'カナヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市青海町', '23', '23216', '4790004', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '青海町', 'セイカイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市大塚町', '23', '23216', '4790005', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '大塚町', 'オオツカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市古道', '23', '23216', '4790006', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '古道', 'フルミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市庄兵衛新田', '23', '23216', '4790007', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '庄兵衛新田', 'ショウベエシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市酉新田', '23', '23216', '4790008', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '酉新田', 'トリシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市平池', '23', '23216', '4790009', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '平池', 'ヒライケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市花狭間', '23', '23216', '4790011', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '花狭間', 'ハナバサマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市上納', '23', '23216', '4790012', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '上納', 'ジョウノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市二ノ割', '23', '23216', '4790013', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '二ノ割', 'ニノワリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市一ノ割', '23', '23216', '4790014', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '一ノ割', 'イチノワリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市大窯', '23', '23216', '4790015', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '大窯', 'オオガマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市高坂', '23', '23216', '4790016', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '高坂', 'タカサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市椎池', '23', '23216', '4790017', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '椎池', 'シイイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市二ノ田', '23', '23216', '4790018', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '二ノ田', 'ニノタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市柴山', '23', '23216', '4790019', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '柴山', 'シバヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市大曽町', '23', '23216', '4790021', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '大曽町', 'オオソチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市堕星', '23', '23216', '4790022', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '堕星', 'ダタボシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市長峰一ノ切', '23', '23216', '4790023', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '長峰一ノ切', 'ナガミネ01ノキリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市池田口', '23', '23216', '4790024', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '池田口', 'イケダグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市新池', '23', '23216', '4790025', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '新池', 'ニイイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市天竺', '23', '23216', '4790026', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '天竺', 'テンジク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市大流', '23', '23216', '4790027', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '大流', 'オオリュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市長峰二ノ切', '23', '23216', '4790028', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '長峰二ノ切', 'ナガミネ02ノキリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市古道東割', '23', '23216', '4790029', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '古道東割', 'フルミチヒガシワリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市長峰三ノ切', '23', '23216', '4790031', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '長峰三ノ切', 'ナガミネ03ノキリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市下隅', '23', '23216', '4790032', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '下隅', 'シタズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市中椎田', '23', '23216', '4790033', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '中椎田', 'ナカシイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市椎田奥', '23', '23216', '4790034', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '椎田奥', 'シイダオク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市椎草南割', '23', '23216', '4790035', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '椎草南割', 'シイクサミナミワリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市椎田口', '23', '23216', '4790036', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '椎田口', 'シイダグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市中大流', '23', '23216', '4790037', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '中大流', 'ナカオオリュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市石窯', '23', '23216', '4790038', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '石窯', 'イシガマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市大流天竺口', '23', '23216', '4790039', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '大流天竺口', 'オオリュウテンジククチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市千代', '23', '23216', '4790041', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '千代', 'チヨ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市社辺', '23', '23216', '4790042', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '社辺', 'コソベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市古社', '23', '23216', '4790043', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '古社', 'フルヤシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市乙田', '23', '23216', '4790044', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '乙田', 'オコダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市仲井', '23', '23216', '4790045', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '仲井', 'ナカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市北古千代', '23', '23216', '4790046', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '北古千代', 'キタゴチヨ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市南古千代', '23', '23216', '4790047', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '南古千代', 'ミナミゴチヨ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市中千代', '23', '23216', '4790048', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '中千代', 'ナカチヨ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市長峰四ノ切', '23', '23216', '4790049', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '長峰四ノ切', 'ナガミネ04ノキリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市梨木', '23', '23216', '4790051', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '梨木', 'ナシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市夏敷', '23', '23216', '4790052', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '夏敷', 'ナチキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市奥夏敷', '23', '23216', '4790053', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '奥夏敷', 'オクナチキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市西梨木', '23', '23216', '4790054', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '西梨木', 'ニシナシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市広内', '23', '23216', '4790055', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '広内', 'ヒロウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市椎垂木', '23', '23216', '4790056', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '椎垂木', 'シイタルキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市樋掛', '23', '23216', '4790057', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '樋掛', 'トイガケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市古千代', '23', '23216', '4790058', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '古千代', 'コチヨ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市南蛇廻間', '23', '23216', '4790059', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '南蛇廻間', 'ミナミジャバサマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市耳切', '23', '23216', '4790061', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '耳切', 'ミミキリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市運内', '23', '23216', '4790062', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '運内', 'ウンナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市萱苅口', '23', '23216', '4790063', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '萱苅口', 'カヤカリグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市斧口', '23', '23216', '4790064', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '斧口', 'ヨキグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市長間', '23', '23216', '4790065', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '長間', 'チョウマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市脇田口', '23', '23216', '4790066', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '脇田口', 'ワキタグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市小森', '23', '23216', '4790067', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '小森', 'コモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市長田', '23', '23216', '4790068', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '長田', 'オサダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市折戸', '23', '23216', '4790069', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '折戸', 'オリド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市蛇廻間', '23', '23216', '4790071', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '蛇廻間', 'ジャバサマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市乳母子', '23', '23216', '4790072', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '乳母子', 'ウバコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市飛渡川', '23', '23216', '4790073', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '飛渡川', 'トンドガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市池田川', '23', '23216', '4790074', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '池田川', 'イケダガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市菅場', '23', '23216', '4790075', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '菅場', 'スガバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市鳥根', '23', '23216', '4790076', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '鳥根', 'トリネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市南飛渡', '23', '23216', '4790077', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '南飛渡', 'ミナミトンド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市飛渡', '23', '23216', '4790078', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '飛渡', 'トンド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市黒山', '23', '23216', '4790079', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '黒山', 'クロヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市樽水', '23', '23216', '4790801', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '樽水', 'タルミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市西阿野', '23', '23216', '4790802', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '西阿野', 'ニシアノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市桧原', '23', '23216', '4790803', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '桧原', 'ヒバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市古場', '23', '23216', '4790804', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '古場', 'コバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市苅屋', '23', '23216', '4790805', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '苅屋', 'カリヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市大谷', '23', '23216', '4790806', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '大谷', 'オオタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市小鈴谷', '23', '23216', '4790807', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '小鈴谷', 'コスガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市広目', '23', '23216', '4790808', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '広目', 'ヒロメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市坂井', '23', '23216', '4790809', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '坂井', 'サカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市泉町', '23', '23216', '4790811', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '泉町', 'イズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市井戸田町', '23', '23216', '4790812', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '井戸田町', 'イドタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市塩田町', '23', '23216', '4790813', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '塩田町', 'シオタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市阿野町', '23', '23216', '4790814', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '阿野町', 'アノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市唐崎町', '23', '23216', '4790815', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '唐崎町', 'カラサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市熊野', '23', '23216', '4790816', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '熊野', 'クマノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市熊野町', '23', '23216', '4790817', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '熊野町', 'クマノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市古場町', '23', '23216', '4790818', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '古場町', 'コバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市苅屋町', '23', '23216', '4790819', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '苅屋町', 'カリヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市瀬木町', '23', '23216', '4790821', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '瀬木町', 'セギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市奥条', '23', '23216', '4790822', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '奥条', 'オクジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市奥栄町', '23', '23216', '4790823', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '奥栄町', 'オクエイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市白山町', '23', '23216', '4790824', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '白山町', 'ハクサンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市山方町', '23', '23216', '4790825', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '山方町', 'ヤマカタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市樽水町', '23', '23216', '4790826', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '樽水町', 'タルミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市保示町', '23', '23216', '4790827', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '保示町', 'ホウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市市場町', '23', '23216', '4790828', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '市場町', 'イチバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市本町', '23', '23216', '4790829', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市錦町', '23', '23216', '4790831', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '錦町', 'ニシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市原松町', '23', '23216', '4790832', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '原松町', 'ハラマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市北条', '23', '23216', '4790833', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '北条', 'キタジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市千代ケ丘', '23', '23216', '4790834', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '千代ケ丘', 'チヨガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市陶郷町', '23', '23216', '4790835', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '陶郷町', 'トウゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市栄町', '23', '23216', '4790836', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市新開町', '23', '23216', '4790837', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '新開町', 'シンカイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市鯉江本町', '23', '23216', '4790838', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '鯉江本町', 'コイエホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市多屋町', '23', '23216', '4790839', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '多屋町', 'タヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市明和町', '23', '23216', '4790841', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '明和町', 'メイワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市大鳥町', '23', '23216', '4790842', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '大鳥町', 'オオドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市多屋', '23', '23216', '4790843', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '多屋', 'タヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市大和町', '23', '23216', '4790844', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '大和町', 'ヤマトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市森西町', '23', '23216', '4790845', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '森西町', 'モリニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市末広町', '23', '23216', '4790846', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '末広町', 'スエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市新浜町', '23', '23216', '4790847', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '新浜町', 'シンハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市港町', '23', '23216', '4790848', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '港町', 'ミナトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市若松町', '23', '23216', '4790851', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '若松町', 'ワカマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市神明町', '23', '23216', '4790852', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '神明町', 'シンメイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市本郷町', '23', '23216', '4790853', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '本郷町', 'ホンゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市榎戸町', '23', '23216', '4790854', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '榎戸町', 'エノキドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市新田町', '23', '23216', '4790855', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '新田町', 'シンデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市蒲池町', '23', '23216', '4790856', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '蒲池町', 'カバイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市榎戸', '23', '23216', '4790857', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '榎戸', 'エノキド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市蒲池', '23', '23216', '4790858', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '蒲池', 'カバイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市晩台町', '23', '23216', '4790861', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '晩台町', 'バンダイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市小倉町', '23', '23216', '4790862', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '小倉町', 'オグラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市西之口', '23', '23216', '4790863', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '西之口', 'ニシノクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市住吉町', '23', '23216', '4790864', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '住吉町', 'スミヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市小林町', '23', '23216', '4790865', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '小林町', 'コバヤシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市大野町', '23', '23216', '4790866', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '大野町', 'オオノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市大曽', '23', '23216', '4790871', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', '大曽', 'オオソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市かじま台', '23', '23216', '4790873', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', 'かじま台', 'カジマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市セントレア', '23', '23216', '4790881', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', 'セントレア', 'セントレア', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県常滑市りんくう町', '23', '23216', '4790882', '愛知県', 'アイチケン', '常滑市', 'トコナメシ', 'りんくう町', 'リンクウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県丹羽郡大口町', '23', '23361', '4800100', '愛知県', 'アイチケン', '丹羽郡大口町', 'ニワグンオオグチチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('47463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県丹羽郡扶桑町', '23', '23362', '4800100', '愛知県', 'アイチケン', '丹羽郡扶桑町', 'ニワグンフソウチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('47464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県丹羽郡扶桑町山那', '23', '23362', '4800101', '愛知県', 'アイチケン', '丹羽郡扶桑町', 'ニワグンフソウチョウ', '山那', 'ヤマナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県丹羽郡扶桑町高雄', '23', '23362', '4800102', '愛知県', 'アイチケン', '丹羽郡扶桑町', 'ニワグンフソウチョウ', '高雄', 'タカオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県丹羽郡扶桑町柏森', '23', '23362', '4800103', '愛知県', 'アイチケン', '丹羽郡扶桑町', 'ニワグンフソウチョウ', '柏森', 'カシワモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県丹羽郡扶桑町斉藤', '23', '23362', '4800104', '愛知県', 'アイチケン', '丹羽郡扶桑町', 'ニワグンフソウチョウ', '斉藤', 'サイト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県丹羽郡扶桑町南山名', '23', '23362', '4800105', '愛知県', 'アイチケン', '丹羽郡扶桑町', 'ニワグンフソウチョウ', '南山名', 'ミナミヤナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県丹羽郡扶桑町小淵', '23', '23362', '4800106', '愛知県', 'アイチケン', '丹羽郡扶桑町', 'ニワグンフソウチョウ', '小淵', 'オブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県丹羽郡扶桑町高木', '23', '23362', '4800107', '愛知県', 'アイチケン', '丹羽郡扶桑町', 'ニワグンフソウチョウ', '高木', 'タカギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県丹羽郡大口町河北', '23', '23361', '4800121', '愛知県', 'アイチケン', '丹羽郡大口町', 'ニワグンオオグチチョウ', '河北', 'コギタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県丹羽郡大口町仲沖', '23', '23361', '4800122', '愛知県', 'アイチケン', '丹羽郡大口町', 'ニワグンオオグチチョウ', '仲沖', 'ナカオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県丹羽郡大口町二ツ屋', '23', '23361', '4800123', '愛知県', 'アイチケン', '丹羽郡大口町', 'ニワグンオオグチチョウ', '二ツ屋', 'フタツヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県丹羽郡大口町萩島', '23', '23361', '4800124', '愛知県', 'アイチケン', '丹羽郡大口町', 'ニワグンオオグチチョウ', '萩島', 'ハギシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県丹羽郡大口町外坪', '23', '23361', '4800125', '愛知県', 'アイチケン', '丹羽郡大口町', 'ニワグンオオグチチョウ', '外坪', 'トツボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県丹羽郡大口町伝右', '23', '23361', '4800126', '愛知県', 'アイチケン', '丹羽郡大口町', 'ニワグンオオグチチョウ', '伝右', 'デンネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県丹羽郡大口町新宮', '23', '23361', '4800127', '愛知県', 'アイチケン', '丹羽郡大口町', 'ニワグンオオグチチョウ', '新宮', 'シンミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県丹羽郡大口町高橋', '23', '23361', '4800131', '愛知県', 'アイチケン', '丹羽郡大口町', 'ニワグンオオグチチョウ', '高橋', 'タカハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県丹羽郡大口町秋田', '23', '23361', '4800132', '愛知県', 'アイチケン', '丹羽郡大口町', 'ニワグンオオグチチョウ', '秋田', 'アキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県丹羽郡大口町替地', '23', '23361', '4800133', '愛知県', 'アイチケン', '丹羽郡大口町', 'ニワグンオオグチチョウ', '替地', 'カエチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県丹羽郡大口町豊田', '23', '23361', '4800134', '愛知県', 'アイチケン', '丹羽郡大口町', 'ニワグンオオグチチョウ', '豊田', 'トヨタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県丹羽郡大口町御供所', '23', '23361', '4800135', '愛知県', 'アイチケン', '丹羽郡大口町', 'ニワグンオオグチチョウ', '御供所', 'ゴゴショ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県丹羽郡大口町堀尾跡', '23', '23361', '4800136', '愛知県', 'アイチケン', '丹羽郡大口町', 'ニワグンオオグチチョウ', '堀尾跡', 'ホリオセキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県丹羽郡大口町大屋敷', '23', '23361', '4800137', '愛知県', 'アイチケン', '丹羽郡大口町', 'ニワグンオオグチチョウ', '大屋敷', 'オオヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県丹羽郡大口町大御堂', '23', '23361', '4800138', '愛知県', 'アイチケン', '丹羽郡大口町', 'ニワグンオオグチチョウ', '大御堂', 'オミド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県丹羽郡大口町奈良子', '23', '23361', '4800139', '愛知県', 'アイチケン', '丹羽郡大口町', 'ニワグンオオグチチョウ', '奈良子', 'ナラシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県丹羽郡大口町上小口', '23', '23361', '4800141', '愛知県', 'アイチケン', '丹羽郡大口町', 'ニワグンオオグチチョウ', '上小口', 'カミオグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県丹羽郡大口町中小口', '23', '23361', '4800142', '愛知県', 'アイチケン', '丹羽郡大口町', 'ニワグンオオグチチョウ', '中小口', 'ナカオグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県丹羽郡大口町城屋敷', '23', '23361', '4800143', '愛知県', 'アイチケン', '丹羽郡大口町', 'ニワグンオオグチチョウ', '城屋敷', 'シロヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県丹羽郡大口町下小口', '23', '23361', '4800144', '愛知県', 'アイチケン', '丹羽郡大口町', 'ニワグンオオグチチョウ', '下小口', 'シモオグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県丹羽郡大口町丸', '23', '23361', '4800145', '愛知県', 'アイチケン', '丹羽郡大口町', 'ニワグンオオグチチョウ', '丸', 'マル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県丹羽郡大口町余野', '23', '23361', '4800146', '愛知県', 'アイチケン', '丹羽郡大口町', 'ニワグンオオグチチョウ', '余野', 'ヨノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県丹羽郡大口町竹田', '23', '23361', '4800147', '愛知県', 'アイチケン', '丹羽郡大口町', 'ニワグンオオグチチョウ', '竹田', 'タケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県丹羽郡大口町小口', '23', '23361', '4800148', '愛知県', 'アイチケン', '丹羽郡大口町', 'ニワグンオオグチチョウ', '小口', 'オグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西春日井郡豊山町', '23', '23342', '4800200', '愛知県', 'アイチケン', '西春日井郡豊山町', 'ニシカスガイグントヨヤマチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('47501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西春日井郡豊山町青山', '23', '23342', '4800201', '愛知県', 'アイチケン', '西春日井郡豊山町', 'ニシカスガイグントヨヤマチョウ', '青山', 'アオヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県西春日井郡豊山町豊場', '23', '23342', '4800202', '愛知県', 'アイチケン', '西春日井郡豊山町', 'ニシカスガイグントヨヤマチョウ', '豊場', 'トヨバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市内津町', '23', '23206', '4800301', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '内津町', 'ウツツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市西尾町', '23', '23206', '4800302', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '西尾町', 'サイオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市明知町', '23', '23206', '4800303', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '明知町', 'アケチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市神屋町', '23', '23206', '4800304', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '神屋町', 'カギヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市坂下町', '23', '23206', '4800305', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '坂下町', 'サカシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市上野町', '23', '23206', '4800306', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '上野町', 'ウエノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道寿都郡黒松内町', '01', '01393', '0480100', '北海道', 'ホッカイドウ', '寿都郡黒松内町', 'スッツグンクロマツナイチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('47520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道寿都郡黒松内町黒松内', '01', '01393', '0480101', '北海道', 'ホッカイドウ', '寿都郡黒松内町', 'スッツグンクロマツナイチョウ', '黒松内', 'クロマツナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛知郡長久手町', '23', '23304', '4801100', '愛知県', 'アイチケン', '愛知郡長久手町', 'アイチグンナガクテチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('47522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛知郡長久手町熊張', '23', '23304', '4801101', '愛知県', 'アイチケン', '愛知郡長久手町', 'アイチグンナガクテチョウ', '熊張', 'クマバリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛知郡長久手町前熊', '23', '23304', '4801102', '愛知県', 'アイチケン', '愛知郡長久手町', 'アイチグンナガクテチョウ', '前熊', 'マエグマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛知郡長久手町岩作', '23', '23304', '4801103', '愛知県', 'アイチケン', '愛知郡長久手町', 'アイチグンナガクテチョウ', '岩作', 'ヤザコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道寿都郡黒松内町中里', '01', '01393', '0480111', '北海道', 'ホッカイドウ', '寿都郡黒松内町', 'スッツグンクロマツナイチョウ', '中里', 'ナカサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛知郡長久手町山越', '23', '23304', '4801111', '愛知県', 'アイチケン', '愛知郡長久手町', 'アイチグンナガクテチョウ', '山越', 'ヤマゴエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛知郡長久手町砂子', '23', '23304', '4801112', '愛知県', 'アイチケン', '愛知郡長久手町', 'アイチグンナガクテチョウ', '砂子', 'スナゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛知郡長久手町山野田', '23', '23304', '4801113', '愛知県', 'アイチケン', '愛知郡長久手町', 'アイチグンナガクテチョウ', '山野田', 'ヤマノタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛知郡長久手町長配', '23', '23304', '4801114', '愛知県', 'アイチケン', '愛知郡長久手町', 'アイチグンナガクテチョウ', '長配', 'チョウハイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛知郡長久手町菖蒲池', '23', '23304', '4801115', '愛知県', 'アイチケン', '愛知郡長久手町', 'アイチグンナガクテチョウ', '菖蒲池', 'ショウブイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛知郡長久手町杁ケ池', '23', '23304', '4801116', '愛知県', 'アイチケン', '愛知郡長久手町', 'アイチグンナガクテチョウ', '杁ケ池', 'イリガイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛知郡長久手町喜婦嶽', '23', '23304', '4801117', '愛知県', 'アイチケン', '愛知郡長久手町', 'アイチグンナガクテチョウ', '喜婦嶽', 'キブタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道寿都郡黒松内町貝殻', '01', '01393', '0480112', '北海道', 'ホッカイドウ', '寿都郡黒松内町', 'スッツグンクロマツナイチョウ', '貝殻', 'カイカラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛知郡長久手町武蔵塚', '23', '23304', '4801121', '愛知県', 'アイチケン', '愛知郡長久手町', 'アイチグンナガクテチョウ', '武蔵塚', 'ムサシヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛知郡長久手町城屋敷', '23', '23304', '4801122', '愛知県', 'アイチケン', '愛知郡長久手町', 'アイチグンナガクテチョウ', '城屋敷', 'シロヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛知郡長久手町東狭間', '23', '23304', '4801123', '愛知県', 'アイチケン', '愛知郡長久手町', 'アイチグンナガクテチョウ', '東狭間', 'ヒガシハザマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛知郡長久手町戸田谷', '23', '23304', '4801124', '愛知県', 'アイチケン', '愛知郡長久手町', 'アイチグンナガクテチョウ', '戸田谷', 'トダガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛知郡長久手町氏神前', '23', '23304', '4801125', '愛知県', 'アイチケン', '愛知郡長久手町', 'アイチグンナガクテチョウ', '氏神前', 'ウジガミマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道寿都郡黒松内町豊幌', '01', '01393', '0480113', '北海道', 'ホッカイドウ', '寿都郡黒松内町', 'スッツグンクロマツナイチョウ', '豊幌', 'トヨホロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛知郡長久手町長湫', '23', '23304', '4801131', '愛知県', 'アイチケン', '愛知郡長久手町', 'アイチグンナガクテチョウ', '長湫', 'ナガクテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛知郡長久手町上川原', '23', '23304', '4801132', '愛知県', 'アイチケン', '愛知郡長久手町', 'アイチグンナガクテチョウ', '上川原', 'カミカワハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛知郡長久手町原山', '23', '23304', '4801133', '愛知県', 'アイチケン', '愛知郡長久手町', 'アイチグンナガクテチョウ', '原山', 'ハラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道寿都郡黒松内町歌才', '01', '01393', '0480114', '北海道', 'ホッカイドウ', '寿都郡黒松内町', 'スッツグンクロマツナイチョウ', '歌才', 'ウタサイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛知郡長久手町根の神', '23', '23304', '4801141', '愛知県', 'アイチケン', '愛知郡長久手町', 'アイチグンナガクテチョウ', '根の神', 'ネノカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛知郡長久手町蟹原', '23', '23304', '4801142', '愛知県', 'アイチケン', '愛知郡長久手町', 'アイチグンナガクテチョウ', '蟹原', 'カニハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛知郡長久手町井堀', '23', '23304', '4801143', '愛知県', 'アイチケン', '愛知郡長久手町', 'アイチグンナガクテチョウ', '井堀', 'イボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛知郡長久手町熊田', '23', '23304', '4801144', '愛知県', 'アイチケン', '愛知郡長久手町', 'アイチグンナガクテチョウ', '熊田', 'クマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道寿都郡黒松内町西沢', '01', '01393', '0480115', '北海道', 'ホッカイドウ', '寿都郡黒松内町', 'スッツグンクロマツナイチョウ', '西沢', 'ニシノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛知郡長久手町久保山', '23', '23304', '4801151', '愛知県', 'アイチケン', '愛知郡長久手町', 'アイチグンナガクテチョウ', '久保山', 'クボヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛知郡長久手町打越', '23', '23304', '4801152', '愛知県', 'アイチケン', '愛知郡長久手町', 'アイチグンナガクテチョウ', '打越', 'ウチコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛知郡長久手町作田', '23', '23304', '4801153', '愛知県', 'アイチケン', '愛知郡長久手町', 'アイチグンナガクテチョウ', '作田', 'サクタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛知郡長久手町塚田', '23', '23304', '4801154', '愛知県', 'アイチケン', '愛知郡長久手町', 'アイチグンナガクテチョウ', '塚田', 'ツカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛知郡長久手町平池', '23', '23304', '4801155', '愛知県', 'アイチケン', '愛知郡長久手町', 'アイチグンナガクテチョウ', '平池', 'ヒライケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛知郡長久手町五合池', '23', '23304', '4801156', '愛知県', 'アイチケン', '愛知郡長久手町', 'アイチグンナガクテチョウ', '五合池', 'ゴゴウイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛知郡長久手町桜作', '23', '23304', '4801157', '愛知県', 'アイチケン', '愛知郡長久手町', 'アイチグンナガクテチョウ', '桜作', 'サクラツクリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道寿都郡黒松内町旭野', '01', '01393', '0480116', '北海道', 'ホッカイドウ', '寿都郡黒松内町', 'スッツグンクロマツナイチョウ', '旭野', 'アサヒノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道寿都郡黒松内町添別', '01', '01393', '0480117', '北海道', 'ホッカイドウ', '寿都郡黒松内町', 'スッツグンクロマツナイチョウ', '添別', 'ソイベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市定光寺町', '23', '23204', '4801201', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '定光寺町', 'ジョウコウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市下半田川町', '23', '23204', '4801202', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '下半田川町', 'シモハダガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市広之田町', '23', '23204', '4801203', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '広之田町', 'ヒロノタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市北丘町', '23', '23204', '4801204', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '北丘町', 'キタオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市落合町', '23', '23204', '4801205', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '落合町', 'オチアイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市八床町', '23', '23204', '4801206', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '八床町', 'ヤトコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市品野町', '23', '23204', '4801207', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '品野町', 'シナノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道寿都郡黒松内町熱郛', '01', '01393', '0480121', '北海道', 'ホッカイドウ', '寿都郡黒松内町', 'スッツグンクロマツナイチョウ', '熱郛', 'ネップ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市上半田川町', '23', '23204', '4801211', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '上半田川町', 'カミハダガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市片草町', '23', '23204', '4801212', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '片草町', 'カタクサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市白岩町', '23', '23204', '4801213', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '白岩町', 'シライワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市上品野町', '23', '23204', '4801214', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '上品野町', 'カミシナノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市岩屋町', '23', '23204', '4801215', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '岩屋町', 'イワヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市鳥原町', '23', '23204', '4801216', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '鳥原町', 'トリハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市井山町', '23', '23204', '4801217', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '井山町', 'イヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市中品野町', '23', '23204', '4801218', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '中品野町', 'ナカシナノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市窯町', '23', '23204', '4801219', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '窯町', 'カママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道寿都郡黒松内町白炭', '01', '01393', '0480122', '北海道', 'ホッカイドウ', '寿都郡黒松内町', 'スッツグンクロマツナイチョウ', '白炭', 'シロズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道寿都郡黒松内町中ノ川', '01', '01393', '0480123', '北海道', 'ホッカイドウ', '寿都郡黒松内町', 'スッツグンクロマツナイチョウ', '中ノ川', 'ナカノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道寿都郡黒松内町五十嵐', '01', '01393', '0480124', '北海道', 'ホッカイドウ', '寿都郡黒松内町', 'スッツグンクロマツナイチョウ', '五十嵐', 'イガラシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道寿都郡黒松内町目名', '01', '01393', '0480125', '北海道', 'ホッカイドウ', '寿都郡黒松内町', 'スッツグンクロマツナイチョウ', '目名', 'メナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道寿都郡黒松内町北作開', '01', '01393', '0480126', '北海道', 'ホッカイドウ', '寿都郡黒松内町', 'スッツグンクロマツナイチョウ', '北作開', 'キタサッカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道寿都郡黒松内町南作開', '01', '01393', '0480127', '北海道', 'ホッカイドウ', '寿都郡黒松内町', 'スッツグンクロマツナイチョウ', '南作開', 'ミナミサッカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道寿都郡黒松内町西熱郛原野', '01', '01393', '0480131', '北海道', 'ホッカイドウ', '寿都郡黒松内町', 'スッツグンクロマツナイチョウ', '西熱郛原野', 'ニシネップゲンヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道寿都郡黒松内町チョポシナイ', '01', '01393', '0480132', '北海道', 'ホッカイドウ', '寿都郡黒松内町', 'スッツグンクロマツナイチョウ', 'チョポシナイ', 'チョポシナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道寿都郡黒松内町大谷地', '01', '01393', '0480133', '北海道', 'ホッカイドウ', '寿都郡黒松内町', 'スッツグンクロマツナイチョウ', '大谷地', 'オオヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道寿都郡黒松内町白井川', '01', '01393', '0480134', '北海道', 'ホッカイドウ', '寿都郡黒松内町', 'スッツグンクロマツナイチョウ', '白井川', 'シロイカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道寿都郡黒松内町角十', '01', '01393', '0480135', '北海道', 'ホッカイドウ', '寿都郡黒松内町', 'スッツグンクロマツナイチョウ', '角十', 'カクジュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道寿都郡黒松内町赤井川', '01', '01393', '0480136', '北海道', 'ホッカイドウ', '寿都郡黒松内町', 'スッツグンクロマツナイチョウ', '赤井川', 'アカイカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道寿都郡黒松内町婆沢', '01', '01393', '0480137', '北海道', 'ホッカイドウ', '寿都郡黒松内町', 'スッツグンクロマツナイチョウ', '婆沢', 'ババサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道寿都郡黒松内町上豊幌', '01', '01393', '0480141', '北海道', 'ホッカイドウ', '寿都郡黒松内町', 'スッツグンクロマツナイチョウ', '上豊幌', 'カミトヨホロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道寿都郡黒松内町東栄', '01', '01393', '0480142', '北海道', 'ホッカイドウ', '寿都郡黒松内町', 'スッツグンクロマツナイチョウ', '東栄', 'トウエイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道寿都郡黒松内町大成', '01', '01393', '0480143', '北海道', 'ホッカイドウ', '寿都郡黒松内町', 'スッツグンクロマツナイチョウ', '大成', 'タイセイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道寿都郡黒松内町東川', '01', '01393', '0480144', '北海道', 'ホッカイドウ', '寿都郡黒松内町', 'スッツグンクロマツナイチョウ', '東川', 'ヒガシカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道寿都郡黒松内町上大成', '01', '01393', '0480145', '北海道', 'ホッカイドウ', '寿都郡黒松内町', 'スッツグンクロマツナイチョウ', '上大成', 'カミタイセイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道寿都郡寿都町磯谷町', '01', '01392', '0480351', '北海道', 'ホッカイドウ', '寿都郡寿都町', 'スッツグンスッツチョウ', '磯谷町', 'イソヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道寿都郡寿都町', '01', '01392', '0480400', '北海道', 'ホッカイドウ', '寿都郡寿都町', 'スッツグンスッツチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('47606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道寿都郡寿都町新栄町', '01', '01392', '0480401', '北海道', 'ホッカイドウ', '寿都郡寿都町', 'スッツグンスッツチョウ', '新栄町', 'シンエイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道寿都郡寿都町矢追町', '01', '01392', '0480402', '北海道', 'ホッカイドウ', '寿都郡寿都町', 'スッツグンスッツチョウ', '矢追町', 'ヤオイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道寿都郡寿都町政泊町', '01', '01392', '0480403', '北海道', 'ホッカイドウ', '寿都郡寿都町', 'スッツグンスッツチョウ', '政泊町', 'マサドマリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道寿都郡寿都町大磯町', '01', '01392', '0480404', '北海道', 'ホッカイドウ', '寿都郡寿都町', 'スッツグンスッツチョウ', '大磯町', 'オオイソチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道寿都郡寿都町開進町', '01', '01392', '0480405', '北海道', 'ホッカイドウ', '寿都郡寿都町', 'スッツグンスッツチョウ', '開進町', 'カイシンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道寿都郡寿都町渡島町', '01', '01392', '0480406', '北海道', 'ホッカイドウ', '寿都郡寿都町', 'スッツグンスッツチョウ', '渡島町', 'トシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道寿都郡寿都町六条町', '01', '01392', '0480411', '北海道', 'ホッカイドウ', '寿都郡寿都町', 'スッツグンスッツチョウ', '六条町', 'ロクジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道寿都郡寿都町岩崎町', '01', '01392', '0480412', '北海道', 'ホッカイドウ', '寿都郡寿都町', 'スッツグンスッツチョウ', '岩崎町', 'イワサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道寿都郡寿都町樽岸町', '01', '01392', '0480413', '北海道', 'ホッカイドウ', '寿都郡寿都町', 'スッツグンスッツチョウ', '樽岸町', 'タルキシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道寿都郡寿都町湯別町', '01', '01392', '0480414', '北海道', 'ホッカイドウ', '寿都郡寿都町', 'スッツグンスッツチョウ', '湯別町', 'ユベツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道寿都郡寿都町歌棄町', '01', '01392', '0480415', '北海道', 'ホッカイドウ', '寿都郡寿都町', 'スッツグンスッツチョウ', '歌棄町', 'ウタスツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道島牧郡島牧村', '01', '01391', '0480600', '北海道', 'ホッカイドウ', '島牧郡島牧村', 'シママキグンシママキムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('47618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道島牧郡島牧村富浦', '01', '01391', '0480601', '北海道', 'ホッカイドウ', '島牧郡島牧村', 'シママキグンシママキムラ', '富浦', 'トミウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道島牧郡島牧村歌島', '01', '01391', '0480602', '北海道', 'ホッカイドウ', '島牧郡島牧村', 'シママキグンシママキムラ', '歌島', 'ウタシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道島牧郡島牧村本目', '01', '01391', '0480603', '北海道', 'ホッカイドウ', '島牧郡島牧村', 'シママキグンシママキムラ', '本目', 'ホンメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道島牧郡島牧村港', '01', '01391', '0480604', '北海道', 'ホッカイドウ', '島牧郡島牧村', 'シママキグンシママキムラ', '港', 'ミナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道島牧郡島牧村栄磯', '01', '01391', '0480611', '北海道', 'ホッカイドウ', '島牧郡島牧村', 'シママキグンシママキムラ', '栄磯', 'サカエイソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道島牧郡島牧村豊浜', '01', '01391', '0480612', '北海道', 'ホッカイドウ', '島牧郡島牧村', 'シママキグンシママキムラ', '豊浜', 'トヨハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道島牧郡島牧村大平', '01', '01391', '0480613', '北海道', 'ホッカイドウ', '島牧郡島牧村', 'シママキグンシママキムラ', '大平', 'オオビラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道島牧郡島牧村永豊町', '01', '01391', '0480614', '北海道', 'ホッカイドウ', '島牧郡島牧村', 'シママキグンシママキムラ', '永豊町', 'ナガトヨマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道島牧郡島牧村泊', '01', '01391', '0480621', '北海道', 'ホッカイドウ', '島牧郡島牧村', 'シママキグンシママキムラ', '泊', 'トマリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道島牧郡島牧村豊平', '01', '01391', '0480622', '北海道', 'ホッカイドウ', '島牧郡島牧村', 'シママキグンシママキムラ', '豊平', 'トヨヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道島牧郡島牧村江の島', '01', '01391', '0480623', '北海道', 'ホッカイドウ', '島牧郡島牧村', 'シママキグンシママキムラ', '江の島', 'エノシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道島牧郡島牧村千走', '01', '01391', '0480631', '北海道', 'ホッカイドウ', '島牧郡島牧村', 'シママキグンシママキムラ', '千走', 'チワセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道島牧郡島牧村元町', '01', '01391', '0480632', '北海道', 'ホッカイドウ', '島牧郡島牧村', 'シママキグンシママキムラ', '元町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道島牧郡島牧村原歌町', '01', '01391', '0480633', '北海道', 'ホッカイドウ', '島牧郡島牧村', 'シママキグンシママキムラ', '原歌町', 'ハラウタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道島牧郡島牧村栄浜', '01', '01391', '0480634', '北海道', 'ホッカイドウ', '島牧郡島牧村', 'シママキグンシママキムラ', '栄浜', 'サカエハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県北名古屋市', '23', '23234', '4810000', '愛知県', 'アイチケン', '北名古屋市', 'キタナゴヤシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('47634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県北名古屋市六ツ師', '23', '23234', '4810001', '愛知県', 'アイチケン', '北名古屋市', 'キタナゴヤシ', '六ツ師', 'ムツシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県北名古屋市片場', '23', '23234', '4810002', '愛知県', 'アイチケン', '北名古屋市', 'キタナゴヤシ', '片場', 'カタバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県北名古屋市能田', '23', '23234', '4810003', '愛知県', 'アイチケン', '北名古屋市', 'キタナゴヤシ', '能田', 'ノウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県北名古屋市鹿田', '23', '23234', '4810004', '愛知県', 'アイチケン', '北名古屋市', 'キタナゴヤシ', '鹿田', 'シカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県北名古屋市薬師寺', '23', '23234', '4810005', '愛知県', 'アイチケン', '北名古屋市', 'キタナゴヤシ', '薬師寺', 'ヤクシジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県北名古屋市熊之庄', '23', '23234', '4810006', '愛知県', 'アイチケン', '北名古屋市', 'キタナゴヤシ', '熊之庄', 'クマノショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県北名古屋市高田寺', '23', '23234', '4810011', '愛知県', 'アイチケン', '北名古屋市', 'キタナゴヤシ', '高田寺', 'タカダジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県北名古屋市久地野', '23', '23234', '4810012', '愛知県', 'アイチケン', '北名古屋市', 'キタナゴヤシ', '久地野', 'クジノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県北名古屋市二子', '23', '23234', '4810013', '愛知県', 'アイチケン', '北名古屋市', 'キタナゴヤシ', '二子', 'フタゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県北名古屋市井瀬木', '23', '23234', '4810014', '愛知県', 'アイチケン', '北名古屋市', 'キタナゴヤシ', '井瀬木', 'イセギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県北名古屋市弥勒寺東', '23', '23234', '4810031', '愛知県', 'アイチケン', '北名古屋市', 'キタナゴヤシ', '弥勒寺東', 'ミロクジヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県北名古屋市弥勒寺西', '23', '23234', '4810032', '愛知県', 'アイチケン', '北名古屋市', 'キタナゴヤシ', '弥勒寺西', 'ミロクジニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県北名古屋市西之保', '23', '23234', '4810033', '愛知県', 'アイチケン', '北名古屋市', 'キタナゴヤシ', '西之保', 'ニシノホウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県北名古屋市北野', '23', '23234', '4810034', '愛知県', 'アイチケン', '北名古屋市', 'キタナゴヤシ', '北野', 'キタノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県北名古屋市宇福寺', '23', '23234', '4810035', '愛知県', 'アイチケン', '北名古屋市', 'キタナゴヤシ', '宇福寺', 'ウブクジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県北名古屋市山之腰', '23', '23234', '4810036', '愛知県', 'アイチケン', '北名古屋市', 'キタナゴヤシ', '山之腰', 'ヤマノコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県北名古屋市鍜治ケ一色', '23', '23234', '4810037', '愛知県', 'アイチケン', '北名古屋市', 'キタナゴヤシ', '鍜治ケ一色', 'カジガイシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県北名古屋市徳重', '23', '23234', '4810038', '愛知県', 'アイチケン', '北名古屋市', 'キタナゴヤシ', '徳重', 'トクシゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県北名古屋市法成寺', '23', '23234', '4810039', '愛知県', 'アイチケン', '北名古屋市', 'キタナゴヤシ', '法成寺', 'ホウジョウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県北名古屋市九之坪', '23', '23234', '4810041', '愛知県', 'アイチケン', '北名古屋市', 'キタナゴヤシ', '九之坪', 'クノツボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県北名古屋市野崎', '23', '23234', '4810042', '愛知県', 'アイチケン', '北名古屋市', 'キタナゴヤシ', '野崎', 'ノザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県北名古屋市沖村', '23', '23234', '4810043', '愛知県', 'アイチケン', '北名古屋市', 'キタナゴヤシ', '沖村', 'オキムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県北名古屋市加島新田', '23', '23234', '4810044', '愛知県', 'アイチケン', '北名古屋市', 'キタナゴヤシ', '加島新田', 'カシマシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県北名古屋市中之郷', '23', '23234', '4810045', '愛知県', 'アイチケン', '北名古屋市', 'キタナゴヤシ', '中之郷', 'ナカノゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県北名古屋市石橋', '23', '23234', '4810046', '愛知県', 'アイチケン', '北名古屋市', 'キタナゴヤシ', '石橋', 'イシバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道磯谷郡蘭越町相生', '01', '01394', '0481251', '北海道', 'ホッカイドウ', '磯谷郡蘭越町', 'イソヤグンランコシチョウ', '相生', 'アイオイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道磯谷郡蘭越町讃岐', '01', '01394', '0481252', '北海道', 'ホッカイドウ', '磯谷郡蘭越町', 'イソヤグンランコシチョウ', '讃岐', 'サヌキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道磯谷郡蘭越町田下', '01', '01394', '0481253', '北海道', 'ホッカイドウ', '磯谷郡蘭越町', 'イソヤグンランコシチョウ', '田下', 'タシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道磯谷郡蘭越町上目名', '01', '01394', '0481254', '北海道', 'ホッカイドウ', '磯谷郡蘭越町', 'イソヤグンランコシチョウ', '上目名', 'カミメナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道磯谷郡蘭越町目名町', '01', '01394', '0481261', '北海道', 'ホッカイドウ', '磯谷郡蘭越町', 'イソヤグンランコシチョウ', '目名町', 'メナマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道磯谷郡蘭越町貝川', '01', '01394', '0481262', '北海道', 'ホッカイドウ', '磯谷郡蘭越町', 'イソヤグンランコシチョウ', '貝川', 'カイカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道磯谷郡蘭越町三笠', '01', '01394', '0481263', '北海道', 'ホッカイドウ', '磯谷郡蘭越町', 'イソヤグンランコシチョウ', '三笠', 'ミカサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道磯谷郡蘭越町清水', '01', '01394', '0481264', '北海道', 'ホッカイドウ', '磯谷郡蘭越町', 'イソヤグンランコシチョウ', '清水', 'シミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道磯谷郡蘭越町鮎川', '01', '01394', '0481265', '北海道', 'ホッカイドウ', '磯谷郡蘭越町', 'イソヤグンランコシチョウ', '鮎川', 'アユカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道磯谷郡蘭越町', '01', '01394', '0481300', '北海道', 'ホッカイドウ', '磯谷郡蘭越町', 'イソヤグンランコシチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('47669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道磯谷郡蘭越町蘭越町', '01', '01394', '0481301', '北海道', 'ホッカイドウ', '磯谷郡蘭越町', 'イソヤグンランコシチョウ', '蘭越町', 'ランコシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道磯谷郡蘭越町昆布町', '01', '01394', '0481302', '北海道', 'ホッカイドウ', '磯谷郡蘭越町', 'イソヤグンランコシチョウ', '昆布町', 'コンブマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道磯谷郡蘭越町立川', '01', '01394', '0481303', '北海道', 'ホッカイドウ', '磯谷郡蘭越町', 'イソヤグンランコシチョウ', '立川', 'タチカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道磯谷郡蘭越町水上', '01', '01394', '0481304', '北海道', 'ホッカイドウ', '磯谷郡蘭越町', 'イソヤグンランコシチョウ', '水上', 'ミズカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道磯谷郡蘭越町大谷', '01', '01394', '0481305', '北海道', 'ホッカイドウ', '磯谷郡蘭越町', 'イソヤグンランコシチョウ', '大谷', 'オオタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道磯谷郡蘭越町淀川', '01', '01394', '0481306', '北海道', 'ホッカイドウ', '磯谷郡蘭越町', 'イソヤグンランコシチョウ', '淀川', 'ヨドガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道磯谷郡蘭越町トンカラ', '01', '01394', '0481307', '北海道', 'ホッカイドウ', '磯谷郡蘭越町', 'イソヤグンランコシチョウ', 'トンカラ', 'トンカラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道磯谷郡蘭越町名駒町', '01', '01394', '0481307', '北海道', 'ホッカイドウ', '磯谷郡蘭越町', 'イソヤグンランコシチョウ', '名駒町', 'ナコママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道磯谷郡蘭越町吉国', '01', '01394', '0481311', '北海道', 'ホッカイドウ', '磯谷郡蘭越町', 'イソヤグンランコシチョウ', '吉国', 'ヨシクニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道磯谷郡蘭越町冷水', '01', '01394', '0481312', '北海道', 'ホッカイドウ', '磯谷郡蘭越町', 'イソヤグンランコシチョウ', '冷水', 'ヒヤミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道磯谷郡蘭越町三和', '01', '01394', '0481312', '北海道', 'ホッカイドウ', '磯谷郡蘭越町', 'イソヤグンランコシチョウ', '三和', 'ミツワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道磯谷郡蘭越町上里', '01', '01394', '0481313', '北海道', 'ホッカイドウ', '磯谷郡蘭越町', 'イソヤグンランコシチョウ', '上里', 'カミサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道磯谷郡蘭越町御成', '01', '01394', '0481314', '北海道', 'ホッカイドウ', '磯谷郡蘭越町', 'イソヤグンランコシチョウ', '御成', 'オナリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道磯谷郡蘭越町共栄', '01', '01394', '0481315', '北海道', 'ホッカイドウ', '磯谷郡蘭越町', 'イソヤグンランコシチョウ', '共栄', 'キョウエイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道磯谷郡蘭越町大曲', '01', '01394', '0481316', '北海道', 'ホッカイドウ', '磯谷郡蘭越町', 'イソヤグンランコシチョウ', '大曲', 'オオマガリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道磯谷郡蘭越町初田', '01', '01394', '0481316', '北海道', 'ホッカイドウ', '磯谷郡蘭越町', 'イソヤグンランコシチョウ', '初田', 'ハツタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道磯谷郡蘭越町昆布温泉', '01', '01394', '0481321', '北海道', 'ホッカイドウ', '磯谷郡蘭越町', 'イソヤグンランコシチョウ', '昆布温泉', 'コンブオンセン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道磯谷郡蘭越町湯里', '01', '01394', '0481321', '北海道', 'ホッカイドウ', '磯谷郡蘭越町', 'イソヤグンランコシチョウ', '湯里', 'ユノサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道磯谷郡蘭越町日出', '01', '01394', '0481322', '北海道', 'ホッカイドウ', '磯谷郡蘭越町', 'イソヤグンランコシチョウ', '日出', 'ヒノデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道磯谷郡蘭越町黄金', '01', '01394', '0481323', '北海道', 'ホッカイドウ', '磯谷郡蘭越町', 'イソヤグンランコシチョウ', '黄金', 'コガネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道磯谷郡蘭越町豊国', '01', '01394', '0481324', '北海道', 'ホッカイドウ', '磯谷郡蘭越町', 'イソヤグンランコシチョウ', '豊国', 'トヨクニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道磯谷郡蘭越町栄', '01', '01394', '0481325', '北海道', 'ホッカイドウ', '磯谷郡蘭越町', 'イソヤグンランコシチョウ', '栄', 'サカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道磯谷郡蘭越町富岡', '01', '01394', '0481326', '北海道', 'ホッカイドウ', '磯谷郡蘭越町', 'イソヤグンランコシチョウ', '富岡', 'トミオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道磯谷郡蘭越町新見', '01', '01394', '0481327', '北海道', 'ホッカイドウ', '磯谷郡蘭越町', 'イソヤグンランコシチョウ', '新見', 'ニイミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道磯谷郡蘭越町港町', '01', '01394', '0481341', '北海道', 'ホッカイドウ', '磯谷郡蘭越町', 'イソヤグンランコシチョウ', '港町', 'ミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡ニセコ町', '01', '01395', '0481500', '北海道', 'ホッカイドウ', '虻田郡ニセコ町', 'アブタグンニセコチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('47700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡ニセコ町富士見', '01', '01395', '0481501', '北海道', 'ホッカイドウ', '虻田郡ニセコ町', 'アブタグンニセコチョウ', '富士見', 'フジミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡ニセコ町本通', '01', '01395', '0481502', '北海道', 'ホッカイドウ', '虻田郡ニセコ町', 'アブタグンニセコチョウ', '本通', 'ホンドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡ニセコ町ニセコ', '01', '01395', '0481511', '北海道', 'ホッカイドウ', '虻田郡ニセコ町', 'アブタグンニセコチョウ', 'ニセコ', 'ニセコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡ニセコ町中央通', '01', '01395', '0481512', '北海道', 'ホッカイドウ', '虻田郡ニセコ町', 'アブタグンニセコチョウ', '中央通', 'チュウオウドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡ニセコ町東山', '01', '01395', '0481521', '北海道', 'ホッカイドウ', '虻田郡ニセコ町', 'アブタグンニセコチョウ', '東山', 'ヒガシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡ニセコ町曽我', '01', '01395', '0481522', '北海道', 'ホッカイドウ', '虻田郡ニセコ町', 'アブタグンニセコチョウ', '曽我', 'ソガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡ニセコ町有島', '01', '01395', '0481531', '北海道', 'ホッカイドウ', '虻田郡ニセコ町', 'アブタグンニセコチョウ', '有島', 'アリシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡ニセコ町羊蹄', '01', '01395', '0481541', '北海道', 'ホッカイドウ', '虻田郡ニセコ町', 'アブタグンニセコチョウ', '羊蹄', 'ヨウテイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡ニセコ町近藤', '01', '01395', '0481542', '北海道', 'ホッカイドウ', '虻田郡ニセコ町', 'アブタグンニセコチョウ', '近藤', 'コンドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡ニセコ町豊里', '01', '01395', '0481543', '北海道', 'ホッカイドウ', '虻田郡ニセコ町', 'アブタグンニセコチョウ', '豊里', 'トヨサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡ニセコ町元町', '01', '01395', '0481544', '北海道', 'ホッカイドウ', '虻田郡ニセコ町', 'アブタグンニセコチョウ', '元町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡ニセコ町里見', '01', '01395', '0481551', '北海道', 'ホッカイドウ', '虻田郡ニセコ町', 'アブタグンニセコチョウ', '里見', 'サトミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡ニセコ町宮田', '01', '01395', '0481552', '北海道', 'ホッカイドウ', '虻田郡ニセコ町', 'アブタグンニセコチョウ', '宮田', 'ミヤタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡ニセコ町黒川', '01', '01395', '0481553', '北海道', 'ホッカイドウ', '虻田郡ニセコ町', 'アブタグンニセコチョウ', '黒川', 'クロカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡ニセコ町富川', '01', '01395', '0481554', '北海道', 'ホッカイドウ', '虻田郡ニセコ町', 'アブタグンニセコチョウ', '富川', 'トミカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡ニセコ町福井', '01', '01395', '0481561', '北海道', 'ホッカイドウ', '虻田郡ニセコ町', 'アブタグンニセコチョウ', '福井', 'フクイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡ニセコ町桂台', '01', '01395', '0481562', '北海道', 'ホッカイドウ', '虻田郡ニセコ町', 'アブタグンニセコチョウ', '桂台', 'カツラダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡ニセコ町西富', '01', '01395', '0481563', '北海道', 'ホッカイドウ', '虻田郡ニセコ町', 'アブタグンニセコチョウ', '西富', 'ニシトミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡真狩村', '01', '01396', '0481600', '北海道', 'ホッカイドウ', '虻田郡真狩村', 'アブタグンマッカリムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('47721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡真狩村美原', '01', '01396', '0481601', '北海道', 'ホッカイドウ', '虻田郡真狩村', 'アブタグンマッカリムラ', '美原', 'ミハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡真狩村泉', '01', '01396', '0481602', '北海道', 'ホッカイドウ', '虻田郡真狩村', 'アブタグンマッカリムラ', '泉', 'イズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡真狩村共明', '01', '01396', '0481603', '北海道', 'ホッカイドウ', '虻田郡真狩村', 'アブタグンマッカリムラ', '共明', 'キョウメイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡真狩村富里', '01', '01396', '0481604', '北海道', 'ホッカイドウ', '虻田郡真狩村', 'アブタグンマッカリムラ', '富里', 'トミサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡真狩村社', '01', '01396', '0481605', '北海道', 'ホッカイドウ', '虻田郡真狩村', 'アブタグンマッカリムラ', '社', 'ヤシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡真狩村光', '01', '01396', '0481611', '北海道', 'ホッカイドウ', '虻田郡真狩村', 'アブタグンマッカリムラ', '光', 'ヒカリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡真狩村見晴', '01', '01396', '0481612', '北海道', 'ホッカイドウ', '虻田郡真狩村', 'アブタグンマッカリムラ', '見晴', 'ミハラシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡真狩村南部', '01', '01396', '0481613', '北海道', 'ホッカイドウ', '虻田郡真狩村', 'アブタグンマッカリムラ', '南部', 'ナンブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡真狩村桜川', '01', '01396', '0481614', '北海道', 'ホッカイドウ', '虻田郡真狩村', 'アブタグンマッカリムラ', '桜川', 'サクラガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡真狩村緑岡', '01', '01396', '0481615', '北海道', 'ホッカイドウ', '虻田郡真狩村', 'アブタグンマッカリムラ', '緑岡', 'ミドリオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡真狩村豊川', '01', '01396', '0481621', '北海道', 'ホッカイドウ', '虻田郡真狩村', 'アブタグンマッカリムラ', '豊川', 'トヨカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡真狩村加野', '01', '01396', '0481622', '北海道', 'ホッカイドウ', '虻田郡真狩村', 'アブタグンマッカリムラ', '加野', 'カノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡真狩村川崎', '01', '01396', '0481623', '北海道', 'ホッカイドウ', '虻田郡真狩村', 'アブタグンマッカリムラ', '川崎', 'カワサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡真狩村神里', '01', '01396', '0481624', '北海道', 'ホッカイドウ', '虻田郡真狩村', 'アブタグンマッカリムラ', '神里', 'カミサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡真狩村真狩', '01', '01396', '0481631', '北海道', 'ホッカイドウ', '虻田郡真狩村', 'アブタグンマッカリムラ', '真狩', 'マッカリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡留寿都村', '01', '01397', '0481700', '北海道', 'ホッカイドウ', '虻田郡留寿都村', 'アブタグンルスツムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('47737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡留寿都村泉川', '01', '01397', '0481711', '北海道', 'ホッカイドウ', '虻田郡留寿都村', 'アブタグンルスツムラ', '泉川', 'イズミカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡留寿都村豊岡', '01', '01397', '0481712', '北海道', 'ホッカイドウ', '虻田郡留寿都村', 'アブタグンルスツムラ', '豊岡', 'トヨオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡留寿都村向丘', '01', '01397', '0481721', '北海道', 'ホッカイドウ', '虻田郡留寿都村', 'アブタグンルスツムラ', '向丘', 'ムカイオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡留寿都村黒田', '01', '01397', '0481722', '北海道', 'ホッカイドウ', '虻田郡留寿都村', 'アブタグンルスツムラ', '黒田', 'クロダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡留寿都村三ノ原', '01', '01397', '0481723', '北海道', 'ホッカイドウ', '虻田郡留寿都村', 'アブタグンルスツムラ', '三ノ原', 'サンノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡留寿都村三豊', '01', '01397', '0481724', '北海道', 'ホッカイドウ', '虻田郡留寿都村', 'アブタグンルスツムラ', '三豊', 'ミトヨ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡留寿都村留寿都', '01', '01397', '0481731', '北海道', 'ホッカイドウ', '虻田郡留寿都村', 'アブタグンルスツムラ', '留寿都', 'ルスツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡留寿都村西ノ原', '01', '01397', '0481741', '北海道', 'ホッカイドウ', '虻田郡留寿都村', 'アブタグンルスツムラ', '西ノ原', 'ニシノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡留寿都村登', '01', '01397', '0481751', '北海道', 'ホッカイドウ', '虻田郡留寿都村', 'アブタグンルスツムラ', '登', 'ノボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡留寿都村旭野', '01', '01397', '0481752', '北海道', 'ホッカイドウ', '虻田郡留寿都村', 'アブタグンルスツムラ', '旭野', 'アサヒノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岩倉市', '23', '23228', '4820000', '愛知県', 'アイチケン', '岩倉市', 'イワクラシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('47773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岩倉市東新町', '23', '23228', '4820001', '愛知県', 'アイチケン', '岩倉市', 'イワクラシ', '東新町', 'ヒガシシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岩倉市大市場町', '23', '23228', '4820002', '愛知県', 'アイチケン', '岩倉市', 'イワクラシ', '大市場町', 'ダイイチバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岩倉市曽野町', '23', '23228', '4820003', '愛知県', 'アイチケン', '岩倉市', 'イワクラシ', '曽野町', 'ソノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岩倉市五条町', '23', '23228', '4820004', '愛知県', 'アイチケン', '岩倉市', 'イワクラシ', '五条町', 'ゴジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岩倉市下本町', '23', '23228', '4820005', '愛知県', 'アイチケン', '岩倉市', 'イワクラシ', '下本町', 'シモホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岩倉市稲荷町羽根', '23', '23228', '4820006', '愛知県', 'アイチケン', '岩倉市', 'イワクラシ', '稲荷町羽根', 'イナリチョウハネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岩倉市大山寺元町', '23', '23228', '4820007', '愛知県', 'アイチケン', '岩倉市', 'イワクラシ', '大山寺元町', 'タイサンジモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岩倉市昭和町', '23', '23228', '4820011', '愛知県', 'アイチケン', '岩倉市', 'イワクラシ', '昭和町', 'ショウワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岩倉市稲荷町', '23', '23228', '4820012', '愛知県', 'アイチケン', '岩倉市', 'イワクラシ', '稲荷町', 'イナリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岩倉市南新町', '23', '23228', '4820013', '愛知県', 'アイチケン', '岩倉市', 'イワクラシ', '南新町', 'ミナミシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岩倉市大山寺町', '23', '23228', '4820014', '愛知県', 'アイチケン', '岩倉市', 'イワクラシ', '大山寺町', 'タイサンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岩倉市川井町', '23', '23228', '4820015', '愛知県', 'アイチケン', '岩倉市', 'イワクラシ', '川井町', 'カワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岩倉市野寄町', '23', '23228', '4820016', '愛知県', 'アイチケン', '岩倉市', 'イワクラシ', '野寄町', 'ノヨリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岩倉市北島町', '23', '23228', '4820017', '愛知県', 'アイチケン', '岩倉市', 'イワクラシ', '北島町', 'キタジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岩倉市大山寺本町', '23', '23228', '4820018', '愛知県', 'アイチケン', '岩倉市', 'イワクラシ', '大山寺本町', 'タイサンジホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岩倉市新柳町', '23', '23228', '4820021', '愛知県', 'アイチケン', '岩倉市', 'イワクラシ', '新柳町', 'シンヤナギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岩倉市栄町', '23', '23228', '4820022', '愛知県', 'アイチケン', '岩倉市', 'イワクラシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岩倉市中央町', '23', '23228', '4820023', '愛知県', 'アイチケン', '岩倉市', 'イワクラシ', '中央町', 'チュウオウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岩倉市旭町', '23', '23228', '4820024', '愛知県', 'アイチケン', '岩倉市', 'イワクラシ', '旭町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岩倉市大地新町', '23', '23228', '4820025', '愛知県', 'アイチケン', '岩倉市', 'イワクラシ', '大地新町', 'ダイチシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岩倉市大地町', '23', '23228', '4820026', '愛知県', 'アイチケン', '岩倉市', 'イワクラシ', '大地町', 'ダイチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岩倉市八剱町', '23', '23228', '4820031', '愛知県', 'アイチケン', '岩倉市', 'イワクラシ', '八剱町', 'ヤツルギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岩倉市井上町', '23', '23228', '4820032', '愛知県', 'アイチケン', '岩倉市', 'イワクラシ', '井上町', 'イノウエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岩倉市神野町', '23', '23228', '4820033', '愛知県', 'アイチケン', '岩倉市', 'イワクラシ', '神野町', 'カミノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岩倉市石仏町', '23', '23228', '4820034', '愛知県', 'アイチケン', '岩倉市', 'イワクラシ', '石仏町', 'イシボトケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岩倉市鈴井町', '23', '23228', '4820035', '愛知県', 'アイチケン', '岩倉市', 'イワクラシ', '鈴井町', 'スズイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岩倉市西市町', '23', '23228', '4820036', '愛知県', 'アイチケン', '岩倉市', 'イワクラシ', '西市町', 'サイチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岩倉市東町', '23', '23228', '4820041', '愛知県', 'アイチケン', '岩倉市', 'イワクラシ', '東町', 'ヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岩倉市中本町', '23', '23228', '4820042', '愛知県', 'アイチケン', '岩倉市', 'イワクラシ', '中本町', 'ナカホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岩倉市本町', '23', '23228', '4820043', '愛知県', 'アイチケン', '岩倉市', 'イワクラシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岩倉市宮前町', '23', '23228', '4820044', '愛知県', 'アイチケン', '岩倉市', 'イワクラシ', '宮前町', 'ミヤマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岩倉市泉町', '23', '23228', '4820045', '愛知県', 'アイチケン', '岩倉市', 'イワクラシ', '泉町', 'イズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県岩倉市中野町', '23', '23228', '4820046', '愛知県', 'アイチケン', '岩倉市', 'イワクラシ', '中野町', 'ナカノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩内郡共和町ワイス', '01', '01401', '0482141', '北海道', 'ホッカイドウ', '岩内郡共和町', 'イワナイグンキョウワチョウ', 'ワイス', 'ワイス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩内郡共和町小沢', '01', '01401', '0482142', '北海道', 'ホッカイドウ', '岩内郡共和町', 'イワナイグンキョウワチョウ', '小沢', 'コザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩内郡共和町国富', '01', '01401', '0482143', '北海道', 'ホッカイドウ', '岩内郡共和町', 'イワナイグンキョウワチョウ', '国富', 'クニトミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩内郡共和町', '01', '01401', '0482200', '北海道', 'ホッカイドウ', '岩内郡共和町', 'イワナイグンキョウワチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('47810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩内郡共和町前田', '01', '01401', '0482201', '北海道', 'ホッカイドウ', '岩内郡共和町', 'イワナイグンキョウワチョウ', '前田', 'マエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩内郡共和町南幌似', '01', '01401', '0482202', '北海道', 'ホッカイドウ', '岩内郡共和町', 'イワナイグンキョウワチョウ', '南幌似', 'ミナミホロニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道余市郡仁木町大江2丁目', '01', '01407', '0482331', '北海道', 'ホッカイドウ', '余市郡仁木町', 'ヨイチグンニキチョウ', '大江', 'オオエ', null, null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('47814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道余市郡仁木町大江3丁目', '01', '01407', '0482331', '北海道', 'ホッカイドウ', '余市郡仁木町', 'ヨイチグンニキチョウ', '大江', 'オオエ', null, null, '3丁目', '03チョウメ');
INSERT INTO `ms_addresses` VALUES ('47815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道余市郡仁木町長沢西', '01', '01407', '0482332', '北海道', 'ホッカイドウ', '余市郡仁木町', 'ヨイチグンニキチョウ', '長沢西', 'ナガサワニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道余市郡仁木町長沢南', '01', '01407', '0482333', '北海道', 'ホッカイドウ', '余市郡仁木町', 'ヨイチグンニキチョウ', '長沢南', 'ナガサワミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道余市郡仁木町尾根内', '01', '01407', '0482334', '北海道', 'ホッカイドウ', '余市郡仁木町', 'ヨイチグンニキチョウ', '尾根内', 'オネナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道余市郡仁木町銀山', '01', '01407', '0482335', '北海道', 'ホッカイドウ', '余市郡仁木町', 'ヨイチグンニキチョウ', '銀山', 'ギンザン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道余市郡仁木町', '01', '01407', '0482400', '北海道', 'ホッカイドウ', '余市郡仁木町', 'ヨイチグンニキチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('47820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道余市郡仁木町旭台', '01', '01407', '0482401', '北海道', 'ホッカイドウ', '余市郡仁木町', 'ヨイチグンニキチョウ', '旭台', 'アサヒダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道余市郡仁木町大江1丁目', '01', '01407', '0482402', '北海道', 'ホッカイドウ', '余市郡仁木町', 'ヨイチグンニキチョウ', '大江', 'オオエ', null, null, '1丁目', '01チョウメ');
INSERT INTO `ms_addresses` VALUES ('47822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道余市郡仁木町大江2丁目', '01', '01407', '0482402', '北海道', 'ホッカイドウ', '余市郡仁木町', 'ヨイチグンニキチョウ', '大江', 'オオエ', null, null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('47823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道余市郡仁木町大江3丁目', '01', '01407', '0482402', '北海道', 'ホッカイドウ', '余市郡仁木町', 'ヨイチグンニキチョウ', '大江', 'オオエ', null, null, '3丁目', '03チョウメ');
INSERT INTO `ms_addresses` VALUES ('47824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道余市郡仁木町然別', '01', '01407', '0482403', '北海道', 'ホッカイドウ', '余市郡仁木町', 'ヨイチグンニキチョウ', '然別', 'シカリベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道余市郡仁木町砥の川', '01', '01407', '0482404', '北海道', 'ホッカイドウ', '余市郡仁木町', 'ヨイチグンニキチョウ', '砥の川', 'トノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道余市郡仁木町北町', '01', '01407', '0482405', '北海道', 'ホッカイドウ', '余市郡仁木町', 'ヨイチグンニキチョウ', '北町', 'キタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道余市郡仁木町西町', '01', '01407', '0482406', '北海道', 'ホッカイドウ', '余市郡仁木町', 'ヨイチグンニキチョウ', '西町', 'ニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道余市郡仁木町東町', '01', '01407', '0482411', '北海道', 'ホッカイドウ', '余市郡仁木町', 'ヨイチグンニキチョウ', '東町', 'ヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道余市郡仁木町東町緑ケ丘', '01', '01407', '0482412', '北海道', 'ホッカイドウ', '余市郡仁木町', 'ヨイチグンニキチョウ', '東町緑ケ丘', 'ヒガシマチミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道余市郡仁木町南町', '01', '01407', '0482413', '北海道', 'ホッカイドウ', '余市郡仁木町', 'ヨイチグンニキチョウ', '南町', 'ミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道小樽市忍路', '01', '01203', '0482561', '北海道', 'ホッカイドウ', '小樽市', 'オタルシ', '忍路', 'オショロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道小樽市蘭島', '01', '01203', '0482562', '北海道', 'ホッカイドウ', '小樽市', 'オタルシ', '蘭島', 'ランシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道小樽市オタモイ', '01', '01203', '0482671', '北海道', 'ホッカイドウ', '小樽市', 'オタルシ', 'オタモイ', 'オタモイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道小樽市塩谷', '01', '01203', '0482672', '北海道', 'ホッカイドウ', '小樽市', 'オタルシ', '塩谷', 'シオヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道小樽市桃内', '01', '01203', '0482673', '北海道', 'ホッカイドウ', '小樽市', 'オタルシ', '桃内', 'モモナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市', '23', '23217', '4830000', '愛知県', 'アイチケン', '江南市', 'コウナンシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('47847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市中般若町東', '23', '23217', '4838001', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '中般若町東', 'ナカハンニャチョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市中般若町西', '23', '23217', '4838002', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '中般若町西', 'ナカハンニャチョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市草井町大野', '23', '23217', '4838003', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '草井町大野', 'クサイチョウオオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市中般若町川端', '23', '23217', '4838003', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '中般若町', 'ナカハンニャチョウ', null, null, '川端', 'カワバタ');
INSERT INTO `ms_addresses` VALUES ('47851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市中般若町北浦', '23', '23217', '4838003', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '中般若町', 'ナカハンニャチョウ', null, null, '北浦', 'キタウラ');
INSERT INTO `ms_addresses` VALUES ('47852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市草井町宮東', '23', '23217', '4838004', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '草井町宮東', 'クサイチョウミヤヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市草井町宮西', '23', '23217', '4838005', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '草井町宮西', 'クサイチョウミヤニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市草井町中', '23', '23217', '4838006', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '草井町中', 'クサイチョウナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市草井町西', '23', '23217', '4838007', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '草井町西', 'クサイチョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市鹿子島町', '23', '23217', '4838008', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '鹿子島町', 'カノコジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市般若町宮山', '23', '23217', '4838011', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '般若町宮山', 'ハンニャチョウミヤヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市般若町東山', '23', '23217', '4838012', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '般若町東山', 'ハンニャチョウヒガシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市般若町南山', '23', '23217', '4838013', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '般若町南山', 'ハンニャチョウミナミヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市和田町川東', '23', '23217', '4838014', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '和田町川東', 'ワダチョウカワヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市和田町中島', '23', '23217', '4838015', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '和田町中島', 'ワダチョウナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市和田町西島', '23', '23217', '4838016', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '和田町西島', 'ワダチョウニシジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市般若町前山', '23', '23217', '4838017', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '般若町前山', 'ハンニャチョウマエヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市般若町中山', '23', '23217', '4838018', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '般若町中山', 'ハンニャチョウナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市和田町小島', '23', '23217', '4838021', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '和田町小島', 'ワダチョウコジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市和田町旭', '23', '23217', '4838022', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '和田町旭', 'ワダチョウアサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市和田町二タ子', '23', '23217', '4838023', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '和田町二タ子', 'ワダチョウフタゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市和田町天神', '23', '23217', '4838024', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '和田町天神', 'ワダチョウテンジン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市和田町宮', '23', '23217', '4838025', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '和田町宮', 'ワダチョウミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市和田町中畑', '23', '23217', '4838026', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '和田町中畑', 'ワダチョウナカハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市和田町本郷', '23', '23217', '4838027', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '和田町本郷', 'ワダチョウホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市和田町中', '23', '23217', '4838028', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '和田町中', 'ワダチョウナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市和田町栄', '23', '23217', '4838029', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '和田町栄', 'ワダチョウサカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市山尻町朝日', '23', '23217', '4838031', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '山尻町朝日', 'ヤマジリチョウアサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市山尻町大桑', '23', '23217', '4838032', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '山尻町大桑', 'ヤマジリチョウオオクワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市山尻町川端', '23', '23217', '4838033', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '山尻町川端', 'ヤマジリチョウカワバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市江森町西', '23', '23217', '4838034', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '江森町西', 'エモリチョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市高屋町大門', '23', '23217', '4838035', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '高屋町大門', 'タカヤチョウダイモン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市山尻町本丸西', '23', '23217', '4838036', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '山尻町本丸西', 'ヤマジリチョウホンマルニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市勝佐町', '23', '23217', '4838037', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '勝佐町', 'カツサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市山尻町本丸', '23', '23217', '4838038', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '山尻町本丸', 'ヤマジリチョウホンマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市江森町上', '23', '23217', '4838041', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '江森町上', 'エモリチョウカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市江森町東', '23', '23217', '4838042', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '江森町東', 'エモリチョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市江森町南', '23', '23217', '4838043', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '江森町南', 'エモリチョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市宮後町', '23', '23217', '4838044', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '宮後町', 'ミヤウシロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市高屋町遠場', '23', '23217', '4838045', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '高屋町遠場', 'タカヤチョウトウバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市高屋町花戸', '23', '23217', '4838046', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '高屋町花戸', 'タカヤチョウハナド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市高屋町大師', '23', '23217', '4838047', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '高屋町大師', 'タカヤチョウダイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市江森町中', '23', '23217', '4838048', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '江森町中', 'エモリチョウナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市前野町新田北', '23', '23217', '4838051', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '前野町新田北', 'マエノチョウシンデンキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市前野町東', '23', '23217', '4838052', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '前野町東', 'マエノチョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市前野町高島', '23', '23217', '4838053', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '前野町高島', 'マエノチョウタカシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市前野町南', '23', '23217', '4838054', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '前野町南', 'マエノチョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市山王町', '23', '23217', '4838055', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '山王町', 'サンノウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市宮後町清水', '23', '23217', '4838056', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '宮後町清水', 'ミヤウシロチョウシミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市前野町新田', '23', '23217', '4838057', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '前野町新田', 'マエノチョウシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市前野町西', '23', '23217', '4838058', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '前野町西', 'マエノチョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市高屋町清水', '23', '23217', '4838061', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '高屋町清水', 'タカヤチョウシミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市高屋町神戸', '23', '23217', '4838062', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '高屋町神戸', 'タカヤチョウゴウド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市高屋町八幡', '23', '23217', '4838063', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '高屋町八幡', 'タカヤチョウハチマン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市高屋町十六田', '23', '23217', '4838064', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '高屋町十六田', 'タカヤチョウジュウロクデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市高屋町旭', '23', '23217', '4838065', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '高屋町旭', 'タカヤチョウアサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市高屋町西町', '23', '23217', '4838066', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '高屋町西町', 'タカヤチョウニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市飛高町中町', '23', '23217', '4838067', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '飛高町中町', 'ヒダカチョウナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市飛高町本町', '23', '23217', '4838068', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '飛高町本町', 'ヒダカチョウホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市飛高町宮町', '23', '23217', '4838069', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '飛高町宮町', 'ヒダカチョウミヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市草井町中野', '23', '23217', '4838071', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '草井町中野', 'クサイチョウナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市草井町若草', '23', '23217', '4838072', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '草井町若草', 'クサイチョウワカクサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市村久野町平松', '23', '23217', '4838074', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '村久野町平松', 'ムラクノチョウヒラマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市村久野町平河', '23', '23217', '4838075', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '村久野町平河', 'ムラクノチョウヒラカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市村久野町上原', '23', '23217', '4838076', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '村久野町上原', 'ムラクノチョウウエハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市草井町榊戸', '23', '23217', '4838077', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '草井町', 'クサイチョウ', null, null, '榊戸', 'サカキド');
INSERT INTO `ms_addresses` VALUES ('47913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市草井町千代見', '23', '23217', '4838077', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '草井町', 'クサイチョウ', null, null, '千代見', 'チヨミ');
INSERT INTO `ms_addresses` VALUES ('47914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市草井町南', '23', '23217', '4838077', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '草井町', 'クサイチョウ', null, null, '南', 'ミナミ');
INSERT INTO `ms_addresses` VALUES ('47915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市高屋町上本郷', '23', '23217', '4838081', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '高屋町上本郷', 'タカヤチョウカミホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市高屋町本郷', '23', '23217', '4838082', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '高屋町本郷', 'タカヤチョウホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市高屋町中屋舗', '23', '23217', '4838083', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '高屋町中屋舗', 'タカヤチョウナカヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市高屋町御日塚', '23', '23217', '4838084', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '高屋町御日塚', 'タカヤチョウオヒヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市高屋町西里', '23', '23217', '4838085', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '高屋町西里', 'タカヤチョウニシサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市高屋町大松原', '23', '23217', '4838086', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '高屋町大松原', 'タカヤチョウオオマツバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市高屋町北上', '23', '23217', '4838087', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '高屋町北上', 'タカヤチョウキタガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市高屋町後山', '23', '23217', '4838088', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '高屋町後山', 'タカヤチョウウシロヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市力長町観音寺', '23', '23217', '4838101', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '力長町観音寺', 'リキナガチョウカンオンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市力長町若宮', '23', '23217', '4838102', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '力長町若宮', 'リキナガチョウワカミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市力長町宮前', '23', '23217', '4838103', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '力長町宮前', 'リキナガチョウミヤマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市力長町大当寺', '23', '23217', '4838104', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '力長町大当寺', 'リキナガチョウダイトウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市力長町社宮司', '23', '23217', '4838105', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '力長町社宮司', 'リキナガチョウシャグウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市石枕町神明', '23', '23217', '4838106', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '石枕町神明', 'イシマクラチョウシンメイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市石枕町白山', '23', '23217', '4838107', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '石枕町白山', 'イシマクラチョウハクサン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市力長町神明', '23', '23217', '4838108', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '力長町神明', 'リキナガチョウシンメイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市力長町神出', '23', '23217', '4838109', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '力長町神出', 'リキナガチョウカミデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市安良町地蔵', '23', '23217', '4838111', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '安良町地蔵', 'ヤスラチョウジゾウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市安良町池尻', '23', '23217', '4838112', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '安良町池尻', 'ヤスラチョウイケジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市天王町五反林', '23', '23217', '4838113', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '天王町五反林', 'テンノウチョウゴタンバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市天王町駒野', '23', '23217', '4838114', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '天王町駒野', 'テンノウチョウコマノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市安良町宮前', '23', '23217', '4838115', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '安良町宮前', 'ヤスラチョウミヤマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市安良町八王子', '23', '23217', '4838116', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '安良町八王子', 'ヤスラチョウハチオウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市安良町上郷', '23', '23217', '4838117', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '安良町上郷', 'ヤスラチョウカミゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市安良町郷中', '23', '23217', '4838118', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '安良町郷中', 'ヤスラチョウゴウナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市曽本町二子', '23', '23217', '4838121', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '曽本町二子', 'ソモトチョウフタゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市曽本町二子前', '23', '23217', '4838122', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '曽本町二子前', 'ソモトチョウフタゴマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市曽本町幼川添', '23', '23217', '4838123', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '曽本町幼川添', 'ソモトチョウオサナガワゾエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市小折本町白山', '23', '23217', '4838124', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '小折本町白山', 'コオリホンマチハクサン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市小折東町旭', '23', '23217', '4838125', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '小折東町旭', 'コオリヒガシマチアサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市小折本町栄', '23', '23217', '4838126', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '小折本町栄', 'コオリホンマチサカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市小折本町小松原', '23', '23217', '4838127', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '小折本町小松原', 'コオリホンマチコマツバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市小折本町柳橋', '23', '23217', '4838128', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '小折本町柳橋', 'コオリホンマチヤナギバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市小折町八反畑', '23', '23217', '4838131', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '小折町', 'コオリチョウ', null, null, '八反畑', 'ハッタンバタ');
INSERT INTO `ms_addresses` VALUES ('47949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市田代町南出', '23', '23217', '4838132', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '田代町南出', 'タシロチョウミナミデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市田代町西ノ丸', '23', '23217', '4838133', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '田代町西ノ丸', 'タシロチョウニシノマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市小折町八竜西', '23', '23217', '4838134', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '小折町', 'コオリチョウ', null, null, '八竜西', 'ハチリュウニシ');
INSERT INTO `ms_addresses` VALUES ('47952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市小郷町粟田木', '23', '23217', '4838135', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '小郷町粟田木', 'オゴウチョウアワタギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市小折町桜雲', '23', '23217', '4838136', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '小折町', 'コオリチョウ', null, null, '桜雲', 'サクモ');
INSERT INTO `ms_addresses` VALUES ('47954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市小折町八竜', '23', '23217', '4838137', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '小折町', 'コオリチョウ', null, null, '八竜', 'ハチリュウ');
INSERT INTO `ms_addresses` VALUES ('47955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市田代町郷中', '23', '23217', '4838138', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '田代町郷中', 'タシロチョウゴウナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市布袋町西布', '23', '23217', '4838141', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '布袋町西布', 'ホテイチョウニシホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市布袋下山町東', '23', '23217', '4838142', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '布袋下山町東', 'ホテイシモヤマチョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市小郷町伍大力', '23', '23217', '4838143', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '小郷町伍大力', 'オゴウチョウゴダイリキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市小郷町楽ノ山', '23', '23217', '4838144', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '小郷町楽ノ山', 'オゴウチョウラクノヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市小郷町西ノ山', '23', '23217', '4838145', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '小郷町西ノ山', 'オゴウチョウニシノヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市布袋下山町西', '23', '23217', '4838146', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '布袋下山町西', 'ホテイシモヤマチョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市布袋下山町北', '23', '23217', '4838147', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '布袋下山町北', 'ホテイシモヤマチョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市布袋下山町南', '23', '23217', '4838148', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '布袋下山町南', 'ホテイシモヤマチョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市小郷町手保ノ木', '23', '23217', '4838149', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '小郷町手保ノ木', 'オゴウチョウテホノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市寄木町白山', '23', '23217', '4838151', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '寄木町白山', 'ヨリキチョウハクサン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市寄木町稲木', '23', '23217', '4838152', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '寄木町稲木', 'ヨリキチョウイナキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市北山町東', '23', '23217', '4838153', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '北山町東', 'キタヤマチョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市南山町東', '23', '23217', '4838154', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '南山町東', 'ミナミヤマチョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市南山町中', '23', '23217', '4838155', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '南山町中', 'ミナミヤマチョウナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市南山町西', '23', '23217', '4838156', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '南山町西', 'ミナミヤマチョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市北山町西', '23', '23217', '4838157', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '北山町西', 'キタヤマチョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市布袋町東', '23', '23217', '4838158', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '布袋町東', 'ホテイチョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市寄木町秋葉', '23', '23217', '4838159', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '寄木町秋葉', 'ヨリキチョウアキバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市尾崎町上田', '23', '23217', '4838161', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '尾崎町上田', 'オサキチョウカミダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市尾崎町河原', '23', '23217', '4838162', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '尾崎町河原', 'オサキチョウカワハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市木賀東町新宮', '23', '23217', '4838163', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '木賀東町新宮', 'キガヒガシチョウシングウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市木賀東町新塚', '23', '23217', '4838164', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '木賀東町新塚', 'キガヒガシチョウシンヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市赤童子町福住', '23', '23217', '4838165', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '赤童子町福住', 'アカドウジチョウフクズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市赤童子町南山', '23', '23217', '4838166', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '赤童子町南山', 'アカドウジチョウミナミヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市赤童子町南野', '23', '23217', '4838167', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '赤童子町南野', 'アカドウジチョウミナミノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市尾崎町屋敷', '23', '23217', '4838168', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '尾崎町屋敷', 'オサキチョウヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市尾崎町若竹', '23', '23217', '4838171', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '尾崎町若竹', 'オサキチョウワカタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市尾崎町白山', '23', '23217', '4838172', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '尾崎町白山', 'オサキチョウハクサン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市尾崎町桐野', '23', '23217', '4838173', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '尾崎町桐野', 'オサキチョウキリノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市北野町小松', '23', '23217', '4838174', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '北野町小松', 'キタノチョウコマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市北野町天神', '23', '23217', '4838175', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '北野町天神', 'キタノチョウテンジン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市北野町旭', '23', '23217', '4838176', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '北野町', 'キタノチョウ', null, null, '旭', 'アサヒ');
INSERT INTO `ms_addresses` VALUES ('47988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市北野町郷浦', '23', '23217', '4838176', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '北野町', 'キタノチョウ', null, null, '郷浦', 'ゴウウラ');
INSERT INTO `ms_addresses` VALUES ('47989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市北野町川石', '23', '23217', '4838177', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '北野町川石', 'キタノチョウカワイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市今市場町秋津', '23', '23217', '4838181', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '今市場町秋津', 'イマイチバチョウアキツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市今市場町宮前', '23', '23217', '4838182', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '今市場町宮前', 'イマイチバチョウミヤマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市今市場町高根', '23', '23217', '4838183', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '今市場町高根', 'イマイチバチョウタカネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市寄木町天道', '23', '23217', '4838184', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '寄木町天道', 'ヨリキチョウテンドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市大海道町神明', '23', '23217', '4838185', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '大海道町神明', 'オオガイドウチョウシンメイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市大海道町中里', '23', '23217', '4838186', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '大海道町中里', 'オオガイドウチョウナカサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市大海道町青木', '23', '23217', '4838187', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '大海道町青木', 'オオガイドウチョウアオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市今市場町美和', '23', '23217', '4838188', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '今市場町美和', 'イマイチバチョウミワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市野白町葭場', '23', '23217', '4838201', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '野白町葭場', 'ノバクチョウヨシバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('47999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市野白町野白', '23', '23217', '4838202', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '野白町野白', 'ノバクチョウノバク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市野白町西千丸', '23', '23217', '4838203', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '野白町西千丸', 'ノバクチョウニシセンマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市野白町東千丸', '23', '23217', '4838204', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '野白町東千丸', 'ノバクチョウヒガシセンマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市古知野町小金', '23', '23217', '4838205', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '古知野町小金', 'コチノチョウコガネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市古知野町千丸', '23', '23217', '4838206', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '古知野町千丸', 'コチノチョウセンマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市古知野町熱田', '23', '23217', '4838207', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '古知野町熱田', 'コチノチョウアツタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市古知野町花霞', '23', '23217', '4838208', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '古知野町花霞', 'コチノチョウハナガスミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市古知野町杉山', '23', '23217', '4838211', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '古知野町杉山', 'コチノチョウスギヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市古知野町瑞穂', '23', '23217', '4838212', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '古知野町瑞穂', 'コチノチョウミズホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市古知野町朝日', '23', '23217', '4838213', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '古知野町朝日', 'コチノチョウアサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市古知野町日の出', '23', '23217', '4838214', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '古知野町日の出', 'コチノチョウヒノデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市古知野町大塔', '23', '23217', '4838215', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '古知野町大塔', 'コチノチョウダイトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市古知野町塔塚', '23', '23217', '4838216', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '古知野町塔塚', 'コチノチョウトウヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市古知野町古渡', '23', '23217', '4838217', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '古知野町古渡', 'コチノチョウフルワタリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市赤童子町大堀', '23', '23217', '4838221', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '赤童子町大堀', 'アカドウジチョウオオボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市赤童子町藤宮', '23', '23217', '4838222', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '赤童子町藤宮', 'アカドウジチョウフジミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市赤童子町御宿', '23', '23217', '4838223', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '赤童子町御宿', 'アカドウジチョウオヤド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市赤童子町白山', '23', '23217', '4838224', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '赤童子町白山', 'アカドウジチョウハクサン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市赤童子町栄', '23', '23217', '4838225', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '赤童子町栄', 'アカドウジチョウサカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市赤童子町大間', '23', '23217', '4838226', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '赤童子町大間', 'アカドウジチョウオオマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市赤童子町良原', '23', '23217', '4838227', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '赤童子町良原', 'アカドウジチョウヨシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市赤童子町桜道', '23', '23217', '4838228', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '赤童子町桜道', 'アカドウジチョウサクラミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市木賀本郷町東', '23', '23217', '4838231', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '木賀本郷町東', 'キガホンゴウチョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市木賀本郷町緑', '23', '23217', '4838232', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '木賀本郷町緑', 'キガホンゴウチョウミドリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市木賀町大門', '23', '23217', '4838233', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '木賀町大門', 'キガチョウダイモン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市布袋町北', '23', '23217', '4838234', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '布袋町北', 'ホテイチョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市布袋町中', '23', '23217', '4838235', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '布袋町中', 'ホテイチョウナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市布袋町南', '23', '23217', '4838236', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '布袋町南', 'ホテイチョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市布袋町西', '23', '23217', '4838237', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '布袋町西', 'ホテイチョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市木賀本郷町南', '23', '23217', '4838238', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '木賀本郷町南', 'キガホンゴウチョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市木賀本郷町西', '23', '23217', '4838239', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '木賀本郷町西', 'キガホンゴウチョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市五明町青木', '23', '23217', '4838241', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '五明町青木', 'ゴミョウチョウアオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市五明町根場', '23', '23217', '4838242', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '五明町根場', 'ゴミョウチョウネバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市五明町石橋', '23', '23217', '4838243', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '五明町石橋', 'ゴミョウチョウイシバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市五明町高砂', '23', '23217', '4838244', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '五明町高砂', 'ゴミョウチョウタカス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市五明町大膳', '23', '23217', '4838245', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '五明町大膳', 'ゴミョウチョウダイゼン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市五明町福森', '23', '23217', '4838246', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '五明町福森', 'ゴミョウチョウフクモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市五明町太子堂', '23', '23217', '4838247', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '五明町太子堂', 'ゴミョウチョウタイシドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市五明町天王', '23', '23217', '4838248', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '五明町天王', 'ゴミョウチョウテンノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市五明町当光地', '23', '23217', '4838249', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '五明町当光地', 'ゴミョウチョウトウコウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市大間町新町', '23', '23217', '4838251', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '大間町新町', 'オオマチョウシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市大間町南大間', '23', '23217', '4838252', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '大間町南大間', 'オオマチョウミナミオオマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市木賀町杉', '23', '23217', '4838253', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '木賀町杉', 'キガチョウスギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市木賀町新開', '23', '23217', '4838254', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '木賀町新開', 'キガチョウシンガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市木賀町定和', '23', '23217', '4838255', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '木賀町定和', 'キガチョウジョウワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市中奈良町', '23', '23217', '4838256', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '中奈良町', 'ナカナラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市上奈良町神明', '23', '23217', '4838257', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '上奈良町', 'カミナラチョウ', null, null, '神明', 'シンメイ');
INSERT INTO `ms_addresses` VALUES ('48046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市上奈良町豊里', '23', '23217', '4838257', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '上奈良町', 'カミナラチョウ', null, null, '豊里', 'トヨサト');
INSERT INTO `ms_addresses` VALUES ('48047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市上奈良町観音寺', '23', '23217', '4838258', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '上奈良町', 'カミナラチョウ', null, null, '観音寺', 'カンノンジ');
INSERT INTO `ms_addresses` VALUES ('48048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市上奈良町久保', '23', '23217', '4838258', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '上奈良町', 'カミナラチョウ', null, null, '久保', 'クボ');
INSERT INTO `ms_addresses` VALUES ('48049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市上奈良町郷', '23', '23217', '4838258', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '上奈良町', 'カミナラチョウ', null, null, '郷', 'ゴウ');
INSERT INTO `ms_addresses` VALUES ('48050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市上奈良町瑞穂', '23', '23217', '4838258', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '上奈良町', 'カミナラチョウ', null, null, '瑞穂', 'ミズホ');
INSERT INTO `ms_addresses` VALUES ('48051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市上奈良町旭', '23', '23217', '4838259', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '上奈良町', 'カミナラチョウ', null, null, '旭', 'アサヒ');
INSERT INTO `ms_addresses` VALUES ('48052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市上奈良町栄', '23', '23217', '4838259', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '上奈良町', 'カミナラチョウ', null, null, '栄', 'サカエ');
INSERT INTO `ms_addresses` VALUES ('48053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市上奈良町天王', '23', '23217', '4838259', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '上奈良町', 'カミナラチョウ', null, null, '天王', 'テンノウ');
INSERT INTO `ms_addresses` VALUES ('48054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市上奈良町錦', '23', '23217', '4838259', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '上奈良町', 'カミナラチョウ', null, null, '錦', 'ニシキ');
INSERT INTO `ms_addresses` VALUES ('48055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市上奈良町緑', '23', '23217', '4838259', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '上奈良町', 'カミナラチョウ', null, null, '緑', 'ミドリ');
INSERT INTO `ms_addresses` VALUES ('48056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市島宮町吉原', '23', '23217', '4838262', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '島宮町吉原', 'シマミヤチョウヨシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市島宮町桐野', '23', '23217', '4838263', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '島宮町桐野', 'シマミヤチョウキリノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市島宮町城', '23', '23217', '4838264', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '島宮町城', 'シマミヤチョウシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市島宮町四日市場', '23', '23217', '4838265', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '島宮町四日市場', 'シマミヤチョウヨッカイチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市島宮町西之宮', '23', '23217', '4838266', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '島宮町西之宮', 'シマミヤチョウニシノミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市島宮町郷内', '23', '23217', '4838267', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '島宮町郷内', 'シマミヤチョウゴウナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市島宮町水堀', '23', '23217', '4838268', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '島宮町水堀', 'シマミヤチョウミズホリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市島宮町巡見', '23', '23217', '4838269', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '島宮町巡見', 'シマミヤチョウジュンケン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市古知野町桃源', '23', '23217', '4838271', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '古知野町桃源', 'コチノチョウトウゲン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市古知野町北屋敷', '23', '23217', '4838272', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '古知野町北屋敷', 'コチノチョウキタヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市古知野町本郷', '23', '23217', '4838273', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '古知野町本郷', 'コチノチョウホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市古知野町広見', '23', '23217', '4838274', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '古知野町広見', 'コチノチョウヒロミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市古知野町久保見', '23', '23217', '4838275', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '古知野町久保見', 'コチノチョウクボミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市古知野町宮前', '23', '23217', '4838276', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '古知野町宮前', 'コチノチョウミヤマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市古知野町福寿', '23', '23217', '4838277', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '古知野町福寿', 'コチノチョウフクジュ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市古知野町牧森', '23', '23217', '4838278', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '古知野町牧森', 'コチノチョウマキモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市古知野町宮裏', '23', '23217', '4838279', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '古知野町宮裏', 'コチノチョウミヤウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市宮田神明町緑', '23', '23217', '4838301', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '宮田神明町緑', 'ミヤタシンメイチョウミドリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市宮田神明町天王', '23', '23217', '4838302', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '宮田神明町天王', 'ミヤタシンメイチョウテンノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市宮田神明町旭', '23', '23217', '4838303', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '宮田神明町旭', 'ミヤタシンメイチョウアサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市宮田神明町栄', '23', '23217', '4838304', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '宮田神明町栄', 'ミヤタシンメイチョウサカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市宮田町生原', '23', '23217', '4838305', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '宮田町生原', 'ミヤタチョウハイバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市宮田町中島', '23', '23217', '4838306', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '宮田町中島', 'ミヤタチョウナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市宮田町新田', '23', '23217', '4838307', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '宮田町新田', 'ミヤタチョウシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市宮田神明町春日', '23', '23217', '4838308', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '宮田神明町春日', 'ミヤタシンメイチョウカスガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市村久野町九郷', '23', '23217', '4838311', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '村久野町九郷', 'ムラクノチョウクゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市村久野町金森', '23', '23217', '4838312', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '村久野町金森', 'ムラクノチョウカナモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市村久野町中郷', '23', '23217', '4838313', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '村久野町中郷', 'ムラクノチョウナカゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市村久野町寺町', '23', '23217', '4838314', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '村久野町寺町', 'ムラクノチョウテラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市村久野町大門', '23', '23217', '4838315', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '村久野町大門', 'ムラクノチョウダイモン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市村久野町河戸', '23', '23217', '4838316', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '村久野町河戸', 'ムラクノチョウカワド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市村久野町藤里', '23', '23217', '4838317', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '村久野町藤里', 'ムラクノチョウフジサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市村久野町宮出', '23', '23217', '4838318', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '村久野町宮出', 'ムラクノチョウミヤデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市村久野町寺東', '23', '23217', '4838319', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '村久野町寺東', 'ムラクノチョウテラヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市村久野町瀬頭', '23', '23217', '4838321', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '村久野町瀬頭', 'ムラクノチョウセガシラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市村久野町鳥附', '23', '23217', '4838322', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '村久野町鳥附', 'ムラクノチョウトリツキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市村久野町門弟山', '23', '23217', '4838323', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '村久野町門弟山', 'ムラクノチョウモンテイヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市村久野町南大門', '23', '23217', '4838324', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '村久野町南大門', 'ムラクノチョウミナミダイモン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市村久野町冨士塚', '23', '23217', '4838325', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '村久野町冨士塚', 'ムラクノチョウフジヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市村久野町仲原', '23', '23217', '4838326', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '村久野町仲原', 'ムラクノチョウナカハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市村久野町平野', '23', '23217', '4838327', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '村久野町平野', 'ムラクノチョウヒラノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市村久野町鈴道', '23', '23217', '4838328', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '村久野町鈴道', 'ムラクノチョウスズミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市古知野町高瀬', '23', '23217', '4838331', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '古知野町高瀬', 'コチノチョウタカセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市飛高町門野', '23', '23217', '4838332', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '飛高町門野', 'ヒダカチョウカドノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市飛高町泉', '23', '23217', '4838333', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '飛高町泉', 'ヒダカチョウイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市前飛保町緑ケ丘', '23', '23217', '4838334', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '前飛保町緑ケ丘', 'マエヒボチョウミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市前飛保町寺前', '23', '23217', '4838335', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '前飛保町寺前', 'マエヒボチョウテラマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市前飛保町寺町', '23', '23217', '4838336', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '前飛保町寺町', 'マエヒボチョウテラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市藤ケ丘', '23', '23217', '4838337', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '藤ケ丘', 'フジガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市前飛保町藤町', '23', '23217', '4838338', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '前飛保町藤町', 'マエヒボチョウフジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市飛高町栄', '23', '23217', '4838339', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '飛高町', 'ヒダカチョウ', null, null, '栄', 'サカエ');
INSERT INTO `ms_addresses` VALUES ('48107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市飛高町夫見添', '23', '23217', '4838339', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '飛高町', 'ヒダカチョウ', null, null, '夫見添', 'フミゾエ');
INSERT INTO `ms_addresses` VALUES ('48108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市前飛保町栄', '23', '23217', '4838341', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '前飛保町栄', 'マエヒボチョウサカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市松竹町上野', '23', '23217', '4838342', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '松竹町上野', 'マツタケチョウカミノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市松竹町米野', '23', '23217', '4838343', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '松竹町米野', 'マツタケチョウコメノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市後飛保町東高瀬', '23', '23217', '4838344', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '後飛保町東高瀬', 'ウシロヒボチョウヒガシタカセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市後飛保町高瀬', '23', '23217', '4838345', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '後飛保町高瀬', 'ウシロヒボチョウタカセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市後飛保町平野', '23', '23217', '4838346', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '後飛保町平野', 'ウシロヒボチョウヒラノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市後飛保町神明野', '23', '23217', '4838347', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '後飛保町神明野', 'ウシロヒボチョウシンメイノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市前飛保町河原', '23', '23217', '4838348', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '前飛保町河原', 'マエヒボチョウカワハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市前飛保町西町', '23', '23217', '4838349', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '前飛保町西町', 'マエヒボチョウニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市松竹町切野', '23', '23217', '4838351', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '松竹町切野', 'マツタケチョウキリノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市松竹町高山', '23', '23217', '4838352', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '松竹町高山', 'マツタケチョウタカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市松竹町元屋敷', '23', '23217', '4838353', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '松竹町元屋敷', 'マツタケチョウモトヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市松竹町八幡', '23', '23217', '4838354', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '松竹町八幡', 'マツタケチョウハチマン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市松竹町西瀬古', '23', '23217', '4838355', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '松竹町西瀬古', 'マツタケチョウニシセコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市松竹町西松竹', '23', '23217', '4838356', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '松竹町西松竹', 'マツタケチョウニシマツタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市松竹町向島', '23', '23217', '4838357', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '松竹町向島', 'マツタケチョウムカイジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市松竹町郷浦', '23', '23217', '4838358', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '松竹町郷浦', 'マツタケチョウゴウウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市松竹町東瀬古', '23', '23217', '4838359', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '松竹町東瀬古', 'マツタケチョウヒガシセコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市宮田町平和', '23', '23217', '4838361', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '宮田町平和', 'ミヤタチョウヘイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市河野町小脇', '23', '23217', '4838362', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '河野町小脇', 'コウノチョウコワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市河野町五十間', '23', '23217', '4838363', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '河野町五十間', 'コウノチョウゴジュッケン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市河野町川西', '23', '23217', '4838364', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '河野町川西', 'コウノチョウカワニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市河野町一色', '23', '23217', '4838365', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '河野町一色', 'コウノチョウイッシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市河野町管竹', '23', '23217', '4838366', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '河野町管竹', 'コウノチョウカンチク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市宮田町南野', '23', '23217', '4838367', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '宮田町南野', 'ミヤタチョウミナミノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市宮田町南野東', '23', '23217', '4838368', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '宮田町南野東', 'ミヤタチョウミナミノヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市河野町河野', '23', '23217', '4838369', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '河野町河野', 'コウノチョウコウノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市宮田町河沼', '23', '23217', '4838371', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '宮田町河沼', 'ミヤタチョウカワヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市宮田町宮東', '23', '23217', '4838372', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '宮田町宮東', 'ミヤタチョウミヤヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市宮田町菖蒲池', '23', '23217', '4838373', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '宮田町菖蒲池', 'ミヤタチョウショウブイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市宮田町久保見', '23', '23217', '4838374', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '宮田町久保見', 'ミヤタチョウクボミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市宮田町泉', '23', '23217', '4838375', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '宮田町泉', 'ミヤタチョウイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市宮田町藤ノ森', '23', '23217', '4838376', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '宮田町藤ノ森', 'ミヤタチョウフジノモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市宮田町本田島', '23', '23217', '4838377', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '宮田町本田島', 'ミヤタチョウホンダジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市宮田町四ツ谷', '23', '23217', '4838378', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '宮田町四ツ谷', 'ミヤタチョウヨツヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市宮田町本郷', '23', '23217', '4838379', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '宮田町本郷', 'ミヤタチョウホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市後飛保町出島', '23', '23217', '4838381', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '後飛保町出島', 'ウシロヒボチョウデシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市後飛保町薬師', '23', '23217', '4838382', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '後飛保町薬師', 'ウシロヒボチョウヤクシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市後飛保町前川', '23', '23217', '4838383', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '後飛保町前川', 'ウシロヒボチョウマエカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市後飛保町宮前', '23', '23217', '4838384', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '後飛保町宮前', 'ウシロヒボチョウミヤマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市後飛保町中町', '23', '23217', '4838385', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '後飛保町中町', 'ウシロヒボチョウナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市後飛保町西町', '23', '23217', '4838386', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '後飛保町西町', 'ウシロヒボチョウニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市後飛保町新開', '23', '23217', '4838387', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '後飛保町新開', 'ウシロヒボチョウシンカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市後飛保町本郷', '23', '23217', '4838388', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '後飛保町本郷', 'ウシロヒボチョウホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市後飛保町両家', '23', '23217', '4838389', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '後飛保町両家', 'ウシロヒボチョウリョウケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市慈光堂町北', '23', '23217', '4838401', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '慈光堂町北', 'ジコウドウチョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市慈光堂町南', '23', '23217', '4838402', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '慈光堂町南', 'ジコウドウチョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市小杁町千代見', '23', '23217', '4838403', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '小杁町千代見', 'オイリチョウチヨミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市小杁町林', '23', '23217', '4838404', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '小杁町林', 'オイリチョウハヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市小杁町鴨ケ池', '23', '23217', '4838405', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '小杁町鴨ケ池', 'オイリチョウカモガイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市小脇町小脇', '23', '23217', '4838406', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '小脇町小脇', 'コワキチョウコワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市小杁町明土', '23', '23217', '4838407', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '小杁町明土', 'オイリチョウミョウド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市小杁町長者毛東', '23', '23217', '4838408', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '小杁町長者毛東', 'オイリチョウチョウジャゲヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市小杁町長者毛西', '23', '23217', '4838409', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '小杁町長者毛西', 'オイリチョウチョウジャゲニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市小杁町八幡', '23', '23217', '4838411', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '小杁町八幡', 'オイリチョウハチマン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市小杁町寺ノ内', '23', '23217', '4838412', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '小杁町寺ノ内', 'オイリチョウテラノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市小杁町本郷', '23', '23217', '4838413', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '小杁町本郷', 'オイリチョウホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市小杁町一色', '23', '23217', '4838414', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '小杁町一色', 'オイリチョウイッシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市東野町鐘鋳山', '23', '23217', '4838415', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '東野町鐘鋳山', 'ヒガシノチョウカネイリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市東野町長幡寺', '23', '23217', '4838416', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '東野町長幡寺', 'ヒガシノチョウチョウバンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市東野町烏森', '23', '23217', '4838417', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '東野町烏森', 'ヒガシノチョウカラスモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市東野町米野', '23', '23217', '4838418', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '東野町米野', 'ヒガシノチョウコメノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市東野町七社宮', '23', '23217', '4838419', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '東野町七社宮', 'ヒガシノチョウナナシャグウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市東野町郷前', '23', '23217', '4838421', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '東野町郷前', 'ヒガシノチョウゴウマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市東野町神上', '23', '23217', '4838422', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '東野町神上', 'ヒガシノチョウカミアゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市東野町郷前西', '23', '23217', '4838423', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '東野町郷前西', 'ヒガシノチョウゴウマエニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市東野町西出', '23', '23217', '4838424', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '東野町西出', 'ヒガシノチョウニシデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市東野町河戸', '23', '23217', '4838425', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '東野町河戸', 'ヒガシノチョウコウド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市東野町河原', '23', '23217', '4838426', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '東野町河原', 'ヒガシノチョウカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市東野町新田', '23', '23217', '4838427', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '東野町新田', 'ヒガシノチョウシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市東野町新田東', '23', '23217', '4838428', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '東野町新田東', 'ヒガシノチョウシンデンヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市東野町西神田', '23', '23217', '4838429', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '東野町西神田', 'ヒガシノチョウニシジンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市東野町神田', '23', '23217', '4838431', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '東野町神田', 'ヒガシノチョウジンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市東野町東神田', '23', '23217', '4838432', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '東野町東神田', 'ヒガシノチョウヒガシジンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県江南市東野町岩見', '23', '23217', '4838433', '愛知県', 'アイチケン', '江南市', 'コウナンシ', '東野町岩見', 'ヒガシノチョウイワミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市', '23', '23215', '4840000', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('48191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市垣ノ内', '23', '23215', '4840001', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '垣ノ内', 'カキノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市栗栖', '23', '23215', '4840002', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '栗栖', 'クリス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市善師野', '23', '23215', '4840003', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '善師野', 'ゼンジノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市善師野台', '23', '23215', '4840004', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '善師野台', 'ゼンジノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市今井', '23', '23215', '4840005', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '今井', 'イマイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市八曽', '23', '23215', '4840006', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '八曽', 'ハッソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市十三塚', '23', '23215', '4840007', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '十三塚', 'ジュウサンヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市岩穴', '23', '23215', '4840008', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '岩穴', 'イワアナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市田口', '23', '23215', '4840009', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '田口', 'タグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市北高根', '23', '23215', '4840011', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '北高根', 'キタタカネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市南高根', '23', '23215', '4840012', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '南高根', 'ミナミタカネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市寺洞', '23', '23215', '4840013', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '寺洞', 'テラボラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市郷中', '23', '23215', '4840014', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '郷中', 'ゴウナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市御殿屋敷', '23', '23215', '4840015', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '御殿屋敷', 'ゴテンヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市藪ケ洞', '23', '23215', '4840016', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '藪ケ洞', 'ヤブガホラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市篠平', '23', '23215', '4840017', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '篠平', 'シノダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市佐ケ瀬', '23', '23215', '4840018', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '佐ケ瀬', 'サガセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市四季の丘', '23', '23215', '4840019', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '四季の丘', 'シキノオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市もえぎケ丘', '23', '23215', '4840020', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', 'もえぎケ丘', 'モエギガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市杁下', '23', '23215', '4840021', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '杁下', 'イリシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市白山洞', '23', '23215', '4840022', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '白山洞', 'ハクサンボラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市堤下', '23', '23215', '4840023', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '堤下', 'ツツミシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市喜六屋敷', '23', '23215', '4840024', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '喜六屋敷', 'キロクヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市野中', '23', '23215', '4840025', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '野中', 'ノナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市内屋敷', '23', '23215', '4840026', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '内屋敷', 'ウチヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市倉曽洞', '23', '23215', '4840027', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '倉曽洞', 'クラソボラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市向田', '23', '23215', '4840028', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '向田', 'ムコダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市西洞', '23', '23215', '4840029', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '西洞', 'ニシボラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市東桑原', '23', '23215', '4840031', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '東桑原', 'ヒガシクワバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市池野安楽寺', '23', '23215', '4840032', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '池野安楽寺', 'イケノアズクシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市井ノ元', '23', '23215', '4840033', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '井ノ元', 'イノモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市大洞', '23', '23215', '4840034', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '大洞', 'オオボラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市裏山', '23', '23215', '4840035', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '裏山', 'ウラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市西桑原', '23', '23215', '4840036', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '西桑原', 'ニシクワバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市西片草', '23', '23215', '4840037', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '西片草', 'ニシカタクサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市東片草', '23', '23215', '4840038', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '東片草', 'ヒガシカタクサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市長者町', '23', '23215', '4840041', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '長者町', 'チョウジャマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市二本木', '23', '23215', '4840042', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '二本木', 'ニホンギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市上ノ田', '23', '23215', '4840043', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '上ノ田', 'カミノタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市下屋敷', '23', '23215', '4840044', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '下屋敷', 'シモヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市仲畑', '23', '23215', '4840045', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '仲畑', 'ナカハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市屋敷裏', '23', '23215', '4840046', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '屋敷裏', 'ヤシキウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市内久保', '23', '23215', '4840047', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '内久保', 'ウチクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市楽田内久保', '23', '23215', '4840048', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '楽田内久保', 'ガクデンウチクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市前田面', '23', '23215', '4840049', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '前田面', 'マエダメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市宮裏', '23', '23215', '4840051', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '宮裏', 'ミヤウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市早稲田', '23', '23215', '4840052', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '早稲田', 'ワセダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市石畑', '23', '23215', '4840053', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '石畑', 'イシハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市仲屋敷', '23', '23215', '4840054', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '仲屋敷', 'ナカヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市牛岩', '23', '23215', '4840055', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '牛岩', 'ウシイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市稲干場', '23', '23215', '4840056', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '稲干場', 'イナホシバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市富士山', '23', '23215', '4840057', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '富士山', 'フジヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市大門', '23', '23215', '4840058', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '大門', 'ダイモン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市上坂町', '23', '23215', '4840059', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '上坂町', 'カミサカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市前原', '23', '23215', '4840061', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '前原', 'マエハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市前原味鹿', '23', '23215', '4840062', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '前原味鹿', 'マエハラアジカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市前原南', '23', '23215', '4840063', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '前原南', 'マエハラミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市前原西', '23', '23215', '4840064', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '前原西', 'マエハラニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市五郎丸東', '23', '23215', '4840065', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '五郎丸東', 'ゴロウマルヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市五郎丸', '23', '23215', '4840066', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '五郎丸', 'ゴロウマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市内田東町', '23', '23215', '4840071', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '内田東町', 'ウチダヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市丸山天白町', '23', '23215', '4840072', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '丸山天白町', 'マルヤマテンパクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市天神町', '23', '23215', '4840073', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '天神町', 'テンジンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市梅坪', '23', '23215', '4840074', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '梅坪', 'ウメツボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市橋爪東', '23', '23215', '4840075', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '橋爪東', 'ハシヅメヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市橋爪', '23', '23215', '4840076', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '橋爪', 'ハシヅメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市上野', '23', '23215', '4840077', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '上野', 'カミノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市上野新町', '23', '23215', '4840078', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '上野新町', 'カミノシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市木津', '23', '23215', '4840079', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '木津', 'コッツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市犬山', '23', '23215', '4840081', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '犬山', 'イヌヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市北古券', '23', '23215', '4840082', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '北古券', 'キタコケン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市東古券', '23', '23215', '4840083', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '東古券', 'ヒガシコケン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市南古券', '23', '23215', '4840084', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '南古券', 'ミナミコケン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市西古券', '23', '23215', '4840085', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '西古券', 'ニシコケン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市松本町', '23', '23215', '4840086', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '松本町', 'マツモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市中山町', '23', '23215', '4840087', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '中山町', 'ナカヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市継鹿尾', '23', '23215', '4840091', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '継鹿尾', 'ツガオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市富岡', '23', '23215', '4840092', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '富岡', 'トミオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市富岡東', '23', '23215', '4840093', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '富岡東', 'トミオカヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市塔野地', '23', '23215', '4840094', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '塔野地', 'トウノジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市塔野地杉', '23', '23215', '4840095', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '塔野地杉', 'トウノジスギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市塔野地西', '23', '23215', '4840096', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '塔野地西', 'トウノジニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市塔野地北', '23', '23215', '4840097', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '塔野地北', 'トウノジキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市富岡南', '23', '23215', '4840098', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '富岡南', 'トミオカミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市富岡新町', '23', '23215', '4840099', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '富岡新町', 'トミオカシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市羽黒安戸南', '23', '23215', '4840801', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '羽黒安戸南', 'ハグロヤスドミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市羽黒安戸西', '23', '23215', '4840802', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '羽黒安戸西', 'ハグロヤスドニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市羽黒新赤坂', '23', '23215', '4840803', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '羽黒新赤坂', 'ハグロシンアカサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市羽黒桜海道', '23', '23215', '4840804', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '羽黒桜海道', 'ハグロサクラカイドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市羽黒新外山', '23', '23215', '4840805', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '羽黒新外山', 'ハグロシントヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市羽黒朝日', '23', '23215', '4840806', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '羽黒朝日', 'ハグロアサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市羽黒鉾添', '23', '23215', '4840807', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '羽黒鉾添', 'ハグロホコゾエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市楽田長塚東', '23', '23215', '4840811', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '楽田長塚東', 'ガクデンナガツカヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市山ノ田', '23', '23215', '4840812', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '山ノ田', 'ヤマノタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市山ノ田腰', '23', '23215', '4840813', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '山ノ田腰', 'ヤマノタゴシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市高根', '23', '23215', '4840814', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '高根', 'タカネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市郷東', '23', '23215', '4840815', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '郷東', 'ゴウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市楽田原東', '23', '23215', '4840816', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '楽田原東', 'ガクデンハラヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市郷西', '23', '23215', '4840817', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '郷西', 'ゴウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市北浦', '23', '23215', '4840818', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '北浦', 'キタウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市楽田長塚西', '23', '23215', '4840819', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '楽田長塚西', 'ガクデンナガツカニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市山崎西', '23', '23215', '4840821', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '山崎西', 'ヤマザキニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市中切', '23', '23215', '4840822', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '中切', 'ナカギリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市北大門', '23', '23215', '4840823', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '北大門', 'キタダイモン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市北洞', '23', '23215', '4840824', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '北洞', 'キタボラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市常福寺洞', '23', '23215', '4840825', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '常福寺洞', 'ジョウフクジボラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市山ノ鼻', '23', '23215', '4840826', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '山ノ鼻', 'ヤマノハナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市薬師前', '23', '23215', '4840827', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '薬師前', 'ヤクシマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市薬師浦', '23', '23215', '4840828', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '薬師浦', 'ヤクシウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市堂屋敷', '23', '23215', '4840831', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '堂屋敷', 'ドウヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市向山', '23', '23215', '4840832', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '向山', 'ムコヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市宮西', '23', '23215', '4840833', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '宮西', 'ミヤニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市宮山', '23', '23215', '4840834', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '宮山', 'ミヤヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市蓮池', '23', '23215', '4840835', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '蓮池', 'ハスイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市笛田', '23', '23215', '4840836', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '笛田', 'フエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市荒井', '23', '23215', '4840837', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '荒井', 'アライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市小路', '23', '23215', '4840838', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '小路', 'コジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市桃山台', '23', '23215', '4840839', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '桃山台', 'モモヤマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市楽田小針', '23', '23215', '4840841', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '楽田小針', 'ガクデンコバリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市下小針', '23', '23215', '4840842', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '下小針', 'シモコバリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市楽田打越', '23', '23215', '4840843', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '楽田打越', 'ガクデンウチコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市鷺山', '23', '23215', '4840844', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '鷺山', 'サギヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市高坪', '23', '23215', '4840845', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '高坪', 'タカツボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市楽田山ノ田', '23', '23215', '4840846', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '楽田山ノ田', 'ガクデンヤマノタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市烏杜', '23', '23215', '4840851', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '烏杜', 'カラスモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市中小針', '23', '23215', '4840852', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '中小針', 'ナカコバリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市横町', '23', '23215', '4840853', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '横町', 'ヨコマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市裏ノ門', '23', '23215', '4840854', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '裏ノ門', 'ウラノモン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市小洞', '23', '23215', '4840855', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '小洞', 'コボラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市楽田天神', '23', '23215', '4840856', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '楽田天神', 'ガクデンテンジン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市外屋敷', '23', '23215', '4840857', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '外屋敷', 'トヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市城山', '23', '23215', '4840858', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '城山', 'シロヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市若宮', '23', '23215', '4840861', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '若宮', 'ワカミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市石塚', '23', '23215', '4840862', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '石塚', 'イシヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市野田', '23', '23215', '4840863', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '野田', 'ノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市番前', '23', '23215', '4840864', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '番前', 'バンマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市藪畔', '23', '23215', '4840865', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '藪畔', 'ヤブグロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市寺西', '23', '23215', '4840866', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '寺西', 'テラニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市九左エ門廻り', '23', '23215', '4840867', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '九左エ門廻り', 'クザエモンマワリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市東北野', '23', '23215', '4840868', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '東北野', 'ヒガシキタノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市惣作', '23', '23215', '4840869', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '惣作', 'ソウサク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市前並', '23', '23215', '4840871', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '前並', 'マエナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市岩田', '23', '23215', '4840872', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '岩田', 'イワタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市天王前', '23', '23215', '4840873', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '天王前', 'テンオウマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市楽田今村', '23', '23215', '4840874', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '楽田今村', 'ガクデンイマムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市林吾塚', '23', '23215', '4840875', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '林吾塚', 'リンゴヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市山神', '23', '23215', '4840876', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '山神', 'ヤマガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市楽田東追分', '23', '23215', '4840877', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '楽田東追分', 'ガクデンヒガシオイワケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市栗林', '23', '23215', '4840878', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '栗林', 'クリバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市楽田三ツ塚', '23', '23215', '4840879', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '楽田三ツ塚', 'ガクデンミツヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市羽黒成海西', '23', '23215', '4840881', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '羽黒成海西', 'ハグロナルミニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市羽黒菊川', '23', '23215', '4840882', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '羽黒菊川', 'ハグロキクカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市羽黒成海南', '23', '23215', '4840883', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '羽黒成海南', 'ハグロナルミミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市羽黒起', '23', '23215', '4840884', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '羽黒起', 'ハグロオコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市楽田原西', '23', '23215', '4840885', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '楽田原西', 'ガクデンハラニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市宮浦', '23', '23215', '4840886', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '宮浦', 'ミヤウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市池田', '23', '23215', '4840887', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '池田', 'イケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市羽黒新田', '23', '23215', '4840888', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '羽黒新田', 'ハグロシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市羽黒高橋', '23', '23215', '4840889', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '羽黒高橋', 'ハグロタカハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市羽黒恩田島', '23', '23215', '4840891', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '羽黒恩田島', 'ハグロオンダシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市羽黒惣境', '23', '23215', '4840892', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '羽黒惣境', 'ハグロソウサカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市羽黒栄', '23', '23215', '4840893', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '羽黒栄', 'ハグロサカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市羽黒', '23', '23215', '4840894', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '羽黒', 'ハグロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市羽黒摺墨', '23', '23215', '4840895', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '羽黒摺墨', 'ハグロスルスミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市羽黒余町', '23', '23215', '4840896', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '羽黒余町', 'ハグロヨマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市羽黒堂前', '23', '23215', '4840897', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '羽黒堂前', 'ハグロドウマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市羽黒稲葉西', '23', '23215', '4840898', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '羽黒稲葉西', 'ハグロイナバニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市羽黒稲葉東', '23', '23215', '4840899', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '羽黒稲葉東', 'ハグロイナバヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市柿畑', '23', '23215', '4840901', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '柿畑', 'カキバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市追分', '23', '23215', '4840902', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '追分', 'オイワケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市追分東', '23', '23215', '4840903', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '追分東', 'オイワケヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市楽田勝部前', '23', '23215', '4840904', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '楽田勝部前', 'ガクデンカチベマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市西北野', '23', '23215', '4840905', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '西北野', 'ニシキタノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市焼野', '23', '23215', '4840906', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '焼野', 'ヤケノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市楽田地蔵池', '23', '23215', '4840907', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '楽田地蔵池', 'ガクデンジゾウイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市大上戸', '23', '23215', '4840908', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '大上戸', 'ダイジョウド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市北之門', '23', '23215', '4840911', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '北之門', 'キタノモン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市舟田', '23', '23215', '4840912', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '舟田', 'フナダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市鳥屋越', '23', '23215', '4840913', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '鳥屋越', 'トリヤコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市観音浦', '23', '23215', '4840914', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '観音浦', 'カンノンウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市楽田上沼', '23', '23215', '4840915', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '楽田上沼', 'ガクデンカミヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市楽田西浦', '23', '23215', '4840916', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '楽田西浦', 'ガクデンニシウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市土取', '23', '23215', '4840917', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '土取', 'ツチトリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市ニタ田', '23', '23215', '4840918', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', 'ニタ田', 'ニタンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市中道', '23', '23215', '4840919', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '中道', 'ナカミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市味加田', '23', '23215', '4840921', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '味加田', 'アジカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市北大橋', '23', '23215', '4840922', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '北大橋', 'キタオオハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市下沼', '23', '23215', '4840923', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '下沼', 'シモヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市楽田大橋', '23', '23215', '4840924', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '楽田大橋', 'ガクデンオオハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市楽田西野', '23', '23215', '4840925', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '楽田西野', 'ガクデンニシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市楽田一色浦', '23', '23215', '4840926', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '楽田一色浦', 'ガクデンイシキウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市的場', '23', '23215', '4840927', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '的場', 'マトバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市七ツ屋', '23', '23215', '4840928', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '七ツ屋', 'ナナツヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市南大橋', '23', '23215', '4840931', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '南大橋', 'ミナミオオハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市西野', '23', '23215', '4840932', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '西野', 'ニシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市東唐曽', '23', '23215', '4840933', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '東唐曽', 'ヒガシガラソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市中唐曽', '23', '23215', '4840934', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '中唐曽', 'ナカガラソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市西唐曽', '23', '23215', '4840935', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '西唐曽', 'ニシガラソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市楽田青塚', '23', '23215', '4840936', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '楽田青塚', 'ガクデンアオツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市宮東', '23', '23215', '4840937', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '宮東', 'ミヤヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市巾廻り', '23', '23215', '4840941', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '巾廻り', 'ハバマワリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市楽田巾', '23', '23215', '4840942', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '楽田巾', 'ガクデンハバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市巾前', '23', '23215', '4840943', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '巾前', 'ハバマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市楽田安師', '23', '23215', '4840944', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '楽田安師', 'ガクデンアンシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市青塚', '23', '23215', '4840945', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '青塚', 'アオツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市東大円', '23', '23215', '4840946', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '東大円', 'ヒガシダイエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市楽田大円', '23', '23215', '4840947', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '楽田大円', 'ガクデンダイエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市西大円', '23', '23215', '4840948', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '西大円', 'ニシダイエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市八反田', '23', '23215', '4840951', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '八反田', 'ハッタンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市上舞台', '23', '23215', '4840952', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '上舞台', 'カミブタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市下舞台', '23', '23215', '4840953', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '下舞台', 'シモブタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市元散前', '23', '23215', '4840954', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '元散前', 'モトサンマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市角池', '23', '23215', '4840955', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '角池', 'カクイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市新川', '23', '23215', '4840956', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '新川', 'シンカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市五反田', '23', '23215', '4840957', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '五反田', 'ゴタンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市平塚', '23', '23215', '4840958', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '平塚', 'ヒラツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市北平塚', '23', '23215', '4840959', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '北平塚', 'キタヒラツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市太吉屋敷', '23', '23215', '4840961', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '太吉屋敷', 'タキチヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市落添', '23', '23215', '4840962', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '落添', 'オチゾエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市楽田鶴池', '23', '23215', '4840963', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '楽田鶴池', 'ガクデンツルイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市上榎島', '23', '23215', '4840964', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '上榎島', 'カミエノキジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市下榎島', '23', '23215', '4840965', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '下榎島', 'シモエノキジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県犬山市五郎丸二タ俣', '23', '23215', '4840966', '愛知県', 'アイチケン', '犬山市', 'イヌヤマシ', '五郎丸二タ俣', 'ゴロウマルフタマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県小牧市', '23', '23219', '4850000', '愛知県', 'アイチケン', '小牧市', 'コマキシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('48426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県小牧市久保一色東', '23', '23219', '4850001', '愛知県', 'アイチケン', '小牧市', 'コマキシ', '久保一色東', 'クボイシキヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県小牧市葭原', '23', '23219', '4850002', '愛知県', 'アイチケン', '小牧市', 'コマキシ', '葭原', 'ヨシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県小牧市久保一色', '23', '23219', '4850003', '愛知県', 'アイチケン', '小牧市', 'コマキシ', '久保一色', 'クボイシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県小牧市田県町', '23', '23219', '4850004', '愛知県', 'アイチケン', '小牧市', 'コマキシ', '田県町', 'タガタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県小牧市久保本町', '23', '23219', '4850005', '愛知県', 'アイチケン', '小牧市', 'コマキシ', '久保本町', 'クボホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県小牧市久保新町', '23', '23219', '4850006', '愛知県', 'アイチケン', '小牧市', 'コマキシ', '久保新町', 'クボシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県小牧市久保一色南', '23', '23219', '4850007', '愛知県', 'アイチケン', '小牧市', 'コマキシ', '久保一色南', 'クボイシキミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県小牧市寺西', '23', '23219', '4850008', '愛知県', 'アイチケン', '小牧市', 'コマキシ', '寺西', 'テラニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県小牧市岩崎', '23', '23219', '4850011', '愛知県', 'アイチケン', '小牧市', 'コマキシ', '岩崎', 'イワザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県小牧市小牧原新田', '23', '23219', '4850012', '愛知県', 'アイチケン', '小牧市', 'コマキシ', '小牧原新田', 'コマキハラシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県小牧市新町', '23', '23219', '4850013', '愛知県', 'アイチケン', '小牧市', 'コマキシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県小牧市安田町', '23', '23219', '4850014', '愛知県', 'アイチケン', '小牧市', 'コマキシ', '安田町', 'ヤスダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県小牧市間々', '23', '23219', '4850015', '愛知県', 'アイチケン', '小牧市', 'コマキシ', '間々', 'ママ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県小牧市間々原新田', '23', '23219', '4850016', '愛知県', 'アイチケン', '小牧市', 'コマキシ', '間々原新田', 'ママハラシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県小牧市岩崎原', '23', '23219', '4850017', '愛知県', 'アイチケン', '小牧市', 'コマキシ', '岩崎原', 'イワザキハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県小牧市二重堀', '23', '23219', '4850021', '愛知県', 'アイチケン', '小牧市', 'コマキシ', '二重堀', 'フタエボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県小牧市北外山入鹿新田', '23', '23219', '4850022', '愛知県', 'アイチケン', '小牧市', 'コマキシ', '北外山入鹿新田', 'キタトヤマイルカシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県小牧市北外山', '23', '23219', '4850023', '愛知県', 'アイチケン', '小牧市', 'コマキシ', '北外山', 'キタトヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県小牧市南外山', '23', '23219', '4850024', '愛知県', 'アイチケン', '小牧市', 'コマキシ', '南外山', 'ミナミトヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県小牧市春日寺', '23', '23219', '4850025', '愛知県', 'アイチケン', '小牧市', 'コマキシ', '春日寺', 'カスガンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県小牧市大山小牧大山', '23', '23219', '4850026', '愛知県', 'アイチケン', '小牧市', 'コマキシ', '大山', 'オオヤマ', null, null, '小牧大山', 'コマキオオヤマ');
INSERT INTO `ms_addresses` VALUES ('48447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県小牧市緑町', '23', '23219', '4850027', '愛知県', 'アイチケン', '小牧市', 'コマキシ', '緑町', 'ミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県小牧市東新町', '23', '23219', '4850028', '愛知県', 'アイチケン', '小牧市', 'コマキシ', '東新町', 'ヒガシシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県小牧市中央', '23', '23219', '4850029', '愛知県', 'アイチケン', '小牧市', 'コマキシ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県小牧市若草町', '23', '23219', '4850031', '愛知県', 'アイチケン', '小牧市', 'コマキシ', '若草町', 'ワカクサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県小牧市掛割町', '23', '23219', '4850032', '愛知県', 'アイチケン', '小牧市', 'コマキシ', '掛割町', 'カケワリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県小牧市郷中', '23', '23219', '4850033', '愛知県', 'アイチケン', '小牧市', 'コマキシ', '郷中', 'ゴウナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県小牧市市之久田', '23', '23219', '4850034', '愛知県', 'アイチケン', '小牧市', 'コマキシ', '市之久田', 'イチノクタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県小牧市多気東町', '23', '23219', '4850035', '愛知県', 'アイチケン', '小牧市', 'コマキシ', '多気東町', 'タキヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県小牧市下小針天神', '23', '23219', '4850036', '愛知県', 'アイチケン', '小牧市', 'コマキシ', '下小針天神', 'シモオバリテンジン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県小牧市小針', '23', '23219', '4850037', '愛知県', 'アイチケン', '小牧市', 'コマキシ', '小針', 'オバリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県小牧市外堀', '23', '23219', '4850039', '愛知県', 'アイチケン', '小牧市', 'コマキシ', '外堀', 'ソトボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県小牧市小牧', '23', '23219', '4850041', '愛知県', 'アイチケン', '小牧市', 'コマキシ', '小牧', 'コマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県小牧市桜井', '23', '23219', '4850042', '愛知県', 'アイチケン', '小牧市', 'コマキシ', '桜井', 'サクライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県小牧市桜井本町', '23', '23219', '4850043', '愛知県', 'アイチケン', '小牧市', 'コマキシ', '桜井本町', 'サクライホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県小牧市常普請', '23', '23219', '4850044', '愛知県', 'アイチケン', '小牧市', 'コマキシ', '常普請', 'ジョウブシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県小牧市川西', '23', '23219', '4850045', '愛知県', 'アイチケン', '小牧市', 'コマキシ', '川西', 'カワニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県小牧市堀の内', '23', '23219', '4850046', '愛知県', 'アイチケン', '小牧市', 'コマキシ', '堀の内', 'ホリノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県小牧市曙町', '23', '23219', '4850047', '愛知県', 'アイチケン', '小牧市', 'コマキシ', '曙町', 'アケボノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県小牧市間々本町', '23', '23219', '4850048', '愛知県', 'アイチケン', '小牧市', 'コマキシ', '間々本町', 'ママホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県小牧市山北町', '23', '23219', '4850049', '愛知県', 'アイチケン', '小牧市', 'コマキシ', '山北町', 'ヤマキタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県小牧市下小針中島', '23', '23219', '4850051', '愛知県', 'アイチケン', '小牧市', 'コマキシ', '下小針中島', 'シモオバリナカシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県小牧市多気中町', '23', '23219', '4850052', '愛知県', 'アイチケン', '小牧市', 'コマキシ', '多気中町', 'タキナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県小牧市多気南町', '23', '23219', '4850053', '愛知県', 'アイチケン', '小牧市', 'コマキシ', '多気南町', 'タキミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県小牧市多気西町', '23', '23219', '4850054', '愛知県', 'アイチケン', '小牧市', 'コマキシ', '多気西町', 'タキニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県小牧市多気北町', '23', '23219', '4850055', '愛知県', 'アイチケン', '小牧市', 'コマキシ', '多気北町', 'タキキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県小牧市小木南', '23', '23219', '4850056', '愛知県', 'アイチケン', '小牧市', 'コマキシ', '小木南', 'コキミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県小牧市小木西', '23', '23219', '4850057', '愛知県', 'アイチケン', '小牧市', 'コマキシ', '小木西', 'コキニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県小牧市小木', '23', '23219', '4850058', '愛知県', 'アイチケン', '小牧市', 'コマキシ', '小木', 'コキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県小牧市小木東', '23', '23219', '4850059', '愛知県', 'アイチケン', '小牧市', 'コマキシ', '小木東', 'コキヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県小牧市藤島町向江', '23', '23219', '4850061', '愛知県', 'アイチケン', '小牧市', 'コマキシ', '藤島町向江', 'フジシマチョウムカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県小牧市藤島町中島', '23', '23219', '4850062', '愛知県', 'アイチケン', '小牧市', 'コマキシ', '藤島町中島', 'フジシマチョウナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県小牧市藤島町鏡池', '23', '23219', '4850063', '愛知県', 'アイチケン', '小牧市', 'コマキシ', '藤島町鏡池', 'フジシマチョウカガミイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県小牧市藤島町徳願寺', '23', '23219', '4850064', '愛知県', 'アイチケン', '小牧市', 'コマキシ', '藤島町徳願寺', 'フジシマチョウトクガンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県小牧市藤島町五才田', '23', '23219', '4850065', '愛知県', 'アイチケン', '小牧市', 'コマキシ', '藤島町五才田', 'フジシマチョウゴサイデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県小牧市藤島町出口', '23', '23219', '4850066', '愛知県', 'アイチケン', '小牧市', 'コマキシ', '藤島町出口', 'フジシマチョウデグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県小牧市藤島町居屋敷', '23', '23219', '4850067', '愛知県', 'アイチケン', '小牧市', 'コマキシ', '藤島町居屋敷', 'フジシマチョウイヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県小牧市藤島', '23', '23219', '4850068', '愛知県', 'アイチケン', '小牧市', 'コマキシ', '藤島', 'フジシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県小牧市藤島町梵天', '23', '23219', '4850069', '愛知県', 'アイチケン', '小牧市', 'コマキシ', '藤島町梵天', 'フジシマチョウボンテン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県小牧市弥生町', '23', '23219', '4850071', '愛知県', 'アイチケン', '小牧市', 'コマキシ', '弥生町', 'ヤヨイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県小牧市元町', '23', '23219', '4850072', '愛知県', 'アイチケン', '小牧市', 'コマキシ', '元町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県小牧市舟津', '23', '23219', '4850073', '愛知県', 'アイチケン', '小牧市', 'コマキシ', '舟津', 'フナツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県小牧市新小木', '23', '23219', '4850074', '愛知県', 'アイチケン', '小牧市', 'コマキシ', '新小木', 'シンコキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県小牧市三ツ渕', '23', '23219', '4850075', '愛知県', 'アイチケン', '小牧市', 'コマキシ', '三ツ渕', 'ミツブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県小牧市三ツ渕原新田', '23', '23219', '4850076', '愛知県', 'アイチケン', '小牧市', 'コマキシ', '三ツ渕原新田', 'ミツブチハラシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県小牧市西之島', '23', '23219', '4850077', '愛知県', 'アイチケン', '小牧市', 'コマキシ', '西之島', 'ニシノシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県小牧市西島町', '23', '23219', '4850078', '愛知県', 'アイチケン', '小牧市', 'コマキシ', '西島町', 'ニシジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県小牧市横内', '23', '23219', '4850081', '愛知県', 'アイチケン', '小牧市', 'コマキシ', '横内', 'ヨコウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県小牧市村中', '23', '23219', '4850082', '愛知県', 'アイチケン', '小牧市', 'コマキシ', '村中', 'ムラナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県小牧市村中新町', '23', '23219', '4850083', '愛知県', 'アイチケン', '小牧市', 'コマキシ', '村中新町', 'ムラナカシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県小牧市入鹿出新田', '23', '23219', '4850084', '愛知県', 'アイチケン', '小牧市', 'コマキシ', '入鹿出新田', 'イルカデシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県小牧市河内屋新田', '23', '23219', '4850085', '愛知県', 'アイチケン', '小牧市', 'コマキシ', '河内屋新田', 'カワチヤシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県小牧市大山篠岡大山', '23', '23219', '4850801', '愛知県', 'アイチケン', '小牧市', 'コマキシ', '大山', 'オオヤマ', null, null, '篠岡大山', 'シノオカオオヤマ');
INSERT INTO `ms_addresses` VALUES ('48502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県小牧市大草', '23', '23219', '4850802', '愛知県', 'アイチケン', '小牧市', 'コマキシ', '大草', 'オオクサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県小牧市高根', '23', '23219', '4850803', '愛知県', 'アイチケン', '小牧市', 'コマキシ', '高根', 'タカネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県小牧市池之内', '23', '23219', '4850804', '愛知県', 'アイチケン', '小牧市', 'コマキシ', '池之内', 'イケノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県小牧市林', '23', '23219', '4850805', '愛知県', 'アイチケン', '小牧市', 'コマキシ', '林', 'ハヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県小牧市野口', '23', '23219', '4850806', '愛知県', 'アイチケン', '小牧市', 'コマキシ', '野口', 'ノグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県小牧市光ケ丘', '23', '23219', '4850811', '愛知県', 'アイチケン', '小牧市', 'コマキシ', '光ケ丘', 'ヒカリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県小牧市城山', '23', '23219', '4850812', '愛知県', 'アイチケン', '小牧市', 'コマキシ', '城山', 'シロヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県小牧市桃ケ丘', '23', '23219', '4850813', '愛知県', 'アイチケン', '小牧市', 'コマキシ', '桃ケ丘', 'モモガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県小牧市古雅', '23', '23219', '4850814', '愛知県', 'アイチケン', '小牧市', 'コマキシ', '古雅', 'コガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県小牧市篠岡', '23', '23219', '4850815', '愛知県', 'アイチケン', '小牧市', 'コマキシ', '篠岡', 'シノオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県小牧市本庄', '23', '23219', '4850821', '愛知県', 'アイチケン', '小牧市', 'コマキシ', '本庄', 'ホンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県小牧市上末', '23', '23219', '4850822', '愛知県', 'アイチケン', '小牧市', 'コマキシ', '上末', 'カミズエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県小牧市郷西町', '23', '23219', '4850823', '愛知県', 'アイチケン', '小牧市', 'コマキシ', '郷西町', 'ゴウニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県小牧市長治町', '23', '23219', '4850824', '愛知県', 'アイチケン', '小牧市', 'コマキシ', '長治町', 'ナガハルチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県小牧市下末', '23', '23219', '4850825', '愛知県', 'アイチケン', '小牧市', 'コマキシ', '下末', 'シモズエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県小牧市東田中', '23', '23219', '4850826', '愛知県', 'アイチケン', '小牧市', 'コマキシ', '東田中', 'ヒガシタナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県小牧市文津', '23', '23219', '4850827', '愛知県', 'アイチケン', '小牧市', 'コマキシ', '文津', 'フミツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県小牧市小松寺', '23', '23219', '4850828', '愛知県', 'アイチケン', '小牧市', 'コマキシ', '小松寺', 'コマツジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県小牧市小牧原', '23', '23219', '4850829', '愛知県', 'アイチケン', '小牧市', 'コマキシ', '小牧原', 'コマキハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県小牧市東', '23', '23219', '4850831', '愛知県', 'アイチケン', '小牧市', 'コマキシ', '東', 'ヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県小牧市応時', '23', '23219', '4850832', '愛知県', 'アイチケン', '小牧市', 'コマキシ', '応時', 'オウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市', '23', '23206', '4860000', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('48572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市上田楽町', '23', '23206', '4860801', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '上田楽町', 'カミタラガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市桃山町', '23', '23206', '4860802', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '桃山町', 'モモヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市西山町', '23', '23206', '4860803', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '西山町', 'ニシヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市鷹来町', '23', '23206', '4860804', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '鷹来町', 'タカキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市岩野町', '23', '23206', '4860805', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '岩野町', 'イワノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市大手田酉町', '23', '23206', '4860806', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '大手田酉町', 'オオデタトリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市大手町', '23', '23206', '4860807', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '大手町', 'オオデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市田楽町', '23', '23206', '4860808', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '田楽町', 'タラガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市町屋町', '23', '23206', '4860809', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '町屋町', 'マチヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市東山町', '23', '23206', '4860811', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '東山町', 'ヒガシヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市大泉寺町', '23', '23206', '4860812', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '大泉寺町', 'ダイセンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市金ケ口町', '23', '23206', '4860813', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '金ケ口町', 'カナガグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市北城町', '23', '23206', '4860814', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '北城町', 'キタシロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市十三塚町', '23', '23206', '4860815', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '十三塚町', 'ジュウサンヅカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市東野新町', '23', '23206', '4860816', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '東野新町', 'ヒガシノシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市東野町', '23', '23206', '4860817', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '東野町', 'ヒガシノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市東野町西', '23', '23206', '4860818', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '東野町西', 'ヒガシノチョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市下原町', '23', '23206', '4860819', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '下原町', 'シモハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市熊野町北', '23', '23206', '4860820', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '熊野町北', 'クマノチョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市神領町', '23', '23206', '4860821', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '神領町', 'ジンリョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市熊野町', '23', '23206', '4860822', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '熊野町', 'クマノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市桜佐町', '23', '23206', '4860823', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '桜佐町', 'サクラサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市割塚町', '23', '23206', '4860824', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '割塚町', 'ワリヅカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市中央通', '23', '23206', '4860825', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '中央通', 'チュウオウドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市貴船町', '23', '23206', '4860826', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '貴船町', 'キブネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市小木田町', '23', '23206', '4860827', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '小木田町', 'オギタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市堀ノ内町北', '23', '23206', '4860828', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '堀ノ内町北', 'ホリノウチチョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市堀ノ内町', '23', '23206', '4860829', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '堀ノ内町', 'ホリノウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市ことぶき町', '23', '23206', '4860831', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', 'ことぶき町', 'コトブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市乙輪町', '23', '23206', '4860832', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '乙輪町', 'オトワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市上条町', '23', '23206', '4860833', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '上条町', 'ジョウジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市王子町', '23', '23206', '4860834', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '王子町', 'オウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市月見町', '23', '23206', '4860835', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '月見町', 'ツキミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市八事町', '23', '23206', '4860836', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '八事町', 'ヤゴトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市春見町', '23', '23206', '4860837', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '春見町', 'ハルミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市弥生町', '23', '23206', '4860838', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '弥生町', 'ヤヨイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市六軒屋町西', '23', '23206', '4860839', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '六軒屋町西', 'ロッケンヤチョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市南下原町', '23', '23206', '4860841', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '南下原町', 'ミナミシモハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市六軒屋町', '23', '23206', '4860842', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '六軒屋町', 'ロッケンヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市鳥居松町', '23', '23206', '4860844', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '鳥居松町', 'トリイマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市瑞穂通', '23', '23206', '4860845', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '瑞穂通', 'ミズホドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市朝宮町', '23', '23206', '4860846', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '朝宮町', 'アサミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市八田町', '23', '23206', '4860849', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '八田町', 'ハッタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市篠木町', '23', '23206', '4860851', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '篠木町', 'シノギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市下市場町', '23', '23206', '4860852', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '下市場町', 'シモイチバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市穴橋町', '23', '23206', '4860853', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '穴橋町', 'アナハシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市林島町', '23', '23206', '4860854', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '林島町', 'ハヤシジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市関田町', '23', '23206', '4860855', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '関田町', 'セキダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市梅ケ坪町', '23', '23206', '4860856', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '梅ケ坪町', 'ウメガツボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市浅山町', '23', '23206', '4860857', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '浅山町', 'アサヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市菅大臣町', '23', '23206', '4860858', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '菅大臣町', 'カンダイジンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市牛山町', '23', '23206', '4860901', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '牛山町', 'ウシヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市新開町', '23', '23206', '4860902', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '新開町', 'シンカイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市前並町', '23', '23206', '4860903', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '前並町', 'マエナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市宮町', '23', '23206', '4860904', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '宮町', 'ミヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市稲口町', '23', '23206', '4860905', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '稲口町', 'イナグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市下屋敷町', '23', '23206', '4860906', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '下屋敷町', 'シモヤシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市黒鉾町', '23', '23206', '4860907', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '黒鉾町', 'クロボコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市西屋町', '23', '23206', '4860908', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '西屋町', 'ニシヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市四ツ家町', '23', '23206', '4860909', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '四ツ家町', 'ヨツヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市西高山町', '23', '23206', '4860911', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '西高山町', 'ニシタカヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市高山町', '23', '23206', '4860912', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '高山町', 'タカヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市柏原町', '23', '23206', '4860913', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '柏原町', 'カシハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市若草通', '23', '23206', '4860914', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '若草通', 'ワカクサドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市八幡町', '23', '23206', '4860915', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '八幡町', 'ハチマンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市八光町', '23', '23206', '4860916', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '八光町', 'ハッコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市美濃町', '23', '23206', '4860917', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '美濃町', 'ミノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市如意申町', '23', '23206', '4860918', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '如意申町', 'ニョイサルチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市杁ケ島町', '23', '23206', '4860921', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '杁ケ島町', 'イリガシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市篠田町', '23', '23206', '4860922', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '篠田町', 'シノダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市下条町', '23', '23206', '4860923', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '下条町', 'ゲジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市下津町', '23', '23206', '4860924', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '下津町', 'シモツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市中切町', '23', '23206', '4860925', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '中切町', 'ナカギリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市小野町', '23', '23206', '4860926', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '小野町', 'オノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市柏井町', '23', '23206', '4860927', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '柏井町', 'カシワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市妙慶町', '23', '23206', '4860928', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '妙慶町', 'ミョウケイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市旭町', '23', '23206', '4860929', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '旭町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市松新町', '23', '23206', '4860931', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '松新町', 'マツシンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市松河戸町', '23', '23206', '4860932', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '松河戸町', 'マツカワドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市愛知町', '23', '23206', '4860933', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '愛知町', 'アイチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市長塚町', '23', '23206', '4860934', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '長塚町', 'ナガツカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市森山田町', '23', '23206', '4860935', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '森山田町', 'モリヤマダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市町田町', '23', '23206', '4860936', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '町田町', 'チョウダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市細木町', '23', '23206', '4860937', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '細木町', 'ホソキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市勝川新町', '23', '23206', '4860941', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '勝川新町', 'カチガワシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市神明町', '23', '23206', '4860942', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '神明町', 'シンメイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市角崎町', '23', '23206', '4860943', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '角崎町', 'ツノサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市大和通', '23', '23206', '4860944', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '大和通', 'ヤマトドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市勝川町', '23', '23206', '4860945', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '勝川町', 'カチガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市勝川町西', '23', '23206', '4860946', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '勝川町西', 'カチガワチョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市知多町', '23', '23206', '4860947', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '知多町', 'チタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市天神町', '23', '23206', '4860948', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '天神町', 'テンジンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市惣中町', '23', '23206', '4860949', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '惣中町', 'ソウナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市花長町', '23', '23206', '4860951', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '花長町', 'ハナオサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市追進町', '23', '23206', '4860952', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '追進町', 'ツイシンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市御幸町', '23', '23206', '4860953', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '御幸町', 'ミユキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市南花長町', '23', '23206', '4860954', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '南花長町', 'ミナミハナオサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市二子町', '23', '23206', '4860955', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '二子町', 'フタゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市中新町', '23', '23206', '4860956', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '中新町', 'ナカシンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市中野町', '23', '23206', '4860957', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '中野町', 'ナカノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市西本町', '23', '23206', '4860958', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '西本町', 'ニシホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市春日井上ノ町', '23', '23206', '4860961', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '春日井上ノ町', 'カスガイカミノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市中町', '23', '23206', '4860962', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '中町', 'ナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市春日井町', '23', '23206', '4860963', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '春日井町', 'カスガイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市宗法町', '23', '23206', '4860964', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '宗法町', 'ソウホウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市味美上ノ町', '23', '23206', '4860965', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '味美上ノ町', 'アジヨシカミノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市上ノ町', '23', '23206', '4860966', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '上ノ町', 'カミノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市味美西本町', '23', '23206', '4860967', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '味美西本町', 'アジヨシニシホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市味美町', '23', '23206', '4860968', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '味美町', 'アジヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市味美白山町', '23', '23206', '4860969', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '味美白山町', 'アジヨシハクサンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市細野町', '23', '23206', '4870001', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '細野町', 'ホソノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市外之原町', '23', '23206', '4870002', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '外之原町', 'トノハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市木附町', '23', '23206', '4870003', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '木附町', 'キヅキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市玉野町', '23', '23206', '4870004', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '玉野町', 'タマノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市押沢台', '23', '23206', '4870005', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '押沢台', 'オシザワダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市石尾台', '23', '23206', '4870006', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '石尾台', 'イシオダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市玉野台', '23', '23206', '4870007', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '玉野台', 'タマノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市中央台', '23', '23206', '4870011', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '中央台', 'チュウオウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市高座町', '23', '23206', '4870012', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '高座町', 'タカクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市高蔵寺町', '23', '23206', '4870013', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '高蔵寺町', 'コウゾウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市気噴町', '23', '23206', '4870014', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '気噴町', 'キブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市気噴町北', '23', '23206', '4870015', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '気噴町北', 'キブキチョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市高蔵寺町北', '23', '23206', '4870016', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '高蔵寺町北', 'コウゾウジチョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市高座台', '23', '23206', '4870017', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '高座台', 'タカクラダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市東神明町', '23', '23206', '4870021', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '東神明町', 'ヒガシシンミョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市庄名町', '23', '23206', '4870022', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '庄名町', 'ショウナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市不二ガ丘', '23', '23206', '4870023', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '不二ガ丘', 'フジガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市大留町', '23', '23206', '4870024', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '大留町', 'オオドメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市出川町', '23', '23206', '4870025', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '出川町', 'テガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市不二町', '23', '23206', '4870026', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '不二町', 'フジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市松本町', '23', '23206', '4870027', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '松本町', 'マツモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市廻間町', '23', '23206', '4870031', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '廻間町', 'ハザマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市高森台', '23', '23206', '4870032', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '高森台', 'タカモリダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市岩成台', '23', '23206', '4870033', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '岩成台', 'イワナリダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市白山町', '23', '23206', '4870034', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '白山町', 'シラヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県春日井市藤山台', '23', '23206', '4870035', '愛知県', 'アイチケン', '春日井市', 'カスガイシ', '藤山台', 'フジヤマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市', '23', '23226', '4880000', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('48738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市旭台', '23', '23226', '4880001', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '旭台', 'アサヒダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市根の鼻町', '23', '23226', '4880002', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '根の鼻町', 'ネノハナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市東大久手町', '23', '23226', '4880003', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '東大久手町', 'ヒガシオオクテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市大久手町一の曾', '23', '23226', '4880004', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '大久手町一の曾', 'オオクテチョウイチノソウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市大久手町上切戸', '23', '23226', '4880005', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '大久手町上切戸', 'オオクテチョウカミキリド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市大久手町中松原', '23', '23226', '4880006', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '大久手町中松原', 'オオクテチョウナカマツバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市柏井町公園通', '23', '23226', '4880007', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '柏井町公園通', 'カシワイチョウコウエンドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市柏井町弥栄', '23', '23226', '4880008', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '柏井町弥栄', 'カシワイチョウイヤサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市東栄町', '23', '23226', '4880011', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '東栄町', 'トウエイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市三郷町角田', '23', '23226', '4880012', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '三郷町角田', 'サンゴウチョウツノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市三郷町富丘', '23', '23226', '4880013', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '三郷町富丘', 'サンゴウチョウトミオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市三郷町中井田', '23', '23226', '4880014', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '三郷町中井田', 'サンゴウチョウナカイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市三郷町栄', '23', '23226', '4880015', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '三郷町栄', 'サンゴウチョウサカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市三郷町陶栄', '23', '23226', '4880016', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '三郷町陶栄', 'サンゴウチョウトウエイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市東三郷町', '23', '23226', '4880017', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '東三郷町', 'ヒガシサンゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市狩宿町', '23', '23226', '4880021', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '狩宿町', 'カリジュクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市狩宿新町', '23', '23226', '4880022', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '狩宿新町', 'カリジュクシンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市瀬戸川町', '23', '23226', '4880023', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '瀬戸川町', 'セトガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市井田町', '23', '23226', '4880024', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '井田町', 'イダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市晴丘町東', '23', '23226', '4880031', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '晴丘町東', 'ハルオカチョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市晴丘町池上', '23', '23226', '4880032', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '晴丘町池上', 'ハルオカチョウイケガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市東本地ケ原町', '23', '23226', '4880033', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '東本地ケ原町', 'ヒガシホンジガハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市上の山町山畑', '23', '23226', '4880034', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '上の山町山畑', 'ウエノヤマチョウヤマハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市上の山町間口', '23', '23226', '4880035', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '上の山町間口', 'ウエノヤマチョウマグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市南新町中畑', '23', '23226', '4880041', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '南新町中畑', 'ミナミシンチョウナカハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市南新町白山', '23', '23226', '4880042', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '南新町白山', 'ミナミシンチョウハクサン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市北本地ケ原町', '23', '23226', '4880043', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '北本地ケ原町', 'キタホンジガハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市南本地ケ原町', '23', '23226', '4880044', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '南本地ケ原町', 'ミナミホンジガハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市南栄町', '23', '23226', '4880045', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '南栄町', 'ミナミサカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市南栄町旭ケ丘', '23', '23226', '4880046', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '南栄町旭ケ丘', 'ミナミサカエチョウアサヒガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市南栄町黒石', '23', '23226', '4880047', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '南栄町黒石', 'ミナミサカエチョウクロイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市下井町前の上', '23', '23226', '4880051', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '下井町前の上', 'シモイチョウマエノカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市下井町下井', '23', '23226', '4880052', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '下井町下井', 'シモイチョウシモイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市下井町刎内', '23', '23226', '4880053', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '下井町刎内', 'シモイチョウハネウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市稲葉町', '23', '23226', '4880054', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '稲葉町', 'イナバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市北山町六反田', '23', '23226', '4880055', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '北山町六反田', 'キタヤマチョウロクタンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市北山町北山', '23', '23226', '4880056', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '北山町北山', 'キタヤマチョウキタヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市北山町北新田', '23', '23226', '4880057', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '北山町北新田', 'キタヤマチョウキタシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市北原山町六田池', '23', '23226', '4880061', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '北原山町六田池', 'キタハラヤマチョウムタイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市北原山町平池浦', '23', '23226', '4880062', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '北原山町平池浦', 'キタハラヤマチョウヒライケウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市北原山町陀摩屋敷', '23', '23226', '4880063', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '北原山町陀摩屋敷', 'キタハラヤマチョウダマヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市北原山町鳴湫', '23', '23226', '4880064', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '北原山町鳴湫', 'キタハラヤマチョウナルクテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市北原山町大久保見', '23', '23226', '4880065', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '北原山町大久保見', 'キタハラヤマチョウオオクボミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市南原山町赤土', '23', '23226', '4880066', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '南原山町赤土', 'ミナミハラヤマチョウアカツチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市南原山町石原', '23', '23226', '4880067', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '南原山町石原', 'ミナミハラヤマチョウイシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市南原山町南原山', '23', '23226', '4880068', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '南原山町南原山', 'ミナミハラヤマチョウミナミハラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市新居町五反田', '23', '23226', '4880070', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '新居町五反田', 'アライチョウゴタンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市新居町下切戸', '23', '23226', '4880071', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '新居町下切戸', 'アライチョウシモキリド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市新居町諏訪南', '23', '23226', '4880072', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '新居町諏訪南', 'アライチョウスワミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市新居町上の田', '23', '23226', '4880073', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '新居町上の田', 'アライチョウカミノタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市新居町明才切', '23', '23226', '4880074', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '新居町明才切', 'アライチョウメイサイギリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市新居町木の本', '23', '23226', '4880075', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '新居町木の本', 'アライチョウキノモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市新居町山の田', '23', '23226', '4880076', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '新居町山の田', 'アライチョウヤマノタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市新居町西浦', '23', '23226', '4880077', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '新居町西浦', 'アライチョウニシウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市新居町寺田', '23', '23226', '4880078', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '新居町寺田', 'アライチョウテラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市新居町今池下', '23', '23226', '4880079', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '新居町今池下', 'アライチョウイマイケシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市新居', '23', '23226', '4880081', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '新居', 'アライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市旭ケ丘町森', '23', '23226', '4880082', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '旭ケ丘町森', 'アサヒガオカチョウモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市旭ケ丘町旭ケ丘', '23', '23226', '4880083', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '旭ケ丘町旭ケ丘', 'アサヒガオカチョウアサヒガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市旭ケ丘町山の手', '23', '23226', '4880084', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '旭ケ丘町山の手', 'アサヒガオカチョウヤマノテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市旭ケ丘町濁池', '23', '23226', '4880085', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '旭ケ丘町濁池', 'アサヒガオカチョウニゴリイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市旭ケ丘町長洞', '23', '23226', '4880086', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '旭ケ丘町長洞', 'アサヒガオカチョウナガボラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市東大道町原田', '23', '23226', '4880801', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '東大道町原田', 'ヒガシダイドウチョウハラタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市東大道町曽我廻間', '23', '23226', '4880802', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '東大道町曽我廻間', 'ヒガシダイドウチョウソガサマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市東大道町山の内', '23', '23226', '4880803', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '東大道町山の内', 'ヒガシダイドウチョウヤマノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市西の野町', '23', '23226', '4880804', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '西の野町', 'ニシノノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市西の野町豆塚', '23', '23226', '4880805', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '西の野町豆塚', 'ニシノノチョウマメヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市西大道町五輪塚', '23', '23226', '4880813', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '西大道町五輪塚', 'ニシダイドウチョウゴリンヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市西大道町前田', '23', '23226', '4880814', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '西大道町前田', 'ニシダイドウチョウマエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市西大道町六兵衛前', '23', '23226', '4880815', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '西大道町六兵衛前', 'ニシダイドウチョウロクベエマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市西大道町下大道', '23', '23226', '4880816', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '西大道町下大道', 'ニシダイドウチョウシモダイドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市西大道町八瀬の木前', '23', '23226', '4880817', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '西大道町八瀬の木前', 'ニシダイドウチョウヤセノキマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市向町', '23', '23226', '4880818', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '向町', 'ムカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市長坂町南山', '23', '23226', '4880821', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '長坂町南山', 'ナガサカチョウミナミヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市緑町緑ケ丘', '23', '23226', '4880822', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '緑町緑ケ丘', 'ミドリチョウミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市庄南町', '23', '23226', '4880823', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '庄南町', 'ショウナンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市西山町', '23', '23226', '4880824', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '西山町', 'ニシヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市東山町', '23', '23226', '4880825', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '東山町', 'ヒガシヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市大塚町', '23', '23226', '4880826', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '大塚町', 'オオツカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市吉岡町', '23', '23226', '4880827', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '吉岡町', 'ヨシオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市東印場町', '23', '23226', '4880830', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '東印場町', 'ヒガシインバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市東印場町一里山', '23', '23226', '4880832', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '東印場町一里山', 'ヒガシインバチョウイチリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市東印場町二反田', '23', '23226', '4880833', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '東印場町二反田', 'ヒガシインバチョウニタンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市庄中町南島', '23', '23226', '4880835', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '庄中町南島', 'ショウナカチョウミナミジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市庄中町渋川', '23', '23226', '4880836', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '庄中町渋川', 'ショウナカチョウシブカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市庄中町', '23', '23226', '4880838', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '庄中町', 'ショウナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市渋川町', '23', '23226', '4880839', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '渋川町', 'シブカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市印場元町', '23', '23226', '4880840', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '印場元町', 'インバモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市印場元町北山', '23', '23226', '4880841', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '印場元町北山', 'インバモトチョウキタヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市印場元町北島', '23', '23226', '4880842', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '印場元町北島', 'インバモトチョウキタジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市印場元町細田', '23', '23226', '4880843', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '印場元町細田', 'インバモトチョウホソダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市東名西町', '23', '23226', '4880844', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '東名西町', 'トウメイニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市霞ケ丘町南', '23', '23226', '4880845', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '霞ケ丘町南', 'カスミガオカチョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市霞ケ丘町中', '23', '23226', '4880846', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '霞ケ丘町中', 'カスミガオカチョウナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市霞ケ丘町北', '23', '23226', '4880847', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '霞ケ丘町北', 'カスミガオカチョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市旭前町北', '23', '23226', '4880851', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '旭前町北', 'アサヒマエチョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市旭前町新田洞', '23', '23226', '4880852', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '旭前町新田洞', 'アサヒマエチョウシンデンボラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市旭前町広久手', '23', '23226', '4880853', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '旭前町広久手', 'アサヒマエチョウヒロクテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市旭前町西新田', '23', '23226', '4880854', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '旭前町西新田', 'アサヒマエチョウニシシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市桜ケ丘町西', '23', '23226', '4880857', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '桜ケ丘町西', 'サクラガオカチョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市白鳳町', '23', '23226', '4880858', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '白鳳町', 'ハクホウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市桜ケ丘町', '23', '23226', '4880859', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '桜ケ丘町', 'サクラガオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市城前町城前', '23', '23226', '4880861', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '城前町城前', 'シロマエチョウシロマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市城前町上大道', '23', '23226', '4880863', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '城前町上大道', 'シロマエチョウカミダイドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市城前町八瀬の木西', '23', '23226', '4880864', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '城前町八瀬の木西', 'シロマエチョウヤセノキニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市城前町砂川', '23', '23226', '4880865', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '城前町砂川', 'シロマエチョウスガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市城前町茅池', '23', '23226', '4880866', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '城前町茅池', 'シロマエチョウチガイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市平子町東', '23', '23226', '4880871', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '平子町東', 'ヒラコチョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市平子町長池上', '23', '23226', '4880872', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '平子町長池上', 'ヒラコチョウナガイケカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市平子町中通', '23', '23226', '4880873', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '平子町中通', 'ヒラコチョウナカドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市平子町西', '23', '23226', '4880874', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '平子町西', 'ヒラコチョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市平子町北', '23', '23226', '4880875', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '平子町北', 'ヒラコチョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市平子ケ丘町', '23', '23226', '4880876', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '平子ケ丘町', 'ヒラコガオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市城山町三ツ池', '23', '23226', '4880881', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '城山町三ツ池', 'シロヤマチョウミツイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市城山町向ケ丘', '23', '23226', '4880882', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '城山町向ケ丘', 'シロヤマチョウムコウガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市城山町長池下', '23', '23226', '4880883', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '城山町長池下', 'シロヤマチョウナガイケシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県尾張旭市城山町城山', '23', '23226', '4880884', '愛知県', 'アイチケン', '尾張旭市', 'オワリアサヒシ', '城山町城山', 'シロヤマチョウシロヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市', '23', '23204', '4890000', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('48868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市川平町', '23', '23204', '4890001', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '川平町', 'カワヒラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市余床町', '23', '23204', '4890002', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '余床町', 'ヨドコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市穴田町', '23', '23204', '4890003', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '穴田町', 'アナダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市日の出町', '23', '23204', '4890004', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '日の出町', 'ヒノデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市中水野町', '23', '23204', '4890005', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '中水野町', 'ナカミズノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市三沢町', '23', '23204', '4890006', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '三沢町', 'ミサワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市鹿乗町', '23', '23204', '4890007', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '鹿乗町', 'カノリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市曽野町', '23', '23204', '4890008', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '曽野町', 'ソノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市水北町', '23', '23204', '4890009', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '水北町', 'スイホクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市針原町', '23', '23204', '4890011', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '針原町', 'ハリハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市長谷口町', '23', '23204', '4890012', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '長谷口町', 'ハセグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市中白坂町', '23', '23204', '4890013', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '中白坂町', 'ナカシラサカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市北白坂町', '23', '23204', '4890014', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '北白坂町', 'キタシラサカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市東白坂町', '23', '23204', '4890015', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '東白坂町', 'ヒガシシラサカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市南白坂町', '23', '23204', '4890016', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '南白坂町', 'ミナミシラサカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市白坂町', '23', '23204', '4890017', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '白坂町', 'シラサカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市西白坂町', '23', '23204', '4890018', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '西白坂町', 'ニシシラサカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市馬ケ城町', '23', '23204', '4890021', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '馬ケ城町', 'ウマガジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市赤津町', '23', '23204', '4890022', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '赤津町', 'アカヅチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市窯元町', '23', '23204', '4890023', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '窯元町', 'カマモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市八王子町', '23', '23204', '4890024', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '八王子町', 'ハチオウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市凧山町', '23', '23204', '4890025', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '凧山町', 'タコヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市東明町', '23', '23204', '4890026', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '東明町', 'トウメイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市東拝戸町', '23', '23204', '4890027', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '東拝戸町', 'ヒガシハイドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市西窯町', '23', '23204', '4890028', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '西窯町', 'ニシガマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市中畑町', '23', '23204', '4890029', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '中畑町', 'ナカバタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市五位塚町', '23', '23204', '4890031', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '五位塚町', 'ゴイヅカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市古瀬戸町', '23', '23204', '4890032', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '古瀬戸町', 'コセトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市須原町', '23', '23204', '4890033', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '須原町', 'スハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市刎田町', '23', '23204', '4890034', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '刎田町', 'ハネダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市紺屋田町', '23', '23204', '4890035', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '紺屋田町', 'コンヤダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市西古瀬戸町', '23', '23204', '4890036', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '西古瀬戸町', 'ニシコセトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市東古瀬戸町', '23', '23204', '4890037', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '東古瀬戸町', 'ヒガシコセトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市背戸側町', '23', '23204', '4890041', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '背戸側町', 'セトガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市仲切町', '23', '23204', '4890042', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '仲切町', 'ナカギリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市朝日町', '23', '23204', '4890043', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '朝日町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市栄町', '23', '23204', '4890044', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市陶本町', '23', '23204', '4890045', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '陶本町', 'トウホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市元町', '23', '23204', '4890046', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '元町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市西谷町', '23', '23204', '4890047', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '西谷町', 'ニシダニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市窯神町', '23', '23204', '4890048', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '窯神町', 'カマガミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市下陣屋町', '23', '23204', '4890051', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '下陣屋町', 'シモジンヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市安戸町', '23', '23204', '4890052', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '安戸町', 'ヤスドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市東安戸町', '23', '23204', '4890053', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '東安戸町', 'ヒガシヤスドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市道泉町', '23', '23204', '4890054', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '道泉町', 'ドウセンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市滝之湯町', '23', '23204', '4890055', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '滝之湯町', 'タキノユチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市東十三塚町', '23', '23204', '4890056', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '東十三塚町', 'ヒガシトミヅカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市西十三塚町', '23', '23204', '4890057', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '西十三塚町', 'ニシトミヅカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市進陶町', '23', '23204', '4890058', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '進陶町', 'シントウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市上本町', '23', '23204', '4890061', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '上本町', 'カミホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市上水野町', '23', '23204', '4890062', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '上水野町', 'カミミズノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市上陣屋町', '23', '23204', '4890063', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '上陣屋町', 'カミジンヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市小金町', '23', '23204', '4890064', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '小金町', 'オガネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市西追分町', '23', '23204', '4890065', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '西追分町', 'ニシオイワケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市東横山町', '23', '23204', '4890066', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '東横山町', 'ヒガシヨコヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市小田妻町', '23', '23204', '4890067', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '小田妻町', 'オダヅマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市上松山町', '23', '23204', '4890068', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '上松山町', 'カミマツヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市東松山町', '23', '23204', '4890069', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '東松山町', 'ヒガシマツヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市暁町', '23', '23204', '4890071', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '暁町', 'アカツキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市東印所町', '23', '23204', '4890072', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '東印所町', 'ヒガシインゾチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市泉町', '23', '23204', '4890073', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '泉町', 'イズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市宮脇町', '23', '23204', '4890074', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '宮脇町', 'ミヤワキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市新道町', '23', '23204', '4890075', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '新道町', 'シンドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市深川町', '23', '23204', '4890076', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '深川町', 'フカガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市宮里町', '23', '23204', '4890077', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '宮里町', 'ミヤザトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市湯之根町', '23', '23204', '4890078', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '湯之根町', 'ユノネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市西印所町', '23', '23204', '4890079', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '西印所町', 'ニシインゾチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市汗干町', '23', '23204', '4890801', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '汗干町', 'アセビチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市今池町', '23', '23204', '4890802', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '今池町', 'イマイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市追分町', '23', '23204', '4890803', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '追分町', 'オイワケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市京町', '23', '23204', '4890804', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '京町', 'キョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市陶原町', '23', '23204', '4890805', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '陶原町', 'トウゲンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市東吉田町', '23', '23204', '4890806', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '東吉田町', 'ヒガシヨシダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市西吉田町', '23', '23204', '4890807', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '西吉田町', 'ニシヨシダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市見付町', '23', '23204', '4890808', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '見付町', 'ミツケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市共栄通', '23', '23204', '4890809', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '共栄通', 'キョウエイドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市山脇町', '23', '23204', '4890811', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '山脇町', 'ヤマワキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市西蔵所町', '23', '23204', '4890812', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '西蔵所町', 'ニシクラショチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市蔵所町', '23', '23204', '4890813', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '蔵所町', 'クラショチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市末広町', '23', '23204', '4890814', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '末広町', 'スエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市南仲之切町', '23', '23204', '4890815', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '南仲之切町', 'ミナミナカノキリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市東本町', '23', '23204', '4890816', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '東本町', 'ヒガシホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市銀杏木町', '23', '23204', '4890817', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '銀杏木町', 'イチョノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市幸町', '23', '23204', '4890818', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市西本町', '23', '23204', '4890819', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '西本町', 'ニシホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市薬師町', '23', '23204', '4890821', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '薬師町', 'ヤクシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市杉塚町', '23', '23204', '4890822', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '杉塚町', 'スギツカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市東郷町', '23', '23204', '4890823', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '東郷町', 'トウゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市仲郷町', '23', '23204', '4890824', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '仲郷町', 'ナカゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市祖母懐町', '23', '23204', '4890825', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '祖母懐町', 'ソボカイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市蛭子町', '23', '23204', '4890826', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '蛭子町', 'エビスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市陶生町', '23', '23204', '4890827', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '陶生町', 'トウセイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市前田町', '23', '23204', '4890828', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '前田町', 'マエダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市西郷町', '23', '23204', '4890829', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '西郷町', 'ニシゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市藤四郎町', '23', '23204', '4890831', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '藤四郎町', 'トウシロウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市王子沢町', '23', '23204', '4890832', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '王子沢町', 'オウジノサワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市仲洞町', '23', '23204', '4890833', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '仲洞町', 'ナカボラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市南東町', '23', '23204', '4890834', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '南東町', 'ミナミアズマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市中山町', '23', '23204', '4890835', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '中山町', 'ナカヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市一里塚町', '23', '23204', '4890836', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '一里塚町', 'イチリヅカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市西洞町', '23', '23204', '4890837', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '西洞町', 'ニシボラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市寺本町', '23', '23204', '4890838', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '寺本町', 'テラモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市東洞町', '23', '23204', '4890841', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '東洞町', 'ヒガシボラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市小空町', '23', '23204', '4890842', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '小空町', 'コソラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市惣作町', '23', '23204', '4890843', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '惣作町', 'ソウサクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市門前町', '23', '23204', '4890844', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '門前町', 'モンゼンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市鐘場町', '23', '23204', '4890845', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '鐘場町', 'カネバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市太子町', '23', '23204', '4890846', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '太子町', 'タイシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市東町', '23', '23204', '4890847', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '東町', 'アズマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市西拝戸町', '23', '23204', '4890848', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '西拝戸町', 'ニシハイトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市新明町', '23', '23204', '4890849', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '新明町', 'シンメイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市西山路町', '23', '23204', '4890851', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '西山路町', 'ニシヤマジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市巡間町', '23', '23204', '4890852', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '巡間町', 'ハザマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市上山路町', '23', '23204', '4890853', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '上山路町', 'カミヤマジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市東山路町', '23', '23204', '4890854', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '東山路町', 'ヒガシヤマジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市海上町', '23', '23204', '4890855', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '海上町', 'カイショチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市広久手町', '23', '23204', '4890856', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '広久手町', 'ヒロクテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市吉野町', '23', '23204', '4890857', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '吉野町', 'ヨシノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市屋戸町', '23', '23204', '4890858', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '屋戸町', 'ヤトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市山路町', '23', '23204', '4890859', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '山路町', 'ヤマジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市八幡台', '23', '23204', '4890861', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '八幡台', 'ハチマンダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市八幡町', '23', '23204', '4890862', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '八幡町', 'ハチマンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市せいれい町', '23', '23204', '4890863', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', 'せいれい町', 'セイレイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市若宮町', '23', '23204', '4890864', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '若宮町', 'ワカミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市山口町', '23', '23204', '4890865', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '山口町', 'ヤマグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市矢形町', '23', '23204', '4890866', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '矢形町', 'ヤカタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市大坂町', '23', '23204', '4890867', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '大坂町', 'オオサカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市今林町', '23', '23204', '4890868', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '今林町', 'イマバヤシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市東長根町', '23', '23204', '4890871', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '東長根町', 'ヒガシナガネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市水無瀬町', '23', '23204', '4890872', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '水無瀬町', 'ミナセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市新郷町', '23', '23204', '4890873', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '新郷町', 'シンゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('48999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市幡野町', '23', '23204', '4890874', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '幡野町', 'ハタノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市緑町', '23', '23204', '4890875', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '緑町', 'ミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市白山町', '23', '23204', '4890876', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '白山町', 'ハクサンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市東赤重町', '23', '23204', '4890877', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '東赤重町', 'ヒガシアカシゲチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市赤重町', '23', '23204', '4890878', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '赤重町', 'アカシゲチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市瘤木町', '23', '23204', '4890879', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '瘤木町', 'コブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市熊野町', '23', '23204', '4890881', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '熊野町', 'クマノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市西権現町', '23', '23204', '4890882', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '西権現町', 'ニシゴンゲンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市東権現町', '23', '23204', '4890883', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '東権現町', 'ヒガシゴンゲンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市西茨町', '23', '23204', '4890884', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '西茨町', 'ニシイバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市萩殿町', '23', '23204', '4890885', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '萩殿町', 'ハギドノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市萩山台', '23', '23204', '4890886', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '萩山台', 'ハギヤマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市菱野台', '23', '23204', '4890887', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '菱野台', 'ヒシノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市原山台', '23', '23204', '4890888', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '原山台', 'ハラヤマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市原山町', '23', '23204', '4890889', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '原山町', 'ハラヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市陶栄町', '23', '23204', '4890891', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '陶栄町', 'トウエイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市上ノ切町', '23', '23204', '4890892', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '上ノ切町', 'カミノキリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市春雨町', '23', '23204', '4890893', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '春雨町', 'ハルサメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市川合町', '23', '23204', '4890894', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '川合町', 'カワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市塩草町', '23', '23204', '4890895', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '塩草町', 'シオクサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市宝ケ丘町', '23', '23204', '4890896', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '宝ケ丘町', 'タカラガオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市東茨町', '23', '23204', '4890897', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '東茨町', 'ヒガシイバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市秋葉町', '23', '23204', '4890898', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '秋葉町', 'アキバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市十軒町', '23', '23204', '4890901', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '十軒町', 'ジッケンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市内田町', '23', '23204', '4890902', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '内田町', 'ウチダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市ゆりの台', '23', '23204', '4890903', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', 'ゆりの台', 'ユリノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市すみれ台', '23', '23204', '4890904', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', 'すみれ台', 'スミレダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市はぎの台', '23', '23204', '4890905', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', 'はぎの台', 'ハギノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市本郷町', '23', '23204', '4890906', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '本郷町', 'ホンゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市ふじの台', '23', '23204', '4890907', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', 'ふじの台', 'フジノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市ききょう台', '23', '23204', '4890908', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', 'ききょう台', 'キキョウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市みずの坂', '23', '23204', '4890909', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', 'みずの坂', 'ミズノザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市北みずの坂', '23', '23204', '4890910', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '北みずの坂', 'キタミズノザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市北松山町', '23', '23204', '4890911', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '北松山町', 'キタマツヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市西松山町', '23', '23204', '4890912', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '西松山町', 'ニシマツヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市水南町', '23', '23204', '4890913', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '水南町', 'スイナンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市孫田町', '23', '23204', '4890914', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '孫田町', 'マゴタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市北浦町', '23', '23204', '4890915', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '北浦町', 'キタウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市平町', '23', '23204', '4890916', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '平町', 'ヒラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市效範町', '23', '23204', '4890917', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '效範町', 'コウハンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市北脇町', '23', '23204', '4890918', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '北脇町', 'キタワキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市川端町', '23', '23204', '4890919', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '川端町', 'カワバタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市田端町', '23', '23204', '4890921', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '田端町', 'タバタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市市場町', '23', '23204', '4890922', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '市場町', 'イチバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市城屋敷町', '23', '23204', '4890923', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '城屋敷町', 'シロヤシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市城ケ根町', '23', '23204', '4890924', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '城ケ根町', 'シロガネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市西寺山町', '23', '23204', '4890925', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '西寺山町', 'ニシテラヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市川西町', '23', '23204', '4890926', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '川西町', 'カワニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市川北町', '23', '23204', '4890927', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '川北町', 'カワキタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市東寺山町', '23', '23204', '4890928', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '東寺山町', 'ヒガシテラヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市西長根町', '23', '23204', '4890929', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '西長根町', 'ニシナガネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市高根町', '23', '23204', '4890931', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '高根町', 'タカネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市美濃池町', '23', '23204', '4890932', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '美濃池町', 'ミノノイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市神川町', '23', '23204', '4890933', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '神川町', 'カミカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市菱野町', '23', '23204', '4890934', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '菱野町', 'ヒシノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市福元町', '23', '23204', '4890935', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '福元町', 'フクモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市西脇町', '23', '23204', '4890936', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '西脇町', 'ニシワキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市南菱野町', '23', '23204', '4890937', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '南菱野町', 'ミナミヒシノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市幡西町', '23', '23204', '4890938', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '幡西町', 'ハタニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市瀬戸口町', '23', '23204', '4890941', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '瀬戸口町', 'セトグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市東菱野町', '23', '23204', '4890942', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '東菱野町', 'ヒガシヒシノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市西米泉町', '23', '23204', '4890943', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '西米泉町', 'ニシコメイズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市東米泉町', '23', '23204', '4890944', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '東米泉町', 'ヒガシコメイズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市弁天町', '23', '23204', '4890945', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '弁天町', 'ベンテンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市幡中町', '23', '23204', '4890946', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '幡中町', 'ハタナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市羽根町', '23', '23204', '4890947', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '羽根町', 'ハネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市幡山町', '23', '23204', '4890948', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '幡山町', 'ハタヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市新田町', '23', '23204', '4890949', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '新田町', 'シンデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市石田町', '23', '23204', '4890951', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '石田町', 'イシダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市池田町', '23', '23204', '4890952', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '池田町', 'イケダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市柳ケ坪町', '23', '23204', '4890953', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '柳ケ坪町', 'ヤナガツボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市台六町', '23', '23204', '4890954', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '台六町', 'ダイロクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市南ケ丘町', '23', '23204', '4890955', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '南ケ丘町', 'ミナミガオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市田中町', '23', '23204', '4890961', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '田中町', 'タナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市大坪町', '23', '23204', '4890962', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '大坪町', 'オオツボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市宮地町', '23', '23204', '4890963', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '宮地町', 'ミヤジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市上之山町', '23', '23204', '4890964', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '上之山町', 'ウエノヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市南山口町', '23', '23204', '4890965', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '南山口町', 'ミナミヤマグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市掛下町', '23', '23204', '4890966', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '掛下町', 'カケシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市西本地町', '23', '23204', '4890971', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '西本地町', 'ニシホンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市西原町', '23', '23204', '4890972', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '西原町', 'ニシハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市東本地町', '23', '23204', '4890973', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '東本地町', 'ヒガシホンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市駒前町', '23', '23204', '4890974', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '駒前町', 'コママエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市山の田町', '23', '23204', '4890975', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '山の田町', 'ヤマノタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市井戸金町', '23', '23204', '4890976', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '井戸金町', 'イドガネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市坂上町', '23', '23204', '4890977', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '坂上町', 'サカウエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市小坂町', '23', '23204', '4890978', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '小坂町', 'コサカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市坊金町', '23', '23204', '4890979', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '坊金町', 'ボウガネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市やまて坂', '23', '23204', '4890980', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', 'やまて坂', 'ヤマテザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市ひまわり台', '23', '23204', '4890981', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', 'ひまわり台', 'ヒマワリダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市さつき台', '23', '23204', '4890982', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', 'さつき台', 'サツキダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市苗場町', '23', '23204', '4890983', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '苗場町', 'ナエバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市北山町', '23', '23204', '4890984', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '北山町', 'キタヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市松原町', '23', '23204', '4890985', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '松原町', 'マツバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市南山町', '23', '23204', '4890986', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '南山町', 'ミナミヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市西山町', '23', '23204', '4890987', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '西山町', 'ニシヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市東山町', '23', '23204', '4890988', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '東山町', 'ヒガシヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県瀬戸市山手町', '23', '23204', '4890989', '愛知県', 'アイチケン', '瀬戸市', 'セトシ', '山手町', 'ヤマテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北斗市', '01', '01236', '0490100', '北海道', 'ホッカイドウ', '北斗市', 'ホクトシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('49114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北斗市追分', '01', '01236', '0490101', '北海道', 'ホッカイドウ', '北斗市', 'ホクトシ', '追分', 'オイワケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県海部郡甚目寺町', '23', '23423', '4901100', '愛知県', 'アイチケン', '海部郡甚目寺町', 'アマグンジモクジチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('49116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県海部郡大治町', '23', '23424', '4901100', '愛知県', 'アイチケン', '海部郡大治町', 'アマグンオオハルチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('49117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県海部郡甚目寺町方領', '23', '23423', '4901101', '愛知県', 'アイチケン', '海部郡甚目寺町', 'アマグンジモクジチョウ', '方領', 'ホウリョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県海部郡甚目寺町石作', '23', '23423', '4901102', '愛知県', 'アイチケン', '海部郡甚目寺町', 'アマグンジモクジチョウ', '石作', 'イシツクリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県海部郡甚目寺町栄', '23', '23423', '4901103', '愛知県', 'アイチケン', '海部郡甚目寺町', 'アマグンジモクジチョウ', '栄', 'サカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県海部郡甚目寺町西今宿', '23', '23423', '4901104', '愛知県', 'アイチケン', '海部郡甚目寺町', 'アマグンジモクジチョウ', '西今宿', 'ニシイマジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県海部郡甚目寺町新居屋', '23', '23423', '4901105', '愛知県', 'アイチケン', '海部郡甚目寺町', 'アマグンジモクジチョウ', '新居屋', 'ニイヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県海部郡甚目寺町小路', '23', '23423', '4901106', '愛知県', 'アイチケン', '海部郡甚目寺町', 'アマグンジモクジチョウ', '小路', 'ショウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県海部郡甚目寺町森', '23', '23423', '4901107', '愛知県', 'アイチケン', '海部郡甚目寺町', 'アマグンジモクジチョウ', '森', 'モリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北斗市七重浜', '01', '01236', '0490111', '北海道', 'ホッカイドウ', '北斗市', 'ホクトシ', '七重浜', 'ナナエハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県海部郡甚目寺町甚目寺', '23', '23423', '4901111', '愛知県', 'アイチケン', '海部郡甚目寺町', 'アマグンジモクジチョウ', '甚目寺', 'ジモクジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県海部郡甚目寺町上萱津', '23', '23423', '4901112', '愛知県', 'アイチケン', '海部郡甚目寺町', 'アマグンジモクジチョウ', '上萱津', 'カミカヤツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県海部郡甚目寺町中萱津', '23', '23423', '4901113', '愛知県', 'アイチケン', '海部郡甚目寺町', 'アマグンジモクジチョウ', '中萱津', 'ナカカヤツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県海部郡甚目寺町下萱津', '23', '23423', '4901114', '愛知県', 'アイチケン', '海部郡甚目寺町', 'アマグンジモクジチョウ', '下萱津', 'シモカヤツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県海部郡甚目寺町坂牧', '23', '23423', '4901115', '愛知県', 'アイチケン', '海部郡甚目寺町', 'アマグンジモクジチョウ', '坂牧', 'サカマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県海部郡甚目寺町本郷', '23', '23423', '4901116', '愛知県', 'アイチケン', '海部郡甚目寺町', 'アマグンジモクジチョウ', '本郷', 'ホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県海部郡大治町長牧', '23', '23424', '4901131', '愛知県', 'アイチケン', '海部郡大治町', 'アマグンオオハルチョウ', '長牧', 'ナガマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県海部郡大治町北間島', '23', '23424', '4901132', '愛知県', 'アイチケン', '海部郡大治町', 'アマグンオオハルチョウ', '北間島', 'キタマジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県海部郡大治町八ツ屋', '23', '23424', '4901133', '愛知県', 'アイチケン', '海部郡大治町', 'アマグンオオハルチョウ', '八ツ屋', 'ヤツヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県海部郡大治町東條', '23', '23424', '4901134', '愛知県', 'アイチケン', '海部郡大治町', 'アマグンオオハルチョウ', '東條', 'ヒガシジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県海部郡大治町鎌須賀', '23', '23424', '4901135', '愛知県', 'アイチケン', '海部郡大治町', 'アマグンオオハルチョウ', '鎌須賀', 'カマスカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県海部郡大治町花常', '23', '23424', '4901136', '愛知県', 'アイチケン', '海部郡大治町', 'アマグンオオハルチョウ', '花常', 'ハナツネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県海部郡大治町堀之内', '23', '23424', '4901137', '愛知県', 'アイチケン', '海部郡大治町', 'アマグンオオハルチョウ', '堀之内', 'ホリノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県海部郡大治町馬島', '23', '23424', '4901141', '愛知県', 'アイチケン', '海部郡大治町', 'アマグンオオハルチョウ', '馬島', 'マジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県海部郡大治町三本木', '23', '23424', '4901142', '愛知県', 'アイチケン', '海部郡大治町', 'アマグンオオハルチョウ', '三本木', 'サンボンギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県海部郡大治町砂子', '23', '23424', '4901143', '愛知県', 'アイチケン', '海部郡大治町', 'アマグンオオハルチョウ', '砂子', 'スナゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県海部郡大治町西條', '23', '23424', '4901144', '愛知県', 'アイチケン', '海部郡大治町', 'アマグンオオハルチョウ', '西條', 'ニシジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県海部郡大治町中島', '23', '23424', '4901145', '愛知県', 'アイチケン', '海部郡大治町', 'アマグンオオハルチョウ', '中島', 'ナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県海部郡美和町', '23', '23422', '4901200', '愛知県', 'アイチケン', '海部郡美和町', 'アマグンミワチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('49148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県海部郡美和町古道', '23', '23422', '4901201', '愛知県', 'アイチケン', '海部郡美和町', 'アマグンミワチョウ', '古道', 'フルミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県海部郡美和町富塚', '23', '23422', '4901202', '愛知県', 'アイチケン', '海部郡美和町', 'アマグンミワチョウ', '富塚', 'トミツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県海部郡美和町木折', '23', '23422', '4901203', '愛知県', 'アイチケン', '海部郡美和町', 'アマグンミワチョウ', '木折', 'キオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県海部郡美和町花長', '23', '23422', '4901204', '愛知県', 'アイチケン', '海部郡美和町', 'アマグンミワチョウ', '花長', 'ハナオサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県海部郡美和町花正', '23', '23422', '4901205', '愛知県', 'アイチケン', '海部郡美和町', 'アマグンミワチョウ', '花正', 'ハナマサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県海部郡美和町東溝口', '23', '23422', '4901206', '愛知県', 'アイチケン', '海部郡美和町', 'アマグンミワチョウ', '東溝口', 'ヒガシミゾグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県海部郡美和町二ツ寺', '23', '23422', '4901207', '愛知県', 'アイチケン', '海部郡美和町', 'アマグンミワチョウ', '二ツ寺', 'フタツテラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北斗市久根別', '01', '01236', '0490121', '北海道', 'ホッカイドウ', '北斗市', 'ホクトシ', '久根別', 'クネベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県海部郡美和町篠田', '23', '23422', '4901211', '愛知県', 'アイチケン', '海部郡美和町', 'アマグンミワチョウ', '篠田', 'シノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県海部郡美和町小橋方', '23', '23422', '4901212', '愛知県', 'アイチケン', '海部郡美和町', 'アマグンミワチョウ', '小橋方', 'コバシカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県海部郡美和町乙之子', '23', '23422', '4901213', '愛知県', 'アイチケン', '海部郡美和町', 'アマグンミワチョウ', '乙之子', 'オトノコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県海部郡美和町北苅', '23', '23422', '4901214', '愛知県', 'アイチケン', '海部郡美和町', 'アマグンミワチョウ', '北苅', 'キタカリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北斗市東浜', '01', '01236', '0490122', '北海道', 'ホッカイドウ', '北斗市', 'ホクトシ', '東浜', 'ヒガシハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県海部郡美和町金岩', '23', '23422', '4901221', '愛知県', 'アイチケン', '海部郡美和町', 'アマグンミワチョウ', '金岩', 'カナイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県海部郡美和町木田', '23', '23422', '4901222', '愛知県', 'アイチケン', '海部郡美和町', 'アマグンミワチョウ', '木田', 'キダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県海部郡美和町森山', '23', '23422', '4901223', '愛知県', 'アイチケン', '海部郡美和町', 'アマグンミワチョウ', '森山', 'モリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県海部郡美和町丹波', '23', '23422', '4901224', '愛知県', 'アイチケン', '海部郡美和町', 'アマグンミワチョウ', '丹波', 'タンバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県海部郡美和町蜂須賀', '23', '23422', '4901225', '愛知県', 'アイチケン', '海部郡美和町', 'アマグンミワチョウ', '蜂須賀', 'ハチスカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県海部郡美和町中橋', '23', '23422', '4901226', '愛知県', 'アイチケン', '海部郡美和町', 'アマグンミワチョウ', '中橋', 'ナカハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市平和町須ケ谷', '23', '23220', '4901301', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '平和町須ケ谷', 'ヘイワチョウスカタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市平和町観音堂', '23', '23220', '4901302', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '平和町観音堂', 'ヘイワチョウカンノンドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市平和町上三宅', '23', '23220', '4901303', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '平和町上三宅', 'ヘイワチョウカミミヤケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市平和町法立', '23', '23220', '4901304', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '平和町法立', 'ヘイワチョウホウリュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市平和町丸渕上', '23', '23220', '4901305', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '平和町', 'ヘイワチョウ', null, null, '丸渕上', 'マルブチカミ');
INSERT INTO `ms_addresses` VALUES ('49176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市平和町丸渕下', '23', '23220', '4901305', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '平和町', 'ヘイワチョウ', null, null, '丸渕下', 'マルブチシモ');
INSERT INTO `ms_addresses` VALUES ('49177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市平和町鷲尾', '23', '23220', '4901305', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '平和町', 'ヘイワチョウ', null, null, '鷲尾', 'ワシオ');
INSERT INTO `ms_addresses` VALUES ('49178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北斗市富川', '01', '01236', '0490131', '北海道', 'ホッカイドウ', '北斗市', 'ホクトシ', '富川', 'トミガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市平和町中三宅', '23', '23220', '4901311', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '平和町中三宅', 'ヘイワチョウナカミヤケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市平和町下三宅', '23', '23220', '4901312', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '平和町下三宅', 'ヘイワチョウシモミヤケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市平和町横池', '23', '23220', '4901313', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '平和町横池', 'ヘイワチョウヨコイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市平和町西光坊', '23', '23220', '4901314', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '平和町西光坊', 'ヘイワチョウサイコウボウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市平和町平池', '23', '23220', '4901315', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '平和町平池', 'ヘイワチョウヒライケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北斗市館野', '01', '01236', '0490132', '北海道', 'ホッカイドウ', '北斗市', 'ホクトシ', '館野', 'ダテノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市平和町東城', '23', '23220', '4901321', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '平和町東城', 'ヘイワチョウトウジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市平和町上前浪', '23', '23220', '4901322', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '平和町', 'ヘイワチョウ', null, null, '上前浪', 'カミマエナミ');
INSERT INTO `ms_addresses` VALUES ('49187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市平和町下前浪', '23', '23220', '4901322', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '平和町', 'ヘイワチョウ', null, null, '下前浪', 'シモマエナミ');
INSERT INTO `ms_addresses` VALUES ('49188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市平和町光和', '23', '23220', '4901323', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '平和町', 'ヘイワチョウ', null, null, '光和', 'コウワ');
INSERT INTO `ms_addresses` VALUES ('49189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市平和町塩川', '23', '23220', '4901323', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '平和町', 'ヘイワチョウ', null, null, '塩川', 'シオカワ');
INSERT INTO `ms_addresses` VALUES ('49190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市平和町下起北', '23', '23220', '4901323', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '平和町', 'ヘイワチョウ', null, null, '下起北', 'シモコシキタ');
INSERT INTO `ms_addresses` VALUES ('49191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市平和町下起中', '23', '23220', '4901323', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '平和町', 'ヘイワチョウ', null, null, '下起中', 'シモコシナカ');
INSERT INTO `ms_addresses` VALUES ('49192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市平和町下起東', '23', '23220', '4901323', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '平和町', 'ヘイワチョウ', null, null, '下起東', 'シモコシヒガシ');
INSERT INTO `ms_addresses` VALUES ('49193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市平和町下起南', '23', '23220', '4901323', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '平和町', 'ヘイワチョウ', null, null, '下起南', 'シモコシミナミ');
INSERT INTO `ms_addresses` VALUES ('49194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市平和町勝幡新田', '23', '23220', '4901323', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '平和町', 'ヘイワチョウ', null, null, '勝幡新田', 'ショバタシンデン');
INSERT INTO `ms_addresses` VALUES ('49195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市平和町城西', '23', '23220', '4901323', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '平和町', 'ヘイワチョウ', null, null, '城西', 'シロニシ');
INSERT INTO `ms_addresses` VALUES ('49196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市平和町城之内', '23', '23220', '4901323', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '平和町', 'ヘイワチョウ', null, null, '城之内', 'シロノウチ');
INSERT INTO `ms_addresses` VALUES ('49197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市平和町須ケ脇', '23', '23220', '4901323', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '平和町', 'ヘイワチョウ', null, null, '須ケ脇', 'スカワキ');
INSERT INTO `ms_addresses` VALUES ('49198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市平和町那古良', '23', '23220', '4901323', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '平和町', 'ヘイワチョウ', null, null, '那古良', 'ナコラ');
INSERT INTO `ms_addresses` VALUES ('49199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市平和町平六', '23', '23220', '4901323', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '平和町', 'ヘイワチョウ', null, null, '平六', 'ヘイロク');
INSERT INTO `ms_addresses` VALUES ('49200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市平和町前平', '23', '23220', '4901323', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '平和町', 'ヘイワチョウ', null, null, '前平', 'マエヒラ');
INSERT INTO `ms_addresses` VALUES ('49201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市平和町明和', '23', '23220', '4901323', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '平和町', 'ヘイワチョウ', null, null, '明和', 'メイワ');
INSERT INTO `ms_addresses` VALUES ('49202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市平和町嫁振', '23', '23220', '4901323', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '平和町', 'ヘイワチョウ', null, null, '嫁振', 'ヨメフリ');
INSERT INTO `ms_addresses` VALUES ('49203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市平和町嫁振北', '23', '23220', '4901323', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '平和町', 'ヘイワチョウ', null, null, '嫁振北', 'ヨメフリキタ');
INSERT INTO `ms_addresses` VALUES ('49204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市平和町嫁振東', '23', '23220', '4901323', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '平和町', 'ヘイワチョウ', null, null, '嫁振東', 'ヨメフリヒガシ');
INSERT INTO `ms_addresses` VALUES ('49205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市平和町領内', '23', '23220', '4901323', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '平和町', 'ヘイワチョウ', null, null, '領内', 'リョウナイ');
INSERT INTO `ms_addresses` VALUES ('49206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北斗市柳沢', '01', '01236', '0490133', '北海道', 'ホッカイドウ', '北斗市', 'ホクトシ', '柳沢', 'ヤナギサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北斗市三好', '01', '01236', '0490134', '北海道', 'ホッカイドウ', '北斗市', 'ホクトシ', '三好', 'ミヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北斗市水無', '01', '01236', '0490135', '北海道', 'ホッカイドウ', '北斗市', 'ホクトシ', '水無', 'ミズナシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北斗市峨朗', '01', '01236', '0490136', '北海道', 'ホッカイドウ', '北斗市', 'ホクトシ', '峨朗', 'ガロウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県海部郡飛島村', '23', '23427', '4901400', '愛知県', 'アイチケン', '海部郡飛島村', 'アマグントビシマムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('49212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県弥富市六條町', '23', '23235', '4901401', '愛知県', 'アイチケン', '弥富市', 'ヤトミシ', '六條町', 'ロクジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県弥富市五斗山', '23', '23235', '4901402', '愛知県', 'アイチケン', '弥富市', 'ヤトミシ', '五斗山', 'ゴトヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県弥富市鳥ケ地', '23', '23235', '4901403', '愛知県', 'アイチケン', '弥富市', 'ヤトミシ', '鳥ケ地', 'トリガンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県弥富市鳥ケ地町', '23', '23235', '4901403', '愛知県', 'アイチケン', '弥富市', 'ヤトミシ', '鳥ケ地町', 'トリガンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県弥富市桴場', '23', '23235', '4901404', '愛知県', 'アイチケン', '弥富市', 'ヤトミシ', '桴場', 'イカダバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県弥富市神戸', '23', '23235', '4901405', '愛知県', 'アイチケン', '弥富市', 'ヤトミシ', '神戸', 'カンド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県弥富市神戸町', '23', '23235', '4901405', '愛知県', 'アイチケン', '弥富市', 'ヤトミシ', '神戸町', 'カンドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県弥富市鍋平', '23', '23235', '4901406', '愛知県', 'アイチケン', '弥富市', 'ヤトミシ', '鍋平', 'ナベヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県弥富市三百島', '23', '23235', '4901407', '愛知県', 'アイチケン', '弥富市', 'ヤトミシ', '三百島', 'サンビャクジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北斗市谷好', '01', '01236', '0490141', '北海道', 'ホッカイドウ', '北斗市', 'ホクトシ', '谷好', 'タニヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県弥富市善太町', '23', '23235', '4901411', '愛知県', 'アイチケン', '弥富市', 'ヤトミシ', '善太町', 'ゼンタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県弥富市馬ケ地', '23', '23235', '4901412', '愛知県', 'アイチケン', '弥富市', 'ヤトミシ', '馬ケ地', 'ウマガンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県弥富市子宝', '23', '23235', '4901413', '愛知県', 'アイチケン', '弥富市', 'ヤトミシ', '子宝', 'コダカラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県弥富市子宝町', '23', '23235', '4901413', '愛知県', 'アイチケン', '弥富市', 'ヤトミシ', '子宝町', 'コダカラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県弥富市坂中地', '23', '23235', '4901414', '愛知県', 'アイチケン', '弥富市', 'ヤトミシ', '坂中地', 'サカナカジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県弥富市坂中地町', '23', '23235', '4901414', '愛知県', 'アイチケン', '弥富市', 'ヤトミシ', '坂中地町', 'サカナカジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県弥富市鮫ケ地', '23', '23235', '4901415', '愛知県', 'アイチケン', '弥富市', 'ヤトミシ', '鮫ケ地', 'サメガンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県弥富市鮫ケ地町', '23', '23235', '4901415', '愛知県', 'アイチケン', '弥富市', 'ヤトミシ', '鮫ケ地町', 'サメガンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北斗市昭和', '01', '01236', '0490142', '北海道', 'ホッカイドウ', '北斗市', 'ホクトシ', '昭和', 'ショウワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県弥富市上押萩', '23', '23235', '4901421', '愛知県', 'アイチケン', '弥富市', 'ヤトミシ', '上押萩', 'カミオシハギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県弥富市上押萩町', '23', '23235', '4901421', '愛知県', 'アイチケン', '弥富市', 'ヤトミシ', '上押萩町', 'カミオシハギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県弥富市下押萩', '23', '23235', '4901422', '愛知県', 'アイチケン', '弥富市', 'ヤトミシ', '下押萩', 'シモオシハギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県弥富市下押萩町', '23', '23235', '4901422', '愛知県', 'アイチケン', '弥富市', 'ヤトミシ', '下押萩町', 'シモオシハギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県弥富市海屋', '23', '23235', '4901423', '愛知県', 'アイチケン', '弥富市', 'ヤトミシ', '海屋', 'カイオク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県弥富市海屋町', '23', '23235', '4901423', '愛知県', 'アイチケン', '弥富市', 'ヤトミシ', '海屋町', 'カイオクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県弥富市亀ケ地', '23', '23235', '4901424', '愛知県', 'アイチケン', '弥富市', 'ヤトミシ', '亀ケ地', 'カメガンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県弥富市東蜆', '23', '23235', '4901425', '愛知県', 'アイチケン', '弥富市', 'ヤトミシ', '東蜆', 'ヒガシシジミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県弥富市四郎兵衛', '23', '23235', '4901426', '愛知県', 'アイチケン', '弥富市', 'ヤトミシ', '四郎兵衛', 'シロベエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県弥富市四郎兵衛町', '23', '23235', '4901426', '愛知県', 'アイチケン', '弥富市', 'ヤトミシ', '四郎兵衛町', 'シロベエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県弥富市西蜆', '23', '23235', '4901427', '愛知県', 'アイチケン', '弥富市', 'ヤトミシ', '西蜆', 'ニシシジミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県弥富市竹田', '23', '23235', '4901428', '愛知県', 'アイチケン', '弥富市', 'ヤトミシ', '竹田', 'タケタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北斗市公園通', '01', '01236', '0490143', '北海道', 'ホッカイドウ', '北斗市', 'ホクトシ', '公園通', 'コウエンドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県海部郡飛島村服岡', '23', '23427', '4901431', '愛知県', 'アイチケン', '海部郡飛島村', 'アマグントビシマムラ', '服岡', 'フクオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県海部郡飛島村三福', '23', '23427', '4901432', '愛知県', 'アイチケン', '海部郡飛島村', 'アマグントビシマムラ', '三福', 'ミフク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県海部郡飛島村渚', '23', '23427', '4901433', '愛知県', 'アイチケン', '海部郡飛島村', 'アマグントビシマムラ', '渚', 'ナギサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県海部郡飛島村松之郷', '23', '23427', '4901434', '愛知県', 'アイチケン', '海部郡飛島村', 'アマグントビシマムラ', '松之郷', 'マツノゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県海部郡飛島村梅之郷', '23', '23427', '4901435', '愛知県', 'アイチケン', '海部郡飛島村', 'アマグントビシマムラ', '梅之郷', 'ウメノゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県海部郡飛島村竹之郷', '23', '23427', '4901436', '愛知県', 'アイチケン', '海部郡飛島村', 'アマグントビシマムラ', '竹之郷', 'タケノゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県海部郡飛島村飛島新田竹之郷', '23', '23427', '4901436', '愛知県', 'アイチケン', '海部郡飛島村', 'アマグントビシマムラ', '飛島新田', 'トビシマシンデン', null, null, '竹之郷', 'タケノゴウ');
INSERT INTO `ms_addresses` VALUES ('49251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県海部郡飛島村飛島新田元起之郷', '23', '23427', '4901437', '愛知県', 'アイチケン', '海部郡飛島村', 'アマグントビシマムラ', '飛島新田', 'トビシマシンデン', null, null, '元起之郷', 'モトキノゴウ');
INSERT INTO `ms_addresses` VALUES ('49252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県海部郡飛島村元起', '23', '23427', '4901437', '愛知県', 'アイチケン', '海部郡飛島村', 'アマグントビシマムラ', '元起', 'モトキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県海部郡飛島村大宝', '23', '23427', '4901438', '愛知県', 'アイチケン', '海部郡飛島村', 'アマグントビシマムラ', '大宝', 'オオダカラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県海部郡飛島村政成新田', '23', '23427', '4901441', '愛知県', 'アイチケン', '海部郡飛島村', 'アマグントビシマムラ', '政成新田', 'マサナリシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県海部郡飛島村古政成', '23', '23427', '4901442', '愛知県', 'アイチケン', '海部郡飛島村', 'アマグントビシマムラ', '古政成', 'コマサナリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県海部郡飛島村新政成', '23', '23427', '4901443', '愛知県', 'アイチケン', '海部郡飛島村', 'アマグントビシマムラ', '新政成', 'シンマサナリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県海部郡飛島村木場', '23', '23427', '4901444', '愛知県', 'アイチケン', '海部郡飛島村', 'アマグントビシマムラ', '木場', 'キバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県海部郡飛島村金岡', '23', '23427', '4901445', '愛知県', 'アイチケン', '海部郡飛島村', 'アマグントビシマムラ', '金岡', 'カナオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県海部郡飛島村東浜', '23', '23427', '4901446', '愛知県', 'アイチケン', '海部郡飛島村', 'アマグントビシマムラ', '東浜', 'ヒガシハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県海部郡飛島村西浜', '23', '23427', '4901447', '愛知県', 'アイチケン', '海部郡飛島村', 'アマグントビシマムラ', '西浜', 'ニシハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北斗市桜岱', '01', '01236', '0490151', '北海道', 'ホッカイドウ', '北斗市', 'ホクトシ', '桜岱', 'サクラタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北斗市押上', '01', '01236', '0490152', '北海道', 'ホッカイドウ', '北斗市', 'ホクトシ', '押上', 'オシアゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北斗市大工川', '01', '01236', '0490153', '北海道', 'ホッカイドウ', '北斗市', 'ホクトシ', '大工川', 'ダイクガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北斗市添山', '01', '01236', '0490154', '北海道', 'ホッカイドウ', '北斗市', 'ホクトシ', '添山', 'ソエヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北斗市中野', '01', '01236', '0490155', '北海道', 'ホッカイドウ', '北斗市', 'ホクトシ', '中野', 'ナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北斗市中野通', '01', '01236', '0490156', '北海道', 'ホッカイドウ', '北斗市', 'ホクトシ', '中野通', 'ナカノドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北斗市清川', '01', '01236', '0490157', '北海道', 'ホッカイドウ', '北斗市', 'ホクトシ', '清川', 'キヨカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北斗市野崎', '01', '01236', '0490158', '北海道', 'ホッカイドウ', '北斗市', 'ホクトシ', '野崎', 'ノザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北斗市飯生', '01', '01236', '0490161', '北海道', 'ホッカイドウ', '北斗市', 'ホクトシ', '飯生', 'イナリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北斗市中央', '01', '01236', '0490162', '北海道', 'ホッカイドウ', '北斗市', 'ホクトシ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北斗市常盤', '01', '01236', '0490171', '北海道', 'ホッカイドウ', '北斗市', 'ホクトシ', '常盤', 'トキワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北斗市茂辺地', '01', '01236', '0490281', '北海道', 'ホッカイドウ', '北斗市', 'ホクトシ', '茂辺地', 'モヘジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北斗市当別', '01', '01236', '0490282', '北海道', 'ホッカイドウ', '北斗市', 'ホクトシ', '当別', 'トウベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北斗市三ツ石', '01', '01236', '0490283', '北海道', 'ホッカイドウ', '北斗市', 'ホクトシ', '三ツ石', 'ミツイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北斗市湯ノ沢', '01', '01236', '0490284', '北海道', 'ホッカイドウ', '北斗市', 'ホクトシ', '湯ノ沢', 'ユノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北斗市茂辺地市ノ渡', '01', '01236', '0490285', '北海道', 'ホッカイドウ', '北斗市', 'ホクトシ', '茂辺地市ノ渡', 'モヘジイチノワタリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北斗市矢不来', '01', '01236', '0490286', '北海道', 'ホッカイドウ', '北斗市', 'ホクトシ', '矢不来', 'ヤフライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上磯郡木古内町', '01', '01334', '0490400', '北海道', 'ホッカイドウ', '上磯郡木古内町', 'カミイソグンキコナイチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('49281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上磯郡木古内町大釜谷', '01', '01334', '0490401', '北海道', 'ホッカイドウ', '上磯郡木古内町', 'カミイソグンキコナイチョウ', '大釜谷', 'オオカマヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上磯郡木古内町御宮野', '01', '01334', '0490402', '北海道', 'ホッカイドウ', '上磯郡木古内町', 'カミイソグンキコナイチョウ', '御宮野', 'オミヤノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上磯郡木古内町釜谷', '01', '01334', '0490403', '北海道', 'ホッカイドウ', '上磯郡木古内町', 'カミイソグンキコナイチョウ', '釜谷', 'カマヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上磯郡木古内町亀川', '01', '01334', '0490404', '北海道', 'ホッカイドウ', '上磯郡木古内町', 'カミイソグンキコナイチョウ', '亀川', 'カメカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上磯郡木古内町泉沢', '01', '01334', '0490405', '北海道', 'ホッカイドウ', '上磯郡木古内町', 'カミイソグンキコナイチョウ', '泉沢', 'イズミサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上磯郡木古内町二乃岱', '01', '01334', '0490406', '北海道', 'ホッカイドウ', '上磯郡木古内町', 'カミイソグンキコナイチョウ', '二乃岱', 'ニノタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上磯郡木古内町橋呉', '01', '01334', '0490407', '北海道', 'ホッカイドウ', '上磯郡木古内町', 'カミイソグンキコナイチョウ', '橋呉', 'ハシクレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上磯郡木古内町幸連', '01', '01334', '0490408', '北海道', 'ホッカイドウ', '上磯郡木古内町', 'カミイソグンキコナイチョウ', '幸連', 'コウレン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上磯郡木古内町札苅', '01', '01334', '0490411', '北海道', 'ホッカイドウ', '上磯郡木古内町', 'カミイソグンキコナイチョウ', '札苅', 'サツカリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上磯郡木古内町大平', '01', '01334', '0490412', '北海道', 'ホッカイドウ', '上磯郡木古内町', 'カミイソグンキコナイチョウ', '大平', 'オオヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上磯郡木古内町前浜', '01', '01334', '0490421', '北海道', 'ホッカイドウ', '上磯郡木古内町', 'カミイソグンキコナイチョウ', '前浜', 'マエハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上磯郡木古内町本町', '01', '01334', '0490422', '北海道', 'ホッカイドウ', '上磯郡木古内町', 'カミイソグンキコナイチョウ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上磯郡木古内町木古内', '01', '01334', '0490431', '北海道', 'ホッカイドウ', '上磯郡木古内町', 'カミイソグンキコナイチョウ', '木古内', 'キコナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上磯郡木古内町中野', '01', '01334', '0490441', '北海道', 'ホッカイドウ', '上磯郡木古内町', 'カミイソグンキコナイチョウ', '中野', 'ナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上磯郡木古内町新道', '01', '01334', '0490451', '北海道', 'ホッカイドウ', '上磯郡木古内町', 'カミイソグンキコナイチョウ', '新道', 'シンミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上磯郡木古内町建川', '01', '01334', '0490452', '北海道', 'ホッカイドウ', '上磯郡木古内町', 'カミイソグンキコナイチョウ', '建川', 'タテカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上磯郡木古内町大川', '01', '01334', '0490453', '北海道', 'ホッカイドウ', '上磯郡木古内町', 'カミイソグンキコナイチョウ', '大川', 'オオカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上磯郡木古内町瓜谷', '01', '01334', '0490454', '北海道', 'ホッカイドウ', '上磯郡木古内町', 'カミイソグンキコナイチョウ', '瓜谷', 'ウリヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上磯郡木古内町鶴岡', '01', '01334', '0490455', '北海道', 'ホッカイドウ', '上磯郡木古内町', 'カミイソグンキコナイチョウ', '鶴岡', 'ツルオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道檜山郡上ノ国町神明', '01', '01362', '0490561', '北海道', 'ホッカイドウ', '檜山郡上ノ国町', 'ヒヤマグンカミノクニチョウ', '神明', 'シンメイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道檜山郡上ノ国町湯ノ岱', '01', '01362', '0490562', '北海道', 'ホッカイドウ', '檜山郡上ノ国町', 'ヒヤマグンカミノクニチョウ', '湯ノ岱', 'ユノタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道檜山郡上ノ国町宮越', '01', '01362', '0490563', '北海道', 'ホッカイドウ', '檜山郡上ノ国町', 'ヒヤマグンカミノクニチョウ', '宮越', 'ミヤコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道檜山郡上ノ国町早瀬', '01', '01362', '0490564', '北海道', 'ホッカイドウ', '檜山郡上ノ国町', 'ヒヤマグンカミノクニチョウ', '早瀬', 'ハヤセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道檜山郡上ノ国町', '01', '01362', '0490600', '北海道', 'ホッカイドウ', '檜山郡上ノ国町', 'ヒヤマグンカミノクニチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('49305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道檜山郡上ノ国町勝山', '01', '01362', '0490601', '北海道', 'ホッカイドウ', '檜山郡上ノ国町', 'ヒヤマグンカミノクニチョウ', '勝山', 'カツヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道檜山郡上ノ国町原歌', '01', '01362', '0490602', '北海道', 'ホッカイドウ', '檜山郡上ノ国町', 'ヒヤマグンカミノクニチョウ', '原歌', 'ハラウタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道檜山郡上ノ国町大崎', '01', '01362', '0490603', '北海道', 'ホッカイドウ', '檜山郡上ノ国町', 'ヒヤマグンカミノクニチョウ', '大崎', 'オオサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道檜山郡上ノ国町大安在', '01', '01362', '0490604', '北海道', 'ホッカイドウ', '檜山郡上ノ国町', 'ヒヤマグンカミノクニチョウ', '大安在', 'オオアンザイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道檜山郡上ノ国町小安在', '01', '01362', '0490605', '北海道', 'ホッカイドウ', '檜山郡上ノ国町', 'ヒヤマグンカミノクニチョウ', '小安在', 'コアンザイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道檜山郡上ノ国町木ノ子', '01', '01362', '0490606', '北海道', 'ホッカイドウ', '檜山郡上ノ国町', 'ヒヤマグンカミノクニチョウ', '木ノ子', 'キノコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道檜山郡上ノ国町扇石', '01', '01362', '0490607', '北海道', 'ホッカイドウ', '檜山郡上ノ国町', 'ヒヤマグンカミノクニチョウ', '扇石', 'オウギイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道檜山郡上ノ国町汐吹', '01', '01362', '0490608', '北海道', 'ホッカイドウ', '檜山郡上ノ国町', 'ヒヤマグンカミノクニチョウ', '汐吹', 'シオフキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道檜山郡上ノ国町大留', '01', '01362', '0490611', '北海道', 'ホッカイドウ', '檜山郡上ノ国町', 'ヒヤマグンカミノクニチョウ', '大留', 'オオドメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道檜山郡上ノ国町上ノ国', '01', '01362', '0490612', '北海道', 'ホッカイドウ', '檜山郡上ノ国町', 'ヒヤマグンカミノクニチョウ', '上ノ国', 'カミノクニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道檜山郡上ノ国町向浜', '01', '01362', '0490613', '北海道', 'ホッカイドウ', '檜山郡上ノ国町', 'ヒヤマグンカミノクニチョウ', '向浜', 'ムカイハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道檜山郡上ノ国町内郷', '01', '01362', '0490621', '北海道', 'ホッカイドウ', '檜山郡上ノ国町', 'ヒヤマグンカミノクニチョウ', '内郷', 'ウチゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道檜山郡上ノ国町北村', '01', '01362', '0490622', '北海道', 'ホッカイドウ', '檜山郡上ノ国町', 'ヒヤマグンカミノクニチョウ', '北村', 'キタムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道檜山郡上ノ国町新村', '01', '01362', '0490623', '北海道', 'ホッカイドウ', '檜山郡上ノ国町', 'ヒヤマグンカミノクニチョウ', '新村', 'シンムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道檜山郡上ノ国町中須田', '01', '01362', '0490624', '北海道', 'ホッカイドウ', '檜山郡上ノ国町', 'ヒヤマグンカミノクニチョウ', '中須田', 'ナカスダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道檜山郡上ノ国町豊田', '01', '01362', '0490625', '北海道', 'ホッカイドウ', '檜山郡上ノ国町', 'ヒヤマグンカミノクニチョウ', '豊田', 'トヨタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道檜山郡上ノ国町桂岡', '01', '01362', '0490626', '北海道', 'ホッカイドウ', '檜山郡上ノ国町', 'ヒヤマグンカミノクニチョウ', '桂岡', 'カツラオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道檜山郡上ノ国町小森', '01', '01362', '0490627', '北海道', 'ホッカイドウ', '檜山郡上ノ国町', 'ヒヤマグンカミノクニチョウ', '小森', 'コモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道檜山郡上ノ国町石崎', '01', '01362', '0490741', '北海道', 'ホッカイドウ', '檜山郡上ノ国町', 'ヒヤマグンカミノクニチョウ', '石崎', 'イシザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道檜山郡上ノ国町館野', '01', '01362', '0490742', '北海道', 'ホッカイドウ', '檜山郡上ノ国町', 'ヒヤマグンカミノクニチョウ', '館野', 'タテノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道檜山郡上ノ国町小砂子', '01', '01362', '0490743', '北海道', 'ホッカイドウ', '檜山郡上ノ国町', 'ヒヤマグンカミノクニチョウ', '小砂子', 'チイサゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道檜山郡上ノ国町早川', '01', '01362', '0490744', '北海道', 'ホッカイドウ', '檜山郡上ノ国町', 'ヒヤマグンカミノクニチョウ', '早川', 'ハヤカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市', '23', '23203', '4910000', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('49333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市瀬部', '23', '23203', '4910001', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '瀬部', 'セベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市時之島', '23', '23203', '4910002', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '時之島', 'トキノシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市春明', '23', '23203', '4910003', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '春明', 'シュンメイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市定水寺', '23', '23203', '4910004', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '定水寺', 'ジョウスイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市西大海道', '23', '23203', '4910005', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '西大海道', 'ニシオオガイドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市柚木颪', '23', '23203', '4910011', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '柚木颪', 'ユギオロシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市小赤見', '23', '23203', '4910012', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '小赤見', 'コアカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市北小渕', '23', '23203', '4910013', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '北小渕', 'キタオブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市南小渕', '23', '23203', '4910014', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '南小渕', 'ミナミオブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市大赤見', '23', '23203', '4910015', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '大赤見', 'オオアカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市東両郷町', '23', '23203', '4910021', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '東両郷町', 'ヒガシリョウゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市両郷町', '23', '23203', '4910022', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '両郷町', 'リョウゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市赤見', '23', '23203', '4910023', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '赤見', 'アカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市富士', '23', '23203', '4910024', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '富士', 'フジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市羽衣', '23', '23203', '4910025', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '羽衣', 'ハゴロモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市和光', '23', '23203', '4910026', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '和光', 'ワコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市藤塚町', '23', '23203', '4910027', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '藤塚町', 'フジツカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市朝日', '23', '23203', '4910028', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '朝日', 'アサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市観音町', '23', '23203', '4910031', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '観音町', 'カンノンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市下沼町', '23', '23203', '4910032', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '下沼町', 'シモヌマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市別明町', '23', '23203', '4910033', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '別明町', 'ベツメイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市浜町', '23', '23203', '4910034', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '浜町', 'ハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市大浜', '23', '23203', '4910035', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '大浜', 'オオハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市桜', '23', '23203', '4910036', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '桜', 'サクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市貴船', '23', '23203', '4910037', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '貴船', 'キフネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市文京', '23', '23203', '4910041', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '文京', 'ブンキョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市松降', '23', '23203', '4910042', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '松降', 'マツフリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市真清田', '23', '23203', '4910043', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '真清田', 'マスミダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市大宮', '23', '23203', '4910044', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '大宮', 'オオミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市音羽', '23', '23203', '4910045', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '音羽', 'オトワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市天王', '23', '23203', '4910046', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '天王', 'テンノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市今伊勢町馬寄', '23', '23203', '4910051', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '今伊勢町馬寄', 'イマイセチョウウマヨセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市今伊勢町新神戸', '23', '23203', '4910052', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '今伊勢町新神戸', 'イマイセチョウシンカンベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市今伊勢町本神戸', '23', '23203', '4910053', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '今伊勢町本神戸', 'イマイセチョウホンカンベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市大正通', '23', '23203', '4910054', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '大正通', 'タイショウドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市神戸町', '23', '23203', '4910055', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '神戸町', 'カンベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市東出町', '23', '23203', '4910056', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '東出町', 'ヒガシデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市今伊勢町宮後', '23', '23203', '4910057', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '今伊勢町宮後', 'イマイセチョウミヤウシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市今伊勢町馬寄舟入', '23', '23203', '4910058', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '今伊勢町馬寄', 'イマイセチョウウマヨセ', null, null, '舟入', 'フナイリ');
INSERT INTO `ms_addresses` VALUES ('49372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市一宮', '23', '23203', '4910059', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '一宮', 'イチノミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市乾町', '23', '23203', '4910061', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '乾町', 'イヌイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市西島町', '23', '23203', '4910062', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '西島町', 'ニシジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市常願通', '23', '23203', '4910063', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '常願通', 'ジョウガンドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市宮西通', '23', '23203', '4910064', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '宮西通', 'ミヤニシドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市水落町', '23', '23203', '4910065', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '水落町', 'ミズオチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市三丹町', '23', '23203', '4910066', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '三丹町', 'サンタンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市北丹町', '23', '23203', '4910067', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '北丹町', 'ホクタンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市小栗町', '23', '23203', '4910068', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '小栗町', 'オグリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市北神明町', '23', '23203', '4910069', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '北神明町', 'キタシンメイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市長島町', '23', '23203', '4910071', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '長島町', 'ナガシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市中島通', '23', '23203', '4910072', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '中島通', 'ナカシマドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市高畑町', '23', '23203', '4910073', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '高畑町', 'タカハタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市東島町', '23', '23203', '4910074', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '東島町', 'ヒガシシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市寺島町', '23', '23203', '4910075', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '寺島町', 'テラシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市貴船町', '23', '23203', '4910076', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '貴船町', 'キフネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市枠杁町', '23', '23203', '4910077', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '枠杁町', 'ワクイリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市松降通', '23', '23203', '4910078', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '松降通', 'マツフリドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市九品町', '23', '23203', '4910079', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '九品町', 'クホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市西小原町', '23', '23203', '4910081', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '西小原町', 'ニシオハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市小原町', '23', '23203', '4910082', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '小原町', 'オハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市丹羽', '23', '23203', '4910083', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '丹羽', 'ニワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市古見町', '23', '23203', '4910084', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '古見町', 'コケンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市松山町', '23', '23203', '4910085', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '松山町', 'マツヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市田島町', '23', '23203', '4910086', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '田島町', 'タジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市浅井町尾関', '23', '23203', '4910101', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '浅井町尾関', 'アザイチョウオゼキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市浅井町尾関長田', '23', '23203', '4910102', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '浅井町尾関', 'アザイチョウオゼキ', null, null, '長田', 'ナガタ');
INSERT INTO `ms_addresses` VALUES ('49399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市浅井町前野', '23', '23203', '4910103', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '浅井町前野', 'アザイチョウマエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市浅井町小日比野', '23', '23203', '4910104', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '浅井町小日比野', 'アザイチョウコヒビノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市浅井町大日比野', '23', '23203', '4910105', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '浅井町大日比野', 'アザイチョウオオヒビノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市浅井町河端', '23', '23203', '4910111', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '浅井町河端', 'アザイチョウコウバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市浅井町東浅井', '23', '23203', '4910112', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '浅井町東浅井', 'アザイチョウヒガシアザイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市浅井町西浅井', '23', '23203', '4910113', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '浅井町西浅井', 'アザイチョウニシアザイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市浅井町江森', '23', '23203', '4910114', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '浅井町江森', 'アザイチョウエモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市浅井町西海戸', '23', '23203', '4910115', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '浅井町西海戸', 'アザイチョウニシガイド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市島村', '23', '23203', '4910121', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '島村', 'シマムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市島村西山', '23', '23203', '4910122', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '島村', 'シマムラ', null, null, '西山', 'ニシヤマ');
INSERT INTO `ms_addresses` VALUES ('49409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市富塚', '23', '23203', '4910123', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '富塚', 'トミツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市佐千原', '23', '23203', '4910124', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '佐千原', 'サチハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市高田', '23', '23203', '4910125', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '高田', 'タカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市笹野', '23', '23203', '4910131', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '笹野', 'ササノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市大毛', '23', '23203', '4910132', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '大毛', 'オオケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市田所', '23', '23203', '4910133', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '田所', 'タドコロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市更屋敷', '23', '23203', '4910134', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '更屋敷', 'サラヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市光明寺', '23', '23203', '4910135', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '光明寺', 'コウミョウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市杉山', '23', '23203', '4910136', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '杉山', 'スギヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市浅井町黒岩', '23', '23203', '4910141', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '浅井町黒岩', 'アザイチョウクロイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市浅井町河田', '23', '23203', '4910142', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '浅井町河田', 'アザイチョウコウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市浅井町大野', '23', '23203', '4910143', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '浅井町大野', 'アザイチョウオオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市浅井町極楽寺', '23', '23203', '4910144', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '浅井町極楽寺', 'アザイチョウゴクラクジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市奥町', '23', '23203', '4910201', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '奥町', 'オクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市萩原町花井方', '23', '23203', '4910351', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '萩原町花井方', 'ハギワラチョウハナイガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市萩原町富田方', '23', '23203', '4910352', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '萩原町富田方', 'ハギワラチョウトミダガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市萩原町萩原', '23', '23203', '4910353', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '萩原町萩原', 'ハギワラチョウハギワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市萩原町朝宮', '23', '23203', '4910354', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '萩原町朝宮', 'ハギワラチョウアサミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市萩原町林野', '23', '23203', '4910361', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '萩原町林野', 'ハギワラチョウハヤシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市萩原町西宮重', '23', '23203', '4910362', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '萩原町西宮重', 'ハギワラチョウニシミヤシゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市萩原町東宮重', '23', '23203', '4910363', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '萩原町東宮重', 'ハギワラチョウヒガシミヤシゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市萩原町中島', '23', '23203', '4910364', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '萩原町中島', 'ハギワラチョウナカシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市萩原町西御堂', '23', '23203', '4910365', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '萩原町西御堂', 'ハギワラチョウニシミドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市萩原町河田方', '23', '23203', '4910366', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '萩原町河田方', 'ハギワラチョウカワダガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市萩原町高木', '23', '23203', '4910371', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '萩原町高木', 'ハギワラチョウタカギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市萩原町滝', '23', '23203', '4910372', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '萩原町滝', 'ハギワラチョウタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市萩原町高松', '23', '23203', '4910373', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '萩原町高松', 'ハギワラチョウタカマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市萩原町築込', '23', '23203', '4910374', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '萩原町築込', 'ハギワラチョウツキコミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市萩原町戸苅', '23', '23203', '4910375', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '萩原町戸苅', 'ハギワラチョウトガリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市萩原町串作', '23', '23203', '4910376', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '萩原町串作', 'ハギワラチョウクシツクリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市千秋町加茂', '23', '23203', '4910801', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '千秋町加茂', 'チアキチョウカモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市千秋町勝栗', '23', '23203', '4910802', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '千秋町勝栗', 'チアキチョウカチクリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市千秋町穂積塚本', '23', '23203', '4910803', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '千秋町穂積塚本', 'チアキチョウホヅミツカモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市千秋町佐野', '23', '23203', '4910804', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '千秋町佐野', 'チアキチョウサノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市千秋町一色', '23', '23203', '4910805', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '千秋町一色', 'チアキチョウイシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市千秋町浮野', '23', '23203', '4910806', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '千秋町浮野', 'チアキチョウウキノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市千秋町加納馬場', '23', '23203', '4910811', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '千秋町加納馬場', 'チアキチョウカノウマンバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市千秋町芝原', '23', '23203', '4910812', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '千秋町芝原', 'チアキチョウシバハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市千秋町町屋', '23', '23203', '4910813', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '千秋町町屋', 'チアキチョウマチヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市千秋町小山', '23', '23203', '4910814', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '千秋町小山', 'チアキチョウオヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市千秋町塩尻', '23', '23203', '4910815', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '千秋町塩尻', 'チアキチョウシオジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市千秋町浅野羽根', '23', '23203', '4910816', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '千秋町浅野羽根', 'チアキチョウアサノハネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市千秋町天摩', '23', '23203', '4910817', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '千秋町天摩', 'チアキチョウテンマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市丹陽町重吉', '23', '23203', '4910821', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '丹陽町重吉', 'タンヨウチョウシゲヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市丹陽町伝法寺', '23', '23203', '4910822', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '丹陽町伝法寺', 'タンヨウチョウデンポウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市丹陽町五日市場', '23', '23203', '4910823', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '丹陽町五日市場', 'タンヨウチョウイツカイチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市丹陽町九日市場', '23', '23203', '4910824', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '丹陽町九日市場', 'タンヨウチョウココノカイチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市丹陽町外崎', '23', '23203', '4910825', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '丹陽町外崎', 'タンヨウチョウドサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市丹陽町三ツ井', '23', '23203', '4910826', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '丹陽町三ツ井', 'タンヨウチョウミツイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市丹陽町森本', '23', '23203', '4910827', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '丹陽町森本', 'タンヨウチョウモリモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市三ツ井', '23', '23203', '4910827', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '三ツ井', 'ミツイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市森本', '23', '23203', '4910831', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '森本', 'モリモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市若竹', '23', '23203', '4910832', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '若竹', 'ワカタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市平島', '23', '23203', '4910833', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '平島', 'ヒラシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市島崎', '23', '23203', '4910834', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '島崎', 'シマサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市あずら', '23', '23203', '4910835', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', 'あずら', 'アズラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市丹陽町多加木', '23', '23203', '4910836', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '丹陽町多加木', 'タンヨウチョウタカキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市多加木', '23', '23203', '4910837', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '多加木', 'タカキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市猿海道', '23', '23203', '4910838', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '猿海道', 'サルカイドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市丹陽町猿海道', '23', '23203', '4910838', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '丹陽町猿海道', 'タンヨウチョウサルガイドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市松島町', '23', '23203', '4910841', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '松島町', 'マツシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市公園通', '23', '23203', '4910842', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '公園通', 'コウエンドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市柳戸町', '23', '23203', '4910843', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '柳戸町', 'ヤナギドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市八町通', '23', '23203', '4910844', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '八町通', 'ハッチョウドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市下川田町', '23', '23203', '4910845', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '下川田町', 'シモカワダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市牛野通', '23', '23203', '4910846', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '牛野通', 'ウシノドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市大和町宮地花池', '23', '23203', '4910847', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '大和町宮地花池', 'ヤマトチョウミヤジハナイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市殿町', '23', '23203', '4910848', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '殿町', 'トノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市大江', '23', '23203', '4910851', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '大江', 'オオエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市大志', '23', '23203', '4910852', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '大志', 'ダイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市川田町', '23', '23203', '4910853', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '川田町', 'カワダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市北園通', '23', '23203', '4910854', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '北園通', 'キタゾノドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市石山町', '23', '23203', '4910855', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '石山町', 'イシヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市本町通', '23', '23203', '4910856', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '本町通', 'ホンマチドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市明治通', '23', '23203', '4910857', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '明治通', 'メイジドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市栄', '23', '23203', '4910858', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '栄', 'サカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市本町', '23', '23203', '4910859', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市泉', '23', '23203', '4910861', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '泉', 'イズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市緑', '23', '23203', '4910862', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '緑', 'ミドリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市東印田町', '23', '23203', '4910863', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '東印田町', 'ヒガシインデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市印田通', '23', '23203', '4910865', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '印田通', 'インデンドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市城崎通', '23', '23203', '4910866', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '城崎通', 'シロサキドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市古金町', '23', '23203', '4910867', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '古金町', 'コガネマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市向山南', '23', '23203', '4910868', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '向山南', 'ムカイヤマミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市向山町', '23', '23203', '4910869', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '向山町', 'ムカイヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市浅野', '23', '23203', '4910871', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '浅野', 'アサノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市平安', '23', '23203', '4910872', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '平安', 'ヘイアン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市せんい', '23', '23203', '4910873', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', 'せんい', 'センイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市馬見塚', '23', '23203', '4910874', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '馬見塚', 'マミヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市水附町', '23', '23203', '4910878', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '水附町', 'ミズツキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市白旗通', '23', '23203', '4910879', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '白旗通', 'シロハタドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市南印田', '23', '23203', '4910881', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '南印田', 'ミナミインデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市相生', '23', '23203', '4910882', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '相生', 'アイオイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市下田', '23', '23203', '4910883', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '下田', 'シモダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市北浦町', '23', '23203', '4910901', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '北浦町', 'キタウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市一色町', '23', '23203', '4910902', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '一色町', 'イシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市八幡', '23', '23203', '4910903', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '八幡', 'ハチマン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市神山', '23', '23203', '4910904', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '神山', 'カミヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市平和', '23', '23203', '4910905', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '平和', 'ヘイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市南出町', '23', '23203', '4910906', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '南出町', 'ミナミデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市西出町', '23', '23203', '4910907', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '西出町', 'ニシデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市深坪町', '23', '23203', '4910908', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '深坪町', 'フカツボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市野口', '23', '23203', '4910911', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '野口', 'ノグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市新生', '23', '23203', '4910912', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '新生', 'シンセイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市中町', '23', '23203', '4910913', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '中町', 'ナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市花池', '23', '23203', '4910914', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '花池', 'ハナイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市宮地', '23', '23203', '4910915', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '宮地', 'ミヤジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市観音寺', '23', '23203', '4910916', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '観音寺', 'カンノンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市昭和', '23', '23203', '4910917', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '昭和', 'ショウワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市末広', '23', '23203', '4910918', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '末広', 'スエヒロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市住吉', '23', '23203', '4910919', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '住吉', 'スミヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市妙興寺', '23', '23203', '4910921', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '妙興寺', 'ミョウコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市大和町妙興寺', '23', '23203', '4910922', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '大和町妙興寺', 'ヤマトチョウミョウコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市大和町氏永', '23', '23203', '4910923', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '大和町氏永', 'ヤマトチョウウジナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市大和町於保', '23', '23203', '4910924', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '大和町於保', 'ヤマトチョウオホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市大和町南高井', '23', '23203', '4910925', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '大和町南高井', 'ヤマトチョウミナミタカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市大和町北高井', '23', '23203', '4910926', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '大和町北高井', 'ヤマトチョウキタタカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市大和町戸塚', '23', '23203', '4910927', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '大和町戸塚', 'ヤマトチョウトツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市大和町馬引', '23', '23203', '4910931', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '大和町馬引', 'ヤマトチョウマビキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市大和町毛受', '23', '23203', '4910932', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '大和町毛受', 'ヤマトチョウメンジョ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市苅安賀', '23', '23203', '4910933', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '苅安賀', 'カリヤスカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市大和町苅安賀', '23', '23203', '4910934', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '大和町苅安賀', 'ヤマトチョウカリヤスカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市大和町福森', '23', '23203', '4910935', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '大和町福森', 'ヤマトチョウフクモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市寺前町', '23', '23203', '4910936', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '寺前町', 'テラマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市竹橋町', '23', '23203', '4910937', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '竹橋町', 'タケハシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市日光町', '23', '23203', '4910938', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '日光町', 'ニッコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上磯郡知内町', '01', '01333', '0491100', '北海道', 'ホッカイドウ', '上磯郡知内町', 'カミイソグンシリウチチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('49541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上磯郡知内町中ノ川', '01', '01333', '0491101', '北海道', 'ホッカイドウ', '上磯郡知内町', 'カミイソグンシリウチチョウ', '中ノ川', 'ナカノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上磯郡知内町森越', '01', '01333', '0491102', '北海道', 'ホッカイドウ', '上磯郡知内町', 'カミイソグンシリウチチョウ', '森越', 'モリコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上磯郡知内町重内', '01', '01333', '0491103', '北海道', 'ホッカイドウ', '上磯郡知内町', 'カミイソグンシリウチチョウ', '重内', 'オモナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上磯郡知内町涌元', '01', '01333', '0491104', '北海道', 'ホッカイドウ', '上磯郡知内町', 'カミイソグンシリウチチョウ', '涌元', 'ワキモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上磯郡知内町小谷石', '01', '01333', '0491105', '北海道', 'ホッカイドウ', '上磯郡知内町', 'カミイソグンシリウチチョウ', '小谷石', 'コタニイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上磯郡知内町元町', '01', '01333', '0491106', '北海道', 'ホッカイドウ', '上磯郡知内町', 'カミイソグンシリウチチョウ', '元町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上磯郡知内町上雷', '01', '01333', '0491107', '北海道', 'ホッカイドウ', '上磯郡知内町', 'カミイソグンシリウチチョウ', '上雷', 'ジョウライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上磯郡知内町湯ノ里', '01', '01333', '0491221', '北海道', 'ホッカイドウ', '上磯郡知内町', 'カミイソグンシリウチチョウ', '湯ノ里', 'ユノサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道松前郡福島町', '01', '01332', '0491300', '北海道', 'ホッカイドウ', '松前郡福島町', 'マツマエグンフクシマチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('49550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道松前郡福島町白符', '01', '01332', '0491301', '北海道', 'ホッカイドウ', '松前郡福島町', 'マツマエグンフクシマチョウ', '白符', 'シラフ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道松前郡福島町日向', '01', '01332', '0491302', '北海道', 'ホッカイドウ', '松前郡福島町', 'マツマエグンフクシマチョウ', '日向', 'ヒュウガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道松前郡福島町桧倉', '01', '01332', '0491311', '北海道', 'ホッカイドウ', '松前郡福島町', 'マツマエグンフクシマチョウ', '桧倉', 'ヒクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道松前郡福島町上町', '01', '01332', '0491312', '北海道', 'ホッカイドウ', '松前郡福島町', 'マツマエグンフクシマチョウ', '上町', 'ウエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道松前郡福島町川原町', '01', '01332', '0491312', '北海道', 'ホッカイドウ', '松前郡福島町', 'マツマエグンフクシマチョウ', '川原町', 'カワラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道松前郡福島町館古', '01', '01332', '0491312', '北海道', 'ホッカイドウ', '松前郡福島町', 'マツマエグンフクシマチョウ', '館古', 'タテコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道松前郡福島町福島', '01', '01332', '0491312', '北海道', 'ホッカイドウ', '松前郡福島町', 'マツマエグンフクシマチョウ', '福島', 'フクシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道松前郡福島町本町', '01', '01332', '0491312', '北海道', 'ホッカイドウ', '松前郡福島町', 'マツマエグンフクシマチョウ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道松前郡福島町吉田町', '01', '01332', '0491312', '北海道', 'ホッカイドウ', '松前郡福島町', 'マツマエグンフクシマチョウ', '吉田町', 'ヨシダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道松前郡福島町月崎', '01', '01332', '0491321', '北海道', 'ホッカイドウ', '松前郡福島町', 'マツマエグンフクシマチョウ', '月崎', 'ツキサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道松前郡福島町丸山団地', '01', '01332', '0491321', '北海道', 'ホッカイドウ', '松前郡福島町', 'マツマエグンフクシマチョウ', '丸山団地', 'マルヤマダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道松前郡福島町緑町', '01', '01332', '0491321', '北海道', 'ホッカイドウ', '松前郡福島町', 'マツマエグンフクシマチョウ', '緑町', 'ミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道松前郡福島町塩釜', '01', '01332', '0491322', '北海道', 'ホッカイドウ', '松前郡福島町', 'マツマエグンフクシマチョウ', '塩釜', 'シオガマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道松前郡福島町浦和', '01', '01332', '0491323', '北海道', 'ホッカイドウ', '松前郡福島町', 'マツマエグンフクシマチョウ', '浦和', 'ウラワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道松前郡福島町日の出', '01', '01332', '0491324', '北海道', 'ホッカイドウ', '松前郡福島町', 'マツマエグンフクシマチョウ', '日の出', 'ヒノデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道松前郡福島町岩部', '01', '01332', '0491325', '北海道', 'ホッカイドウ', '松前郡福島町', 'マツマエグンフクシマチョウ', '岩部', 'イワベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道松前郡福島町新栄町', '01', '01332', '0491331', '北海道', 'ホッカイドウ', '松前郡福島町', 'マツマエグンフクシマチョウ', '新栄町', 'シンエイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道松前郡福島町三岳', '01', '01332', '0491331', '北海道', 'ホッカイドウ', '松前郡福島町', 'マツマエグンフクシマチョウ', '三岳', 'ミタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道松前郡福島町千軒', '01', '01332', '0491332', '北海道', 'ホッカイドウ', '松前郡福島町', 'マツマエグンフクシマチョウ', '千軒', 'センゲン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道松前郡福島町宮歌', '01', '01332', '0491451', '北海道', 'ホッカイドウ', '松前郡福島町', 'マツマエグンフクシマチョウ', '宮歌', 'ミヤウタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道松前郡福島町豊浜', '01', '01332', '0491452', '北海道', 'ホッカイドウ', '松前郡福島町', 'マツマエグンフクシマチョウ', '豊浜', 'トヨハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道松前郡福島町美山', '01', '01332', '0491453', '北海道', 'ホッカイドウ', '松前郡福島町', 'マツマエグンフクシマチョウ', '美山', 'ミヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道松前郡福島町吉岡', '01', '01332', '0491453', '北海道', 'ホッカイドウ', '松前郡福島町', 'マツマエグンフクシマチョウ', '吉岡', 'ヨシオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道松前郡福島町館崎', '01', '01332', '0491454', '北海道', 'ホッカイドウ', '松前郡福島町', 'マツマエグンフクシマチョウ', '館崎', 'タテサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道松前郡福島町吉野', '01', '01332', '0491455', '北海道', 'ホッカイドウ', '松前郡福島町', 'マツマエグンフクシマチョウ', '吉野', 'ヨシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道松前郡福島町松浦', '01', '01332', '0491456', '北海道', 'ホッカイドウ', '松前郡福島町', 'マツマエグンフクシマチョウ', '松浦', 'マツウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道松前郡松前町', '01', '01331', '0491500', '北海道', 'ホッカイドウ', '松前郡松前町', 'マツマエグンマツマエチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('49578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道松前郡松前町建石', '01', '01331', '0491501', '北海道', 'ホッカイドウ', '松前郡松前町', 'マツマエグンマツマエチョウ', '建石', 'タテイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道松前郡松前町弁天', '01', '01331', '0491502', '北海道', 'ホッカイドウ', '松前郡松前町', 'マツマエグンマツマエチョウ', '弁天', 'ベンテン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道松前郡松前町大磯', '01', '01331', '0491503', '北海道', 'ホッカイドウ', '松前郡松前町', 'マツマエグンマツマエチョウ', '大磯', 'オオイソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道松前郡松前町愛宕', '01', '01331', '0491504', '北海道', 'ホッカイドウ', '松前郡松前町', 'マツマエグンマツマエチョウ', '愛宕', 'アタゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道松前郡松前町博多', '01', '01331', '0491505', '北海道', 'ホッカイドウ', '松前郡松前町', 'マツマエグンマツマエチョウ', '博多', 'ハカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道松前郡松前町唐津', '01', '01331', '0491506', '北海道', 'ホッカイドウ', '松前郡松前町', 'マツマエグンマツマエチョウ', '唐津', 'カラツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道松前郡松前町西館', '01', '01331', '0491507', '北海道', 'ホッカイドウ', '松前郡松前町', 'マツマエグンマツマエチョウ', '西館', 'ニシダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道松前郡松前町松城', '01', '01331', '0491511', '北海道', 'ホッカイドウ', '松前郡松前町', 'マツマエグンマツマエチョウ', '松城', 'マツシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道松前郡松前町福山', '01', '01331', '0491512', '北海道', 'ホッカイドウ', '松前郡松前町', 'マツマエグンマツマエチョウ', '福山', 'フクヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道松前郡松前町神明', '01', '01331', '0491513', '北海道', 'ホッカイドウ', '松前郡松前町', 'マツマエグンマツマエチョウ', '神明', 'シンメイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道松前郡松前町豊岡', '01', '01331', '0491514', '北海道', 'ホッカイドウ', '松前郡松前町', 'マツマエグンマツマエチョウ', '豊岡', 'トヨオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道松前郡松前町月島', '01', '01331', '0491515', '北海道', 'ホッカイドウ', '松前郡松前町', 'マツマエグンマツマエチョウ', '月島', 'ツキシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道松前郡松前町東山', '01', '01331', '0491516', '北海道', 'ホッカイドウ', '松前郡松前町', 'マツマエグンマツマエチョウ', '東山', 'ヒガシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道松前郡松前町朝日', '01', '01331', '0491517', '北海道', 'ホッカイドウ', '松前郡松前町', 'マツマエグンマツマエチョウ', '朝日', 'アサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道松前郡松前町上川', '01', '01331', '0491521', '北海道', 'ホッカイドウ', '松前郡松前町', 'マツマエグンマツマエチョウ', '上川', 'カミカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道松前郡松前町大沢', '01', '01331', '0491522', '北海道', 'ホッカイドウ', '松前郡松前町', 'マツマエグンマツマエチョウ', '大沢', 'オオサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道松前郡松前町荒谷', '01', '01331', '0491523', '北海道', 'ホッカイドウ', '松前郡松前町', 'マツマエグンマツマエチョウ', '荒谷', 'アラヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道松前郡松前町白神', '01', '01331', '0491524', '北海道', 'ホッカイドウ', '松前郡松前町', 'マツマエグンマツマエチョウ', '白神', 'シラカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道松前郡松前町館浜', '01', '01331', '0491641', '北海道', 'ホッカイドウ', '松前郡松前町', 'マツマエグンマツマエチョウ', '館浜', 'タテハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道松前郡松前町札前', '01', '01331', '0491642', '北海道', 'ホッカイドウ', '松前郡松前町', 'マツマエグンマツマエチョウ', '札前', 'サツマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道松前郡松前町赤神', '01', '01331', '0491643', '北海道', 'ホッカイドウ', '松前郡松前町', 'マツマエグンマツマエチョウ', '赤神', 'アカガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道松前郡松前町静浦', '01', '01331', '0491644', '北海道', 'ホッカイドウ', '松前郡松前町', 'マツマエグンマツマエチョウ', '静浦', 'シズウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道松前郡松前町茂草', '01', '01331', '0491645', '北海道', 'ホッカイドウ', '松前郡松前町', 'マツマエグンマツマエチョウ', '茂草', 'モグサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道松前郡松前町神山', '01', '01331', '0491761', '北海道', 'ホッカイドウ', '松前郡松前町', 'マツマエグンマツマエチョウ', '神山', 'カミヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道松前郡松前町原口', '01', '01331', '0491762', '北海道', 'ホッカイドウ', '松前郡松前町', 'マツマエグンマツマエチョウ', '原口', 'ハラグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道松前郡松前町白坂', '01', '01331', '0491763', '北海道', 'ホッカイドウ', '松前郡松前町', 'マツマエグンマツマエチョウ', '白坂', 'シラサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道松前郡松前町二越', '01', '01331', '0491764', '北海道', 'ホッカイドウ', '松前郡松前町', 'マツマエグンマツマエチョウ', '二越', 'フタゴエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道松前郡松前町江良', '01', '01331', '0491771', '北海道', 'ホッカイドウ', '松前郡松前町', 'マツマエグンマツマエチョウ', '江良', 'エラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道松前郡松前町大津', '01', '01331', '0491781', '北海道', 'ホッカイドウ', '松前郡松前町', 'マツマエグンマツマエチョウ', '大津', 'オオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道松前郡松前町高野', '01', '01331', '0491782', '北海道', 'ホッカイドウ', '松前郡松前町', 'マツマエグンマツマエチョウ', '高野', 'タカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道松前郡松前町清部', '01', '01331', '0491783', '北海道', 'ホッカイドウ', '松前郡松前町', 'マツマエグンマツマエチョウ', '清部', 'キヨベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道松前郡松前町小浜', '01', '01331', '0491784', '北海道', 'ホッカイドウ', '松前郡松前町', 'マツマエグンマツマエチョウ', '小浜', 'コハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市', '23', '23220', '4920000', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('49650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道茅部郡森町駒ケ岳', '01', '01345', '0492141', '北海道', 'ホッカイドウ', '茅部郡森町', 'カヤベグンモリマチ', '駒ケ岳', 'コマガタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道茅部郡森町赤井川', '01', '01345', '0492142', '北海道', 'ホッカイドウ', '茅部郡森町', 'カヤベグンモリマチ', '赤井川', 'アカイガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道茅部郡森町砂原西', '01', '01345', '0492221', '北海道', 'ホッカイドウ', '茅部郡森町', 'カヤベグンモリマチ', '砂原西', 'サワラニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道茅部郡森町砂原', '01', '01345', '0492222', '北海道', 'ホッカイドウ', '茅部郡森町', 'カヤベグンモリマチ', '砂原', 'サワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道茅部郡森町砂原東', '01', '01345', '0492223', '北海道', 'ホッカイドウ', '茅部郡森町', 'カヤベグンモリマチ', '砂原東', 'サワラヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道茅部郡森町', '01', '01345', '0492300', '北海道', 'ホッカイドウ', '茅部郡森町', 'カヤベグンモリマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('49657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道茅部郡森町尾白内町', '01', '01345', '0492301', '北海道', 'ホッカイドウ', '茅部郡森町', 'カヤベグンモリマチ', '尾白内町', 'オシロナイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道茅部郡森町港町', '01', '01345', '0492302', '北海道', 'ホッカイドウ', '茅部郡森町', 'カヤベグンモリマチ', '港町', 'ミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道茅部郡森町東森町', '01', '01345', '0492303', '北海道', 'ホッカイドウ', '茅部郡森町', 'カヤベグンモリマチ', '東森町', 'ヒガシモリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道茅部郡森町新川町', '01', '01345', '0492304', '北海道', 'ホッカイドウ', '茅部郡森町', 'カヤベグンモリマチ', '新川町', 'シンカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道茅部郡森町常盤町', '01', '01345', '0492305', '北海道', 'ホッカイドウ', '茅部郡森町', 'カヤベグンモリマチ', '常盤町', 'トキワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道茅部郡森町姫川', '01', '01345', '0492306', '北海道', 'ホッカイドウ', '茅部郡森町', 'カヤベグンモリマチ', '姫川', 'ヒメカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道茅部郡森町白川', '01', '01345', '0492307', '北海道', 'ホッカイドウ', '茅部郡森町', 'カヤベグンモリマチ', '白川', 'シラカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道茅部郡森町栄町', '01', '01345', '0492308', '北海道', 'ホッカイドウ', '茅部郡森町', 'カヤベグンモリマチ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道茅部郡森町上台町', '01', '01345', '0492311', '北海道', 'ホッカイドウ', '茅部郡森町', 'カヤベグンモリマチ', '上台町', 'ウワダイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道茅部郡森町霞台', '01', '01345', '0492312', '北海道', 'ホッカイドウ', '茅部郡森町', 'カヤベグンモリマチ', '霞台', 'カスミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道茅部郡森町森川町', '01', '01345', '0492313', '北海道', 'ホッカイドウ', '茅部郡森町', 'カヤベグンモリマチ', '森川町', 'モリカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道茅部郡森町鷲ノ木町', '01', '01345', '0492321', '北海道', 'ホッカイドウ', '茅部郡森町', 'カヤベグンモリマチ', '鷲ノ木町', 'ワシノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道茅部郡森町富士見町', '01', '01345', '0492322', '北海道', 'ホッカイドウ', '茅部郡森町', 'カヤベグンモリマチ', '富士見町', 'フジミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道茅部郡森町鳥崎町', '01', '01345', '0492323', '北海道', 'ホッカイドウ', '茅部郡森町', 'カヤベグンモリマチ', '鳥崎町', 'トリザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道茅部郡森町栗ケ丘', '01', '01345', '0492324', '北海道', 'ホッカイドウ', '茅部郡森町', 'カヤベグンモリマチ', '栗ケ丘', 'クリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道茅部郡森町本町', '01', '01345', '0492325', '北海道', 'ホッカイドウ', '茅部郡森町', 'カヤベグンモリマチ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道茅部郡森町御幸町', '01', '01345', '0492326', '北海道', 'ホッカイドウ', '茅部郡森町', 'カヤベグンモリマチ', '御幸町', 'ミユキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道茅部郡森町清澄町', '01', '01345', '0492327', '北海道', 'ホッカイドウ', '茅部郡森町', 'カヤベグンモリマチ', '清澄町', 'キヨズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道茅部郡森町三岱', '01', '01345', '0492461', '北海道', 'ホッカイドウ', '茅部郡森町', 'カヤベグンモリマチ', '三岱', 'サンタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道茅部郡森町濁川', '01', '01345', '0492462', '北海道', 'ホッカイドウ', '茅部郡森町', 'カヤベグンモリマチ', '濁川', 'ニゴリカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道茅部郡森町石倉町', '01', '01345', '0492463', '北海道', 'ホッカイドウ', '茅部郡森町', 'カヤベグンモリマチ', '石倉町', 'イシクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道茅部郡森町本茅部町', '01', '01345', '0492464', '北海道', 'ホッカイドウ', '茅部郡森町', 'カヤベグンモリマチ', '本茅部町', 'ホンカヤベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道茅部郡森町蛯谷町', '01', '01345', '0492465', '北海道', 'ホッカイドウ', '茅部郡森町', 'カヤベグンモリマチ', '蛯谷町', 'エビヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道二海郡八雲町旭丘', '01', '01346', '0492561', '北海道', 'ホッカイドウ', '二海郡八雲町', 'フタミグンヤクモチョウ', '旭丘', 'アサヒオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道二海郡八雲町落部', '01', '01346', '0492562', '北海道', 'ホッカイドウ', '二海郡八雲町', 'フタミグンヤクモチョウ', '落部', 'オトシベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道二海郡八雲町栄浜', '01', '01346', '0492563', '北海道', 'ホッカイドウ', '二海郡八雲町', 'フタミグンヤクモチョウ', '栄浜', 'サカエハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道二海郡八雲町入沢', '01', '01346', '0492564', '北海道', 'ホッカイドウ', '二海郡八雲町', 'フタミグンヤクモチョウ', '入沢', 'イリサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道二海郡八雲町下の湯', '01', '01346', '0492565', '北海道', 'ホッカイドウ', '二海郡八雲町', 'フタミグンヤクモチョウ', '下の湯', 'シモノユ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道二海郡八雲町上の湯', '01', '01346', '0492566', '北海道', 'ホッカイドウ', '二海郡八雲町', 'フタミグンヤクモチョウ', '上の湯', 'カミノユ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道二海郡八雲町山越', '01', '01346', '0492671', '北海道', 'ホッカイドウ', '二海郡八雲町', 'フタミグンヤクモチョウ', '山越', 'ヤマコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道二海郡八雲町野田生', '01', '01346', '0492672', '北海道', 'ホッカイドウ', '二海郡八雲町', 'フタミグンヤクモチョウ', '野田生', 'ノダオイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道二海郡八雲町東野', '01', '01346', '0492673', '北海道', 'ホッカイドウ', '二海郡八雲町', 'フタミグンヤクモチョウ', '東野', 'ヒガシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道二海郡八雲町わらび野', '01', '01346', '0492674', '北海道', 'ホッカイドウ', '二海郡八雲町', 'フタミグンヤクモチョウ', 'わらび野', 'ワラビノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道二海郡八雲町桜野', '01', '01346', '0492675', '北海道', 'ホッカイドウ', '二海郡八雲町', 'フタミグンヤクモチョウ', '桜野', 'サクラノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市赤池池田町', '23', '23220', '4928001', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '赤池池田町', 'アカイケイケダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市赤池居道町', '23', '23220', '4928002', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '赤池居道町', 'アカイケイミチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市赤池西出町', '23', '23220', '4928003', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '赤池西出町', 'アカイケニシデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市赤池裏田町', '23', '23220', '4928004', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '赤池裏田町', 'アカイケウラダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市赤池陣出町', '23', '23220', '4928005', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '赤池陣出町', 'アカイケジンデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市赤池真崎町', '23', '23220', '4928006', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '赤池真崎町', 'アカイケマツサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市赤池山中町', '23', '23220', '4928007', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '赤池山中町', 'アカイケヤマナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市赤池町', '23', '23220', '4928008', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '赤池町', 'アカイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市赤池前山町', '23', '23220', '4928011', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '赤池前山町', 'アカイケマエヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市赤池天王町', '23', '23220', '4928012', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '赤池天王町', 'アカイケテンノウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市赤池寺東町', '23', '23220', '4928013', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '赤池寺東町', 'アカイケテラヒガシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市赤池北町', '23', '23220', '4928014', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '赤池北町', 'アカイケキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市赤池北池田町', '23', '23220', '4928015', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '赤池北池田町', 'アカイケキタイケダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市赤池宮西町', '23', '23220', '4928016', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '赤池宮西町', 'アカイケミヤニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市赤池旗屋町', '23', '23220', '4928017', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '赤池旗屋町', 'アカイケハタヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市赤池東山町', '23', '23220', '4928021', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '赤池東山町', 'アカイケヒガシヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市赤池坂畑町', '23', '23220', '4928022', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '赤池坂畑町', 'アカイケサカハタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市赤池広畑町', '23', '23220', '4928023', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '赤池広畑町', 'アカイケヒロハタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市赤池南町', '23', '23220', '4928024', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '赤池南町', 'アカイケミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市赤池中町', '23', '23220', '4928025', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '赤池中町', 'アカイケナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市陸田高畑町', '23', '23220', '4928031', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '陸田高畑町', 'クガタタカバタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市陸田東出町', '23', '23220', '4928032', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '陸田東出町', 'クガタヒガシデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市陸田一里山町', '23', '23220', '4928033', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '陸田一里山町', 'クガタイチリヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市陸田栗林町', '23', '23220', '4928034', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '陸田栗林町', 'クガタクリバヤシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市陸田宮前町', '23', '23220', '4928035', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '陸田宮前町', 'クガタミヤマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市陸田本町', '23', '23220', '4928036', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '陸田本町', 'クガタホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市陸田白山町', '23', '23220', '4928037', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '陸田白山町', 'クガタハクサンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市陸田町', '23', '23220', '4928038', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '陸田町', 'クガタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市陸田丸之内町', '23', '23220', '4928041', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '陸田丸之内町', 'クガタマルノウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市陸田花塚町', '23', '23220', '4928042', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '陸田花塚町', 'クガタハナヅカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市陸田馬山町', '23', '23220', '4928043', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '陸田馬山町', 'クガタウマヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市下津光明寺町', '23', '23220', '4928051', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '下津光明寺町', 'オリヅコウミョウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市下津ふじ塚町', '23', '23220', '4928052', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '下津ふじ塚町', 'オリヅフジツカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市下津蛇池町', '23', '23220', '4928053', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '下津蛇池町', 'オリヅジャイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市下津片町', '23', '23220', '4928054', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '下津片町', 'オリヅカタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市下津穂所町', '23', '23220', '4928055', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '下津穂所町', 'オリヅホドコロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市下津鞍掛町', '23', '23220', '4928056', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '下津鞍掛町', 'オリヅクラカケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市下津長田町', '23', '23220', '4928057', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '下津長田町', 'オリヅナガタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市下津牛洗町', '23', '23220', '4928058', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '下津牛洗町', 'オリヅウシアライチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市下津高戸町', '23', '23220', '4928061', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '下津高戸町', 'オリヅタカドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市下津住吉町', '23', '23220', '4928062', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '下津住吉町', 'オリヅスミヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市下津矢口町', '23', '23220', '4928063', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '下津矢口町', 'オリヅヤグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市下津二本杉町', '23', '23220', '4928064', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '下津二本杉町', 'オリヅニホンスギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市下津大門町', '23', '23220', '4928065', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '下津大門町', 'オリヅダイモンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市下津新町', '23', '23220', '4928066', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '下津新町', 'オリヅシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市下津北山町', '23', '23220', '4928067', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '下津北山町', 'オリヅキタヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市下津小井戸町', '23', '23220', '4928068', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '下津小井戸町', 'オリヅコイドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市下津本郷町', '23', '23220', '4928071', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '下津本郷町', 'オリヅホンゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市下津北信正寺町', '23', '23220', '4928072', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '下津北信正寺町', 'オリヅキタシンショウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市下津南信正寺町', '23', '23220', '4928073', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '下津南信正寺町', 'オリヅミナミシンショウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市下津下町東', '23', '23220', '4928074', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '下津下町東', 'オリヅシモマチヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市下津町', '23', '23220', '4928075', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '下津町', 'オリヅチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市下津宮西町', '23', '23220', '4928076', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '下津宮西町', 'オリヅミヤニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市下津土山町', '23', '23220', '4928077', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '下津土山町', 'オリヅドヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市下津寺前町', '23', '23220', '4928078', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '下津寺前町', 'オリヅテラマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市下津油田町', '23', '23220', '4928081', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '下津油田町', 'オリヅアブラデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市下津下町西', '23', '23220', '4928082', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '下津下町西', 'オリヅシモマチニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市下津森町', '23', '23220', '4928083', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '下津森町', 'オリヅモリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市下津南山町', '23', '23220', '4928084', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '下津南山町', 'オリヅミナミヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市下津丹下田町', '23', '23220', '4928085', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '下津丹下田町', 'オリヅタンゲダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市子生和池田町', '23', '23220', '4928101', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '子生和池田町', 'コウワイケダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市子生和神明町', '23', '23220', '4928102', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '子生和神明町', 'コウワシンメイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市子生和溝師町', '23', '23220', '4928103', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '子生和溝師町', 'コウワミゾシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市子生和八島町', '23', '23220', '4928104', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '子生和八島町', 'コウワヤシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市子生和円場町', '23', '23220', '4928105', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '子生和円場町', 'コウワエンバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市子生和町', '23', '23220', '4928106', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '子生和町', 'コウワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市子生和住吉町', '23', '23220', '4928107', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '子生和住吉町', 'コウワスミヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市子生和子安賀町', '23', '23220', '4928108', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '子生和子安賀町', 'コウワコヤスガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市子生和山王町', '23', '23220', '4928109', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '子生和山王町', 'コウワサンノウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市子生和小原町', '23', '23220', '4928111', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '子生和小原町', 'コウワコハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市子生和坂田町', '23', '23220', '4928112', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '子生和坂田町', 'コウワサカタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市治郎丸神木町', '23', '23220', '4928113', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '治郎丸神木町', 'ジロマルシンボクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市治郎丸椿町', '23', '23220', '4928114', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '治郎丸椿町', 'ジロマルツバキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市治郎丸東町', '23', '23220', '4928115', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '治郎丸東町', 'ジロマルヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市治郎丸西町', '23', '23220', '4928116', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '治郎丸西町', 'ジロマルニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市治郎丸高須町', '23', '23220', '4928117', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '治郎丸高須町', 'ジロマルタカスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市治郎丸北町', '23', '23220', '4928118', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '治郎丸北町', 'ジロマルキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市治郎丸大明町', '23', '23220', '4928119', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '治郎丸大明町', 'ジロマルダイミョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市治郎丸柳町', '23', '23220', '4928121', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '治郎丸柳町', 'ジロマルヤナギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市治郎丸元町', '23', '23220', '4928122', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '治郎丸元町', 'ジロマルモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市治郎丸白山町', '23', '23220', '4928123', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '治郎丸白山町', 'ジロマルハクサンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市治郎丸土井町', '23', '23220', '4928124', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '治郎丸土井町', 'ジロマルドイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市治郎丸清敷町', '23', '23220', '4928125', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '治郎丸清敷町', 'ジロマルセイシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市治郎丸郷前町', '23', '23220', '4928126', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '治郎丸郷前町', 'ジロマルゴウマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市治郎丸南町', '23', '23220', '4928127', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '治郎丸南町', 'ジロマルミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市治郎丸中町', '23', '23220', '4928128', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '治郎丸中町', 'ジロマルナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市治郎丸古江町', '23', '23220', '4928131', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '治郎丸古江町', 'ジロマルフルエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市治郎丸天神町', '23', '23220', '4928132', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '治郎丸天神町', 'ジロマルテンジンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市治郎丸細道町', '23', '23220', '4928133', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '治郎丸細道町', 'ジロマルホソミチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市治郎丸大角町', '23', '23220', '4928134', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '治郎丸大角町', 'ジロマルオオスミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市治郎丸石塚町', '23', '23220', '4928135', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '治郎丸石塚町', 'ジロマルイシヅカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市小池正明寺北街道', '23', '23220', '4928136', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '小池正明寺北街道', 'コイケショウメイジキタカイドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市国府宮', '23', '23220', '4928137', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '国府宮', 'コウノミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市国府宮町', '23', '23220', '4928138', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '国府宮町', 'コウノミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市国府宮神田町', '23', '23220', '4928139', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '国府宮神田町', 'コウノミヤジンデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市長野町', '23', '23220', '4928141', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '長野町', 'ナガノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市長野', '23', '23220', '4928142', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '長野', 'ナガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市駅前', '23', '23220', '4928143', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '駅前', 'エキマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市小池', '23', '23220', '4928144', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '小池', 'コイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市正明寺', '23', '23220', '4928145', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '正明寺', 'ショウメイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市御供所町', '23', '23220', '4928146', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '御供所町', 'ゴクショチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市小池正明寺町', '23', '23220', '4928147', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '小池正明寺町', 'コイケショウメイジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市井之口北畑町', '23', '23220', '4928151', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '井之口北畑町', 'イノクチキタバタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市井之口大宮町', '23', '23220', '4928152', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '井之口大宮町', 'イノクチオオミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市井之口町', '23', '23220', '4928153', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '井之口町', 'イノクチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市井之口本町', '23', '23220', '4928154', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '井之口本町', 'イノクチホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市井之口四家町', '23', '23220', '4928155', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '井之口四家町', 'イノクチヨツヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市井之口親畑町', '23', '23220', '4928156', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '井之口親畑町', 'イノクチオヤバタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市井之口柿ノ木町', '23', '23220', '4928157', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '井之口柿ノ木町', 'イノクチカキノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市井之口白山町', '23', '23220', '4928158', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '井之口白山町', 'イノクチハクサンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市菱町', '23', '23220', '4928161', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '菱町', 'ヒシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市井之口小番戸町', '23', '23220', '4928162', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '井之口小番戸町', 'イノクチコバンドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市井之口石塚町', '23', '23220', '4928163', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '井之口石塚町', 'イノクチイシヅカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市井之口大坪町', '23', '23220', '4928164', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '井之口大坪町', 'イノクチオオツボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市井之口鶴田町', '23', '23220', '4928165', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '井之口鶴田町', 'イノクチツルデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市井之口沖ノ田町', '23', '23220', '4928166', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '井之口沖ノ田町', 'イノクチオキノタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市長束町', '23', '23220', '4928167', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '長束町', 'ナヅカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市六角堂西町', '23', '23220', '4928171', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '六角堂西町', 'ロッカクドウニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市六角堂東町', '23', '23220', '4928172', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '六角堂東町', 'ロッカクドウヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市北市場町', '23', '23220', '4928173', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '北市場町', 'キタイチバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市北市場西町', '23', '23220', '4928174', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '北市場西町', 'キタイチバニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市北市場南町', '23', '23220', '4928175', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '北市場南町', 'キタイチバミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市日下部花ノ木町', '23', '23220', '4928176', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '日下部花ノ木町', 'クサカベハナノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市日下部東町', '23', '23220', '4928177', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '日下部東町', 'クサカベヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市日下部北町', '23', '23220', '4928181', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '日下部北町', 'クサカベキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市日下部中町', '23', '23220', '4928182', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '日下部中町', 'クサカベナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市日下部南町', '23', '23220', '4928183', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '日下部南町', 'クサカベミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市日下部松野町', '23', '23220', '4928184', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '日下部松野町', 'クサカベマツノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市日下部西町', '23', '23220', '4928185', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '日下部西町', 'クサカベニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市日下部町', '23', '23220', '4928186', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '日下部町', 'クサカベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市島子安賀町', '23', '23220', '4928201', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '島子安賀町', 'シマコヤスカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市島東之郷町', '23', '23220', '4928202', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '島東之郷町', 'シマヒガシノゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市島小原町', '23', '23220', '4928203', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '島小原町', 'シマコハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市島高須賀町', '23', '23220', '4928204', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '島高須賀町', 'シマタカスカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市島町', '23', '23220', '4928205', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '島町', 'シマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市稲島法成寺町', '23', '23220', '4928206', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '稲島法成寺町', 'イナジマホウジョウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市稲島町', '23', '23220', '4928207', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '稲島町', 'イナジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市松下', '23', '23220', '4928208', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '松下', 'マツシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市木全町', '23', '23220', '4928209', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '木全町', 'キマタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市木全', '23', '23220', '4928210', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '木全', 'キマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市稲沢町北山', '23', '23220', '4928211', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '稲沢町北山', 'イナザワチョウキタヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市小沢', '23', '23220', '4928212', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '小沢', 'コザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市高御堂', '23', '23220', '4928213', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '高御堂', 'タカミドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市大塚南', '23', '23220', '4928214', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '大塚南', 'オオツカミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市大塚北', '23', '23220', '4928215', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '大塚北', 'オオツカキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市大塚町', '23', '23220', '4928216', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '大塚町', 'オオツカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市稲沢町', '23', '23220', '4928217', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '稲沢町', 'イナザワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市西町', '23', '23220', '4928218', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '西町', 'ニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市稲葉', '23', '23220', '4928219', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '稲葉', 'イナバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市前田', '23', '23220', '4928220', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '前田', 'マエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市幸町', '23', '23220', '4928221', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市奥田天目寺町', '23', '23220', '4928222', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '奥田天目寺町', 'オクダテンモクジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市奥田井之下町', '23', '23220', '4928223', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '奥田井之下町', 'オクダイノシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市奥田大沢町', '23', '23220', '4928224', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '奥田大沢町', 'オクダオオサワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市奥田膳棚町', '23', '23220', '4928225', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '奥田膳棚町', 'オクダゼンタナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市奥田大門町', '23', '23220', '4928226', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '奥田大門町', 'オクダダイモンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市奥田白山町', '23', '23220', '4928227', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '奥田白山町', 'オクダハクサンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市奥田長角町', '23', '23220', '4928228', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '奥田長角町', 'オクダナガスミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市稲島', '23', '23220', '4928229', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '稲島', 'イナジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市稲島東', '23', '23220', '4928230', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '稲島東', 'イナジマヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市奥田流町', '23', '23220', '4928231', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '奥田流町', 'オクダナガレチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市奥田酒伊町', '23', '23220', '4928232', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '奥田酒伊町', 'オクダサカイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市奥田町', '23', '23220', '4928233', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '奥田町', 'オクダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市奥田切田町', '23', '23220', '4928234', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '奥田切田町', 'オクダキリタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市奥田立長町', '23', '23220', '4928235', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '奥田立長町', 'オクダタテオサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市奥田寺切町', '23', '23220', '4928236', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '奥田寺切町', 'オクダテラギリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市奥田馬場町', '23', '23220', '4928237', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '奥田馬場町', 'オクダバンバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市奥田堀畑町', '23', '23220', '4928238', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '奥田堀畑町', 'オクダホリバタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市奥田中切町', '23', '23220', '4928239', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '奥田中切町', 'オクダナカキリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市奥田田畑町', '23', '23220', '4928241', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '奥田田畑町', 'オクダタバタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市奥田町田畑切', '23', '23220', '4928242', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '奥田町田畑切', 'オクダチョウタバタキリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市奥田町文七西', '23', '23220', '4928242', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '奥田町文七西', 'オクダチョウブンヒチニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市奥田木塚町', '23', '23220', '4928243', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '奥田木塚町', 'オクダキヅカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市奥田下河町', '23', '23220', '4928244', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '奥田下河町', 'オクダシモカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市奥田南花ノ木町', '23', '23220', '4928245', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '奥田南花ノ木町', 'オクダミナミハナノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市奥田計用町', '23', '23220', '4928246', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '奥田計用町', 'オクダケイヨウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市東緑町', '23', '23220', '4928251', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '東緑町', 'ヒガシミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市緑町', '23', '23220', '4928252', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '緑町', 'ミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市奥田神ノ木町', '23', '23220', '4928253', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '奥田神ノ木町', 'オクダカミノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市奥田宮長町', '23', '23220', '4928254', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '奥田宮長町', 'オクダミヤナガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市奥田天神町', '23', '23220', '4928255', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '奥田天神町', 'オクダテンジンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市奥田北花ノ木町', '23', '23220', '4928256', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '奥田北花ノ木町', 'オクダキタハナノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市奥田島崎町', '23', '23220', '4928257', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '奥田島崎町', 'オクダシマザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市重本', '23', '23220', '4928261', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '重本', 'シゲモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市池部町', '23', '23220', '4928262', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '池部町', 'イケベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市平野', '23', '23220', '4928263', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '平野', 'ヒラノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市平野町', '23', '23220', '4928264', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '平野町', 'ヒラノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市小寺町', '23', '23220', '4928265', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '小寺町', 'コデラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市横地', '23', '23220', '4928266', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '横地', 'ヨコチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市船橋町', '23', '23220', '4928267', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '船橋町', 'フナバシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市朝府町', '23', '23220', '4928268', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '朝府町', 'アザブチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市稲府町', '23', '23220', '4928269', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '稲府町', 'イナブチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市石橋', '23', '23220', '4928271', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '石橋', 'イシバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市桜木', '23', '23220', '4928272', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '桜木', 'サクラギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市桜木宮前町', '23', '23220', '4928273', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '桜木宮前町', 'サクラギミヤマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市天池光田町', '23', '23220', '4928274', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '天池光田町', 'アマイケコウダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市天池五反田町', '23', '23220', '4928275', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '天池五反田町', 'アマイケゴタンダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市天池町', '23', '23220', '4928276', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '天池町', 'アマイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市天池牧作町', '23', '23220', '4928277', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '天池牧作町', 'アマイケマキツクリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市天池金山町', '23', '23220', '4928278', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '天池金山町', 'アマイケカナヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市天池遠松町', '23', '23220', '4928279', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '天池遠松町', 'アマイケトオマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市天池伝代町', '23', '23220', '4928281', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '天池伝代町', 'アマイケデンダイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市天池東町', '23', '23220', '4928282', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '天池東町', 'アマイケヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市天池浪寄町', '23', '23220', '4928283', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '天池浪寄町', 'アマイケナミヨセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市天池西町', '23', '23220', '4928284', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '天池西町', 'アマイケニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市竹腰東町', '23', '23220', '4928285', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '竹腰東町', 'タケノコシヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市竹腰中町', '23', '23220', '4928286', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '竹腰中町', 'タケノコシナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市竹腰西町', '23', '23220', '4928287', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '竹腰西町', 'タケノコシニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市竹腰北町', '23', '23220', '4928288', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '竹腰北町', 'タケノコシキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市竹腰本町', '23', '23220', '4928289', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '竹腰本町', 'タケノコシホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市生出本町', '23', '23220', '4928301', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '生出本町', 'ハイデホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市生出西道根町', '23', '23220', '4928302', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '生出西道根町', 'ハイデニシドウネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市生出東道根町', '23', '23220', '4928303', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '生出東道根町', 'ハイデヒガシドウネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市生出山田町', '23', '23220', '4928304', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '生出山田町', 'ハイデヤマダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市生出郷前町', '23', '23220', '4928305', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '生出郷前町', 'ハイデゴウマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市生出横西町', '23', '23220', '4928306', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '生出横西町', 'ハイデヨコニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市生出上山町', '23', '23220', '4928307', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '生出上山町', 'ハイデカミヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市生出河戸町', '23', '23220', '4928308', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '生出河戸町', 'ハイデコエドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市下屋', '23', '23220', '4928310', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '下屋', 'シモヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市清水西川原町', '23', '23220', '4928311', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '清水西川原町', 'シミズニシカワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市清水八尻町', '23', '23220', '4928312', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '清水八尻町', 'シミズハチジリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市清水阿原町', '23', '23220', '4928313', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '清水阿原町', 'シミズアワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市清水町', '23', '23220', '4928314', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '清水町', 'シミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市清水郷西町', '23', '23220', '4928315', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '清水郷西町', 'シミズゴウニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市清水寺前町', '23', '23220', '4928316', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '清水寺前町', 'シミズテラマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市清水八神町', '23', '23220', '4928317', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '清水八神町', 'シミズヤガミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市浅井町', '23', '23220', '4928318', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '浅井町', 'アサイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市下屋町', '23', '23220', '4928319', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '下屋町', 'シモヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市西島北町', '23', '23220', '4928321', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '西島北町', 'ニシジマキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市西島出町', '23', '23220', '4928322', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '西島出町', 'ニシジマデマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市西島新町', '23', '23220', '4928323', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '西島新町', 'ニシジマシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市西島東町', '23', '23220', '4928325', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '西島東町', 'ニシジマヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市西島本町', '23', '23220', '4928326', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '西島本町', 'ニシジマホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市西島中町', '23', '23220', '4928327', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '西島中町', 'ニシジマナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市西島', '23', '23220', '4928328', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '西島', 'ニシジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市西島町', '23', '23220', '4928329', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '西島町', 'ニシジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市平佛供田町', '23', '23220', '4928331', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '平佛供田町', 'タイラブクデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市平尾苅町', '23', '23220', '4928332', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '平尾苅町', 'タイラオガリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市平蜂ノ坪町', '23', '23220', '4928333', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '平蜂ノ坪町', 'タイラハチノツボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市平高道町', '23', '23220', '4928334', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '平高道町', 'タイラタカミチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市法花寺町', '23', '23220', '4928335', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '法花寺町', 'ホッケジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市平苅田町', '23', '23220', '4928336', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '平苅田町', 'タイラカリタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市平細工蔵町', '23', '23220', '4928337', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '平細工蔵町', 'タイラサイクゾウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市平金森町', '23', '23220', '4928338', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '平金森町', 'タイラカナモリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市平江向町', '23', '23220', '4928339', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '平江向町', 'タイラエムカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市馬場町', '23', '23220', '4928341', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '馬場町', 'バンバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市矢合町', '23', '23220', '4928342', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '矢合町', 'ヤワセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市儀長町', '23', '23220', '4928343', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '儀長町', 'ギチョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市山口南町', '23', '23220', '4928344', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '山口南町', 'ヤマグチミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市山口宮前町', '23', '23220', '4928345', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '山口宮前町', 'ヤマグチミヤマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市山口本町', '23', '23220', '4928346', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '山口本町', 'ヤマグチホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市山口町', '23', '23220', '4928347', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '山口町', 'ヤマグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市馬場', '23', '23220', '4928348', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '馬場', 'バンバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市一色竹橋町', '23', '23220', '4928351', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '一色竹橋町', 'イシキタケハシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市一色神宮町', '23', '23220', '4928352', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '一色神宮町', 'イシキジングウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市一色藤塚町', '23', '23220', '4928353', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '一色藤塚町', 'イシキフジツカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市一色三反田町', '23', '23220', '4928354', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '一色三反田町', 'イシキサンタンダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市片原一色町', '23', '23220', '4928355', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '片原一色町', 'カタハライシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市一色市場町', '23', '23220', '4928356', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '一色市場町', 'イシキイチバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市一色道上町', '23', '23220', '4928357', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '一色道上町', 'イシキミチカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市一色白山町', '23', '23220', '4928358', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '一色白山町', 'イシキハクサンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市一色長畑町', '23', '23220', '4928361', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '一色長畑町', 'イシキナガハタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市一色青海町', '23', '23220', '4928362', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '一色青海町', 'イシキアオカイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市一色跡之口町', '23', '23220', '4928363', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '一色跡之口町', 'イシキアトノクチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市一色森山町', '23', '23220', '4928364', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '一色森山町', 'イシキモリヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市一色下方町', '23', '23220', '4928365', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '一色下方町', 'イシキシモカタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市一色川俣町', '23', '23220', '4928366', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '一色川俣町', 'イシキカワマタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市一色上方町', '23', '23220', '4928371', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '一色上方町', 'イシキカミガタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市一色中屋敷町', '23', '23220', '4928372', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '一色中屋敷町', 'イシキナカヤシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市一色中通町', '23', '23220', '4928373', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '一色中通町', 'イシキナカドオリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市一色西町', '23', '23220', '4928374', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '一色西町', 'イシキニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市一色巡見町', '23', '23220', '4928375', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '一色巡見町', 'イシキジュンケンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市横野西郷町', '23', '23220', '4928381', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '横野西郷町', 'ヨコノニシゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市横野堂根町', '23', '23220', '4928382', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '横野堂根町', 'ヨコノドウネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市横野東出町', '23', '23220', '4928383', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '横野東出町', 'ヨコノヒガシデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市横野東郷町', '23', '23220', '4928384', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '横野東郷町', 'ヨコノヒガシゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市横野河原町', '23', '23220', '4928385', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '横野河原町', 'ヨコノカワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市横野松前町', '23', '23220', '4928386', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '横野松前町', 'ヨコノマツマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市横野神田町', '23', '23220', '4928387', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '横野神田町', 'ヨコノジンデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市横野境塚町', '23', '23220', '4928388', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '横野境塚町', 'ヨコノサカイヅカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市横野町', '23', '23220', '4928389', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '横野町', 'ヨコノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市中野川端町', '23', '23220', '4928391', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '中野川端町', 'ナカノカワバタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市中野元町', '23', '23220', '4928392', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '中野元町', 'ナカノモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市中野宮町', '23', '23220', '4928393', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '中野宮町', 'ナカノミヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市梅須賀町', '23', '23220', '4928401', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '梅須賀町', 'メスカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市千代町', '23', '23220', '4928402', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '千代町', 'センダイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市千代', '23', '23220', '4928403', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '千代', 'センダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市千代西町', '23', '23220', '4928404', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '千代西町', 'センダイニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市堀之内町', '23', '23220', '4928405', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '堀之内町', 'ホリノウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市井堀大縄町', '23', '23220', '4928406', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '井堀大縄町', 'イボリオオナワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市井堀宿塚町', '23', '23220', '4928407', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '井堀宿塚町', 'イボリシュクヅカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市井堀川東町', '23', '23220', '4928408', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '井堀川東町', 'イボリカワヒガシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市井堀橋下町', '23', '23220', '4928409', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '井堀橋下町', 'イボリハシシモチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市北島', '23', '23220', '4928410', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '北島', 'キタジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市北島町', '23', '23220', '4928411', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '北島町', 'キタジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市大矢町', '23', '23220', '4928412', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '大矢町', 'オオヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市大矢江西町', '23', '23220', '4928413', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '大矢江西町', 'オオヤエニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市大矢浄土寺町', '23', '23220', '4928414', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '大矢浄土寺町', 'オオヤジョウドジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市大矢青山町', '23', '23220', '4928415', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '大矢青山町', 'オオヤアオヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市大矢白山町', '23', '23220', '4928416', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '大矢白山町', 'オオヤシロヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市大矢仙口町', '23', '23220', '4928417', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '大矢仙口町', 'オオヤセングチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市大矢高田町', '23', '23220', '4928418', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '大矢高田町', 'オオヤコウダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市大矢真宮町', '23', '23220', '4928419', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '大矢真宮町', 'オオヤシングウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市高重西町', '23', '23220', '4928421', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '高重西町', 'タカシゲニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市高重町', '23', '23220', '4928422', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '高重町', 'タカシゲチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('49999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市高重中町', '23', '23220', '4928423', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '高重中町', 'タカシゲナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市高重東町', '23', '23220', '4928424', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '高重東町', 'タカシゲヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市増田北町', '23', '23220', '4928425', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '増田北町', 'マシタキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市増田東町', '23', '23220', '4928426', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '増田東町', 'マシタヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市増田南町', '23', '23220', '4928427', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '増田南町', 'マシタミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市増田町', '23', '23220', '4928428', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '増田町', 'マシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市増田西町', '23', '23220', '4928429', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '増田西町', 'マシタニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市中之庄高畑町', '23', '23220', '4928431', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '中之庄高畑町', 'ナカノショウタカバタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市中之庄半田町', '23', '23220', '4928432', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '中之庄半田町', 'ナカノショウハンダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市中之庄元屋敷町', '23', '23220', '4928433', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '中之庄元屋敷町', 'ナカノショウモトヤシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市中之庄堤畔町', '23', '23220', '4928434', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '中之庄堤畔町', 'ナカノショウツツミグロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市中之庄町', '23', '23220', '4928435', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '中之庄町', 'ナカノショウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市中之庄海道町', '23', '23220', '4928436', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '中之庄海道町', 'ナカノショウカイドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市中之庄長堤町', '23', '23220', '4928437', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '中之庄長堤町', 'ナカノショウナガツツミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市堀田町', '23', '23220', '4928438', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '堀田町', 'ホッタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市七ツ寺町', '23', '23220', '4928439', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '七ツ寺町', 'ナナツデラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市福島町', '23', '23220', '4928441', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '福島町', 'フクジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市附島町', '23', '23220', '4928442', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '附島町', 'ツケシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市牛踏町', '23', '23220', '4928443', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '牛踏町', 'ウシブミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市込野町', '23', '23220', '4928444', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '込野町', 'コミノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市南麻績町', '23', '23220', '4928445', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '南麻績町', 'ミナミオウミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市目比町', '23', '23220', '4928446', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '目比町', 'ムクイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市野崎町', '23', '23220', '4928447', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '野崎町', 'ノサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市北麻績町', '23', '23220', '4928448', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '北麻績町', 'キタオウミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市板葺町', '23', '23220', '4928451', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '板葺町', 'イタブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市西溝口町', '23', '23220', '4928452', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '西溝口町', 'ニシミゾグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市今村町', '23', '23220', '4928453', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '今村町', 'イマムラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市坂田町', '23', '23220', '4928454', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '坂田町', 'サカタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市田代', '23', '23220', '4928455', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '田代', 'タシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市氷室町', '23', '23220', '4928456', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '氷室町', 'ヒムロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市井堀北出町', '23', '23220', '4928461', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '井堀北出町', 'イボリキタデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市井堀高見町', '23', '23220', '4928462', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '井堀高見町', 'イボリタカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市井堀中郷町', '23', '23220', '4928463', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '井堀中郷町', 'イボリナカゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市井堀下郷町', '23', '23220', '4928464', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '井堀下郷町', 'イボリシモゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市井堀犬城町', '23', '23220', '4928465', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '井堀犬城町', 'イボリイヌシロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市井堀江西町', '23', '23220', '4928466', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '井堀江西町', 'イボリエニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市井堀蒲六町', '23', '23220', '4928467', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '井堀蒲六町', 'イボリガマロクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市井堀野口町', '23', '23220', '4928468', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '井堀野口町', 'イボリノグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市木曽川町黒田', '23', '23203', '4930001', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '木曽川町黒田', 'キソガワチョウクロダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市木曽川町門間', '23', '23203', '4930002', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '木曽川町門間', 'キソガワチョウカドマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市木曽川町三ツ法寺', '23', '23203', '4930003', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '木曽川町三ツ法寺', 'キソガワチョウミツホウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市木曽川町玉ノ井', '23', '23203', '4930004', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '木曽川町玉ノ井', 'キソガワチョウタマノイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市木曽川町里小牧', '23', '23203', '4930005', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '木曽川町里小牧', 'キソガワチョウサトコマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市木曽川町内割田', '23', '23203', '4930006', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '木曽川町内割田', 'キソガワチョウウチワリデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市木曽川町外割田', '23', '23203', '4930007', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '木曽川町外割田', 'キソガワチョウソトワリデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道二海郡八雲町', '01', '01346', '0493100', '北海道', 'ホッカイドウ', '二海郡八雲町', 'フタミグンヤクモチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('50078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道二海郡八雲町元町', '01', '01346', '0493101', '北海道', 'ホッカイドウ', '二海郡八雲町', 'フタミグンヤクモチョウ', '元町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道二海郡八雲町東町', '01', '01346', '0493102', '北海道', 'ホッカイドウ', '二海郡八雲町', 'フタミグンヤクモチョウ', '東町', 'ヒガシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道二海郡八雲町豊河町', '01', '01346', '0493103', '北海道', 'ホッカイドウ', '二海郡八雲町', 'フタミグンヤクモチョウ', '豊河町', 'トヨカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道二海郡八雲町内浦町', '01', '01346', '0493104', '北海道', 'ホッカイドウ', '二海郡八雲町', 'フタミグンヤクモチョウ', '内浦町', 'ウチウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道二海郡八雲町東雲町', '01', '01346', '0493105', '北海道', 'ホッカイドウ', '二海郡八雲町', 'フタミグンヤクモチョウ', '東雲町', 'シノノメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道二海郡八雲町富士見町', '01', '01346', '0493106', '北海道', 'ホッカイドウ', '二海郡八雲町', 'フタミグンヤクモチョウ', '富士見町', 'フジミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道二海郡八雲町本町', '01', '01346', '0493107', '北海道', 'ホッカイドウ', '二海郡八雲町', 'フタミグンヤクモチョウ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道二海郡八雲町住初町', '01', '01346', '0493111', '北海道', 'ホッカイドウ', '二海郡八雲町', 'フタミグンヤクモチョウ', '住初町', 'スミゾメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道二海郡八雲町末広町', '01', '01346', '0493112', '北海道', 'ホッカイドウ', '二海郡八雲町', 'フタミグンヤクモチョウ', '末広町', 'スエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道二海郡八雲町相生町', '01', '01346', '0493113', '北海道', 'ホッカイドウ', '二海郡八雲町', 'フタミグンヤクモチョウ', '相生町', 'アイオイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道二海郡八雲町三杉町', '01', '01346', '0493114', '北海道', 'ホッカイドウ', '二海郡八雲町', 'フタミグンヤクモチョウ', '三杉町', 'ミスギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道二海郡八雲町出雲町', '01', '01346', '0493115', '北海道', 'ホッカイドウ', '二海郡八雲町', 'フタミグンヤクモチョウ', '出雲町', 'イズモチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道二海郡八雲町宮園町', '01', '01346', '0493116', '北海道', 'ホッカイドウ', '二海郡八雲町', 'フタミグンヤクモチョウ', '宮園町', 'ミヤゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道二海郡八雲町栄町', '01', '01346', '0493117', '北海道', 'ホッカイドウ', '二海郡八雲町', 'フタミグンヤクモチョウ', '栄町', 'サカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道二海郡八雲町緑町', '01', '01346', '0493118', '北海道', 'ホッカイドウ', '二海郡八雲町', 'フタミグンヤクモチョウ', '緑町', 'ミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道二海郡八雲町上八雲', '01', '01346', '0493121', '北海道', 'ホッカイドウ', '二海郡八雲町', 'フタミグンヤクモチョウ', '上八雲', 'カミヤクモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道二海郡八雲町富咲', '01', '01346', '0493121', '北海道', 'ホッカイドウ', '二海郡八雲町', 'フタミグンヤクモチョウ', '富咲', 'トミサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道二海郡八雲町花浦', '01', '01346', '0493122', '北海道', 'ホッカイドウ', '二海郡八雲町', 'フタミグンヤクモチョウ', '花浦', 'ハナウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道二海郡八雲町立岩', '01', '01346', '0493123', '北海道', 'ホッカイドウ', '二海郡八雲町', 'フタミグンヤクモチョウ', '立岩', 'タテイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道二海郡八雲町浜松', '01', '01346', '0493124', '北海道', 'ホッカイドウ', '二海郡八雲町', 'フタミグンヤクモチョウ', '浜松', 'ハママツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道二海郡八雲町熱田', '01', '01346', '0493125', '北海道', 'ホッカイドウ', '二海郡八雲町', 'フタミグンヤクモチョウ', '熱田', 'アツタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道二海郡八雲町大新', '01', '01346', '0493126', '北海道', 'ホッカイドウ', '二海郡八雲町', 'フタミグンヤクモチョウ', '大新', 'オオシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道二海郡八雲町春日', '01', '01346', '0493127', '北海道', 'ホッカイドウ', '二海郡八雲町', 'フタミグンヤクモチョウ', '春日', 'カスガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道二海郡八雲町鉛川', '01', '01346', '0493128', '北海道', 'ホッカイドウ', '二海郡八雲町', 'フタミグンヤクモチョウ', '鉛川', 'ナマリカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道二海郡八雲町黒岩', '01', '01346', '0493341', '北海道', 'ホッカイドウ', '二海郡八雲町', 'フタミグンヤクモチョウ', '黒岩', 'クロイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道二海郡八雲町山崎', '01', '01346', '0493342', '北海道', 'ホッカイドウ', '二海郡八雲町', 'フタミグンヤクモチョウ', '山崎', 'ヤマザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道山越郡長万部町花岡', '01', '01347', '0493461', '北海道', 'ホッカイドウ', '山越郡長万部町', 'ヤマコシグンオシャマンベチョウ', '花岡', 'ハナオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道山越郡長万部町国縫', '01', '01347', '0493462', '北海道', 'ホッカイドウ', '山越郡長万部町', 'ヤマコシグンオシャマンベチョウ', '国縫', 'クンヌイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道山越郡長万部町豊野', '01', '01347', '0493463', '北海道', 'ホッカイドウ', '山越郡長万部町', 'ヤマコシグンオシャマンベチョウ', '豊野', 'トヨノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道山越郡長万部町豊津', '01', '01347', '0493464', '北海道', 'ホッカイドウ', '山越郡長万部町', 'ヤマコシグンオシャマンベチョウ', '豊津', 'トヨツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道山越郡長万部町茶屋川', '01', '01347', '0493465', '北海道', 'ホッカイドウ', '山越郡長万部町', 'ヤマコシグンオシャマンベチョウ', '茶屋川', 'チャヤガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道山越郡長万部町', '01', '01347', '0493500', '北海道', 'ホッカイドウ', '山越郡長万部町', 'ヤマコシグンオシャマンベチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('50113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道山越郡長万部町大峰', '01', '01347', '0493501', '北海道', 'ホッカイドウ', '山越郡長万部町', 'ヤマコシグンオシャマンベチョウ', '大峰', 'オオミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道山越郡長万部町双葉', '01', '01347', '0493501', '北海道', 'ホッカイドウ', '山越郡長万部町', 'ヤマコシグンオシャマンベチョウ', '双葉', 'フタバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道山越郡長万部町知来', '01', '01347', '0493502', '北海道', 'ホッカイドウ', '山越郡長万部町', 'ヤマコシグンオシャマンベチョウ', '知来', 'チライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道山越郡長万部町蕨岱', '01', '01347', '0493503', '北海道', 'ホッカイドウ', '山越郡長万部町', 'ヤマコシグンオシャマンベチョウ', '蕨岱', 'ワラビタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道山越郡長万部町美畑', '01', '01347', '0493504', '北海道', 'ホッカイドウ', '山越郡長万部町', 'ヤマコシグンオシャマンベチョウ', '美畑', 'ビハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道山越郡長万部町大浜', '01', '01347', '0493511', '北海道', 'ホッカイドウ', '山越郡長万部町', 'ヤマコシグンオシャマンベチョウ', '大浜', 'オオハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道山越郡長万部町中の沢', '01', '01347', '0493512', '北海道', 'ホッカイドウ', '山越郡長万部町', 'ヤマコシグンオシャマンベチョウ', '中の沢', 'ナカノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道山越郡長万部町平里', '01', '01347', '0493513', '北海道', 'ホッカイドウ', '山越郡長万部町', 'ヤマコシグンオシャマンベチョウ', '平里', 'ヒラサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道山越郡長万部町富野', '01', '01347', '0493514', '北海道', 'ホッカイドウ', '山越郡長万部町', 'ヤマコシグンオシャマンベチョウ', '富野', 'トミノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道山越郡長万部町栗岡', '01', '01347', '0493515', '北海道', 'ホッカイドウ', '山越郡長万部町', 'ヤマコシグンオシャマンベチョウ', '栗岡', 'クリオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道山越郡長万部町栄原', '01', '01347', '0493516', '北海道', 'ホッカイドウ', '山越郡長万部町', 'ヤマコシグンオシャマンベチョウ', '栄原', 'サカエハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道山越郡長万部町共立', '01', '01347', '0493517', '北海道', 'ホッカイドウ', '山越郡長万部町', 'ヤマコシグンオシャマンベチョウ', '共立', 'キョウリツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道山越郡長万部町静狩', '01', '01347', '0493518', '北海道', 'ホッカイドウ', '山越郡長万部町', 'ヤマコシグンオシャマンベチョウ', '静狩', 'シズカリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道山越郡長万部町旭浜', '01', '01347', '0493519', '北海道', 'ホッカイドウ', '山越郡長万部町', 'ヤマコシグンオシャマンベチョウ', '旭浜', 'アサヒハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道山越郡長万部町曙町', '01', '01347', '0493521', '北海道', 'ホッカイドウ', '山越郡長万部町', 'ヤマコシグンオシャマンベチョウ', '曙町', 'アケボノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道山越郡長万部町大町', '01', '01347', '0493521', '北海道', 'ホッカイドウ', '山越郡長万部町', 'ヤマコシグンオシャマンベチョウ', '大町', 'オオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道山越郡長万部町長万部', '01', '01347', '0493521', '北海道', 'ホッカイドウ', '山越郡長万部町', 'ヤマコシグンオシャマンベチョウ', '長万部', 'オシャマンベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道山越郡長万部町温泉町', '01', '01347', '0493521', '北海道', 'ホッカイドウ', '山越郡長万部町', 'ヤマコシグンオシャマンベチョウ', '温泉町', 'オンセンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道山越郡長万部町新開町', '01', '01347', '0493521', '北海道', 'ホッカイドウ', '山越郡長万部町', 'ヤマコシグンオシャマンベチョウ', '新開町', 'シンカイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道山越郡長万部町陣屋町', '01', '01347', '0493521', '北海道', 'ホッカイドウ', '山越郡長万部町', 'ヤマコシグンオシャマンベチョウ', '陣屋町', 'ジンヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道山越郡長万部町住吉町', '01', '01347', '0493521', '北海道', 'ホッカイドウ', '山越郡長万部町', 'ヤマコシグンオシャマンベチョウ', '住吉町', 'スミヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道山越郡長万部町高砂町', '01', '01347', '0493521', '北海道', 'ホッカイドウ', '山越郡長万部町', 'ヤマコシグンオシャマンベチョウ', '高砂町', 'タカサゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道山越郡長万部町本町', '01', '01347', '0493521', '北海道', 'ホッカイドウ', '山越郡長万部町', 'ヤマコシグンオシャマンベチョウ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道山越郡長万部町南栄町', '01', '01347', '0493521', '北海道', 'ホッカイドウ', '山越郡長万部町', 'ヤマコシグンオシャマンベチョウ', '南栄町', 'ミナミサカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道山越郡長万部町元町', '01', '01347', '0493521', '北海道', 'ホッカイドウ', '山越郡長万部町', 'ヤマコシグンオシャマンベチョウ', '元町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市北方町北方', '23', '23203', '4938001', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '北方町北方', 'キタガタチョウキタガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市北方町曽根', '23', '23203', '4938002', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '北方町曽根', 'キタガタチョウソネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市北方町中島', '23', '23203', '4938003', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '北方町中島', 'キタガタチョウナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市開明', '23', '23203', '4940001', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '開明', 'カイメイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市篭屋', '23', '23203', '4940002', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '篭屋', 'カゴヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市三条', '23', '23203', '4940003', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '三条', 'サンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市北今', '23', '23203', '4940004', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '北今', 'キタイマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市西五城', '23', '23203', '4940005', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '西五城', 'ニシイツシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市起', '23', '23203', '4940006', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '起', 'オコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市小信中島', '23', '23203', '4940007', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '小信中島', 'コノブナカシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市東五城', '23', '23203', '4940008', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '東五城', 'ヒガシイツシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市西萩原', '23', '23203', '4940011', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '西萩原', 'ニシハギワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市明地', '23', '23203', '4940012', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '明地', 'メイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市玉野', '23', '23203', '4940013', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '玉野', 'タマノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市上祖父江', '23', '23203', '4940014', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '上祖父江', 'カミソブエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市西中野', '23', '23203', '4940015', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '西中野', 'ニシナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市東加賀野井', '23', '23203', '4940016', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '東加賀野井', 'ヒガシカガノイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市祐久', '23', '23203', '4940017', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '祐久', 'ユウク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市冨田', '23', '23203', '4940018', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '冨田', 'トミダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県一宮市蓮池', '23', '23203', '4940019', '愛知県', 'アイチケン', '一宮市', 'イチノミヤシ', '蓮池', 'ハスイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道瀬棚郡今金町美利河', '01', '01370', '0494151', '北海道', 'ホッカイドウ', '瀬棚郡今金町', 'セタナグンイマカネチョウ', '美利河', 'ピリカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道瀬棚郡今金町宮島', '01', '01370', '0494152', '北海道', 'ホッカイドウ', '瀬棚郡今金町', 'セタナグンイマカネチョウ', '宮島', 'ミヤジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道瀬棚郡今金町花石', '01', '01370', '0494153', '北海道', 'ホッカイドウ', '瀬棚郡今金町', 'セタナグンイマカネチョウ', '花石', 'ハナイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道瀬棚郡今金町中里', '01', '01370', '0494154', '北海道', 'ホッカイドウ', '瀬棚郡今金町', 'セタナグンイマカネチョウ', '中里', 'ナカサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道瀬棚郡今金町奥沢', '01', '01370', '0494155', '北海道', 'ホッカイドウ', '瀬棚郡今金町', 'セタナグンイマカネチョウ', '奥沢', 'オクサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道瀬棚郡今金町住吉', '01', '01370', '0494156', '北海道', 'ホッカイドウ', '瀬棚郡今金町', 'セタナグンイマカネチョウ', '住吉', 'スミヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道瀬棚郡今金町上種川', '01', '01370', '0494157', '北海道', 'ホッカイドウ', '瀬棚郡今金町', 'セタナグンイマカネチョウ', '上種川', 'カミタネガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道瀬棚郡今金町', '01', '01370', '0494300', '北海道', 'ホッカイドウ', '瀬棚郡今金町', 'セタナグンイマカネチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('50167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道瀬棚郡今金町東町', '01', '01370', '0494301', '北海道', 'ホッカイドウ', '瀬棚郡今金町', 'セタナグンイマカネチョウ', '東町', 'アズマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道瀬棚郡今金町日の出町', '01', '01370', '0494302', '北海道', 'ホッカイドウ', '瀬棚郡今金町', 'セタナグンイマカネチョウ', '日の出町', 'ヒノデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道瀬棚郡今金町曙町', '01', '01370', '0494303', '北海道', 'ホッカイドウ', '瀬棚郡今金町', 'セタナグンイマカネチョウ', '曙町', 'アケボノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道瀬棚郡今金町寒昇', '01', '01370', '0494304', '北海道', 'ホッカイドウ', '瀬棚郡今金町', 'セタナグンイマカネチョウ', '寒昇', 'カンノボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道瀬棚郡今金町南栄町', '01', '01370', '0494305', '北海道', 'ホッカイドウ', '瀬棚郡今金町', 'セタナグンイマカネチョウ', '南栄町', 'ナンエイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道瀬棚郡今金町高美町', '01', '01370', '0494306', '北海道', 'ホッカイドウ', '瀬棚郡今金町', 'セタナグンイマカネチョウ', '高美町', 'タカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道瀬棚郡今金町八幡町', '01', '01370', '0494307', '北海道', 'ホッカイドウ', '瀬棚郡今金町', 'セタナグンイマカネチョウ', '八幡町', 'ハチマンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道瀬棚郡今金町今金', '01', '01370', '0494308', '北海道', 'ホッカイドウ', '瀬棚郡今金町', 'セタナグンイマカネチョウ', '今金', 'イマカネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道瀬棚郡今金町栄町', '01', '01370', '0494311', '北海道', 'ホッカイドウ', '瀬棚郡今金町', 'セタナグンイマカネチョウ', '栄町', 'サカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道瀬棚郡今金町旭町', '01', '01370', '0494312', '北海道', 'ホッカイドウ', '瀬棚郡今金町', 'セタナグンイマカネチョウ', '旭町', 'アサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道瀬棚郡今金町本町', '01', '01370', '0494313', '北海道', 'ホッカイドウ', '瀬棚郡今金町', 'セタナグンイマカネチョウ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道瀬棚郡今金町昭和町', '01', '01370', '0494314', '北海道', 'ホッカイドウ', '瀬棚郡今金町', 'セタナグンイマカネチョウ', '昭和町', 'ショウワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道瀬棚郡今金町末広町', '01', '01370', '0494315', '北海道', 'ホッカイドウ', '瀬棚郡今金町', 'セタナグンイマカネチョウ', '末広町', 'スエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道瀬棚郡今金町南町', '01', '01370', '0494316', '北海道', 'ホッカイドウ', '瀬棚郡今金町', 'セタナグンイマカネチョウ', '南町', 'ミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道瀬棚郡今金町緑町', '01', '01370', '0494317', '北海道', 'ホッカイドウ', '瀬棚郡今金町', 'セタナグンイマカネチョウ', '緑町', 'ミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道瀬棚郡今金町大和町', '01', '01370', '0494318', '北海道', 'ホッカイドウ', '瀬棚郡今金町', 'セタナグンイマカネチョウ', '大和町', 'ヤマトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道瀬棚郡今金町鈴岡', '01', '01370', '0494321', '北海道', 'ホッカイドウ', '瀬棚郡今金町', 'セタナグンイマカネチョウ', '鈴岡', 'スズオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道瀬棚郡今金町御影', '01', '01370', '0494322', '北海道', 'ホッカイドウ', '瀬棚郡今金町', 'セタナグンイマカネチョウ', '御影', 'ミカゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道瀬棚郡今金町光台', '01', '01370', '0494323', '北海道', 'ホッカイドウ', '瀬棚郡今金町', 'セタナグンイマカネチョウ', '光台', 'ヒカリダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道瀬棚郡今金町種川', '01', '01370', '0494324', '北海道', 'ホッカイドウ', '瀬棚郡今金町', 'セタナグンイマカネチョウ', '種川', 'タネガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道瀬棚郡今金町稲穂', '01', '01370', '0494325', '北海道', 'ホッカイドウ', '瀬棚郡今金町', 'セタナグンイマカネチョウ', '稲穂', 'イナホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道瀬棚郡今金町商工団地', '01', '01370', '0494326', '北海道', 'ホッカイドウ', '瀬棚郡今金町', 'セタナグンイマカネチョウ', '商工団地', 'ショウコウダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道瀬棚郡今金町神丘', '01', '01370', '0494327', '北海道', 'ホッカイドウ', '瀬棚郡今金町', 'セタナグンイマカネチョウ', '神丘', 'カミオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道瀬棚郡今金町田代', '01', '01370', '0494331', '北海道', 'ホッカイドウ', '瀬棚郡今金町', 'セタナグンイマカネチョウ', '田代', 'タシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道瀬棚郡今金町白石', '01', '01370', '0494332', '北海道', 'ホッカイドウ', '瀬棚郡今金町', 'セタナグンイマカネチョウ', '白石', 'シライシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道瀬棚郡今金町日進', '01', '01370', '0494333', '北海道', 'ホッカイドウ', '瀬棚郡今金町', 'セタナグンイマカネチョウ', '日進', 'ニッシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道瀬棚郡今金町八束', '01', '01370', '0494334', '北海道', 'ホッカイドウ', '瀬棚郡今金町', 'セタナグンイマカネチョウ', '八束', 'ヤツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道瀬棚郡今金町金原', '01', '01370', '0494335', '北海道', 'ホッカイドウ', '瀬棚郡今金町', 'セタナグンイマカネチョウ', '金原', 'キンバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道瀬棚郡今金町鈴金', '01', '01370', '0494336', '北海道', 'ホッカイドウ', '瀬棚郡今金町', 'セタナグンイマカネチョウ', '鈴金', 'スズカネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道瀬棚郡今金町豊田', '01', '01370', '0494337', '北海道', 'ホッカイドウ', '瀬棚郡今金町', 'セタナグンイマカネチョウ', '豊田', 'トヨタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道久遠郡せたな町北檜山区小倉山', '01', '01371', '0494431', '北海道', 'ホッカイドウ', '久遠郡せたな町', 'クドウグンセタナチョウ', '北檜山区小倉山', 'キタヒヤマクオグラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道久遠郡せたな町北檜山区東丹羽', '01', '01371', '0494432', '北海道', 'ホッカイドウ', '久遠郡せたな町', 'クドウグンセタナチョウ', '北檜山区東丹羽', 'キタヒヤマクヒガシニワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道久遠郡せたな町北檜山区丹羽', '01', '01371', '0494433', '北海道', 'ホッカイドウ', '久遠郡せたな町', 'クドウグンセタナチョウ', '北檜山区丹羽', 'キタヒヤマクニワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道久遠郡せたな町北檜山区西丹羽', '01', '01371', '0494434', '北海道', 'ホッカイドウ', '久遠郡せたな町', 'クドウグンセタナチョウ', '北檜山区西丹羽', 'キタヒヤマクニシニワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道久遠郡せたな町', '01', '01371', '0494500', '北海道', 'ホッカイドウ', '久遠郡せたな町', 'クドウグンセタナチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('50204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道久遠郡せたな町北檜山区北檜山', '01', '01371', '0494501', '北海道', 'ホッカイドウ', '久遠郡せたな町', 'クドウグンセタナチョウ', '北檜山区北檜山', 'キタヒヤマクキタヒヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道久遠郡せたな町北檜山区松岡', '01', '01371', '0494511', '北海道', 'ホッカイドウ', '久遠郡せたな町', 'クドウグンセタナチョウ', '北檜山区松岡', 'キタヒヤマクマツオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道久遠郡せたな町北檜山区徳島', '01', '01371', '0494512', '北海道', 'ホッカイドウ', '久遠郡せたな町', 'クドウグンセタナチョウ', '北檜山区徳島', 'キタヒヤマクトクシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道久遠郡せたな町北檜山区愛知', '01', '01371', '0494513', '北海道', 'ホッカイドウ', '久遠郡せたな町', 'クドウグンセタナチョウ', '北檜山区愛知', 'キタヒヤマクアイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道久遠郡せたな町北檜山区豊岡', '01', '01371', '0494514', '北海道', 'ホッカイドウ', '久遠郡せたな町', 'クドウグンセタナチョウ', '北檜山区豊岡', 'キタヒヤマクトヨオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道久遠郡せたな町北檜山区兜野', '01', '01371', '0494515', '北海道', 'ホッカイドウ', '久遠郡せたな町', 'クドウグンセタナチョウ', '北檜山区兜野', 'キタヒヤマクカブトノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道久遠郡せたな町北檜山区共和', '01', '01371', '0494516', '北海道', 'ホッカイドウ', '久遠郡せたな町', 'クドウグンセタナチョウ', '北檜山区共和', 'キタヒヤマクキョウワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道久遠郡せたな町北檜山区太櫓', '01', '01371', '0494517', '北海道', 'ホッカイドウ', '久遠郡せたな町', 'クドウグンセタナチョウ', '北檜山区太櫓', 'キタヒヤマクフトロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道久遠郡せたな町北檜山区新成', '01', '01371', '0494518', '北海道', 'ホッカイドウ', '久遠郡せたな町', 'クドウグンセタナチョウ', '北檜山区新成', 'キタヒヤマクシンセイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道久遠郡せたな町北檜山区栄', '01', '01371', '0494751', '北海道', 'ホッカイドウ', '久遠郡せたな町', 'クドウグンセタナチョウ', '北檜山区栄', 'キタヒヤマクサカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道久遠郡せたな町北檜山区若松', '01', '01371', '0494752', '北海道', 'ホッカイドウ', '久遠郡せたな町', 'クドウグンセタナチョウ', '北檜山区若松', 'キタヒヤマクワカマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道久遠郡せたな町北檜山区小川', '01', '01371', '0494753', '北海道', 'ホッカイドウ', '久遠郡せたな町', 'クドウグンセタナチョウ', '北檜山区小川', 'キタヒヤマクコガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道久遠郡せたな町北檜山区二俣', '01', '01371', '0494754', '北海道', 'ホッカイドウ', '久遠郡せたな町', 'クドウグンセタナチョウ', '北檜山区二俣', 'キタヒヤマクフタマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道久遠郡せたな町北檜山区富里', '01', '01371', '0494755', '北海道', 'ホッカイドウ', '久遠郡せたな町', 'クドウグンセタナチョウ', '北檜山区富里', 'キタヒヤマクトミサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道久遠郡せたな町瀬棚区本町1区', '01', '01371', '0494801', '北海道', 'ホッカイドウ', '久遠郡せたな町', 'クドウグンセタナチョウ', '瀬棚区本町', 'セタナクホンチョウ', null, null, '1区', '01ク');
INSERT INTO `ms_addresses` VALUES ('50221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道久遠郡せたな町瀬棚区本町2区', '01', '01371', '0494802', '北海道', 'ホッカイドウ', '久遠郡せたな町', 'クドウグンセタナチョウ', '瀬棚区本町', 'セタナクホンチョウ', null, null, '2区', '02ク');
INSERT INTO `ms_addresses` VALUES ('50222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道久遠郡せたな町瀬棚区本町3区', '01', '01371', '0494803', '北海道', 'ホッカイドウ', '久遠郡せたな町', 'クドウグンセタナチョウ', '瀬棚区本町', 'セタナクホンチョウ', null, null, '3区', '03ク');
INSERT INTO `ms_addresses` VALUES ('50223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道久遠郡せたな町瀬棚区本町4区', '01', '01371', '0494804', '北海道', 'ホッカイドウ', '久遠郡せたな町', 'クドウグンセタナチョウ', '瀬棚区本町', 'セタナクホンチョウ', null, null, '4区', '04ク');
INSERT INTO `ms_addresses` VALUES ('50224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道久遠郡せたな町瀬棚区本町5区', '01', '01371', '0494805', '北海道', 'ホッカイドウ', '久遠郡せたな町', 'クドウグンセタナチョウ', '瀬棚区本町', 'セタナクホンチョウ', null, null, '5区', '05ク');
INSERT INTO `ms_addresses` VALUES ('50225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道久遠郡せたな町瀬棚区本町6区', '01', '01371', '0494811', '北海道', 'ホッカイドウ', '久遠郡せたな町', 'クドウグンセタナチョウ', '瀬棚区本町', 'セタナクホンチョウ', null, null, '6区', '06ク');
INSERT INTO `ms_addresses` VALUES ('50226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道久遠郡せたな町瀬棚区本町7区', '01', '01371', '0494812', '北海道', 'ホッカイドウ', '久遠郡せたな町', 'クドウグンセタナチョウ', '瀬棚区本町', 'セタナクホンチョウ', null, null, '7区', '07ク');
INSERT INTO `ms_addresses` VALUES ('50227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道久遠郡せたな町瀬棚区本町8区', '01', '01371', '0494813', '北海道', 'ホッカイドウ', '久遠郡せたな町', 'クドウグンセタナチョウ', '瀬棚区本町', 'セタナクホンチョウ', null, null, '8区', '08ク');
INSERT INTO `ms_addresses` VALUES ('50228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道久遠郡せたな町瀬棚区本町9区', '01', '01371', '0494814', '北海道', 'ホッカイドウ', '久遠郡せたな町', 'クドウグンセタナチョウ', '瀬棚区本町', 'セタナクホンチョウ', null, null, '9区', '09ク');
INSERT INTO `ms_addresses` VALUES ('50229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道久遠郡せたな町瀬棚区本町10区', '01', '01371', '0494815', '北海道', 'ホッカイドウ', '久遠郡せたな町', 'クドウグンセタナチョウ', '瀬棚区本町', 'セタナクホンチョウ', null, null, '10区', '10ク');
INSERT INTO `ms_addresses` VALUES ('50230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道久遠郡せたな町瀬棚区本町', '01', '01371', '0494816', '北海道', 'ホッカイドウ', '久遠郡せたな町', 'クドウグンセタナチョウ', '瀬棚区本町', 'セタナクホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道久遠郡せたな町瀬棚区三本杉', '01', '01371', '0494821', '北海道', 'ホッカイドウ', '久遠郡せたな町', 'クドウグンセタナチョウ', '瀬棚区三本杉', 'セタナクサンボンスギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道久遠郡せたな町瀬棚区元浦', '01', '01371', '0494822', '北海道', 'ホッカイドウ', '久遠郡せたな町', 'クドウグンセタナチョウ', '瀬棚区元浦', 'セタナクモトウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道久遠郡せたな町瀬棚区島歌', '01', '01371', '0494823', '北海道', 'ホッカイドウ', '久遠郡せたな町', 'クドウグンセタナチョウ', '瀬棚区島歌', 'セタナクシマウタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道久遠郡せたな町瀬棚区北島歌', '01', '01371', '0494824', '北海道', 'ホッカイドウ', '久遠郡せたな町', 'クドウグンセタナチョウ', '瀬棚区北島歌', 'セタナクキタシマウタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道久遠郡せたな町瀬棚区西大里', '01', '01371', '0494825', '北海道', 'ホッカイドウ', '久遠郡せたな町', 'クドウグンセタナチョウ', '瀬棚区西大里', 'セタナクニシオオサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道久遠郡せたな町瀬棚区東大里', '01', '01371', '0494826', '北海道', 'ホッカイドウ', '久遠郡せたな町', 'クドウグンセタナチョウ', '瀬棚区東大里', 'セタナクヒガシオオサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道久遠郡せたな町瀬棚区共和', '01', '01371', '0494827', '北海道', 'ホッカイドウ', '久遠郡せたな町', 'クドウグンセタナチョウ', '瀬棚区共和', 'セタナクキョウワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道久遠郡せたな町瀬棚区南川', '01', '01371', '0494828', '北海道', 'ホッカイドウ', '久遠郡せたな町', 'クドウグンセタナチョウ', '瀬棚区南川', 'セタナクミナミカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市祖父江町祖父江', '23', '23220', '4950001', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '祖父江町祖父江', 'ソブエチョウソブエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市祖父江町山崎', '23', '23220', '4950002', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '祖父江町山崎', 'ソブエチョウヤマザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市祖父江町森上', '23', '23220', '4950011', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '祖父江町森上', 'ソブエチョウモリカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市祖父江町本甲', '23', '23220', '4950012', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '祖父江町本甲', 'ソブエチョウホンコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市祖父江町二俣', '23', '23220', '4950013', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '祖父江町二俣', 'ソブエチョウフタマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市祖父江町大牧', '23', '23220', '4950014', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '祖父江町大牧', 'ソブエチョウオオマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市祖父江町桜方', '23', '23220', '4950015', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '祖父江町桜方', 'ソブエチョウサクラガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市祖父江町三丸渕', '23', '23220', '4950021', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '祖父江町三丸渕', 'ソブエチョウサンマルブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市祖父江町甲新田', '23', '23220', '4950022', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '祖父江町甲新田', 'ソブエチョウカブトシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市祖父江町島本', '23', '23220', '4950023', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '祖父江町島本', 'ソブエチョウシマモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市祖父江町野田', '23', '23220', '4950024', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '祖父江町野田', 'ソブエチョウノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市祖父江町両寺内', '23', '23220', '4950025', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '祖父江町両寺内', 'ソブエチョウリョウジナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市祖父江町上牧', '23', '23220', '4950031', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '祖父江町上牧', 'ソブエチョウカンマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市祖父江町中牧', '23', '23220', '4950032', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '祖父江町中牧', 'ソブエチョウナカマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市祖父江町四貫', '23', '23220', '4950033', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '祖父江町四貫', 'ソブエチョウヨツヌキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市祖父江町西鵜之本', '23', '23220', '4950034', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '祖父江町西鵜之本', 'ソブエチョウニシウノモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市祖父江町神明津', '23', '23220', '4950035', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '祖父江町神明津', 'ソブエチョウシンミョウヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市祖父江町馬飼', '23', '23220', '4950036', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '祖父江町馬飼', 'ソブエチョウマカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県稲沢市祖父江町拾町野', '23', '23220', '4950037', '愛知県', 'アイチケン', '稲沢市', 'イナザワシ', '祖父江町拾町野', 'ソブエチョウジュツチョウノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道山越郡長万部町静狩', '01', '01347', '0495141', '北海道', 'ホッカイドウ', '山越郡長万部町', 'ヤマコシグンオシャマンベチョウ', '静狩', 'シズカリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡豊浦町豊泉', '01', '01571', '0495331', '北海道', 'ホッカイドウ', '虻田郡豊浦町', 'アブタグントヨウラチョウ', '豊泉', 'トヨイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡豊浦町大岸', '01', '01571', '0495332', '北海道', 'ホッカイドウ', '虻田郡豊浦町', 'アブタグントヨウラチョウ', '大岸', 'オオキシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡豊浦町礼文華', '01', '01571', '0495333', '北海道', 'ホッカイドウ', '虻田郡豊浦町', 'アブタグントヨウラチョウ', '礼文華', 'レブンゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡豊浦町', '01', '01571', '0495400', '北海道', 'ホッカイドウ', '虻田郡豊浦町', 'アブタグントヨウラチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('50273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡豊浦町山梨', '01', '01571', '0495401', '北海道', 'ホッカイドウ', '虻田郡豊浦町', 'アブタグントヨウラチョウ', '山梨', 'ヤマナシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡豊浦町大和', '01', '01571', '0495402', '北海道', 'ホッカイドウ', '虻田郡豊浦町', 'アブタグントヨウラチョウ', '大和', 'ヤマト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡豊浦町美和', '01', '01571', '0495403', '北海道', 'ホッカイドウ', '虻田郡豊浦町', 'アブタグントヨウラチョウ', '美和', 'ミワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡豊浦町桜', '01', '01571', '0495404', '北海道', 'ホッカイドウ', '虻田郡豊浦町', 'アブタグントヨウラチョウ', '桜', 'サクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡豊浦町高岡', '01', '01571', '0495405', '北海道', 'ホッカイドウ', '虻田郡豊浦町', 'アブタグントヨウラチョウ', '高岡', 'タカオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡豊浦町新山梨', '01', '01571', '0495406', '北海道', 'ホッカイドウ', '虻田郡豊浦町', 'アブタグントヨウラチョウ', '新山梨', 'シンヤマナシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡豊浦町上泉', '01', '01571', '0495407', '北海道', 'ホッカイドウ', '虻田郡豊浦町', 'アブタグントヨウラチョウ', '上泉', 'カミイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡豊浦町新富', '01', '01571', '0495408', '北海道', 'ホッカイドウ', '虻田郡豊浦町', 'アブタグントヨウラチョウ', '新富', 'シントミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡豊浦町東雲町', '01', '01571', '0495411', '北海道', 'ホッカイドウ', '虻田郡豊浦町', 'アブタグントヨウラチョウ', '東雲町', 'シノノメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡豊浦町旭町', '01', '01571', '0495412', '北海道', 'ホッカイドウ', '虻田郡豊浦町', 'アブタグントヨウラチョウ', '旭町', 'アサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡豊浦町海岸町', '01', '01571', '0495413', '北海道', 'ホッカイドウ', '虻田郡豊浦町', 'アブタグントヨウラチョウ', '海岸町', 'カイガンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡豊浦町幸町', '01', '01571', '0495414', '北海道', 'ホッカイドウ', '虻田郡豊浦町', 'アブタグントヨウラチョウ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡豊浦町浜町', '01', '01571', '0495415', '北海道', 'ホッカイドウ', '虻田郡豊浦町', 'アブタグントヨウラチョウ', '浜町', 'ハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡豊浦町船見町', '01', '01571', '0495416', '北海道', 'ホッカイドウ', '虻田郡豊浦町', 'アブタグントヨウラチョウ', '船見町', 'フナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡洞爺湖町', '01', '01584', '0495600', '北海道', 'ホッカイドウ', '虻田郡洞爺湖町', 'アブタグントウヤコチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('50289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡洞爺湖町青葉町', '01', '01584', '0495601', '北海道', 'ホッカイドウ', '虻田郡洞爺湖町', 'アブタグントウヤコチョウ', '青葉町', 'アオバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡洞爺湖町泉', '01', '01584', '0495602', '北海道', 'ホッカイドウ', '虻田郡洞爺湖町', 'アブタグントウヤコチョウ', '泉', 'イズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡洞爺湖町入江', '01', '01584', '0495603', '北海道', 'ホッカイドウ', '虻田郡洞爺湖町', 'アブタグントウヤコチョウ', '入江', 'イリエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡洞爺湖町栄町', '01', '01584', '0495604', '北海道', 'ホッカイドウ', '虻田郡洞爺湖町', 'アブタグントウヤコチョウ', '栄町', 'サカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡洞爺湖町高砂町', '01', '01584', '0495605', '北海道', 'ホッカイドウ', '虻田郡洞爺湖町', 'アブタグントウヤコチョウ', '高砂町', 'タカサゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡洞爺湖町旭町', '01', '01584', '0495611', '北海道', 'ホッカイドウ', '虻田郡洞爺湖町', 'アブタグントウヤコチョウ', '旭町', 'アサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡洞爺湖町大磯町', '01', '01584', '0495612', '北海道', 'ホッカイドウ', '虻田郡洞爺湖町', 'アブタグントウヤコチョウ', '大磯町', 'オオイソチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡洞爺湖町清水', '01', '01584', '0495613', '北海道', 'ホッカイドウ', '虻田郡洞爺湖町', 'アブタグントウヤコチョウ', '清水', 'シミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡洞爺湖町浜町', '01', '01584', '0495614', '北海道', 'ホッカイドウ', '虻田郡洞爺湖町', 'アブタグントウヤコチョウ', '浜町', 'ハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡洞爺湖町本町', '01', '01584', '0495615', '北海道', 'ホッカイドウ', '虻田郡洞爺湖町', 'アブタグントウヤコチョウ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡洞爺湖町三豊', '01', '01584', '0495616', '北海道', 'ホッカイドウ', '虻田郡洞爺湖町', 'アブタグントウヤコチョウ', '三豊', 'ミトヨ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡洞爺湖町洞爺湖温泉', '01', '01584', '0495721', '北海道', 'ホッカイドウ', '虻田郡洞爺湖町', 'アブタグントウヤコチョウ', '洞爺湖温泉', 'トウヤコオンセン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡洞爺湖町清水', '01', '01584', '0495722', '北海道', 'ホッカイドウ', '虻田郡洞爺湖町', 'アブタグントウヤコチョウ', '清水', 'シミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡洞爺湖町月浦', '01', '01584', '0495723', '北海道', 'ホッカイドウ', '虻田郡洞爺湖町', 'アブタグントウヤコチョウ', '月浦', 'ツキウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡洞爺湖町花和', '01', '01584', '0495724', '北海道', 'ホッカイドウ', '虻田郡洞爺湖町', 'アブタグントウヤコチョウ', '花和', 'ハナワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道有珠郡壮瞥町洞爺湖温泉', '01', '01575', '0495731', '北海道', 'ホッカイドウ', '有珠郡壮瞥町', 'ウスグンソウベツチョウ', '洞爺湖温泉', 'トウヤコオンセン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡洞爺湖町旭浦', '01', '01584', '0495801', '北海道', 'ホッカイドウ', '虻田郡洞爺湖町', 'アブタグントウヤコチョウ', '旭浦', 'アサヒウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡洞爺湖町洞爺町', '01', '01584', '0495802', '北海道', 'ホッカイドウ', '虻田郡洞爺湖町', 'アブタグントウヤコチョウ', '洞爺町', 'トウヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡洞爺湖町岩屋', '01', '01584', '0495811', '北海道', 'ホッカイドウ', '虻田郡洞爺湖町', 'アブタグントウヤコチョウ', '岩屋', 'イワヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡洞爺湖町川東', '01', '01584', '0495812', '北海道', 'ホッカイドウ', '虻田郡洞爺湖町', 'アブタグントウヤコチョウ', '川東', 'カワヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡洞爺湖町財田', '01', '01584', '0495813', '北海道', 'ホッカイドウ', '虻田郡洞爺湖町', 'アブタグントウヤコチョウ', '財田', 'タカラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡洞爺湖町早月', '01', '01584', '0495814', '北海道', 'ホッカイドウ', '虻田郡洞爺湖町', 'アブタグントウヤコチョウ', '早月', 'ハヤツキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡洞爺湖町大原', '01', '01584', '0495821', '北海道', 'ホッカイドウ', '虻田郡洞爺湖町', 'アブタグントウヤコチョウ', '大原', 'オオハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡洞爺湖町富丘', '01', '01584', '0495822', '北海道', 'ホッカイドウ', '虻田郡洞爺湖町', 'アブタグントウヤコチョウ', '富丘', 'トミオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡洞爺湖町香川', '01', '01584', '0495831', '北海道', 'ホッカイドウ', '虻田郡洞爺湖町', 'アブタグントウヤコチョウ', '香川', 'カガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡洞爺湖町成香', '01', '01584', '0495832', '北海道', 'ホッカイドウ', '虻田郡洞爺湖町', 'アブタグントウヤコチョウ', '成香', 'ナルカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道虻田郡洞爺湖町伏見', '01', '01584', '0495833', '北海道', 'ホッカイドウ', '虻田郡洞爺湖町', 'アブタグントウヤコチョウ', '伏見', 'フシミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市', '23', '23208', '4960000', '愛知県', 'アイチケン', '津島市', 'ツシマシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('50326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛西市', '23', '23232', '4960000', '愛知県', 'アイチケン', '愛西市', 'アイサイシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('50327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市青塚町', '23', '23208', '4960001', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '青塚町', 'アオツカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市牧野町', '23', '23208', '4960002', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '牧野町', 'マキノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市寺野町', '23', '23208', '4960003', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '寺野町', 'テラノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市蛭間町', '23', '23208', '4960004', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '蛭間町', 'ヒルマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市神守町', '23', '23208', '4960005', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '神守町', 'カモリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市大木町', '23', '23208', '4960006', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '大木町', 'ダイギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市光正寺町', '23', '23208', '4960007', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '光正寺町', 'コウショウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市宇治町', '23', '23208', '4960008', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '宇治町', 'ウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市葉苅町', '23', '23208', '4960009', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '葉苅町', 'ハカリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市莪原町', '23', '23208', '4960011', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '莪原町', 'バイバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市大坪町', '23', '23208', '4960012', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '大坪町', 'オオツボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市神尾町', '23', '23208', '4960013', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '神尾町', 'カンノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市金柳町', '23', '23208', '4960014', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '金柳町', 'カナヤナギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市高台寺町', '23', '23208', '4960015', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '高台寺町', 'コウタイジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市白浜町', '23', '23208', '4960016', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '白浜町', 'シラハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市百町', '23', '23208', '4960017', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '百町', 'ヒャクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市牛田町', '23', '23208', '4960018', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '牛田町', 'ウシダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市百島町', '23', '23208', '4960019', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '百島町', 'モモジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市椿市町', '23', '23208', '4960021', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '椿市町', 'ツバイチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市越津町', '23', '23208', '4960022', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '越津町', 'コシヅチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市鹿伏兎町', '23', '23208', '4960023', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '鹿伏兎町', 'カブトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市半頭町', '23', '23208', '4960024', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '半頭町', 'ハンガシラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市中一色町', '23', '23208', '4960025', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '中一色町', 'ナカイシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市唐臼町', '23', '23208', '4960026', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '唐臼町', 'カラウスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市新開', '23', '23208', '4960027', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '新開', 'シンガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市津島', '23', '23208', '4960027', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '津島', 'ツシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市日光', '23', '23208', '4960028', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '日光', 'ニッコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市下切町', '23', '23208', '4960029', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '下切町', 'シモギリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市埋田町', '23', '23208', '4960031', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '埋田町', 'ウメダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市深坪町', '23', '23208', '4960032', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '深坪町', 'フカツボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市杁前町', '23', '23208', '4960033', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '杁前町', 'イリマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市元寺町', '23', '23208', '4960034', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '元寺町', 'モトデラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市東愛宕町', '23', '23208', '4960035', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '東愛宕町', 'ヒガシアダゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市愛宕町', '23', '23208', '4960036', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '愛宕町', 'アタゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市西愛宕町', '23', '23208', '4960037', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '西愛宕町', 'ニシアタゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市橘町', '23', '23208', '4960038', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '橘町', 'タチバナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市高畑町', '23', '23208', '4960041', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '高畑町', 'タカハタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市寺前町', '23', '23208', '4960042', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '寺前町', 'テラマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市古川', '23', '23208', '4960043', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '古川', 'フルカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市古川町', '23', '23208', '4960043', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '古川町', 'フルカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市立込町', '23', '23208', '4960044', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '立込町', 'タテコミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市東柳原町', '23', '23208', '4960045', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '東柳原町', 'ヒガシヤナギハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市柳原町', '23', '23208', '4960046', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '柳原町', 'ヤナギハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市西柳原町', '23', '23208', '4960047', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '西柳原町', 'ニシヤナギハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市藤里町', '23', '23208', '4960048', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '藤里町', 'フジサトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市新開町', '23', '23208', '4960071', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '新開町', 'シンガイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市南新開町', '23', '23208', '4960072', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '南新開町', 'ミナミシンガイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市藤浪町', '23', '23208', '4960801', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '藤浪町', 'フジナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市錦町', '23', '23208', '4960802', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '錦町', 'ニシキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市今市場町', '23', '23208', '4960803', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '今市場町', 'イマイチバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市弥生町', '23', '23208', '4960804', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '弥生町', 'ヤヨイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市本町', '23', '23208', '4960805', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市池麩町', '23', '23208', '4960806', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '池麩町', 'イケフチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市天王通', '23', '23208', '4960807', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '天王通', 'テンノウドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市宝町', '23', '23208', '4960808', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '宝町', 'タカラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市昭和町', '23', '23208', '4960809', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '昭和町', 'ショウワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市喜楽町', '23', '23208', '4960811', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '喜楽町', 'キラクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市兼平町', '23', '23208', '4960812', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '兼平町', 'カネヒラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市片岡町', '23', '23208', '4960813', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '片岡町', 'カタオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市良王町', '23', '23208', '4960814', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '良王町', 'リョウオウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市米之座町', '23', '23208', '4960815', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '米之座町', 'コメノザチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市米町', '23', '23208', '4960816', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '米町', 'コメマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市北町', '23', '23208', '4960817', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '北町', 'キタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市松原町', '23', '23208', '4960818', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '松原町', 'マツバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市又吉町', '23', '23208', '4960819', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '又吉町', 'マタキチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市城之越町', '23', '23208', '4960821', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '城之越町', 'シロノコシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市高屋敷町', '23', '23208', '4960822', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '高屋敷町', 'タカヤシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市上河原町', '23', '23208', '4960823', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '上河原町', 'カミガワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市金町', '23', '23208', '4960824', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '金町', 'カナマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市橋詰町', '23', '23208', '4960825', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '橋詰町', 'ハシヅメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市片町', '23', '23208', '4960826', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '片町', 'カタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市浦方町', '23', '23208', '4960827', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '浦方町', 'ウラカタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市池須町', '23', '23208', '4960828', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '池須町', 'イケスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市寿町', '23', '23208', '4960829', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '寿町', 'コトブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市瑞穂町', '23', '23208', '4960831', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '瑞穂町', 'ミズホチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市東洋町', '23', '23208', '4960832', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '東洋町', 'トウヨウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市常盤町', '23', '23208', '4960833', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '常盤町', 'トキワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市南本町', '23', '23208', '4960834', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '南本町', 'ミナミホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市皆戸町', '23', '23208', '4960835', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '皆戸町', 'ミナトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市中野町', '23', '23208', '4960836', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '中野町', 'ナカノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市大政町', '23', '23208', '4960837', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '大政町', 'タイセイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市明天町', '23', '23208', '4960838', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '明天町', 'メイテンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市藤川町', '23', '23208', '4960839', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '藤川町', 'フジカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市横町', '23', '23208', '4960841', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '横町', 'ヨコマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市筏場町', '23', '23208', '4960842', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '筏場町', 'イカダバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市舟戸町', '23', '23208', '4960843', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '舟戸町', 'フナドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市薬師町', '23', '23208', '4960844', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '薬師町', 'ヤクシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市永楽町', '23', '23208', '4960845', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '永楽町', 'エイラクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市東中地町', '23', '23208', '4960846', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '東中地町', 'ヒガシナカジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市中地町', '23', '23208', '4960847', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '中地町', 'ナカジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市大慶寺町', '23', '23208', '4960848', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '大慶寺町', 'タイケイジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市西御堂町', '23', '23208', '4960849', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '西御堂町', 'ニシミドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市神明町', '23', '23208', '4960851', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '神明町', 'シンメイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市祢宜町', '23', '23208', '4960852', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '祢宜町', 'ネギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市宮川町', '23', '23208', '4960853', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '宮川町', 'ミヤガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市老松町', '23', '23208', '4960854', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '老松町', 'オイマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市江東町', '23', '23208', '4960855', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '江東町', 'エトウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市瑠璃小路町', '23', '23208', '4960856', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '瑠璃小路町', 'ルリコウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市南門前町', '23', '23208', '4960857', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '南門前町', 'ミナミモンゼンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市観音町', '23', '23208', '4960861', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '観音町', 'カンノンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市城山町', '23', '23208', '4960862', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '城山町', 'シロヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市上之町', '23', '23208', '4960863', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '上之町', 'カミノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市中之町', '23', '23208', '4960864', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '中之町', 'ナカノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市馬場町', '23', '23208', '4960865', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '馬場町', 'ババチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市大和町', '23', '23208', '4960866', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '大和町', 'ヤマトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市江川町', '23', '23208', '4960867', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '江川町', 'エガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市申塚町', '23', '23208', '4960868', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '申塚町', 'サルヅカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市河原町', '23', '23208', '4960869', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '河原町', 'カワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市上新田町', '23', '23208', '4960871', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '上新田町', 'カミシンデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市松ケ下町', '23', '23208', '4960872', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '松ケ下町', 'マツガシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市一本木町', '23', '23208', '4960873', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '一本木町', 'イッポンギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市江西町', '23', '23208', '4960874', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '江西町', 'エニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市下新田町', '23', '23208', '4960875', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '下新田町', 'シモシンデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市大縄町', '23', '23208', '4960876', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '大縄町', 'オオナワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県津島市河田町', '23', '23208', '4960877', '愛知県', 'アイチケン', '津島市', 'ツシマシ', '河田町', 'カワダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛西市佐屋町', '23', '23232', '4960901', '愛知県', 'アイチケン', '愛西市', 'アイサイシ', '佐屋町', 'サヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛西市須依町', '23', '23232', '4960902', '愛知県', 'アイチケン', '愛西市', 'アイサイシ', '須依町', 'スエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛西市内佐屋町', '23', '23232', '4960903', '愛知県', 'アイチケン', '愛西市', 'アイサイシ', '内佐屋町', 'ウチザヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛西市柚木町', '23', '23232', '4960904', '愛知県', 'アイチケン', '愛西市', 'アイサイシ', '柚木町', 'ユギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛西市北一色町', '23', '23232', '4960905', '愛知県', 'アイチケン', '愛西市', 'アイサイシ', '北一色町', 'キタイシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛西市日置町', '23', '23232', '4960906', '愛知県', 'アイチケン', '愛西市', 'アイサイシ', '日置町', 'ヒキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛西市稲葉町', '23', '23232', '4960907', '愛知県', 'アイチケン', '愛西市', 'アイサイシ', '稲葉町', 'イナバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛西市金棒町', '23', '23232', '4960908', '愛知県', 'アイチケン', '愛西市', 'アイサイシ', '金棒町', 'カナボウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛西市甘村井町', '23', '23232', '4960908', '愛知県', 'アイチケン', '愛西市', 'アイサイシ', '甘村井町', 'カムライチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛西市落合町', '23', '23232', '4960909', '愛知県', 'アイチケン', '愛西市', 'アイサイシ', '落合町', 'オチアイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛西市西保町', '23', '23232', '4960911', '愛知県', 'アイチケン', '愛西市', 'アイサイシ', '西保町', 'ニシホチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛西市東保町', '23', '23232', '4960912', '愛知県', 'アイチケン', '愛西市', 'アイサイシ', '東保町', 'ヒガシホチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛西市西條町', '23', '23232', '4960913', '愛知県', 'アイチケン', '愛西市', 'アイサイシ', '西條町', 'ニシジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛西市東條町', '23', '23232', '4960914', '愛知県', 'アイチケン', '愛西市', 'アイサイシ', '東條町', 'ヒガシジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛西市本部田町', '23', '23232', '4960915', '愛知県', 'アイチケン', '愛西市', 'アイサイシ', '本部田町', 'ホンブタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛西市大井町', '23', '23232', '4960921', '愛知県', 'アイチケン', '愛西市', 'アイサイシ', '大井町', 'オオイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛西市大野町', '23', '23232', '4960922', '愛知県', 'アイチケン', '愛西市', 'アイサイシ', '大野町', 'オオノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛西市鰯江町', '23', '23232', '4960923', '愛知県', 'アイチケン', '愛西市', 'アイサイシ', '鰯江町', 'イワシエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛西市善太新田町', '23', '23232', '4960924', '愛知県', 'アイチケン', '愛西市', 'アイサイシ', '善太新田町', 'ゼンタシンデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛西市早尾町', '23', '23232', '4960931', '愛知県', 'アイチケン', '愛西市', 'アイサイシ', '早尾町', 'ハヤオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛西市葛木町', '23', '23232', '4960932', '愛知県', 'アイチケン', '愛西市', 'アイサイシ', '葛木町', 'カツラギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛西市戸倉町', '23', '23232', '4960933', '愛知県', 'アイチケン', '愛西市', 'アイサイシ', '戸倉町', 'トクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛西市新右エ門新田町', '23', '23232', '4960934', '愛知県', 'アイチケン', '愛西市', 'アイサイシ', '新右エ門新田町', 'シンウエモンシンデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛西市下一色町', '23', '23232', '4960935', '愛知県', 'アイチケン', '愛西市', 'アイサイシ', '下一色町', 'シモイシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛西市四会町', '23', '23232', '4960936', '愛知県', 'アイチケン', '愛西市', 'アイサイシ', '四会町', 'ヨツエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛西市宮地町', '23', '23232', '4960937', '愛知県', 'アイチケン', '愛西市', 'アイサイシ', '宮地町', 'ミヤジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛西市石田町', '23', '23232', '4960938', '愛知県', 'アイチケン', '愛西市', 'アイサイシ', '石田町', 'イシダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛西市後江町', '23', '23232', '4960939', '愛知県', 'アイチケン', '愛西市', 'アイサイシ', '後江町', 'ヒツエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛西市雀ケ森町', '23', '23232', '4960941', '愛知県', 'アイチケン', '愛西市', 'アイサイシ', '雀ケ森町', 'スズガモリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛西市山路町', '23', '23232', '4960942', '愛知県', 'アイチケン', '愛西市', 'アイサイシ', '山路町', 'ヤマジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛西市森川町', '23', '23232', '4960943', '愛知県', 'アイチケン', '愛西市', 'アイサイシ', '森川町', 'モリカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛西市小茂井町', '23', '23232', '4960944', '愛知県', 'アイチケン', '愛西市', 'アイサイシ', '小茂井町', 'コモイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛西市三和町', '23', '23232', '4960945', '愛知県', 'アイチケン', '愛西市', 'アイサイシ', '三和町', 'ミツワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛西市立田町', '23', '23232', '4960946', '愛知県', 'アイチケン', '愛西市', 'アイサイシ', '立田町', 'タツダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛西市福原新田町', '23', '23232', '4960947', '愛知県', 'アイチケン', '愛西市', 'アイサイシ', '福原新田町', 'フクハラシンデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛西市勝幡町', '23', '23232', '4968001', '愛知県', 'アイチケン', '愛西市', 'アイサイシ', '勝幡町', 'ショバタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛西市佐折町', '23', '23232', '4968002', '愛知県', 'アイチケン', '愛西市', 'アイサイシ', '佐折町', 'サオリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛西市千引町', '23', '23232', '4968003', '愛知県', 'アイチケン', '愛西市', 'アイサイシ', '千引町', 'センビキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛西市古瀬町', '23', '23232', '4968004', '愛知県', 'アイチケン', '愛西市', 'アイサイシ', '古瀬町', 'コセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛西市諸桑町', '23', '23232', '4968005', '愛知県', 'アイチケン', '愛西市', 'アイサイシ', '諸桑町', 'モロクワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛西市持中町', '23', '23232', '4968006', '愛知県', 'アイチケン', '愛西市', 'アイサイシ', '持中町', 'モツチュウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛西市南河田町', '23', '23232', '4968007', '愛知県', 'アイチケン', '愛西市', 'アイサイシ', '南河田町', 'ミナミゴウタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛西市北河田町', '23', '23232', '4968008', '愛知県', 'アイチケン', '愛西市', 'アイサイシ', '北河田町', 'キタゴウタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛西市小津町', '23', '23232', '4968009', '愛知県', 'アイチケン', '愛西市', 'アイサイシ', '小津町', 'オヅチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛西市六輪町', '23', '23232', '4968010', '愛知県', 'アイチケン', '愛西市', 'アイサイシ', '六輪町', 'ロクワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛西市諏訪町', '23', '23232', '4968011', '愛知県', 'アイチケン', '愛西市', 'アイサイシ', '諏訪町', 'スワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛西市根高町', '23', '23232', '4968012', '愛知県', 'アイチケン', '愛西市', 'アイサイシ', '根高町', 'ネダカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛西市見越町', '23', '23232', '4968013', '愛知県', 'アイチケン', '愛西市', 'アイサイシ', '見越町', 'ミコシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛西市町方町', '23', '23232', '4968014', '愛知県', 'アイチケン', '愛西市', 'アイサイシ', '町方町', 'マチカタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛西市草平町', '23', '23232', '4968015', '愛知県', 'アイチケン', '愛西市', 'アイサイシ', '草平町', 'クサヒラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛西市鷹場町', '23', '23232', '4968016', '愛知県', 'アイチケン', '愛西市', 'アイサイシ', '鷹場町', 'タカバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛西市大野山町', '23', '23232', '4968017', '愛知県', 'アイチケン', '愛西市', 'アイサイシ', '大野山町', 'オオノヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛西市渕高町', '23', '23232', '4968018', '愛知県', 'アイチケン', '愛西市', 'アイサイシ', '渕高町', 'フチダカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛西市西川端町', '23', '23232', '4968019', '愛知県', 'アイチケン', '愛西市', 'アイサイシ', '西川端町', 'ニシカワバタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛西市平和町', '23', '23232', '4968020', '愛知県', 'アイチケン', '愛西市', 'アイサイシ', '平和町', 'ヘイワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛西市二子町柳原', '23', '23232', '4968030', '愛知県', 'アイチケン', '愛西市', 'アイサイシ', '二子町柳原', 'フタゴチョウヤナギハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛西市上東川町', '23', '23232', '4968031', '愛知県', 'アイチケン', '愛西市', 'アイサイシ', '上東川町', 'カミヒガシガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛西市下東川町', '23', '23232', '4968032', '愛知県', 'アイチケン', '愛西市', 'アイサイシ', '下東川町', 'シモヒガシガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛西市鵜多須町', '23', '23232', '4968033', '愛知県', 'アイチケン', '愛西市', 'アイサイシ', '鵜多須町', 'ウタスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛西市二子町小判山', '23', '23232', '4968034', '愛知県', 'アイチケン', '愛西市', 'アイサイシ', '二子町小判山', 'フタゴチョウコバンヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛西市二子町上丸島', '23', '23232', '4968035', '愛知県', 'アイチケン', '愛西市', 'アイサイシ', '二子町上丸島', 'フタゴチョウカミマルジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛西市二子町丸島', '23', '23232', '4968036', '愛知県', 'アイチケン', '愛西市', 'アイサイシ', '二子町丸島', 'フタゴチョウマルジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛西市二子町新田', '23', '23232', '4968037', '愛知県', 'アイチケン', '愛西市', 'アイサイシ', '二子町新田', 'フタゴチョウシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛西市二子町定納', '23', '23232', '4968038', '愛知県', 'アイチケン', '愛西市', 'アイサイシ', '二子町定納', 'フタゴチョウジョウノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛西市川北町', '23', '23232', '4968039', '愛知県', 'アイチケン', '愛西市', 'アイサイシ', '川北町', 'カワキタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛西市二子町松原', '23', '23232', '4968040', '愛知県', 'アイチケン', '愛西市', 'アイサイシ', '二子町松原', 'フタゴチョウマツバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛西市藤ケ瀬町', '23', '23232', '4968041', '愛知県', 'アイチケン', '愛西市', 'アイサイシ', '藤ケ瀬町', 'フジガセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛西市給父町', '23', '23232', '4968042', '愛知県', 'アイチケン', '愛西市', 'アイサイシ', '給父町', 'キュウブチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛西市高畑町', '23', '23232', '4968043', '愛知県', 'アイチケン', '愛西市', 'アイサイシ', '高畑町', 'タカバタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛西市江西町', '23', '23232', '4968044', '愛知県', 'アイチケン', '愛西市', 'アイサイシ', '江西町', 'エニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛西市元赤目町', '23', '23232', '4968045', '愛知県', 'アイチケン', '愛西市', 'アイサイシ', '元赤目町', 'モトアカメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛西市赤目町', '23', '23232', '4968046', '愛知県', 'アイチケン', '愛西市', 'アイサイシ', '赤目町', 'アカメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛西市立石町', '23', '23232', '4968047', '愛知県', 'アイチケン', '愛西市', 'アイサイシ', '立石町', 'タテイシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛西市下大牧町', '23', '23232', '4968048', '愛知県', 'アイチケン', '愛西市', 'アイサイシ', '下大牧町', 'シモオオマキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県愛西市塩田町', '23', '23232', '4968049', '愛知県', 'アイチケン', '愛西市', 'アイサイシ', '塩田町', 'シオタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県海部郡七宝町', '23', '23421', '4970000', '愛知県', 'アイチケン', '海部郡七宝町', 'アマグンシッポウチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('50537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県海部郡蟹江町', '23', '23425', '4970000', '愛知県', 'アイチケン', '海部郡蟹江町', 'アマグンカニエチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('50538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県海部郡七宝町沖之島', '23', '23421', '4970001', '愛知県', 'アイチケン', '海部郡七宝町', 'アマグンシッポウチョウ', '沖之島', 'オキノシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県海部郡七宝町遠島', '23', '23421', '4970002', '愛知県', 'アイチケン', '海部郡七宝町', 'アマグンシッポウチョウ', '遠島', 'トオシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県海部郡七宝町秋竹', '23', '23421', '4970003', '愛知県', 'アイチケン', '海部郡七宝町', 'アマグンシッポウチョウ', '秋竹', 'アキタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県海部郡七宝町桂', '23', '23421', '4970004', '愛知県', 'アイチケン', '海部郡七宝町', 'アマグンシッポウチョウ', '桂', 'カツラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県海部郡七宝町伊福', '23', '23421', '4970005', '愛知県', 'アイチケン', '海部郡七宝町', 'アマグンシッポウチョウ', '伊福', 'イフク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県海部郡七宝町下之森', '23', '23421', '4970006', '愛知県', 'アイチケン', '海部郡七宝町', 'アマグンシッポウチョウ', '下之森', 'シモノモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県海部郡七宝町安松', '23', '23421', '4970011', '愛知県', 'アイチケン', '海部郡七宝町', 'アマグンシッポウチョウ', '安松', 'ヤスマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県海部郡七宝町下田', '23', '23421', '4970012', '愛知県', 'アイチケン', '海部郡七宝町', 'アマグンシッポウチョウ', '下田', 'シモダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県海部郡七宝町川部', '23', '23421', '4970013', '愛知県', 'アイチケン', '海部郡七宝町', 'アマグンシッポウチョウ', '川部', 'カワベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県海部郡七宝町鷹居', '23', '23421', '4970014', '愛知県', 'アイチケン', '海部郡七宝町', 'アマグンシッポウチョウ', '鷹居', 'タカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県海部郡七宝町鯰橋', '23', '23421', '4970015', '愛知県', 'アイチケン', '海部郡七宝町', 'アマグンシッポウチョウ', '鯰橋', 'ナマズバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県海部郡七宝町徳実', '23', '23421', '4970016', '愛知県', 'アイチケン', '海部郡七宝町', 'アマグンシッポウチョウ', '徳実', 'トクザネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県海部郡蟹江町宝', '23', '23425', '4970030', '愛知県', 'アイチケン', '海部郡蟹江町', 'アマグンカニエチョウ', '宝', 'タカラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県海部郡蟹江町須成', '23', '23425', '4970031', '愛知県', 'アイチケン', '海部郡蟹江町', 'アマグンカニエチョウ', '須成', 'スナリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県海部郡蟹江町今', '23', '23425', '4970032', '愛知県', 'アイチケン', '海部郡蟹江町', 'アマグンカニエチョウ', '今', 'イマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県海部郡蟹江町蟹江本町', '23', '23425', '4970033', '愛知県', 'アイチケン', '海部郡蟹江町', 'アマグンカニエチョウ', '蟹江本町', 'カニエホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県海部郡蟹江町本町', '23', '23425', '4970034', '愛知県', 'アイチケン', '海部郡蟹江町', 'アマグンカニエチョウ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県海部郡蟹江町蟹江新町', '23', '23425', '4970035', '愛知県', 'アイチケン', '海部郡蟹江町', 'アマグンカニエチョウ', '蟹江新町', 'カニエシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県海部郡蟹江町須成西', '23', '23425', '4970036', '愛知県', 'アイチケン', '海部郡蟹江町', 'アマグンカニエチョウ', '須成西', 'スナリニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県海部郡蟹江町今西', '23', '23425', '4970037', '愛知県', 'アイチケン', '海部郡蟹江町', 'アマグンカニエチョウ', '今西', 'イマニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県海部郡蟹江町本町片堀', '23', '23425', '4970038', '愛知県', 'アイチケン', '海部郡蟹江町', 'アマグンカニエチョウ', '本町片堀', 'ホンマチカタホリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県海部郡蟹江町本町川原', '23', '23425', '4970039', '愛知県', 'アイチケン', '海部郡蟹江町', 'アマグンカニエチョウ', '本町川原', 'ホンマチカワハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県海部郡蟹江町鍋蓋新田', '23', '23425', '4970042', '愛知県', 'アイチケン', '海部郡蟹江町', 'アマグンカニエチョウ', '鍋蓋新田', 'ナベブタシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県海部郡蟹江町新千秋', '23', '23425', '4970043', '愛知県', 'アイチケン', '海部郡蟹江町', 'アマグンカニエチョウ', '新千秋', 'シンチアキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県海部郡蟹江町蟹江新田', '23', '23425', '4970044', '愛知県', 'アイチケン', '海部郡蟹江町', 'アマグンカニエチョウ', '蟹江新田', 'カニエシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県海部郡蟹江町緑', '23', '23425', '4970045', '愛知県', 'アイチケン', '海部郡蟹江町', 'アマグンカニエチョウ', '緑', 'ミドリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県海部郡蟹江町旭', '23', '23425', '4970046', '愛知県', 'アイチケン', '海部郡蟹江町', 'アマグンカニエチョウ', '旭', 'アサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県海部郡蟹江町泉', '23', '23425', '4970047', '愛知県', 'アイチケン', '海部郡蟹江町', 'アマグンカニエチョウ', '泉', 'イズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県海部郡蟹江町舟入', '23', '23425', '4970048', '愛知県', 'アイチケン', '海部郡蟹江町', 'アマグンカニエチョウ', '舟入', 'フナイリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県海部郡蟹江町学戸', '23', '23425', '4970050', '愛知県', 'アイチケン', '海部郡蟹江町', 'アマグンカニエチョウ', '学戸', 'ガクト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県海部郡蟹江町北新田', '23', '23425', '4970051', '愛知県', 'アイチケン', '海部郡蟹江町', 'アマグンカニエチョウ', '北新田', 'キタシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県海部郡蟹江町西之森', '23', '23425', '4970052', '愛知県', 'アイチケン', '海部郡蟹江町', 'アマグンカニエチョウ', '西之森', 'ニシノモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県海部郡蟹江町平安', '23', '23425', '4970053', '愛知県', 'アイチケン', '海部郡蟹江町', 'アマグンカニエチョウ', '平安', 'ヘイアン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県海部郡蟹江町錦', '23', '23425', '4970054', '愛知県', 'アイチケン', '海部郡蟹江町', 'アマグンカニエチョウ', '錦', 'ニシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県海部郡蟹江町源氏', '23', '23425', '4970055', '愛知県', 'アイチケン', '海部郡蟹江町', 'アマグンカニエチョウ', '源氏', 'ゲンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県海部郡蟹江町八幡', '23', '23425', '4970056', '愛知県', 'アイチケン', '海部郡蟹江町', 'アマグンカニエチョウ', '八幡', 'ハチマン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県海部郡蟹江町上川田', '23', '23425', '4970057', '愛知県', 'アイチケン', '海部郡蟹江町', 'アマグンカニエチョウ', '上川田', 'カミカワタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県弥富市', '23', '23235', '4980000', '愛知県', 'アイチケン', '弥富市', 'ヤトミシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('50594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名郡木曽岬町', '24', '24303', '4980000', '三重県', 'ミエケン', '桑名郡木曽岬町', 'クワナグンキソサキチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('50595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県弥富市西中地町', '23', '23235', '4980001', '愛知県', 'アイチケン', '弥富市', 'ヤトミシ', '西中地町', 'ニシナカジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県弥富市東中地', '23', '23235', '4980002', '愛知県', 'アイチケン', '弥富市', 'ヤトミシ', '東中地', 'ヒガシナカジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県弥富市前ケ平', '23', '23235', '4980003', '愛知県', 'アイチケン', '弥富市', 'ヤトミシ', '前ケ平', 'マエガヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県弥富市又八', '23', '23235', '4980004', '愛知県', 'アイチケン', '弥富市', 'ヤトミシ', '又八', 'マタハチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県弥富市又八町', '23', '23235', '4980004', '愛知県', 'アイチケン', '弥富市', 'ヤトミシ', '又八町', 'マタハチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県弥富市楽平', '23', '23235', '4980005', '愛知県', 'アイチケン', '弥富市', 'ヤトミシ', '楽平', 'ヨシヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県弥富市佐古木', '23', '23235', '4980006', '愛知県', 'アイチケン', '弥富市', 'ヤトミシ', '佐古木', 'サコギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県弥富市鎌倉町', '23', '23235', '4980007', '愛知県', 'アイチケン', '弥富市', 'ヤトミシ', '鎌倉町', 'カマクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県弥富市荷之上町', '23', '23235', '4980011', '愛知県', 'アイチケン', '弥富市', 'ヤトミシ', '荷之上町', 'ニノウエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県弥富市五之三町', '23', '23235', '4980012', '愛知県', 'アイチケン', '弥富市', 'ヤトミシ', '五之三町', 'ゴノサンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県弥富市川平', '23', '23235', '4980013', '愛知県', 'アイチケン', '弥富市', 'ヤトミシ', '川平', 'カワヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県弥富市五明', '23', '23235', '4980014', '愛知県', 'アイチケン', '弥富市', 'ヤトミシ', '五明', 'ゴミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県弥富市五明町', '23', '23235', '4980014', '愛知県', 'アイチケン', '弥富市', 'ヤトミシ', '五明町', 'ゴミョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県弥富市海老江', '23', '23235', '4980015', '愛知県', 'アイチケン', '弥富市', 'ヤトミシ', '海老江', 'エビエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県弥富市小島町', '23', '23235', '4980016', '愛知県', 'アイチケン', '弥富市', 'ヤトミシ', '小島町', 'コジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県弥富市前ケ須町', '23', '23235', '4980017', '愛知県', 'アイチケン', '弥富市', 'ヤトミシ', '前ケ須町', 'マエガスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県弥富市五之三川平', '23', '23235', '4980018', '愛知県', 'アイチケン', '弥富市', 'ヤトミシ', '五之三川平', 'ゴノサンカワヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県弥富市鯏浦町', '23', '23235', '4980021', '愛知県', 'アイチケン', '弥富市', 'ヤトミシ', '鯏浦町', 'ウグイウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県弥富市鯏浦町下六', '23', '23235', '4980022', '愛知県', 'アイチケン', '弥富市', 'ヤトミシ', '鯏浦町', 'ウグイウラチョウ', null, null, '下六', 'シモロク');
INSERT INTO `ms_addresses` VALUES ('50614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県弥富市鯏浦町上六', '23', '23235', '4980023', '愛知県', 'アイチケン', '弥富市', 'ヤトミシ', '鯏浦町', 'ウグイウラチョウ', null, null, '上六', 'カミロク');
INSERT INTO `ms_addresses` VALUES ('50615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県弥富市鯏浦町気開', '23', '23235', '4980024', '愛知県', 'アイチケン', '弥富市', 'ヤトミシ', '鯏浦町', 'ウグイウラチョウ', null, null, '気開', 'キトケ');
INSERT INTO `ms_addresses` VALUES ('50616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県弥富市平島町喜右味名', '23', '23235', '4980025', '愛知県', 'アイチケン', '弥富市', 'ヤトミシ', '平島町', 'ヘイジマチョウ', null, null, '喜右味名', 'キアジナ');
INSERT INTO `ms_addresses` VALUES ('50617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県弥富市鯏浦町西前新田', '23', '23235', '4980026', '愛知県', 'アイチケン', '弥富市', 'ヤトミシ', '鯏浦町', 'ウグイウラチョウ', null, null, '西前新田', 'ニシマエシンデン');
INSERT INTO `ms_addresses` VALUES ('50618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県弥富市鯏浦町南前新田', '23', '23235', '4980027', '愛知県', 'アイチケン', '弥富市', 'ヤトミシ', '鯏浦町', 'ウグイウラチョウ', null, null, '南前新田', 'ミナミマエシンデン');
INSERT INTO `ms_addresses` VALUES ('50619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県弥富市鯏浦町中六', '23', '23235', '4980028', '愛知県', 'アイチケン', '弥富市', 'ヤトミシ', '鯏浦町', 'ウグイウラチョウ', null, null, '中六', 'ナカロク');
INSERT INTO `ms_addresses` VALUES ('50620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県弥富市平島町', '23', '23235', '4980031', '愛知県', 'アイチケン', '弥富市', 'ヤトミシ', '平島町', 'ヘイジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県弥富市平島中', '23', '23235', '4980032', '愛知県', 'アイチケン', '弥富市', 'ヤトミシ', '平島中', 'ヘイジマナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県弥富市平島西', '23', '23235', '4980033', '愛知県', 'アイチケン', '弥富市', 'ヤトミシ', '平島西', 'ヘイジマニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県弥富市平島東', '23', '23235', '4980034', '愛知県', 'アイチケン', '弥富市', 'ヤトミシ', '平島東', 'ヘイジマヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県弥富市鎌島', '23', '23235', '4980035', '愛知県', 'アイチケン', '弥富市', 'ヤトミシ', '鎌島', 'カマジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県弥富市森津', '23', '23235', '4980036', '愛知県', 'アイチケン', '弥富市', 'ヤトミシ', '森津', 'モリヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県弥富市森津町', '23', '23235', '4980036', '愛知県', 'アイチケン', '弥富市', 'ヤトミシ', '森津町', 'モリヅチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県弥富市川原欠', '23', '23235', '4980037', '愛知県', 'アイチケン', '弥富市', 'ヤトミシ', '川原欠', 'カワラガケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県弥富市川原欠町', '23', '23235', '4980037', '愛知県', 'アイチケン', '弥富市', 'ヤトミシ', '川原欠町', 'カワラガケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県弥富市中山町', '23', '23235', '4980038', '愛知県', 'アイチケン', '弥富市', 'ヤトミシ', '中山町', 'ナカヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県弥富市芝井', '23', '23235', '4980041', '愛知県', 'アイチケン', '弥富市', 'ヤトミシ', '芝井', 'シバイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県弥富市芝井町', '23', '23235', '4980041', '愛知県', 'アイチケン', '弥富市', 'ヤトミシ', '芝井町', 'シバイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県弥富市松名', '23', '23235', '4980042', '愛知県', 'アイチケン', '弥富市', 'ヤトミシ', '松名', 'マツナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県弥富市松名町', '23', '23235', '4980042', '愛知県', 'アイチケン', '弥富市', 'ヤトミシ', '松名町', 'マツナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県弥富市寛延', '23', '23235', '4980043', '愛知県', 'アイチケン', '弥富市', 'ヤトミシ', '寛延', 'カンエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県弥富市間崎', '23', '23235', '4980044', '愛知県', 'アイチケン', '弥富市', 'ヤトミシ', '間崎', 'カンザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県弥富市間崎町', '23', '23235', '4980044', '愛知県', 'アイチケン', '弥富市', 'ヤトミシ', '間崎町', 'カンザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県弥富市稲元', '23', '23235', '4980045', '愛知県', 'アイチケン', '弥富市', 'ヤトミシ', '稲元', 'イナモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県弥富市稲元町', '23', '23235', '4980045', '愛知県', 'アイチケン', '弥富市', 'ヤトミシ', '稲元町', 'イナモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県弥富市三好', '23', '23235', '4980046', '愛知県', 'アイチケン', '弥富市', 'ヤトミシ', '三好', 'ミヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県弥富市三好町', '23', '23235', '4980046', '愛知県', 'アイチケン', '弥富市', 'ヤトミシ', '三好町', 'ミヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県弥富市加稲', '23', '23235', '4980047', '愛知県', 'アイチケン', '弥富市', 'ヤトミシ', '加稲', 'カイナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県弥富市稲吉', '23', '23235', '4980048', '愛知県', 'アイチケン', '弥富市', 'ヤトミシ', '稲吉', 'イナヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県弥富市狐地', '23', '23235', '4980051', '愛知県', 'アイチケン', '弥富市', 'ヤトミシ', '狐地', 'キツネジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県弥富市狐地町', '23', '23235', '4980051', '愛知県', 'アイチケン', '弥富市', 'ヤトミシ', '狐地町', 'キツネジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県弥富市稲荷', '23', '23235', '4980052', '愛知県', 'アイチケン', '弥富市', 'ヤトミシ', '稲荷', 'イナリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県弥富市稲荷町', '23', '23235', '4980052', '愛知県', 'アイチケン', '弥富市', 'ヤトミシ', '稲荷町', 'イナリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県弥富市稲狐町', '23', '23235', '4980053', '愛知県', 'アイチケン', '弥富市', 'ヤトミシ', '稲狐町', 'イナコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県弥富市三稲', '23', '23235', '4980054', '愛知県', 'アイチケン', '弥富市', 'ヤトミシ', '三稲', 'サント', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県弥富市三稲町', '23', '23235', '4980054', '愛知県', 'アイチケン', '弥富市', 'ヤトミシ', '三稲町', 'サントチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県弥富市境町', '23', '23235', '4980055', '愛知県', 'アイチケン', '弥富市', 'ヤトミシ', '境町', 'サカイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県弥富市稲荷崎', '23', '23235', '4980056', '愛知県', 'アイチケン', '弥富市', 'ヤトミシ', '稲荷崎', 'イナリザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県弥富市稲荷崎町', '23', '23235', '4980056', '愛知県', 'アイチケン', '弥富市', 'ヤトミシ', '稲荷崎町', 'イナリザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県弥富市中原', '23', '23235', '4980057', '愛知県', 'アイチケン', '弥富市', 'ヤトミシ', '中原', 'ナカハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県弥富市中原町', '23', '23235', '4980057', '愛知県', 'アイチケン', '弥富市', 'ヤトミシ', '中原町', 'ナカハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県弥富市富島', '23', '23235', '4980058', '愛知県', 'アイチケン', '弥富市', 'ヤトミシ', '富島', 'トミシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県弥富市富島町', '23', '23235', '4980058', '愛知県', 'アイチケン', '弥富市', 'ヤトミシ', '富島町', 'トミシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県弥富市操出', '23', '23235', '4980061', '愛知県', 'アイチケン', '弥富市', 'ヤトミシ', '操出', 'クリダシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県弥富市大谷', '23', '23235', '4980062', '愛知県', 'アイチケン', '弥富市', 'ヤトミシ', '大谷', 'オオタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県弥富市東末広', '23', '23235', '4980063', '愛知県', 'アイチケン', '弥富市', 'ヤトミシ', '東末広', 'ヒガシスエヒロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県弥富市西末広', '23', '23235', '4980064', '愛知県', 'アイチケン', '弥富市', 'ヤトミシ', '西末広', 'ニシスエヒロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県弥富市駒野町', '23', '23235', '4980065', '愛知県', 'アイチケン', '弥富市', 'ヤトミシ', '駒野町', 'コマノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県弥富市楠', '23', '23235', '4980066', '愛知県', 'アイチケン', '弥富市', 'ヤトミシ', '楠', 'クスノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県弥富市上野町', '23', '23235', '4980067', '愛知県', 'アイチケン', '弥富市', 'ヤトミシ', '上野町', 'ウエノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県弥富市鍋田町', '23', '23235', '4980068', '愛知県', 'アイチケン', '弥富市', 'ヤトミシ', '鍋田町', 'ナベタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛知県弥富市富浜', '23', '23235', '4980069', '愛知県', 'アイチケン', '弥富市', 'ヤトミシ', '富浜', 'トミハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名郡木曽岬町加路戸', '24', '24303', '4980801', '三重県', 'ミエケン', '桑名郡木曽岬町', 'クワナグンキソサキチョウ', '加路戸', 'カロト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名郡木曽岬町見入', '24', '24303', '4980802', '三重県', 'ミエケン', '桑名郡木曽岬町', 'クワナグンキソサキチョウ', '見入', 'ケンニュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名郡木曽岬町和泉', '24', '24303', '4980803', '三重県', 'ミエケン', '桑名郡木曽岬町', 'クワナグンキソサキチョウ', '和泉', 'イズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名郡木曽岬町小和泉', '24', '24303', '4980804', '三重県', 'ミエケン', '桑名郡木曽岬町', 'クワナグンキソサキチョウ', '小和泉', 'コイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名郡木曽岬町小林', '24', '24303', '4980805', '三重県', 'ミエケン', '桑名郡木曽岬町', 'クワナグンキソサキチョウ', '小林', 'コバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名郡木曽岬町外平喜', '24', '24303', '4980806', '三重県', 'ミエケン', '桑名郡木曽岬町', 'クワナグンキソサキチョウ', '外平喜', 'ソトビラキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名郡木曽岬町西対海地', '24', '24303', '4980807', '三重県', 'ミエケン', '桑名郡木曽岬町', 'クワナグンキソサキチョウ', '西対海地', 'ニシタイガンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名郡木曽岬町近江島', '24', '24303', '4980808', '三重県', 'ミエケン', '桑名郡木曽岬町', 'クワナグンキソサキチョウ', '近江島', 'オウミジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名郡木曽岬町栄', '24', '24303', '4980811', '三重県', 'ミエケン', '桑名郡木曽岬町', 'クワナグンキソサキチョウ', '栄', 'サカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名郡木曽岬町中和泉', '24', '24303', '4980812', '三重県', 'ミエケン', '桑名郡木曽岬町', 'クワナグンキソサキチョウ', '中和泉', 'ナカイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名郡木曽岬町富田子', '24', '24303', '4980813', '三重県', 'ミエケン', '桑名郡木曽岬町', 'クワナグンキソサキチョウ', '富田子', 'トミタネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名郡木曽岬町三崎', '24', '24303', '4980814', '三重県', 'ミエケン', '桑名郡木曽岬町', 'クワナグンキソサキチョウ', '三崎', 'ミサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名郡木曽岬町白鷺', '24', '24303', '4980815', '三重県', 'ミエケン', '桑名郡木曽岬町', 'クワナグンキソサキチョウ', '白鷺', 'ハクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名郡木曽岬町源緑輪中', '24', '24303', '4980816', '三重県', 'ミエケン', '桑名郡木曽岬町', 'クワナグンキソサキチョウ', '源緑輪中', 'ゲンロクワジュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名郡木曽岬町松永', '24', '24303', '4980817', '三重県', 'ミエケン', '桑名郡木曽岬町', 'クワナグンキソサキチョウ', '松永', 'マツナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名郡木曽岬町雁ケ地', '24', '24303', '4980818', '三重県', 'ミエケン', '桑名郡木曽岬町', 'クワナグンキソサキチョウ', '雁ケ地', 'ガンガジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名郡木曽岬町田代', '24', '24303', '4980819', '三重県', 'ミエケン', '桑名郡木曽岬町', 'クワナグンキソサキチョウ', '田代', 'タシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名郡木曽岬町新加路戸', '24', '24303', '4980821', '三重県', 'ミエケン', '桑名郡木曽岬町', 'クワナグンキソサキチョウ', '新加路戸', 'シンカロト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名郡木曽岬町見入流作', '24', '24303', '4980822', '三重県', 'ミエケン', '桑名郡木曽岬町', 'クワナグンキソサキチョウ', '見入流作', 'ケンニュウリュウサク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名郡木曽岬町和富', '24', '24303', '4980823', '三重県', 'ミエケン', '桑名郡木曽岬町', 'クワナグンキソサキチョウ', '和富', 'カズトミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市南区', '01', '01106', '0050000', '北海道', 'ホッカイドウ', '札幌市南区', 'サッポロシミナミク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('50691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道室蘭市', '01', '01205', '0500000', '北海道', 'ホッカイドウ', '室蘭市', 'ムロランシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('50692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市', '21', '21201', '5000000', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('50693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市南区澄川1条', '01', '01106', '0050001', '北海道', 'ホッカイドウ', '札幌市南区', 'サッポロシミナミク', '澄川1条', 'スミカワ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市南区澄川2条', '01', '01106', '0050002', '北海道', 'ホッカイドウ', '札幌市南区', 'サッポロシミナミク', '澄川2条', 'スミカワ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市南区澄川3条', '01', '01106', '0050003', '北海道', 'ホッカイドウ', '札幌市南区', 'サッポロシミナミク', '澄川3条', 'スミカワ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市南区澄川4条', '01', '01106', '0050004', '北海道', 'ホッカイドウ', '札幌市南区', 'サッポロシミナミク', '澄川4条', 'スミカワ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市南区澄川5条', '01', '01106', '0050005', '北海道', 'ホッカイドウ', '札幌市南区', 'サッポロシミナミク', '澄川5条', 'スミカワ05ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道室蘭市石川町', '01', '01205', '0500051', '北海道', 'ホッカイドウ', '室蘭市', 'ムロランシ', '石川町', 'イシカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道室蘭市香川町', '01', '01205', '0500052', '北海道', 'ホッカイドウ', '室蘭市', 'ムロランシ', '香川町', 'カガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道室蘭市神代町', '01', '01205', '0500053', '北海道', 'ホッカイドウ', '室蘭市', 'ムロランシ', '神代町', 'カミシロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道室蘭市白鳥台', '01', '01205', '0500054', '北海道', 'ホッカイドウ', '室蘭市', 'ムロランシ', '白鳥台', 'ハクチョウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道室蘭市崎守町', '01', '01205', '0500055', '北海道', 'ホッカイドウ', '室蘭市', 'ムロランシ', '崎守町', 'サキモリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市南区澄川6条', '01', '01106', '0050006', '北海道', 'ホッカイドウ', '札幌市南区', 'サッポロシミナミク', '澄川6条', 'スミカワ06ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道室蘭市八丁平', '01', '01205', '0500061', '北海道', 'ホッカイドウ', '室蘭市', 'ムロランシ', '八丁平', 'ハッチョウダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道室蘭市高平町', '01', '01205', '0500062', '北海道', 'ホッカイドウ', '室蘭市', 'ムロランシ', '高平町', 'タカヒラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道室蘭市港北町', '01', '01205', '0500063', '北海道', 'ホッカイドウ', '室蘭市', 'ムロランシ', '港北町', 'コウホクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道室蘭市柏木町', '01', '01205', '0500064', '北海道', 'ホッカイドウ', '室蘭市', 'ムロランシ', '柏木町', 'カシワギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道室蘭市本輪西町', '01', '01205', '0500065', '北海道', 'ホッカイドウ', '室蘭市', 'ムロランシ', '本輪西町', 'モトワニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道室蘭市幌萌町', '01', '01205', '0500066', '北海道', 'ホッカイドウ', '室蘭市', 'ムロランシ', '幌萌町', 'ホロモエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道室蘭市陣屋町', '01', '01205', '0500067', '北海道', 'ホッカイドウ', '室蘭市', 'ムロランシ', '陣屋町', 'ジンヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市南区澄川', '01', '01106', '0050007', '北海道', 'ホッカイドウ', '札幌市南区', 'サッポロシミナミク', '澄川', 'スミカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道室蘭市水元町', '01', '01205', '0500071', '北海道', 'ホッカイドウ', '室蘭市', 'ムロランシ', '水元町', 'ミズモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道室蘭市高砂町', '01', '01205', '0500072', '北海道', 'ホッカイドウ', '室蘭市', 'ムロランシ', '高砂町', 'タカサゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道室蘭市宮の森町', '01', '01205', '0500073', '北海道', 'ホッカイドウ', '室蘭市', 'ムロランシ', '宮の森町', 'ミヤノモリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道室蘭市中島町', '01', '01205', '0500074', '北海道', 'ホッカイドウ', '室蘭市', 'ムロランシ', '中島町', 'ナカジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道室蘭市中島本町', '01', '01205', '0500075', '北海道', 'ホッカイドウ', '室蘭市', 'ムロランシ', '中島本町', 'ナカジマホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道室蘭市知利別町', '01', '01205', '0500076', '北海道', 'ホッカイドウ', '室蘭市', 'ムロランシ', '知利別町', 'チリベツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道室蘭市天神町', '01', '01205', '0500077', '北海道', 'ホッカイドウ', '室蘭市', 'ムロランシ', '天神町', 'テンジンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市南区真駒内', '01', '01106', '0050008', '北海道', 'ホッカイドウ', '札幌市南区', 'サッポロシミナミク', '真駒内', 'マコマナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道室蘭市日の出町', '01', '01205', '0500081', '北海道', 'ホッカイドウ', '室蘭市', 'ムロランシ', '日の出町', 'ヒノデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道室蘭市寿町', '01', '01205', '0500082', '北海道', 'ホッカイドウ', '室蘭市', 'ムロランシ', '寿町', 'コトブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道室蘭市東町', '01', '01205', '0500083', '北海道', 'ホッカイドウ', '室蘭市', 'ムロランシ', '東町', 'ヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道室蘭市みゆき町', '01', '01205', '0500084', '北海道', 'ホッカイドウ', '室蘭市', 'ムロランシ', 'みゆき町', 'ミユキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道室蘭市輪西町', '01', '01205', '0500085', '北海道', 'ホッカイドウ', '室蘭市', 'ムロランシ', '輪西町', 'ワニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道室蘭市大沢町', '01', '01205', '0500086', '北海道', 'ホッカイドウ', '室蘭市', 'ムロランシ', '大沢町', 'オオサワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道室蘭市仲町', '01', '01205', '0500087', '北海道', 'ホッカイドウ', '室蘭市', 'ムロランシ', '仲町', 'ナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市南区真駒内東町', '01', '01106', '0050011', '北海道', 'ホッカイドウ', '札幌市南区', 'サッポロシミナミク', '真駒内東町', 'マコマナイヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市南区真駒内上町', '01', '01106', '0050012', '北海道', 'ホッカイドウ', '札幌市南区', 'サッポロシミナミク', '真駒内上町', 'マコマナイカミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市南区真駒内緑町', '01', '01106', '0050013', '北海道', 'ホッカイドウ', '札幌市南区', 'サッポロシミナミク', '真駒内緑町', 'マコマナイミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市南区真駒内幸町', '01', '01106', '0050014', '北海道', 'ホッカイドウ', '札幌市南区', 'サッポロシミナミク', '真駒内幸町', 'マコマナイサイワイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市南区真駒内泉町', '01', '01106', '0050015', '北海道', 'ホッカイドウ', '札幌市南区', 'サッポロシミナミク', '真駒内泉町', 'マコマナイイズミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市南区真駒内南町', '01', '01106', '0050016', '北海道', 'ホッカイドウ', '札幌市南区', 'サッポロシミナミク', '真駒内南町', 'マコマナイミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市南区真駒内公園', '01', '01106', '0050017', '北海道', 'ホッカイドウ', '札幌市南区', 'サッポロシミナミク', '真駒内公園', 'マコマナイコウエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市南区真駒内曙町', '01', '01106', '0050018', '北海道', 'ホッカイドウ', '札幌市南区', 'サッポロシミナミク', '真駒内曙町', 'マコマナイアケボノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市南区真駒内本町', '01', '01106', '0050021', '北海道', 'ホッカイドウ', '札幌市南区', 'サッポロシミナミク', '真駒内本町', 'マコマナイホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市南区真駒内柏丘', '01', '01106', '0050022', '北海道', 'ホッカイドウ', '札幌市南区', 'サッポロシミナミク', '真駒内柏丘', 'マコマナイカシワオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市南区南30条西', '01', '01106', '0050030', '北海道', 'ホッカイドウ', '札幌市南区', 'サッポロシミナミク', '南30条西', 'ミナミ30ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市南区南31条西', '01', '01106', '0050031', '北海道', 'ホッカイドウ', '札幌市南区', 'サッポロシミナミク', '南31条西', 'ミナミ31ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市南区南32条西', '01', '01106', '0050032', '北海道', 'ホッカイドウ', '札幌市南区', 'サッポロシミナミク', '南32条西', 'ミナミ32ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市南区南33条西', '01', '01106', '0050033', '北海道', 'ホッカイドウ', '札幌市南区', 'サッポロシミナミク', '南33条西', 'ミナミ33ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市南区南34条西', '01', '01106', '0050034', '北海道', 'ホッカイドウ', '札幌市南区', 'サッポロシミナミク', '南34条西', 'ミナミ34ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市南区南35条西', '01', '01106', '0050035', '北海道', 'ホッカイドウ', '札幌市南区', 'サッポロシミナミク', '南35条西', 'ミナミ35ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市南区南36条西', '01', '01106', '0050036', '北海道', 'ホッカイドウ', '札幌市南区', 'サッポロシミナミク', '南36条西', 'ミナミ36ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市南区南37条西', '01', '01106', '0050037', '北海道', 'ホッカイドウ', '札幌市南区', 'サッポロシミナミク', '南37条西', 'ミナミ37ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市南区南38条西', '01', '01106', '0050038', '北海道', 'ホッカイドウ', '札幌市南区', 'サッポロシミナミク', '南38条西', 'ミナミ38ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市南区南39条西', '01', '01106', '0050039', '北海道', 'ホッカイドウ', '札幌市南区', 'サッポロシミナミク', '南39条西', 'ミナミ39ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市南区藻岩下', '01', '01106', '0050040', '北海道', 'ホッカイドウ', '札幌市南区', 'サッポロシミナミク', '藻岩下', 'モイワシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市南区藻岩山', '01', '01106', '0050041', '北海道', 'ホッカイドウ', '札幌市南区', 'サッポロシミナミク', '藻岩山', 'モイワヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市鏡岩', '21', '21201', '5008001', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '鏡岩', 'カガミイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市御手洗', '21', '21201', '5008002', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '御手洗', 'ミタラシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市大宮町', '21', '21201', '5008003', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '大宮町', 'オオミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市千畳敷', '21', '21201', '5008004', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '千畳敷', 'センジョウジキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市上材木町', '21', '21201', '5008005', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '上材木町', 'カミザイモクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市堤外', '21', '21201', '5008006', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '堤外', 'テイガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市元浜町', '21', '21201', '5008007', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '元浜町', 'モトハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市玉井町', '21', '21201', '5008008', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '玉井町', 'タマイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市湊町', '21', '21201', '5008009', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '湊町', 'ミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市木挽町', '21', '21201', '5008011', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '木挽町', 'コビキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市山口町', '21', '21201', '5008012', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '山口町', 'ヤマグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市松下町', '21', '21201', '5008013', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '松下町', 'マツシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市夕陽ケ丘', '21', '21201', '5008014', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '夕陽ケ丘', 'ユウヒガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市松山町', '21', '21201', '5008015', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '松山町', 'マツヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市松ケ枝町', '21', '21201', '5008016', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '松ケ枝町', 'マツガエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市梶川町', '21', '21201', '5008017', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '梶川町', 'カジカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市大仏町', '21', '21201', '5008018', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '大仏町', 'ダイブツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市益屋町', '21', '21201', '5008019', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '益屋町', 'マスヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市上茶屋町', '21', '21201', '5008021', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '上茶屋町', 'カミチャヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市下茶屋町', '21', '21201', '5008022', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '下茶屋町', 'シモチャヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市今町', '21', '21201', '5008023', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '今町', 'イママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市上新町', '21', '21201', '5008024', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '上新町', 'カミシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市久屋町', '21', '21201', '5008025', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '久屋町', 'ヒサヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市上大久和町', '21', '21201', '5008026', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '上大久和町', 'カミオオクワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市中大桑町', '21', '21201', '5008027', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '中大桑町', 'ナカオオクワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市西材木町', '21', '21201', '5008028', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '西材木町', 'ニシザイモクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市東材木町', '21', '21201', '5008029', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '東材木町', 'ヒガシザイモクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市蜂屋町', '21', '21201', '5008031', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '蜂屋町', 'ハチヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市中新町', '21', '21201', '5008032', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '中新町', 'ナカシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市魚屋町', '21', '21201', '5008033', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '魚屋町', 'ウオヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市本町', '21', '21201', '5008034', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市布屋町', '21', '21201', '5008035', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '布屋町', 'ヌノヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市甚衛町', '21', '21201', '5008036', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '甚衛町', 'ジンエイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市下新町', '21', '21201', '5008037', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '下新町', 'シモシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市大工町', '21', '21201', '5008038', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '大工町', 'ダイクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市下大桑町', '21', '21201', '5008039', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '下大桑町', 'シモオオクワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市靱屋町', '21', '21201', '5008041', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '靱屋町', 'ウツボヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市末広町', '21', '21201', '5008042', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '末広町', 'スエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市伊奈波通', '21', '21201', '5008043', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '伊奈波通', 'イナバドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市万力町', '21', '21201', '5008044', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '万力町', 'マンリキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市新桜町', '21', '21201', '5008045', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '新桜町', 'シンサクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市米屋町', '21', '21201', '5008046', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '米屋町', 'コメヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市中竹屋町', '21', '21201', '5008047', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '中竹屋町', 'ナカタケヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市大和町', '21', '21201', '5008048', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '大和町', 'ヤマトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市上竹屋町', '21', '21201', '5008049', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '上竹屋町', 'カミタケヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市駿河山', '21', '21201', '5008051', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '駿河山', 'スルガヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市鶯谷', '21', '21201', '5008052', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '鶯谷', 'ウグイスダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市鶯谷町', '21', '21201', '5008053', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '鶯谷町', 'ウグイスダニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市大門町', '21', '21201', '5008054', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '大門町', 'ダイモンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市笹土居町', '21', '21201', '5008055', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '笹土居町', 'ササドイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市下竹町', '21', '21201', '5008056', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '下竹町', 'シモタケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市上竹町', '21', '21201', '5008057', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '上竹町', 'カミタケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市常盤町', '21', '21201', '5008058', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '常盤町', 'トキワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市栄扇町', '21', '21201', '5008059', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '栄扇町', 'エイセンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市小熊町', '21', '21201', '5008061', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '小熊町', 'オグマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市初音町', '21', '21201', '5008062', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '初音町', 'ハツネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市金屋横町', '21', '21201', '5008063', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '金屋横町', 'カナヤヨコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市柳沢町', '21', '21201', '5008064', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '柳沢町', 'ヤナザワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市金屋町', '21', '21201', '5008065', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '金屋町', 'カナヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市下太田町', '21', '21201', '5008066', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '下太田町', 'シモオオタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市秋津町', '21', '21201', '5008067', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '秋津町', 'アキツマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市上太田町', '21', '21201', '5008068', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '上太田町', 'カミオオタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市今小町', '21', '21201', '5008069', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '今小町', 'イマコマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市柳町', '21', '21201', '5008071', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '柳町', 'ヤナギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市緑町', '21', '21201', '5008072', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '緑町', 'ミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市泉町', '21', '21201', '5008073', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '泉町', 'イズミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市七軒町', '21', '21201', '5008074', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '七軒町', 'ヒチケンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市室町', '21', '21201', '5008075', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '室町', 'ムロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市司町', '21', '21201', '5008076', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '司町', 'ツカサマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市伊吹町', '21', '21201', '5008077', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '伊吹町', 'イブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市柳生町', '21', '21201', '5008078', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '柳生町', 'ヤギュウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市御杉町', '21', '21201', '5008079', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '御杉町', 'オスギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市啓運町', '21', '21201', '5008081', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '啓運町', 'ケイウンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市矢島町', '21', '21201', '5008082', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '矢島町', 'ヤジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市間之町', '21', '21201', '5008083', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '間之町', 'アイノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市松屋町', '21', '21201', '5008084', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '松屋町', 'マツヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市白木町', '21', '21201', '5008085', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '白木町', 'シラキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市木造町', '21', '21201', '5008086', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '木造町', 'キヅクリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市堀江町', '21', '21201', '5008087', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '堀江町', 'ホリエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市四屋町', '21', '21201', '5008088', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '四屋町', 'ヨツヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市若松町', '21', '21201', '5008089', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '若松町', 'ワカマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市多賀町', '21', '21201', '5008101', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '多賀町', 'タガマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市粕森町', '21', '21201', '5008102', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '粕森町', 'カシモリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市藍川町', '21', '21201', '5008103', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '藍川町', 'アイカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市美園町', '21', '21201', '5008104', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '美園町', 'ミソノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市西園町', '21', '21201', '5008105', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '西園町', 'ニシゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市東高岩町', '21', '21201', '5008106', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '東高岩町', 'ヒガシコウガンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市高岩町', '21', '21201', '5008107', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '高岩町', 'コウガンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市川端町', '21', '21201', '5008108', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '川端町', 'カワバタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市朝日町', '21', '21201', '5008109', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '朝日町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市梅林', '21', '21201', '5008111', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '梅林', 'バイリン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市梅林南町', '21', '21201', '5008112', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '梅林南町', 'バイリンミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市金園町', '21', '21201', '5008113', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '金園町', 'カナゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市金竜町', '21', '21201', '5008114', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '金竜町', 'キンリュウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市田端町', '21', '21201', '5008115', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '田端町', 'タバタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市殿町', '21', '21201', '5008116', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '殿町', 'トノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市南殿町', '21', '21201', '5008117', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '南殿町', 'ミナミトノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市寺町', '21', '21201', '5008118', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '寺町', 'テラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市梅林西町', '21', '21201', '5008119', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '梅林西町', 'バイリンニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市上加納山', '21', '21201', '5008121', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '上加納山', 'カミカノウヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市旭見ケ池町', '21', '21201', '5008122', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '旭見ケ池町', 'ヒミガイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市雲竜町', '21', '21201', '5008123', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '雲竜町', 'ウンリュウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市宝来町', '21', '21201', '5008124', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '宝来町', 'ホウライチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市城望町', '21', '21201', '5008125', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '城望町', 'ジョウボウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市隆城町', '21', '21201', '5008126', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '隆城町', 'リュウジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市塩町', '21', '21201', '5008127', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '塩町', 'シオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市花月町', '21', '21201', '5008128', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '花月町', 'カゲツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市鶴見町', '21', '21201', '5008129', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '鶴見町', 'ツルミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市月ノ会町', '21', '21201', '5008131', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '月ノ会町', 'ツキノエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市尼ケ崎町', '21', '21201', '5008132', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '尼ケ崎町', 'アマガサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市永楽町', '21', '21201', '5008133', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '永楽町', 'エイラクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市岩栄町', '21', '21201', '5008134', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '岩栄町', 'イワエイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市織田塚町', '21', '21201', '5008135', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '織田塚町', 'オダヅカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市雪見町', '21', '21201', '5008136', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '雪見町', 'ユキミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市東興町', '21', '21201', '5008137', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '東興町', 'トウコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市中道北', '21', '21201', '5008138', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '中道北', 'ナカミチキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市庵町', '21', '21201', '5008139', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '庵町', 'イオリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市月丘町', '21', '21201', '5008141', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '月丘町', 'ツキオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市花沢町', '21', '21201', '5008142', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '花沢町', 'ハナザワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市瑞雲町', '21', '21201', '5008143', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '瑞雲町', 'ズイウンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市東栄町', '21', '21201', '5008144', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '東栄町', 'トウエイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市雲井町', '21', '21201', '5008145', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '雲井町', 'クモイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市九重町', '21', '21201', '5008146', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '九重町', 'ココノエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市三笠町', '21', '21201', '5008147', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '三笠町', 'ミカサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市曙町', '21', '21201', '5008148', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '曙町', 'アケボノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市戎町', '21', '21201', '5008149', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '戎町', 'エビスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市大黒町', '21', '21201', '5008151', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '大黒町', 'ダイコクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市入舟町', '21', '21201', '5008152', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '入舟町', 'イリフネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市石長町', '21', '21201', '5008153', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '石長町', 'イシナガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市木ノ下町', '21', '21201', '5008154', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '木ノ下町', 'キノシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市市ノ坪町', '21', '21201', '5008155', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '市ノ坪町', 'イチノツボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市祈年町', '21', '21201', '5008156', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '祈年町', 'キネンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市五坪', '21', '21201', '5008157', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '五坪', 'ゴツボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市五坪町', '21', '21201', '5008157', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '五坪町', 'ゴツボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市田神', '21', '21201', '5008158', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '田神', 'タガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市田神町', '21', '21201', '5008159', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '田神町', 'タガミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市茨木町', '21', '21201', '5008161', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '茨木町', 'イバラギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市高尾町', '21', '21201', '5008162', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '高尾町', 'タカオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市鶴舞町', '21', '21201', '5008163', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '鶴舞町', 'ツルマイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市鶴田町', '21', '21201', '5008164', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '鶴田町', 'ツルタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市老松町', '21', '21201', '5008165', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '老松町', 'オイマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市天王町', '21', '21201', '5008166', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '天王町', 'テンノウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市東金宝町', '21', '21201', '5008167', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '東金宝町', 'ヒガシキンポウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市東駒爪町', '21', '21201', '5008168', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '東駒爪町', 'ヒガシコマヅメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市溝旗町', '21', '21201', '5008169', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '溝旗町', 'ミゾバタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市高森町', '21', '21201', '5008171', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '高森町', 'タカモリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市白山町', '21', '21201', '5008172', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '白山町', 'ハクサンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市田生越町', '21', '21201', '5008173', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '田生越町', 'タショウゴエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市栗矢田町', '21', '21201', '5008174', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '栗矢田町', 'クリヤダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市長住町', '21', '21201', '5008175', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '長住町', 'ナガズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市県町', '21', '21201', '5008176', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '県町', 'アガタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市長旗町', '21', '21201', '5008177', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '長旗町', 'ナガハタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市清住町', '21', '21201', '5008178', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '清住町', 'キヨズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市元住町', '21', '21201', '5008179', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '元住町', 'モトズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市御浪町', '21', '21201', '5008181', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '御浪町', 'オナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市美殿町', '21', '21201', '5008182', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '美殿町', 'ミトノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市一番町', '21', '21201', '5008183', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '一番町', 'イチバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市西駒爪町', '21', '21201', '5008184', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '西駒爪町', 'ニシコマヅメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市元町', '21', '21201', '5008185', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '元町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市霞町', '21', '21201', '5008186', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '霞町', 'カスミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市吉津町', '21', '21201', '5008187', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '吉津町', 'ヨシヅマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市二番町', '21', '21201', '5008188', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '二番町', 'ニバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市三番町', '21', '21201', '5008189', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '三番町', 'サンバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市日野北', '21', '21201', '5008207', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '日野北', 'ヒノキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市日野東', '21', '21201', '5008211', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '日野東', 'ヒノヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市日野南', '21', '21201', '5008212', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '日野南', 'ヒノミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市日野西', '21', '21201', '5008213', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '日野西', 'ヒノニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市天池', '21', '21201', '5008221', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '天池', 'アマイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市琴塚', '21', '21201', '5008222', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '琴塚', 'コトヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市水海道', '21', '21201', '5008223', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '水海道', 'ミズカイドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市高田', '21', '21201', '5008224', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '高田', 'タカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市岩地', '21', '21201', '5008225', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '岩地', 'イワチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市野一色', '21', '21201', '5008226', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '野一色', 'ノイッシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市北一色', '21', '21201', '5008227', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '北一色', 'キタイッシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市長森本町', '21', '21201', '5008228', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '長森本町', 'ナガモリホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市長森岩戸', '21', '21201', '5008229', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '長森岩戸', 'ナガモリイワド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市前一色西町', '21', '21201', '5008231', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '前一色西町', 'マエイッシキニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市前一色', '21', '21201', '5008232', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '前一色', 'マエイッシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市蔵前', '21', '21201', '5008233', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '蔵前', 'クラノマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市芋島', '21', '21201', '5008234', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '芋島', 'イモジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市東中島', '21', '21201', '5008235', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '東中島', 'ヒガシナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市手力町', '21', '21201', '5008236', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '手力町', 'テヂカラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市切通', '21', '21201', '5008237', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '切通', 'キリドオシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市細畑', '21', '21201', '5008238', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '細畑', 'ホソバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市領下', '21', '21201', '5008241', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '領下', 'リョウゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市細畑野寄', '21', '21201', '5008242', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '細畑野寄', 'ホソバタノヨリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市細畑華南', '21', '21201', '5008243', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '細畑華南', 'ホソバタカナン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市細畑塚浦', '21', '21201', '5008244', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '細畑塚浦', 'ホソバタツカウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市上川手', '21', '21201', '5008245', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '上川手', 'カミカワテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市下川手', '21', '21201', '5008246', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '下川手', 'シモカワテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市長森細畑', '21', '21201', '5008247', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '長森細畑', 'ナガモリホソバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市加納御車町', '21', '21201', '5008251', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '加納御車町', 'カノウミクルマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市加納舟田町', '21', '21201', '5008252', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '加納舟田町', 'カノウフナダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市薬師町', '21', '21201', '5008253', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '薬師町', 'ヤクシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市光樹町', '21', '21201', '5008254', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '光樹町', 'コウキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市朝霧町', '21', '21201', '5008255', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '朝霧町', 'アサギリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市八坂町', '21', '21201', '5008256', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '八坂町', 'ヤサカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市東川手', '21', '21201', '5008257', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '東川手', 'ヒガシカワテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市西川手', '21', '21201', '5008258', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '西川手', 'ニシカワテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市水主町', '21', '21201', '5008259', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '水主町', 'カコマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市茜部大野', '21', '21201', '5008261', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '茜部大野', 'アカナベオオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市茜部本郷', '21', '21201', '5008262', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '茜部本郷', 'アカナベホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市茜部新所', '21', '21201', '5008263', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '茜部新所', 'アカナベシンショ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市茜部辰新', '21', '21201', '5008264', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '茜部辰新', 'アカナベタツシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市茜部神清寺', '21', '21201', '5008265', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '茜部神清寺', 'アカナベシンセイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市境川', '21', '21201', '5008266', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '境川', 'サカイガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市茜部寺屋敷', '21', '21201', '5008267', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '茜部寺屋敷', 'アカナベテラヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市茜部菱野', '21', '21201', '5008268', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '茜部菱野', 'アカナベヒシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市茜部中島', '21', '21201', '5008269', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '茜部中島', 'アカナベナカシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市加納堀田町', '21', '21201', '5008271', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '加納堀田町', 'カノウホッタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市加納奥平町', '21', '21201', '5008272', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '加納奥平町', 'カノウオクダイラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市加納矢場町', '21', '21201', '5008273', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '加納矢場町', 'カノウヤバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市加納鷹匠町', '21', '21201', '5008274', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '加納鷹匠町', 'カノウタカショウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市加納花ノ木町', '21', '21201', '5008275', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '加納花ノ木町', 'カノウハナノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市加納南陽町', '21', '21201', '5008276', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '加納南陽町', 'カノウナンヨウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市加納立花町', '21', '21201', '5008277', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '加納立花町', 'カノウタチバナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市加納西山町', '21', '21201', '5008278', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '加納西山町', 'カノウニシヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市加納梅田町', '21', '21201', '5008279', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '加納梅田町', 'カノウウメダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市東鶉', '21', '21201', '5008281', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '東鶉', 'ヒガシウズラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市茜部大川', '21', '21201', '5008282', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '茜部大川', 'アカナベオオカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市茜部野瀬', '21', '21201', '5008283', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '茜部野瀬', 'アカナベノセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市茜町', '21', '21201', '5008284', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '茜町', 'アカネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市南鶉', '21', '21201', '5008285', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '南鶉', 'ミナミウズラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市西鶉', '21', '21201', '5008286', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '西鶉', 'ニシウズラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市北鶉', '21', '21201', '5008287', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '北鶉', 'キタウズラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市中鶉', '21', '21201', '5008288', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '中鶉', 'ナカウズラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市須賀', '21', '21201', '5008289', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '須賀', 'スガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市浪花町', '21', '21201', '5008301', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '浪花町', 'ナニワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市本郷町', '21', '21201', '5008302', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '本郷町', 'ホンゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市春日町', '21', '21201', '5008303', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '春日町', 'カスガマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市柳川町', '21', '21201', '5008304', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '柳川町', 'ヤナガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市沖ノ橋町', '21', '21201', '5008305', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '沖ノ橋町', 'オキノハシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市鍵屋東町', '21', '21201', '5008306', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '鍵屋東町', 'カギヤヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市弁天町', '21', '21201', '5008307', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '弁天町', 'ベンテンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市三橋町', '21', '21201', '5008308', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '三橋町', 'ミツハシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市都通', '21', '21201', '5008309', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '都通', 'ミヤコドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市長者町', '21', '21201', '5008311', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '長者町', 'チョウジャマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市村雨町', '21', '21201', '5008312', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '村雨町', 'ムラサメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市鍵屋中町', '21', '21201', '5008313', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '鍵屋中町', 'カギヤナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市鍵屋西町', '21', '21201', '5008314', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '鍵屋西町', 'カギヤニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市島田東町', '21', '21201', '5008315', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '島田東町', 'シマダヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市島田中町', '21', '21201', '5008316', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '島田中町', 'シマダナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市島田西町', '21', '21201', '5008317', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '島田西町', 'シマダニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市桜通', '21', '21201', '5008318', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '桜通', 'サクラドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市桜木町', '21', '21201', '5008319', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '桜木町', 'サクラギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市早田', '21', '21201', '5008319', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '早田', 'ソウデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市菊井町', '21', '21201', '5008321', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '菊井町', 'キクイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市香取町', '21', '21201', '5008322', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '香取町', 'カトリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市鹿島町', '21', '21201', '5008323', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '鹿島町', 'カシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市早苗町', '21', '21201', '5008324', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '早苗町', 'サナエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('50999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市寿町', '21', '21201', '5008325', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '寿町', 'コトブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市吹上町', '21', '21201', '5008326', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '吹上町', 'フキアゲチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市如月町', '21', '21201', '5008327', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '如月町', 'キサラギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市五反田町', '21', '21201', '5008328', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '五反田町', 'ゴタンダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市本荘町', '21', '21201', '5008329', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '本荘町', 'ホンジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市錦町', '21', '21201', '5008331', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '錦町', 'ニシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市羽衣町', '21', '21201', '5008332', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '羽衣町', 'ハゴロモチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市此花町', '21', '21201', '5008333', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '此花町', 'コノハナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市葭町', '21', '21201', '5008334', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '葭町', 'ヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市三歳町', '21', '21201', '5008335', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '三歳町', 'ミトセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市稲荷町', '21', '21201', '5008336', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '稲荷町', 'イナリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市雨踊町', '21', '21201', '5008337', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '雨踊町', 'アマオドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市千鳥町', '21', '21201', '5008339', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '千鳥町', 'チドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市南本荘四条通', '21', '21201', '5008341', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '南本荘四条通', 'ミナミホンジョウ04ジョウドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市南本荘三条通', '21', '21201', '5008342', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '南本荘三条通', 'ミナミホンジョウ03ジョウドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市南本荘二条通', '21', '21201', '5008343', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '南本荘二条通', 'ミナミホンジョウ02ジョウドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市南本荘一条通', '21', '21201', '5008344', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '南本荘一条通', 'ミナミホンジョウ01ジョウドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市菊地町', '21', '21201', '5008345', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '菊地町', 'キクチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市清', '21', '21201', '5008346', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '清', 'セイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市松原町', '21', '21201', '5008347', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '松原町', 'マツバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市三ツ又町', '21', '21201', '5008348', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '三ツ又町', 'ミツマタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市久保見町', '21', '21201', '5008349', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '久保見町', 'クボミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市清本町', '21', '21201', '5008351', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '清本町', 'セイホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市六条', '21', '21201', '5008352', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '六条', 'ロクジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市六条東', '21', '21201', '5008353', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '六条東', 'ロクジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市六条福寿町', '21', '21201', '5008354', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '六条福寿町', 'ロクジョウフクジュチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市六条片田', '21', '21201', '5008355', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '六条片田', 'ロクジョウカタダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市六条江東', '21', '21201', '5008356', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '六条江東', 'ロクジョウエヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市六条大溝', '21', '21201', '5008357', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '六条大溝', 'ロクジョウオオミゾ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市六条南', '21', '21201', '5008358', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '六条南', 'ロクジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市六条北', '21', '21201', '5008359', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '六条北', 'ロクジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市本荘西', '21', '21201', '5008361', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '本荘西', 'ホンジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市西荘', '21', '21201', '5008362', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '西荘', 'ニシノショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市爪', '21', '21201', '5008363', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '爪', 'ツメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市本荘中ノ町', '21', '21201', '5008364', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '本荘中ノ町', 'ホンジョウナカノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市柳森町', '21', '21201', '5008365', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '柳森町', 'ヤナギモリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市宇佐東町', '21', '21201', '5008366', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '宇佐東町', 'ウサヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市宇佐南', '21', '21201', '5008367', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '宇佐南', 'ウサミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市宇佐', '21', '21201', '5008368', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '宇佐', 'ウサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市敷島町', '21', '21201', '5008369', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '敷島町', 'シキシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市梅園町', '21', '21201', '5008371', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '梅園町', 'ウメゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市熊野町', '21', '21201', '5008372', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '熊野町', 'クマノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市大池町', '21', '21201', '5008373', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '大池町', 'オオイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市豊岡町', '21', '21201', '5008374', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '豊岡町', 'トヨオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市新興町', '21', '21201', '5008375', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '新興町', 'シンコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市富沢町', '21', '21201', '5008376', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '富沢町', 'トミザワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市瑞穂町', '21', '21201', '5008377', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '瑞穂町', 'ミズホチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市雲雀ケ丘', '21', '21201', '5008378', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '雲雀ケ丘', 'ヒバリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市権現町', '21', '21201', '5008379', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '権現町', 'ゴンゲンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市市橋', '21', '21201', '5008381', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '市橋', 'イチハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市薮田東', '21', '21201', '5008382', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '薮田東', 'ヤブタヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市江添', '21', '21201', '5008383', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '江添', 'エゾエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市薮田南', '21', '21201', '5008384', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '薮田南', 'ヤブタミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市下奈良', '21', '21201', '5008385', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '下奈良', 'シモナラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市薮田西', '21', '21201', '5008386', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '薮田西', 'ヤブタニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市薮田中', '21', '21201', '5008387', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '薮田中', 'ヤブタナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市今嶺', '21', '21201', '5008388', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '今嶺', 'イマミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市本荘', '21', '21201', '5008389', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '本荘', 'ホンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市安良田町', '21', '21201', '5008401', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '安良田町', 'アラタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市竜田町', '21', '21201', '5008402', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '竜田町', 'タツタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市一松道', '21', '21201', '5008403', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '一松道', 'イッショウドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市華陽', '21', '21201', '5008404', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '華陽', 'カヨウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市生田町', '21', '21201', '5008405', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '生田町', 'イクタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市平安町', '21', '21201', '5008406', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '平安町', 'ヘイアンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市高砂町', '21', '21201', '5008407', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '高砂町', 'タカサゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市住ノ江町', '21', '21201', '5008408', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '住ノ江町', 'スミノエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市幸ノ町', '21', '21201', '5008409', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '幸ノ町', 'コウノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市安宅町', '21', '21201', '5008411', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '安宅町', 'アタカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市松鴻町', '21', '21201', '5008412', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '松鴻町', 'ショウコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市加納東陽町', '21', '21201', '5008413', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '加納東陽町', 'カノウトウヨウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市加納東広江町', '21', '21201', '5008414', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '加納東広江町', 'カノウヒガシヒロエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市加納中広江町', '21', '21201', '5008415', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '加納中広江町', 'カノウナカヒロエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市加納徳川町', '21', '21201', '5008416', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '加納徳川町', 'カノウトクガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市加納清田町', '21', '21201', '5008417', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '加納清田町', 'カノウキヨダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市加納西広江町', '21', '21201', '5008418', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '加納西広江町', 'カノウニシヒロエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市加納北広江町', '21', '21201', '5008419', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '加納北広江町', 'カノウキタヒロエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市加納新柳町', '21', '21201', '5008421', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '加納新柳町', 'カノウシンヤナギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市加納安良町', '21', '21201', '5008422', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '加納安良町', 'カノウアラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市渋谷町', '21', '21201', '5008423', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '渋谷町', 'シブヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市加納柳町', '21', '21201', '5008424', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '加納柳町', 'カノウヤナギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市加納新町', '21', '21201', '5008425', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '加納新町', 'カノウシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市加納南広江町', '21', '21201', '5008426', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '加納南広江町', 'カノウミナミヒロエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市加納大石町', '21', '21201', '5008427', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '加納大石町', 'カノウオオイシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市加納桜道', '21', '21201', '5008428', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '加納桜道', 'カノウサクラミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市加納清水町', '21', '21201', '5008429', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '加納清水町', 'カノウシミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市加納八幡町', '21', '21201', '5008431', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '加納八幡町', 'カノウハチマンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市畷町', '21', '21201', '5008432', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '畷町', 'ナワテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市若杉町', '21', '21201', '5008433', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '若杉町', 'ワカスギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市向陽町', '21', '21201', '5008434', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '向陽町', 'コウヨウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市宮北町', '21', '21201', '5008435', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '宮北町', 'ミヤキタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市東明見町', '21', '21201', '5008436', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '東明見町', 'ヒガシアケミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市石切町', '21', '21201', '5008437', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '石切町', 'イシキリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市島原町', '21', '21201', '5008438', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '島原町', 'シマバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市村里町', '21', '21201', '5008439', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '村里町', 'ムラサトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市城東通', '21', '21201', '5008441', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '城東通', 'ジョウトウドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市正法寺町', '21', '21201', '5008442', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '正法寺町', 'ショウホウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市神楽町', '21', '21201', '5008443', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '神楽町', 'カグラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市西明見町', '21', '21201', '5008444', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '西明見町', 'ニシアケミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市八島町', '21', '21201', '5008445', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '八島町', 'ヤシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市矢倉町', '21', '21201', '5008446', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '矢倉町', 'ヤクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市大倉町', '21', '21201', '5008447', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '大倉町', 'オオクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市中洲町', '21', '21201', '5008448', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '中洲町', 'ナカスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市荒川町', '21', '21201', '5008449', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '荒川町', 'アラカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市加納上本町', '21', '21201', '5008451', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '加納上本町', 'カノウカミホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市加納朝日町', '21', '21201', '5008452', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '加納朝日町', 'カノウアサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市加納鉄砲町', '21', '21201', '5008453', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '加納鉄砲町', 'カノウテッポウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市加納永井町', '21', '21201', '5008454', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '加納永井町', 'カノウナガイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市加納栄町通', '21', '21201', '5008455', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '加納栄町通', 'カノウサカエマチドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市加納大黒町', '21', '21201', '5008456', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '加納大黒町', 'カノウダイコクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市加納青藤町', '21', '21201', '5008457', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '加納青藤町', 'カノウアオフジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市加納村松町', '21', '21201', '5008458', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '加納村松町', 'カノウムラマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市加納高柳町', '21', '21201', '5008459', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '加納高柳町', 'カノウタカヤナギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市加納黒木町', '21', '21201', '5008461', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '加納黒木町', 'カノウクロキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市加納神明町', '21', '21201', '5008462', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '加納神明町', 'カノウシンメイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市加納新本町', '21', '21201', '5008463', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '加納新本町', 'カノウシンホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市加納前田町', '21', '21201', '5008464', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '加納前田町', 'カノウマエダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市加納寿町', '21', '21201', '5008465', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '加納寿町', 'カノウコトブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市加納本石町', '21', '21201', '5008466', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '加納本石町', 'カノウホンゴクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市加納三笠町', '21', '21201', '5008467', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '加納三笠町', 'カノウミカサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市加納桜田町', '21', '21201', '5008468', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '加納桜田町', 'カノウサクラダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市加納竜興町', '21', '21201', '5008469', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '加納竜興町', 'カノウリュウコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市加納富士町', '21', '21201', '5008471', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '加納富士町', 'カノウフジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市加納清野町', '21', '21201', '5008472', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '加納清野町', 'カノウキヨノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市加納天神町', '21', '21201', '5008473', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '加納天神町', 'カノウテンジンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市加納本町', '21', '21201', '5008474', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '加納本町', 'カノウホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市加納坂井町', '21', '21201', '5008475', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '加納坂井町', 'カノウサカイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市加納愛宕町', '21', '21201', '5008476', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '加納愛宕町', 'カノウアタゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市加納水野町', '21', '21201', '5008477', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '加納水野町', 'カノウミズノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市加納伏見町', '21', '21201', '5008478', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '加納伏見町', 'カノウフシミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市加納菱野町', '21', '21201', '5008479', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '加納菱野町', 'カノウヒシノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市加納沓井町', '21', '21201', '5008481', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '加納沓井町', 'カノウクツイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市加納大手町', '21', '21201', '5008482', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '加納大手町', 'カノウオオテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市加納東丸町', '21', '21201', '5008483', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '加納東丸町', 'カノウヒガシマルチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市加納二之丸', '21', '21201', '5008484', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '加納二之丸', 'カノウニノマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市加納丸之内', '21', '21201', '5008485', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '加納丸之内', 'カノウマルノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市加納城南通', '21', '21201', '5008486', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '加納城南通', 'カノウジョウナンドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市加納長刀堀', '21', '21201', '5008487', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '加納長刀堀', 'カノウナギナタボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市加納西丸町', '21', '21201', '5008488', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '加納西丸町', 'カノウニシマルチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市稲荷山', '21', '21201', '5008489', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '稲荷山', 'イナリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市忠節町', '21', '21201', '5008801', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '忠節町', 'チュウセツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市不動町', '21', '21201', '5008802', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '不動町', 'フドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市佐久間町', '21', '21201', '5008803', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '佐久間町', 'サクマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市京町', '21', '21201', '5008804', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '京町', 'キョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市忠節三丁目南町', '21', '21201', '5008805', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '忠節三丁目南町', 'チュウセツサンチョウメミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市天神町', '21', '21201', '5008806', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '天神町', 'テンジンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市北野町', '21', '21201', '5008807', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '北野町', 'キタノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市永田町', '21', '21201', '5008808', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '永田町', 'ナガタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市平河町', '21', '21201', '5008809', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '平河町', 'ヒラカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市端詰町', '21', '21201', '5008811', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '端詰町', 'ハシヅメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市美江寺町', '21', '21201', '5008812', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '美江寺町', 'ミエジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市明徳町', '21', '21201', '5008813', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '明徳町', 'メイトクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市今川町', '21', '21201', '5008814', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '今川町', 'イマガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市梅河町', '21', '21201', '5008815', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '梅河町', 'ウメガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市菅原町', '21', '21201', '5008816', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '菅原町', 'スガハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市八ツ梅町', '21', '21201', '5008817', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '八ツ梅町', 'ヤツウメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市梅ケ枝町', '21', '21201', '5008818', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '梅ケ枝町', 'ウメガエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市千石町', '21', '21201', '5008819', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '千石町', 'センゴクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市鷹見町', '21', '21201', '5008821', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '鷹見町', 'タカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市今沢町', '21', '21201', '5008822', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '今沢町', 'イマザワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市江川町', '21', '21201', '5008823', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '江川町', 'エガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市北八ツ寺町', '21', '21201', '5008824', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '北八ツ寺町', 'キタヤツデラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市八ツ寺町', '21', '21201', '5008825', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '八ツ寺町', 'ヤツデラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市住吉町', '21', '21201', '5008826', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '住吉町', 'スミヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市弥八町', '21', '21201', '5008827', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '弥八町', 'ヤハチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市若宮町', '21', '21201', '5008828', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '若宮町', 'ワカミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市杉山町', '21', '21201', '5008829', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '杉山町', 'スギヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市弥生町', '21', '21201', '5008831', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '弥生町', 'ヤヨイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市小柳町', '21', '21201', '5008832', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '小柳町', 'コヤナギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市神田町', '21', '21201', '5008833', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '神田町', 'カンダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市羽根町', '21', '21201', '5008834', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '羽根町', 'ハネマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市玉宮町', '21', '21201', '5008835', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '玉宮町', 'タマミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市西玉宮町', '21', '21201', '5008836', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '西玉宮町', 'ニシタマミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市玉森町', '21', '21201', '5008837', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '玉森町', 'タマモリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市八幡町', '21', '21201', '5008838', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '八幡町', 'ハチマンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市蕪城町', '21', '21201', '5008839', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '蕪城町', 'カブラギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市高野町', '21', '21201', '5008841', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '高野町', 'タカノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市金町', '21', '21201', '5008842', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '金町', 'コガネマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市住田町', '21', '21201', '5008843', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '住田町', 'スミダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市吉野町', '21', '21201', '5008844', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '吉野町', 'ヨシノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市問屋町', '21', '21201', '5008845', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '問屋町', 'トイヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市玉姓町', '21', '21201', '5008846', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '玉姓町', 'ギョクセイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市金宝町', '21', '21201', '5008847', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '金宝町', 'キンポウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市神明町', '21', '21201', '5008848', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '神明町', 'シンメイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市金岡町', '21', '21201', '5008849', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '金岡町', 'カナオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市大宝町', '21', '21201', '5008851', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '大宝町', 'ダイホウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市日ノ本町', '21', '21201', '5008852', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '日ノ本町', 'ヒノモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市西問屋町', '21', '21201', '5008853', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '西問屋町', 'ニシトイヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市花園町', '21', '21201', '5008854', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '花園町', 'ハナゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市新栄町', '21', '21201', '5008855', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '新栄町', 'シンサカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市橋本町', '21', '21201', '5008856', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '橋本町', 'ハシモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市坂井町', '21', '21201', '5008857', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '坂井町', 'サカイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市福住町', '21', '21201', '5008858', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '福住町', 'フクズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市室津町', '21', '21201', '5008859', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '室津町', 'ムロツマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市千手堂北町', '21', '21201', '5008861', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '千手堂北町', 'センジュドウキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市千手堂中町', '21', '21201', '5008862', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '千手堂中町', 'センジュドウナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市千手堂南町', '21', '21201', '5008863', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '千手堂南町', 'センジュドウミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市真砂町', '21', '21201', '5008864', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '真砂町', 'マサゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市昭和町', '21', '21201', '5008865', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '昭和町', 'ショウワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市寺島町', '21', '21201', '5008866', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '寺島町', 'テラジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市木ノ本町', '21', '21201', '5008867', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '木ノ本町', 'キノモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市光明町', '21', '21201', '5008868', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '光明町', 'コウメイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市元宮町', '21', '21201', '5008869', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '元宮町', 'モトミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市大正町', '21', '21201', '5008871', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '大正町', 'タイショウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市栄枝町', '21', '21201', '5008872', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '栄枝町', 'サカエダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市大富町', '21', '21201', '5008873', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '大富町', 'オオトミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市銀町', '21', '21201', '5008874', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '銀町', 'シロガネマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市柳ケ瀬通', '21', '21201', '5008875', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '柳ケ瀬通', 'ヤナガセドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市日ノ出町', '21', '21201', '5008876', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '日ノ出町', 'ヒノデマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市雲雀町', '21', '21201', '5008877', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '雲雀町', 'ヒバリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市神室町', '21', '21201', '5008878', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '神室町', 'カムロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市徹明通', '21', '21201', '5008879', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '徹明通', 'テツメイドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市青柳町', '21', '21201', '5008881', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '青柳町', 'アオヤギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市西野町', '21', '21201', '5008882', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '西野町', 'ニシノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市吾妻町', '21', '21201', '5008883', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '吾妻町', 'アヅマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市池田町', '21', '21201', '5008884', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '池田町', 'イケダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市大柳町', '21', '21201', '5008885', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '大柳町', 'オオヤナギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市西野町七丁目北町', '21', '21201', '5008886', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '西野町七丁目北町', 'ニシノマチナナチョウメキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市西野町六丁目北町', '21', '21201', '5008887', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '西野町六丁目北町', 'ニシノマチロクチョウメキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市万年町', '21', '21201', '5008888', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '万年町', 'マンネンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市大縄場', '21', '21201', '5008889', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '大縄場', 'オオナワバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市香蘭', '21', '21201', '5008891', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '香蘭', 'コウラン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市曽我屋', '21', '21201', '5010101', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '曽我屋', 'ソガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市一日市場北町', '21', '21201', '5010102', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '一日市場北町', 'ヒトイチバキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市一日市場', '21', '21201', '5010103', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '一日市場', 'ヒトイチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市寺田', '21', '21201', '5010104', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '寺田', 'テラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市河渡', '21', '21201', '5010105', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '河渡', 'ゴウド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市西河渡', '21', '21201', '5010106', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '西河渡', 'ニシゴウド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市鏡島', '21', '21201', '5010111', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '鏡島', 'カガシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市鏡島町', '21', '21201', '5010111', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '鏡島町', 'カガシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市川原畑', '21', '21201', '5010111', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '川原畑', 'カワハラバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市鏡島精華', '21', '21201', '5010112', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '鏡島精華', 'カガシマセイカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市鏡島市場', '21', '21201', '5010113', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '鏡島市場', 'カガシマイチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市鏡島南', '21', '21201', '5010115', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '鏡島南', 'カガシマミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市江崎', '21', '21201', '5010117', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '江崎', 'エサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市大菅北', '21', '21201', '5010118', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '大菅北', 'オオスガキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市大菅南', '21', '21201', '5010119', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '大菅南', 'オオスガミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市江崎北', '21', '21201', '5010121', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '江崎北', 'エサキキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市江崎南', '21', '21201', '5010122', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '江崎南', 'エサキミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市鏡島西', '21', '21201', '5010123', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '鏡島西', 'カガシマニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県瑞穂市', '21', '21216', '5010200', '岐阜県', 'ギフケン', '瑞穂市', 'ミズホシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('51354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県瑞穂市馬場', '21', '21216', '5010201', '岐阜県', 'ギフケン', '瑞穂市', 'ミズホシ', '馬場', 'ババ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県瑞穂市馬場前畑町', '21', '21216', '5010202', '岐阜県', 'ギフケン', '瑞穂市', 'ミズホシ', '馬場前畑町', 'ババマエハタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県瑞穂市馬場上光町', '21', '21216', '5010203', '岐阜県', 'ギフケン', '瑞穂市', 'ミズホシ', '馬場上光町', 'ババジョウコウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県瑞穂市馬場春雨町', '21', '21216', '5010204', '岐阜県', 'ギフケン', '瑞穂市', 'ミズホシ', '馬場春雨町', 'ババハルサメマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県瑞穂市馬場小城町', '21', '21216', '5010205', '岐阜県', 'ギフケン', '瑞穂市', 'ミズホシ', '馬場小城町', 'ババコシロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県瑞穂市馬場北町', '21', '21216', '5010206', '岐阜県', 'ギフケン', '瑞穂市', 'ミズホシ', '馬場北町', 'ババキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県瑞穂市生津', '21', '21216', '5010211', '岐阜県', 'ギフケン', '瑞穂市', 'ミズホシ', '生津', 'ナマヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県瑞穂市生津滝坪町', '21', '21216', '5010212', '岐阜県', 'ギフケン', '瑞穂市', 'ミズホシ', '生津滝坪町', 'ナマヅタキツボマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県瑞穂市生津内宮町', '21', '21216', '5010213', '岐阜県', 'ギフケン', '瑞穂市', 'ミズホシ', '生津内宮町', 'ナマヅナイグウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県瑞穂市生津外宮東町', '21', '21216', '5010214', '岐阜県', 'ギフケン', '瑞穂市', 'ミズホシ', '生津外宮東町', 'ナマヅゲグウヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県瑞穂市生津天王東町', '21', '21216', '5010215', '岐阜県', 'ギフケン', '瑞穂市', 'ミズホシ', '生津天王東町', 'ナマヅテンノウヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県瑞穂市生津天王町', '21', '21216', '5010216', '岐阜県', 'ギフケン', '瑞穂市', 'ミズホシ', '生津天王町', 'ナマヅテンノウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県瑞穂市生津外宮前町', '21', '21216', '5010217', '岐阜県', 'ギフケン', '瑞穂市', 'ミズホシ', '生津外宮前町', 'ナマヅゲグウマエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県瑞穂市只越', '21', '21216', '5010221', '岐阜県', 'ギフケン', '瑞穂市', 'ミズホシ', '只越', 'タダコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県瑞穂市別府', '21', '21216', '5010222', '岐阜県', 'ギフケン', '瑞穂市', 'ミズホシ', '別府', 'ベップ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県瑞穂市穂積', '21', '21216', '5010223', '岐阜県', 'ギフケン', '瑞穂市', 'ミズホシ', '穂積', 'ホヅミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県瑞穂市稲里', '21', '21216', '5010224', '岐阜県', 'ギフケン', '瑞穂市', 'ミズホシ', '稲里', 'イナサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県瑞穂市祖父江', '21', '21216', '5010225', '岐阜県', 'ギフケン', '瑞穂市', 'ミズホシ', '祖父江', 'ソブエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県瑞穂市野白新田', '21', '21216', '5010231', '岐阜県', 'ギフケン', '瑞穂市', 'ミズホシ', '野白新田', 'ノバクシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県瑞穂市野田新田', '21', '21216', '5010232', '岐阜県', 'ギフケン', '瑞穂市', 'ミズホシ', '野田新田', 'ノダシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県瑞穂市宝江', '21', '21216', '5010233', '岐阜県', 'ギフケン', '瑞穂市', 'ミズホシ', '宝江', 'ホウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県瑞穂市牛牧', '21', '21216', '5010234', '岐阜県', 'ギフケン', '瑞穂市', 'ミズホシ', '牛牧', 'ウシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県瑞穂市十九条', '21', '21216', '5010235', '岐阜県', 'ギフケン', '瑞穂市', 'ミズホシ', '十九条', 'ジュウクジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県瑞穂市本田', '21', '21216', '5010236', '岐阜県', 'ギフケン', '瑞穂市', 'ミズホシ', '本田', 'ホンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県瑞穂市七崎', '21', '21216', '5010301', '岐阜県', 'ギフケン', '瑞穂市', 'ミズホシ', '七崎', 'ナナサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県瑞穂市居倉', '21', '21216', '5010302', '岐阜県', 'ギフケン', '瑞穂市', 'ミズホシ', '居倉', 'イクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県瑞穂市森', '21', '21216', '5010303', '岐阜県', 'ギフケン', '瑞穂市', 'ミズホシ', '森', 'モリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県瑞穂市田之上', '21', '21216', '5010304', '岐阜県', 'ギフケン', '瑞穂市', 'ミズホシ', '田之上', 'タノカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県瑞穂市宮田', '21', '21216', '5010305', '岐阜県', 'ギフケン', '瑞穂市', 'ミズホシ', '宮田', 'ミヤデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県瑞穂市大月', '21', '21216', '5010306', '岐阜県', 'ギフケン', '瑞穂市', 'ミズホシ', '大月', 'オオツキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県瑞穂市唐栗', '21', '21216', '5010307', '岐阜県', 'ギフケン', '瑞穂市', 'ミズホシ', '唐栗', 'カラクリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県瑞穂市重里', '21', '21216', '5010311', '岐阜県', 'ギフケン', '瑞穂市', 'ミズホシ', '重里', 'シゲサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県瑞穂市美江寺', '21', '21216', '5010312', '岐阜県', 'ギフケン', '瑞穂市', 'ミズホシ', '美江寺', 'ミエジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県瑞穂市十七条', '21', '21216', '5010313', '岐阜県', 'ギフケン', '瑞穂市', 'ミズホシ', '十七条', 'ジュウシチジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県瑞穂市十八条', '21', '21216', '5010314', '岐阜県', 'ギフケン', '瑞穂市', 'ミズホシ', '十八条', 'ジュウハチジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県瑞穂市横屋', '21', '21216', '5010321', '岐阜県', 'ギフケン', '瑞穂市', 'ミズホシ', '横屋', 'ヨコヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県瑞穂市古橋', '21', '21216', '5010322', '岐阜県', 'ギフケン', '瑞穂市', 'ミズホシ', '古橋', 'フルハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県瑞穂市中宮', '21', '21216', '5010323', '岐阜県', 'ギフケン', '瑞穂市', 'ミズホシ', '中宮', 'ナカミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県瑞穂市呂久', '21', '21216', '5010324', '岐阜県', 'ギフケン', '瑞穂市', 'ミズホシ', '呂久', 'ロク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県本巣市', '21', '21218', '5010400', '岐阜県', 'ギフケン', '本巣市', 'モトスシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('51400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県本巣郡北方町', '21', '21421', '5010400', '岐阜県', 'ギフケン', '本巣郡北方町', 'モトスグンキタガタチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('51401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県本巣市上保', '21', '21218', '5010401', '岐阜県', 'ギフケン', '本巣市', 'モトスシ', '上保', 'カミノホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県本巣市郡府', '21', '21218', '5010402', '岐阜県', 'ギフケン', '本巣市', 'モトスシ', '郡府', 'グンブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県本巣市北野', '21', '21218', '5010403', '岐阜県', 'ギフケン', '本巣市', 'モトスシ', '北野', 'キタノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県本巣市春近', '21', '21218', '5010404', '岐阜県', 'ギフケン', '本巣市', 'モトスシ', '春近', 'ハルチカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県本巣市石原', '21', '21218', '5010405', '岐阜県', 'ギフケン', '本巣市', 'モトスシ', '石原', 'イシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県本巣市三橋', '21', '21218', '5010406', '岐阜県', 'ギフケン', '本巣市', 'モトスシ', '三橋', 'ミツハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県本巣市仏生寺', '21', '21218', '5010407', '岐阜県', 'ギフケン', '本巣市', 'モトスシ', '仏生寺', 'ブッショウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県本巣市石神', '21', '21218', '5010410', '岐阜県', 'ギフケン', '本巣市', 'モトスシ', '石神', 'イシガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県本巣市上高屋', '21', '21218', '5010411', '岐阜県', 'ギフケン', '本巣市', 'モトスシ', '上高屋', 'カミタカヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県本巣市長屋', '21', '21218', '5010412', '岐阜県', 'ギフケン', '本巣市', 'モトスシ', '長屋', 'ナガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県本巣市見延', '21', '21218', '5010413', '岐阜県', 'ギフケン', '本巣市', 'モトスシ', '見延', 'ミノベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県本巣市数屋', '21', '21218', '5010414', '岐阜県', 'ギフケン', '本巣市', 'モトスシ', '数屋', 'カズヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県本巣市有里', '21', '21218', '5010415', '岐阜県', 'ギフケン', '本巣市', 'モトスシ', '有里', 'アリサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県本巣市随原', '21', '21218', '5010416', '岐阜県', 'ギフケン', '本巣市', 'モトスシ', '随原', 'ズイハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県本巣市屋井', '21', '21218', '5010417', '岐阜県', 'ギフケン', '本巣市', 'モトスシ', '屋井', 'ヤイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県本巣市七五三', '21', '21218', '5010418', '岐阜県', 'ギフケン', '本巣市', 'モトスシ', '七五三', 'シメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県本巣市早野', '21', '21218', '5010419', '岐阜県', 'ギフケン', '本巣市', 'モトスシ', '早野', 'ハヤノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県本巣郡北方町芝原西町', '21', '21421', '5010421', '岐阜県', 'ギフケン', '本巣郡北方町', 'モトスグンキタガタチョウ', '芝原西町', 'シバハラニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県本巣郡北方町芝原中町', '21', '21421', '5010422', '岐阜県', 'ギフケン', '本巣郡北方町', 'モトスグンキタガタチョウ', '芝原中町', 'シバハラナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県本巣郡北方町芝原東町', '21', '21421', '5010423', '岐阜県', 'ギフケン', '本巣郡北方町', 'モトスグンキタガタチョウ', '芝原東町', 'シバハラヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県本巣郡北方町朝日町', '21', '21421', '5010424', '岐阜県', 'ギフケン', '本巣郡北方町', 'モトスグンキタガタチョウ', '朝日町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県本巣郡北方町加茂', '21', '21421', '5010425', '岐阜県', 'ギフケン', '本巣郡北方町', 'モトスグンキタガタチョウ', '加茂', 'カモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県本巣郡北方町北方', '21', '21421', '5010431', '岐阜県', 'ギフケン', '本巣郡北方町', 'モトスグンキタガタチョウ', '北方', 'キタガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県本巣郡北方町一本松', '21', '21421', '5010432', '岐阜県', 'ギフケン', '本巣郡北方町', 'モトスグンキタガタチョウ', '一本松', 'イッポンマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県本巣郡北方町天狗堂', '21', '21421', '5010433', '岐阜県', 'ギフケン', '本巣郡北方町', 'モトスグンキタガタチョウ', '天狗堂', 'テングドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県本巣郡北方町小柳', '21', '21421', '5010434', '岐阜県', 'ギフケン', '本巣郡北方町', 'モトスグンキタガタチョウ', '小柳', 'コヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県本巣郡北方町春来町', '21', '21421', '5010435', '岐阜県', 'ギフケン', '本巣郡北方町', 'モトスグンキタガタチョウ', '春来町', 'ハルキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県本巣郡北方町長谷川西', '21', '21421', '5010436', '岐阜県', 'ギフケン', '本巣郡北方町', 'モトスグンキタガタチョウ', '長谷川西', 'ハセガワニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県本巣郡北方町清水', '21', '21421', '5010437', '岐阜県', 'ギフケン', '本巣郡北方町', 'モトスグンキタガタチョウ', '清水', 'シミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県本巣郡北方町平成', '21', '21421', '5010438', '岐阜県', 'ギフケン', '本巣郡北方町', 'モトスグンキタガタチョウ', '平成', 'ヘイセイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県本巣郡北方町曲路', '21', '21421', '5010441', '岐阜県', 'ギフケン', '本巣郡北方町', 'モトスグンキタガタチョウ', '曲路', 'スジカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県本巣郡北方町曲路東', '21', '21421', '5010442', '岐阜県', 'ギフケン', '本巣郡北方町', 'モトスグンキタガタチョウ', '曲路東', 'スジカイヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県本巣郡北方町柱本池之頭', '21', '21421', '5010443', '岐阜県', 'ギフケン', '本巣郡北方町', 'モトスグンキタガタチョウ', '柱本池之頭', 'ハシラモトイケノガシラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県本巣郡北方町柱本白坪', '21', '21421', '5010444', '岐阜県', 'ギフケン', '本巣郡北方町', 'モトスグンキタガタチョウ', '柱本白坪', 'ハシラモトシラツボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県本巣郡北方町柱本南', '21', '21421', '5010445', '岐阜県', 'ギフケン', '本巣郡北方町', 'モトスグンキタガタチョウ', '柱本南', 'ハシラモトミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県本巣郡北方町柱本', '21', '21421', '5010446', '岐阜県', 'ギフケン', '本巣郡北方町', 'モトスグンキタガタチョウ', '柱本', 'ハシラモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県本巣郡北方町高屋勅使', '21', '21421', '5010451', '岐阜県', 'ギフケン', '本巣郡北方町', 'モトスグンキタガタチョウ', '高屋勅使', 'タカヤチョクシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県本巣郡北方町高屋石末', '21', '21421', '5010452', '岐阜県', 'ギフケン', '本巣郡北方町', 'モトスグンキタガタチョウ', '高屋石末', 'タカヤイシズエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県本巣郡北方町高屋分木', '21', '21421', '5010453', '岐阜県', 'ギフケン', '本巣郡北方町', 'モトスグンキタガタチョウ', '高屋分木', 'タカヤブンギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県本巣郡北方町高屋白木', '21', '21421', '5010454', '岐阜県', 'ギフケン', '本巣郡北方町', 'モトスグンキタガタチョウ', '高屋白木', 'タカヤシラキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県本巣郡北方町高屋伊勢田', '21', '21421', '5010455', '岐阜県', 'ギフケン', '本巣郡北方町', 'モトスグンキタガタチョウ', '高屋伊勢田', 'タカヤイセデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県本巣郡北方町高屋条里', '21', '21421', '5010456', '岐阜県', 'ギフケン', '本巣郡北方町', 'モトスグンキタガタチョウ', '高屋条里', 'タカヤジョウリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県本巣郡北方町高屋太子', '21', '21421', '5010457', '岐阜県', 'ギフケン', '本巣郡北方町', 'モトスグンキタガタチョウ', '高屋太子', 'タカヤタイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県本巣郡北方町高屋', '21', '21421', '5010458', '岐阜県', 'ギフケン', '本巣郡北方町', 'モトスグンキタガタチョウ', '高屋', 'タカヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県本巣市上真桑', '21', '21218', '5010461', '岐阜県', 'ギフケン', '本巣市', 'モトスシ', '上真桑', 'カミマクワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県本巣市宗慶', '21', '21218', '5010462', '岐阜県', 'ギフケン', '本巣市', 'モトスシ', '宗慶', 'ソウケイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県本巣市小柿', '21', '21218', '5010463', '岐阜県', 'ギフケン', '本巣市', 'モトスシ', '小柿', 'コガキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県本巣市十四条', '21', '21218', '5010464', '岐阜県', 'ギフケン', '本巣市', 'モトスシ', '十四条', 'ジュウシジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県本巣市軽海', '21', '21218', '5010465', '岐阜県', 'ギフケン', '本巣市', 'モトスシ', '軽海', 'カルミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県本巣市下真桑', '21', '21218', '5010466', '岐阜県', 'ギフケン', '本巣市', 'モトスシ', '下真桑', 'シモマクワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県本巣市政田', '21', '21218', '5010471', '岐阜県', 'ギフケン', '本巣市', 'モトスシ', '政田', 'マサダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県本巣市下福島', '21', '21218', '5010472', '岐阜県', 'ギフケン', '本巣市', 'モトスシ', '下福島', 'シモフクジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県本巣市温井', '21', '21218', '5010473', '岐阜県', 'ギフケン', '本巣市', 'モトスシ', '温井', 'ヌクイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県本巣市国領', '21', '21218', '5010474', '岐阜県', 'ギフケン', '本巣市', 'モトスシ', '国領', 'コクリョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県本巣市浅木', '21', '21218', '5010475', '岐阜県', 'ギフケン', '本巣市', 'モトスシ', '浅木', 'アサギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県本巣市海老', '21', '21218', '5010476', '岐阜県', 'ギフケン', '本巣市', 'モトスシ', '海老', 'カイロウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡大野町', '21', '21403', '5010500', '岐阜県', 'ギフケン', '揖斐郡大野町', 'イビグンオオノチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('51465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡大野町稲富', '21', '21403', '5010501', '岐阜県', 'ギフケン', '揖斐郡大野町', 'イビグンオオノチョウ', '稲富', 'イナドミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡大野町古川', '21', '21403', '5010502', '岐阜県', 'ギフケン', '揖斐郡大野町', 'イビグンオオノチョウ', '古川', 'フルカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡大野町寺内', '21', '21403', '5010503', '岐阜県', 'ギフケン', '揖斐郡大野町', 'イビグンオオノチョウ', '寺内', 'ジナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡大野町野', '21', '21403', '5010504', '岐阜県', 'ギフケン', '揖斐郡大野町', 'イビグンオオノチョウ', '野', 'ノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡大野町稲畑', '21', '21403', '5010511', '岐阜県', 'ギフケン', '揖斐郡大野町', 'イビグンオオノチョウ', '稲畑', 'イナバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡大野町上秋', '21', '21403', '5010512', '岐阜県', 'ギフケン', '揖斐郡大野町', 'イビグンオオノチョウ', '上秋', 'カンダケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡大野町大野', '21', '21403', '5010513', '岐阜県', 'ギフケン', '揖斐郡大野町', 'イビグンオオノチョウ', '大野', 'オオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡大野町西方', '21', '21403', '5010514', '岐阜県', 'ギフケン', '揖斐郡大野町', 'イビグンオオノチョウ', '西方', 'ニシガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡大野町桜大門', '21', '21403', '5010515', '岐阜県', 'ギフケン', '揖斐郡大野町', 'イビグンオオノチョウ', '桜大門', 'サクラダイモン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡大野町黒野', '21', '21403', '5010521', '岐阜県', 'ギフケン', '揖斐郡大野町', 'イビグンオオノチョウ', '黒野', 'クロノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡大野町相羽', '21', '21403', '5010522', '岐阜県', 'ギフケン', '揖斐郡大野町', 'イビグンオオノチョウ', '相羽', 'アイバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡大野町下方', '21', '21403', '5010523', '岐阜県', 'ギフケン', '揖斐郡大野町', 'イビグンオオノチョウ', '下方', 'シモガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡大野町郡家', '21', '21403', '5010524', '岐阜県', 'ギフケン', '揖斐郡大野町', 'イビグンオオノチョウ', '郡家', 'グゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡大野町六里', '21', '21403', '5010525', '岐阜県', 'ギフケン', '揖斐郡大野町', 'イビグンオオノチョウ', '六里', 'ロクリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡大野町上磯', '21', '21403', '5010531', '岐阜県', 'ギフケン', '揖斐郡大野町', 'イビグンオオノチョウ', '上磯', 'カミイソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡大野町下磯', '21', '21403', '5010532', '岐阜県', 'ギフケン', '揖斐郡大野町', 'イビグンオオノチョウ', '下磯', 'シモイソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡大野町本庄', '21', '21403', '5010533', '岐阜県', 'ギフケン', '揖斐郡大野町', 'イビグンオオノチョウ', '本庄', 'ホンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡大野町下座倉', '21', '21403', '5010534', '岐阜県', 'ギフケン', '揖斐郡大野町', 'イビグンオオノチョウ', '下座倉', 'シモザグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡大野町加納', '21', '21403', '5010535', '岐阜県', 'ギフケン', '揖斐郡大野町', 'イビグンオオノチョウ', '加納', 'カノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡大野町小衣斐', '21', '21403', '5010551', '岐阜県', 'ギフケン', '揖斐郡大野町', 'イビグンオオノチョウ', '小衣斐', 'コエビ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡大野町大衣斐', '21', '21403', '5010552', '岐阜県', 'ギフケン', '揖斐郡大野町', 'イビグンオオノチョウ', '大衣斐', 'オオエビ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡大野町南方', '21', '21403', '5010553', '岐阜県', 'ギフケン', '揖斐郡大野町', 'イビグンオオノチョウ', '南方', 'ミナミガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡大野町五之里', '21', '21403', '5010554', '岐阜県', 'ギフケン', '揖斐郡大野町', 'イビグンオオノチョウ', '五之里', 'ゴノリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡大野町公郷', '21', '21403', '5010555', '岐阜県', 'ギフケン', '揖斐郡大野町', 'イビグンオオノチョウ', '公郷', 'クゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡大野町領家', '21', '21403', '5010556', '岐阜県', 'ギフケン', '揖斐郡大野町', 'イビグンオオノチョウ', '領家', 'リョウケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡大野町牛洞', '21', '21403', '5010561', '岐阜県', 'ギフケン', '揖斐郡大野町', 'イビグンオオノチョウ', '牛洞', 'ウシボラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡大野町松山', '21', '21403', '5010562', '岐阜県', 'ギフケン', '揖斐郡大野町', 'イビグンオオノチョウ', '松山', 'マツヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡大野町瀬古', '21', '21403', '5010563', '岐阜県', 'ギフケン', '揖斐郡大野町', 'イビグンオオノチョウ', '瀬古', 'セコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡大野町麻生', '21', '21403', '5010564', '岐阜県', 'ギフケン', '揖斐郡大野町', 'イビグンオオノチョウ', '麻生', 'アソウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡大野町中之元', '21', '21403', '5010565', '岐阜県', 'ギフケン', '揖斐郡大野町', 'イビグンオオノチョウ', '中之元', 'ナカノモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡揖斐川町', '21', '21401', '5010600', '岐阜県', 'ギフケン', '揖斐郡揖斐川町', 'イビグンイビガワチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('51497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡揖斐川町北方', '21', '21401', '5010601', '岐阜県', 'ギフケン', '揖斐郡揖斐川町', 'イビグンイビガワチョウ', '北方', 'キタガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡揖斐川町若松', '21', '21401', '5010602', '岐阜県', 'ギフケン', '揖斐郡揖斐川町', 'イビグンイビガワチョウ', '若松', 'ワカマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡揖斐川町上南方', '21', '21401', '5010603', '岐阜県', 'ギフケン', '揖斐郡揖斐川町', 'イビグンイビガワチョウ', '上南方', 'カミミナミガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡揖斐川町大光寺', '21', '21401', '5010604', '岐阜県', 'ギフケン', '揖斐郡揖斐川町', 'イビグンイビガワチョウ', '大光寺', 'ダイコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡揖斐川町極楽寺', '21', '21401', '5010605', '岐阜県', 'ギフケン', '揖斐郡揖斐川町', 'イビグンイビガワチョウ', '極楽寺', 'ゴクラクジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡揖斐川町房島', '21', '21401', '5010606', '岐阜県', 'ギフケン', '揖斐郡揖斐川町', 'イビグンイビガワチョウ', '房島', 'ボウジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡揖斐川町桂', '21', '21401', '5010607', '岐阜県', 'ギフケン', '揖斐郡揖斐川町', 'イビグンイビガワチョウ', '桂', 'カツラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡揖斐川町小谷', '21', '21401', '5010611', '岐阜県', 'ギフケン', '揖斐郡揖斐川町', 'イビグンイビガワチョウ', '小谷', 'コタテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡揖斐川町小野', '21', '21401', '5010612', '岐阜県', 'ギフケン', '揖斐郡揖斐川町', 'イビグンイビガワチョウ', '小野', 'オノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡揖斐川町志津山', '21', '21401', '5010613', '岐阜県', 'ギフケン', '揖斐郡揖斐川町', 'イビグンイビガワチョウ', '志津山', 'シヅヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡揖斐川町長良', '21', '21401', '5010614', '岐阜県', 'ギフケン', '揖斐郡揖斐川町', 'イビグンイビガワチョウ', '長良', 'ナガラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡揖斐川町清水', '21', '21401', '5010615', '岐阜県', 'ギフケン', '揖斐郡揖斐川町', 'イビグンイビガワチョウ', '清水', 'キヨミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡揖斐川町福島', '21', '21401', '5010616', '岐阜県', 'ギフケン', '揖斐郡揖斐川町', 'イビグンイビガワチョウ', '福島', 'フクジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡揖斐川町島', '21', '21401', '5010617', '岐阜県', 'ギフケン', '揖斐郡揖斐川町', 'イビグンイビガワチョウ', '島', 'シマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡揖斐川町上ミ野', '21', '21401', '5010618', '岐阜県', 'ギフケン', '揖斐郡揖斐川町', 'イビグンイビガワチョウ', '上ミ野', 'カミノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡揖斐川町三輪', '21', '21401', '5010619', '岐阜県', 'ギフケン', '揖斐郡揖斐川町', 'イビグンイビガワチョウ', '三輪', 'ミワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡揖斐川町下岡島', '21', '21401', '5010621', '岐阜県', 'ギフケン', '揖斐郡揖斐川町', 'イビグンイビガワチョウ', '下岡島', 'シモオカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡揖斐川町脛永', '21', '21401', '5010622', '岐阜県', 'ギフケン', '揖斐郡揖斐川町', 'イビグンイビガワチョウ', '脛永', 'ハギナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡揖斐川町和田', '21', '21401', '5010623', '岐阜県', 'ギフケン', '揖斐郡揖斐川町', 'イビグンイビガワチョウ', '和田', 'ワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡揖斐川町岡', '21', '21401', '5010624', '岐阜県', 'ギフケン', '揖斐郡揖斐川町', 'イビグンイビガワチョウ', '岡', 'オカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡揖斐川町黒田', '21', '21401', '5010625', '岐阜県', 'ギフケン', '揖斐郡揖斐川町', 'イビグンイビガワチョウ', '黒田', 'クロダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡揖斐川町瑞岩寺', '21', '21401', '5010626', '岐阜県', 'ギフケン', '揖斐郡揖斐川町', 'イビグンイビガワチョウ', '瑞岩寺', 'ズイガンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡揖斐川町市場', '21', '21401', '5010627', '岐阜県', 'ギフケン', '揖斐郡揖斐川町', 'イビグンイビガワチョウ', '市場', 'イチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡揖斐川町新宮', '21', '21401', '5010628', '岐阜県', 'ギフケン', '揖斐郡揖斐川町', 'イビグンイビガワチョウ', '新宮', 'シングウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡揖斐川町上岡島', '21', '21401', '5010631', '岐阜県', 'ギフケン', '揖斐郡揖斐川町', 'イビグンイビガワチョウ', '上岡島', 'カミオカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡揖斐川町上東野', '21', '21401', '5010632', '岐阜県', 'ギフケン', '揖斐郡揖斐川町', 'イビグンイビガワチョウ', '上東野', 'カミヒガシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡揖斐川町小島', '21', '21401', '5010633', '岐阜県', 'ギフケン', '揖斐郡揖斐川町', 'イビグンイビガワチョウ', '小島', 'コジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡揖斐川町上野', '21', '21401', '5010634', '岐阜県', 'ギフケン', '揖斐郡揖斐川町', 'イビグンイビガワチョウ', '上野', 'ウエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡揖斐川町白樫', '21', '21401', '5010635', '岐阜県', 'ギフケン', '揖斐郡揖斐川町', 'イビグンイビガワチョウ', '白樫', 'シラカシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡揖斐川町小津', '21', '21401', '5010701', '岐阜県', 'ギフケン', '揖斐郡揖斐川町', 'イビグンイビガワチョウ', '小津', 'オヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡揖斐川町東津汲', '21', '21401', '5010702', '岐阜県', 'ギフケン', '揖斐郡揖斐川町', 'イビグンイビガワチョウ', '東津汲', 'ヒガシツクミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡揖斐川町乙原', '21', '21401', '5010703', '岐阜県', 'ギフケン', '揖斐郡揖斐川町', 'イビグンイビガワチョウ', '乙原', 'オトハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡揖斐川町三倉', '21', '21401', '5010704', '岐阜県', 'ギフケン', '揖斐郡揖斐川町', 'イビグンイビガワチョウ', '三倉', 'ミクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡揖斐川町外津汲', '21', '21401', '5010705', '岐阜県', 'ギフケン', '揖斐郡揖斐川町', 'イビグンイビガワチョウ', '外津汲', 'トツクミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡揖斐川町西津汲', '21', '21401', '5010706', '岐阜県', 'ギフケン', '揖斐郡揖斐川町', 'イビグンイビガワチョウ', '西津汲', 'ニシツクミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡揖斐川町日坂', '21', '21401', '5010707', '岐阜県', 'ギフケン', '揖斐郡揖斐川町', 'イビグンイビガワチョウ', '日坂', 'ヒサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡揖斐川町樫原', '21', '21401', '5010708', '岐阜県', 'ギフケン', '揖斐郡揖斐川町', 'イビグンイビガワチョウ', '樫原', 'カシバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡揖斐川町鶴見', '21', '21401', '5010802', '岐阜県', 'ギフケン', '揖斐郡揖斐川町', 'イビグンイビガワチョウ', '鶴見', 'ツルミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡揖斐川町東杉原', '21', '21401', '5010803', '岐阜県', 'ギフケン', '揖斐郡揖斐川町', 'イビグンイビガワチョウ', '東杉原', 'ヒガシスギハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡揖斐川町東横山', '21', '21401', '5010804', '岐阜県', 'ギフケン', '揖斐郡揖斐川町', 'イビグンイビガワチョウ', '東横山', 'ヒガシヨコヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡揖斐川町西横山', '21', '21401', '5010805', '岐阜県', 'ギフケン', '揖斐郡揖斐川町', 'イビグンイビガワチョウ', '西横山', 'ニシヨコヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡揖斐川町塚', '21', '21401', '5010811', '岐阜県', 'ギフケン', '揖斐郡揖斐川町', 'イビグンイビガワチョウ', '塚', 'ツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡揖斐川町櫨原', '21', '21401', '5010812', '岐阜県', 'ギフケン', '揖斐郡揖斐川町', 'イビグンイビガワチョウ', '櫨原', 'ハゼハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡揖斐川町山手', '21', '21401', '5010813', '岐阜県', 'ギフケン', '揖斐郡揖斐川町', 'イビグンイビガワチョウ', '山手', 'ヤマテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡揖斐川町徳山', '21', '21401', '5010814', '岐阜県', 'ギフケン', '揖斐郡揖斐川町', 'イビグンイビガワチョウ', '徳山', 'トクヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡揖斐川町開田', '21', '21401', '5010815', '岐阜県', 'ギフケン', '揖斐郡揖斐川町', 'イビグンイビガワチョウ', '開田', 'カイデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡揖斐川町戸入', '21', '21401', '5010816', '岐阜県', 'ギフケン', '揖斐郡揖斐川町', 'イビグンイビガワチョウ', '戸入', 'トニュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡揖斐川町門入', '21', '21401', '5010817', '岐阜県', 'ギフケン', '揖斐郡揖斐川町', 'イビグンイビガワチョウ', '門入', 'カドニュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡揖斐川町坂内川上', '21', '21401', '5010901', '岐阜県', 'ギフケン', '揖斐郡揖斐川町', 'イビグンイビガワチョウ', '坂内川上', 'サカウチカワカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡揖斐川町坂内広瀬', '21', '21401', '5010902', '岐阜県', 'ギフケン', '揖斐郡揖斐川町', 'イビグンイビガワチョウ', '坂内広瀬', 'サカウチヒロセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡揖斐川町坂内坂本', '21', '21401', '5010903', '岐阜県', 'ギフケン', '揖斐郡揖斐川町', 'イビグンイビガワチョウ', '坂内坂本', 'サカウチサカモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市佐野', '21', '21201', '5011101', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '佐野', 'サノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市岩利', '21', '21201', '5011102', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '岩利', 'イワリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市彦坂川北', '21', '21201', '5011103', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '彦坂川北', 'ヒコサカカワキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市彦坂川上', '21', '21201', '5011104', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '彦坂川上', 'ヒコサカカワカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市彦坂', '21', '21201', '5011105', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '彦坂', 'ヒコサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市石谷', '21', '21201', '5011106', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '石谷', 'イシガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市村山', '21', '21201', '5011107', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '村山', 'ムラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市安食志良古', '21', '21201', '5011108', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '安食志良古', 'アジキシラコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市安食', '21', '21201', '5011109', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '安食', 'アジキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市大学北', '21', '21201', '5011111', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '大学北', 'ダイガクキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市柳戸', '21', '21201', '5011112', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '柳戸', 'ヤナギト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市大学西', '21', '21201', '5011113', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '大学西', 'ダイガクニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市今川', '21', '21201', '5011114', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '今川', 'イマガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市交人', '21', '21201', '5011115', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '交人', 'マシト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市深坂', '21', '21201', '5011116', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '深坂', 'フカサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市古市場', '21', '21201', '5011121', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '古市場', 'フルイチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市古市場老ノ上', '21', '21201', '5011122', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '古市場老ノ上', 'フルイチバオイノカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市古市場高田', '21', '21201', '5011123', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '古市場高田', 'フルイチバタカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市古市場中原', '21', '21201', '5011124', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '古市場中原', 'フルイチバナカハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市古市場東町田', '21', '21201', '5011125', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '古市場東町田', 'フルイチバヒガシマチダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市古市場高宮', '21', '21201', '5011126', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '古市場高宮', 'フルイチバタカミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市古市場神田', '21', '21201', '5011127', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '古市場神田', 'フルイチバジンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市洞', '21', '21201', '5011128', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '洞', 'ホラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市黒野', '21', '21201', '5011131', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '黒野', 'クロノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市折立', '21', '21201', '5011132', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '折立', 'オリタテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市北柿ケ瀬', '21', '21201', '5011133', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '北柿ケ瀬', 'キタカキガセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市南柿ケ瀬', '21', '21201', '5011134', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '南柿ケ瀬', 'ミナミカキガセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市木田', '21', '21201', '5011135', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '木田', 'キダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市黒野南', '21', '21201', '5011136', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '黒野南', 'クロノミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市東板谷', '21', '21201', '5011141', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '東板谷', 'ヒガシイタヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市東改田', '21', '21201', '5011142', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '東改田', 'ヒガシカイデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市東改田鶴田', '21', '21201', '5011143', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '東改田鶴田', 'ヒガシカイデンツルタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市東改田再勝', '21', '21201', '5011144', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '東改田再勝', 'ヒガシカイデンサイカチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市東改田腰前田', '21', '21201', '5011145', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '東改田腰前田', 'ヒガシカイデンコシマエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市下尻毛', '21', '21201', '5011146', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '下尻毛', 'シモシッケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市尻毛', '21', '21201', '5011147', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '尻毛', 'シッケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市上尻毛日吉', '21', '21201', '5011148', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '上尻毛日吉', 'カミシツケヒヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市上尻毛八幡', '21', '21201', '5011149', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '上尻毛八幡', 'カミシッケハチマン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市上尻毛', '21', '21201', '5011150', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '上尻毛', 'カミシッケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市川部', '21', '21201', '5011151', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '川部', 'カワベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市又丸', '21', '21201', '5011152', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '又丸', 'マタマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市又丸町畑', '21', '21201', '5011153', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '又丸町畑', 'マタマルチョウバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市又丸柳町', '21', '21201', '5011154', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '又丸柳町', 'マタマルヤナギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市又丸宮東', '21', '21201', '5011155', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '又丸宮東', 'マタマルミヤヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市又丸津島', '21', '21201', '5011156', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '又丸津島', 'マタマルツシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市又丸村中', '21', '21201', '5011157', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '又丸村中', 'マタマルムラナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市西改田先道', '21', '21201', '5011158', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '西改田先道', 'ニシカイデンセンドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市西改田', '21', '21201', '5011159', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '西改田', 'ニシカイデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市西改田松の木', '21', '21201', '5011159', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '西改田松の木', 'ニシカイデンマツノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市西改田川向', '21', '21201', '5011161', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '西改田川向', 'ニシカイデンカワムカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市西改田若宮', '21', '21201', '5011162', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '西改田若宮', 'ニシカイデンワカミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市西改田米野', '21', '21201', '5011163', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '西改田米野', 'ニシカイデンコメノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市西改田東改田入会地', '21', '21201', '5011164', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '西改田東改田入会地', 'ニシカイデンヒガシカイデンイリアイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市西改田宮西', '21', '21201', '5011165', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '西改田宮西', 'ニシカイデンミヤニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市西改田村前', '21', '21201', '5011166', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '西改田村前', 'ニシカイデンムラマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市西改田夏梅', '21', '21201', '5011167', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '西改田夏梅', 'ニシカイデンナツメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市西改田上の町', '21', '21201', '5011168', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '西改田上の町', 'ニシカイデンウエノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市西改田七石', '21', '21201', '5011169', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '西改田七石', 'ニシカイデンヒチコク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市御望', '21', '21201', '5011171', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '御望', 'ゴモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市下鵜飼', '21', '21201', '5011172', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '下鵜飼', 'シモウカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市中', '21', '21201', '5011173', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '中', 'ナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市小野', '21', '21201', '5011174', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '小野', 'コノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市下西郷', '21', '21201', '5011175', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '下西郷', 'シモサイゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市小西郷', '21', '21201', '5011176', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '小西郷', 'コサイゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市中西郷', '21', '21201', '5011177', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '中西郷', 'ナカサイゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市上西郷', '21', '21201', '5011178', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '上西郷', 'カミサイゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市雛倉', '21', '21201', '5011181', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '雛倉', 'ヒナクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市秋沢', '21', '21201', '5011182', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '秋沢', 'アキサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市則松', '21', '21201', '5011183', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '則松', 'ノリマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市西秋沢', '21', '21201', '5011184', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '西秋沢', 'ニシアキサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市奥', '21', '21201', '5011185', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '奥', 'オク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市外山', '21', '21201', '5011186', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '外山', 'トヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県本巣市山口', '21', '21218', '5011201', '岐阜県', 'ギフケン', '本巣市', 'モトスシ', '山口', 'ヤマグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県本巣市法林寺', '21', '21218', '5011202', '岐阜県', 'ギフケン', '本巣市', 'モトスシ', '法林寺', 'ホウリンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県本巣市宝珠ハイツ', '21', '21218', '5011203', '岐阜県', 'ギフケン', '本巣市', 'モトスシ', '宝珠ハイツ', 'ホウジュハイツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県本巣市文殊', '21', '21218', '5011203', '岐阜県', 'ギフケン', '本巣市', 'モトスシ', '文殊', 'モンジュ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県本巣市曽井中島', '21', '21218', '5011205', '岐阜県', 'ギフケン', '本巣市', 'モトスシ', '曽井中島', 'ソイナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県本巣市日当', '21', '21218', '5011231', '岐阜県', 'ギフケン', '本巣市', 'モトスシ', '日当', 'ヒナタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県本巣市金原', '21', '21218', '5011232', '岐阜県', 'ギフケン', '本巣市', 'モトスシ', '金原', 'キンバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県本巣市外山', '21', '21218', '5011233', '岐阜県', 'ギフケン', '本巣市', 'モトスシ', '外山', 'トヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県本巣市木知原', '21', '21218', '5011234', '岐阜県', 'ギフケン', '本巣市', 'モトスシ', '木知原', 'コチボラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県本巣市神海', '21', '21218', '5011235', '岐阜県', 'ギフケン', '本巣市', 'モトスシ', '神海', 'コウミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県本巣市佐原', '21', '21218', '5011236', '岐阜県', 'ギフケン', '本巣市', 'モトスシ', '佐原', 'サワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県本巣市鍋原', '21', '21218', '5011236', '岐阜県', 'ギフケン', '本巣市', 'モトスシ', '鍋原', 'ナベラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡揖斐川町谷汲高科', '21', '21401', '5011301', '岐阜県', 'ギフケン', '揖斐郡揖斐川町', 'イビグンイビガワチョウ', '谷汲高科', 'タニグミタカシナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡揖斐川町谷汲岐礼', '21', '21401', '5011302', '岐阜県', 'ギフケン', '揖斐郡揖斐川町', 'イビグンイビガワチョウ', '谷汲岐礼', 'タニグミキレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡揖斐川町谷汲長瀬', '21', '21401', '5011303', '岐阜県', 'ギフケン', '揖斐郡揖斐川町', 'イビグンイビガワチョウ', '谷汲長瀬', 'タニグミナガセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡揖斐川町谷汲徳積', '21', '21401', '5011311', '岐阜県', 'ギフケン', '揖斐郡揖斐川町', 'イビグンイビガワチョウ', '谷汲徳積', 'タニグミトクヅミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡揖斐川町谷汲大洞', '21', '21401', '5011312', '岐阜県', 'ギフケン', '揖斐郡揖斐川町', 'イビグンイビガワチョウ', '谷汲大洞', 'タニグミオオボラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡揖斐川町谷汲深坂', '21', '21401', '5011313', '岐阜県', 'ギフケン', '揖斐郡揖斐川町', 'イビグンイビガワチョウ', '谷汲深坂', 'タニグミフカサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡揖斐川町谷汲名礼', '21', '21401', '5011314', '岐阜県', 'ギフケン', '揖斐郡揖斐川町', 'イビグンイビガワチョウ', '谷汲名礼', 'タニグミナレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡揖斐川町谷汲有鳥', '21', '21401', '5011315', '岐阜県', 'ギフケン', '揖斐郡揖斐川町', 'イビグンイビガワチョウ', '谷汲有鳥', 'タニグミアツトリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡揖斐川町谷汲木曽屋', '21', '21401', '5011316', '岐阜県', 'ギフケン', '揖斐郡揖斐川町', 'イビグンイビガワチョウ', '谷汲木曽屋', 'タニグミキソヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡揖斐川町谷汲神原', '21', '21401', '5011317', '岐阜県', 'ギフケン', '揖斐郡揖斐川町', 'イビグンイビガワチョウ', '谷汲神原', 'タニグミカンバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県本巣市根尾越波', '21', '21218', '5011501', '岐阜県', 'ギフケン', '本巣市', 'モトスシ', '根尾越波', 'ネオオッパ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県本巣市根尾黒津', '21', '21218', '5011502', '岐阜県', 'ギフケン', '本巣市', 'モトスシ', '根尾黒津', 'ネオクロヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県本巣市根尾長嶺', '21', '21218', '5011503', '岐阜県', 'ギフケン', '本巣市', 'モトスシ', '根尾長嶺', 'ネオナガミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県本巣市根尾天神堂', '21', '21218', '5011504', '岐阜県', 'ギフケン', '本巣市', 'モトスシ', '根尾天神堂', 'ネオテンジンドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県本巣市根尾長島', '21', '21218', '5011505', '岐阜県', 'ギフケン', '本巣市', 'モトスシ', '根尾長島', 'ネオナガシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県本巣市根尾能郷', '21', '21218', '5011506', '岐阜県', 'ギフケン', '本巣市', 'モトスシ', '根尾能郷', 'ネオノウゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県本巣市根尾大河原', '21', '21218', '5011507', '岐阜県', 'ギフケン', '本巣市', 'モトスシ', '根尾大河原', 'ネオオオカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県本巣市根尾上大須', '21', '21218', '5011511', '岐阜県', 'ギフケン', '本巣市', 'モトスシ', '根尾上大須', 'ネオカミオオス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県本巣市根尾下大須', '21', '21218', '5011512', '岐阜県', 'ギフケン', '本巣市', 'モトスシ', '根尾下大須', 'ネオシモオオス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県本巣市根尾松田', '21', '21218', '5011513', '岐阜県', 'ギフケン', '本巣市', 'モトスシ', '根尾松田', 'ネオマツダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県本巣市根尾奥谷', '21', '21218', '5011514', '岐阜県', 'ギフケン', '本巣市', 'モトスシ', '根尾奥谷', 'ネオオクダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県本巣市根尾口谷', '21', '21218', '5011515', '岐阜県', 'ギフケン', '本巣市', 'モトスシ', '根尾口谷', 'ネオクチダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県本巣市根尾東板屋', '21', '21218', '5011516', '岐阜県', 'ギフケン', '本巣市', 'モトスシ', '根尾東板屋', 'ネオヒガシイタヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県本巣市根尾西板屋', '21', '21218', '5011517', '岐阜県', 'ギフケン', '本巣市', 'モトスシ', '根尾西板屋', 'ネオニシイタヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県本巣市根尾小鹿', '21', '21218', '5011518', '岐阜県', 'ギフケン', '本巣市', 'モトスシ', '根尾小鹿', 'ネオオジカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県本巣市根尾市場', '21', '21218', '5011521', '岐阜県', 'ギフケン', '本巣市', 'モトスシ', '根尾市場', 'ネオイチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県本巣市根尾樽見', '21', '21218', '5011522', '岐阜県', 'ギフケン', '本巣市', 'モトスシ', '根尾樽見', 'ネオタルミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県本巣市根尾川原', '21', '21218', '5011523', '岐阜県', 'ギフケン', '本巣市', 'モトスシ', '根尾川原', 'ネオカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県本巣市根尾板所', '21', '21218', '5011524', '岐阜県', 'ギフケン', '本巣市', 'モトスシ', '根尾板所', 'ネオイタショ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県本巣市根尾今村', '21', '21218', '5011525', '岐阜県', 'ギフケン', '本巣市', 'モトスシ', '根尾今村', 'ネオイマムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県本巣市根尾平野', '21', '21218', '5011526', '岐阜県', 'ギフケン', '本巣市', 'モトスシ', '根尾平野', 'ネオヒラノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県本巣市根尾宇津志', '21', '21218', '5011527', '岐阜県', 'ギフケン', '本巣市', 'モトスシ', '根尾宇津志', 'ネオウツシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県本巣市根尾高尾', '21', '21218', '5011528', '岐阜県', 'ギフケン', '本巣市', 'モトスシ', '根尾高尾', 'ネオタカオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県本巣市根尾水鳥', '21', '21218', '5011529', '岐阜県', 'ギフケン', '本巣市', 'モトスシ', '根尾水鳥', 'ネオミドリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県本巣市根尾門脇', '21', '21218', '5011531', '岐阜県', 'ギフケン', '本巣市', 'モトスシ', '根尾門脇', 'ネオカドワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県本巣市根尾越卒', '21', '21218', '5011532', '岐阜県', 'ギフケン', '本巣市', 'モトスシ', '根尾越卒', 'ネオオッソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県本巣市根尾中', '21', '21218', '5011533', '岐阜県', 'ギフケン', '本巣市', 'モトスシ', '根尾中', 'ネオナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県本巣市根尾神所', '21', '21218', '5011534', '岐阜県', 'ギフケン', '本巣市', 'モトスシ', '根尾神所', 'ネオコウドコロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県本巣市根尾大井', '21', '21218', '5011535', '岐阜県', 'ギフケン', '本巣市', 'モトスシ', '根尾大井', 'ネオオオイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県本巣市根尾八谷', '21', '21218', '5011536', '岐阜県', 'ギフケン', '本巣市', 'モトスシ', '根尾八谷', 'ネオヤタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県山県市', '21', '21215', '5012100', '岐阜県', 'ギフケン', '山県市', 'ヤマガタシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('51689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県山県市大桑', '21', '21215', '5012101', '岐阜県', 'ギフケン', '山県市', 'ヤマガタシ', '大桑', 'オオガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県山県市伊佐美', '21', '21215', '5012102', '岐阜県', 'ギフケン', '山県市', 'ヤマガタシ', '伊佐美', 'イサミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県山県市椎倉', '21', '21215', '5012103', '岐阜県', 'ギフケン', '山県市', 'ヤマガタシ', '椎倉', 'シグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県山県市東深瀬', '21', '21215', '5012104', '岐阜県', 'ギフケン', '山県市', 'ヤマガタシ', '東深瀬', 'ヒガシフカセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県山県市高富', '21', '21215', '5012105', '岐阜県', 'ギフケン', '山県市', 'ヤマガタシ', '高富', 'タカトミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県山県市赤尾', '21', '21215', '5012111', '岐阜県', 'ギフケン', '山県市', 'ヤマガタシ', '赤尾', 'アカオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県山県市西深瀬', '21', '21215', '5012112', '岐阜県', 'ギフケン', '山県市', 'ヤマガタシ', '西深瀬', 'ニシフカセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県山県市高木', '21', '21215', '5012113', '岐阜県', 'ギフケン', '山県市', 'ヤマガタシ', '高木', 'タカキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県山県市佐賀', '21', '21215', '5012114', '岐阜県', 'ギフケン', '山県市', 'ヤマガタシ', '佐賀', 'サガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県山県市梅原', '21', '21215', '5012115', '岐阜県', 'ギフケン', '山県市', 'ヤマガタシ', '梅原', 'ウメハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県山県市大門', '21', '21215', '5012121', '岐阜県', 'ギフケン', '山県市', 'ヤマガタシ', '大門', 'ダイモン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県山県市藤倉', '21', '21215', '5012122', '岐阜県', 'ギフケン', '山県市', 'ヤマガタシ', '藤倉', 'フジクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県山県市大森', '21', '21215', '5012123', '岐阜県', 'ギフケン', '山県市', 'ヤマガタシ', '大森', 'オオモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県山県市小倉', '21', '21215', '5012124', '岐阜県', 'ギフケン', '山県市', 'ヤマガタシ', '小倉', 'コグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県山県市洞田', '21', '21215', '5012125', '岐阜県', 'ギフケン', '山県市', 'ヤマガタシ', '洞田', 'ホラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県山県市平井', '21', '21215', '5012131', '岐阜県', 'ギフケン', '山県市', 'ヤマガタシ', '平井', 'ヒライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県山県市掛', '21', '21215', '5012132', '岐阜県', 'ギフケン', '山県市', 'ヤマガタシ', '掛', 'カケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県山県市上願', '21', '21215', '5012133', '岐阜県', 'ギフケン', '山県市', 'ヤマガタシ', '上願', 'ジョウガン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県山県市松尾', '21', '21215', '5012134', '岐阜県', 'ギフケン', '山県市', 'ヤマガタシ', '松尾', 'マツオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県山県市長滝', '21', '21215', '5012135', '岐阜県', 'ギフケン', '山県市', 'ヤマガタシ', '長滝', 'ナガタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県山県市柿野', '21', '21215', '5012251', '岐阜県', 'ギフケン', '山県市', 'ヤマガタシ', '柿野', 'カキノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県山県市相戸', '21', '21215', '5012252', '岐阜県', 'ギフケン', '山県市', 'ヤマガタシ', '相戸', 'アイド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県山県市日永', '21', '21215', '5012253', '岐阜県', 'ギフケン', '山県市', 'ヤマガタシ', '日永', 'ヒナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県山県市出戸', '21', '21215', '5012254', '岐阜県', 'ギフケン', '山県市', 'ヤマガタシ', '出戸', 'デト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県山県市船越', '21', '21215', '5012255', '岐阜県', 'ギフケン', '山県市', 'ヤマガタシ', '船越', 'フナコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県山県市青波', '21', '21215', '5012256', '岐阜県', 'ギフケン', '山県市', 'ヤマガタシ', '青波', 'アオナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県山県市富永', '21', '21215', '5012257', '岐阜県', 'ギフケン', '山県市', 'ヤマガタシ', '富永', 'トミナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県山県市中洞', '21', '21215', '5012258', '岐阜県', 'ギフケン', '山県市', 'ヤマガタシ', '中洞', 'ナカホラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県山県市岩佐', '21', '21215', '5012259', '岐阜県', 'ギフケン', '山県市', 'ヤマガタシ', '岩佐', 'イワサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県山県市神崎', '21', '21215', '5012301', '岐阜県', 'ギフケン', '山県市', 'ヤマガタシ', '神崎', 'カンザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県山県市円原', '21', '21215', '5012302', '岐阜県', 'ギフケン', '山県市', 'ヤマガタシ', '円原', 'エンバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県山県市片原', '21', '21215', '5012303', '岐阜県', 'ギフケン', '山県市', 'ヤマガタシ', '片原', 'カタハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県山県市椿', '21', '21215', '5012311', '岐阜県', 'ギフケン', '山県市', 'ヤマガタシ', '椿', 'ツバキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県山県市佐野', '21', '21215', '5012312', '岐阜県', 'ギフケン', '山県市', 'ヤマガタシ', '佐野', 'サノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県山県市徳永', '21', '21215', '5012313', '岐阜県', 'ギフケン', '山県市', 'ヤマガタシ', '徳永', 'トクナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県山県市笹賀', '21', '21215', '5012314', '岐阜県', 'ギフケン', '山県市', 'ヤマガタシ', '笹賀', 'ササガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県山県市田栗', '21', '21215', '5012315', '岐阜県', 'ギフケン', '山県市', 'ヤマガタシ', '田栗', 'タグリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県山県市谷合', '21', '21215', '5012321', '岐阜県', 'ギフケン', '山県市', 'ヤマガタシ', '谷合', 'タニアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県山県市葛原', '21', '21215', '5012331', '岐阜県', 'ギフケン', '山県市', 'ヤマガタシ', '葛原', 'クズハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市出屋敷', '21', '21201', '5012501', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '出屋敷', 'デヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市山県北野', '21', '21201', '5012502', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '山県北野', 'ヤマガタキタノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市北野阿原', '21', '21201', '5012503', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '北野阿原', 'キタノアワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市山県岩', '21', '21201', '5012504', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '山県岩', 'ヤマガタイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市山県岩東', '21', '21201', '5012505', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '山県岩東', 'ヤマガタイワヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市山県岩南', '21', '21201', '5012506', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '山県岩南', 'ヤマガタイワミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市山県岩中', '21', '21201', '5012507', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '山県岩中', 'ヤマガタイワナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市山県岩明光', '21', '21201', '5012508', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '山県岩明光', 'ヤマガタイワミョウコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市山県岩西', '21', '21201', '5012509', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '山県岩西', 'ヤマガタイワニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市北野北', '21', '21201', '5012511', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '北野北', 'キタノキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市北野東', '21', '21201', '5012512', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '北野東', 'キタノヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市三輪', '21', '21201', '5012513', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '三輪', 'ミワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市三輪宮前', '21', '21201', '5012514', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '三輪宮前', 'ミワミヤマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市三輪宮西', '21', '21201', '5012515', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '三輪宮西', 'ミワミヤニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市北野南', '21', '21201', '5012516', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '北野南', 'キタノミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市三輪ぷりんとぴあ', '21', '21201', '5012517', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '三輪ぷりんとぴあ', 'ミワプリントピア', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市北野西', '21', '21201', '5012518', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '北野西', 'キタノニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市北野西山', '21', '21201', '5012519', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '北野西山', 'キタノニシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市門屋', '21', '21201', '5012521', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '門屋', 'カドヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市門屋溝上', '21', '21201', '5012522', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '門屋溝上', 'カドヤミゾガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市茂地', '21', '21201', '5012523', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '茂地', 'モチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市春近古市場北', '21', '21201', '5012524', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '春近古市場北', 'ハルチカフルイチバキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市春近古市場南', '21', '21201', '5012525', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '春近古市場南', 'ハルチカフルイチバミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市門屋野崎', '21', '21201', '5012526', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '門屋野崎', 'カドヤノザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市門屋勢引', '21', '21201', '5012527', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '門屋勢引', 'カドヤセイヒキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市門屋門', '21', '21201', '5012528', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '門屋門', 'カドヤカド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市中屋東', '21', '21201', '5012531', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '中屋東', 'ナカヤヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市中屋西', '21', '21201', '5012532', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '中屋西', 'ナカヤニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市森東', '21', '21201', '5012533', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '森東', 'モリヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市森西', '21', '21201', '5012534', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '森西', 'モリニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市石原1丁目', '21', '21201', '5012535', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '石原', 'イシハラ', null, null, '1丁目', '01チョウメ');
INSERT INTO `ms_addresses` VALUES ('51761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市石原2丁目', '21', '21201', '5012535', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '石原', 'イシハラ', null, null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('51762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市石原3丁目', '21', '21201', '5012535', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '石原', 'イシハラ', null, null, '3丁目', '03チョウメ');
INSERT INTO `ms_addresses` VALUES ('51763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市太郎丸樫木', '21', '21201', '5012536', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '太郎丸樫木', 'タロウマルカシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市世保', '21', '21201', '5012541', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '世保', 'ヨヤス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市世保東', '21', '21201', '5012542', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '世保東', 'ヨヤスヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市世保南', '21', '21201', '5012543', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '世保南', 'ヨヤスミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市世保西', '21', '21201', '5012544', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '世保西', 'ヨヤスニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市世保北', '21', '21201', '5012545', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '世保北', 'ヨヤスキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市溝口', '21', '21201', '5012551', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '溝口', 'ミゾグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市溝口東', '21', '21201', '5012552', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '溝口東', 'ミゾグチヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市溝口中野', '21', '21201', '5012553', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '溝口中野', 'ミゾグチナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市溝口童子', '21', '21201', '5012554', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '溝口童子', 'ミゾグチドウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市溝口下', '21', '21201', '5012555', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '溝口下', 'ミゾグチシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市溝口中', '21', '21201', '5012556', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '溝口中', 'ミゾグチナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市溝口上', '21', '21201', '5012557', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '溝口上', 'ミゾグチカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市福富笠海道', '21', '21201', '5012561', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '福富笠海道', 'フクトミカサカイドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市福富出口', '21', '21201', '5012562', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '福富出口', 'フクトミデグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市福富迎田', '21', '21201', '5012563', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '福富迎田', 'フクトミムカエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市福富永田', '21', '21201', '5012564', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '福富永田', 'フクトミナガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市福富', '21', '21201', '5012565', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '福富', 'フクトミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市福富天神前', '21', '21201', '5012566', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '福富天神前', 'フクトミテンジンマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市福富町田', '21', '21201', '5012567', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '福富町田', 'フクトミチョウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市太郎丸向良', '21', '21201', '5012571', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '太郎丸向良', 'タロウマルムガイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市太郎丸北郷', '21', '21201', '5012572', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '太郎丸北郷', 'タロウマルキタゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市太郎丸諏訪', '21', '21201', '5012573', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '太郎丸諏訪', 'タロウマルスワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市太郎丸北浦', '21', '21201', '5012574', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '太郎丸北浦', 'タロウマルキタウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市太郎丸中島', '21', '21201', '5012575', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '太郎丸中島', 'タロウマルナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市太郎丸新屋敷', '21', '21201', '5012576', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '太郎丸新屋敷', 'タロウマルシンヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市太郎丸', '21', '21201', '5012577', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '太郎丸', 'タロウマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市太郎丸野田', '21', '21201', '5012578', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '太郎丸野田', 'タロウマルノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市太郎丸知之道', '21', '21201', '5012579', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '太郎丸知之道', 'タロウマルチノミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市武芸川町谷口', '21', '21205', '5012601', '岐阜県', 'ギフケン', '関市', 'セキシ', '武芸川町谷口', 'ムゲガワチョウタニグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市武芸川町小知野', '21', '21205', '5012602', '岐阜県', 'ギフケン', '関市', 'セキシ', '武芸川町小知野', 'ムゲガワチョウオジノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市武芸川町八幡', '21', '21205', '5012603', '岐阜県', 'ギフケン', '関市', 'セキシ', '武芸川町八幡', 'ムゲガワチョウハチマン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市武芸川町高野', '21', '21205', '5012604', '岐阜県', 'ギフケン', '関市', 'セキシ', '武芸川町高野', 'ムゲガワチョウタカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市武芸川町跡部', '21', '21205', '5012605', '岐阜県', 'ギフケン', '関市', 'セキシ', '武芸川町跡部', 'ムゲガワチョウアトベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市武芸川町平', '21', '21205', '5012606', '岐阜県', 'ギフケン', '関市', 'セキシ', '武芸川町平', 'ムゲガワチョウヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市武芸川町宇多院', '21', '21205', '5012607', '岐阜県', 'ギフケン', '関市', 'セキシ', '武芸川町宇多院', 'ムゲガワチョウウダイン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市洞戸栗原', '21', '21205', '5012801', '岐阜県', 'ギフケン', '関市', 'セキシ', '洞戸栗原', 'ホラドクリハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市洞戸通元寺', '21', '21205', '5012802', '岐阜県', 'ギフケン', '関市', 'セキシ', '洞戸通元寺', 'ホラドツウゲンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市洞戸飛瀬', '21', '21205', '5012803', '岐阜県', 'ギフケン', '関市', 'セキシ', '洞戸飛瀬', 'ホラドヒセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市洞戸尾倉', '21', '21205', '5012805', '岐阜県', 'ギフケン', '関市', 'セキシ', '洞戸尾倉', 'ホラドオグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市洞戸高賀', '21', '21205', '5012806', '岐阜県', 'ギフケン', '関市', 'セキシ', '洞戸高賀', 'ホラドコウカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市洞戸阿部', '21', '21205', '5012807', '岐阜県', 'ギフケン', '関市', 'セキシ', '洞戸阿部', 'ホラドアベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市洞戸高見', '21', '21205', '5012808', '岐阜県', 'ギフケン', '関市', 'セキシ', '洞戸高見', 'ホラドコウミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市洞戸小瀬見', '21', '21205', '5012809', '岐阜県', 'ギフケン', '関市', 'セキシ', '洞戸小瀬見', 'ホラドオゼミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市洞戸片', '21', '21205', '5012811', '岐阜県', 'ギフケン', '関市', 'セキシ', '洞戸片', 'ホラドカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市洞戸市場', '21', '21205', '5012812', '岐阜県', 'ギフケン', '関市', 'セキシ', '洞戸市場', 'ホラドイチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市洞戸菅谷', '21', '21205', '5012814', '岐阜県', 'ギフケン', '関市', 'セキシ', '洞戸菅谷', 'ホラドスガダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市洞戸黒谷', '21', '21205', '5012815', '岐阜県', 'ギフケン', '関市', 'セキシ', '洞戸黒谷', 'ホラドクロダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市洞戸大野', '21', '21205', '5012816', '岐阜県', 'ギフケン', '関市', 'セキシ', '洞戸大野', 'ホラドオオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市洞戸小坂', '21', '21205', '5012817', '岐阜県', 'ギフケン', '関市', 'セキシ', '洞戸小坂', 'ホラドコサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市板取', '21', '21205', '5012901', '岐阜県', 'ギフケン', '関市', 'セキシ', '板取', 'イタドリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市岩井', '21', '21201', '5013101', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '岩井', 'イワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市岩井万場', '21', '21201', '5013102', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '岩井万場', 'イワイマンバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市石原', '21', '21201', '5013104', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '石原', 'イシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市加野', '21', '21201', '5013107', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '加野', 'カノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市大蔵台', '21', '21201', '5013108', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '大蔵台', 'オオクラダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市向加野', '21', '21201', '5013109', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '向加野', 'ムカイカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市芥見大退', '21', '21201', '5013111', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '芥見大退', 'アクタミオオノギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市芥見東山', '21', '21201', '5013112', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '芥見東山', 'アクタミヒガシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市北山', '21', '21201', '5013113', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '北山', 'キタヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市芥見大船', '21', '21201', '5013114', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '芥見大船', 'アクタミオオブネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市上芥見', '21', '21201', '5013115', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '上芥見', 'カミアクタミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市芥見町屋', '21', '21201', '5013116', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '芥見町屋', 'アクタミマチヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市コモンヒルズ北山', '21', '21201', '5013117', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', 'コモンヒルズ北山', 'コモンヒルズキタヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市大洞桐ケ丘', '21', '21201', '5013121', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '大洞桐ケ丘', 'オオボラキリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市大洞紅葉が丘', '21', '21201', '5013122', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '大洞紅葉が丘', 'オオボラモミジガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市大洞柏台', '21', '21201', '5013123', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '大洞柏台', 'オオボラカシワダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市大洞', '21', '21201', '5013124', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '大洞', 'オオボラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市大洞緑山', '21', '21201', '5013125', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '大洞緑山', 'オオボラミドリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市大洞西', '21', '21201', '5013126', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '大洞西', 'オオボラニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市大洞桜台', '21', '21201', '5013127', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '大洞桜台', 'オオボラサクラダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市祇園', '21', '21201', '5013131', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '祇園', 'ギオン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市芥見長山', '21', '21201', '5013132', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '芥見長山', 'アクタミナガヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市芥見南山', '21', '21201', '5013133', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '芥見南山', 'アクタミミナミヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市芥見', '21', '21201', '5013134', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '芥見', 'アクタミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市芥見清水', '21', '21201', '5013135', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '芥見清水', 'アクタミキヨミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市芥見海戸山', '21', '21201', '5013136', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '芥見海戸山', 'アクタミカイトヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市芥見中野畑', '21', '21201', '5013141', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '芥見中野畑', 'アクタミナカノバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市諏訪山', '21', '21201', '5013142', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '諏訪山', 'スワヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市芥見影山', '21', '21201', '5013143', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '芥見影山', 'アクタミカゲヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市芥見大般若', '21', '21201', '5013144', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '芥見大般若', 'アクタミダイハンニャ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市芥見野畑', '21', '21201', '5013145', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '芥見野畑', 'アクタミノバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市芥見嵯峨', '21', '21201', '5013146', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '芥見嵯峨', 'アクタミサガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市芥見堀田', '21', '21201', '5013147', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '芥見堀田', 'アクタミホリタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市岩滝東', '21', '21201', '5013151', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '岩滝東', 'イワタキヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市岩滝西', '21', '21201', '5013152', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '岩滝西', 'イワタキニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市静が丘町', '21', '21201', '5013153', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '静が丘町', 'シズガオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市岩田東', '21', '21201', '5013154', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '岩田東', 'イワタヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市岩田坂', '21', '21201', '5013155', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '岩田坂', 'イワタザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市岩田西', '21', '21201', '5013156', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '岩田西', 'イワタニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市', '21', '21205', '5013200', '岐阜県', 'ギフケン', '関市', 'セキシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('51859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市小野', '21', '21205', '5013201', '岐阜県', 'ギフケン', '関市', 'セキシ', '小野', 'オノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市西神野', '21', '21205', '5013202', '岐阜県', 'ギフケン', '関市', 'セキシ', '西神野', 'ニシカミノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市神野', '21', '21205', '5013203', '岐阜県', 'ギフケン', '関市', 'セキシ', '神野', 'カミノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市上大野', '21', '21205', '5013204', '岐阜県', 'ギフケン', '関市', 'セキシ', '上大野', 'カミオオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市志津野', '21', '21205', '5013205', '岐阜県', 'ギフケン', '関市', 'セキシ', '志津野', 'シツノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市塔ノ洞', '21', '21205', '5013206', '岐阜県', 'ギフケン', '関市', 'セキシ', '塔ノ洞', 'トウノホラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市黒屋', '21', '21205', '5013207', '岐阜県', 'ギフケン', '関市', 'セキシ', '黒屋', 'クロヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市尾太町', '21', '21205', '5013210', '岐阜県', 'ギフケン', '関市', 'セキシ', '尾太町', 'オブトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市関ノ上', '21', '21205', '5013211', '岐阜県', 'ギフケン', '関市', 'セキシ', '関ノ上', 'セキノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市寺田', '21', '21205', '5013212', '岐阜県', 'ギフケン', '関市', 'セキシ', '寺田', 'テラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市東貸上', '21', '21205', '5013213', '岐阜県', 'ギフケン', '関市', 'セキシ', '東貸上', 'ヒガシカシアゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市貸上町', '21', '21205', '5013214', '岐阜県', 'ギフケン', '関市', 'セキシ', '貸上町', 'カシアゲチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市西境松町', '21', '21205', '5013215', '岐阜県', 'ギフケン', '関市', 'セキシ', '西境松町', 'ニシサカイマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市水ノ輪町', '21', '21205', '5013216', '岐阜県', 'ギフケン', '関市', 'セキシ', '水ノ輪町', 'ミズノワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市下有知', '21', '21205', '5013217', '岐阜県', 'ギフケン', '関市', 'セキシ', '下有知', 'シモウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市東志摩', '21', '21205', '5013218', '岐阜県', 'ギフケン', '関市', 'セキシ', '東志摩', 'ヒガシシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市のぞみケ丘', '21', '21205', '5013219', '岐阜県', 'ギフケン', '関市', 'セキシ', 'のぞみケ丘', 'ノゾミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市西貸上', '21', '21205', '5013221', '岐阜県', 'ギフケン', '関市', 'セキシ', '西貸上', 'ニシカシアゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市南貸上', '21', '21205', '5013222', '岐阜県', 'ギフケン', '関市', 'セキシ', '南貸上', 'ミナミカシアゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市竪切南', '21', '21205', '5013223', '岐阜県', 'ギフケン', '関市', 'セキシ', '竪切南', 'タテキリミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市東仙房', '21', '21205', '5013224', '岐阜県', 'ギフケン', '関市', 'セキシ', '東仙房', 'ヒガシセンボウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市南仙房', '21', '21205', '5013225', '岐阜県', 'ギフケン', '関市', 'セキシ', '南仙房', 'ミナミセンボウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市向西仙房', '21', '21205', '5013226', '岐阜県', 'ギフケン', '関市', 'セキシ', '向西仙房', 'ムカイサイセンボウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市北仙房', '21', '21205', '5013227', '岐阜県', 'ギフケン', '関市', 'セキシ', '北仙房', 'ホクセンボウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市竪切北', '21', '21205', '5013228', '岐阜県', 'ギフケン', '関市', 'セキシ', '竪切北', 'タテキリキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市東桜町', '21', '21205', '5013231', '岐阜県', 'ギフケン', '関市', 'セキシ', '東桜町', 'ヒガシサクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市桜本町', '21', '21205', '5013232', '岐阜県', 'ギフケン', '関市', 'セキシ', '桜本町', 'サクラホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市西木戸町', '21', '21205', '5013233', '岐阜県', 'ギフケン', '関市', 'セキシ', '西木戸町', 'ニシキドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市若宮町', '21', '21205', '5013234', '岐阜県', 'ギフケン', '関市', 'セキシ', '若宮町', 'ワカミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市川間町', '21', '21205', '5013235', '岐阜県', 'ギフケン', '関市', 'セキシ', '川間町', 'カワマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市辻井戸町', '21', '21205', '5013236', '岐阜県', 'ギフケン', '関市', 'セキシ', '辻井戸町', 'ツジイドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市緑町', '21', '21205', '5013237', '岐阜県', 'ギフケン', '関市', 'セキシ', '緑町', 'ミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市西仙房', '21', '21205', '5013241', '岐阜県', 'ギフケン', '関市', 'セキシ', '西仙房', 'サイセンボウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市東福野町', '21', '21205', '5013242', '岐阜県', 'ギフケン', '関市', 'セキシ', '東福野町', 'ヒガシフクノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市中福野町', '21', '21205', '5013243', '岐阜県', 'ギフケン', '関市', 'セキシ', '中福野町', 'ナカフクノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市西福野町', '21', '21205', '5013244', '岐阜県', 'ギフケン', '関市', 'セキシ', '西福野町', 'ニシフクノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市北福野町', '21', '21205', '5013245', '岐阜県', 'ギフケン', '関市', 'セキシ', '北福野町', 'キタフクノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市緑ケ丘', '21', '21205', '5013246', '岐阜県', 'ギフケン', '関市', 'セキシ', '緑ケ丘', 'ミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市池田町', '21', '21205', '5013247', '岐阜県', 'ギフケン', '関市', 'セキシ', '池田町', 'イケダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市十三塚町', '21', '21205', '5013250', '岐阜県', 'ギフケン', '関市', 'セキシ', '十三塚町', 'ジュウサンヅカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市山王通西', '21', '21205', '5013251', '岐阜県', 'ギフケン', '関市', 'セキシ', '山王通西', 'サンノウドオリニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市山王通', '21', '21205', '5013252', '岐阜県', 'ギフケン', '関市', 'セキシ', '山王通', 'サンノウドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市栄町', '21', '21205', '5013253', '岐阜県', 'ギフケン', '関市', 'セキシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市雄飛ケ丘', '21', '21205', '5013254', '岐阜県', 'ギフケン', '関市', 'セキシ', '雄飛ケ丘', 'ユウヒガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市段下', '21', '21205', '5013255', '岐阜県', 'ギフケン', '関市', 'セキシ', '段下', 'ダンシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市巾', '21', '21205', '5013256', '岐阜県', 'ギフケン', '関市', 'セキシ', '巾', 'ハバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市新田', '21', '21205', '5013257', '岐阜県', 'ギフケン', '関市', 'セキシ', '新田', 'シンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市十三塚南', '21', '21205', '5013258', '岐阜県', 'ギフケン', '関市', 'セキシ', '十三塚南', 'ジュウサンヅカミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市十三塚北', '21', '21205', '5013259', '岐阜県', 'ギフケン', '関市', 'セキシ', '十三塚北', 'ジュウサンヅカキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市広見北町', '21', '21205', '5013261', '岐阜県', 'ギフケン', '関市', 'セキシ', '広見北町', 'ヒロミキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市広見東町', '21', '21205', '5013262', '岐阜県', 'ギフケン', '関市', 'セキシ', '広見東町', 'ヒロミヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市広見', '21', '21205', '5013263', '岐阜県', 'ギフケン', '関市', 'セキシ', '広見', 'ヒロミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市池尻', '21', '21205', '5013264', '岐阜県', 'ギフケン', '関市', 'セキシ', '池尻', 'イケジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市小瀬', '21', '21205', '5013265', '岐阜県', 'ギフケン', '関市', 'セキシ', '小瀬', 'オゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市小瀬南', '21', '21205', '5013266', '岐阜県', 'ギフケン', '関市', 'セキシ', '小瀬南', 'オゼミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市星ケ丘', '21', '21205', '5013267', '岐阜県', 'ギフケン', '関市', 'セキシ', '星ケ丘', 'ホシガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県加茂郡富加町', '21', '21502', '5013300', '岐阜県', 'ギフケン', '加茂郡富加町', 'カモグントミカチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('51919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県加茂郡富加町加治田', '21', '21502', '5013301', '岐阜県', 'ギフケン', '加茂郡富加町', 'カモグントミカチョウ', '加治田', 'カジタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県加茂郡富加町夕田', '21', '21502', '5013302', '岐阜県', 'ギフケン', '加茂郡富加町', 'カモグントミカチョウ', '夕田', 'ユウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県加茂郡富加町羽生', '21', '21502', '5013303', '岐阜県', 'ギフケン', '加茂郡富加町', 'カモグントミカチョウ', '羽生', 'ハニュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県加茂郡富加町高畑', '21', '21502', '5013304', '岐阜県', 'ギフケン', '加茂郡富加町', 'カモグントミカチョウ', '高畑', 'タカハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県加茂郡富加町滝田', '21', '21502', '5013305', '岐阜県', 'ギフケン', '加茂郡富加町', 'カモグントミカチョウ', '滝田', 'タキダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県加茂郡富加町大山', '21', '21502', '5013306', '岐阜県', 'ギフケン', '加茂郡富加町', 'カモグントミカチョウ', '大山', 'オオヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県加茂郡富加町大平賀', '21', '21502', '5013307', '岐阜県', 'ギフケン', '加茂郡富加町', 'カモグントミカチョウ', '大平賀', 'オオヒラガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市富之保', '21', '21205', '5013501', '岐阜県', 'ギフケン', '関市', 'セキシ', '富之保', 'トミノホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市中之保', '21', '21205', '5013511', '岐阜県', 'ギフケン', '関市', 'セキシ', '中之保', 'ナカノホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市下之保', '21', '21205', '5013521', '岐阜県', 'ギフケン', '関市', 'セキシ', '下之保', 'シモノホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市上之保', '21', '21205', '5013601', '岐阜県', 'ギフケン', '関市', 'セキシ', '上之保', 'カミノホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県美濃市', '21', '21207', '5013700', '岐阜県', 'ギフケン', '美濃市', 'ミノシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('51934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県美濃市', '21', '21207', '5013701', '岐阜県', 'ギフケン', '美濃市', 'ミノシ', null, '　', '（直番地）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('51935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県美濃市上河和', '21', '21207', '5013702', '岐阜県', 'ギフケン', '美濃市', 'ミノシ', '上河和', 'カミコウワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県美濃市下河和', '21', '21207', '5013703', '岐阜県', 'ギフケン', '美濃市', 'ミノシ', '下河和', 'シモコウワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県美濃市保木脇', '21', '21207', '5013704', '岐阜県', 'ギフケン', '美濃市', 'ミノシ', '保木脇', 'ホキワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県美濃市立花', '21', '21207', '5013705', '岐阜県', 'ギフケン', '美濃市', 'ミノシ', '立花', 'タチバナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県美濃市須原', '21', '21207', '5013706', '岐阜県', 'ギフケン', '美濃市', 'ミノシ', '須原', 'スハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県美濃市樋ケ洞', '21', '21207', '5013711', '岐阜県', 'ギフケン', '美濃市', 'ミノシ', '樋ケ洞', 'ヒガホラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県美濃市口野々', '21', '21207', '5013712', '岐阜県', 'ギフケン', '美濃市', 'ミノシ', '口野々', 'クチノノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県美濃市富野', '21', '21207', '5013713', '岐阜県', 'ギフケン', '美濃市', 'ミノシ', '富野', 'トミノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県美濃市曽代', '21', '21207', '5013714', '岐阜県', 'ギフケン', '美濃市', 'ミノシ', '曽代', 'ソダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県美濃市梅山町', '21', '21207', '5013715', '岐阜県', 'ギフケン', '美濃市', 'ミノシ', '梅山町', 'ウメヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県美濃市前野', '21', '21207', '5013716', '岐阜県', 'ギフケン', '美濃市', 'ミノシ', '前野', 'マエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県美濃市安毛', '21', '21207', '5013717', '岐阜県', 'ギフケン', '美濃市', 'ミノシ', '安毛', 'アタゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県美濃市吉川町', '21', '21207', '5013721', '岐阜県', 'ギフケン', '美濃市', 'ミノシ', '吉川町', 'ヨシカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県美濃市常盤町', '21', '21207', '5013722', '岐阜県', 'ギフケン', '美濃市', 'ミノシ', '常盤町', 'トキワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県美濃市相生町', '21', '21207', '5013723', '岐阜県', 'ギフケン', '美濃市', 'ミノシ', '相生町', 'アイオイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県美濃市魚屋町', '21', '21207', '5013724', '岐阜県', 'ギフケン', '美濃市', 'ミノシ', '魚屋町', 'ウオヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県美濃市俵町', '21', '21207', '5013725', '岐阜県', 'ギフケン', '美濃市', 'ミノシ', '俵町', 'タワラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県美濃市加治屋町', '21', '21207', '5013726', '岐阜県', 'ギフケン', '美濃市', 'ミノシ', '加治屋町', 'カジヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県美濃市永重町', '21', '21207', '5013727', '岐阜県', 'ギフケン', '美濃市', 'ミノシ', '永重町', 'ナガシゲチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県美濃市本住町', '21', '21207', '5013728', '岐阜県', 'ギフケン', '美濃市', 'ミノシ', '本住町', 'モトズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県美濃市泉町', '21', '21207', '5013729', '岐阜県', 'ギフケン', '美濃市', 'ミノシ', '泉町', 'イズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県美濃市東市場町', '21', '21207', '5013731', '岐阜県', 'ギフケン', '美濃市', 'ミノシ', '東市場町', 'ヒガシイチバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県美濃市広岡町', '21', '21207', '5013732', '岐阜県', 'ギフケン', '美濃市', 'ミノシ', '広岡町', 'ヒロオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県美濃市亀野町', '21', '21207', '5013733', '岐阜県', 'ギフケン', '美濃市', 'ミノシ', '亀野町', 'カメノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県美濃市千畝町', '21', '21207', '5013734', '岐阜県', 'ギフケン', '美濃市', 'ミノシ', '千畝町', 'チウネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県美濃市西市場町', '21', '21207', '5013735', '岐阜県', 'ギフケン', '美濃市', 'ミノシ', '西市場町', 'ニシイチバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県美濃市米屋町', '21', '21207', '5013736', '岐阜県', 'ギフケン', '美濃市', 'ミノシ', '米屋町', 'コメヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県美濃市新町', '21', '21207', '5013737', '岐阜県', 'ギフケン', '美濃市', 'ミノシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県美濃市港町', '21', '21207', '5013741', '岐阜県', 'ギフケン', '美濃市', 'ミノシ', '港町', 'ミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県美濃市殿町', '21', '21207', '5013742', '岐阜県', 'ギフケン', '美濃市', 'ミノシ', '殿町', 'トノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県美濃市上条', '21', '21207', '5013743', '岐阜県', 'ギフケン', '美濃市', 'ミノシ', '上条', 'カミジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県美濃市段町', '21', '21207', '5013744', '岐阜県', 'ギフケン', '美濃市', 'ミノシ', '段町', 'ダンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県美濃市下渡', '21', '21207', '5013745', '岐阜県', 'ギフケン', '美濃市', 'ミノシ', '下渡', 'シモワタリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県美濃市中央', '21', '21207', '5013746', '岐阜県', 'ギフケン', '美濃市', 'ミノシ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県美濃市松倉台', '21', '21207', '5013751', '岐阜県', 'ギフケン', '美濃市', 'ミノシ', '松倉台', 'マツクラダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県美濃市松栄町', '21', '21207', '5013752', '岐阜県', 'ギフケン', '美濃市', 'ミノシ', '松栄町', 'ショウエイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県美濃市松森', '21', '21207', '5013753', '岐阜県', 'ギフケン', '美濃市', 'ミノシ', '松森', 'マツモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県美濃市さくらケ丘', '21', '21207', '5013754', '岐阜県', 'ギフケン', '美濃市', 'ミノシ', 'さくらケ丘', 'サクラガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県美濃市志摩', '21', '21207', '5013755', '岐阜県', 'ギフケン', '美濃市', 'ミノシ', '志摩', 'シマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県美濃市生櫛', '21', '21207', '5013756', '岐阜県', 'ギフケン', '美濃市', 'ミノシ', '生櫛', 'イクシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県美濃市横越', '21', '21207', '5013761', '岐阜県', 'ギフケン', '美濃市', 'ミノシ', '横越', 'ヨコゴシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県美濃市藍川', '21', '21207', '5013762', '岐阜県', 'ギフケン', '美濃市', 'ミノシ', '藍川', 'アイカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県美濃市極楽寺', '21', '21207', '5013763', '岐阜県', 'ギフケン', '美濃市', 'ミノシ', '極楽寺', 'ゴクラクジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県美濃市笠神', '21', '21207', '5013764', '岐阜県', 'ギフケン', '美濃市', 'ミノシ', '笠神', 'カサガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県美濃市大矢田', '21', '21207', '5013771', '岐阜県', 'ギフケン', '美濃市', 'ミノシ', '大矢田', 'オヤダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県美濃市楓台', '21', '21207', '5013772', '岐阜県', 'ギフケン', '美濃市', 'ミノシ', '楓台', 'カエデダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県美濃市もみじが丘', '21', '21207', '5013773', '岐阜県', 'ギフケン', '美濃市', 'ミノシ', 'もみじが丘', 'モミジガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県美濃市片知', '21', '21207', '5013781', '岐阜県', 'ギフケン', '美濃市', 'ミノシ', '片知', 'カタジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県美濃市長瀬', '21', '21207', '5013782', '岐阜県', 'ギフケン', '美濃市', 'ミノシ', '長瀬', 'ナガセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県美濃市神洞', '21', '21207', '5013783', '岐阜県', 'ギフケン', '美濃市', 'ミノシ', '神洞', 'カンボラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県美濃市御手洗', '21', '21207', '5013784', '岐阜県', 'ギフケン', '美濃市', 'ミノシ', '御手洗', 'ミタライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県美濃市小倉', '21', '21207', '5013785', '岐阜県', 'ギフケン', '美濃市', 'ミノシ', '小倉', 'コクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県美濃市乙狩', '21', '21207', '5013786', '岐阜県', 'ギフケン', '美濃市', 'ミノシ', '乙狩', 'オトガリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県美濃市上野', '21', '21207', '5013787', '岐阜県', 'ギフケン', '美濃市', 'ミノシ', '上野', 'カミノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県美濃市蕨生', '21', '21207', '5013788', '岐阜県', 'ギフケン', '美濃市', 'ミノシ', '蕨生', 'ワラビ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市大坪', '21', '21205', '5013801', '岐阜県', 'ギフケン', '関市', 'セキシ', '大坪', 'オオツボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市若草通', '21', '21205', '5013802', '岐阜県', 'ギフケン', '関市', 'セキシ', '若草通', 'ワカクサドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市西本郷通', '21', '21205', '5013803', '岐阜県', 'ギフケン', '関市', 'セキシ', '西本郷通', 'ニシホンゴウドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市円保通', '21', '21205', '5013804', '岐阜県', 'ギフケン', '関市', 'セキシ', '円保通', 'エンボドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市本郷町', '21', '21205', '5013805', '岐阜県', 'ギフケン', '関市', 'セキシ', '本郷町', 'ホンゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市観音山', '21', '21205', '5013806', '岐阜県', 'ギフケン', '関市', 'セキシ', '観音山', 'カンノンヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市安桜山', '21', '21205', '5013807', '岐阜県', 'ギフケン', '関市', 'セキシ', '安桜山', 'アサクラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市安桜台', '21', '21205', '5013808', '岐阜県', 'ギフケン', '関市', 'セキシ', '安桜台', 'アサクラダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('51999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市東本郷通', '21', '21205', '5013811', '岐阜県', 'ギフケン', '関市', 'セキシ', '東本郷通', 'ヒガシホンゴウドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市東本郷', '21', '21205', '5013812', '岐阜県', 'ギフケン', '関市', 'セキシ', '東本郷', 'ヒガシホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市東野町', '21', '21205', '5013813', '岐阜県', 'ギフケン', '関市', 'セキシ', '東野町', 'ヒガシノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市東山', '21', '21205', '5013814', '岐阜県', 'ギフケン', '関市', 'セキシ', '東山', 'ヒガシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市東町', '21', '21205', '5013815', '岐阜県', 'ギフケン', '関市', 'セキシ', '東町', 'ヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市吉野町', '21', '21205', '5013816', '岐阜県', 'ギフケン', '関市', 'セキシ', '吉野町', 'ヨシノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市仲町', '21', '21205', '5013817', '岐阜県', 'ギフケン', '関市', 'セキシ', '仲町', 'ナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市吉本町', '21', '21205', '5013818', '岐阜県', 'ギフケン', '関市', 'セキシ', '吉本町', 'ヨシモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市西町', '21', '21205', '5013819', '岐阜県', 'ギフケン', '関市', 'セキシ', '西町', 'ニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市平賀町', '21', '21205', '5013821', '岐阜県', 'ギフケン', '関市', 'セキシ', '平賀町', 'ヒラガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市市平賀', '21', '21205', '5013822', '岐阜県', 'ギフケン', '関市', 'セキシ', '市平賀', 'イチヒラガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市東出町', '21', '21205', '5013823', '岐阜県', 'ギフケン', '関市', 'セキシ', '東出町', 'ヒガシデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市東新町', '21', '21205', '5013824', '岐阜県', 'ギフケン', '関市', 'セキシ', '東新町', 'トウシンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市南出', '21', '21205', '5013825', '岐阜県', 'ギフケン', '関市', 'セキシ', '南出', 'ミナミデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市関口町', '21', '21205', '5013826', '岐阜県', 'ギフケン', '関市', 'セキシ', '関口町', 'セキグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市宮地町', '21', '21205', '5013827', '岐阜県', 'ギフケン', '関市', 'セキシ', '宮地町', 'ミヤジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市西旭ケ丘', '21', '21205', '5013828', '岐阜県', 'ギフケン', '関市', 'セキシ', '西旭ケ丘', 'ニシアサヒガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市旭ケ丘', '21', '21205', '5013829', '岐阜県', 'ギフケン', '関市', 'セキシ', '旭ケ丘', 'アサヒガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市長谷寺町', '21', '21205', '5013831', '岐阜県', 'ギフケン', '関市', 'セキシ', '長谷寺町', 'ハセデラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市花園町', '21', '21205', '5013832', '岐阜県', 'ギフケン', '関市', 'セキシ', '花園町', 'ハナゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市大平町', '21', '21205', '5013833', '岐阜県', 'ギフケン', '関市', 'セキシ', '大平町', 'タイヘイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市大門町', '21', '21205', '5013834', '岐阜県', 'ギフケン', '関市', 'セキシ', '大門町', 'ダイモンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市観音前', '21', '21205', '5013835', '岐阜県', 'ギフケン', '関市', 'セキシ', '観音前', 'カンノンマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市美園町', '21', '21205', '5013836', '岐阜県', 'ギフケン', '関市', 'セキシ', '美園町', 'ミソノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市西門前町', '21', '21205', '5013837', '岐阜県', 'ギフケン', '関市', 'セキシ', '西門前町', 'ニシモンゼンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市東門前町', '21', '21205', '5013838', '岐阜県', 'ギフケン', '関市', 'セキシ', '東門前町', 'ヒガシモンゼンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市長住町', '21', '21205', '5013839', '岐阜県', 'ギフケン', '関市', 'セキシ', '長住町', 'ナガズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市伊勢町', '21', '21205', '5013841', '岐阜県', 'ギフケン', '関市', 'セキシ', '伊勢町', 'イセマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市出来町', '21', '21205', '5013842', '岐阜県', 'ギフケン', '関市', 'セキシ', '出来町', 'デキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市吉田町', '21', '21205', '5013843', '岐阜県', 'ギフケン', '関市', 'セキシ', '吉田町', 'キッタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市美和町', '21', '21205', '5013844', '岐阜県', 'ギフケン', '関市', 'セキシ', '美和町', 'ミワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市吾妻町', '21', '21205', '5013845', '岐阜県', 'ギフケン', '関市', 'セキシ', '吾妻町', 'アヅマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市住吉町', '21', '21205', '5013846', '岐阜県', 'ギフケン', '関市', 'セキシ', '住吉町', 'スミヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市新町', '21', '21205', '5013847', '岐阜県', 'ギフケン', '関市', 'セキシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市末広町', '21', '21205', '5013848', '岐阜県', 'ギフケン', '関市', 'セキシ', '末広町', 'スエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市相生町', '21', '21205', '5013851', '岐阜県', 'ギフケン', '関市', 'セキシ', '相生町', 'アイオイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市上利町', '21', '21205', '5013852', '岐阜県', 'ギフケン', '関市', 'セキシ', '上利町', 'アガリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市朝倉町', '21', '21205', '5013853', '岐阜県', 'ギフケン', '関市', 'セキシ', '朝倉町', 'アサクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市月見町', '21', '21205', '5013854', '岐阜県', 'ギフケン', '関市', 'セキシ', '月見町', 'ツキミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市いろは町', '21', '21205', '5013855', '岐阜県', 'ギフケン', '関市', 'セキシ', 'いろは町', 'イロハチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市桜木町', '21', '21205', '5013856', '岐阜県', 'ギフケン', '関市', 'セキシ', '桜木町', 'サクラギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市南春日町', '21', '21205', '5013857', '岐阜県', 'ギフケン', '関市', 'セキシ', '南春日町', 'ミナミカスガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市小柳町', '21', '21205', '5013861', '岐阜県', 'ギフケン', '関市', 'セキシ', '小柳町', 'コヤナギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市兼永町', '21', '21205', '5013862', '岐阜県', 'ギフケン', '関市', 'セキシ', '兼永町', 'カネナガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市富本町', '21', '21205', '5013863', '岐阜県', 'ギフケン', '関市', 'セキシ', '富本町', 'トミモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市前町', '21', '21205', '5013864', '岐阜県', 'ギフケン', '関市', 'セキシ', '前町', 'マエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市春日町', '21', '21205', '5013865', '岐阜県', 'ギフケン', '関市', 'セキシ', '春日町', 'カスガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市千年町', '21', '21205', '5013866', '岐阜県', 'ギフケン', '関市', 'セキシ', '千年町', 'センネンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市常盤町', '21', '21205', '5013867', '岐阜県', 'ギフケン', '関市', 'セキシ', '常盤町', 'トキワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市白川町', '21', '21205', '5013868', '岐阜県', 'ギフケン', '関市', 'セキシ', '白川町', 'シラカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市鍛冶町', '21', '21205', '5013871', '岐阜県', 'ギフケン', '関市', 'セキシ', '鍛冶町', 'カジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市金屋町', '21', '21205', '5013872', '岐阜県', 'ギフケン', '関市', 'セキシ', '金屋町', 'カナヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市日ノ出町', '21', '21205', '5013873', '岐阜県', 'ギフケン', '関市', 'セキシ', '日ノ出町', 'ヒノデマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市平和通', '21', '21205', '5013874', '岐阜県', 'ギフケン', '関市', 'セキシ', '平和通', 'ヘイワドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市森西町', '21', '21205', '5013875', '岐阜県', 'ギフケン', '関市', 'セキシ', '森西町', 'モリニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市貴船町', '21', '21205', '5013876', '岐阜県', 'ギフケン', '関市', 'セキシ', '貴船町', 'キブネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市河合町', '21', '21205', '5013877', '岐阜県', 'ギフケン', '関市', 'セキシ', '河合町', 'カワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市十軒町', '21', '21205', '5013878', '岐阜県', 'ギフケン', '関市', 'セキシ', '十軒町', 'ジッケンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市元重町', '21', '21205', '5013881', '岐阜県', 'ギフケン', '関市', 'セキシ', '元重町', 'モトシゲチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市西日吉町', '21', '21205', '5013882', '岐阜県', 'ギフケン', '関市', 'セキシ', '西日吉町', 'ニシヒヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市東日吉町', '21', '21205', '5013883', '岐阜県', 'ギフケン', '関市', 'セキシ', '東日吉町', 'ヒガシヒヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市孫六町', '21', '21205', '5013884', '岐阜県', 'ギフケン', '関市', 'セキシ', '孫六町', 'マゴロクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市山ノ手', '21', '21205', '5013885', '岐阜県', 'ギフケン', '関市', 'セキシ', '山ノ手', 'ヤマノテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市本町', '21', '21205', '5013886', '岐阜県', 'ギフケン', '関市', 'セキシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市吐月町', '21', '21205', '5013887', '岐阜県', 'ギフケン', '関市', 'セキシ', '吐月町', 'トゲツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市坂下町', '21', '21205', '5013888', '岐阜県', 'ギフケン', '関市', 'セキシ', '坂下町', 'サカシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市春里町', '21', '21205', '5013901', '岐阜県', 'ギフケン', '関市', 'セキシ', '春里町', 'ハルサトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市弥生町', '21', '21205', '5013902', '岐阜県', 'ギフケン', '関市', 'セキシ', '弥生町', 'ヤヨイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市桜ケ丘', '21', '21205', '5013903', '岐阜県', 'ギフケン', '関市', 'セキシ', '桜ケ丘', 'サクラガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市明生町', '21', '21205', '5013904', '岐阜県', 'ギフケン', '関市', 'セキシ', '明生町', 'メイセイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市神明町', '21', '21205', '5013905', '岐阜県', 'ギフケン', '関市', 'セキシ', '神明町', 'シンメイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市西欠ノ下', '21', '21205', '5013906', '岐阜県', 'ギフケン', '関市', 'セキシ', '西欠ノ下', 'ニシカケノシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市南町', '21', '21205', '5013907', '岐阜県', 'ギフケン', '関市', 'セキシ', '南町', 'ミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市寿町', '21', '21205', '5013908', '岐阜県', 'ギフケン', '関市', 'セキシ', '寿町', 'コトブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市新堀町', '21', '21205', '5013909', '岐阜県', 'ギフケン', '関市', 'セキシ', '新堀町', 'シンボリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市肥田瀬', '21', '21205', '5013911', '岐阜県', 'ギフケン', '関市', 'セキシ', '肥田瀬', 'ヒダセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市宮河町', '21', '21205', '5013912', '岐阜県', 'ギフケン', '関市', 'セキシ', '宮河町', 'ミヤガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市稲河町', '21', '21205', '5013913', '岐阜県', 'ギフケン', '関市', 'セキシ', '稲河町', 'イナゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市鋳物師屋', '21', '21205', '5013914', '岐阜県', 'ギフケン', '関市', 'セキシ', '鋳物師屋', 'イモジヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市天徳町', '21', '21205', '5013915', '岐阜県', 'ギフケン', '関市', 'セキシ', '天徳町', 'テントクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市豊岡町', '21', '21205', '5013916', '岐阜県', 'ギフケン', '関市', 'セキシ', '豊岡町', 'トヨオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市北天神', '21', '21205', '5013917', '岐阜県', 'ギフケン', '関市', 'セキシ', '北天神', 'キタテンジン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市南天神', '21', '21205', '5013918', '岐阜県', 'ギフケン', '関市', 'セキシ', '南天神', 'ミナミテンジン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市平成通', '21', '21205', '5013919', '岐阜県', 'ギフケン', '関市', 'セキシ', '平成通', 'ヘイセイドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市東田原', '21', '21205', '5013921', '岐阜県', 'ギフケン', '関市', 'セキシ', '東田原', 'ヒガシタワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市大杉', '21', '21205', '5013922', '岐阜県', 'ギフケン', '関市', 'セキシ', '大杉', 'オオスギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市新迫間', '21', '21205', '5013923', '岐阜県', 'ギフケン', '関市', 'セキシ', '新迫間', 'シンハサマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市迫間', '21', '21205', '5013924', '岐阜県', 'ギフケン', '関市', 'セキシ', '迫間', 'ハサマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市迫間台', '21', '21205', '5013925', '岐阜県', 'ギフケン', '関市', 'セキシ', '迫間台', 'ハサマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市小迫間', '21', '21205', '5013926', '岐阜県', 'ギフケン', '関市', 'セキシ', '小迫間', 'コバサマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市向陽台', '21', '21205', '5013927', '岐阜県', 'ギフケン', '関市', 'セキシ', '向陽台', 'コウヨウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市西田原', '21', '21205', '5013928', '岐阜県', 'ギフケン', '関市', 'セキシ', '西田原', 'ニシタワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市倉知南', '21', '21205', '5013930', '岐阜県', 'ギフケン', '関市', 'セキシ', '倉知南', 'クラチミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市桜台', '21', '21205', '5013931', '岐阜県', 'ギフケン', '関市', 'セキシ', '桜台', 'サクラダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市稲口', '21', '21205', '5013932', '岐阜県', 'ギフケン', '関市', 'セキシ', '稲口', 'イナグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市向山町', '21', '21205', '5013933', '岐阜県', 'ギフケン', '関市', 'セキシ', '向山町', 'ムコウヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市桐谷台', '21', '21205', '5013934', '岐阜県', 'ギフケン', '関市', 'セキシ', '桐谷台', 'キリヤダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市四季ノ台', '21', '21205', '5013935', '岐阜県', 'ギフケン', '関市', 'セキシ', '四季ノ台', 'シキノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市倉知', '21', '21205', '5013936', '岐阜県', 'ギフケン', '関市', 'セキシ', '倉知', 'クラチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市前山町', '21', '21205', '5013937', '岐阜県', 'ギフケン', '関市', 'セキシ', '前山町', 'マエヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市桐ヶ丘', '21', '21205', '5013938', '岐阜県', 'ギフケン', '関市', 'セキシ', '桐ヶ丘', 'キリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市桃紅大地', '21', '21205', '5013939', '岐阜県', 'ギフケン', '関市', 'セキシ', '桃紅大地', 'トウコウダイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市小屋名', '21', '21205', '5013941', '岐阜県', 'ギフケン', '関市', 'セキシ', '小屋名', 'オヤナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市希望ケ丘', '21', '21205', '5013942', '岐阜県', 'ギフケン', '関市', 'セキシ', '希望ケ丘', 'キボウガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市虹ケ丘南', '21', '21205', '5013943', '岐阜県', 'ギフケン', '関市', 'セキシ', '虹ケ丘南', 'ニジガオカミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市山田', '21', '21205', '5013944', '岐阜県', 'ギフケン', '関市', 'セキシ', '山田', 'ヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市虹ケ丘北', '21', '21205', '5013945', '岐阜県', 'ギフケン', '関市', 'セキシ', '虹ケ丘北', 'ニジガオカキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市津保川台', '21', '21205', '5013946', '岐阜県', 'ギフケン', '関市', 'セキシ', '津保川台', 'ツボカワダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市上白金', '21', '21205', '5013947', '岐阜県', 'ギフケン', '関市', 'セキシ', '上白金', 'カミシロカネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市植野', '21', '21205', '5013951', '岐阜県', 'ギフケン', '関市', 'セキシ', '植野', 'ウエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市大平台', '21', '21205', '5013952', '岐阜県', 'ギフケン', '関市', 'セキシ', '大平台', 'タイヘイダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市千疋北', '21', '21205', '5013953', '岐阜県', 'ギフケン', '関市', 'セキシ', '千疋北', 'センビキキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市千疋', '21', '21205', '5013954', '岐阜県', 'ギフケン', '関市', 'セキシ', '千疋', 'センビキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市下白金', '21', '21205', '5013955', '岐阜県', 'ギフケン', '関市', 'セキシ', '下白金', 'シモシロカネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市保明', '21', '21205', '5013956', '岐阜県', 'ギフケン', '関市', 'セキシ', '保明', 'ホウミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市側島', '21', '21205', '5013957', '岐阜県', 'ギフケン', '関市', 'セキシ', '側島', 'ソバシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市戸田', '21', '21205', '5013958', '岐阜県', 'ギフケン', '関市', 'セキシ', '戸田', 'トダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市清蔵寺', '21', '21205', '5013961', '岐阜県', 'ギフケン', '関市', 'セキシ', '清蔵寺', 'セイゾウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市柳町', '21', '21205', '5013962', '岐阜県', 'ギフケン', '関市', 'セキシ', '柳町', 'ヤナギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市片倉町', '21', '21205', '5013963', '岐阜県', 'ギフケン', '関市', 'セキシ', '片倉町', 'カタクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市宝山町', '21', '21205', '5013964', '岐阜県', 'ギフケン', '関市', 'セキシ', '宝山町', 'タカラヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市十六所', '21', '21205', '5013965', '岐阜県', 'ギフケン', '関市', 'セキシ', '十六所', 'ジュウロクセン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市居敷町', '21', '21205', '5013966', '岐阜県', 'ギフケン', '関市', 'セキシ', '居敷町', 'イシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市西居敷', '21', '21205', '5013967', '岐阜県', 'ギフケン', '関市', 'セキシ', '西居敷', 'ニシイシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市力山', '21', '21205', '5013968', '岐阜県', 'ギフケン', '関市', 'セキシ', '力山', 'チカラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市馬場出', '21', '21205', '5013969', '岐阜県', 'ギフケン', '関市', 'セキシ', '馬場出', 'ババダシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市古屋敷町', '21', '21205', '5013971', '岐阜県', 'ギフケン', '関市', 'セキシ', '古屋敷町', 'フルヤシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市寺内町', '21', '21205', '5013972', '岐阜県', 'ギフケン', '関市', 'セキシ', '寺内町', 'ジナイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市一ツ山町', '21', '21205', '5013973', '岐阜県', 'ギフケン', '関市', 'セキシ', '一ツ山町', 'ヒトツヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市梅ケ枝町', '21', '21205', '5013974', '岐阜県', 'ギフケン', '関市', 'セキシ', '梅ケ枝町', 'ウメガエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市豊川町', '21', '21205', '5013975', '岐阜県', 'ギフケン', '関市', 'セキシ', '豊川町', 'トヨカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市梅竜寺山', '21', '21205', '5013976', '岐阜県', 'ギフケン', '関市', 'セキシ', '梅竜寺山', 'バイリュウジヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市清水町', '21', '21205', '5013977', '岐阜県', 'ギフケン', '関市', 'セキシ', '清水町', 'シミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市赤渕', '21', '21205', '5013978', '岐阜県', 'ギフケン', '関市', 'セキシ', '赤渕', 'アカフチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県関市一本木町', '21', '21205', '5013979', '岐阜県', 'ギフケン', '関市', 'セキシ', '一本木町', 'イッポンギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市美並町上田', '21', '21219', '5014101', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '美並町上田', 'ミナミチョウカミタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市美並町高砂', '21', '21219', '5014102', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '美並町高砂', 'ミナミチョウタカサゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市美並町山田', '21', '21219', '5014103', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '美並町山田', 'ミナミチョウヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市美並町梅原', '21', '21219', '5014104', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '美並町梅原', 'ミナミチョウウメバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市美並町三戸', '21', '21219', '5014105', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '美並町三戸', 'ミナミチョウミト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市美並町白山', '21', '21219', '5014106', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '美並町白山', 'ミナミチョウハクサン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市美並町大原', '21', '21219', '5014107', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '美並町大原', 'ミナミチョウオオハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市', '21', '21219', '5014200', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('52151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市八幡町有穂', '21', '21219', '5014201', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '八幡町有穂', 'ハチマンチョウアリホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市八幡町市島', '21', '21219', '5014202', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '八幡町市島', 'ハチマンチョウイチシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市八幡町初納', '21', '21219', '5014203', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '八幡町初納', 'ハチマンチョウショノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市八幡町旭', '21', '21219', '5014204', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '八幡町旭', 'ハチマンチョウアサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市八幡町安久田', '21', '21219', '5014205', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '八幡町安久田', 'ハチマンチョウアクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市八幡町吉野', '21', '21219', '5014206', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '八幡町吉野', 'ハチマンチョウヨシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市八幡町西乙原', '21', '21219', '5014207', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '八幡町西乙原', 'ハチマンチョウニシオツパラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市八幡町中坪', '21', '21219', '5014211', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '八幡町中坪', 'ハチマンチョウナカツボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市八幡町職人町', '21', '21219', '5014212', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '八幡町職人町', 'ハチマンチョウショクニンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市八幡町殿町', '21', '21219', '5014213', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '八幡町殿町', 'ハチマンチョウトノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市八幡町柳町', '21', '21219', '5014214', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '八幡町柳町', 'ハチマンチョウヤナギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市八幡町肴町', '21', '21219', '5014215', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '八幡町肴町', 'ハチマンチョウサカナマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市八幡町本町', '21', '21219', '5014216', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '八幡町本町', 'ハチマンチョウホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市八幡町尾崎町', '21', '21219', '5014217', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '八幡町尾崎町', 'ハチマンチョウオサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市八幡町鍛冶屋町', '21', '21219', '5014218', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '八幡町鍛冶屋町', 'ハチマンチョウカジヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市八幡町大手町', '21', '21219', '5014219', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '八幡町大手町', 'ハチマンチョウオオテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市八幡町小野', '21', '21219', '5014221', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '八幡町小野', 'ハチマンチョウオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市八幡町島谷', '21', '21219', '5014222', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '八幡町島谷', 'ハチマンチョウシマダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市八幡町稲成', '21', '21219', '5014223', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '八幡町稲成', 'ハチマンチョウイナリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市八幡町城南町', '21', '21219', '5014224', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '八幡町城南町', 'ハチマンチョウジョウナンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市八幡町大正町', '21', '21219', '5014225', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '八幡町大正町', 'ハチマンチョウタイショウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市八幡町新町', '21', '21219', '5014226', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '八幡町新町', 'ハチマンチョウシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市八幡町橋本町', '21', '21219', '5014227', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '八幡町橋本町', 'ハチマンチョウハシモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市八幡町桜町', '21', '21219', '5014228', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '八幡町桜町', 'ハチマンチョウサクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市八幡町河鹿', '21', '21219', '5014231', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '八幡町河鹿', 'ハチマンチョウカジカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市八幡町初音', '21', '21219', '5014232', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '八幡町初音', 'ハチマンチョウハツネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市八幡町瀬取', '21', '21219', '5014233', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '八幡町瀬取', 'ハチマンチョウセトリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市八幡町五町', '21', '21219', '5014234', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '八幡町五町', 'ハチマンチョウゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市八幡町有坂', '21', '21219', '5014235', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '八幡町有坂', 'ハチマンチョウアリサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市八幡町相生', '21', '21219', '5014236', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '八幡町相生', 'ハチマンチョウアイオイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市八幡町那比', '21', '21219', '5014237', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '八幡町那比', 'ハチマンチョウナビ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市八幡町島', '21', '21219', '5014238', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '八幡町島', 'ハチマンチョウシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市八幡町向山', '21', '21219', '5014241', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '八幡町向山', 'ハチマンチョウムカイヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市明宝大谷', '21', '21219', '5014301', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '明宝大谷', 'メイホウオオタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市明宝寒水', '21', '21219', '5014302', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '明宝寒水', 'メイホウカノミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市明宝気良', '21', '21219', '5014303', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '明宝気良', 'メイホウケラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市明宝奥住', '21', '21219', '5014304', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '明宝奥住', 'メイホウオクズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市明宝小川', '21', '21219', '5014305', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '明宝小川', 'メイホウオガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市明宝畑佐', '21', '21219', '5014306', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '明宝畑佐', 'メイホウハタサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市明宝二間手', '21', '21219', '5014307', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '明宝二間手', 'メイホウフタマテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市八幡町入間', '21', '21219', '5014451', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '八幡町入間', 'ハチマンチョウイリマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市八幡町美山', '21', '21219', '5014452', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '八幡町美山', 'ハチマンチョウミヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市八幡町洲河', '21', '21219', '5014453', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '八幡町洲河', 'ハチマンチョウスゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市八幡町野々倉', '21', '21219', '5014454', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '八幡町野々倉', 'ハチマンチョウノノクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市八幡町小那比', '21', '21219', '5014455', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '八幡町小那比', 'ハチマンチョウオナビ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市和良町鹿倉', '21', '21219', '5014501', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '和良町鹿倉', 'ワラチョウカクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市和良町宮代', '21', '21219', '5014502', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '和良町宮代', 'ワラチョウミヤシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市和良町野尻', '21', '21219', '5014503', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '和良町野尻', 'ワラチョウノジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市和良町田平', '21', '21219', '5014504', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '和良町田平', 'ワラチョウタヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市和良町東野', '21', '21219', '5014505', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '和良町東野', 'ワラチョウヒガシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市和良町横野', '21', '21219', '5014506', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '和良町横野', 'ワラチョウヨコノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市和良町宮地', '21', '21219', '5014507', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '和良町宮地', 'ワラチョウミヤジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市和良町上沢', '21', '21219', '5014508', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '和良町上沢', 'ワラチョウカミサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市和良町下沢', '21', '21219', '5014509', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '和良町下沢', 'ワラチョウシモサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市和良町法師丸', '21', '21219', '5014510', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '和良町法師丸', 'ワラチョウホシマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市和良町下洞', '21', '21219', '5014511', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '和良町下洞', 'ワラチョウシモホラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市和良町上土京', '21', '21219', '5014512', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '和良町上土京', 'ワラチョウカミドキョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市和良町下土京', '21', '21219', '5014513', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '和良町下土京', 'ワラチョウシモドキョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市和良町安郷野', '21', '21219', '5014514', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '和良町安郷野', 'ワラチョウアゴノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市和良町方須', '21', '21219', '5014515', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '和良町方須', 'ワラチョウホウス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市和良町三庫', '21', '21219', '5014516', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '和良町三庫', 'ワラチョウミクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市和良町沢', '21', '21219', '5014517', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '和良町沢', 'ワラチョウサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市和良町土京', '21', '21219', '5014518', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '和良町土京', 'ワラチョウドキョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市大和町大間見', '21', '21219', '5014601', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '大和町大間見', 'ヤマトチョウオオマミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市大和町小間見', '21', '21219', '5014602', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '大和町小間見', 'ヤマトチョウコマミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市大和町栗巣', '21', '21219', '5014603', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '大和町栗巣', 'ヤマトチョウクリス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市大和町古道', '21', '21219', '5014604', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '大和町古道', 'ヤマトチョウフルミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市大和町神路', '21', '21219', '5014605', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '大和町神路', 'ヤマトチョウカンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市大和町河辺', '21', '21219', '5014606', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '大和町河辺', 'ヤマトチョウカベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市大和町徳永', '21', '21219', '5014607', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '大和町徳永', 'ヤマトチョウトクナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市大和町牧', '21', '21219', '5014608', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '大和町牧', 'ヤマトチョウマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市大和町島', '21', '21219', '5014610', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '大和町島', 'ヤマトチョウシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市大和町万場', '21', '21219', '5014611', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '大和町万場', 'ヤマトチョウマンバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市大和町剣', '21', '21219', '5014612', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '大和町剣', 'ヤマトチョウツルギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市大和町名皿部', '21', '21219', '5014613', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '大和町名皿部', 'ヤマトチョウナサラベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市大和町野口', '21', '21219', '5014614', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '大和町野口', 'ヤマトチョウノグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市大和町場皿', '21', '21219', '5014615', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '大和町場皿', 'ヤマトチョウバツサラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市大和町福田', '21', '21219', '5014616', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '大和町福田', 'ヤマトチョウフクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市大和町洞口', '21', '21219', '5014617', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '大和町洞口', 'ヤマトチョウホラグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市大和町内ケ谷', '21', '21219', '5014618', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '大和町内ケ谷', 'ヤマトチョウウチガタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市大和町落部', '21', '21219', '5014619', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '大和町落部', 'ヤマトチョウオチベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市白鳥町前谷', '21', '21219', '5015101', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '白鳥町前谷', 'シロトリチョウマエダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市白鳥町歩岐島', '21', '21219', '5015102', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '白鳥町歩岐島', 'シロトリチョウホキジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市白鳥町二日町', '21', '21219', '5015103', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '白鳥町二日町', 'シロトリチョウフツカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市白鳥町長滝', '21', '21219', '5015104', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '白鳥町長滝', 'シロトリチョウナガタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市白鳥町干田野', '21', '21219', '5015105', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '白鳥町干田野', 'シロトリチョウヒタノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市白鳥町阿多岐', '21', '21219', '5015111', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '白鳥町阿多岐', 'シロトリチョウアタギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市白鳥町六ノ里', '21', '21219', '5015112', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '白鳥町六ノ里', 'シロトリチョウロクノリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市白鳥町野添', '21', '21219', '5015113', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '白鳥町野添', 'シロトリチョウノゾエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市白鳥町那留', '21', '21219', '5015114', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '白鳥町那留', 'シロトリチョウナル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市白鳥町恩地', '21', '21219', '5015115', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '白鳥町恩地', 'シロトリチョウオンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市白鳥町中西', '21', '21219', '5015116', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '白鳥町中西', 'シロトリチョウナカニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市白鳥町白鳥', '21', '21219', '5015121', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '白鳥町白鳥', 'シロトリチョウシロトリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市白鳥町為真', '21', '21219', '5015122', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '白鳥町為真', 'シロトリチョウタメザニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市白鳥町中津屋', '21', '21219', '5015123', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '白鳥町中津屋', 'シロトリチョウナカツヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市白鳥町大島', '21', '21219', '5015124', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '白鳥町大島', 'シロトリチョウオオシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市白鳥町越佐', '21', '21219', '5015125', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '白鳥町越佐', 'シロトリチョウコツサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市白鳥町向小駄良', '21', '21219', '5015126', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '白鳥町向小駄良', 'シロトリチョウムカイコダラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市白鳥町石徹白', '21', '21219', '5015231', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '白鳥町石徹白', 'シロトリチョウイトシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市高鷲町ひるがの', '21', '21219', '5015301', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '高鷲町ひるがの', 'タカスチョウヒルガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市高鷲町鷲見', '21', '21219', '5015302', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '高鷲町鷲見', 'タカスチョウワシミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市高鷲町鷲見上野', '21', '21219', '5015302', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '高鷲町鷲見', 'タカスチョウワシミ', null, null, '上野', 'ウエノ');
INSERT INTO `ms_addresses` VALUES ('52259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市高鷲町大鷲', '21', '21219', '5015303', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '高鷲町大鷲', 'タカスチョウオオワシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市高鷲町鮎立', '21', '21219', '5015304', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '高鷲町鮎立', 'タカスチョウアユタテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市高鷲町切立', '21', '21219', '5015304', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '高鷲町切立', 'タカスチョウキッタテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県郡上市高鷲町西洞', '21', '21219', '5015305', '岐阜県', 'ギフケン', '郡上市', 'グジョウシ', '高鷲町西洞', 'タカスチョウニシボラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市荘川町六厩', '21', '21203', '5015401', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '荘川町六厩', 'ショウカワチョウムマヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市荘川町三谷', '21', '21203', '5015402', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '荘川町三谷', 'ショウカワチョウサンダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市荘川町三尾河', '21', '21203', '5015403', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '荘川町三尾河', 'ショウカワチョウミオゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市荘川町黒谷', '21', '21203', '5015404', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '荘川町黒谷', 'ショウカワチョウクロダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市荘川町寺河戸', '21', '21203', '5015405', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '荘川町寺河戸', 'ショウカワチョウテラカワド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市荘川町惣則', '21', '21203', '5015406', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '荘川町惣則', 'ショウカワチョウソウノリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市荘川町牧戸', '21', '21203', '5015411', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '荘川町牧戸', 'ショウカワチョウマキド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市荘川町中畑', '21', '21203', '5015412', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '荘川町中畑', 'ショウカワチョウナカハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市荘川町新渕', '21', '21203', '5015413', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '荘川町新渕', 'ショウカワチョウアラブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市荘川町猿丸', '21', '21203', '5015414', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '荘川町猿丸', 'ショウカワチョウサルマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市荘川町一色', '21', '21203', '5015415', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '荘川町一色', 'ショウカワチョウイッシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市荘川町町屋', '21', '21203', '5015416', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '荘川町町屋', 'ショウカワチョウマチヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市荘川町野々俣', '21', '21203', '5015417', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '荘川町野々俣', 'ショウカワチョウノノマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市荘川町赤谷', '21', '21203', '5015421', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '荘川町赤谷', 'ショウカワチョウアカダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市荘川町牛丸', '21', '21203', '5015422', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '荘川町牛丸', 'ショウカワチョウウシマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市荘川町岩瀬', '21', '21203', '5015423', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '荘川町岩瀬', 'ショウカワチョウイワゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市荘川町中野', '21', '21203', '5015424', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '荘川町中野', 'ショウカワチョウナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市荘川町海上', '21', '21203', '5015425', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '荘川町海上', 'ショウカワチョウカイジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市荘川町尾上郷', '21', '21203', '5015426', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '荘川町尾上郷', 'ショウカワチョウオガミゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大野郡白川村保木脇', '21', '21604', '5015501', '岐阜県', 'ギフケン', '大野郡白川村', 'オオノグンシラカワムラ', '保木脇', 'ホキワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大野郡白川村木谷', '21', '21604', '5015502', '岐阜県', 'ギフケン', '大野郡白川村', 'オオノグンシラカワムラ', '木谷', 'キダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大野郡白川村長瀬', '21', '21604', '5015503', '岐阜県', 'ギフケン', '大野郡白川村', 'オオノグンシラカワムラ', '長瀬', 'ナガセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大野郡白川村福島', '21', '21604', '5015504', '岐阜県', 'ギフケン', '大野郡白川村', 'オオノグンシラカワムラ', '福島', 'フクシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大野郡白川村牧', '21', '21604', '5015505', '岐阜県', 'ギフケン', '大野郡白川村', 'オオノグンシラカワムラ', '牧', 'マキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大野郡白川村御母衣', '21', '21604', '5015506', '岐阜県', 'ギフケン', '大野郡白川村', 'オオノグンシラカワムラ', '御母衣', 'ミボロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大野郡白川村平瀬', '21', '21604', '5015507', '岐阜県', 'ギフケン', '大野郡白川村', 'オオノグンシラカワムラ', '平瀬', 'ヒラセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大野郡白川村', '21', '21604', '5015600', '岐阜県', 'ギフケン', '大野郡白川村', 'オオノグンシラカワムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('52292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大野郡白川村馬狩', '21', '21604', '5015620', '岐阜県', 'ギフケン', '大野郡白川村', 'オオノグンシラカワムラ', '馬狩', 'マガリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大野郡白川村小白川', '21', '21604', '5015621', '岐阜県', 'ギフケン', '大野郡白川村', 'オオノグンシラカワムラ', '小白川', 'コジラカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大野郡白川村芦倉', '21', '21604', '5015622', '岐阜県', 'ギフケン', '大野郡白川村', 'オオノグンシラカワムラ', '芦倉', 'アシクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大野郡白川村椿原', '21', '21604', '5015623', '岐阜県', 'ギフケン', '大野郡白川村', 'オオノグンシラカワムラ', '椿原', 'ツバキハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大野郡白川村有家ケ原', '21', '21604', '5015624', '岐阜県', 'ギフケン', '大野郡白川村', 'オオノグンシラカワムラ', '有家ケ原', 'ウケガハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大野郡白川村飯島', '21', '21604', '5015625', '岐阜県', 'ギフケン', '大野郡白川村', 'オオノグンシラカワムラ', '飯島', 'イイシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大野郡白川村島', '21', '21604', '5015626', '岐阜県', 'ギフケン', '大野郡白川村', 'オオノグンシラカワムラ', '島', 'シマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大野郡白川村荻町', '21', '21604', '5015627', '岐阜県', 'ギフケン', '大野郡白川村', 'オオノグンシラカワムラ', '荻町', 'オギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大野郡白川村大牧', '21', '21604', '5015628', '岐阜県', 'ギフケン', '大野郡白川村', 'オオノグンシラカワムラ', '大牧', 'オオマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大野郡白川村鳩谷', '21', '21604', '5015629', '岐阜県', 'ギフケン', '大野郡白川村', 'オオノグンシラカワムラ', '鳩谷', 'ハトガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島郡岐南町上印食', '21', '21302', '5016001', '岐阜県', 'ギフケン', '羽島郡岐南町', 'ハシマグンギナンチョウ', '上印食', 'カミインジキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島郡岐南町三宅', '21', '21302', '5016002', '岐阜県', 'ギフケン', '羽島郡岐南町', 'ハシマグンギナンチョウ', '三宅', 'ミヤケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島郡岐南町平島', '21', '21302', '5016003', '岐阜県', 'ギフケン', '羽島郡岐南町', 'ハシマグンギナンチョウ', '平島', 'ヘイジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島郡岐南町野中', '21', '21302', '5016004', '岐阜県', 'ギフケン', '羽島郡岐南町', 'ハシマグンギナンチョウ', '野中', 'ノナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島郡岐南町若宮地', '21', '21302', '5016005', '岐阜県', 'ギフケン', '羽島郡岐南町', 'ハシマグンギナンチョウ', '若宮地', 'ワカミヤジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島郡岐南町伏屋', '21', '21302', '5016006', '岐阜県', 'ギフケン', '羽島郡岐南町', 'ハシマグンギナンチョウ', '伏屋', 'フセヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島郡岐南町八剣北', '21', '21302', '5016011', '岐阜県', 'ギフケン', '羽島郡岐南町', 'ハシマグンギナンチョウ', '八剣北', 'ヤツルギキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島郡岐南町八剣', '21', '21302', '5016012', '岐阜県', 'ギフケン', '羽島郡岐南町', 'ハシマグンギナンチョウ', '八剣', 'ヤツルギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島郡岐南町平成', '21', '21302', '5016013', '岐阜県', 'ギフケン', '羽島郡岐南町', 'ハシマグンギナンチョウ', '平成', 'ヘイセイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島郡岐南町薬師寺', '21', '21302', '5016014', '岐阜県', 'ギフケン', '羽島郡岐南町', 'ハシマグンギナンチョウ', '薬師寺', 'ヤクシジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島郡岐南町石原瀬', '21', '21302', '5016015', '岐阜県', 'ギフケン', '羽島郡岐南町', 'ハシマグンギナンチョウ', '石原瀬', 'イシハラセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島郡岐南町徳田', '21', '21302', '5016016', '岐阜県', 'ギフケン', '羽島郡岐南町', 'ハシマグンギナンチョウ', '徳田', 'トクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島郡岐南町徳田西', '21', '21302', '5016017', '岐阜県', 'ギフケン', '羽島郡岐南町', 'ハシマグンギナンチョウ', '徳田西', 'トクダニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島郡岐南町下印食', '21', '21302', '5016018', '岐阜県', 'ギフケン', '羽島郡岐南町', 'ハシマグンギナンチョウ', '下印食', 'シモインジキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島郡岐南町みやまち', '21', '21302', '5016019', '岐阜県', 'ギフケン', '羽島郡岐南町', 'ハシマグンギナンチョウ', 'みやまち', 'ミヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市川島笠田町', '21', '21213', '5016021', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '川島笠田町', 'カワシマカサダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市川島松倉町', '21', '21213', '5016022', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '川島松倉町', 'カワシママツクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市川島小網町', '21', '21213', '5016023', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '川島小網町', 'カワシマコアミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市川島竹早町', '21', '21213', '5016024', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '川島竹早町', 'カワシマタケハヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市川島河田町', '21', '21213', '5016025', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '川島河田町', 'カワシマコウダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市川島松原町', '21', '21213', '5016026', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '川島松原町', 'カワシママツバラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市川島緑町', '21', '21213', '5016027', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '川島緑町', 'カワシマミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市川島渡町', '21', '21213', '5016028', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '川島渡町', 'カワシマワタリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市川島北山町', '21', '21213', '5016029', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '川島北山町', 'カワシマキタヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島郡笠松町米野', '21', '21303', '5016031', '岐阜県', 'ギフケン', '羽島郡笠松町', 'ハシマグンカサマツチョウ', '米野', 'コメノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島郡笠松町江川', '21', '21303', '5016032', '岐阜県', 'ギフケン', '羽島郡笠松町', 'ハシマグンカサマツチョウ', '江川', 'エガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島郡笠松町無動寺', '21', '21303', '5016033', '岐阜県', 'ギフケン', '羽島郡笠松町', 'ハシマグンカサマツチョウ', '無動寺', 'ムドウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島郡笠松町中野', '21', '21303', '5016034', '岐阜県', 'ギフケン', '羽島郡笠松町', 'ハシマグンカサマツチョウ', '中野', 'ナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島郡笠松町円城寺', '21', '21303', '5016035', '岐阜県', 'ギフケン', '羽島郡笠松町', 'ハシマグンカサマツチョウ', '円城寺', 'エンジョウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島郡笠松町若葉町', '21', '21303', '5016036', '岐阜県', 'ギフケン', '羽島郡笠松町', 'ハシマグンカサマツチョウ', '若葉町', 'ワカバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島郡笠松町西金池町', '21', '21303', '5016037', '岐阜県', 'ギフケン', '羽島郡笠松町', 'ハシマグンカサマツチョウ', '西金池町', 'ニシカナイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島郡笠松町東金池町', '21', '21303', '5016038', '岐阜県', 'ギフケン', '羽島郡笠松町', 'ハシマグンカサマツチョウ', '東金池町', 'ヒガシカナイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島郡笠松町奈良町', '21', '21303', '5016041', '岐阜県', 'ギフケン', '羽島郡笠松町', 'ハシマグンカサマツチョウ', '奈良町', 'ナラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島郡笠松町八幡町', '21', '21303', '5016042', '岐阜県', 'ギフケン', '羽島郡笠松町', 'ハシマグンカサマツチョウ', '八幡町', 'ハチマンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島郡笠松町県町', '21', '21303', '5016043', '岐阜県', 'ギフケン', '羽島郡笠松町', 'ハシマグンカサマツチョウ', '県町', 'ケンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島郡笠松町相生町', '21', '21303', '5016044', '岐阜県', 'ギフケン', '羽島郡笠松町', 'ハシマグンカサマツチョウ', '相生町', 'アイオイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島郡笠松町司町', '21', '21303', '5016045', '岐阜県', 'ギフケン', '羽島郡笠松町', 'ハシマグンカサマツチョウ', '司町', 'ツカサマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島郡笠松町宮川町', '21', '21303', '5016046', '岐阜県', 'ギフケン', '羽島郡笠松町', 'ハシマグンカサマツチョウ', '宮川町', 'ミヤガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島郡笠松町二見町', '21', '21303', '5016047', '岐阜県', 'ギフケン', '羽島郡笠松町', 'ハシマグンカサマツチョウ', '二見町', 'フタミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島郡笠松町上本町', '21', '21303', '5016051', '岐阜県', 'ギフケン', '羽島郡笠松町', 'ハシマグンカサマツチョウ', '上本町', 'カミホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島郡笠松町下本町', '21', '21303', '5016052', '岐阜県', 'ギフケン', '羽島郡笠松町', 'ハシマグンカサマツチョウ', '下本町', 'シモホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島郡笠松町港町', '21', '21303', '5016053', '岐阜県', 'ギフケン', '羽島郡笠松町', 'ハシマグンカサマツチョウ', '港町', 'ミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島郡笠松町柳原町', '21', '21303', '5016054', '岐阜県', 'ギフケン', '羽島郡笠松町', 'ハシマグンカサマツチョウ', '柳原町', 'ヤナギハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島郡笠松町西町', '21', '21303', '5016055', '岐阜県', 'ギフケン', '羽島郡笠松町', 'ハシマグンカサマツチョウ', '西町', 'ニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島郡笠松町朝日町', '21', '21303', '5016056', '岐阜県', 'ギフケン', '羽島郡笠松町', 'ハシマグンカサマツチョウ', '朝日町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島郡笠松町下柳川町', '21', '21303', '5016057', '岐阜県', 'ギフケン', '羽島郡笠松町', 'ハシマグンカサマツチョウ', '下柳川町', 'シモヤナガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島郡笠松町上柳川町', '21', '21303', '5016058', '岐阜県', 'ギフケン', '羽島郡笠松町', 'ハシマグンカサマツチョウ', '上柳川町', 'カミヤナガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島郡笠松町東宮町', '21', '21303', '5016059', '岐阜県', 'ギフケン', '羽島郡笠松町', 'ハシマグンカサマツチョウ', '東宮町', 'ヒガシミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島郡笠松町泉町', '21', '21303', '5016061', '岐阜県', 'ギフケン', '羽島郡笠松町', 'ハシマグンカサマツチョウ', '泉町', 'イズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島郡笠松町田代', '21', '21303', '5016062', '岐阜県', 'ギフケン', '羽島郡笠松町', 'ハシマグンカサマツチョウ', '田代', 'デンダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島郡笠松町長池', '21', '21303', '5016063', '岐阜県', 'ギフケン', '羽島郡笠松町', 'ハシマグンカサマツチョウ', '長池', 'ナガイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島郡笠松町北及', '21', '21303', '5016064', '岐阜県', 'ギフケン', '羽島郡笠松町', 'ハシマグンカサマツチョウ', '北及', 'キタオヨビ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島郡笠松町門間', '21', '21303', '5016065', '岐阜県', 'ギフケン', '羽島郡笠松町', 'ハシマグンカサマツチョウ', '門間', 'カドマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島郡笠松町上新町', '21', '21303', '5016071', '岐阜県', 'ギフケン', '羽島郡笠松町', 'ハシマグンカサマツチョウ', '上新町', 'カミシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島郡笠松町中新町', '21', '21303', '5016072', '岐阜県', 'ギフケン', '羽島郡笠松町', 'ハシマグンカサマツチョウ', '中新町', 'ナカシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島郡笠松町下新町', '21', '21303', '5016073', '岐阜県', 'ギフケン', '羽島郡笠松町', 'ハシマグンカサマツチョウ', '下新町', 'シモシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島郡笠松町新町', '21', '21303', '5016074', '岐阜県', 'ギフケン', '羽島郡笠松町', 'ハシマグンカサマツチョウ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島郡笠松町西宮町', '21', '21303', '5016075', '岐阜県', 'ギフケン', '羽島郡笠松町', 'ハシマグンカサマツチョウ', '西宮町', 'ニシミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島郡笠松町門前町', '21', '21303', '5016076', '岐阜県', 'ギフケン', '羽島郡笠松町', 'ハシマグンカサマツチョウ', '門前町', 'モンゼンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島郡笠松町天王町', '21', '21303', '5016077', '岐阜県', 'ギフケン', '羽島郡笠松町', 'ハシマグンカサマツチョウ', '天王町', 'テンノウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島郡笠松町東陽町', '21', '21303', '5016081', '岐阜県', 'ギフケン', '羽島郡笠松町', 'ハシマグンカサマツチョウ', '東陽町', 'トウヨウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島郡笠松町春日町', '21', '21303', '5016082', '岐阜県', 'ギフケン', '羽島郡笠松町', 'ハシマグンカサマツチョウ', '春日町', 'カスガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島郡笠松町常盤町', '21', '21303', '5016083', '岐阜県', 'ギフケン', '羽島郡笠松町', 'ハシマグンカサマツチョウ', '常盤町', 'トキワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島郡笠松町如月町', '21', '21303', '5016084', '岐阜県', 'ギフケン', '羽島郡笠松町', 'ハシマグンカサマツチョウ', '如月町', 'キサラギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島郡笠松町弥生町', '21', '21303', '5016085', '岐阜県', 'ギフケン', '羽島郡笠松町', 'ハシマグンカサマツチョウ', '弥生町', 'ヤヨイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島郡笠松町清住町', '21', '21303', '5016086', '岐阜県', 'ギフケン', '羽島郡笠松町', 'ハシマグンカサマツチョウ', '清住町', 'キヨズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島郡笠松町大池町', '21', '21303', '5016087', '岐阜県', 'ギフケン', '羽島郡笠松町', 'ハシマグンカサマツチョウ', '大池町', 'オオイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島郡笠松町美笠通', '21', '21303', '5016088', '岐阜県', 'ギフケン', '羽島郡笠松町', 'ハシマグンカサマツチョウ', '美笠通', 'ミカサドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島郡笠松町松栄町', '21', '21303', '5016091', '岐阜県', 'ギフケン', '羽島郡笠松町', 'ハシマグンカサマツチョウ', '松栄町', 'ショウエイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島郡笠松町月美町', '21', '21303', '5016092', '岐阜県', 'ギフケン', '羽島郡笠松町', 'ハシマグンカサマツチョウ', '月美町', 'ツキミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島郡笠松町緑町', '21', '21303', '5016093', '岐阜県', 'ギフケン', '羽島郡笠松町', 'ハシマグンカサマツチョウ', '緑町', 'ミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島郡笠松町羽衣町', '21', '21303', '5016094', '岐阜県', 'ギフケン', '羽島郡笠松町', 'ハシマグンカサマツチョウ', '羽衣町', 'ハゴロモチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島郡笠松町中川町', '21', '21303', '5016095', '岐阜県', 'ギフケン', '羽島郡笠松町', 'ハシマグンカサマツチョウ', '中川町', 'ナカガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島郡笠松町友楽町', '21', '21303', '5016096', '岐阜県', 'ギフケン', '羽島郡笠松町', 'ハシマグンカサマツチョウ', '友楽町', 'ユウラクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島郡笠松町瓢町', '21', '21303', '5016097', '岐阜県', 'ギフケン', '羽島郡笠松町', 'ハシマグンカサマツチョウ', '瓢町', 'ヒサゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島郡笠松町桜町', '21', '21303', '5016098', '岐阜県', 'ギフケン', '羽島郡笠松町', 'ハシマグンカサマツチョウ', '桜町', 'サクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島郡岐南町', '21', '21302', '5016100', '岐阜県', 'ギフケン', '羽島郡岐南町', 'ハシマグンギナンチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('52380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島郡笠松町', '21', '21303', '5016100', '岐阜県', 'ギフケン', '羽島郡笠松町', 'ハシマグンカサマツチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('52381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市柳津町栄町', '21', '21201', '5016101', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '柳津町栄町', 'ヤナイヅチョウサカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市柳津町東塚', '21', '21201', '5016102', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '柳津町東塚', 'ヤナイヅチョウヒガシヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市柳津町蓮池', '21', '21201', '5016103', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '柳津町蓮池', 'ヤナイヅチョウハスイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市柳津町本郷', '21', '21201', '5016104', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '柳津町本郷', 'ヤナイヅチョウホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市柳津町梅松', '21', '21201', '5016105', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '柳津町梅松', 'ヤナイヅチョウウメマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市柳津町宮東', '21', '21201', '5016111', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '柳津町宮東', 'ヤナイヅチョウミヤヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市柳津町北塚', '21', '21201', '5016112', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '柳津町北塚', 'ヤナイヅチョウキタヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市柳津町南塚', '21', '21201', '5016113', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '柳津町南塚', 'ヤナイヅチョウミナミヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市柳津町丸野', '21', '21201', '5016115', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '柳津町丸野', 'ヤナイヅチョウマルノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市柳津町上佐波', '21', '21201', '5016121', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '柳津町上佐波', 'ヤナイヅチョウカミサバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市柳津町上佐波西', '21', '21201', '5016121', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '柳津町上佐波西', 'ヤナイヅチョウカミサバニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市柳津町上佐波東', '21', '21201', '5016121', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '柳津町上佐波東', 'ヤナイヅチョウカミサバヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市柳津町佐波', '21', '21201', '5016121', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '柳津町佐波', 'ヤナイヅチョウサバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市柳津町下佐波', '21', '21201', '5016121', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '柳津町下佐波', 'ヤナイヅチョウシモサバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市柳津町下佐波西', '21', '21201', '5016121', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '柳津町下佐波西', 'ヤナイヅチョウシモサバニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市柳津町高桑', '21', '21201', '5016122', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '柳津町高桑', 'ヤナイヅチョウタカクワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市柳津町高桑西', '21', '21201', '5016122', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '柳津町高桑西', 'ヤナイヅチョウタカクワニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市柳津町高桑東', '21', '21201', '5016122', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '柳津町高桑東', 'ヤナイヅチョウタカクワヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市柳津町流通センター', '21', '21201', '5016123', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '柳津町流通センター', 'ヤナイヅチョウリュウツウセンター', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市高河原', '21', '21201', '5016131', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '高河原', 'タカガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市次木', '21', '21201', '5016132', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '次木', 'ナメキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市日置江', '21', '21201', '5016133', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '日置江', 'ヒキエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市大脇', '21', '21201', '5016134', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '大脇', 'オオワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市茶屋新田', '21', '21201', '5016135', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '茶屋新田', 'チャヤシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島市', '21', '21209', '5016200', '岐阜県', 'ギフケン', '羽島市', 'ハシマシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('52415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島市足近町北宿', '21', '21209', '5016201', '岐阜県', 'ギフケン', '羽島市', 'ハシマシ', '足近町北宿', 'アジカチョウキタジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島市足近町市場', '21', '21209', '5016202', '岐阜県', 'ギフケン', '羽島市', 'ハシマシ', '足近町市場', 'アジカチョウイチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島市足近町南宿', '21', '21209', '5016203', '岐阜県', 'ギフケン', '羽島市', 'ハシマシ', '足近町南宿', 'アジカチョウミナミジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島市足近町小荒井', '21', '21209', '5016204', '岐阜県', 'ギフケン', '羽島市', 'ハシマシ', '足近町小荒井', 'アジカチョウコアライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島市足近町南之川', '21', '21209', '5016205', '岐阜県', 'ギフケン', '羽島市', 'ハシマシ', '足近町南之川', 'アジカチョウミナミノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島市新生町', '21', '21209', '5016206', '岐阜県', 'ギフケン', '羽島市', 'ハシマシ', '新生町', 'シンセイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島市足近町', '21', '21209', '5016207', '岐阜県', 'ギフケン', '羽島市', 'ハシマシ', '足近町', 'アジカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島市足近町坂井', '21', '21209', '5016208', '岐阜県', 'ギフケン', '羽島市', 'ハシマシ', '足近町坂井', 'アジカチョウサカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島市足近町直道', '21', '21209', '5016209', '岐阜県', 'ギフケン', '羽島市', 'ハシマシ', '足近町直道', 'アジカチョウスグミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島市正木町南及', '21', '21209', '5016211', '岐阜県', 'ギフケン', '羽島市', 'ハシマシ', '正木町南及', 'マサキチョウミナミオヨビ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島市正木町上大浦', '21', '21209', '5016212', '岐阜県', 'ギフケン', '羽島市', 'ハシマシ', '正木町上大浦', 'マサキチョウカミオオウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島市正木町光法寺', '21', '21209', '5016213', '岐阜県', 'ギフケン', '羽島市', 'ハシマシ', '正木町光法寺', 'マサキチョウミツホウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島市正木町須賀池端', '21', '21209', '5016214', '岐阜県', 'ギフケン', '羽島市', 'ハシマシ', '正木町須賀池端', 'マサキチョウスカイケハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島市正木町須賀赤松', '21', '21209', '5016215', '岐阜県', 'ギフケン', '羽島市', 'ハシマシ', '正木町須賀赤松', 'マサキチョウスカアカマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島市正木町須賀', '21', '21209', '5016216', '岐阜県', 'ギフケン', '羽島市', 'ハシマシ', '正木町須賀', 'マサキチョウスカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島市正木町須賀小松', '21', '21209', '5016217', '岐阜県', 'ギフケン', '羽島市', 'ハシマシ', '正木町須賀小松', 'マサキチョウスカコマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島市正木町須賀本村', '21', '21209', '5016218', '岐阜県', 'ギフケン', '羽島市', 'ハシマシ', '正木町須賀本村', 'マサキチョウスカホンムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島市正木町森', '21', '21209', '5016221', '岐阜県', 'ギフケン', '羽島市', 'ハシマシ', '正木町森', 'マサキチョウモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島市正木町森新田', '21', '21209', '5016222', '岐阜県', 'ギフケン', '羽島市', 'ハシマシ', '正木町森新田', 'マサキチョウモリシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島市正木町大浦新田', '21', '21209', '5016223', '岐阜県', 'ギフケン', '羽島市', 'ハシマシ', '正木町大浦新田', 'マサキチョウオオウラシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島市正木町大浦', '21', '21209', '5016224', '岐阜県', 'ギフケン', '羽島市', 'ハシマシ', '正木町大浦', 'マサキチョウオオウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島市正木町新井', '21', '21209', '5016225', '岐阜県', 'ギフケン', '羽島市', 'ハシマシ', '正木町新井', 'マサキチョウアライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島市正木町三ツ柳', '21', '21209', '5016226', '岐阜県', 'ギフケン', '羽島市', 'ハシマシ', '正木町三ツ柳', 'マサキチョウミツヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島市正木町曲利', '21', '21209', '5016227', '岐阜県', 'ギフケン', '羽島市', 'ハシマシ', '正木町曲利', 'マサキチョウマガリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島市正木町不破一色', '21', '21209', '5016228', '岐阜県', 'ギフケン', '羽島市', 'ハシマシ', '正木町不破一色', 'マサキチョウフワイシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島市正木町坂丸', '21', '21209', '5016229', '岐阜県', 'ギフケン', '羽島市', 'ハシマシ', '正木町坂丸', 'マサキチョウサカマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島市竹鼻町神楽', '21', '21209', '5016231', '岐阜県', 'ギフケン', '羽島市', 'ハシマシ', '竹鼻町神楽', 'タケハナチョウカグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島市竹鼻町狐穴', '21', '21209', '5016232', '岐阜県', 'ギフケン', '羽島市', 'ハシマシ', '竹鼻町狐穴', 'タケハナチョウキツネアナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島市竹鼻町飯柄', '21', '21209', '5016233', '岐阜県', 'ギフケン', '羽島市', 'ハシマシ', '竹鼻町飯柄', 'タケハナチョウイイガラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島市竹鼻町駒塚', '21', '21209', '5016234', '岐阜県', 'ギフケン', '羽島市', 'ハシマシ', '竹鼻町駒塚', 'タケハナチョウコマヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島市竹鼻町蜂尻', '21', '21209', '5016235', '岐阜県', 'ギフケン', '羽島市', 'ハシマシ', '竹鼻町蜂尻', 'タケハナチョウハチジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島市江吉良町', '21', '21209', '5016236', '岐阜県', 'ギフケン', '羽島市', 'ハシマシ', '江吉良町', 'エギラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島市江吉良町江西', '21', '21209', '5016237', '岐阜県', 'ギフケン', '羽島市', 'ハシマシ', '江吉良町江西', 'エギラチョウエニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島市江吉良町江中', '21', '21209', '5016238', '岐阜県', 'ギフケン', '羽島市', 'ハシマシ', '江吉良町江中', 'エギラチョウエナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島市竹鼻町', '21', '21209', '5016241', '岐阜県', 'ギフケン', '羽島市', 'ハシマシ', '竹鼻町', 'タケハナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島市竹鼻町錦町', '21', '21209', '5016242', '岐阜県', 'ギフケン', '羽島市', 'ハシマシ', '竹鼻町錦町', 'タケハナチョウニシキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島市竹鼻町西野町', '21', '21209', '5016243', '岐阜県', 'ギフケン', '羽島市', 'ハシマシ', '竹鼻町西野町', 'タケハナチョウニシノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島市竹鼻町丸の内', '21', '21209', '5016244', '岐阜県', 'ギフケン', '羽島市', 'ハシマシ', '竹鼻町丸の内', 'タケハナチョウマルノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島市福寿町間島', '21', '21209', '5016251', '岐阜県', 'ギフケン', '羽島市', 'ハシマシ', '福寿町間島', 'フクジュチョウマジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島市小熊町島前', '21', '21209', '5016252', '岐阜県', 'ギフケン', '羽島市', 'ハシマシ', '小熊町島前', 'オグマチョウシママエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島市小熊町島新道', '21', '21209', '5016253', '岐阜県', 'ギフケン', '羽島市', 'ハシマシ', '小熊町島新道', 'オグマチョウシマシンドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島市福寿町本郷', '21', '21209', '5016254', '岐阜県', 'ギフケン', '羽島市', 'ハシマシ', '福寿町本郷', 'フクジュチョウホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島市福寿町浅平', '21', '21209', '5016255', '岐阜県', 'ギフケン', '羽島市', 'ハシマシ', '福寿町浅平', 'フクジュチョウアサヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島市福寿町千代田', '21', '21209', '5016256', '岐阜県', 'ギフケン', '羽島市', 'ハシマシ', '福寿町千代田', 'フクジュチョウチヨダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島市福寿町平方', '21', '21209', '5016257', '岐阜県', 'ギフケン', '羽島市', 'ハシマシ', '福寿町平方', 'フクジュチョウヒラカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島市小熊町外粟野', '21', '21209', '5016261', '岐阜県', 'ギフケン', '羽島市', 'ハシマシ', '小熊町外粟野', 'オグマチョウソトアワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島市小熊町内粟野', '21', '21209', '5016262', '岐阜県', 'ギフケン', '羽島市', 'ハシマシ', '小熊町内粟野', 'オグマチョウウチアワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島市小熊町江頭', '21', '21209', '5016263', '岐阜県', 'ギフケン', '羽島市', 'ハシマシ', '小熊町江頭', 'オグマチョウエガシラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島市小熊町島', '21', '21209', '5016264', '岐阜県', 'ギフケン', '羽島市', 'ハシマシ', '小熊町島', 'オグマチョウシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島市小熊町川口前', '21', '21209', '5016265', '岐阜県', 'ギフケン', '羽島市', 'ハシマシ', '小熊町川口前', 'オグマチョウカワクチマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島市小熊町川口', '21', '21209', '5016266', '岐阜県', 'ギフケン', '羽島市', 'ハシマシ', '小熊町川口', 'オグマチョウカワクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島市小熊町天王', '21', '21209', '5016267', '岐阜県', 'ギフケン', '羽島市', 'ハシマシ', '小熊町天王', 'オグマチョウテンノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島市小熊町東小熊', '21', '21209', '5016271', '岐阜県', 'ギフケン', '羽島市', 'ハシマシ', '小熊町東小熊', 'オグマチョウヒガシオグマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島市小熊町相田', '21', '21209', '5016272', '岐阜県', 'ギフケン', '羽島市', 'ハシマシ', '小熊町相田', 'オグマチョウアイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島市小熊町', '21', '21209', '5016273', '岐阜県', 'ギフケン', '羽島市', 'ハシマシ', '小熊町', 'オグマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島市小熊町西小熊', '21', '21209', '5016274', '岐阜県', 'ギフケン', '羽島市', 'ハシマシ', '小熊町西小熊', 'オグマチョウニシオグマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島市舟橋町宮北', '21', '21209', '5016301', '岐阜県', 'ギフケン', '羽島市', 'ハシマシ', '舟橋町宮北', 'フナバシチョウミヤキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島市舟橋町', '21', '21209', '5016302', '岐阜県', 'ギフケン', '羽島市', 'ハシマシ', '舟橋町', 'フナバシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島市舟橋町本町', '21', '21209', '5016303', '岐阜県', 'ギフケン', '羽島市', 'ハシマシ', '舟橋町本町', 'フナバシチョウホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島市舟橋町出須賀', '21', '21209', '5016304', '岐阜県', 'ギフケン', '羽島市', 'ハシマシ', '舟橋町出須賀', 'フナバシチョウデスカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島市上中町長間', '21', '21209', '5016311', '岐阜県', 'ギフケン', '羽島市', 'ハシマシ', '上中町長間', 'カミナカチョウナガマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島市上中町一色', '21', '21209', '5016312', '岐阜県', 'ギフケン', '羽島市', 'ハシマシ', '上中町一色', 'カミナカチョウイシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島市下中町加賀野井', '21', '21209', '5016313', '岐阜県', 'ギフケン', '羽島市', 'ハシマシ', '下中町加賀野井', 'シモナカチョウカガノイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島市下中町城屋敷', '21', '21209', '5016314', '岐阜県', 'ギフケン', '羽島市', 'ハシマシ', '下中町城屋敷', 'シモナカチョウシロヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島市下中町石田', '21', '21209', '5016315', '岐阜県', 'ギフケン', '羽島市', 'ハシマシ', '下中町石田', 'シモナカチョウイシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島市下中町市之枝', '21', '21209', '5016316', '岐阜県', 'ギフケン', '羽島市', 'ハシマシ', '下中町市之枝', 'シモナカチョウイチノエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島市上中町午北', '21', '21209', '5016317', '岐阜県', 'ギフケン', '羽島市', 'ハシマシ', '上中町午北', 'カミナカチョウウマキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島市上中町沖', '21', '21209', '5016318', '岐阜県', 'ギフケン', '羽島市', 'ハシマシ', '上中町沖', 'カミナカチョウオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島市上中町中', '21', '21209', '5016319', '岐阜県', 'ギフケン', '羽島市', 'ハシマシ', '上中町中', 'カミナカチョウナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島市桑原町八神', '21', '21209', '5016321', '岐阜県', 'ギフケン', '羽島市', 'ハシマシ', '桑原町八神', 'クワバラチョウヤガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島市桑原町前野', '21', '21209', '5016322', '岐阜県', 'ギフケン', '羽島市', 'ハシマシ', '桑原町前野', 'クワバラチョウマエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島市桑原町午南', '21', '21209', '5016323', '岐阜県', 'ギフケン', '羽島市', 'ハシマシ', '桑原町午南', 'クワバラチョウウマミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島市桑原町小薮', '21', '21209', '5016324', '岐阜県', 'ギフケン', '羽島市', 'ハシマシ', '桑原町小薮', 'クワバラチョウコヤブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島市桑原町大須', '21', '21209', '5016325', '岐阜県', 'ギフケン', '羽島市', 'ハシマシ', '桑原町大須', 'クワバラチョウオオス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島市桑原町東方', '21', '21209', '5016326', '岐阜県', 'ギフケン', '羽島市', 'ハシマシ', '桑原町東方', 'クワバラチョウヒガシガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島市桑原町西小薮', '21', '21209', '5016327', '岐阜県', 'ギフケン', '羽島市', 'ハシマシ', '桑原町西小薮', 'クワバラチョウニシコヤブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島市桑原町平太', '21', '21209', '5016328', '岐阜県', 'ギフケン', '羽島市', 'ハシマシ', '桑原町平太', 'クワバラチョウヘイタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島市堀津町', '21', '21209', '5016330', '岐阜県', 'ギフケン', '羽島市', 'ハシマシ', '堀津町', 'ホッツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島市堀津町横手', '21', '21209', '5016331', '岐阜県', 'ギフケン', '羽島市', 'ハシマシ', '堀津町横手', 'ホッツチョウヨコテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島市堀津町須賀北', '21', '21209', '5016332', '岐阜県', 'ギフケン', '羽島市', 'ハシマシ', '堀津町須賀北', 'ホッツチョウスカキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島市堀津町東山', '21', '21209', '5016333', '岐阜県', 'ギフケン', '羽島市', 'ハシマシ', '堀津町東山', 'ホッツチョウヒガシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島市堀津町前谷', '21', '21209', '5016334', '岐阜県', 'ギフケン', '羽島市', 'ハシマシ', '堀津町前谷', 'ホッツチョウマエダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島市堀津町須賀南', '21', '21209', '5016335', '岐阜県', 'ギフケン', '羽島市', 'ハシマシ', '堀津町須賀南', 'ホッツチョウスカミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島市堀津町須賀西', '21', '21209', '5016336', '岐阜県', 'ギフケン', '羽島市', 'ハシマシ', '堀津町須賀西', 'ホッツチョウスカニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島市堀津町中屋敷', '21', '21209', '5016337', '岐阜県', 'ギフケン', '羽島市', 'ハシマシ', '堀津町中屋敷', 'ホッツチョウナカヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県羽島市堀津町須賀中', '21', '21209', '5016338', '岐阜県', 'ギフケン', '羽島市', 'ハシマシ', '堀津町須賀中', 'ホッツチョウスカナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市粟野', '21', '21201', '5020001', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '粟野', 'アワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市粟野東', '21', '21201', '5020002', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '粟野東', 'アワノヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市三田洞東', '21', '21201', '5020003', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '三田洞東', 'ミタホラヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市三田洞', '21', '21201', '5020004', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '三田洞', 'ミタホラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市岩崎', '21', '21201', '5020005', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '岩崎', 'イワサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市粟野西', '21', '21201', '5020006', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '粟野西', 'アワノニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市粟野台', '21', '21201', '5020007', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '粟野台', 'アワノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市長良古津', '21', '21201', '5020011', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '長良古津', 'ナガラフルツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市長良志段見', '21', '21201', '5020012', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '長良志段見', 'ナガラシダミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市中川原', '21', '21201', '5020013', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '中川原', 'ナカガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市雄総緑町', '21', '21201', '5020014', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '雄総緑町', 'オブサミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市雄総柳町', '21', '21201', '5020015', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '雄総柳町', 'オブサヤナギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市雄総桜町', '21', '21201', '5020016', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '雄総桜町', 'オブササクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市長良雄総', '21', '21201', '5020017', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '長良雄総', 'ナガラオブサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市西後町', '21', '21201', '5020021', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '西後町', 'サイゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市長良東郷町', '21', '21201', '5020022', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '長良東郷町', 'ナガラトウゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市城前町', '21', '21201', '5020023', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '城前町', 'シロマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市堀田町', '21', '21201', '5020024', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '堀田町', 'ホリタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市山先町', '21', '21201', '5020025', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '山先町', 'ヤマサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市長良桜井町', '21', '21201', '5020026', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '長良桜井町', 'ナガラサクライチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市長良宮口町', '21', '21201', '5020027', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '長良宮口町', 'ナガラミヤグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市長良白妙町', '21', '21201', '5020028', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '長良白妙町', 'ナガラシラタエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市長良若葉町', '21', '21201', '5020029', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '長良若葉町', 'ナガラワカバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市長良大路', '21', '21201', '5020031', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '長良大路', 'ナガラオオジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市長良高嶺町', '21', '21201', '5020032', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '長良高嶺町', 'ナガラタカミネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市長良有楽町', '21', '21201', '5020033', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '長良有楽町', 'ナガラユウラクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市長良有明町', '21', '21201', '5020034', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '長良有明町', 'ナガラアリアケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市長良南陽町', '21', '21201', '5020035', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '長良南陽町', 'ナガラナンヨウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市長良大前町', '21', '21201', '5020036', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '長良大前町', 'ナガラオオマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市長良金碧町', '21', '21201', '5020037', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '長良金碧町', 'ナガラキンペキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市長良法久寺町', '21', '21201', '5020038', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '長良法久寺町', 'ナガラホウキュウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市長良海用町', '21', '21201', '5020041', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '長良海用町', 'ナガラカイヨウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市長良城西町', '21', '21201', '5020042', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '長良城西町', 'ナガラシロニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市長良東町', '21', '21201', '5020043', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '長良東町', 'ナガラヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市長良校文町', '21', '21201', '5020044', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '長良校文町', 'ナガラコウブンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市長良校前町', '21', '21201', '5020045', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '長良校前町', 'ナガラコウゼンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市長良杉乃町', '21', '21201', '5020046', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '長良杉乃町', 'ナガラスギノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市長良葵町', '21', '21201', '5020047', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '長良葵町', 'ナガラアオイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市長良幸和町', '21', '21201', '5020051', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '長良幸和町', 'ナガラコウワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市長良小松町', '21', '21201', '5020052', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '長良小松町', 'ナガラコマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市長良宮路町', '21', '21201', '5020053', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '長良宮路町', 'ナガラミヤジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市長良井田', '21', '21201', '5020054', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '長良井田', 'ナガライダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市長良福江町', '21', '21201', '5020055', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '長良福江町', 'ナガラフクエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市長良真生町', '21', '21201', '5020056', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '長良真生町', 'ナガラシンセイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市長良竜東町', '21', '21201', '5020061', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '長良竜東町', 'ナガラリュウトウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市長良春田', '21', '21201', '5020062', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '長良春田', 'ナガラハルタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市長良一楽', '21', '21201', '5020063', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '長良一楽', 'ナガライチラク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市長良田中前', '21', '21201', '5020064', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '長良田中前', 'ナガラタナカマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市長良森町', '21', '21201', '5020065', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '長良森町', 'ナガラモリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市長良仙田町', '21', '21201', '5020066', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '長良仙田町', 'ナガラセンダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市長良西野前', '21', '21201', '5020067', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '長良西野前', 'ナガラニシノマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市長良', '21', '21201', '5020071', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '長良', 'ナガラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市長良福泉', '21', '21201', '5020072', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '長良福泉', 'ナガラフクイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市長良田中', '21', '21201', '5020073', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '長良田中', 'ナガラタナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市長良西山前', '21', '21201', '5020074', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '長良西山前', 'ナガラニシヤママエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市長良子正賀', '21', '21201', '5020075', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '長良子正賀', 'ナガラコショウガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市長良友瀬', '21', '21201', '5020076', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '長良友瀬', 'ナガラトモセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市長良奥郷', '21', '21201', '5020077', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '長良奥郷', 'ナガラオクゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市長良', '21', '21201', '5020081', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '長良', 'ナガラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市長良東', '21', '21201', '5020082', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '長良東', 'ナガラヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市椿洞', '21', '21201', '5020801', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '椿洞', 'ツバキボラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市打越', '21', '21201', '5020802', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '打越', 'ウチコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市上土居', '21', '21201', '5020803', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '上土居', 'カミツチイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市若福町', '21', '21201', '5020811', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '若福町', 'ワカフクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市八代', '21', '21201', '5020812', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '八代', 'ヤシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市福光東', '21', '21201', '5020813', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '福光東', 'フクミツヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市福光西', '21', '21201', '5020814', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '福光西', 'フクミツニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市福光南町', '21', '21201', '5020815', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '福光南町', 'フクミツミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市道三町', '21', '21201', '5020816', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '道三町', 'ドウサンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市長良福光', '21', '21201', '5020817', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '長良福光', 'ナガラフクミツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市太平町', '21', '21201', '5020821', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '太平町', 'タイヘイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市福田町', '21', '21201', '5020822', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '福田町', 'フクタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市光栄町', '21', '21201', '5020823', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '光栄町', 'コウエイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市花ノ木町', '21', '21201', '5020824', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '花ノ木町', 'ハナノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市初日町', '21', '21201', '5020825', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '初日町', 'ハツヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市楠町', '21', '21201', '5020826', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '楠町', 'クスノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市平和通', '21', '21201', '5020827', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '平和通', 'ヘイワドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市金華町', '21', '21201', '5020828', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '金華町', 'キンカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市万代町', '21', '21201', '5020829', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '万代町', 'バンダイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市菊水町', '21', '21201', '5020831', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '菊水町', 'キクスイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市千代田町', '21', '21201', '5020832', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '千代田町', 'チヨダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市松風町', '21', '21201', '5020833', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '松風町', 'マツカゼチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市養老町', '21', '21201', '5020834', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '養老町', 'ヨウロウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市織田町', '21', '21201', '5020835', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '織田町', 'オダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市若竹町', '21', '21201', '5020836', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '若竹町', 'ワカタケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市鵜川町', '21', '21201', '5020837', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '鵜川町', 'ウカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市長良丘', '21', '21201', '5020838', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '長良丘', 'ナガラオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市学園町', '21', '21201', '5020841', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '学園町', 'ガクエンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市早田', '21', '21201', '5020842', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '早田', 'ソウデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市早田東町', '21', '21201', '5020843', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '早田東町', 'ソウデンヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市岩倉町', '21', '21201', '5020844', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '岩倉町', 'イワクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市早田町', '21', '21201', '5020845', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '早田町', 'ソウデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市津島町', '21', '21201', '5020846', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '津島町', 'ツシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市早田栄町', '21', '21201', '5020847', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '早田栄町', 'ソウデンサカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市早田本町', '21', '21201', '5020848', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '早田本町', 'ソウデンホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市栄新町', '21', '21201', '5020849', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '栄新町', 'サカエシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市鷺山東', '21', '21201', '5020850', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '鷺山東', 'サギヤマヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市鷺山', '21', '21201', '5020851', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '鷺山', 'サギヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市南蝉', '21', '21201', '5020852', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '南蝉', 'ミナミセミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市鷺山清洲町', '21', '21201', '5020853', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '鷺山清洲町', 'サギヤマキヨスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市鷺山向井町', '21', '21201', '5020854', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '鷺山向井町', 'サギヤマムカイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市鷺山緑ケ丘', '21', '21201', '5020855', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '鷺山緑ケ丘', 'サギヤマミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市鷺山緑ケ丘新町', '21', '21201', '5020856', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '鷺山緑ケ丘新町', 'サギヤマミドリガオカシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市正木', '21', '21201', '5020857', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '正木', 'マサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市下土居', '21', '21201', '5020858', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '下土居', 'シモツチイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市城田寺', '21', '21201', '5020859', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '城田寺', 'キダイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市上城田寺南', '21', '21201', '5020861', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '上城田寺南', 'カミキダイジミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市上城田寺中', '21', '21201', '5020862', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '上城田寺中', 'カミキダイジナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市上城田寺西', '21', '21201', '5020863', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '上城田寺西', 'カミキダイジニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市上城田寺東', '21', '21201', '5020864', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '上城田寺東', 'カミキダイジヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市鷺山新町', '21', '21201', '5020871', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '鷺山新町', 'サギヤマシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市正木北町', '21', '21201', '5020881', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '正木北町', 'マサキキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市正木中', '21', '21201', '5020882', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '正木中', 'マサキナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市光町', '21', '21201', '5020901', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '光町', 'ヒカリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市早田大通', '21', '21201', '5020902', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '早田大通', 'ソウデンオオドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市美島町', '21', '21201', '5020903', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '美島町', 'ミシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市島栄町', '21', '21201', '5020904', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '島栄町', 'シマサカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市山吹町', '21', '21201', '5020905', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '山吹町', 'ヤマブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市池ノ上町', '21', '21201', '5020906', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '池ノ上町', 'イケノウエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市島新町', '21', '21201', '5020907', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '島新町', 'シマシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市近島', '21', '21201', '5020908', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '近島', 'ゴンノシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市白菊町', '21', '21201', '5020909', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '白菊町', 'シラギクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市北島', '21', '21201', '5020911', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '北島', 'キタジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市西島町', '21', '21201', '5020912', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '西島町', 'ニシジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市東島', '21', '21201', '5020913', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '東島', 'ヒガシジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市菅生', '21', '21201', '5020914', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '菅生', 'スゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市江口', '21', '21201', '5020915', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '江口', 'エグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市西中島', '21', '21201', '5020916', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '西中島', 'ニシナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市島田', '21', '21201', '5020917', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '島田', 'シマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市守口町', '21', '21201', '5020921', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '守口町', 'モリグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市明神町', '21', '21201', '5020922', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '明神町', 'ミョウジンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市宮浦町', '21', '21201', '5020923', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '宮浦町', 'ミヤウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市旦島宮町', '21', '21201', '5020924', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '旦島宮町', 'ダンノシマミヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市旦島中町', '21', '21201', '5020925', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '旦島中町', 'ダンノシマナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市旦島', '21', '21201', '5020926', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '旦島', 'ダンノシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市旦島西町', '21', '21201', '5020927', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '旦島西町', 'ダンノシマニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市旦島中', '21', '21201', '5020928', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '旦島中', 'ダンノシマナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市則武', '21', '21201', '5020931', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '則武', 'ノリタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市則武中', '21', '21201', '5020932', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '則武中', 'ノリタケナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市日光町', '21', '21201', '5020933', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '日光町', 'ニッコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市大福町', '21', '21201', '5020934', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '大福町', 'ダイフクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市萱場東町', '21', '21201', '5020935', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '萱場東町', 'カヤバヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市萱場南', '21', '21201', '5020936', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '萱場南', 'カヤバミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市萱場町', '21', '21201', '5020937', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '萱場町', 'カヤバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市萱場北町', '21', '21201', '5020938', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '萱場北町', 'カヤバキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県岐阜市則武西', '21', '21201', '5020939', '岐阜県', 'ギフケン', '岐阜市', 'ギフシ', '則武西', 'ノリタケニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市', '21', '21202', '5030000', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('52661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市大島町', '21', '21202', '5030001', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '大島町', 'オオシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市開発町', '21', '21202', '5030002', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '開発町', 'カイハツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市津村町', '21', '21202', '5030003', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '津村町', 'ツムラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市新開町', '21', '21202', '5030004', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '新開町', 'シンカイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市和合本町', '21', '21202', '5030005', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '和合本町', 'ワゴウホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市加賀野', '21', '21202', '5030006', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '加賀野', 'カガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市貝曽根町', '21', '21202', '5030007', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '貝曽根町', 'カイゾネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市楽田町', '21', '21202', '5030008', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '楽田町', 'ガクデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市坂下町', '21', '21202', '5030009', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '坂下町', 'サカシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市曽根町', '21', '21202', '5030011', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '曽根町', 'ソネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市三津屋町', '21', '21202', '5030012', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '三津屋町', 'ミツヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市赤花町', '21', '21202', '5030013', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '赤花町', 'アカバナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市領家町', '21', '21202', '5030014', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '領家町', 'リョウケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市林町', '21', '21202', '5030015', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '林町', 'ハヤシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市八島町', '21', '21202', '5030016', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '八島町', 'ヤシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市中川町', '21', '21202', '5030017', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '中川町', 'ナカガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市西之川町', '21', '21202', '5030018', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '西之川町', 'ニシノカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市北方町', '21', '21202', '5030019', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '北方町', 'キタガタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市河間町', '21', '21202', '5030021', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '河間町', 'ガマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市中野町', '21', '21202', '5030022', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '中野町', 'ナカノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市笠木町', '21', '21202', '5030023', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '笠木町', 'カサギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市宿地町', '21', '21202', '5030024', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '宿地町', 'シュクジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市見取町', '21', '21202', '5030025', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '見取町', 'ミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市室村町', '21', '21202', '5030026', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '室村町', 'ムロムラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市笠縫町', '21', '21202', '5030027', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '笠縫町', 'カサヌイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市牧野町', '21', '21202', '5030031', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '牧野町', 'マキノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市熊野町', '21', '21202', '5030032', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '熊野町', 'クマノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市福田町', '21', '21202', '5030033', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '福田町', 'フクタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市荒尾町', '21', '21202', '5030034', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '荒尾町', 'アラオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市荒尾玉池', '21', '21202', '5030035', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '荒尾玉池', 'アラオタマイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市古知丸', '21', '21202', '5030036', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '古知丸', 'コチマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県安八郡安八町', '21', '21383', '5030100', '岐阜県', 'ギフケン', '安八郡安八町', 'アンパチグンアンパチチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('52693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市墨俣町先入方', '21', '21202', '5030101', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '墨俣町先入方', 'スノマタチョウセンイリカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市墨俣町墨俣', '21', '21202', '5030102', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '墨俣町墨俣', 'スノマタチョウスノマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市墨俣町上宿', '21', '21202', '5030103', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '墨俣町上宿', 'スノマタチョウカミジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市墨俣町下宿', '21', '21202', '5030104', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '墨俣町下宿', 'スノマタチョウシモジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市墨俣町二ツ木', '21', '21202', '5030105', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '墨俣町二ツ木', 'スノマタチョウフタツギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県安八郡安八町西結', '21', '21383', '5030111', '岐阜県', 'ギフケン', '安八郡安八町', 'アンパチグンアンパチチョウ', '西結', 'ニシムスブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県安八郡安八町芝原', '21', '21383', '5030112', '岐阜県', 'ギフケン', '安八郡安八町', 'アンパチグンアンパチチョウ', '芝原', 'シバハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県安八郡安八町東結', '21', '21383', '5030112', '岐阜県', 'ギフケン', '安八郡安八町', 'アンパチグンアンパチチョウ', '東結', 'ヒガシムスブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県安八郡安八町北今ケ渕', '21', '21383', '5030113', '岐阜県', 'ギフケン', '安八郡安八町', 'アンパチグンアンパチチョウ', '北今ケ渕', 'キタイマガフチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県安八郡安八町森部', '21', '21383', '5030114', '岐阜県', 'ギフケン', '安八郡安八町', 'アンパチグンアンパチチョウ', '森部', 'モリベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県安八郡安八町南今ケ渕', '21', '21383', '5030115', '岐阜県', 'ギフケン', '安八郡安八町', 'アンパチグンアンパチチョウ', '南今ケ渕', 'ミナミイマガフチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県安八郡安八町大森', '21', '21383', '5030116', '岐阜県', 'ギフケン', '安八郡安八町', 'アンパチグンアンパチチョウ', '大森', 'オオモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県安八郡安八町大明神', '21', '21383', '5030117', '岐阜県', 'ギフケン', '安八郡安八町', 'アンパチグンアンパチチョウ', '大明神', 'ダイミョウジン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県安八郡安八町宝江', '21', '21383', '5030118', '岐阜県', 'ギフケン', '安八郡安八町', 'アンパチグンアンパチチョウ', '宝江', 'ホウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県安八郡安八町氷取', '21', '21383', '5030121', '岐阜県', 'ギフケン', '安八郡安八町', 'アンパチグンアンパチチョウ', '氷取', 'コオリトリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県安八郡安八町善光', '21', '21383', '5030122', '岐阜県', 'ギフケン', '安八郡安八町', 'アンパチグンアンパチチョウ', '善光', 'ゼンコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県安八郡安八町南條', '21', '21383', '5030123', '岐阜県', 'ギフケン', '安八郡安八町', 'アンパチグンアンパチチョウ', '南條', 'ミナミジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県安八郡安八町中', '21', '21383', '5030124', '岐阜県', 'ギフケン', '安八郡安八町', 'アンパチグンアンパチチョウ', '中', 'ナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県安八郡安八町牧', '21', '21383', '5030125', '岐阜県', 'ギフケン', '安八郡安八町', 'アンパチグンアンパチチョウ', '牧', 'マキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県安八郡安八町中須', '21', '21383', '5030126', '岐阜県', 'ギフケン', '安八郡安八町', 'アンパチグンアンパチチョウ', '中須', 'ナカズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県安八郡安八町城', '21', '21383', '5030127', '岐阜県', 'ギフケン', '安八郡安八町', 'アンパチグンアンパチチョウ', '城', 'シロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県安八郡安八町大野', '21', '21383', '5030128', '岐阜県', 'ギフケン', '安八郡安八町', 'アンパチグンアンパチチョウ', '大野', 'オオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県安八郡安八町外善光', '21', '21383', '5030129', '岐阜県', 'ギフケン', '安八郡安八町', 'アンパチグンアンパチチョウ', '外善光', 'ソトゼンコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市平町揖斐川東', '21', '21202', '5030141', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '平町', 'ヒラマチ', null, null, '揖斐川東', 'イビガワヒガシ');
INSERT INTO `ms_addresses` VALUES ('52720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県安八郡輪之内町', '21', '21382', '5030200', '岐阜県', 'ギフケン', '安八郡輪之内町', 'アンパチグンワノウチチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('52721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県安八郡輪之内町楡俣', '21', '21382', '5030201', '岐阜県', 'ギフケン', '安八郡輪之内町', 'アンパチグンワノウチチョウ', '楡俣', 'ニレマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県安八郡輪之内町大藪', '21', '21382', '5030202', '岐阜県', 'ギフケン', '安八郡輪之内町', 'アンパチグンワノウチチョウ', '大藪', 'オオヤブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県安八郡輪之内町楡俣新田', '21', '21382', '5030203', '岐阜県', 'ギフケン', '安八郡輪之内町', 'アンパチグンワノウチチョウ', '楡俣新田', 'ニレマタシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県安八郡輪之内町四郷', '21', '21382', '5030204', '岐阜県', 'ギフケン', '安八郡輪之内町', 'アンパチグンワノウチチョウ', '四郷', 'ヨゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県安八郡輪之内町下大榑', '21', '21382', '5030205', '岐阜県', 'ギフケン', '安八郡輪之内町', 'アンパチグンワノウチチョウ', '下大榑', 'シモオオグレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県安八郡輪之内町下大榑新田', '21', '21382', '5030206', '岐阜県', 'ギフケン', '安八郡輪之内町', 'アンパチグンワノウチチョウ', '下大榑新田', 'シモオオグレシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県安八郡輪之内町福束新田', '21', '21382', '5030211', '岐阜県', 'ギフケン', '安八郡輪之内町', 'アンパチグンワノウチチョウ', '福束新田', 'フクヅカシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県安八郡輪之内町中郷新田', '21', '21382', '5030212', '岐阜県', 'ギフケン', '安八郡輪之内町', 'アンパチグンワノウチチョウ', '中郷新田', 'ナカゴウシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県安八郡輪之内町藻池新田', '21', '21382', '5030213', '岐阜県', 'ギフケン', '安八郡輪之内町', 'アンパチグンワノウチチョウ', '藻池新田', 'モイケシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県安八郡輪之内町海松新田', '21', '21382', '5030214', '岐阜県', 'ギフケン', '安八郡輪之内町', 'アンパチグンワノウチチョウ', '海松新田', 'ミルシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県安八郡輪之内町松内', '21', '21382', '5030215', '岐阜県', 'ギフケン', '安八郡輪之内町', 'アンパチグンワノウチチョウ', '松内', 'マツウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県安八郡輪之内町大吉新田', '21', '21382', '5030216', '岐阜県', 'ギフケン', '安八郡輪之内町', 'アンパチグンワノウチチョウ', '大吉新田', 'オオヨシシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県安八郡輪之内町南波', '21', '21382', '5030231', '岐阜県', 'ギフケン', '安八郡輪之内町', 'アンパチグンワノウチチョウ', '南波', 'ナンバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県安八郡輪之内町本戸', '21', '21382', '5030232', '岐阜県', 'ギフケン', '安八郡輪之内町', 'アンパチグンワノウチチョウ', '本戸', 'ホンド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県安八郡輪之内町中郷', '21', '21382', '5030233', '岐阜県', 'ギフケン', '安八郡輪之内町', 'アンパチグンワノウチチョウ', '中郷', 'ナカゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県安八郡輪之内町里', '21', '21382', '5030234', '岐阜県', 'ギフケン', '安八郡輪之内町', 'アンパチグンワノウチチョウ', '里', 'サト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県安八郡輪之内町福束', '21', '21382', '5030235', '岐阜県', 'ギフケン', '安八郡輪之内町', 'アンパチグンワノウチチョウ', '福束', 'フクヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県安八郡輪之内町塩喰', '21', '21382', '5030236', '岐阜県', 'ギフケン', '安八郡輪之内町', 'アンパチグンワノウチチョウ', '塩喰', 'シオバミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県海津市平田町須賀', '21', '21221', '5030301', '岐阜県', 'ギフケン', '海津市', 'カイヅシ', '平田町須賀', 'ヒラタチョウスカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県海津市平田町勝賀', '21', '21221', '5030302', '岐阜県', 'ギフケン', '海津市', 'カイヅシ', '平田町勝賀', 'ヒラタチョウカツガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県海津市平田町野寺', '21', '21221', '5030303', '岐阜県', 'ギフケン', '海津市', 'カイヅシ', '平田町野寺', 'ヒラタチョウノデラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県海津市平田町幡長', '21', '21221', '5030304', '岐阜県', 'ギフケン', '海津市', 'カイヅシ', '平田町幡長', 'ヒラタチョウハタオサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県海津市平田町者結', '21', '21221', '5030305', '岐阜県', 'ギフケン', '海津市', 'カイヅシ', '平田町者結', 'ヒラタチョウジャケツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県海津市平田町蛇池', '21', '21221', '5030306', '岐阜県', 'ギフケン', '海津市', 'カイヅシ', '平田町蛇池', 'ヒラタチョウジャイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県海津市平田町岡', '21', '21221', '5030307', '岐阜県', 'ギフケン', '海津市', 'カイヅシ', '平田町岡', 'ヒラタチョウオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県海津市平田町仏師川', '21', '21221', '5030311', '岐阜県', 'ギフケン', '海津市', 'カイヅシ', '平田町仏師川', 'ヒラタチョウブシガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県海津市平田町三郷', '21', '21221', '5030312', '岐阜県', 'ギフケン', '海津市', 'カイヅシ', '平田町三郷', 'ヒラタチョウサンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県海津市平田町高田', '21', '21221', '5030313', '岐阜県', 'ギフケン', '海津市', 'カイヅシ', '平田町高田', 'ヒラタチョウタカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県海津市平田町西島', '21', '21221', '5030314', '岐阜県', 'ギフケン', '海津市', 'カイヅシ', '平田町西島', 'ヒラタチョウニシジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県海津市平田町今尾', '21', '21221', '5030321', '岐阜県', 'ギフケン', '海津市', 'カイヅシ', '平田町今尾', 'ヒラタチョウイマオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県海津市平田町土倉', '21', '21221', '5030322', '岐阜県', 'ギフケン', '海津市', 'カイヅシ', '平田町土倉', 'ヒラタチョウツチクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県海津市平田町脇野', '21', '21221', '5030323', '岐阜県', 'ギフケン', '海津市', 'カイヅシ', '平田町脇野', 'ヒラタチョウワキノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県海津市南濃町津屋', '21', '21221', '5030401', '岐阜県', 'ギフケン', '海津市', 'カイヅシ', '南濃町津屋', 'ナンノウチョウツヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県海津市南濃町志津新田', '21', '21221', '5030402', '岐阜県', 'ギフケン', '海津市', 'カイヅシ', '南濃町志津新田', 'ナンノウチョウシヅシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県海津市南濃町志津', '21', '21221', '5030403', '岐阜県', 'ギフケン', '海津市', 'カイヅシ', '南濃町志津', 'ナンノウチョウシヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県海津市南濃町早瀬', '21', '21221', '5030404', '岐阜県', 'ギフケン', '海津市', 'カイヅシ', '南濃町早瀬', 'ナンノウチョウハヤセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県海津市南濃町駒野新田', '21', '21221', '5030405', '岐阜県', 'ギフケン', '海津市', 'カイヅシ', '南濃町駒野新田', 'ナンノウチョウコマノシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県海津市南濃町戸田', '21', '21221', '5030406', '岐阜県', 'ギフケン', '海津市', 'カイヅシ', '南濃町戸田', 'ナンノウチョウトダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県海津市南濃町徳田', '21', '21221', '5030407', '岐阜県', 'ギフケン', '海津市', 'カイヅシ', '南濃町徳田', 'ナンノウチョウトクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県海津市南濃町庭田', '21', '21221', '5030408', '岐阜県', 'ギフケン', '海津市', 'カイヅシ', '南濃町庭田', 'ナンノウチョウニワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県海津市南濃町駒野', '21', '21221', '5030411', '岐阜県', 'ギフケン', '海津市', 'カイヅシ', '南濃町駒野', 'ナンノウチョウコマノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県海津市南濃町奥条', '21', '21221', '5030412', '岐阜県', 'ギフケン', '海津市', 'カイヅシ', '南濃町奥条', 'ナンノウチョウオクジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県海津市南濃町羽沢', '21', '21221', '5030413', '岐阜県', 'ギフケン', '海津市', 'カイヅシ', '南濃町羽沢', 'ナンノウチョウハザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県海津市南濃町上野河戸', '21', '21221', '5030414', '岐阜県', 'ギフケン', '海津市', 'カイヅシ', '南濃町上野河戸', 'ナンノウチョウウエノコウズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県海津市南濃町山崎', '21', '21221', '5030415', '岐阜県', 'ギフケン', '海津市', 'カイヅシ', '南濃町山崎', 'ナンノウチョウヤマザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県海津市南濃町安江', '21', '21221', '5030531', '岐阜県', 'ギフケン', '海津市', 'カイヅシ', '南濃町安江', 'ナンノウチョウヤスエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県海津市南濃町太田', '21', '21221', '5030532', '岐阜県', 'ギフケン', '海津市', 'カイヅシ', '南濃町太田', 'ナンノウチョウオオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県海津市南濃町田鶴', '21', '21221', '5030533', '岐阜県', 'ギフケン', '海津市', 'カイヅシ', '南濃町田鶴', 'ナンノウチョウタヅル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県海津市南濃町境', '21', '21221', '5030534', '岐阜県', 'ギフケン', '海津市', 'カイヅシ', '南濃町境', 'ナンノウチョウサカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県海津市南濃町松山', '21', '21221', '5030535', '岐阜県', 'ギフケン', '海津市', 'カイヅシ', '南濃町松山', 'ナンノウチョウマツヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県海津市南濃町吉田', '21', '21221', '5030536', '岐阜県', 'ギフケン', '海津市', 'カイヅシ', '南濃町吉田', 'ナンノウチョウヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県海津市', '21', '21221', '5030600', '岐阜県', 'ギフケン', '海津市', 'カイヅシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('52778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県海津市海津町松木', '21', '21221', '5030601', '岐阜県', 'ギフケン', '海津市', 'カイヅシ', '海津町松木', 'カイヅチョウマツノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県海津市海津町瀬古', '21', '21221', '5030602', '岐阜県', 'ギフケン', '海津市', 'カイヅシ', '海津町瀬古', 'カイヅチョウセコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県海津市海津町神桐', '21', '21221', '5030603', '岐阜県', 'ギフケン', '海津市', 'カイヅシ', '海津町神桐', 'カイヅチョウカミギリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県海津市海津町成戸', '21', '21221', '5030604', '岐阜県', 'ギフケン', '海津市', 'カイヅシ', '海津町成戸', 'カイヅチョウナリト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県海津市海津町福一色', '21', '21221', '5030605', '岐阜県', 'ギフケン', '海津市', 'カイヅシ', '海津町福一色', 'カイヅチョウフクイシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県海津市海津町田中', '21', '21221', '5030606', '岐阜県', 'ギフケン', '海津市', 'カイヅシ', '海津町田中', 'カイヅチョウタナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県海津市海津町鹿野', '21', '21221', '5030608', '岐阜県', 'ギフケン', '海津市', 'カイヅシ', '海津町鹿野', 'カイヅチョウカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県海津市海津町秋江', '21', '21221', '5030611', '岐阜県', 'ギフケン', '海津市', 'カイヅシ', '海津町秋江', 'カイヅチョウアキエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県海津市海津町大和田', '21', '21221', '5030612', '岐阜県', 'ギフケン', '海津市', 'カイヅシ', '海津町大和田', 'カイヅチョウオワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県海津市海津町駒ケ江', '21', '21221', '5030613', '岐阜県', 'ギフケン', '海津市', 'カイヅシ', '海津町駒ケ江', 'カイヅチョウコマガエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県海津市海津町長瀬', '21', '21221', '5030614', '岐阜県', 'ギフケン', '海津市', 'カイヅシ', '海津町長瀬', 'カイヅチョウナガセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県海津市海津町日原', '21', '21221', '5030615', '岐阜県', 'ギフケン', '海津市', 'カイヅシ', '海津町日原', 'カイヅチョウヒワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県海津市海津町長久保', '21', '21221', '5030616', '岐阜県', 'ギフケン', '海津市', 'カイヅシ', '海津町長久保', 'カイヅチョウナガクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県海津市海津町立野', '21', '21221', '5030617', '岐阜県', 'ギフケン', '海津市', 'カイヅシ', '海津町立野', 'カイヅチョウタテノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県海津市海津町草場', '21', '21221', '5030618', '岐阜県', 'ギフケン', '海津市', 'カイヅシ', '海津町草場', 'カイヅチョウクサバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県海津市海津町外浜', '21', '21221', '5030621', '岐阜県', 'ギフケン', '海津市', 'カイヅシ', '海津町外浜', 'カイヅチョウソトハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県海津市海津町森下', '21', '21221', '5030622', '岐阜県', 'ギフケン', '海津市', 'カイヅシ', '海津町森下', 'カイヅチョウモリシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県海津市海津町古中島', '21', '21221', '5030623', '岐阜県', 'ギフケン', '海津市', 'カイヅシ', '海津町古中島', 'カイヅチョウフルナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県海津市海津町金廻', '21', '21221', '5030624', '岐阜県', 'ギフケン', '海津市', 'カイヅシ', '海津町金廻', 'カイヅチョウカナマワリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県海津市海津町油島', '21', '21221', '5030625', '岐阜県', 'ギフケン', '海津市', 'カイヅシ', '海津町油島', 'カイヅチョウアブラジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県海津市海津町万寿新田', '21', '21221', '5030626', '岐阜県', 'ギフケン', '海津市', 'カイヅシ', '海津町万寿新田', 'カイヅチョウマンジュシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県海津市海津町七右衛門新田', '21', '21221', '5030627', '岐阜県', 'ギフケン', '海津市', 'カイヅシ', '海津町七右衛門新田', 'カイヅチョウシチウエモンシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県海津市海津町福江', '21', '21221', '5030628', '岐阜県', 'ギフケン', '海津市', 'カイヅシ', '海津町福江', 'カイヅチョウフクエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県海津市海津町石亀', '21', '21221', '5030629', '岐阜県', 'ギフケン', '海津市', 'カイヅシ', '海津町石亀', 'カイヅチョウイシガメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県海津市海津町稲山', '21', '21221', '5030631', '岐阜県', 'ギフケン', '海津市', 'カイヅシ', '海津町稲山', 'カイヅチョウイナヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県海津市海津町宮地', '21', '21221', '5030632', '岐阜県', 'ギフケン', '海津市', 'カイヅシ', '海津町宮地', 'カイヅチョウミヤジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県海津市海津町本阿弥新田', '21', '21221', '5030633', '岐阜県', 'ギフケン', '海津市', 'カイヅシ', '海津町本阿弥新田', 'カイヅチョウホンナミシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県海津市海津町沼新田', '21', '21221', '5030634', '岐阜県', 'ギフケン', '海津市', 'カイヅシ', '海津町沼新田', 'カイヅチョウヌマシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県海津市海津町江東', '21', '21221', '5030635', '岐阜県', 'ギフケン', '海津市', 'カイヅシ', '海津町江東', 'カイヅチョウエヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県海津市海津町帆引新田', '21', '21221', '5030636', '岐阜県', 'ギフケン', '海津市', 'カイヅシ', '海津町帆引新田', 'カイヅチョウホビキシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県海津市海津町安田', '21', '21221', '5030637', '岐阜県', 'ギフケン', '海津市', 'カイヅシ', '海津町安田', 'カイヅチョウヤスダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県海津市海津町安田新田', '21', '21221', '5030638', '岐阜県', 'ギフケン', '海津市', 'カイヅシ', '海津町安田新田', 'カイヅチョウヤスダシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県海津市海津町内記', '21', '21221', '5030641', '岐阜県', 'ギフケン', '海津市', 'カイヅシ', '海津町内記', 'カイヅチョウナイキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県海津市海津町札野', '21', '21221', '5030643', '岐阜県', 'ギフケン', '海津市', 'カイヅシ', '海津町札野', 'カイヅチョウフダノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県海津市海津町深浜', '21', '21221', '5030644', '岐阜県', 'ギフケン', '海津市', 'カイヅシ', '海津町深浜', 'カイヅチョウフカハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県海津市海津町五町', '21', '21221', '5030645', '岐阜県', 'ギフケン', '海津市', 'カイヅシ', '海津町五町', 'カイヅチョウゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県海津市海津町萱野', '21', '21221', '5030646', '岐阜県', 'ギフケン', '海津市', 'カイヅシ', '海津町萱野', 'カイヅチョウカヤノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県海津市海津町東小島', '21', '21221', '5030647', '岐阜県', 'ギフケン', '海津市', 'カイヅシ', '海津町東小島', 'カイヅチョウヒガシオジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県海津市海津町西小島', '21', '21221', '5030648', '岐阜県', 'ギフケン', '海津市', 'カイヅシ', '海津町西小島', 'カイヅチョウニシオジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県海津市海津町平原', '21', '21221', '5030651', '岐阜県', 'ギフケン', '海津市', 'カイヅシ', '海津町平原', 'カイヅチョウヒラハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県海津市海津町馬目', '21', '21221', '5030652', '岐阜県', 'ギフケン', '海津市', 'カイヅシ', '海津町馬目', 'カイヅチョウマノメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県海津市海津町高須町', '21', '21221', '5030653', '岐阜県', 'ギフケン', '海津市', 'カイヅシ', '海津町高須町', 'カイヅチョウタカスマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県海津市海津町高須', '21', '21221', '5030654', '岐阜県', 'ギフケン', '海津市', 'カイヅシ', '海津町高須', 'カイヅチョウタカス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県海津市海津町福岡', '21', '21221', '5030655', '岐阜県', 'ギフケン', '海津市', 'カイヅシ', '海津町福岡', 'カイヅチョウフクオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市和合新町', '21', '21202', '5030801', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '和合新町', 'ワゴウシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市東町', '21', '21202', '5030802', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '東町', 'アズマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市小野', '21', '21202', '5030803', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '小野', 'コノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市中ノ江', '21', '21202', '5030804', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '中ノ江', 'ナカノエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市鶴見町', '21', '21202', '5030805', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '鶴見町', 'ツルミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市緑園', '21', '21202', '5030806', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '緑園', 'ミドリエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市今宿', '21', '21202', '5030807', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '今宿', 'イマジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市三塚町', '21', '21202', '5030808', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '三塚町', 'ミツヅカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市波須', '21', '21202', '5030811', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '波須', 'ハス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市万石', '21', '21202', '5030812', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '万石', 'マンゴク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市三本木', '21', '21202', '5030813', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '三本木', 'サンボンギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市大村', '21', '21202', '5030814', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '大村', 'オオムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市直江町', '21', '21202', '5030815', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '直江町', 'スグエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市小泉町', '21', '21202', '5030816', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '小泉町', 'コイズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市上面', '21', '21202', '5030817', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '上面', 'ジョウメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市早苗町', '21', '21202', '5030821', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '早苗町', 'サナエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市住吉町', '21', '21202', '5030822', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '住吉町', 'スミヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市鹿島町', '21', '21202', '5030823', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '鹿島町', 'カシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市旭町', '21', '21202', '5030824', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '旭町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市花園町', '21', '21202', '5030825', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '花園町', 'ハナゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市恵比寿町北', '21', '21202', '5030826', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '恵比寿町北', 'エビスチョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市恵比寿町南', '21', '21202', '5030827', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '恵比寿町南', 'エビスチョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市恵比寿町', '21', '21202', '5030828', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '恵比寿町', 'エビスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市新長沢町', '21', '21202', '5030831', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '新長沢町', 'シンナガサワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市寿町', '21', '21202', '5030832', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '寿町', 'コトブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市長沢町', '21', '21202', '5030833', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '長沢町', 'ナガサワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市犬ケ渕町', '21', '21202', '5030834', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '犬ケ渕町', 'イヌガブチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市東前', '21', '21202', '5030835', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '東前', 'ヒガシマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市大井', '21', '21202', '5030836', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '大井', 'オオイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市安井町', '21', '21202', '5030837', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '安井町', 'ヤスイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市江崎町', '21', '21202', '5030838', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '江崎町', 'エザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市長井町', '21', '21202', '5030839', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '長井町', 'ナガイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市平町', '21', '21202', '5030841', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '平町', 'ヒラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市馬の瀬町', '21', '21202', '5030842', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '馬の瀬町', 'ウマノセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市今福町', '21', '21202', '5030843', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '今福町', 'イマフクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市難波野町', '21', '21202', '5030844', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '難波野町', 'ナンバノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市牧新田町', '21', '21202', '5030845', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '牧新田町', 'マキシンデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市深池町', '21', '21202', '5030846', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '深池町', 'フカイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市米野町', '21', '21202', '5030847', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '米野町', 'コメノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市古宮町', '21', '21202', '5030848', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '古宮町', 'フルミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市東前町', '21', '21202', '5030849', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '東前町', 'ヒガシマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市禾森', '21', '21202', '5030851', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '禾森', 'ノギノモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市禾森町', '21', '21202', '5030852', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '禾森町', 'ノギノモリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市田口町', '21', '21202', '5030853', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '田口町', 'タグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市築捨町', '21', '21202', '5030854', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '築捨町', 'ツキズテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市問屋町', '21', '21202', '5030855', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '問屋町', 'トイヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市新田町', '21', '21202', '5030856', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '新田町', 'シンデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市美和町', '21', '21202', '5030857', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '美和町', 'ミワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市世安町', '21', '21202', '5030858', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '世安町', 'ヨヤスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市羽衣町', '21', '21202', '5030861', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '羽衣町', 'ハゴロモチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市二葉町', '21', '21202', '5030862', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '二葉町', 'フタバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市大池町', '21', '21202', '5030863', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '大池町', 'オオイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市南頬町', '21', '21202', '5030864', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '南頬町', 'ミナミノカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市寺内町', '21', '21202', '5030865', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '寺内町', 'ジナイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市魚屋町', '21', '21202', '5030871', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '魚屋町', 'ウオヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市新町', '21', '21202', '5030872', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市南高橋町', '21', '21202', '5030873', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '南高橋町', 'ミナミタカハシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市今岡町', '21', '21202', '5030874', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '今岡町', 'イマオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市田町', '21', '21202', '5030875', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '田町', 'タマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市俵町', '21', '21202', '5030876', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '俵町', 'タワラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市御殿町', '21', '21202', '5030877', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '御殿町', 'ゴテンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市竹島町', '21', '21202', '5030878', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '竹島町', 'タケジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市岐阜町', '21', '21202', '5030881', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '岐阜町', 'ギフマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市東長町', '21', '21202', '5030882', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '東長町', 'ヒガシナガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市清水町', '21', '21202', '5030883', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '清水町', 'シミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市中町', '21', '21202', '5030884', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '中町', 'ナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市本町', '21', '21202', '5030885', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市郭町東', '21', '21202', '5030886', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '郭町東', 'クルワマチヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市郭町', '21', '21202', '5030887', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '郭町', 'クルワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市丸の内', '21', '21202', '5030888', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '丸の内', 'マルノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市高砂町', '21', '21202', '5030889', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '高砂町', 'タカサゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市千鳥町', '21', '21202', '5030891', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '千鳥町', 'チドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市橘町', '21', '21202', '5030892', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '橘町', 'タチバナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市藤江町', '21', '21202', '5030893', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '藤江町', 'フジエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市新地町', '21', '21202', '5030894', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '新地町', 'シンチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市代官町', '21', '21202', '5030895', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '代官町', 'ダイカンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市高橋町', '21', '21202', '5030896', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '高橋町', 'タカハシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市伝馬町', '21', '21202', '5030897', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '伝馬町', 'テンマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市歩行町', '21', '21202', '5030898', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '歩行町', 'オカチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市錦町', '21', '21202', '5030899', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '錦町', 'ニシキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市高屋町', '21', '21202', '5030901', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '高屋町', 'タカヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市栗屋町', '21', '21202', '5030902', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '栗屋町', 'クリヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市東外側町', '21', '21202', '5030903', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '東外側町', 'ヒガシトガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市桐ケ崎町', '21', '21202', '5030904', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '桐ケ崎町', 'キリガサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市宮町', '21', '21202', '5030905', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '宮町', 'ミヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市室町', '21', '21202', '5030906', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '室町', 'ムロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市番組町', '21', '21202', '5030907', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '番組町', 'バングミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市西外側町', '21', '21202', '5030908', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '西外側町', 'ニシトガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市室本町', '21', '21202', '5030911', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '室本町', 'ムロホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市鳩部屋町', '21', '21202', '5030912', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '鳩部屋町', 'ハトベヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市鷹匠町', '21', '21202', '5030913', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '鷹匠町', 'タカジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市西長町', '21', '21202', '5030914', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '西長町', 'ニシナガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市北切石町', '21', '21202', '5030915', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '北切石町', 'キタキリイシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市日の出町', '21', '21202', '5030916', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '日の出町', 'ヒノデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市神田町', '21', '21202', '5030917', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '神田町', 'カンダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市西崎町', '21', '21202', '5030918', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '西崎町', 'ニシザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市新馬場町', '21', '21202', '5030921', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '新馬場町', 'シンババチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市馬場町', '21', '21202', '5030922', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '馬場町', 'ババチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市船町', '21', '21202', '5030923', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '船町', 'フナマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市今町', '21', '21202', '5030924', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '今町', 'イママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市南切石町', '21', '21202', '5030925', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '南切石町', 'ミナミキリイシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市切石町', '21', '21202', '5030926', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '切石町', 'キリイシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市本今', '21', '21202', '5030931', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '本今', 'モトイマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市本今町', '21', '21202', '5030932', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '本今町', 'モトイマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市外野', '21', '21202', '5030933', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '外野', 'ソトノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市外渕', '21', '21202', '5030934', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '外渕', 'ソブツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市島里', '21', '21202', '5030935', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '島里', 'シマザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市内原', '21', '21202', '5030936', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '内原', 'ウチワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市釜笛', '21', '21202', '5030937', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '釜笛', 'カマフエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市川口', '21', '21202', '5030941', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '川口', 'カワグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市昭和', '21', '21202', '5030942', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '昭和', 'ショウワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市横曽根町', '21', '21202', '5030943', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '横曽根町', 'ヨコゾネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市横曽根', '21', '21202', '5030944', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '横曽根', 'ヨコゾネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市浅西', '21', '21202', '5030945', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '浅西', 'アサニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市浅中', '21', '21202', '5030946', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '浅中', 'アサナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市浅草', '21', '21202', '5030947', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '浅草', 'アサクサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市外野町', '21', '21202', '5030951', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '外野町', 'ソトノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市割田町', '21', '21202', '5030952', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '割田町', 'ワリデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市割田', '21', '21202', '5030953', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '割田', 'ワリデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市外花', '21', '21202', '5030954', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '外花', 'トバナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市友江', '21', '21202', '5030955', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '友江', 'トモエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市大外羽', '21', '21202', '5030956', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '大外羽', 'オオトバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市上屋', '21', '21202', '5030957', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '上屋', 'カミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市高渕', '21', '21202', '5030958', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '高渕', 'タカブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市高渕町', '21', '21202', '5030959', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '高渕町', 'タカブチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市青柳町', '21', '21202', '5030961', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '青柳町', 'アオヤナギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市入方', '21', '21202', '5030962', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '入方', 'イリカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市西大外羽', '21', '21202', '5030963', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '西大外羽', 'ニシオオトバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市上笠', '21', '21202', '5030964', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '上笠', 'カミガサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市多芸島', '21', '21202', '5030965', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '多芸島', 'タギシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市南一色町', '21', '21202', '5030971', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '南一色町', 'ミナミイッシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市宝和町', '21', '21202', '5030972', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '宝和町', 'ホウワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市木戸町', '21', '21202', '5030973', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '木戸町', 'キドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市久瀬川町', '21', '21202', '5030974', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '久瀬川町', 'クゼガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市若森町', '21', '21202', '5030975', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '若森町', 'ワカモリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市南若森町', '21', '21202', '5030976', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '南若森町', 'ミナミワカモリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市南若森', '21', '21202', '5030977', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '南若森', 'ミナミワカモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市桧町', '21', '21202', '5030981', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '桧町', 'ヒノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市久徳町', '21', '21202', '5030982', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '久徳町', 'キュウトクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市静里町', '21', '21202', '5030983', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '静里町', 'シズサトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市綾野', '21', '21202', '5030984', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '綾野', 'アヤノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市野口', '21', '21202', '5030985', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '野口', 'ノグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市中曽根町', '21', '21202', '5030986', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '中曽根町', 'ナカゾネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市木呂町', '21', '21202', '5030991', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '木呂町', 'キロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市新長松', '21', '21202', '5030992', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '新長松', 'シンナガマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市荒川町', '21', '21202', '5030993', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '荒川町', 'アラカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市綾野町', '21', '21202', '5030994', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '綾野町', 'アヤノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市十六町', '21', '21202', '5030995', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '十六町', 'ジュウロクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市島町', '21', '21202', '5030996', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '島町', 'シマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市長松町', '21', '21202', '5030997', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '長松町', 'ナガマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県養老郡養老町沢田', '21', '21341', '5031241', '岐阜県', 'ギフケン', '養老郡養老町', 'ヨウロウグンヨウロウチョウ', '沢田', 'サワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県養老郡養老町桜井', '21', '21341', '5031242', '岐阜県', 'ギフケン', '養老郡養老町', 'ヨウロウグンヨウロウチョウ', '桜井', 'サクライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県養老郡養老町五日市', '21', '21341', '5031243', '岐阜県', 'ギフケン', '養老郡養老町', 'ヨウロウグンヨウロウチョウ', '五日市', 'イツカイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県養老郡養老町竜泉寺', '21', '21341', '5031244', '岐阜県', 'ギフケン', '養老郡養老町', 'ヨウロウグンヨウロウチョウ', '竜泉寺', 'リュウセンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県養老郡養老町上方', '21', '21341', '5031245', '岐阜県', 'ギフケン', '養老郡養老町', 'ヨウロウグンヨウロウチョウ', '上方', 'ウワガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県養老郡養老町石畑', '21', '21341', '5031251', '岐阜県', 'ギフケン', '養老郡養老町', 'ヨウロウグンヨウロウチョウ', '石畑', 'イシバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県養老郡養老町明徳', '21', '21341', '5031252', '岐阜県', 'ギフケン', '養老郡養老町', 'ヨウロウグンヨウロウチョウ', '明徳', 'ミョウトク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県養老郡養老町柏尾', '21', '21341', '5031253', '岐阜県', 'ギフケン', '養老郡養老町', 'ヨウロウグンヨウロウチョウ', '柏尾', 'カシワオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県養老郡養老町養老公園', '21', '21341', '5031254', '岐阜県', 'ギフケン', '養老郡養老町', 'ヨウロウグンヨウロウチョウ', '養老公園', 'ヨウロウコウエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県養老郡養老町養老', '21', '21341', '5031255', '岐阜県', 'ギフケン', '養老郡養老町', 'ヨウロウグンヨウロウチョウ', '養老', 'ヨウロウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県養老郡養老町勢至', '21', '21341', '5031256', '岐阜県', 'ギフケン', '養老郡養老町', 'ヨウロウグンヨウロウチョウ', '勢至', 'セイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県養老郡養老町鷲巣', '21', '21341', '5031261', '岐阜県', 'ギフケン', '養老郡養老町', 'ヨウロウグンヨウロウチョウ', '鷲巣', 'ワシノス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県養老郡養老町小倉', '21', '21341', '5031262', '岐阜県', 'ギフケン', '養老郡養老町', 'ヨウロウグンヨウロウチョウ', '小倉', 'オグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県養老郡養老町船見', '21', '21341', '5031263', '岐阜県', 'ギフケン', '養老郡養老町', 'ヨウロウグンヨウロウチョウ', '船見', 'フナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県養老郡養老町一色', '21', '21341', '5031264', '岐阜県', 'ギフケン', '養老郡養老町', 'ヨウロウグンヨウロウチョウ', '一色', 'イッシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県養老郡養老町若宮', '21', '21341', '5031265', '岐阜県', 'ギフケン', '養老郡養老町', 'ヨウロウグンヨウロウチョウ', '若宮', 'ワカミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県養老郡養老町京ケ脇', '21', '21341', '5031266', '岐阜県', 'ギフケン', '養老郡養老町', 'ヨウロウグンヨウロウチョウ', '京ケ脇', 'キョウガワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県養老郡養老町高林', '21', '21341', '5031267', '岐阜県', 'ギフケン', '養老郡養老町', 'ヨウロウグンヨウロウチョウ', '高林', 'タカバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県養老郡養老町西小倉', '21', '21341', '5031268', '岐阜県', 'ギフケン', '養老郡養老町', 'ヨウロウグンヨウロウチョウ', '西小倉', 'ニシオグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県養老郡養老町田', '21', '21341', '5031271', '岐阜県', 'ギフケン', '養老郡養老町', 'ヨウロウグンヨウロウチョウ', '田', 'タ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県養老郡養老町大場', '21', '21341', '5031272', '岐阜県', 'ギフケン', '養老郡養老町', 'ヨウロウグンヨウロウチョウ', '大場', 'オオバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県養老郡養老町根古地', '21', '21341', '5031273', '岐阜県', 'ギフケン', '養老郡養老町', 'ヨウロウグンヨウロウチョウ', '根古地', 'ネコジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県養老郡養老町瑞穂', '21', '21341', '5031274', '岐阜県', 'ギフケン', '養老郡養老町', 'ヨウロウグンヨウロウチョウ', '瑞穂', 'ミズホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県養老郡養老町大巻', '21', '21341', '5031275', '岐阜県', 'ギフケン', '養老郡養老町', 'ヨウロウグンヨウロウチョウ', '大巻', 'オオマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県養老郡養老町釜段', '21', '21341', '5031276', '岐阜県', 'ギフケン', '養老郡養老町', 'ヨウロウグンヨウロウチョウ', '釜段', 'カマダン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県養老郡養老町有尾', '21', '21341', '5031277', '岐阜県', 'ギフケン', '養老郡養老町', 'ヨウロウグンヨウロウチョウ', '有尾', 'アリオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('52999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県養老郡養老町横屋', '21', '21341', '5031278', '岐阜県', 'ギフケン', '養老郡養老町', 'ヨウロウグンヨウロウチョウ', '横屋', 'ヨコヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県養老郡養老町', '21', '21341', '5031300', '岐阜県', 'ギフケン', '養老郡養老町', 'ヨウロウグンヨウロウチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('53001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県養老郡養老町室原', '21', '21341', '5031301', '岐阜県', 'ギフケン', '養老郡養老町', 'ヨウロウグンヨウロウチョウ', '室原', 'ムロハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県養老郡養老町大坪', '21', '21341', '5031302', '岐阜県', 'ギフケン', '養老郡養老町', 'ヨウロウグンヨウロウチョウ', '大坪', 'オオツボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県養老郡養老町蛇持', '21', '21341', '5031303', '岐阜県', 'ギフケン', '養老郡養老町', 'ヨウロウグンヨウロウチョウ', '蛇持', 'ジャモチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県養老郡養老町飯田', '21', '21341', '5031304', '岐阜県', 'ギフケン', '養老郡養老町', 'ヨウロウグンヨウロウチョウ', '飯田', 'イイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県養老郡養老町祖父江', '21', '21341', '5031305', '岐阜県', 'ギフケン', '養老郡養老町', 'ヨウロウグンヨウロウチョウ', '祖父江', 'ソブエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県養老郡養老町江月', '21', '21341', '5031306', '岐阜県', 'ギフケン', '養老郡養老町', 'ヨウロウグンヨウロウチョウ', '江月', 'エツキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県養老郡養老町泉町', '21', '21341', '5031311', '岐阜県', 'ギフケン', '養老郡養老町', 'ヨウロウグンヨウロウチョウ', '泉町', 'イズミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県養老郡養老町三神町', '21', '21341', '5031312', '岐阜県', 'ギフケン', '養老郡養老町', 'ヨウロウグンヨウロウチョウ', '三神町', 'ミカミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県養老郡養老町高田馬場町', '21', '21341', '5031313', '岐阜県', 'ギフケン', '養老郡養老町', 'ヨウロウグンヨウロウチョウ', '高田馬場町', 'タカダババチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県養老郡養老町高田', '21', '21341', '5031314', '岐阜県', 'ギフケン', '養老郡養老町', 'ヨウロウグンヨウロウチョウ', '高田', 'タカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県養老郡養老町烏江', '21', '21341', '5031315', '岐阜県', 'ギフケン', '養老郡養老町', 'ヨウロウグンヨウロウチョウ', '烏江', 'カラスエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県養老郡養老町押越', '21', '21341', '5031316', '岐阜県', 'ギフケン', '養老郡養老町', 'ヨウロウグンヨウロウチョウ', '押越', 'オシコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県養老郡養老町滝見町', '21', '21341', '5031317', '岐阜県', 'ギフケン', '養老郡養老町', 'ヨウロウグンヨウロウチョウ', '滝見町', 'タキミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県養老郡養老町岩道', '21', '21341', '5031321', '岐阜県', 'ギフケン', '養老郡養老町', 'ヨウロウグンヨウロウチョウ', '岩道', 'イワミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県養老郡養老町西岩道', '21', '21341', '5031322', '岐阜県', 'ギフケン', '養老郡養老町', 'ヨウロウグンヨウロウチョウ', '西岩道', 'ニシイワミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県養老郡養老町口ケ島', '21', '21341', '5031323', '岐阜県', 'ギフケン', '養老郡養老町', 'ヨウロウグンヨウロウチョウ', '口ケ島', 'クチガシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県養老郡養老町大跡', '21', '21341', '5031324', '岐阜県', 'ギフケン', '養老郡養老町', 'ヨウロウグンヨウロウチョウ', '大跡', 'オオアト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県養老郡養老町飯ノ木', '21', '21341', '5031325', '岐阜県', 'ギフケン', '養老郡養老町', 'ヨウロウグンヨウロウチョウ', '飯ノ木', 'ハンノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県養老郡養老町橋爪', '21', '21341', '5031331', '岐阜県', 'ギフケン', '養老郡養老町', 'ヨウロウグンヨウロウチョウ', '橋爪', 'ハシヅメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県養老郡養老町中', '21', '21341', '5031332', '岐阜県', 'ギフケン', '養老郡養老町', 'ヨウロウグンヨウロウチョウ', '中', 'ナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県養老郡養老町色目', '21', '21341', '5031333', '岐阜県', 'ギフケン', '養老郡養老町', 'ヨウロウグンヨウロウチョウ', '色目', 'イロメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県養老郡養老町豊', '21', '21341', '5031334', '岐阜県', 'ギフケン', '養老郡養老町', 'ヨウロウグンヨウロウチョウ', '豊', 'トヨ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県養老郡養老町宇田', '21', '21341', '5031335', '岐阜県', 'ギフケン', '養老郡養老町', 'ヨウロウグンヨウロウチョウ', '宇田', 'ウタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県養老郡養老町飯積', '21', '21341', '5031336', '岐阜県', 'ギフケン', '養老郡養老町', 'ヨウロウグンヨウロウチョウ', '飯積', 'イイヅミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県養老郡養老町直江', '21', '21341', '5031337', '岐阜県', 'ギフケン', '養老郡養老町', 'ヨウロウグンヨウロウチョウ', '直江', 'ナオエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県養老郡養老町安久', '21', '21341', '5031338', '岐阜県', 'ギフケン', '養老郡養老町', 'ヨウロウグンヨウロウチョウ', '安久', 'ヤスヒサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県養老郡養老町金屋', '21', '21341', '5031339', '岐阜県', 'ギフケン', '養老郡養老町', 'ヨウロウグンヨウロウチョウ', '金屋', 'カナヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県養老郡養老町栗笠', '21', '21341', '5031381', '岐阜県', 'ギフケン', '養老郡養老町', 'ヨウロウグンヨウロウチョウ', '栗笠', 'クリガサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県養老郡養老町船附', '21', '21341', '5031382', '岐阜県', 'ギフケン', '養老郡養老町', 'ヨウロウグンヨウロウチョウ', '船附', 'フナツケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県養老郡養老町大野', '21', '21341', '5031383', '岐阜県', 'ギフケン', '養老郡養老町', 'ヨウロウグンヨウロウチョウ', '大野', 'オオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県養老郡養老町下笠', '21', '21341', '5031384', '岐阜県', 'ギフケン', '養老郡養老町', 'ヨウロウグンヨウロウチョウ', '下笠', 'シモガサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県養老郡養老町上之郷', '21', '21341', '5031385', '岐阜県', 'ギフケン', '養老郡養老町', 'ヨウロウグンヨウロウチョウ', '上之郷', 'カミノゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県不破郡関ケ原町', '21', '21362', '5031500', '岐阜県', 'ギフケン', '不破郡関ケ原町', 'フワグンセキガハラチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('53039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県不破郡関ケ原町関ケ原', '21', '21362', '5031501', '岐阜県', 'ギフケン', '不破郡関ケ原町', 'フワグンセキガハラチョウ', '関ケ原', 'セキガハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県不破郡関ケ原町東町', '21', '21362', '5031511', '岐阜県', 'ギフケン', '不破郡関ケ原町', 'フワグンセキガハラチョウ', '東町', 'ヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県不破郡関ケ原町公門', '21', '21362', '5031512', '岐阜県', 'ギフケン', '不破郡関ケ原町', 'フワグンセキガハラチョウ', '公門', 'クモン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県不破郡関ケ原町中山', '21', '21362', '5031513', '岐阜県', 'ギフケン', '不破郡関ケ原町', 'フワグンセキガハラチョウ', '中山', 'ナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県不破郡関ケ原町稲荷', '21', '21362', '5031514', '岐阜県', 'ギフケン', '不破郡関ケ原町', 'フワグンセキガハラチョウ', '稲荷', 'イナリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県不破郡関ケ原町西町', '21', '21362', '5031514', '岐阜県', 'ギフケン', '不破郡関ケ原町', 'フワグンセキガハラチョウ', '西町', 'ニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県不破郡関ケ原町中町', '21', '21362', '5031515', '岐阜県', 'ギフケン', '不破郡関ケ原町', 'フワグンセキガハラチョウ', '中町', 'ナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県不破郡関ケ原町宝有', '21', '21362', '5031521', '岐阜県', 'ギフケン', '不破郡関ケ原町', 'フワグンセキガハラチョウ', '宝有', 'ホウユウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県不破郡関ケ原町陣場野', '21', '21362', '5031522', '岐阜県', 'ギフケン', '不破郡関ケ原町', 'フワグンセキガハラチョウ', '陣場野', 'ジンバノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県不破郡関ケ原町小池', '21', '21362', '5031523', '岐阜県', 'ギフケン', '不破郡関ケ原町', 'フワグンセキガハラチョウ', '小池', 'コイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県不破郡関ケ原町小関', '21', '21362', '5031523', '岐阜県', 'ギフケン', '不破郡関ケ原町', 'フワグンセキガハラチョウ', '小関', 'コゼキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県不破郡関ケ原町御祭田', '21', '21362', '5031524', '岐阜県', 'ギフケン', '不破郡関ケ原町', 'フワグンセキガハラチョウ', '御祭田', 'ゴサイデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県不破郡関ケ原町笹尾', '21', '21362', '5031524', '岐阜県', 'ギフケン', '不破郡関ケ原町', 'フワグンセキガハラチョウ', '笹尾', 'ササオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県不破郡関ケ原町緑ケ丘', '21', '21362', '5031524', '岐阜県', 'ギフケン', '不破郡関ケ原町', 'フワグンセキガハラチョウ', '緑ケ丘', 'ミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県不破郡関ケ原町大高', '21', '21362', '5031531', '岐阜県', 'ギフケン', '不破郡関ケ原町', 'フワグンセキガハラチョウ', '大高', 'オダカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県不破郡関ケ原町野上', '21', '21362', '5031532', '岐阜県', 'ギフケン', '不破郡関ケ原町', 'フワグンセキガハラチョウ', '野上', 'ノガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県不破郡関ケ原町松尾', '21', '21362', '5031541', '岐阜県', 'ギフケン', '不破郡関ケ原町', 'フワグンセキガハラチョウ', '松尾', 'マツオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県不破郡関ケ原町藤下', '21', '21362', '5031542', '岐阜県', 'ギフケン', '不破郡関ケ原町', 'フワグンセキガハラチョウ', '藤下', 'トウゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県不破郡関ケ原町今須', '21', '21362', '5031543', '岐阜県', 'ギフケン', '不破郡関ケ原町', 'フワグンセキガハラチョウ', '今須', 'イマス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県不破郡関ケ原町山中', '21', '21362', '5031544', '岐阜県', 'ギフケン', '不破郡関ケ原町', 'フワグンセキガハラチョウ', '山中', 'ヤマナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県不破郡関ケ原町玉', '21', '21362', '5031545', '岐阜県', 'ギフケン', '不破郡関ケ原町', 'フワグンセキガハラチョウ', '玉', 'タマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市上石津町乙坂', '21', '21202', '5031601', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '上石津町乙坂', 'カミイシヅチョウオツサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市上石津町牧田', '21', '21202', '5031602', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '上石津町牧田', 'カミイシヅチョウマキダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市上石津町奥', '21', '21202', '5031611', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '上石津町奥', 'カミイシヅチョウオク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市上石津町谷畑', '21', '21202', '5031612', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '上石津町谷畑', 'カミイシヅチョウタニハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市上石津町上鍛治屋', '21', '21202', '5031613', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '上石津町上鍛治屋', 'カミイシヅチョウカミカジヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市上石津町一之瀬', '21', '21202', '5031614', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '上石津町一之瀬', 'カミイシヅチョウイチノセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市上石津町下多良', '21', '21202', '5031621', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '上石津町下多良', 'カミイシヅチョウシモタラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市上石津町上原', '21', '21202', '5031622', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '上石津町上原', 'カミイシヅチョウウワハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市上石津町上多良', '21', '21202', '5031623', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '上石津町上多良', 'カミイシヅチョウカミタラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市上石津町三ツ里', '21', '21202', '5031624', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '上石津町三ツ里', 'カミイシヅチョウミツサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市上石津町宮', '21', '21202', '5031625', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '上石津町宮', 'カミイシヅチョウミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市上石津町祢宜上', '21', '21202', '5031626', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '上石津町祢宜上', 'カミイシヅチョウネギカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市上石津町前ケ瀬', '21', '21202', '5031631', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '上石津町前ケ瀬', 'カミイシヅチョウマエガセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市上石津町下山', '21', '21202', '5031632', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '上石津町下山', 'カミイシヅチョウシモヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市上石津町打上', '21', '21202', '5031633', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '上石津町打上', 'カミイシヅチョウウチアゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市上石津町細野', '21', '21202', '5031634', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '上石津町細野', 'カミイシヅチョウホソノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市上石津町時山', '21', '21202', '5031635', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '上石津町時山', 'カミイシヅチョウトキヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市上石津町西山', '21', '21202', '5031636', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '上石津町西山', 'カミイシヅチョウニシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市上石津町堂之上', '21', '21202', '5031637', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '上石津町堂之上', 'カミイシヅチョウドウノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市上石津町上', '21', '21202', '5031638', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '上石津町上', 'カミイシヅチョウカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県不破郡垂井町', '21', '21361', '5032100', '岐阜県', 'ギフケン', '不破郡垂井町', 'フワグンタルイチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('53084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県不破郡垂井町大滝', '21', '21361', '5032101', '岐阜県', 'ギフケン', '不破郡垂井町', 'フワグンタルイチョウ', '大滝', 'オオタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県不破郡垂井町敷原', '21', '21361', '5032102', '岐阜県', 'ギフケン', '不破郡垂井町', 'フワグンタルイチョウ', '敷原', 'シキハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県不破郡垂井町梅谷', '21', '21361', '5032103', '岐阜県', 'ギフケン', '不破郡垂井町', 'フワグンタルイチョウ', '梅谷', 'ウメタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県不破郡垂井町市之尾', '21', '21361', '5032104', '岐阜県', 'ギフケン', '不破郡垂井町', 'フワグンタルイチョウ', '市之尾', 'イチノオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県不破郡垂井町新井', '21', '21361', '5032105', '岐阜県', 'ギフケン', '不破郡垂井町', 'フワグンタルイチョウ', '新井', 'アライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県不破郡垂井町伊吹', '21', '21361', '5032106', '岐阜県', 'ギフケン', '不破郡垂井町', 'フワグンタルイチョウ', '伊吹', 'イブキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県不破郡垂井町岩手', '21', '21361', '5032107', '岐阜県', 'ギフケン', '不破郡垂井町', 'フワグンタルイチョウ', '岩手', 'イワデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県不破郡垂井町大石', '21', '21361', '5032108', '岐阜県', 'ギフケン', '不破郡垂井町', 'フワグンタルイチョウ', '大石', 'オオイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県不破郡垂井町南新井', '21', '21361', '5032109', '岐阜県', 'ギフケン', '不破郡垂井町', 'フワグンタルイチョウ', '南新井', 'ミナミアライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県不破郡垂井町平尾', '21', '21361', '5032111', '岐阜県', 'ギフケン', '不破郡垂井町', 'フワグンタルイチョウ', '平尾', 'ヒラオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県不破郡垂井町綾戸', '21', '21361', '5032112', '岐阜県', 'ギフケン', '不破郡垂井町', 'フワグンタルイチョウ', '綾戸', 'アヤド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県不破郡垂井町清水', '21', '21361', '5032113', '岐阜県', 'ギフケン', '不破郡垂井町', 'フワグンタルイチョウ', '清水', 'シミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県不破郡垂井町府中', '21', '21361', '5032114', '岐阜県', 'ギフケン', '不破郡垂井町', 'フワグンタルイチョウ', '府中', 'フチュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県不破郡垂井町', '21', '21361', '5032121', '岐阜県', 'ギフケン', '不破郡垂井町', 'フワグンタルイチョウ', null, '　', '（直番地）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('53098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県不破郡垂井町表佐', '21', '21361', '5032122', '岐阜県', 'ギフケン', '不破郡垂井町', 'フワグンタルイチョウ', '表佐', 'オサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県不破郡垂井町栗原', '21', '21361', '5032123', '岐阜県', 'ギフケン', '不破郡垂井町', 'フワグンタルイチョウ', '栗原', 'クリハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県不破郡垂井町宮代', '21', '21361', '5032124', '岐阜県', 'ギフケン', '不破郡垂井町', 'フワグンタルイチョウ', '宮代', 'ミヤシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県不破郡垂井町東神田', '21', '21361', '5032125', '岐阜県', 'ギフケン', '不破郡垂井町', 'フワグンタルイチョウ', '東神田', 'ヒガシカンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市草道島町', '21', '21202', '5032201', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '草道島町', 'ソウドウジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市青木町', '21', '21202', '5032202', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '青木町', 'アオキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市興福地町', '21', '21202', '5032203', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '興福地町', 'コウフクジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市池尻町', '21', '21202', '5032204', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '池尻町', 'イケジリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市神明', '21', '21202', '5032205', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '神明', 'シンメイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市赤坂新町', '21', '21202', '5032206', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '赤坂新町', 'アカサカシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市枝郷', '21', '21202', '5032207', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '枝郷', 'エダゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市菅野', '21', '21202', '5032208', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '菅野', 'スガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市南市橋町', '21', '21202', '5032211', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '南市橋町', 'ミナミイチハシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市赤坂東町', '21', '21202', '5032212', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '赤坂東町', 'アカサカヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市赤坂町', '21', '21202', '5032213', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '赤坂町', 'アカサカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市赤坂新田', '21', '21202', '5032214', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '赤坂新田', 'アカサカシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市赤坂大門', '21', '21202', '5032215', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '赤坂大門', 'アカサカダイモン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市昼飯町', '21', '21202', '5032216', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '昼飯町', 'ヒルイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市青墓町', '21', '21202', '5032221', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '青墓町', 'アオハカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市榎戸町', '21', '21202', '5032222', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '榎戸町', 'ヨノキドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市矢道町', '21', '21202', '5032223', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '矢道町', 'ヤミチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市稲葉東', '21', '21202', '5032224', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '稲葉東', 'イナバヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市稲葉西', '21', '21202', '5032225', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '稲葉西', 'イナバニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市稲葉北', '21', '21202', '5032226', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '稲葉北', 'イナバキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県大垣市青野町', '21', '21202', '5032227', '岐阜県', 'ギフケン', '大垣市', 'オオガキシ', '青野町', 'アオノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県安八郡神戸町', '21', '21381', '5032300', '岐阜県', 'ギフケン', '安八郡神戸町', 'アンパチグンゴウドチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('53126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県安八郡神戸町横井', '21', '21381', '5032301', '岐阜県', 'ギフケン', '安八郡神戸町', 'アンパチグンゴウドチョウ', '横井', 'ヨコイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県安八郡神戸町田', '21', '21381', '5032302', '岐阜県', 'ギフケン', '安八郡神戸町', 'アンパチグンゴウドチョウ', '田', 'タ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県安八郡神戸町安次', '21', '21381', '5032303', '岐阜県', 'ギフケン', '安八郡神戸町', 'アンパチグンゴウドチョウ', '安次', 'ヤスツグ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県安八郡神戸町丈六道', '21', '21381', '5032304', '岐阜県', 'ギフケン', '安八郡神戸町', 'アンパチグンゴウドチョウ', '丈六道', 'ジョウロクドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県安八郡神戸町神戸', '21', '21381', '5032305', '岐阜県', 'ギフケン', '安八郡神戸町', 'アンパチグンゴウドチョウ', '神戸', 'ゴウド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県安八郡神戸町北一色', '21', '21381', '5032306', '岐阜県', 'ギフケン', '安八郡神戸町', 'アンパチグンゴウドチョウ', '北一色', 'キタイシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県安八郡神戸町川西', '21', '21381', '5032311', '岐阜県', 'ギフケン', '安八郡神戸町', 'アンパチグンゴウドチョウ', '川西', 'カワニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県安八郡神戸町下宮', '21', '21381', '5032312', '岐阜県', 'ギフケン', '安八郡神戸町', 'アンパチグンゴウドチョウ', '下宮', 'シモミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県安八郡神戸町新屋敷', '21', '21381', '5032313', '岐阜県', 'ギフケン', '安八郡神戸町', 'アンパチグンゴウドチョウ', '新屋敷', 'シンヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県安八郡神戸町落合', '21', '21381', '5032314', '岐阜県', 'ギフケン', '安八郡神戸町', 'アンパチグンゴウドチョウ', '落合', 'オチアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県安八郡神戸町付寄', '21', '21381', '5032315', '岐阜県', 'ギフケン', '安八郡神戸町', 'アンパチグンゴウドチョウ', '付寄', 'ツキヨリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県安八郡神戸町斉田', '21', '21381', '5032316', '岐阜県', 'ギフケン', '安八郡神戸町', 'アンパチグンゴウドチョウ', '斉田', 'サイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県安八郡神戸町柳瀬', '21', '21381', '5032317', '岐阜県', 'ギフケン', '安八郡神戸町', 'アンパチグンゴウドチョウ', '柳瀬', 'ヤナゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県安八郡神戸町瀬古', '21', '21381', '5032318', '岐阜県', 'ギフケン', '安八郡神戸町', 'アンパチグンゴウドチョウ', '瀬古', 'セコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県安八郡神戸町前田', '21', '21381', '5032319', '岐阜県', 'ギフケン', '安八郡神戸町', 'アンパチグンゴウドチョウ', '前田', 'マエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県安八郡神戸町末守', '21', '21381', '5032321', '岐阜県', 'ギフケン', '安八郡神戸町', 'アンパチグンゴウドチョウ', '末守', 'スエモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県安八郡神戸町更屋敷', '21', '21381', '5032322', '岐阜県', 'ギフケン', '安八郡神戸町', 'アンパチグンゴウドチョウ', '更屋敷', 'サラヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県安八郡神戸町西保', '21', '21381', '5032323', '岐阜県', 'ギフケン', '安八郡神戸町', 'アンパチグンゴウドチョウ', '西保', 'ニシノホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県安八郡神戸町八条', '21', '21381', '5032324', '岐阜県', 'ギフケン', '安八郡神戸町', 'アンパチグンゴウドチョウ', '八条', 'ハチジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県安八郡神戸町加納', '21', '21381', '5032325', '岐阜県', 'ギフケン', '安八郡神戸町', 'アンパチグンゴウドチョウ', '加納', 'カノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県安八郡神戸町中沢', '21', '21381', '5032326', '岐阜県', 'ギフケン', '安八郡神戸町', 'アンパチグンゴウドチョウ', '中沢', 'ナカザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県安八郡神戸町和泉', '21', '21381', '5032327', '岐阜県', 'ギフケン', '安八郡神戸町', 'アンパチグンゴウドチョウ', '和泉', 'イズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県安八郡神戸町南方', '21', '21381', '5032328', '岐阜県', 'ギフケン', '安八郡神戸町', 'アンパチグンゴウドチョウ', '南方', 'ミナミガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県安八郡神戸町西座倉', '21', '21381', '5032341', '岐阜県', 'ギフケン', '安八郡神戸町', 'アンパチグンゴウドチョウ', '西座倉', 'ニシザクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡池田町', '21', '21404', '5032400', '岐阜県', 'ギフケン', '揖斐郡池田町', 'イビグンイケダチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('53157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡池田町沓井', '21', '21404', '5032401', '岐阜県', 'ギフケン', '揖斐郡池田町', 'イビグンイケダチョウ', '沓井', 'クツイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡池田町粕ケ原', '21', '21404', '5032402', '岐阜県', 'ギフケン', '揖斐郡池田町', 'イビグンイケダチョウ', '粕ケ原', 'カスガハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡池田町田中', '21', '21404', '5032403', '岐阜県', 'ギフケン', '揖斐郡池田町', 'イビグンイケダチョウ', '田中', 'タナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡池田町小牛', '21', '21404', '5032404', '岐阜県', 'ギフケン', '揖斐郡池田町', 'イビグンイケダチョウ', '小牛', 'コウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡池田町願成寺', '21', '21404', '5032405', '岐阜県', 'ギフケン', '揖斐郡池田町', 'イビグンイケダチョウ', '願成寺', 'ガンジョウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡池田町宮地', '21', '21404', '5032406', '岐阜県', 'ギフケン', '揖斐郡池田町', 'イビグンイケダチョウ', '宮地', 'ミヤジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡池田町般若畑', '21', '21404', '5032407', '岐阜県', 'ギフケン', '揖斐郡池田町', 'イビグンイケダチョウ', '般若畑', 'ハンニャバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡池田町段', '21', '21404', '5032408', '岐阜県', 'ギフケン', '揖斐郡池田町', 'イビグンイケダチョウ', '段', 'ダン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡池田町舟子', '21', '21404', '5032409', '岐阜県', 'ギフケン', '揖斐郡池田町', 'イビグンイケダチョウ', '舟子', 'フナゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡池田町杉野', '21', '21404', '5032411', '岐阜県', 'ギフケン', '揖斐郡池田町', 'イビグンイケダチョウ', '杉野', 'スギノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡池田町砂畑', '21', '21404', '5032412', '岐阜県', 'ギフケン', '揖斐郡池田町', 'イビグンイケダチョウ', '砂畑', 'スナバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡池田町白鳥', '21', '21404', '5032413', '岐阜県', 'ギフケン', '揖斐郡池田町', 'イビグンイケダチョウ', '白鳥', 'シロトリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡池田町下東野', '21', '21404', '5032414', '岐阜県', 'ギフケン', '揖斐郡池田町', 'イビグンイケダチョウ', '下東野', 'シモヒガシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡池田町上田', '21', '21404', '5032415', '岐阜県', 'ギフケン', '揖斐郡池田町', 'イビグンイケダチョウ', '上田', 'ウエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡池田町萩原', '21', '21404', '5032416', '岐阜県', 'ギフケン', '揖斐郡池田町', 'イビグンイケダチョウ', '萩原', 'ハギワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡池田町本郷', '21', '21404', '5032417', '岐阜県', 'ギフケン', '揖斐郡池田町', 'イビグンイケダチョウ', '本郷', 'ホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡池田町草深', '21', '21404', '5032418', '岐阜県', 'ギフケン', '揖斐郡池田町', 'イビグンイケダチョウ', '草深', 'クサブカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡池田町小寺', '21', '21404', '5032419', '岐阜県', 'ギフケン', '揖斐郡池田町', 'イビグンイケダチョウ', '小寺', 'コデラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡池田町山洞', '21', '21404', '5032421', '岐阜県', 'ギフケン', '揖斐郡池田町', 'イビグンイケダチョウ', '山洞', 'ヤマホラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡池田町田畑', '21', '21404', '5032422', '岐阜県', 'ギフケン', '揖斐郡池田町', 'イビグンイケダチョウ', '田畑', 'タバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡池田町青柳', '21', '21404', '5032423', '岐阜県', 'ギフケン', '揖斐郡池田町', 'イビグンイケダチョウ', '青柳', 'アオヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡池田町池野', '21', '21404', '5032424', '岐阜県', 'ギフケン', '揖斐郡池田町', 'イビグンイケダチョウ', '池野', 'イケノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡池田町六之井', '21', '21404', '5032425', '岐阜県', 'ギフケン', '揖斐郡池田町', 'イビグンイケダチョウ', '六之井', 'ロクノイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡池田町八幡', '21', '21404', '5032426', '岐阜県', 'ギフケン', '揖斐郡池田町', 'イビグンイケダチョウ', '八幡', 'ヤワタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡池田町市橋', '21', '21404', '5032427', '岐阜県', 'ギフケン', '揖斐郡池田町', 'イビグンイケダチョウ', '市橋', 'イチハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡池田町片山', '21', '21404', '5032428', '岐阜県', 'ギフケン', '揖斐郡池田町', 'イビグンイケダチョウ', '片山', 'カタヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡池田町藤代', '21', '21404', '5032429', '岐阜県', 'ギフケン', '揖斐郡池田町', 'イビグンイケダチョウ', '藤代', 'フジシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡揖斐川町春日美束', '21', '21401', '5032501', '岐阜県', 'ギフケン', '揖斐郡揖斐川町', 'イビグンイビガワチョウ', '春日美束', 'カスガミツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡揖斐川町春日六合', '21', '21401', '5032502', '岐阜県', 'ギフケン', '揖斐郡揖斐川町', 'イビグンイビガワチョウ', '春日六合', 'カスガロクゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡揖斐川町春日川合', '21', '21401', '5032503', '岐阜県', 'ギフケン', '揖斐郡揖斐川町', 'イビグンイビガワチョウ', '春日川合', 'カスガカワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡揖斐川町春日中山', '21', '21401', '5032504', '岐阜県', 'ギフケン', '揖斐郡揖斐川町', 'イビグンイビガワチョウ', '春日中山', 'カスガナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡揖斐川町春日小宮神', '21', '21401', '5032505', '岐阜県', 'ギフケン', '揖斐郡揖斐川町', 'イビグンイビガワチョウ', '春日小宮神', 'カスガコミヤカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県揖斐郡揖斐川町春日香六', '21', '21401', '5032506', '岐阜県', 'ギフケン', '揖斐郡揖斐川町', 'イビグンイビガワチョウ', '春日香六', 'カスガコウロク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市', '21', '21213', '5040000', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('53241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市那加大洞', '21', '21213', '5040001', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '那加大洞', 'ナカオオボラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市尾崎北町', '21', '21213', '5040002', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '尾崎北町', 'オザキキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市尾崎南町', '21', '21213', '5040003', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '尾崎南町', 'オザキミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市尾崎西町', '21', '21213', '5040004', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '尾崎西町', 'オザキニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市那加柄山町', '21', '21213', '5040005', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '那加柄山町', 'ナカカラヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市那加琴が丘町', '21', '21213', '5040006', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '那加琴が丘町', 'ナカコトガオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市那加芦原町', '21', '21213', '5040007', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '那加芦原町', 'ナカアワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市那加桐野町', '21', '21213', '5040008', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '那加桐野町', 'ナカキリノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市那加扇平', '21', '21213', '5040009', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '那加扇平', 'ナカオオギヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市那加北洞町', '21', '21213', '5040011', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '那加北洞町', 'ナカキタボラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市蘇原宮代町', '21', '21213', '5040012', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '蘇原宮代町', 'ソハラミヤダイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市蘇原宮塚町', '21', '21213', '5040013', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '蘇原宮塚町', 'ソハラミヤヅカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市那加山崎町', '21', '21213', '5040014', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '那加山崎町', 'ナカヤマザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市那加東野町', '21', '21213', '5040015', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '那加東野町', 'ナカヒガシノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市那加御屋敷町', '21', '21213', '5040016', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '那加御屋敷町', 'ナカオヤシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市那加山下町', '21', '21213', '5040017', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '那加山下町', 'ナカヤマシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市那加西市場町', '21', '21213', '5040018', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '那加西市場町', 'ナカニシイチバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市那加前洞新町', '21', '21213', '5040021', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '那加前洞新町', 'ナカマエボラシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市那加東亜町', '21', '21213', '5040022', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '那加東亜町', 'ナカトウアチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市那加太平町', '21', '21213', '5040023', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '那加太平町', 'ナカタイヘイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市那加幸町', '21', '21213', '5040024', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '那加幸町', 'ナカサイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市那加野畑町', '21', '21213', '5040025', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '那加野畑町', 'ナカノバタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市那加前野町', '21', '21213', '5040026', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '那加前野町', 'ナカマエノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市那加兼橋町', '21', '21213', '5040031', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '那加兼橋町', 'ナカカネハシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市那加神田町', '21', '21213', '5040032', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '那加神田町', 'ナカジンデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市那加大谷町', '21', '21213', '5040033', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '那加大谷町', 'ナカオオタニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市那加浜見町', '21', '21213', '5040034', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '那加浜見町', 'ナカハマミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市那加宮浦町', '21', '21213', '5040035', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '那加宮浦町', 'ナカミヤウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市那加荒田町', '21', '21213', '5040036', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '那加荒田町', 'ナカアラタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市那加五反田町', '21', '21213', '5040037', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '那加五反田町', 'ナカゴタンダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市那加大門町', '21', '21213', '5040038', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '那加大門町', 'ナカダイモンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市那加土山町', '21', '21213', '5040041', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '那加土山町', 'ナカドヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市那加山後町', '21', '21213', '5040042', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '那加山後町', 'ナカヤマウシロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市那加手力町', '21', '21213', '5040043', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '那加手力町', 'ナカテヂカラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市那加石山町', '21', '21213', '5040044', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '那加石山町', 'ナカイシヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市那加新田町', '21', '21213', '5040045', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '那加新田町', 'ナカシンデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市那加長塚町', '21', '21213', '5040046', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '那加長塚町', 'ナカナガツカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市那加岩地町', '21', '21213', '5040047', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '那加岩地町', 'ナカイワチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市蘇原北山町', '21', '21213', '5040801', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '蘇原北山町', 'ソハラキタヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市蘇原持田町', '21', '21213', '5040802', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '蘇原持田町', 'ソハラモチダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市蘇原東門町', '21', '21213', '5040803', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '蘇原東門町', 'ソハラトウモンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市蘇原新生町', '21', '21213', '5040804', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '蘇原新生町', 'ソハラシンセイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市蘇原昭栄町', '21', '21213', '5040805', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '蘇原昭栄町', 'ソハラショウエイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市蘇原外山町', '21', '21213', '5040806', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '蘇原外山町', 'ソハラトヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市蘇原清住町', '21', '21213', '5040807', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '蘇原清住町', 'ソハラキヨズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市蘇原飛鳥町', '21', '21213', '5040808', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '蘇原飛鳥町', 'ソハラアズカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市蘇原北陽町', '21', '21213', '5040809', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '蘇原北陽町', 'ソハラホクヨウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市蘇原和合町', '21', '21213', '5040811', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '蘇原和合町', 'ソハラワゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市蘇原坂井町', '21', '21213', '5040812', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '蘇原坂井町', 'ソハラサカイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市蘇原中央町', '21', '21213', '5040813', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '蘇原中央町', 'ソハラチュウオウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市蘇原興亜町', '21', '21213', '5040814', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '蘇原興亜町', 'ソハラコウアマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市蘇原東栄町', '21', '21213', '5040815', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '蘇原東栄町', 'ソハラトウエイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市蘇原東島町', '21', '21213', '5040816', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '蘇原東島町', 'ソハラヒガシジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市蘇原瑞雲町', '21', '21213', '5040821', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '蘇原瑞雲町', 'ソハラズイウンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市蘇原栄町', '21', '21213', '5040822', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '蘇原栄町', 'ソハラサカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市蘇原菊園町', '21', '21213', '5040823', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '蘇原菊園町', 'ソハラキクゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市蘇原旭町', '21', '21213', '5040824', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '蘇原旭町', 'ソハラアサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市蘇原柿沢町', '21', '21213', '5040825', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '蘇原柿沢町', 'ソハラカキザワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市蘇原早苗町', '21', '21213', '5040826', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '蘇原早苗町', 'ソハラサナエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市蘇原沢上町', '21', '21213', '5040827', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '蘇原沢上町', 'ソハラサワガミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市蘇原村雨町', '21', '21213', '5040828', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '蘇原村雨町', 'ソハラムラサメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市蘇原希望町', '21', '21213', '5040829', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '蘇原希望町', 'ソハラキボウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市蘇原瑞穂町', '21', '21213', '5040831', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '蘇原瑞穂町', 'ソハラミズホチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市蘇原花園町', '21', '21213', '5040832', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '蘇原花園町', 'ソハラハナゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市入会町', '21', '21213', '5040833', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '入会町', 'ニュウカイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市那加昭南町', '21', '21213', '5040834', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '那加昭南町', 'ナカショウナンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市那加雄飛ケ丘町', '21', '21213', '5040835', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '那加雄飛ケ丘町', 'ナカユウヒガオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市那加雲雀町', '21', '21213', '5040836', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '那加雲雀町', 'ナカヒバリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市那加甥田町', '21', '21213', '5040837', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '那加甥田町', 'ナカオイダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市那加不動丘', '21', '21213', '5040838', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '那加不動丘', 'ナカフドウガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市那加巾下町', '21', '21213', '5040839', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '那加巾下町', 'ナカハバシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市蘇原赤羽根町', '21', '21213', '5040841', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '蘇原赤羽根町', 'ソハラアカバネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市蘇原寺島町', '21', '21213', '5040842', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '蘇原寺島町', 'ソハラテラジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市蘇原青雲町', '21', '21213', '5040843', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '蘇原青雲町', 'ソハラセイウンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市蘇原吉新町', '21', '21213', '5040844', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '蘇原吉新町', 'ソハラキチシンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市蘇原申子町', '21', '21213', '5040845', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '蘇原申子町', 'ソハラサルコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市蘇原吉野町', '21', '21213', '5040846', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '蘇原吉野町', 'ソハラヨシノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市蘇原大島町', '21', '21213', '5040847', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '蘇原大島町', 'ソハラオオシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市蘇原伊吹町', '21', '21213', '5040851', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '蘇原伊吹町', 'ソハライブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市蘇原古市場町', '21', '21213', '5040852', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '蘇原古市場町', 'ソハラフルイチバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市蘇原熊田町', '21', '21213', '5040853', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '蘇原熊田町', 'ソハラクマタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市蘇原野口町', '21', '21213', '5040854', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '蘇原野口町', 'ソハラノグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市蘇原新栄町', '21', '21213', '5040855', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '蘇原新栄町', 'ソハラシンサカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市蘇原島崎町', '21', '21213', '5040856', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '蘇原島崎町', 'ソハラシマサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市東山', '21', '21213', '5040861', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '東山', 'ヒガシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市那加東新町', '21', '21213', '5040901', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '那加東新町', 'ナカトウシンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市蘇原緑町', '21', '21213', '5040902', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '蘇原緑町', 'ソハラミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市蘇原月丘町', '21', '21213', '5040903', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '蘇原月丘町', 'ソハラツキオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市蘇原三柿野町', '21', '21213', '5040904', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '蘇原三柿野町', 'ソハラミカキノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市蘇原六軒町', '21', '21213', '5040905', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '蘇原六軒町', 'ソハラロッケンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市那加桐野外二ケ所大字入会地', '21', '21213', '5040906', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '那加桐野外二ケ所大字入会地', 'ナカキリノホカニカショオオアザニュウカイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市那加住吉町', '21', '21213', '5040907', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '那加住吉町', 'ナカスミヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市那加織田町', '21', '21213', '5040908', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '那加織田町', 'ナカオダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市那加信長町', '21', '21213', '5040909', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '那加信長町', 'ナカノブナガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市那加門前町', '21', '21213', '5040911', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '那加門前町', 'ナカモンゼンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市那加桜町', '21', '21213', '5040912', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '那加桜町', 'ナカサクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市那加大東町', '21', '21213', '5040913', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '那加大東町', 'ナカダイトウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市三井東町', '21', '21213', '5040914', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '三井東町', 'ミイヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市三井山町', '21', '21213', '5040915', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '三井山町', 'ミイヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市那加楠町', '21', '21213', '5040916', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '那加楠町', 'ナカクスノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市前渡北町', '21', '21213', '5040921', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '前渡北町', 'マエドキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市前渡東町', '21', '21213', '5040922', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '前渡東町', 'マエドヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市前渡西町', '21', '21213', '5040923', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '前渡西町', 'マエドニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市下切町', '21', '21213', '5040924', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '下切町', 'シモギリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市松本町', '21', '21213', '5040925', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '松本町', 'マツモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市上中屋町', '21', '21213', '5040926', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '上中屋町', 'カミナカヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市上戸町', '21', '21213', '5040927', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '上戸町', 'ジョウゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市山脇町', '21', '21213', '5040928', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '山脇町', 'ヤマワキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市大佐野町', '21', '21213', '5040931', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '大佐野町', 'オオザノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市下中屋町', '21', '21213', '5040932', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '下中屋町', 'シモナカヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市神置町', '21', '21213', '5040933', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '神置町', 'カミオキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市大野町', '21', '21213', '5040934', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '大野町', 'オオノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市成清町', '21', '21213', '5040935', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '成清町', 'ナルキヨチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市三井町', '21', '21213', '5040941', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '三井町', 'ミイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市小佐野町', '21', '21213', '5040942', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '小佐野町', 'コザノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市那加萱場町', '21', '21213', '5040943', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '那加萱場町', 'ナカカヤバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市那加緑町', '21', '21213', '5040944', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '那加緑町', 'ナカミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市那加日新町', '21', '21213', '5040945', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '那加日新町', 'ナカニッシンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市那加日吉町', '21', '21213', '5040951', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '那加日吉町', 'ナカヒヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市那加西那加町', '21', '21213', '5040952', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '那加西那加町', 'ナカニシナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市那加東那加町', '21', '21213', '5040953', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '那加東那加町', 'ナカヒガシナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市那加栄町', '21', '21213', '5040954', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '那加栄町', 'ナカサカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市那加南栄町', '21', '21213', '5040955', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '那加南栄町', 'ナカミナミサカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市三井北町', '21', '21213', '5040956', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '三井北町', 'ミイキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市金属団地', '21', '21213', '5040957', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '金属団地', 'キンゾクダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市那加新加納町', '21', '21213', '5040958', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '那加新加納町', 'ナカシンカノウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市那加西浦町', '21', '21213', '5040959', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '那加西浦町', 'ナカニシウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市那加新那加町', '21', '21213', '5040961', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '那加新那加町', 'ナカシンナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市那加吾妻町', '21', '21213', '5040962', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '那加吾妻町', 'ナカアヅマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市那加北栄町', '21', '21213', '5040963', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '那加北栄町', 'ナカキタサカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市那加元町', '21', '21213', '5040964', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '那加元町', 'ナカモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市那加日之出町', '21', '21213', '5040965', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '那加日之出町', 'ナカヒノデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市那加本町', '21', '21213', '5040966', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '那加本町', 'ナカホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市那加楽天地町', '21', '21213', '5040967', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '那加楽天地町', 'ナカラクテンチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市那加西野町', '21', '21213', '5040968', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '那加西野町', 'ナカニシノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市川崎町', '21', '21213', '5040971', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '川崎町', 'カワサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県美濃加茂市', '21', '21211', '5050000', '岐阜県', 'ギフケン', '美濃加茂市', 'ミノカモシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('53390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県加茂郡坂祝町', '21', '21501', '5050000', '岐阜県', 'ギフケン', '加茂郡坂祝町', 'カモグンサカホギチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('53391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県美濃加茂市三和町廿屋', '21', '21211', '5050001', '岐阜県', 'ギフケン', '美濃加茂市', 'ミノカモシ', '三和町廿屋', 'ミワチョウツヅヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県美濃加茂市三和町川浦', '21', '21211', '5050002', '岐阜県', 'ギフケン', '美濃加茂市', 'ミノカモシ', '三和町川浦', 'ミワチョウカワウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県美濃加茂市山之上町', '21', '21211', '5050003', '岐阜県', 'ギフケン', '美濃加茂市', 'ミノカモシ', '山之上町', 'ヤマノウエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県美濃加茂市蜂屋町上蜂屋', '21', '21211', '5050004', '岐阜県', 'ギフケン', '美濃加茂市', 'ミノカモシ', '蜂屋町上蜂屋', 'ハチヤチョウカミハチヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県美濃加茂市蜂屋町中蜂屋', '21', '21211', '5050005', '岐阜県', 'ギフケン', '美濃加茂市', 'ミノカモシ', '蜂屋町中蜂屋', 'ハチヤチョウナカハチヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県美濃加茂市蜂屋町伊瀬', '21', '21211', '5050006', '岐阜県', 'ギフケン', '美濃加茂市', 'ミノカモシ', '蜂屋町伊瀬', 'ハチヤチョウイゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県美濃加茂市蜂屋町下蜂屋', '21', '21211', '5050007', '岐阜県', 'ギフケン', '美濃加茂市', 'ミノカモシ', '蜂屋町下蜂屋', 'ハチヤチョウシモハチヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県美濃加茂市伊深町', '21', '21211', '5050008', '岐阜県', 'ギフケン', '美濃加茂市', 'ミノカモシ', '伊深町', 'イブカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県美濃加茂市蜂屋町矢田', '21', '21211', '5050009', '岐阜県', 'ギフケン', '美濃加茂市', 'ミノカモシ', '蜂屋町矢田', 'ハチヤチョウヤタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県美濃加茂市下米田町東栃井', '21', '21211', '5050011', '岐阜県', 'ギフケン', '美濃加茂市', 'ミノカモシ', '下米田町東栃井', 'シモヨネダチョウヒガシトチイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県美濃加茂市下米田町山本', '21', '21211', '5050012', '岐阜県', 'ギフケン', '美濃加茂市', 'ミノカモシ', '下米田町山本', 'シモヨネダチョウヤマモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県美濃加茂市下米田町信友', '21', '21211', '5050013', '岐阜県', 'ギフケン', '美濃加茂市', 'ミノカモシ', '下米田町信友', 'シモヨネダチョウノブトモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県美濃加茂市下米田町則光', '21', '21211', '5050014', '岐阜県', 'ギフケン', '美濃加茂市', 'ミノカモシ', '下米田町則光', 'シモヨネダチョウノリミツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県美濃加茂市下米田町今', '21', '21211', '5050015', '岐阜県', 'ギフケン', '美濃加茂市', 'ミノカモシ', '下米田町今', 'シモヨネダチョウイマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県美濃加茂市牧野', '21', '21211', '5050016', '岐阜県', 'ギフケン', '美濃加茂市', 'ミノカモシ', '牧野', 'マキノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県美濃加茂市下米田町小山', '21', '21211', '5050017', '岐阜県', 'ギフケン', '美濃加茂市', 'ミノカモシ', '下米田町小山', 'シモヨネダチョウコヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県美濃加茂市下米田町西脇', '21', '21211', '5050018', '岐阜県', 'ギフケン', '美濃加茂市', 'ミノカモシ', '下米田町西脇', 'シモヨネダチョウニシワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県美濃加茂市下米田町為岡', '21', '21211', '5050019', '岐阜県', 'ギフケン', '美濃加茂市', 'ミノカモシ', '下米田町為岡', 'シモヨネダチョウタメオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県美濃加茂市森山町', '21', '21211', '5050021', '岐阜県', 'ギフケン', '美濃加茂市', 'ミノカモシ', '森山町', 'モリヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県美濃加茂市川合町', '21', '21211', '5050022', '岐阜県', 'ギフケン', '美濃加茂市', 'ミノカモシ', '川合町', 'カワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県美濃加茂市野笹町', '21', '21211', '5050023', '岐阜県', 'ギフケン', '美濃加茂市', 'ミノカモシ', '野笹町', 'ノザサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県美濃加茂市御門町', '21', '21211', '5050024', '岐阜県', 'ギフケン', '美濃加茂市', 'ミノカモシ', '御門町', 'ミカドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県美濃加茂市島町', '21', '21211', '5050025', '岐阜県', 'ギフケン', '美濃加茂市', 'ミノカモシ', '島町', 'シマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県美濃加茂市清水町', '21', '21211', '5050026', '岐阜県', 'ギフケン', '美濃加茂市', 'ミノカモシ', '清水町', 'シミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県美濃加茂市本郷町', '21', '21211', '5050027', '岐阜県', 'ギフケン', '美濃加茂市', 'ミノカモシ', '本郷町', 'ホンゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県美濃加茂市新池町', '21', '21211', '5050031', '岐阜県', 'ギフケン', '美濃加茂市', 'ミノカモシ', '新池町', 'シンイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県美濃加茂市田島町', '21', '21211', '5050032', '岐阜県', 'ギフケン', '美濃加茂市', 'ミノカモシ', '田島町', 'タジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県美濃加茂市中富町', '21', '21211', '5050033', '岐阜県', 'ギフケン', '美濃加茂市', 'ミノカモシ', '中富町', 'ナカトミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県美濃加茂市古井町下古井', '21', '21211', '5050034', '岐阜県', 'ギフケン', '美濃加茂市', 'ミノカモシ', '古井町下古井', 'コビチョウシモコビ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県美濃加茂市大手町', '21', '21211', '5050035', '岐阜県', 'ギフケン', '美濃加茂市', 'ミノカモシ', '大手町', 'オオテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県美濃加茂市山手町', '21', '21211', '5050036', '岐阜県', 'ギフケン', '美濃加茂市', 'ミノカモシ', '山手町', 'ヤマテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県美濃加茂市前平町', '21', '21211', '5050037', '岐阜県', 'ギフケン', '美濃加茂市', 'ミノカモシ', '前平町', 'マエヒラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県美濃加茂市中部台', '21', '21211', '5050038', '岐阜県', 'ギフケン', '美濃加茂市', 'ミノカモシ', '中部台', 'チュウブダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県美濃加茂市蜂屋台', '21', '21211', '5050039', '岐阜県', 'ギフケン', '美濃加茂市', 'ミノカモシ', '蜂屋台', 'ハチヤダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県美濃加茂市太田町', '21', '21211', '5050041', '岐阜県', 'ギフケン', '美濃加茂市', 'ミノカモシ', '太田町', 'オオタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県美濃加茂市太田本町', '21', '21211', '5050042', '岐阜県', 'ギフケン', '美濃加茂市', 'ミノカモシ', '太田本町', 'オオタホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県美濃加茂市深田町', '21', '21211', '5050043', '岐阜県', 'ギフケン', '美濃加茂市', 'ミノカモシ', '深田町', 'フカタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県美濃加茂市加茂川町', '21', '21211', '5050044', '岐阜県', 'ギフケン', '美濃加茂市', 'ミノカモシ', '加茂川町', 'カモガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県美濃加茂市草笛町', '21', '21211', '5050045', '岐阜県', 'ギフケン', '美濃加茂市', 'ミノカモシ', '草笛町', 'クサブエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県美濃加茂市西町', '21', '21211', '5050046', '岐阜県', 'ギフケン', '美濃加茂市', 'ミノカモシ', '西町', 'ニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県美濃加茂市加茂野町鷹之巣', '21', '21211', '5050051', '岐阜県', 'ギフケン', '美濃加茂市', 'ミノカモシ', '加茂野町鷹之巣', 'カモノチョウタカノス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県美濃加茂市加茂野町今泉', '21', '21211', '5050052', '岐阜県', 'ギフケン', '美濃加茂市', 'ミノカモシ', '加茂野町今泉', 'カモノチョウイマイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県美濃加茂市加茂野町木野', '21', '21211', '5050053', '岐阜県', 'ギフケン', '美濃加茂市', 'ミノカモシ', '加茂野町木野', 'カモノチョウコノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県美濃加茂市加茂野町加茂野', '21', '21211', '5050054', '岐阜県', 'ギフケン', '美濃加茂市', 'ミノカモシ', '加茂野町加茂野', 'カモノチョウカモノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県美濃加茂市加茂野町稲辺', '21', '21211', '5050055', '岐阜県', 'ギフケン', '美濃加茂市', 'ミノカモシ', '加茂野町稲辺', 'カモノチョウイナベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県美濃加茂市加茂野町市橋', '21', '21211', '5050056', '岐阜県', 'ギフケン', '美濃加茂市', 'ミノカモシ', '加茂野町市橋', 'カモノチョウイチハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県加茂郡坂祝町黒岩', '21', '21501', '5050071', '岐阜県', 'ギフケン', '加茂郡坂祝町', 'カモグンサカホギチョウ', '黒岩', 'クロイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県加茂郡坂祝町大針', '21', '21501', '5050072', '岐阜県', 'ギフケン', '加茂郡坂祝町', 'カモグンサカホギチョウ', '大針', 'オオハリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県加茂郡坂祝町加茂山', '21', '21501', '5050073', '岐阜県', 'ギフケン', '加茂郡坂祝町', 'カモグンサカホギチョウ', '加茂山', 'カモヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県加茂郡坂祝町酒倉', '21', '21501', '5050074', '岐阜県', 'ギフケン', '加茂郡坂祝町', 'カモグンサカホギチョウ', '酒倉', 'サカクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県加茂郡坂祝町取組', '21', '21501', '5050075', '岐阜県', 'ギフケン', '加茂郡坂祝町', 'カモグンサカホギチョウ', '取組', 'トリクミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県加茂郡坂祝町勝山', '21', '21501', '5050076', '岐阜県', 'ギフケン', '加茂郡坂祝町', 'カモグンサカホギチョウ', '勝山', 'カツヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県加茂郡坂祝町深萱', '21', '21501', '5050077', '岐阜県', 'ギフケン', '加茂郡坂祝町', 'カモグンサカホギチョウ', '深萱', 'フカガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県可児郡御嵩町', '21', '21521', '5050100', '岐阜県', 'ギフケン', '可児郡御嵩町', 'カニグンミタケチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('53445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県可児郡御嵩町大久後', '21', '21521', '5050101', '岐阜県', 'ギフケン', '可児郡御嵩町', 'カニグンミタケチョウ', '大久後', 'オオクゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県可児郡御嵩町前沢', '21', '21521', '5050102', '岐阜県', 'ギフケン', '可児郡御嵩町', 'カニグンミタケチョウ', '前沢', 'マエザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県可児郡御嵩町津橋', '21', '21521', '5050103', '岐阜県', 'ギフケン', '可児郡御嵩町', 'カニグンミタケチョウ', '津橋', 'ツバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県可児郡御嵩町謡坂', '21', '21521', '5050104', '岐阜県', 'ギフケン', '可児郡御嵩町', 'カニグンミタケチョウ', '謡坂', 'ウトウザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県可児郡御嵩町西洞', '21', '21521', '5050105', '岐阜県', 'ギフケン', '可児郡御嵩町', 'カニグンミタケチョウ', '西洞', 'サイト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県可児郡御嵩町小原', '21', '21521', '5050106', '岐阜県', 'ギフケン', '可児郡御嵩町', 'カニグンミタケチョウ', '小原', 'オバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県可児郡御嵩町上之郷', '21', '21521', '5050107', '岐阜県', 'ギフケン', '可児郡御嵩町', 'カニグンミタケチョウ', '上之郷', 'カミノゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県可児郡御嵩町小和沢', '21', '21521', '5050108', '岐阜県', 'ギフケン', '可児郡御嵩町', 'カニグンミタケチョウ', '小和沢', 'コワサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県可児郡御嵩町次月', '21', '21521', '5050111', '岐阜県', 'ギフケン', '可児郡御嵩町', 'カニグンミタケチョウ', '次月', 'シヅキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県可児郡御嵩町美佐野', '21', '21521', '5050112', '岐阜県', 'ギフケン', '可児郡御嵩町', 'カニグンミタケチョウ', '美佐野', 'ミザノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県可児郡御嵩町宿', '21', '21521', '5050113', '岐阜県', 'ギフケン', '可児郡御嵩町', 'カニグンミタケチョウ', '宿', 'シュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県可児郡御嵩町中切', '21', '21521', '5050114', '岐阜県', 'ギフケン', '可児郡御嵩町', 'カニグンミタケチョウ', '中切', 'ナカギリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県可児郡御嵩町井尻', '21', '21521', '5050115', '岐阜県', 'ギフケン', '可児郡御嵩町', 'カニグンミタケチョウ', '井尻', 'イジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県可児郡御嵩町御嵩', '21', '21521', '5050116', '岐阜県', 'ギフケン', '可児郡御嵩町', 'カニグンミタケチョウ', '御嵩', 'ミタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県可児郡御嵩町中', '21', '21521', '5050121', '岐阜県', 'ギフケン', '可児郡御嵩町', 'カニグンミタケチョウ', '中', 'ナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県可児郡御嵩町顔戸', '21', '21521', '5050122', '岐阜県', 'ギフケン', '可児郡御嵩町', 'カニグンミタケチョウ', '顔戸', 'ゴウト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県可児郡御嵩町古屋敷', '21', '21521', '5050123', '岐阜県', 'ギフケン', '可児郡御嵩町', 'カニグンミタケチョウ', '古屋敷', 'フルヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県可児郡御嵩町比衣', '21', '21521', '5050124', '岐阜県', 'ギフケン', '可児郡御嵩町', 'カニグンミタケチョウ', '比衣', 'ヒエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県可児郡御嵩町伏見', '21', '21521', '5050125', '岐阜県', 'ギフケン', '可児郡御嵩町', 'カニグンミタケチョウ', '伏見', 'フシミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県可児郡御嵩町上恵土', '21', '21521', '5050126', '岐阜県', 'ギフケン', '可児郡御嵩町', 'カニグンミタケチョウ', '上恵土', 'カミエド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県可児市兼山', '21', '21214', '5050130', '岐阜県', 'ギフケン', '可児市', 'カニシ', '兼山', 'カネヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県加茂郡八百津町', '21', '21505', '5050300', '岐阜県', 'ギフケン', '加茂郡八百津町', 'カモグンヤオツチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('53467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県加茂郡八百津町八百津', '21', '21505', '5050301', '岐阜県', 'ギフケン', '加茂郡八百津町', 'カモグンヤオツチョウ', '八百津', 'ヤオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県加茂郡八百津町錦織', '21', '21505', '5050302', '岐阜県', 'ギフケン', '加茂郡八百津町', 'カモグンヤオツチョウ', '錦織', 'ニシキオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県加茂郡八百津町伊岐津志', '21', '21505', '5050303', '岐阜県', 'ギフケン', '加茂郡八百津町', 'カモグンヤオツチョウ', '伊岐津志', 'イキツシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県加茂郡八百津町上牧野', '21', '21505', '5050304', '岐阜県', 'ギフケン', '加茂郡八百津町', 'カモグンヤオツチョウ', '上牧野', 'カミマキノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県加茂郡八百津町和知', '21', '21505', '5050305', '岐阜県', 'ギフケン', '加茂郡八百津町', 'カモグンヤオツチョウ', '和知', 'ワチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県加茂郡八百津町上飯田', '21', '21505', '5050306', '岐阜県', 'ギフケン', '加茂郡八百津町', 'カモグンヤオツチョウ', '上飯田', 'カミイイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県加茂郡八百津町野上', '21', '21505', '5050307', '岐阜県', 'ギフケン', '加茂郡八百津町', 'カモグンヤオツチョウ', '野上', 'ノガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県加茂郡八百津町福地', '21', '21505', '5050421', '岐阜県', 'ギフケン', '加茂郡八百津町', 'カモグンヤオツチョウ', '福地', 'フクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県加茂郡八百津町久田見', '21', '21505', '5050422', '岐阜県', 'ギフケン', '加茂郡八百津町', 'カモグンヤオツチョウ', '久田見', 'クタミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県加茂郡八百津町上吉田', '21', '21505', '5050423', '岐阜県', 'ギフケン', '加茂郡八百津町', 'カモグンヤオツチョウ', '上吉田', 'カミヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県加茂郡八百津町潮見', '21', '21505', '5050531', '岐阜県', 'ギフケン', '加茂郡八百津町', 'カモグンヤオツチョウ', '潮見', 'シオミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県加茂郡八百津町南戸', '21', '21505', '5050532', '岐阜県', 'ギフケン', '加茂郡八百津町', 'カモグンヤオツチョウ', '南戸', 'ミナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市', '21', '21203', '5060000', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('53487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市冬頭町', '21', '21203', '5060001', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '冬頭町', 'フユトウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市問屋町', '21', '21203', '5060002', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '問屋町', 'トンヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市本母町', '21', '21203', '5060003', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '本母町', 'ホノブマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市桐生町', '21', '21203', '5060004', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '桐生町', 'キリウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市七日町', '21', '21203', '5060005', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '七日町', 'ナヌカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市神田町', '21', '21203', '5060006', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '神田町', 'カンダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市総和町', '21', '21203', '5060007', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '総和町', 'ソウワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市初田町', '21', '21203', '5060008', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '初田町', 'ハツダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市花岡町', '21', '21203', '5060009', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '花岡町', 'ハナオカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市本町', '21', '21203', '5060011', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市八軒町', '21', '21203', '5060012', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '八軒町', 'ハチケンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市有楽町', '21', '21203', '5060013', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '有楽町', 'ウラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市相生町', '21', '21203', '5060014', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '相生町', 'アイオイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市花川町', '21', '21203', '5060015', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '花川町', 'ハナカワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市末広町', '21', '21203', '5060016', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '末広町', 'スエヒロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市朝日町', '21', '21203', '5060017', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '朝日町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市名田町', '21', '21203', '5060021', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '名田町', 'ナダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市西町', '21', '21203', '5060022', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '西町', 'ニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市川原町', '21', '21203', '5060023', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '川原町', 'カワハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市上川原町', '21', '21203', '5060024', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '上川原町', 'カミカワハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市天満町', '21', '21203', '5060025', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '天満町', 'テンマンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市花里町', '21', '21203', '5060026', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '花里町', 'ハナサトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市西之一色町', '21', '21203', '5060031', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '西之一色町', 'ニシノイッシキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市千島町', '21', '21203', '5060032', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '千島町', 'チシママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市越後町', '21', '21203', '5060033', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '越後町', 'エチゴマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市松倉町', '21', '21203', '5060034', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '松倉町', 'マツクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市新宮町', '21', '21203', '5060035', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '新宮町', 'シングウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市下切町', '21', '21203', '5060041', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '下切町', 'シモギリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市旭ケ丘町', '21', '21203', '5060042', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '旭ケ丘町', 'アサヒガオカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市中切町', '21', '21203', '5060043', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '中切町', 'ナカギリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市上切町', '21', '21203', '5060044', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '上切町', 'カミギリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市赤保木町', '21', '21203', '5060045', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '赤保木町', 'アカホキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市下之切町', '21', '21203', '5060046', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '下之切町', 'シモノキリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市八日町', '21', '21203', '5060047', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '八日町', 'ヨウカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市前原町', '21', '21203', '5060048', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '前原町', 'マエハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市中山町', '21', '21203', '5060051', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '中山町', 'ナカヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市下岡本町', '21', '21203', '5060052', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '下岡本町', 'シモオカモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市昭和町', '21', '21203', '5060053', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '昭和町', 'ショウワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市岡本町', '21', '21203', '5060054', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '岡本町', 'オカモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市上岡本町', '21', '21203', '5060055', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '上岡本町', 'カミオカモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市緑ケ丘町', '21', '21203', '5060056', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '緑ケ丘町', 'ミドリガオカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市匠ケ丘町', '21', '21203', '5060057', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '匠ケ丘町', 'タクミガオカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市山田町', '21', '21203', '5060058', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '山田町', 'ヤマダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市下林町', '21', '21203', '5060059', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '下林町', 'シモバヤシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市清見町牧ケ洞', '21', '21203', '5060101', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '清見町牧ケ洞', 'キヨミチョウマキガホラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市清見町三日町', '21', '21203', '5060102', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '清見町三日町', 'キヨミチョウミッカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市清見町藤瀬', '21', '21203', '5060103', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '清見町藤瀬', 'キヨミチョウフジセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市清見町福寄', '21', '21203', '5060104', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '清見町福寄', 'キヨミチョウフクヨリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市清見町三ツ谷', '21', '21203', '5060105', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '清見町三ツ谷', 'キヨミチョウミツダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市清見町坂下', '21', '21203', '5060106', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '清見町坂下', 'キヨミチョウサカシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市清見町巣野俣', '21', '21203', '5060107', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '清見町巣野俣', 'キヨミチョウスノマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市清見町江黒', '21', '21203', '5060201', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '清見町江黒', 'キヨミチョウエグロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市清見町大谷', '21', '21203', '5060202', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '清見町大谷', 'キヨミチョウオオタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市清見町池本', '21', '21203', '5060203', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '清見町池本', 'キヨミチョウイケモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市清見町二本木', '21', '21203', '5060204', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '清見町二本木', 'キヨミチョウニホンギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市清見町夏厩', '21', '21203', '5060205', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '清見町夏厩', 'キヨミチョウナツマヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市清見町上小鳥', '21', '21203', '5060206', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '清見町上小鳥', 'キヨミチョウカミオドリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市清見町森茂', '21', '21203', '5060207', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '清見町森茂', 'キヨミチョウモリモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市河合町舟原', '21', '21217', '5060271', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '河合町舟原', 'カワイチョウフナバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市上野町', '21', '21203', '5060801', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '上野町', 'ウワノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市松之木町', '21', '21203', '5060802', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '松之木町', 'マツノキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市日の出町', '21', '21203', '5060803', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '日の出町', 'ヒノデマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市長坂町', '21', '21203', '5060804', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '長坂町', 'ナガサカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市東山町', '21', '21203', '5060805', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '東山町', 'ヒガシヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市曙町', '21', '21203', '5060806', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '曙町', 'アケボノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市三福寺町', '21', '21203', '5060807', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '三福寺町', 'サンフクジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市松本町', '21', '21203', '5060808', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '松本町', 'マツモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市大洞町', '21', '21203', '5060811', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '大洞町', 'オオボラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市漆垣内町', '21', '21203', '5060812', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '漆垣内町', 'ウルシガイトウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市塩屋町', '21', '21203', '5060813', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '塩屋町', 'シオヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市滝町', '21', '21203', '5060814', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '滝町', 'タキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市岩井町', '21', '21203', '5060815', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '岩井町', 'イワイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市大島町', '21', '21203', '5060816', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '大島町', 'オオジママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市山口町', '21', '21203', '5060817', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '山口町', 'ヤマグチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市江名子町', '21', '21203', '5060818', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '江名子町', 'エナコマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市神明町', '21', '21203', '5060821', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '神明町', 'シンメイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市城山', '21', '21203', '5060822', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '城山', 'シロヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市森下町', '21', '21203', '5060823', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '森下町', 'モリシタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市片野町', '21', '21203', '5060824', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '片野町', 'カタノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市石浦町', '21', '21203', '5060825', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '石浦町', 'イシウラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市吹屋町', '21', '21203', '5060831', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '吹屋町', 'フキヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市天性寺町', '21', '21203', '5060832', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '天性寺町', 'テンショウジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市西洞町', '21', '21203', '5060833', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '西洞町', 'ニシボラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市宗猷寺町', '21', '21203', '5060834', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '宗猷寺町', 'ソウユウジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市春日町', '21', '21203', '5060835', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '春日町', 'カスガマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市島川原町', '21', '21203', '5060836', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '島川原町', 'シマカワハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市堀端町', '21', '21203', '5060837', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '堀端町', 'ホリバタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市馬場町', '21', '21203', '5060838', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '馬場町', 'ババマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市下三之町', '21', '21203', '5060841', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '下三之町', 'シモ03ノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市下二之町', '21', '21203', '5060842', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '下二之町', 'シモ02ノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市下一之町', '21', '21203', '5060843', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '下一之町', 'シモ01ノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市上一之町', '21', '21203', '5060844', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '上一之町', 'カミ01ノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市上二之町', '21', '21203', '5060845', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '上二之町', 'カミ02ノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市上三之町', '21', '21203', '5060846', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '上三之町', 'カミ03ノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市片原町', '21', '21203', '5060847', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '片原町', 'カタハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市大新町', '21', '21203', '5060851', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '大新町', 'オオシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市八幡町', '21', '21203', '5060852', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '八幡町', 'ハチマンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市左京町', '21', '21203', '5060853', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '左京町', 'サキョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市若達町', '21', '21203', '5060854', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '若達町', 'ワカタツマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市愛宕町', '21', '21203', '5060855', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '愛宕町', 'アタゴマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市大門町', '21', '21203', '5060856', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '大門町', 'ダイモンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市鉄砲町', '21', '21203', '5060857', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '鉄砲町', 'テッポウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市桜町', '21', '21203', '5060858', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '桜町', 'サクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市', '21', '21217', '5061100', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('53593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市神岡町和佐府', '21', '21217', '5061101', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '神岡町和佐府', 'カミオカチョウワサフ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市神岡町打保', '21', '21217', '5061102', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '神岡町打保', 'カミオカチョウウツボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市神岡町岩井谷', '21', '21217', '5061103', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '神岡町岩井谷', 'カミオカチョウイワイダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市神岡町森茂', '21', '21217', '5061104', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '神岡町森茂', 'カミオカチョウモリモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市神岡町和佐保', '21', '21217', '5061105', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '神岡町和佐保', 'カミオカチョウワサボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市神岡町伊西', '21', '21217', '5061106', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '神岡町伊西', 'カミオカチョウイニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市神岡町下之本', '21', '21217', '5061107', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '神岡町下之本', 'カミオカチョウシモノモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市神岡町瀬戸', '21', '21217', '5061108', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '神岡町瀬戸', 'カミオカチョウセト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市神岡町東町', '21', '21217', '5061111', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '神岡町東町', 'カミオカチョウヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市神岡町六郎', '21', '21217', '5061111', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '神岡町六郎', 'カミオカチョウロクロウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市神岡町割石', '21', '21217', '5061112', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '神岡町割石', 'カミオカチョウワリイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市神岡町吉ケ原', '21', '21217', '5061113', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '神岡町吉ケ原', 'カミオカチョウヨシガハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市神岡町鹿間', '21', '21217', '5061114', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '神岡町鹿間', 'カミオカチョウシカマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市神岡町旭ケ丘', '21', '21217', '5061121', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '神岡町旭ケ丘', 'カミオカチョウアサヒガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市神岡町殿', '21', '21217', '5061121', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '神岡町殿', 'カミオカチョウトノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市神岡町坂富町', '21', '21217', '5061122', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '神岡町坂富町', 'カミオカチョウサカトミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市神岡町城ケ丘', '21', '21217', '5061123', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '神岡町城ケ丘', 'カミオカチョウシロガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市神岡町夕陽ケ丘', '21', '21217', '5061124', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '神岡町夕陽ケ丘', 'カミオカチョウユウヒガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市神岡町江馬町', '21', '21217', '5061125', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '神岡町江馬町', 'カミオカチョウエマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市神岡町桜ケ丘', '21', '21217', '5061126', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '神岡町桜ケ丘', 'カミオカチョウサクラガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市神岡町麻生野', '21', '21217', '5061131', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '神岡町麻生野', 'カミオカチョウアソヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市神岡町石神', '21', '21217', '5061132', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '神岡町石神', 'カミオカチョウイシガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市神岡町数河', '21', '21217', '5061133', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '神岡町数河', 'カミオカチョウスゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市神岡町野首', '21', '21217', '5061141', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '神岡町野首', 'カミオカチョウノクビ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市神岡町丸山', '21', '21217', '5061142', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '神岡町丸山', 'カミオカチョウマルヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市神岡町小萱', '21', '21217', '5061143', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '神岡町小萱', 'カミオカチョウコカヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市神岡町吉田', '21', '21217', '5061144', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '神岡町吉田', 'カミオカチョウヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市神岡町釜崎', '21', '21217', '5061145', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '神岡町釜崎', 'カミオカチョウカマサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市神岡町緑ケ丘', '21', '21217', '5061146', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '神岡町緑ケ丘', 'カミオカチョウミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市神岡町東雲', '21', '21217', '5061147', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '神岡町東雲', 'カミオカチョウアズモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市神岡町館野町', '21', '21217', '5061148', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '神岡町館野町', 'カミオカチョウタテノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市神岡町阿曽保', '21', '21217', '5061149', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '神岡町阿曽保', 'カミオカチョウアソボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市神岡町梨ケ根', '21', '21217', '5061151', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '神岡町梨ケ根', 'カミオカチョウナシガネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市神岡町寺林', '21', '21217', '5061152', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '神岡町寺林', 'カミオカチョウテラバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市神岡町堀之内', '21', '21217', '5061153', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '神岡町堀之内', 'カミオカチョウホリノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市神岡町伏方', '21', '21217', '5061154', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '神岡町伏方', 'カミオカチョウフセガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市神岡町西', '21', '21217', '5061155', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '神岡町西', 'カミオカチョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市神岡町山田', '21', '21217', '5061156', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '神岡町山田', 'カミオカチョウヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市神岡町巣山', '21', '21217', '5061157', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '神岡町巣山', 'カミオカチョウスヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市神岡町柏原', '21', '21217', '5061158', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '神岡町柏原', 'カミオカチョウカシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市神岡町船津', '21', '21217', '5061161', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '神岡町船津', 'カミオカチョウフナツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市神岡町牧ケ平', '21', '21217', '5061161', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '神岡町牧ケ平', 'カミオカチョウマキガヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市神岡町朝浦', '21', '21217', '5061162', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '神岡町朝浦', 'カミオカチョウアソラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市神岡町谷', '21', '21217', '5061201', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '神岡町谷', 'カミオカチョウタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市神岡町中山', '21', '21217', '5061202', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '神岡町中山', 'カミオカチョウナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市神岡町横山', '21', '21217', '5061203', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '神岡町横山', 'カミオカチョウヨコヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市神岡町杉山', '21', '21217', '5061204', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '神岡町杉山', 'カミオカチョウスギヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市神岡町東茂住', '21', '21217', '5061205', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '神岡町東茂住', 'カミオカチョウヒガシモズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市神岡町西茂住', '21', '21217', '5061206', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '神岡町西茂住', 'カミオカチョウニシモズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市神岡町佐古', '21', '21217', '5061211', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '神岡町佐古', 'カミオカチョウサコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市神岡町跡津川', '21', '21217', '5061212', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '神岡町跡津川', 'カミオカチョウアトツガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市神岡町土', '21', '21217', '5061213', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '神岡町土', 'カミオカチョウド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市神岡町牧', '21', '21217', '5061214', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '神岡町牧', 'カミオカチョウマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市神岡町西漆山', '21', '21217', '5061215', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '神岡町西漆山', 'カミオカチョウニシウルシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市神岡町東漆山', '21', '21217', '5061216', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '神岡町東漆山', 'カミオカチョウヒガシウルシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市神岡町二ツ屋', '21', '21217', '5061217', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '神岡町二ツ屋', 'カミオカチョウフタツヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市上宝町葛山', '21', '21203', '5061301', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '上宝町葛山', 'カミタカラチョウクズヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市上宝町長倉', '21', '21203', '5061302', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '上宝町長倉', 'カミタカラチョウナガクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市上宝町岩井戸', '21', '21203', '5061303', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '上宝町岩井戸', 'カミタカラチョウイワイド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市上宝町宮原', '21', '21203', '5061304', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '上宝町宮原', 'カミタカラチョウミヤハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市上宝町中山', '21', '21203', '5061305', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '上宝町中山', 'カミタカラチョウナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市上宝町見座', '21', '21203', '5061306', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '上宝町見座', 'カミタカラチョウミザ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市上宝町双六', '21', '21203', '5061307', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '上宝町双六', 'カミタカラチョウスゴロク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市上宝町金木戸', '21', '21203', '5061308', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '上宝町金木戸', 'カミタカラチョウカナキド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市上宝町鼠餅', '21', '21203', '5061311', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '上宝町鼠餅', 'カミタカラチョウネズモチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市上宝町新田', '21', '21203', '5061312', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '上宝町新田', 'カミタカラチョウアラタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市上宝町在家', '21', '21203', '5061313', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '上宝町在家', 'カミタカラチョウザイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市上宝町蔵柱', '21', '21203', '5061314', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '上宝町蔵柱', 'カミタカラチョウクラバシラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市上宝町荒原', '21', '21203', '5061315', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '上宝町荒原', 'カミタカラチョウアラハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市上宝町吉野', '21', '21203', '5061316', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '上宝町吉野', 'カミタカラチョウヨシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市上宝町本郷', '21', '21203', '5061317', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '上宝町本郷', 'カミタカラチョウホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市上宝町芋生茂', '21', '21203', '5061318', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '上宝町芋生茂', 'カミタカラチョウオイモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市上宝町下佐谷', '21', '21203', '5061319', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '上宝町下佐谷', 'カミタカラチョウシモサダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市奥飛騨温泉郷神坂新穂高', '21', '21203', '5061421', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '奥飛騨温泉郷神坂', 'オクヒダオンセンゴウカンサカ', null, null, '新穂高', 'シンホダカ');
INSERT INTO `ms_addresses` VALUES ('53670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市奥飛騨温泉郷中尾', '21', '21203', '5061422', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '奥飛騨温泉郷中尾', 'オクヒダオンセンゴウナカオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市奥飛騨温泉郷栃尾', '21', '21203', '5061423', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '奥飛騨温泉郷栃尾', 'オクヒダオンセンゴウトチオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市奥飛騨温泉郷柏当', '21', '21203', '5061424', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '奥飛騨温泉郷柏当', 'オクヒダオンセンゴウカシアテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市奥飛騨温泉郷今見', '21', '21203', '5061425', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '奥飛騨温泉郷今見', 'オクヒダオンセンゴウイマミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市奥飛騨温泉郷蓼之俣', '21', '21203', '5061426', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '奥飛騨温泉郷蓼之俣', 'オクヒダオンセンゴウタテノマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市奥飛騨温泉郷田頃家', '21', '21203', '5061427', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '奥飛騨温泉郷田頃家', 'オクヒダオンセンゴウタゴロケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市奥飛騨温泉郷笹嶋', '21', '21203', '5061428', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '奥飛騨温泉郷笹嶋', 'オクヒダオンセンゴウササジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市奥飛騨温泉郷赤桶', '21', '21203', '5061429', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '奥飛騨温泉郷赤桶', 'オクヒダオンセンゴウアカオケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市奥飛騨温泉郷村上', '21', '21203', '5061431', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '奥飛騨温泉郷村上', 'オクヒダオンセンゴウムラカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市奥飛騨温泉郷一重ケ根', '21', '21203', '5061432', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '奥飛騨温泉郷一重ケ根', 'オクヒダオンセンゴウヒトエガネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市奥飛騨温泉郷平湯', '21', '21203', '5061433', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '奥飛騨温泉郷平湯', 'オクヒダオンセンゴウヒラユ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市奥飛騨温泉郷福地', '21', '21203', '5061434', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '奥飛騨温泉郷福地', 'オクヒダオンセンゴウフクジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市丹生川町森部', '21', '21203', '5062101', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '丹生川町森部', 'ニュウカワチョウモリブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市丹生川町折敷地', '21', '21203', '5062103', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '丹生川町折敷地', 'ニュウカワチョウオシキジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市丹生川町大沼', '21', '21203', '5062104', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '丹生川町大沼', 'ニュウカワチョウオオヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市丹生川町三之瀬', '21', '21203', '5062105', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '丹生川町三之瀬', 'ニュウカワチョウサンノセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市丹生川町柏原', '21', '21203', '5062106', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '丹生川町柏原', 'ニュウカワチョウカシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市丹生川町瓜田', '21', '21203', '5062111', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '丹生川町瓜田', 'ニュウカワチョウウリダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市丹生川町板殿', '21', '21203', '5062112', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '丹生川町板殿', 'ニュウカワチョウイタンド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市丹生川町芦谷', '21', '21203', '5062113', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '丹生川町芦谷', 'ニュウカワチョウアシタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市丹生川町日影', '21', '21203', '5062114', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '丹生川町日影', 'ニュウカワチョウヒカゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市丹生川町小野', '21', '21203', '5062115', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '丹生川町小野', 'ニュウカワチョウコノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市丹生川町大谷', '21', '21203', '5062116', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '丹生川町大谷', 'ニュウカワチョウオオタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市丹生川町根方', '21', '21203', '5062117', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '丹生川町根方', 'ニュウカワチョウゴンボウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市丹生川町白井', '21', '21203', '5062118', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '丹生川町白井', 'ニュウカワチョウシロイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市丹生川町坊方', '21', '21203', '5062121', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '丹生川町坊方', 'ニュウカワチョウボウカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市丹生川町山口', '21', '21203', '5062122', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '丹生川町山口', 'ニュウカワチョウヤマクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市丹生川町町方', '21', '21203', '5062123', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '丹生川町町方', 'ニュウカワチョウマチカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市丹生川町新張', '21', '21203', '5062124', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '丹生川町新張', 'ニュウカワチョウニイバリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市丹生川町細越', '21', '21203', '5062125', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '丹生川町細越', 'ニュウカワチョウホソゴエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市丹生川町大萱', '21', '21203', '5062131', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '丹生川町大萱', 'ニュウカワチョウオオガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市丹生川町法力', '21', '21203', '5062132', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '丹生川町法力', 'ニュウカワチョウホウリキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市丹生川町北方', '21', '21203', '5062133', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '丹生川町北方', 'ニュウカワチョウキタカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市丹生川町桐山', '21', '21203', '5062134', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '丹生川町桐山', 'ニュウカワチョウキリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市丹生川町下保', '21', '21203', '5062135', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '丹生川町下保', 'ニュウカワチョウシモボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市丹生川町旗鉾', '21', '21203', '5062251', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '丹生川町旗鉾', 'ニュウカワチョウハタホコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市丹生川町久手', '21', '21203', '5062252', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '丹生川町久手', 'ニュウカワチョウクテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市丹生川町池之俣', '21', '21203', '5062253', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '丹生川町池之俣', 'ニュウカワチョウイケノマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市丹生川町岩井谷', '21', '21203', '5062254', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '丹生川町岩井谷', 'ニュウカワチョウイワイタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市丹生川町駄吉', '21', '21203', '5062255', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '丹生川町駄吉', 'ニュウカワチョウダヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市丹生川町日面', '21', '21203', '5062256', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '丹生川町日面', 'ニュウカワチョウヒヨモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市丹生川町曽手', '21', '21203', '5062257', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '丹生川町曽手', 'ニュウカワチョウソデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市丹生川町塩屋', '21', '21203', '5062258', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '丹生川町塩屋', 'ニュウカワチョウシオヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市', '21', '21204', '5070000', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('53732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市小名田町小滝', '21', '21204', '5070001', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '小名田町小滝', 'オナダチョウコタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市小名田町別山', '21', '21204', '5070002', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '小名田町別山', 'オナダチョウハナレヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市小名田町東谷', '21', '21204', '5070003', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '小名田町東谷', 'オナダチョウヒガシダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市小名田町', '21', '21204', '5070004', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '小名田町', 'オナダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市小名田町岩ケ根', '21', '21204', '5070005', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '小名田町岩ケ根', 'オナダチョウイワガネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市小名田町西山', '21', '21204', '5070006', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '小名田町西山', 'オナダチョウニシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市小名田町西ケ洞', '21', '21204', '5070007', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '小名田町西ケ洞', 'オナダチョウニシガボラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市希望ケ丘', '21', '21204', '5070008', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '希望ケ丘', 'キボウガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市高田町岩曽根', '21', '21204', '5070011', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '高田町岩曽根', 'タカタチョウイワゾネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市高田町白粉', '21', '21204', '5070012', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '高田町白粉', 'タカタチョウシロコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市東栄町', '21', '21204', '5070013', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '東栄町', 'トウエイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市虎渓山町', '21', '21204', '5070014', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '虎渓山町', 'コケイザンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市住吉町', '21', '21204', '5070015', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '住吉町', 'スミヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市金岡町', '21', '21204', '5070016', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '金岡町', 'カナオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市長瀬町', '21', '21204', '5070017', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '長瀬町', 'ナガセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市高田町', '21', '21204', '5070018', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '高田町', 'タカタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市東山', '21', '21204', '5070019', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '東山', 'ヒガシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市緑ケ丘', '21', '21204', '5070021', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '緑ケ丘', 'ミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市上山町', '21', '21204', '5070022', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '上山町', 'カミヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市小田町', '21', '21204', '5070023', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '小田町', 'オダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市大正町', '21', '21204', '5070024', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '大正町', 'タイショウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市宮前町', '21', '21204', '5070025', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '宮前町', 'ミヤマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市虎渓町', '21', '21204', '5070026', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '虎渓町', 'コケイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市上野町', '21', '21204', '5070027', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '上野町', 'ウエノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市弁天町', '21', '21204', '5070028', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '弁天町', 'ベンテンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市精華町', '21', '21204', '5070031', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '精華町', 'セイカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市大日町', '21', '21204', '5070032', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '大日町', 'ダイニチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市本町', '21', '21204', '5070033', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市豊岡町', '21', '21204', '5070034', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '豊岡町', 'トヨオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市栄町', '21', '21204', '5070035', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市田代町', '21', '21204', '5070036', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '田代町', 'タシロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市音羽町', '21', '21204', '5070037', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '音羽町', 'オトワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市白山町', '21', '21204', '5070038', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '白山町', 'ハクサンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市十九田町', '21', '21204', '5070039', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '十九田町', 'ジュクタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市太平町', '21', '21204', '5070041', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '太平町', 'タイヘイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市前畑町', '21', '21204', '5070042', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '前畑町', 'マエバタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市月見町', '21', '21204', '5070043', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '月見町', 'ツキミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市諏訪町', '21', '21204', '5070044', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '諏訪町', 'スワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市三の倉町', '21', '21204', '5070045', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '三の倉町', 'サンノクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市廿原町', '21', '21204', '5070046', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '廿原町', 'ツヅハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市富士見町', '21', '21204', '5070047', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '富士見町', 'フジミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市池田町', '21', '21204', '5070048', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '池田町', 'イケダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市西坂町', '21', '21204', '5070051', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '西坂町', 'ニシザカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市光ケ丘', '21', '21204', '5070052', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '光ケ丘', 'ヒカリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市若松町', '21', '21204', '5070053', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '若松町', 'ワカマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市宝町', '21', '21204', '5070054', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '宝町', 'タカラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市喜多町', '21', '21204', '5070055', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '喜多町', 'キタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市美山町', '21', '21204', '5070056', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '美山町', 'ミヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市赤坂町', '21', '21204', '5070057', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '赤坂町', 'アカサカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市平井町', '21', '21204', '5070058', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '平井町', 'ヒライチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市姫町', '21', '21204', '5070061', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '姫町', 'ヒメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市大針町', '21', '21204', '5070062', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '大針町', 'オオハリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市松坂町', '21', '21204', '5070063', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '松坂町', 'マツサカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市北丘町', '21', '21204', '5070064', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '北丘町', 'キタオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市根本町', '21', '21204', '5070065', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '根本町', 'ネモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市西山町', '21', '21204', '5070066', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '西山町', 'ニシヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市北小木町', '21', '21204', '5070067', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '北小木町', 'キタオギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市大薮町', '21', '21204', '5070068', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '大薮町', 'オオヤブチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市旭ケ丘', '21', '21204', '5070071', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '旭ケ丘', 'アサヒガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市明和町', '21', '21204', '5070072', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '明和町', 'メイワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市小泉町', '21', '21204', '5070073', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '小泉町', 'コイズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市大原町', '21', '21204', '5070074', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '大原町', 'オオハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市大沢町', '21', '21204', '5070075', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '大沢町', 'オオサワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市昭栄町', '21', '21204', '5070076', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '昭栄町', 'ショウエイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市幸町', '21', '21204', '5070077', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市高根町', '21', '21204', '5070078', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '高根町', 'タカネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市東町', '21', '21204', '5070801', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '東町', 'ヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市山吹町', '21', '21204', '5070802', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '山吹町', 'ヤマブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市美坂町', '21', '21204', '5070803', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '美坂町', 'ミサカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市坂上町', '21', '21204', '5070804', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '坂上町', 'サカウエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市新富町', '21', '21204', '5070805', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '新富町', 'シントミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市上町', '21', '21204', '5070806', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '上町', 'カミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市生田町', '21', '21204', '5070807', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '生田町', 'イクタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市星ケ台', '21', '21204', '5070811', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '星ケ台', 'ホシガダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市下沢町', '21', '21204', '5070812', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '下沢町', 'シモザワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市滝呂町', '21', '21204', '5070813', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '滝呂町', 'タキロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市市之倉町', '21', '21204', '5070814', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '市之倉町', 'イチノクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市大畑町赤松', '21', '21204', '5070815', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '大畑町赤松', 'オオバタチョウアカマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市大畑町西仲根', '21', '21204', '5070816', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '大畑町西仲根', 'オオバタチョウニシナカネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市大畑町大洞', '21', '21204', '5070817', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '大畑町大洞', 'オオバタチョウオオボラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市大畑町', '21', '21204', '5070818', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '大畑町', 'オオバタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市窯町', '21', '21204', '5070821', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '窯町', 'カママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市奥川町', '21', '21204', '5070822', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '奥川町', 'オクガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市平野町', '21', '21204', '5070823', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '平野町', 'ヒラノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市元町', '21', '21204', '5070824', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '元町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市京町', '21', '21204', '5070825', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '京町', 'キョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市脇之島町', '21', '21204', '5070826', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '脇之島町', 'ワキノシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市平和町', '21', '21204', '5070827', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '平和町', 'ヘイワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市三笠町', '21', '21204', '5070828', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '三笠町', 'ミカサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市新町', '21', '21204', '5070831', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市金山町', '21', '21204', '5070832', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '金山町', 'カナヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市広小路', '21', '21204', '5070833', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '広小路', 'ヒロコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市御幸町', '21', '21204', '5070834', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '御幸町', 'ミユキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市錦町', '21', '21204', '5070835', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '錦町', 'ニシキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市昭和町', '21', '21204', '5070836', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '昭和町', 'ショウワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市青木町', '21', '21204', '5070837', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '青木町', 'アオキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市末広町', '21', '21204', '5070838', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '末広町', 'スエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市明治町', '21', '21204', '5070841', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '明治町', 'メイジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市中町', '21', '21204', '5070842', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '中町', 'ナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市常盤町', '21', '21204', '5070843', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '常盤町', 'トキワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市陶元町', '21', '21204', '5070844', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '陶元町', 'トウゲンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市山下町', '21', '21204', '5070845', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '山下町', 'ヤマシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市神楽町', '21', '21204', '5070846', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '神楽町', 'カグラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市小路町', '21', '21204', '5070847', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '小路町', 'ショウジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市日ノ出町', '21', '21204', '5070848', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '日ノ出町', 'ヒノデマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県多治見市笠原町', '21', '21204', '5070901', '岐阜県', 'ギフケン', '多治見市', 'タジミシ', '笠原町', 'カサハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県中津川市', '21', '21206', '5080000', '岐阜県', 'ギフケン', '中津川市', 'ナカツガワシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('53859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県中津川市中津川', '21', '21206', '5080001', '岐阜県', 'ギフケン', '中津川市', 'ナカツガワシ', '中津川', 'ナカツガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県中津川市阿木', '21', '21206', '5080002', '岐阜県', 'ギフケン', '中津川市', 'ナカツガワシ', '阿木', 'アギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県中津川市阿木川上', '21', '21206', '5080002', '岐阜県', 'ギフケン', '中津川市', 'ナカツガワシ', '阿木川上', 'アギカオレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県中津川市中一色町', '21', '21206', '5080003', '岐阜県', 'ギフケン', '中津川市', 'ナカツガワシ', '中一色町', 'ナカイッシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県中津川市花戸町', '21', '21206', '5080004', '岐阜県', 'ギフケン', '中津川市', 'ナカツガワシ', '花戸町', 'ハナドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県中津川市日の出町', '21', '21206', '5080005', '岐阜県', 'ギフケン', '中津川市', 'ナカツガワシ', '日の出町', 'ヒノデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県中津川市落合', '21', '21206', '5080006', '岐阜県', 'ギフケン', '中津川市', 'ナカツガワシ', '落合', 'オチアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県中津川市神坂', '21', '21206', '5080007', '岐阜県', 'ギフケン', '中津川市', 'ナカツガワシ', '神坂', 'ミサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県中津川市駒場', '21', '21206', '5080011', '岐阜県', 'ギフケン', '中津川市', 'ナカツガワシ', '駒場', 'コマンバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県中津川市津島町', '21', '21206', '5080012', '岐阜県', 'ギフケン', '中津川市', 'ナカツガワシ', '津島町', 'ツシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県中津川市柳町', '21', '21206', '5080013', '岐阜県', 'ギフケン', '中津川市', 'ナカツガワシ', '柳町', 'ヤナギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県中津川市駒場町', '21', '21206', '5080014', '岐阜県', 'ギフケン', '中津川市', 'ナカツガワシ', '駒場町', 'コマンバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県中津川市手賀野', '21', '21206', '5080015', '岐阜県', 'ギフケン', '中津川市', 'ナカツガワシ', '手賀野', 'テガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県中津川市中川町', '21', '21206', '5080021', '岐阜県', 'ギフケン', '中津川市', 'ナカツガワシ', '中川町', 'ナカガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県中津川市北野町', '21', '21206', '5080022', '岐阜県', 'ギフケン', '中津川市', 'ナカツガワシ', '北野町', 'キタノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県中津川市小川町', '21', '21206', '5080023', '岐阜県', 'ギフケン', '中津川市', 'ナカツガワシ', '小川町', 'オガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県中津川市桃山町', '21', '21206', '5080024', '岐阜県', 'ギフケン', '中津川市', 'ナカツガワシ', '桃山町', 'モモヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県中津川市宮前町', '21', '21206', '5080031', '岐阜県', 'ギフケン', '中津川市', 'ナカツガワシ', '宮前町', 'ミヤマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県中津川市栄町', '21', '21206', '5080032', '岐阜県', 'ギフケン', '中津川市', 'ナカツガワシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県中津川市太田町', '21', '21206', '5080033', '岐阜県', 'ギフケン', '中津川市', 'ナカツガワシ', '太田町', 'オオタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県中津川市淀川町', '21', '21206', '5080034', '岐阜県', 'ギフケン', '中津川市', 'ナカツガワシ', '淀川町', 'ヨドガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県中津川市東町', '21', '21206', '5080035', '岐阜県', 'ギフケン', '中津川市', 'ナカツガワシ', '東町', 'ヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県中津川市東宮町', '21', '21206', '5080036', '岐阜県', 'ギフケン', '中津川市', 'ナカツガワシ', '東宮町', 'ヒガシミヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県中津川市えびす町', '21', '21206', '5080037', '岐阜県', 'ギフケン', '中津川市', 'ナカツガワシ', 'えびす町', 'エビスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県中津川市新町', '21', '21206', '5080038', '岐阜県', 'ギフケン', '中津川市', 'ナカツガワシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県中津川市本町', '21', '21206', '5080041', '岐阜県', 'ギフケン', '中津川市', 'ナカツガワシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県中津川市西宮町', '21', '21206', '5080042', '岐阜県', 'ギフケン', '中津川市', 'ナカツガワシ', '西宮町', 'ニシミヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県中津川市八幡町', '21', '21206', '5080043', '岐阜県', 'ギフケン', '中津川市', 'ナカツガワシ', '八幡町', 'ハチマンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県中津川市昭和町', '21', '21206', '5080044', '岐阜県', 'ギフケン', '中津川市', 'ナカツガワシ', '昭和町', 'ショウワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県中津川市かやの木町', '21', '21206', '5080045', '岐阜県', 'ギフケン', '中津川市', 'ナカツガワシ', 'かやの木町', 'カヤノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市南区川沿1条', '01', '01106', '0050801', '北海道', 'ホッカイドウ', '札幌市南区', 'サッポロシミナミク', '川沿1条', 'カワゾエ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県中津川市苗木', '21', '21206', '5080101', '岐阜県', 'ギフケン', '中津川市', 'ナカツガワシ', '苗木', 'ナエギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県中津川市瀬戸', '21', '21206', '5080111', '岐阜県', 'ギフケン', '中津川市', 'ナカツガワシ', '瀬戸', 'セト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市南区川沿2条', '01', '01106', '0050802', '北海道', 'ホッカイドウ', '札幌市南区', 'サッポロシミナミク', '川沿2条', 'カワゾエ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県中津川市田瀬', '21', '21206', '5080201', '岐阜県', 'ギフケン', '中津川市', 'ナカツガワシ', '田瀬', 'タセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県中津川市下野', '21', '21206', '5080202', '岐阜県', 'ギフケン', '中津川市', 'ナカツガワシ', '下野', 'シモノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県中津川市福岡', '21', '21206', '5080203', '岐阜県', 'ギフケン', '中津川市', 'ナカツガワシ', '福岡', 'フクオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県中津川市高山', '21', '21206', '5080204', '岐阜県', 'ギフケン', '中津川市', 'ナカツガワシ', '高山', 'タカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市南区川沿3条', '01', '01106', '0050803', '北海道', 'ホッカイドウ', '札幌市南区', 'サッポロシミナミク', '川沿3条', 'カワゾエ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県中津川市付知町', '21', '21206', '5080351', '岐阜県', 'ギフケン', '中津川市', 'ナカツガワシ', '付知町', 'ツケチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市南区川沿4条', '01', '01106', '0050804', '北海道', 'ホッカイドウ', '札幌市南区', 'サッポロシミナミク', '川沿4条', 'カワゾエ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県中津川市加子母', '21', '21206', '5080421', '岐阜県', 'ギフケン', '中津川市', 'ナカツガワシ', '加子母', 'カシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市南区川沿5条', '01', '01106', '0050805', '北海道', 'ホッカイドウ', '札幌市南区', 'サッポロシミナミク', '川沿5条', 'カワゾエ05ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県中津川市山口', '21', '21206', '5080501', '岐阜県', 'ギフケン', '中津川市', 'ナカツガワシ', '山口', 'ヤマグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県中津川市馬籠', '21', '21206', '5080502', '岐阜県', 'ギフケン', '中津川市', 'ナカツガワシ', '馬籠', 'マゴメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市南区川沿6条', '01', '01106', '0050806', '北海道', 'ホッカイドウ', '札幌市南区', 'サッポロシミナミク', '川沿6条', 'カワゾエ06ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市南区川沿7条', '01', '01106', '0050807', '北海道', 'ホッカイドウ', '札幌市南区', 'サッポロシミナミク', '川沿7条', 'カワゾエ07ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市南区川沿8条', '01', '01106', '0050808', '北海道', 'ホッカイドウ', '札幌市南区', 'サッポロシミナミク', '川沿8条', 'カワゾエ08ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市南区川沿9条', '01', '01106', '0050809', '北海道', 'ホッカイドウ', '札幌市南区', 'サッポロシミナミク', '川沿9条', 'カワゾエ09ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市南区川沿10条', '01', '01106', '0050810', '北海道', 'ホッカイドウ', '札幌市南区', 'サッポロシミナミク', '川沿10条', 'カワゾエ10ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市南区川沿11条', '01', '01106', '0050811', '北海道', 'ホッカイドウ', '札幌市南区', 'サッポロシミナミク', '川沿11条', 'カワゾエ11ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市南区川沿12条', '01', '01106', '0050812', '北海道', 'ホッカイドウ', '札幌市南区', 'サッポロシミナミク', '川沿12条', 'カワゾエ12ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市南区川沿13条', '01', '01106', '0050813', '北海道', 'ホッカイドウ', '札幌市南区', 'サッポロシミナミク', '川沿13条', 'カワゾエ13ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市南区川沿14条', '01', '01106', '0050814', '北海道', 'ホッカイドウ', '札幌市南区', 'サッポロシミナミク', '川沿14条', 'カワゾエ14ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市南区川沿15条', '01', '01106', '0050815', '北海道', 'ホッカイドウ', '札幌市南区', 'サッポロシミナミク', '川沿15条', 'カワゾエ15ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市南区川沿16条', '01', '01106', '0050816', '北海道', 'ホッカイドウ', '札幌市南区', 'サッポロシミナミク', '川沿16条', 'カワゾエ16ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市南区川沿17条', '01', '01106', '0050817', '北海道', 'ホッカイドウ', '札幌市南区', 'サッポロシミナミク', '川沿17条', 'カワゾエ17ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市南区川沿18条', '01', '01106', '0050818', '北海道', 'ホッカイドウ', '札幌市南区', 'サッポロシミナミク', '川沿18条', 'カワゾエ18ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市南区南沢1条', '01', '01106', '0050821', '北海道', 'ホッカイドウ', '札幌市南区', 'サッポロシミナミク', '南沢1条', 'ミナミサワ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市南区南沢2条', '01', '01106', '0050822', '北海道', 'ホッカイドウ', '札幌市南区', 'サッポロシミナミク', '南沢2条', 'ミナミサワ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市南区南沢3条', '01', '01106', '0050823', '北海道', 'ホッカイドウ', '札幌市南区', 'サッポロシミナミク', '南沢3条', 'ミナミサワ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市南区南沢4条', '01', '01106', '0050824', '北海道', 'ホッカイドウ', '札幌市南区', 'サッポロシミナミク', '南沢4条', 'ミナミサワ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市南区南沢5条', '01', '01106', '0050825', '北海道', 'ホッカイドウ', '札幌市南区', 'サッポロシミナミク', '南沢5条', 'ミナミサワ05ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市南区南沢6条', '01', '01106', '0050826', '北海道', 'ホッカイドウ', '札幌市南区', 'サッポロシミナミク', '南沢6条', 'ミナミサワ06ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市南区南沢', '01', '01106', '0050827', '北海道', 'ホッカイドウ', '札幌市南区', 'サッポロシミナミク', '南沢', 'ミナミサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市南区砥石山', '01', '01106', '0050830', '北海道', 'ホッカイドウ', '札幌市南区', 'サッポロシミナミク', '砥石山', 'トイシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市南区中ノ沢', '01', '01106', '0050831', '北海道', 'ホッカイドウ', '札幌市南区', 'サッポロシミナミク', '中ノ沢', 'ナカノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市南区北ノ沢', '01', '01106', '0050832', '北海道', 'ホッカイドウ', '札幌市南区', 'サッポロシミナミク', '北ノ沢', 'キタノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市南区藤野', '01', '01106', '0050840', '北海道', 'ホッカイドウ', '札幌市南区', 'サッポロシミナミク', '藤野', 'フジノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市南区石山1条', '01', '01106', '0050841', '北海道', 'ホッカイドウ', '札幌市南区', 'サッポロシミナミク', '石山1条', 'イシヤマ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市南区石山2条', '01', '01106', '0050842', '北海道', 'ホッカイドウ', '札幌市南区', 'サッポロシミナミク', '石山2条', 'イシヤマ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市南区石山3条', '01', '01106', '0050843', '北海道', 'ホッカイドウ', '札幌市南区', 'サッポロシミナミク', '石山3条', 'イシヤマ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市南区石山4条', '01', '01106', '0050844', '北海道', 'ホッカイドウ', '札幌市南区', 'サッポロシミナミク', '石山4条', 'イシヤマ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市南区石山', '01', '01106', '0050849', '北海道', 'ホッカイドウ', '札幌市南区', 'サッポロシミナミク', '石山', 'イシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市南区石山東', '01', '01106', '0050850', '北海道', 'ホッカイドウ', '札幌市南区', 'サッポロシミナミク', '石山東', 'イシヤマヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市南区常盤1条', '01', '01106', '0050851', '北海道', 'ホッカイドウ', '札幌市南区', 'サッポロシミナミク', '常盤1条', 'トキワ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市南区常盤2条', '01', '01106', '0050852', '北海道', 'ホッカイドウ', '札幌市南区', 'サッポロシミナミク', '常盤2条', 'トキワ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市南区常盤3条', '01', '01106', '0050853', '北海道', 'ホッカイドウ', '札幌市南区', 'サッポロシミナミク', '常盤3条', 'トキワ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市南区常盤4条', '01', '01106', '0050854', '北海道', 'ホッカイドウ', '札幌市南区', 'サッポロシミナミク', '常盤4条', 'トキワ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市南区常盤5条', '01', '01106', '0050855', '北海道', 'ホッカイドウ', '札幌市南区', 'サッポロシミナミク', '常盤5条', 'トキワ05ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市南区常盤6条', '01', '01106', '0050856', '北海道', 'ホッカイドウ', '札幌市南区', 'サッポロシミナミク', '常盤6条', 'トキワ06ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市南区真駒内', '01', '01106', '0050861', '北海道', 'ホッカイドウ', '札幌市南区', 'サッポロシミナミク', '真駒内', 'マコマナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市南区滝野', '01', '01106', '0050862', '北海道', 'ホッカイドウ', '札幌市南区', 'サッポロシミナミク', '滝野', 'タキノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市南区常盤', '01', '01106', '0050863', '北海道', 'ホッカイドウ', '札幌市南区', 'サッポロシミナミク', '常盤', 'トキワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市南区芸術の森', '01', '01106', '0050864', '北海道', 'ホッカイドウ', '札幌市南区', 'サッポロシミナミク', '芸術の森', 'ゲイジュツノモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市南区常盤', '01', '01106', '0050865', '北海道', 'ホッカイドウ', '札幌市南区', 'サッポロシミナミク', '常盤', 'トキワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市須衛', '21', '21213', '5090101', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '須衛', 'スエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市各務車洞', '21', '21213', '5090102', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '各務車洞', 'カカミクルマホラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市各務東町', '21', '21213', '5090103', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '各務東町', 'カカミヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市各務おがせ町', '21', '21213', '5090104', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '各務おがせ町', 'カカミオガセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市各務山の前町', '21', '21213', '5090105', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '各務山の前町', 'カカミヤマノマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市各務西町', '21', '21213', '5090106', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '各務西町', 'カカミニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市各務船山町', '21', '21213', '5090107', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '各務船山町', 'カカミフナヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市須衛町', '21', '21213', '5090108', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '須衛町', 'スエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市テクノプラザ', '21', '21213', '5090109', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', 'テクノプラザ', 'テクノプラザ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市鵜沼', '21', '21213', '5090111', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '鵜沼', 'ウヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市緑苑北', '21', '21213', '5090112', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '緑苑北', 'リョクエンキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市緑苑東', '21', '21213', '5090113', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '緑苑東', 'リョクエンヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市緑苑中', '21', '21213', '5090114', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '緑苑中', 'リョクエンナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市緑苑南', '21', '21213', '5090115', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '緑苑南', 'リョクエンミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市緑苑西', '21', '21213', '5090116', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '緑苑西', 'リョクエンニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市鵜沼大安寺町', '21', '21213', '5090117', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '鵜沼大安寺町', 'ウヌマダイアンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市鵜沼台', '21', '21213', '5090121', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '鵜沼台', 'ウヌマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市新鵜沼台', '21', '21213', '5090122', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '新鵜沼台', 'シンウヌマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市鵜沼宝積寺町', '21', '21213', '5090123', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '鵜沼宝積寺町', 'ウヌマホウシャクジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市鵜沼山崎町', '21', '21213', '5090124', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '鵜沼山崎町', 'ウヌマヤマザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市鵜沼南町', '21', '21213', '5090125', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '鵜沼南町', 'ウヌマミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市鵜沼東町', '21', '21213', '5090126', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '鵜沼東町', 'ウヌマヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市つつじが丘', '21', '21213', '5090131', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', 'つつじが丘', 'ツツジガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市鵜沼西町', '21', '21213', '5090132', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '鵜沼西町', 'ウヌマニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市鵜沼古市場町', '21', '21213', '5090133', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '鵜沼古市場町', 'ウヌマフルイチバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市鵜沼真名越町', '21', '21213', '5090134', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '鵜沼真名越町', 'ウヌママナゴシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市鵜沼羽場町', '21', '21213', '5090135', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '鵜沼羽場町', 'ウヌマハバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市松が丘', '21', '21213', '5090136', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '松が丘', 'マツガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市鵜沼各務原町', '21', '21213', '5090141', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '鵜沼各務原町', 'ウヌマカカミガハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市鵜沼丸子町', '21', '21213', '5090142', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '鵜沼丸子町', 'ウヌママルコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市鵜沼小伊木町', '21', '21213', '5090143', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '鵜沼小伊木町', 'ウヌマコイギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市鵜沼大伊木町', '21', '21213', '5090144', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '鵜沼大伊木町', 'ウヌマオオイギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市鵜沼朝日町', '21', '21213', '5090145', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '鵜沼朝日町', 'ウヌマアサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('53999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市鵜沼三ツ池町', '21', '21213', '5090146', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '鵜沼三ツ池町', 'ウヌマミツイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県各務原市鵜沼川崎町', '21', '21213', '5090147', '岐阜県', 'ギフケン', '各務原市', 'カカミガハラシ', '鵜沼川崎町', 'ウヌマカワサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県可児市', '21', '21214', '5090200', '岐阜県', 'ギフケン', '可児市', 'カニシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('54004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県可児市川合', '21', '21214', '5090201', '岐阜県', 'ギフケン', '可児市', 'カニシ', '川合', 'カワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県可児市中恵土', '21', '21214', '5090202', '岐阜県', 'ギフケン', '可児市', 'カニシ', '中恵土', 'ナカエド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県可児市下恵土', '21', '21214', '5090203', '岐阜県', 'ギフケン', '可児市', 'カニシ', '下恵土', 'シモエド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県可児市禅台寺', '21', '21214', '5090204', '岐阜県', 'ギフケン', '可児市', 'カニシ', '禅台寺', 'ゼンダイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県可児市徳野南', '21', '21214', '5090205', '岐阜県', 'ギフケン', '可児市', 'カニシ', '徳野南', 'トクノミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県可児市土田', '21', '21214', '5090206', '岐阜県', 'ギフケン', '可児市', 'カニシ', '土田', 'ドタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県可児市今渡', '21', '21214', '5090207', '岐阜県', 'ギフケン', '可児市', 'カニシ', '今渡', 'イマワタリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県可児市川合北', '21', '21214', '5090208', '岐阜県', 'ギフケン', '可児市', 'カニシ', '川合北', 'カワイキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県可児市渕之上', '21', '21214', '5090211', '岐阜県', 'ギフケン', '可児市', 'カニシ', '渕之上', 'フチノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県可児市柿田', '21', '21214', '5090212', '岐阜県', 'ギフケン', '可児市', 'カニシ', '柿田', 'カキダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県可児市瀬田', '21', '21214', '5090213', '岐阜県', 'ギフケン', '可児市', 'カニシ', '瀬田', 'セタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県可児市広見', '21', '21214', '5090214', '岐阜県', 'ギフケン', '可児市', 'カニシ', '広見', 'ヒロミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県可児市石井', '21', '21214', '5090215', '岐阜県', 'ギフケン', '可児市', 'カニシ', '石井', 'イシイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県可児市石森', '21', '21214', '5090216', '岐阜県', 'ギフケン', '可児市', 'カニシ', '石森', 'イシモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県可児市平貝戸', '21', '21214', '5090217', '岐阜県', 'ギフケン', '可児市', 'カニシ', '平貝戸', 'ヒラガイト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県可児市松伏', '21', '21214', '5090218', '岐阜県', 'ギフケン', '可児市', 'カニシ', '松伏', 'マツブセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県可児市広眺ケ丘', '21', '21214', '5090221', '岐阜県', 'ギフケン', '可児市', 'カニシ', '広眺ケ丘', 'ヒロミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県可児市羽崎', '21', '21214', '5090222', '岐阜県', 'ギフケン', '可児市', 'カニシ', '羽崎', 'ハザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県可児市羽生ケ丘', '21', '21214', '5090223', '岐阜県', 'ギフケン', '可児市', 'カニシ', '羽生ケ丘', 'ハニュウガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県可児市久々利', '21', '21214', '5090224', '岐阜県', 'ギフケン', '可児市', 'カニシ', '久々利', 'ククリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県可児市星見台', '21', '21214', '5090230', '岐阜県', 'ギフケン', '可児市', 'カニシ', '星見台', 'ホシミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県可児市緑ケ丘', '21', '21214', '5090231', '岐阜県', 'ギフケン', '可児市', 'カニシ', '緑ケ丘', 'ミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県可児市二野', '21', '21214', '5090232', '岐阜県', 'ギフケン', '可児市', 'カニシ', '二野', 'ニノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県可児市柿下', '21', '21214', '5090233', '岐阜県', 'ギフケン', '可児市', 'カニシ', '柿下', 'カキシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県可児市久々利柿下入会', '21', '21214', '5090234', '岐阜県', 'ギフケン', '可児市', 'カニシ', '久々利柿下入会', 'ククリカキシタニュウカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県可児市桜ケ丘', '21', '21214', '5090235', '岐阜県', 'ギフケン', '可児市', 'カニシ', '桜ケ丘', 'サクラガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県可児市皐ケ丘', '21', '21214', '5090236', '岐阜県', 'ギフケン', '可児市', 'カニシ', '皐ケ丘', 'サツキガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県可児市桂ケ丘', '21', '21214', '5090237', '岐阜県', 'ギフケン', '可児市', 'カニシ', '桂ケ丘', 'カツラガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県可児市大森', '21', '21214', '5090238', '岐阜県', 'ギフケン', '可児市', 'カニシ', '大森', 'オオモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県可児市大森台', '21', '21214', '5090239', '岐阜県', 'ギフケン', '可児市', 'カニシ', '大森台', 'オオモリダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県可児市みずきケ丘', '21', '21214', '5090240', '岐阜県', 'ギフケン', '可児市', 'カニシ', 'みずきケ丘', 'ミズキガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県可児市坂戸', '21', '21214', '5090241', '岐阜県', 'ギフケン', '可児市', 'カニシ', '坂戸', 'サカド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県可児市谷迫間', '21', '21214', '5090242', '岐阜県', 'ギフケン', '可児市', 'カニシ', '谷迫間', 'ヤバサマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県可児市下切', '21', '21214', '5090245', '岐阜県', 'ギフケン', '可児市', 'カニシ', '下切', 'シモギリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県可児市今', '21', '21214', '5090246', '岐阜県', 'ギフケン', '可児市', 'カニシ', '今', 'イマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県可児市塩河', '21', '21214', '5090247', '岐阜県', 'ギフケン', '可児市', 'カニシ', '塩河', 'シュウガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県可児市清水ケ丘', '21', '21214', '5090248', '岐阜県', 'ギフケン', '可児市', 'カニシ', '清水ケ丘', 'シミズガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県可児市姫ケ丘', '21', '21214', '5090249', '岐阜県', 'ギフケン', '可児市', 'カニシ', '姫ケ丘', 'ヒメガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県可児市美里ケ丘', '21', '21214', '5090250', '岐阜県', 'ギフケン', '可児市', 'カニシ', '美里ケ丘', 'ミサトガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県可児市塩', '21', '21214', '5090251', '岐阜県', 'ギフケン', '可児市', 'カニシ', '塩', 'シオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県可児市矢戸', '21', '21214', '5090252', '岐阜県', 'ギフケン', '可児市', 'カニシ', '矢戸', 'ヤト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県可児市室原', '21', '21214', '5090253', '岐阜県', 'ギフケン', '可児市', 'カニシ', '室原', 'ムロハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県可児市長洞', '21', '21214', '5090254', '岐阜県', 'ギフケン', '可児市', 'カニシ', '長洞', 'ナガホラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県可児市光陽台', '21', '21214', '5090255', '岐阜県', 'ギフケン', '可児市', 'カニシ', '光陽台', 'コウヨウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県可児市東帷子', '21', '21214', '5090256', '岐阜県', 'ギフケン', '可児市', 'カニシ', '東帷子', 'ヒガシカタビラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県可児市長坂', '21', '21214', '5090257', '岐阜県', 'ギフケン', '可児市', 'カニシ', '長坂', 'ナガサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県可児市若葉台', '21', '21214', '5090258', '岐阜県', 'ギフケン', '可児市', 'カニシ', '若葉台', 'ワカバダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県可児市愛岐ケ丘', '21', '21214', '5090259', '岐阜県', 'ギフケン', '可児市', 'カニシ', '愛岐ケ丘', 'アイギガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県可児市虹ケ丘', '21', '21214', '5090261', '岐阜県', 'ギフケン', '可児市', 'カニシ', '虹ケ丘', 'ニジガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県可児市菅刈', '21', '21214', '5090262', '岐阜県', 'ギフケン', '可児市', 'カニシ', '菅刈', 'スゲカリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県可児市緑', '21', '21214', '5090263', '岐阜県', 'ギフケン', '可児市', 'カニシ', '緑', 'ミドリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県可児市鳩吹台', '21', '21214', '5090264', '岐阜県', 'ギフケン', '可児市', 'カニシ', '鳩吹台', 'ハトフキダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県可児市西帷子', '21', '21214', '5090265', '岐阜県', 'ギフケン', '可児市', 'カニシ', '西帷子', 'ニシカタビラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県可児市帷子新町', '21', '21214', '5090266', '岐阜県', 'ギフケン', '可児市', 'カニシ', '帷子新町', 'カタビラシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県加茂郡川辺町', '21', '21503', '5090300', '岐阜県', 'ギフケン', '加茂郡川辺町', 'カモグンカワベチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('54064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県加茂郡川辺町下麻生', '21', '21503', '5090301', '岐阜県', 'ギフケン', '加茂郡川辺町', 'カモグンカワベチョウ', '下麻生', 'シモアソウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県加茂郡川辺町上川辺', '21', '21503', '5090302', '岐阜県', 'ギフケン', '加茂郡川辺町', 'カモグンカワベチョウ', '上川辺', 'カミカワベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県加茂郡川辺町石神', '21', '21503', '5090303', '岐阜県', 'ギフケン', '加茂郡川辺町', 'カモグンカワベチョウ', '石神', 'イシガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県加茂郡川辺町中川辺', '21', '21503', '5090304', '岐阜県', 'ギフケン', '加茂郡川辺町', 'カモグンカワベチョウ', '中川辺', 'ナカカワベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県加茂郡川辺町西栃井', '21', '21503', '5090305', '岐阜県', 'ギフケン', '加茂郡川辺町', 'カモグンカワベチョウ', '西栃井', 'ニシトチイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県加茂郡川辺町下川辺', '21', '21503', '5090306', '岐阜県', 'ギフケン', '加茂郡川辺町', 'カモグンカワベチョウ', '下川辺', 'シモカワベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県加茂郡川辺町鹿塩', '21', '21503', '5090307', '岐阜県', 'ギフケン', '加茂郡川辺町', 'カモグンカワベチョウ', '鹿塩', 'カシオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県加茂郡川辺町下吉田', '21', '21503', '5090311', '岐阜県', 'ギフケン', '加茂郡川辺町', 'カモグンカワベチョウ', '下吉田', 'シモヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県加茂郡川辺町中野', '21', '21503', '5090312', '岐阜県', 'ギフケン', '加茂郡川辺町', 'カモグンカワベチョウ', '中野', 'ナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県加茂郡川辺町下飯田', '21', '21503', '5090313', '岐阜県', 'ギフケン', '加茂郡川辺町', 'カモグンカワベチョウ', '下飯田', 'シモイイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県加茂郡川辺町福島', '21', '21503', '5090314', '岐阜県', 'ギフケン', '加茂郡川辺町', 'カモグンカワベチョウ', '福島', 'フクシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県加茂郡川辺町比久見', '21', '21503', '5090315', '岐阜県', 'ギフケン', '加茂郡川辺町', 'カモグンカワベチョウ', '比久見', 'ヒクミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県加茂郡七宗町', '21', '21504', '5090400', '岐阜県', 'ギフケン', '加茂郡七宗町', 'カモグンヒチソウチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('54078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県加茂郡七宗町上麻生', '21', '21504', '5090401', '岐阜県', 'ギフケン', '加茂郡七宗町', 'カモグンヒチソウチョウ', '上麻生', 'カミアソウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県加茂郡七宗町川並', '21', '21504', '5090402', '岐阜県', 'ギフケン', '加茂郡七宗町', 'カモグンヒチソウチョウ', '川並', 'カワナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県加茂郡七宗町中麻生', '21', '21504', '5090403', '岐阜県', 'ギフケン', '加茂郡七宗町', 'カモグンヒチソウチョウ', '中麻生', 'ナカアソウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県加茂郡七宗町神渕', '21', '21504', '5090511', '岐阜県', 'ギフケン', '加茂郡七宗町', 'カモグンヒチソウチョウ', '神渕', 'カブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県加茂郡白川町', '21', '21506', '5091100', '岐阜県', 'ギフケン', '加茂郡白川町', 'カモグンシラカワチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('54084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県加茂郡白川町白山', '21', '21506', '5091101', '岐阜県', 'ギフケン', '加茂郡白川町', 'カモグンシラカワチョウ', '白山', 'シラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県加茂郡白川町中川', '21', '21506', '5091102', '岐阜県', 'ギフケン', '加茂郡白川町', 'カモグンシラカワチョウ', '中川', 'ナカガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県加茂郡白川町水戸野', '21', '21506', '5091103', '岐阜県', 'ギフケン', '加茂郡白川町', 'カモグンシラカワチョウ', '水戸野', 'ミドノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県加茂郡白川町和泉', '21', '21506', '5091104', '岐阜県', 'ギフケン', '加茂郡白川町', 'カモグンシラカワチョウ', '和泉', 'イズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県加茂郡白川町河岐', '21', '21506', '5091105', '岐阜県', 'ギフケン', '加茂郡白川町', 'カモグンシラカワチョウ', '河岐', 'カワマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県加茂郡白川町坂ノ東', '21', '21506', '5091106', '岐阜県', 'ギフケン', '加茂郡白川町', 'カモグンシラカワチョウ', '坂ノ東', 'サカノヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県加茂郡白川町河東', '21', '21506', '5091107', '岐阜県', 'ギフケン', '加茂郡白川町', 'カモグンシラカワチョウ', '河東', 'カトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県加茂郡白川町広野', '21', '21506', '5091108', '岐阜県', 'ギフケン', '加茂郡白川町', 'カモグンシラカワチョウ', '広野', 'ヒロノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県加茂郡白川町切井', '21', '21506', '5091111', '岐阜県', 'ギフケン', '加茂郡白川町', 'カモグンシラカワチョウ', '切井', 'キリイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県加茂郡白川町赤河', '21', '21506', '5091112', '岐阜県', 'ギフケン', '加茂郡白川町', 'カモグンシラカワチョウ', '赤河', 'アコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県加茂郡白川町三川', '21', '21506', '5091113', '岐阜県', 'ギフケン', '加茂郡白川町', 'カモグンシラカワチョウ', '三川', 'ミカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県加茂郡白川町上佐見', '21', '21506', '5091221', '岐阜県', 'ギフケン', '加茂郡白川町', 'カモグンシラカワチョウ', '上佐見', 'カミサミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県加茂郡白川町下佐見', '21', '21506', '5091222', '岐阜県', 'ギフケン', '加茂郡白川町', 'カモグンシラカワチョウ', '下佐見', 'シモサミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県加茂郡東白川村', '21', '21507', '5091300', '岐阜県', 'ギフケン', '加茂郡東白川村', 'カモグンヒガシシラカワムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('54100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県加茂郡東白川村越原', '21', '21507', '5091301', '岐阜県', 'ギフケン', '加茂郡東白川村', 'カモグンヒガシシラカワムラ', '越原', 'オッパラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県加茂郡東白川村神土', '21', '21507', '5091302', '岐阜県', 'ギフケン', '加茂郡東白川村', 'カモグンヒガシシラカワムラ', '神土', 'カンド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県加茂郡東白川村五加', '21', '21507', '5091303', '岐阜県', 'ギフケン', '加茂郡東白川村', 'カモグンヒガシシラカワムラ', '五加', 'ゴカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県加茂郡白川町黒川', '21', '21506', '5091431', '岐阜県', 'ギフケン', '加茂郡白川町', 'カモグンシラカワチョウ', '黒川', 'クロカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県下呂市金山町弓掛', '21', '21220', '5091601', '岐阜県', 'ギフケン', '下呂市', 'ゲロシ', '金山町弓掛', 'カナヤマチョウユガケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県下呂市金山町卯野原', '21', '21220', '5091602', '岐阜県', 'ギフケン', '下呂市', 'ゲロシ', '金山町卯野原', 'カナヤマチョウウノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県下呂市金山町岩瀬', '21', '21220', '5091603', '岐阜県', 'ギフケン', '下呂市', 'ゲロシ', '金山町岩瀬', 'カナヤマチョウイワセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県下呂市金山町東沓部', '21', '21220', '5091604', '岐阜県', 'ギフケン', '下呂市', 'ゲロシ', '金山町東沓部', 'カナヤマチョウヒガシクツベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県下呂市金山町戸部', '21', '21220', '5091605', '岐阜県', 'ギフケン', '下呂市', 'ゲロシ', '金山町戸部', 'カナヤマチョウトベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県下呂市金山町祖師野', '21', '21220', '5091606', '岐阜県', 'ギフケン', '下呂市', 'ゲロシ', '金山町祖師野', 'カナヤマチョウソシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県下呂市金山町乙原', '21', '21220', '5091607', '岐阜県', 'ギフケン', '下呂市', 'ゲロシ', '金山町乙原', 'カナヤマチョウオッパラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県下呂市金山町中切', '21', '21220', '5091611', '岐阜県', 'ギフケン', '下呂市', 'ゲロシ', '金山町中切', 'カナヤマチョウナカギリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県下呂市金山町福来', '21', '21220', '5091612', '岐阜県', 'ギフケン', '下呂市', 'ゲロシ', '金山町福来', 'カナヤマチョウフクライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県下呂市金山町中津原', '21', '21220', '5091613', '岐阜県', 'ギフケン', '下呂市', 'ゲロシ', '金山町中津原', 'カナヤマチョウナカツハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県下呂市金山町大船渡', '21', '21220', '5091614', '岐阜県', 'ギフケン', '下呂市', 'ゲロシ', '金山町大船渡', 'カナヤマチョウオオフナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県下呂市金山町田島', '21', '21220', '5091615', '岐阜県', 'ギフケン', '下呂市', 'ゲロシ', '金山町田島', 'カナヤマチョウタジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県下呂市金山町下原町', '21', '21220', '5091616', '岐阜県', 'ギフケン', '下呂市', 'ゲロシ', '金山町下原町', 'カナヤマチョウシモハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県下呂市金山町渡', '21', '21220', '5091621', '岐阜県', 'ギフケン', '下呂市', 'ゲロシ', '金山町渡', 'カナヤマチョウワタリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県下呂市金山町金山', '21', '21220', '5091622', '岐阜県', 'ギフケン', '下呂市', 'ゲロシ', '金山町金山', 'カナヤマチョウカナヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県下呂市金山町菅田桐洞', '21', '21220', '5091623', '岐阜県', 'ギフケン', '下呂市', 'ゲロシ', '金山町菅田桐洞', 'カナヤマチョウスガタキリホラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県下呂市金山町菅田笹洞', '21', '21220', '5091624', '岐阜県', 'ギフケン', '下呂市', 'ゲロシ', '金山町菅田笹洞', 'カナヤマチョウスガタササホラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県下呂市久野川', '21', '21220', '5092131', '岐阜県', 'ギフケン', '下呂市', 'ゲロシ', '久野川', 'クノガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県下呂市火打', '21', '21220', '5092132', '岐阜県', 'ギフケン', '下呂市', 'ゲロシ', '火打', 'ヒウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県下呂市和佐', '21', '21220', '5092133', '岐阜県', 'ギフケン', '下呂市', 'ゲロシ', '和佐', 'ワサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県下呂市焼石', '21', '21220', '5092134', '岐阜県', 'ギフケン', '下呂市', 'ゲロシ', '焼石', 'ヤケイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県下呂市三ツ渕', '21', '21220', '5092135', '岐阜県', 'ギフケン', '下呂市', 'ゲロシ', '三ツ渕', 'ミツブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県下呂市瀬戸', '21', '21220', '5092136', '岐阜県', 'ギフケン', '下呂市', 'ゲロシ', '瀬戸', 'セト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県下呂市保井戸', '21', '21220', '5092137', '岐阜県', 'ギフケン', '下呂市', 'ゲロシ', '保井戸', 'ホイド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県下呂市門原', '21', '21220', '5092138', '岐阜県', 'ギフケン', '下呂市', 'ゲロシ', '門原', 'カドハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県下呂市', '21', '21220', '5092200', '岐阜県', 'ギフケン', '下呂市', 'ゲロシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('54139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県下呂市東上田', '21', '21220', '5092201', '岐阜県', 'ギフケン', '下呂市', 'ゲロシ', '東上田', 'ヒガシウエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県下呂市森', '21', '21220', '5092202', '岐阜県', 'ギフケン', '下呂市', 'ゲロシ', '森', 'モリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県下呂市小川', '21', '21220', '5092203', '岐阜県', 'ギフケン', '下呂市', 'ゲロシ', '小川', 'オガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県下呂市三原', '21', '21220', '5092204', '岐阜県', 'ギフケン', '下呂市', 'ゲロシ', '三原', 'サンバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県下呂市少ケ野', '21', '21220', '5092205', '岐阜県', 'ギフケン', '下呂市', 'ゲロシ', '少ケ野', 'ショウガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県下呂市幸田', '21', '21220', '5092206', '岐阜県', 'ギフケン', '下呂市', 'ゲロシ', '幸田', 'コウデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県下呂市湯之島', '21', '21220', '5092207', '岐阜県', 'ギフケン', '下呂市', 'ゲロシ', '湯之島', 'ユノシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県下呂市乗政', '21', '21220', '5092311', '岐阜県', 'ギフケン', '下呂市', 'ゲロシ', '乗政', 'ノリマサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県下呂市御厩野', '21', '21220', '5092312', '岐阜県', 'ギフケン', '下呂市', 'ゲロシ', '御厩野', 'ミマヤノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県下呂市野尻', '21', '21220', '5092313', '岐阜県', 'ギフケン', '下呂市', 'ゲロシ', '野尻', 'ノジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県下呂市宮地', '21', '21220', '5092314', '岐阜県', 'ギフケン', '下呂市', 'ゲロシ', '宮地', 'ミヤジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県下呂市夏焼', '21', '21220', '5092421', '岐阜県', 'ギフケン', '下呂市', 'ゲロシ', '夏焼', 'ナツヤケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県下呂市田口', '21', '21220', '5092422', '岐阜県', 'ギフケン', '下呂市', 'ゲロシ', '田口', 'タグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県下呂市蛇之尾', '21', '21220', '5092423', '岐阜県', 'ギフケン', '下呂市', 'ゲロシ', '蛇之尾', 'ヘビノオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県下呂市門和佐', '21', '21220', '5092424', '岐阜県', 'ギフケン', '下呂市', 'ゲロシ', '門和佐', 'カドワサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県下呂市萩原町山之口', '21', '21220', '5092501', '岐阜県', 'ギフケン', '下呂市', 'ゲロシ', '萩原町山之口', 'ハギワラチョウヤマノクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県下呂市萩原町四美', '21', '21220', '5092502', '岐阜県', 'ギフケン', '下呂市', 'ゲロシ', '萩原町四美', 'ハギワラチョウシミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県下呂市萩原町西上田', '21', '21220', '5092503', '岐阜県', 'ギフケン', '下呂市', 'ゲロシ', '萩原町西上田', 'ハギワラチョウニシウエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県下呂市萩原町跡津', '21', '21220', '5092504', '岐阜県', 'ギフケン', '下呂市', 'ゲロシ', '萩原町跡津', 'ハギワラチョウアトツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県下呂市萩原町古関', '21', '21220', '5092505', '岐阜県', 'ギフケン', '下呂市', 'ゲロシ', '萩原町古関', 'ハギワラチョウフルセキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県下呂市萩原町羽根', '21', '21220', '5092506', '岐阜県', 'ギフケン', '下呂市', 'ゲロシ', '萩原町羽根', 'ハギワラチョウハネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県下呂市萩原町野上', '21', '21220', '5092507', '岐阜県', 'ギフケン', '下呂市', 'ゲロシ', '萩原町野上', 'ハギワラチョウノガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県下呂市萩原町尾崎', '21', '21220', '5092508', '岐阜県', 'ギフケン', '下呂市', 'ゲロシ', '萩原町尾崎', 'ハギワラチョウオサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県下呂市萩原町宮田', '21', '21220', '5092511', '岐阜県', 'ギフケン', '下呂市', 'ゲロシ', '萩原町宮田', 'ハギワラチョウミヤダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県下呂市萩原町大ケ洞', '21', '21220', '5092512', '岐阜県', 'ギフケン', '下呂市', 'ゲロシ', '萩原町大ケ洞', 'ハギワラチョウオオガホラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県下呂市萩原町桜洞', '21', '21220', '5092513', '岐阜県', 'ギフケン', '下呂市', 'ゲロシ', '萩原町桜洞', 'ハギワラチョウサクラボラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県下呂市萩原町中呂', '21', '21220', '5092514', '岐阜県', 'ギフケン', '下呂市', 'ゲロシ', '萩原町中呂', 'ハギワラチョウチュウロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県下呂市萩原町花池', '21', '21220', '5092515', '岐阜県', 'ギフケン', '下呂市', 'ゲロシ', '萩原町花池', 'ハギワラチョウハナイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県下呂市萩原町上村', '21', '21220', '5092516', '岐阜県', 'ギフケン', '下呂市', 'ゲロシ', '萩原町上村', 'ハギワラチョウウワムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県下呂市萩原町萩原', '21', '21220', '5092517', '岐阜県', 'ギフケン', '下呂市', 'ゲロシ', '萩原町萩原', 'ハギワラチョウハギワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県下呂市萩原町上呂', '21', '21220', '5092518', '岐阜県', 'ギフケン', '下呂市', 'ゲロシ', '萩原町上呂', 'ハギワラチョウジョウロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県下呂市萩原町奥田洞', '21', '21220', '5092519', '岐阜県', 'ギフケン', '下呂市', 'ゲロシ', '萩原町奥田洞', 'ハギワラチョウオクダボラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県下呂市馬瀬川上', '21', '21220', '5092601', '岐阜県', 'ギフケン', '下呂市', 'ゲロシ', '馬瀬川上', 'マゼカオレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県下呂市馬瀬黒石', '21', '21220', '5092602', '岐阜県', 'ギフケン', '下呂市', 'ゲロシ', '馬瀬黒石', 'マゼクロイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県下呂市馬瀬数河', '21', '21220', '5092603', '岐阜県', 'ギフケン', '下呂市', 'ゲロシ', '馬瀬数河', 'マゼスゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県下呂市馬瀬中切', '21', '21220', '5092604', '岐阜県', 'ギフケン', '下呂市', 'ゲロシ', '馬瀬中切', 'マゼナカギリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県下呂市馬瀬堀之内', '21', '21220', '5092611', '岐阜県', 'ギフケン', '下呂市', 'ゲロシ', '馬瀬堀之内', 'マゼホリノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県下呂市馬瀬名丸', '21', '21220', '5092612', '岐阜県', 'ギフケン', '下呂市', 'ゲロシ', '馬瀬名丸', 'マゼナマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県下呂市馬瀬井谷', '21', '21220', '5092613', '岐阜県', 'ギフケン', '下呂市', 'ゲロシ', '馬瀬井谷', 'マゼイダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県下呂市馬瀬惣島', '21', '21220', '5092614', '岐阜県', 'ギフケン', '下呂市', 'ゲロシ', '馬瀬惣島', 'マゼソウジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県下呂市馬瀬西村', '21', '21220', '5092615', '岐阜県', 'ギフケン', '下呂市', 'ゲロシ', '馬瀬西村', 'マゼニシムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市清見町楢谷', '21', '21203', '5092701', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '清見町楢谷', 'キヨミチョウナラダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市清見町大原', '21', '21203', '5092702', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '清見町大原', 'キヨミチョウオッパラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県下呂市小坂町岩崎', '21', '21220', '5093101', '岐阜県', 'ギフケン', '下呂市', 'ゲロシ', '小坂町岩崎', 'オサカチョウイワサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県下呂市小坂町門坂', '21', '21220', '5093102', '岐阜県', 'ギフケン', '下呂市', 'ゲロシ', '小坂町門坂', 'オサカチョウカドサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県下呂市小坂町大垣内', '21', '21220', '5093103', '岐阜県', 'ギフケン', '下呂市', 'ゲロシ', '小坂町大垣内', 'オサカチョウオオガイト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県下呂市小坂町小坂町', '21', '21220', '5093104', '岐阜県', 'ギフケン', '下呂市', 'ゲロシ', '小坂町小坂町', 'オサカチョウオサカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県下呂市小坂町坂下', '21', '21220', '5093105', '岐阜県', 'ギフケン', '下呂市', 'ゲロシ', '小坂町坂下', 'オサカチョウサコレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県下呂市小坂町大島', '21', '21220', '5093106', '岐阜県', 'ギフケン', '下呂市', 'ゲロシ', '小坂町大島', 'オサカチョウオオシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県下呂市小坂町無数原', '21', '21220', '5093107', '岐阜県', 'ギフケン', '下呂市', 'ゲロシ', '小坂町無数原', 'オサカチョウムスバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県下呂市小坂町落合', '21', '21220', '5093111', '岐阜県', 'ギフケン', '下呂市', 'ゲロシ', '小坂町落合', 'オサカチョウオチアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県下呂市小坂町大洞', '21', '21220', '5093112', '岐阜県', 'ギフケン', '下呂市', 'ゲロシ', '小坂町大洞', 'オサカチョウオオボラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県下呂市小坂町湯屋', '21', '21220', '5093113', '岐阜県', 'ギフケン', '下呂市', 'ゲロシ', '小坂町湯屋', 'オサカチョウユヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県下呂市小坂町赤沼田', '21', '21220', '5093114', '岐阜県', 'ギフケン', '下呂市', 'ゲロシ', '小坂町赤沼田', 'オサカチョウアカンタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県下呂市小坂町長瀬', '21', '21220', '5093115', '岐阜県', 'ギフケン', '下呂市', 'ゲロシ', '小坂町長瀬', 'オサカチョウナガセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市久々野町大西', '21', '21203', '5093201', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '久々野町大西', 'クグノチョウオオニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市久々野町小屋名', '21', '21203', '5093202', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '久々野町小屋名', 'クグノチョウコヤナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市久々野町柳島', '21', '21203', '5093203', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '久々野町柳島', 'クグノチョウヤナジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市久々野町久須母', '21', '21203', '5093204', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '久々野町久須母', 'クグノチョウクスモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市久々野町久々野', '21', '21203', '5093205', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '久々野町久々野', 'クグノチョウクグノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市久々野町山梨', '21', '21203', '5093206', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '久々野町山梨', 'クグノチョウヤマナシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市久々野町辻', '21', '21203', '5093207', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '久々野町辻', 'クグノチョウツジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市久々野町小坊', '21', '21203', '5093211', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '久々野町小坊', 'クグノチョウコボウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市久々野町阿多粕', '21', '21203', '5093212', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '久々野町阿多粕', 'クグノチョウアタガス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市久々野町渚', '21', '21203', '5093213', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '久々野町渚', 'クグノチョウナギサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市久々野町無数河', '21', '21203', '5093214', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '久々野町無数河', 'クグノチョウムスゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市久々野町引下', '21', '21203', '5093215', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '久々野町引下', 'クグノチョウヒキサゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市久々野町木賊洞', '21', '21203', '5093216', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '久々野町木賊洞', 'クグノチョウトクサボラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市久々野町長淀', '21', '21203', '5093217', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '久々野町長淀', 'クグノチョウナガトロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市久々野町有道', '21', '21203', '5093218', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '久々野町有道', 'クグノチョウウトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市朝日町青屋', '21', '21203', '5093301', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '朝日町青屋', 'アサヒチョウアオヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市朝日町寺附', '21', '21203', '5093302', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '朝日町寺附', 'アサヒチョウテラヅキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市朝日町浅井', '21', '21203', '5093303', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '朝日町浅井', 'アサヒチョウアサイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市朝日町立岩', '21', '21203', '5093304', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '朝日町立岩', 'アサヒチョウタテイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市朝日町小瀬', '21', '21203', '5093305', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '朝日町小瀬', 'アサヒチョウコセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市朝日町見座', '21', '21203', '5093306', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '朝日町見座', 'アサヒチョウミザ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市朝日町一之宿', '21', '21203', '5093311', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '朝日町一之宿', 'アサヒチョウイチノシュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市朝日町桑之島', '21', '21203', '5093312', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '朝日町桑之島', 'アサヒチョウクワノシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市朝日町胡桃島', '21', '21203', '5093313', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '朝日町胡桃島', 'アサヒチョウクルミシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市朝日町西洞スズラン高原', '21', '21203', '5093314', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '朝日町西洞', 'アサヒチョウニシボラ', null, null, 'スズラン高原', 'スズランコウゲン');
INSERT INTO `ms_addresses` VALUES ('54228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市朝日町宮之前', '21', '21203', '5093315', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '朝日町宮之前', 'アサヒチョウミヤノマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市朝日町黍生谷', '21', '21203', '5093316', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '朝日町黍生谷', 'アサヒチョウキビュウダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市朝日町小瀬ケ洞', '21', '21203', '5093317', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '朝日町小瀬ケ洞', 'アサヒチョウコセガホラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市朝日町黒川', '21', '21203', '5093321', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '朝日町黒川', 'アサヒチョウクロカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市朝日町大廣', '21', '21203', '5093322', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '朝日町大廣', 'アサヒチョウオオヒロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市朝日町寺澤', '21', '21203', '5093323', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '朝日町寺澤', 'アサヒチョウテラザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市朝日町上ケ見', '21', '21203', '5093324', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '朝日町上ケ見', 'アサヒチョウアゲミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市朝日町万石', '21', '21203', '5093325', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '朝日町万石', 'アサヒチョウマンゴク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市朝日町甲', '21', '21203', '5093326', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '朝日町甲', 'アサヒチョウカブト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市朝日町小谷', '21', '21203', '5093327', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '朝日町小谷', 'アサヒチョウコダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市高根町阿多野郷', '21', '21203', '5093401', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '高根町阿多野郷', 'タカネマチアタノゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市高根町野麦', '21', '21203', '5093402', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '高根町野麦', 'タカネマチノムギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市高根町日和田', '21', '21203', '5093403', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '高根町日和田', 'タカネマチヒワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市高根町小日和田', '21', '21203', '5093404', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '高根町小日和田', 'タカネマチコヒワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市高根町留之原', '21', '21203', '5093405', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '高根町留之原', 'タカネマチトメノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市高根町上ケ洞', '21', '21203', '5093411', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '高根町上ケ洞', 'タカネマチカミガホラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市高根町大古井', '21', '21203', '5093412', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '高根町大古井', 'タカネマチオオブルイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市高根町下之向', '21', '21203', '5093413', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '高根町下之向', 'タカネマチシモノムカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市高根町中之宿', '21', '21203', '5093414', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '高根町中之宿', 'タカネマチナカノシュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市高根町猪之鼻', '21', '21203', '5093415', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '高根町猪之鼻', 'タカネマチイノハナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市高根町中洞', '21', '21203', '5093416', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '高根町中洞', 'タカネマチナカボラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市高根町池ケ洞', '21', '21203', '5093417', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '高根町池ケ洞', 'タカネマチイケガホラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市高根町黍生', '21', '21203', '5093418', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '高根町黍生', 'タカネマチキビュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市高根町日影', '21', '21203', '5093419', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '高根町日影', 'タカネマチヒカゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市一之宮町', '21', '21203', '5093505', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '一之宮町', 'イチノミヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市国府町桐谷', '21', '21203', '5094101', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '国府町桐谷', 'コクフチョウキリダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市国府町八日町', '21', '21203', '5094102', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '国府町八日町', 'コクフチョウヨウカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市国府町宮地', '21', '21203', '5094103', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '国府町宮地', 'コクフチョウミヤジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市国府町今', '21', '21203', '5094104', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '国府町今', 'コクフチョウイマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市国府町蓑輪', '21', '21203', '5094105', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '国府町蓑輪', 'コクフチョウミノワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市国府町漆垣内', '21', '21203', '5094106', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '国府町漆垣内', 'コクフチョウウルシガイト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市国府町西門前', '21', '21203', '5094107', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '国府町西門前', 'コクフチョウニシモンゼン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市国府町東門前', '21', '21203', '5094108', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '国府町東門前', 'コクフチョウヒガシモンゼン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市国府町山本', '21', '21203', '5094111', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '国府町山本', 'コクフチョウヤマモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市国府町鶴巣', '21', '21203', '5094112', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '国府町鶴巣', 'コクフチョウツルス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市国府町木曽垣内', '21', '21203', '5094113', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '国府町木曽垣内', 'コクフチョウキソガイト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市国府町半田', '21', '21203', '5094114', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '国府町半田', 'コクフチョウハンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市国府町三日町', '21', '21203', '5094115', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '国府町三日町', 'コクフチョウミッカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市国府町上広瀬', '21', '21203', '5094116', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '国府町上広瀬', 'コクフチョウカミヒロセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市国府町三川', '21', '21203', '5094117', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '国府町三川', 'コクフチョウサンガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市国府町広瀬町桜野', '21', '21203', '5094119', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '国府町広瀬町', 'コクフチョウヒロセマチ', null, null, '桜野', 'サクラノ');
INSERT INTO `ms_addresses` VALUES ('54269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市国府町宇津江', '21', '21203', '5094121', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '国府町宇津江', 'コクフチョウウツエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市国府町名張', '21', '21203', '5094122', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '国府町名張', 'コクフチョウナバリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市国府町金桶', '21', '21203', '5094123', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '国府町金桶', 'コクフチョウカネオケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市国府町村山', '21', '21203', '5094124', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '国府町村山', 'コクフチョウムラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市国府町糠塚', '21', '21203', '5094125', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '国府町糠塚', 'コクフチョウヌカヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県高山市国府町瓜巣', '21', '21203', '5094126', '岐阜県', 'ギフケン', '高山市', 'タカヤマシ', '国府町瓜巣', 'コクフチョウウリス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市古川町数河', '21', '21217', '5094201', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '古川町数河', 'フルカワチョウスゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市古川町戸市', '21', '21217', '5094202', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '古川町戸市', 'フルカワチョウトイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市古川町袈裟丸', '21', '21217', '5094203', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '古川町袈裟丸', 'フルカワチョウケサマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市古川町野口', '21', '21217', '5094204', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '古川町野口', 'フルカワチョウノグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市古川町末真', '21', '21217', '5094205', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '古川町末真', 'フルカワチョウスエザネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市古川町太江', '21', '21217', '5094211', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '古川町太江', 'フルカワチョウタイエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市古川町上気多', '21', '21217', '5094212', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '古川町上気多', 'フルカワチョウカミキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市古川町下気多', '21', '21217', '5094213', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '古川町下気多', 'フルカワチョウシモキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市古川町沼町', '21', '21217', '5094214', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '古川町沼町', 'フルカワチョウヌママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市古川町杉崎', '21', '21217', '5094215', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '古川町杉崎', 'フルカワチョウスギサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市古川町若宮', '21', '21217', '5094221', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '古川町若宮', 'フルカワチョウワカミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市古川町片原町', '21', '21217', '5094222', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '古川町片原町', 'フルカワチョウカタハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市古川町東町', '21', '21217', '5094223', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '古川町東町', 'フルカワチョウヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市古川町殿町', '21', '21217', '5094224', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '古川町殿町', 'フルカワチョウトノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市古川町金森町', '21', '21217', '5094225', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '古川町金森町', 'フルカワチョウカナモリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市古川町新栄町', '21', '21217', '5094231', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '古川町新栄町', 'フルカワチョウシンサカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市古川町本町', '21', '21217', '5094232', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '古川町本町', 'フルカワチョウホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市古川町末広町', '21', '21217', '5094233', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '古川町末広町', 'フルカワチョウスエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市古川町壱之町', '21', '21217', '5094234', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '古川町壱之町', 'フルカワチョウイチノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市古川町弐之町', '21', '21217', '5094235', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '古川町弐之町', 'フルカワチョウニノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市古川町三之町', '21', '21217', '5094236', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '古川町三之町', 'フルカワチョウサンノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市古川町栄', '21', '21217', '5094237', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '古川町栄', 'フルカワチョウサカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市古川町向町', '21', '21217', '5094241', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '古川町向町', 'フルカワチョウムカイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市古川町増島町', '21', '21217', '5094242', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '古川町増島町', 'フルカワチョウマスシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市古川町貴船町', '21', '21217', '5094243', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '古川町貴船町', 'フルカワチョウキフネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市古川町是重', '21', '21217', '5094244', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '古川町是重', 'フルカワチョウコレシゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市古川町幸栄町', '21', '21217', '5094245', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '古川町幸栄町', 'フルカワチョウコウエイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市古川町宮城町', '21', '21217', '5094251', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '古川町宮城町', 'フルカワチョウミヤギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市古川町朝開町', '21', '21217', '5094252', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '古川町朝開町', 'フルカワチョウアサビラキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市古川町南成町', '21', '21217', '5094253', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '古川町南成町', 'フルカワチョウナンセイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市古川町上町', '21', '21217', '5094254', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '古川町上町', 'フルカワチョウカンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市古川町大野町', '21', '21217', '5094255', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '古川町大野町', 'フルカワチョウオオノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市古川町高野', '21', '21217', '5094256', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '古川町高野', 'フルカワチョウタカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市古川町下野', '21', '21217', '5094261', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '古川町下野', 'フルカワチョウシモノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市古川町中野', '21', '21217', '5094262', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '古川町中野', 'フルカワチョウナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市古川町上野', '21', '21217', '5094263', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '古川町上野', 'フルカワチョウカミノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市古川町平岩', '21', '21217', '5094264', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '古川町平岩', 'フルカワチョウヒライワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市古川町畦畑', '21', '21217', '5094265', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '古川町畦畑', 'フルカワチョウウネハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市古川町谷', '21', '21217', '5094271', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '古川町谷', 'フルカワチョウタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市古川町信包', '21', '21217', '5094272', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '古川町信包', 'フルカワチョウノブカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市古川町寺地', '21', '21217', '5094273', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '古川町寺地', 'フルカワチョウテラジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市古川町笹ケ洞', '21', '21217', '5094274', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '古川町笹ケ洞', 'フルカワチョウササガホラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市古川町黒内', '21', '21217', '5094275', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '古川町黒内', 'フルカワチョウクロウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市河合町角川', '21', '21217', '5094301', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '河合町角川', 'カワイチョウツノガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市河合町小無雁', '21', '21217', '5094302', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '河合町小無雁', 'カワイチョウコムカリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市河合町有家', '21', '21217', '5094303', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '河合町有家', 'カワイチョウウケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市河合町羽根', '21', '21217', '5094304', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '河合町羽根', 'カワイチョウハネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市河合町保木林', '21', '21217', '5094305', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '河合町保木林', 'カワイチョウホキバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市河合町中沢上', '21', '21217', '5094306', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '河合町中沢上', 'カワイチョウナカゾウレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市河合町大谷', '21', '21217', '5094311', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '河合町大谷', 'カワイチョウオオタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市河合町稲越', '21', '21217', '5094312', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '河合町稲越', 'カワイチョウイナゴエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市河合町保', '21', '21217', '5094313', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '河合町保', 'カワイチョウホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市河合町月ケ瀬', '21', '21217', '5094314', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '河合町月ケ瀬', 'カワイチョウツキガセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市河合町天生', '21', '21217', '5094315', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '河合町天生', 'カワイチョウアモウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市河合町元田', '21', '21217', '5094316', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '河合町元田', 'カワイチョウゲンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市河合町上ケ島', '21', '21217', '5094317', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '河合町上ケ島', 'カワイチョウジョウガシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市河合町新名', '21', '21217', '5094318', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '河合町新名', 'カワイチョウシンミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市宮川町菅沼', '21', '21217', '5094401', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '宮川町菅沼', 'ミヤガワチョウスガヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市宮川町種蔵', '21', '21217', '5094402', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '宮川町種蔵', 'ミヤガワチョウタネクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市宮川町三川原', '21', '21217', '5094403', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '宮川町三川原', 'ミヤガワチョウサンガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市宮川町巣之内', '21', '21217', '5094404', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '宮川町巣之内', 'ミヤガワチョウスノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市宮川町丸山', '21', '21217', '5094405', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '宮川町丸山', 'ミヤガワチョウマルヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市宮川町牧戸', '21', '21217', '5094406', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '宮川町牧戸', 'ミヤガワチョウマキド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市宮川町野首', '21', '21217', '5094411', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '宮川町野首', 'ミヤガワチョウノクビ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市宮川町岸奥', '21', '21217', '5094412', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '宮川町岸奥', 'ミヤガワチョウキシオク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市宮川町小谷', '21', '21217', '5094413', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '宮川町小谷', 'ミヤガワチョウコダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市宮川町大無雁', '21', '21217', '5094414', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '宮川町大無雁', 'ミヤガワチョウオオムカリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市宮川町落合', '21', '21217', '5094415', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '宮川町落合', 'ミヤガワチョウオチアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市宮川町高牧', '21', '21217', '5094421', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '宮川町高牧', 'ミヤガワチョウタカマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市宮川町西忍', '21', '21217', '5094422', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '宮川町西忍', 'ミヤガワチョウニシシノビ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市宮川町林', '21', '21217', '5094423', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '宮川町林', 'ミヤガワチョウハヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市宮川町森安', '21', '21217', '5094424', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '宮川町森安', 'ミヤガワチョウモリヤス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市宮川町鮎飛', '21', '21217', '5094531', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '宮川町鮎飛', 'ミヤガワチョウアユトビ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市宮川町巣納谷', '21', '21217', '5094531', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '宮川町巣納谷', 'ミヤガワチョウスノダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市宮川町洞', '21', '21217', '5094532', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '宮川町洞', 'ミヤガワチョウホラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市宮川町塩屋', '21', '21217', '5094533', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '宮川町塩屋', 'ミヤガワチョウシオヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市宮川町中沢上', '21', '21217', '5094534', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '宮川町中沢上', 'ミヤガワチョウナカゾレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市宮川町祢宜ケ沢上', '21', '21217', '5094535', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '宮川町祢宜ケ沢上', 'ミヤガワチョウネガソレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市宮川町小豆沢', '21', '21217', '5094541', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '宮川町小豆沢', 'ミヤガワチョウアズキザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市宮川町杉原', '21', '21217', '5094542', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '宮川町杉原', 'ミヤガワチョウスギハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市宮川町桑野', '21', '21217', '5094543', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '宮川町桑野', 'ミヤガワチョウクワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市宮川町戸谷', '21', '21217', '5094544', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '宮川町戸谷', 'ミヤガワチョウトダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県飛騨市宮川町打保', '21', '21217', '5094545', '岐阜県', 'ギフケン', '飛騨市', 'ヒダシ', '宮川町打保', 'ミヤガワチョウウツボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県土岐市', '21', '21212', '5095100', '岐阜県', 'ギフケン', '土岐市', 'トキシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('54362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県土岐市泉町河合', '21', '21212', '5095101', '岐阜県', 'ギフケン', '土岐市', 'トキシ', '泉町河合', 'イズミチョウカワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県土岐市泉町定林寺', '21', '21212', '5095102', '岐阜県', 'ギフケン', '土岐市', 'トキシ', '泉町定林寺', 'イズミチョウジョウリンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県土岐市泉東窯町', '21', '21212', '5095103', '岐阜県', 'ギフケン', '土岐市', 'トキシ', '泉東窯町', 'イズミヒガシガマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県土岐市泉中窯町', '21', '21212', '5095104', '岐阜県', 'ギフケン', '土岐市', 'トキシ', '泉中窯町', 'イズミナカガマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県土岐市泉西窯町', '21', '21212', '5095105', '岐阜県', 'ギフケン', '土岐市', 'トキシ', '泉西窯町', 'イズミニシガマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県土岐市泉仲森町', '21', '21212', '5095106', '岐阜県', 'ギフケン', '土岐市', 'トキシ', '泉仲森町', 'イズミナカモリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県土岐市泉梅ノ木町', '21', '21212', '5095107', '岐阜県', 'ギフケン', '土岐市', 'トキシ', '泉梅ノ木町', 'イズミウメノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県土岐市肥田浅野双葉町', '21', '21212', '5095111', '岐阜県', 'ギフケン', '土岐市', 'トキシ', '肥田浅野双葉町', 'ヒダアサノフタバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県土岐市肥田浅野笠神町', '21', '21212', '5095112', '岐阜県', 'ギフケン', '土岐市', 'トキシ', '肥田浅野笠神町', 'ヒダアサノカサガミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県土岐市肥田浅野元町', '21', '21212', '5095113', '岐阜県', 'ギフケン', '土岐市', 'トキシ', '肥田浅野元町', 'ヒダアサノモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県土岐市肥田町浅野', '21', '21212', '5095114', '岐阜県', 'ギフケン', '土岐市', 'トキシ', '肥田町浅野', 'ヒダチョウアサノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県土岐市肥田町肥田', '21', '21212', '5095115', '岐阜県', 'ギフケン', '土岐市', 'トキシ', '肥田町肥田', 'ヒダチョウヒダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県土岐市肥田浅野矢落町', '21', '21212', '5095116', '岐阜県', 'ギフケン', '土岐市', 'トキシ', '肥田浅野矢落町', 'ヒダアサノヤオチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県土岐市肥田浅野朝日町', '21', '21212', '5095117', '岐阜県', 'ギフケン', '土岐市', 'トキシ', '肥田浅野朝日町', 'ヒダアサノアサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県土岐市肥田浅野梅ノ木町', '21', '21212', '5095118', '岐阜県', 'ギフケン', '土岐市', 'トキシ', '肥田浅野梅ノ木町', 'ヒダアサノウメノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県土岐市土岐津町高山', '21', '21212', '5095121', '岐阜県', 'ギフケン', '土岐市', 'トキシ', '土岐津町高山', 'トキツチョウタカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県土岐市土岐津町土岐口', '21', '21212', '5095122', '岐阜県', 'ギフケン', '土岐市', 'トキシ', '土岐津町土岐口', 'トキツチョウトキグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県土岐市土岐口南町', '21', '21212', '5095123', '岐阜県', 'ギフケン', '土岐市', 'トキシ', '土岐口南町', 'トキグチミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県土岐市土岐口中町', '21', '21212', '5095124', '岐阜県', 'ギフケン', '土岐市', 'トキシ', '土岐口中町', 'トキグチナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県土岐市御幸町', '21', '21212', '5095125', '岐阜県', 'ギフケン', '土岐市', 'トキシ', '御幸町', 'ミユキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県土岐市土岐口北町', '21', '21212', '5095126', '岐阜県', 'ギフケン', '土岐市', 'トキシ', '土岐口北町', 'トキグチキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県土岐市土岐ヶ丘', '21', '21212', '5095127', '岐阜県', 'ギフケン', '土岐市', 'トキシ', '土岐ヶ丘', 'トキガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県土岐市泉寺田町', '21', '21212', '5095131', '岐阜県', 'ギフケン', '土岐市', 'トキシ', '泉寺田町', 'イズミテラダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県土岐市泉町大富', '21', '21212', '5095132', '岐阜県', 'ギフケン', '土岐市', 'トキシ', '泉町大富', 'イズミチョウオオトミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県土岐市泉神栄町', '21', '21212', '5095133', '岐阜県', 'ギフケン', '土岐市', 'トキシ', '泉神栄町', 'イズミシンエイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県土岐市泉島田町', '21', '21212', '5095134', '岐阜県', 'ギフケン', '土岐市', 'トキシ', '泉島田町', 'イズミシマダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県土岐市泉森下町', '21', '21212', '5095135', '岐阜県', 'ギフケン', '土岐市', 'トキシ', '泉森下町', 'イズミモリシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県土岐市泉大島町', '21', '21212', '5095136', '岐阜県', 'ギフケン', '土岐市', 'トキシ', '泉大島町', 'イズミオオシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県土岐市泉岩畑町', '21', '21212', '5095141', '岐阜県', 'ギフケン', '土岐市', 'トキシ', '泉岩畑町', 'イズミイワバタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県土岐市泉町久尻', '21', '21212', '5095142', '岐阜県', 'ギフケン', '土岐市', 'トキシ', '泉町久尻', 'イズミチョウクジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県土岐市泉日の出町', '21', '21212', '5095143', '岐阜県', 'ギフケン', '土岐市', 'トキシ', '泉日の出町', 'イズミヒノデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県土岐市泉池ノ上町', '21', '21212', '5095144', '岐阜県', 'ギフケン', '土岐市', 'トキシ', '泉池ノ上町', 'イズミイケノウエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県土岐市泉大沼町', '21', '21212', '5095145', '岐阜県', 'ギフケン', '土岐市', 'トキシ', '泉大沼町', 'イズミオオヌマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県土岐市泉明治町', '21', '21212', '5095146', '岐阜県', 'ギフケン', '土岐市', 'トキシ', '泉明治町', 'イズミメイジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県土岐市泉郷町', '21', '21212', '5095147', '岐阜県', 'ギフケン', '土岐市', 'トキシ', '泉郷町', 'イズミゴウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県土岐市泉大坪町', '21', '21212', '5095151', '岐阜県', 'ギフケン', '土岐市', 'トキシ', '泉大坪町', 'イズミオオツボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県土岐市泉寺下町', '21', '21212', '5095152', '岐阜県', 'ギフケン', '土岐市', 'トキシ', '泉寺下町', 'イズミテラシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県土岐市泉西原町', '21', '21212', '5095153', '岐阜県', 'ギフケン', '土岐市', 'トキシ', '泉西原町', 'イズミニシハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県土岐市泉西山町', '21', '21212', '5095154', '岐阜県', 'ギフケン', '土岐市', 'トキシ', '泉西山町', 'イズミニシヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県土岐市泉が丘町', '21', '21212', '5095161', '岐阜県', 'ギフケン', '土岐市', 'トキシ', '泉が丘町', 'イズミガオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県土岐市泉北山町', '21', '21212', '5095171', '岐阜県', 'ギフケン', '土岐市', 'トキシ', '泉北山町', 'イズミキタヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県土岐市下石阿庄町', '21', '21212', '5095201', '岐阜県', 'ギフケン', '土岐市', 'トキシ', '下石阿庄町', 'オロシアショウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県土岐市下石町', '21', '21212', '5095202', '岐阜県', 'ギフケン', '土岐市', 'トキシ', '下石町', 'オロシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県土岐市下石陶史台', '21', '21212', '5095203', '岐阜県', 'ギフケン', '土岐市', 'トキシ', '下石陶史台', 'オロシトウシダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県土岐市妻木町', '21', '21212', '5095301', '岐阜県', 'ギフケン', '土岐市', 'トキシ', '妻木町', 'ツマギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県土岐市妻木平成町', '21', '21212', '5095302', '岐阜県', 'ギフケン', '土岐市', 'トキシ', '妻木平成町', 'ツマギヘイセイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県土岐市鶴里町細野', '21', '21212', '5095311', '岐阜県', 'ギフケン', '土岐市', 'トキシ', '鶴里町細野', 'ツルサトチョウホソノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県土岐市鶴里町柿野', '21', '21212', '5095312', '岐阜県', 'ギフケン', '土岐市', 'トキシ', '鶴里町柿野', 'ツルサトチョウカキノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県土岐市駄知町', '21', '21212', '5095401', '岐阜県', 'ギフケン', '土岐市', 'トキシ', '駄知町', 'ダチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県土岐市曽木町', '21', '21212', '5095402', '岐阜県', 'ギフケン', '土岐市', 'トキシ', '曽木町', 'ソギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県土岐市旭ケ丘町', '21', '21212', '5095403', '岐阜県', 'ギフケン', '土岐市', 'トキシ', '旭ケ丘町', 'アサヒガオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県土岐市肥田町肥田', '21', '21212', '5095403', '岐阜県', 'ギフケン', '土岐市', 'トキシ', '肥田町肥田', 'ヒダチョウヒダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県瑞浪市', '21', '21208', '5096100', '岐阜県', 'ギフケン', '瑞浪市', 'ミズナミシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('54420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県瑞浪市土岐町', '21', '21208', '5096101', '岐阜県', 'ギフケン', '瑞浪市', 'ミズナミシ', '土岐町', 'トキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県瑞浪市稲津町萩原', '21', '21208', '5096102', '岐阜県', 'ギフケン', '瑞浪市', 'ミズナミシ', '稲津町萩原', 'イナツチョウハギワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県瑞浪市稲津町小里', '21', '21208', '5096103', '岐阜県', 'ギフケン', '瑞浪市', 'ミズナミシ', '稲津町小里', 'イナツチョウオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県瑞浪市山田町', '21', '21208', '5096104', '岐阜県', 'ギフケン', '瑞浪市', 'ミズナミシ', '山田町', 'ヤマダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県瑞浪市明賀台', '21', '21208', '5096105', '岐阜県', 'ギフケン', '瑞浪市', 'ミズナミシ', '明賀台', 'ミョウガダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県瑞浪市学園台', '21', '21208', '5096106', '岐阜県', 'ギフケン', '瑞浪市', 'ミズナミシ', '学園台', 'ガクエンダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県瑞浪市穂並', '21', '21208', '5096107', '岐阜県', 'ギフケン', '瑞浪市', 'ミズナミシ', '穂並', 'ホナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県瑞浪市下沖町', '21', '21208', '5096111', '岐阜県', 'ギフケン', '瑞浪市', 'ミズナミシ', '下沖町', 'シタオキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県瑞浪市小田町', '21', '21208', '5096112', '岐阜県', 'ギフケン', '瑞浪市', 'ミズナミシ', '小田町', 'オダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県瑞浪市和合町', '21', '21208', '5096113', '岐阜県', 'ギフケン', '瑞浪市', 'ミズナミシ', '和合町', 'ワゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県瑞浪市西小田町', '21', '21208', '5096114', '岐阜県', 'ギフケン', '瑞浪市', 'ミズナミシ', '西小田町', 'ニシオダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県瑞浪市北小田町', '21', '21208', '5096115', '岐阜県', 'ギフケン', '瑞浪市', 'ミズナミシ', '北小田町', 'キタオダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県瑞浪市南小田町', '21', '21208', '5096116', '岐阜県', 'ギフケン', '瑞浪市', 'ミズナミシ', '南小田町', 'ミナミオダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県瑞浪市寺河戸町', '21', '21208', '5096121', '岐阜県', 'ギフケン', '瑞浪市', 'ミズナミシ', '寺河戸町', 'テラカワドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県瑞浪市上平町', '21', '21208', '5096122', '岐阜県', 'ギフケン', '瑞浪市', 'ミズナミシ', '上平町', 'ウエダイラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県瑞浪市樽上町', '21', '21208', '5096123', '岐阜県', 'ギフケン', '瑞浪市', 'ミズナミシ', '樽上町', 'タルウエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県瑞浪市一色町', '21', '21208', '5096124', '岐阜県', 'ギフケン', '瑞浪市', 'ミズナミシ', '一色町', 'イシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県瑞浪市上野町', '21', '21208', '5096125', '岐阜県', 'ギフケン', '瑞浪市', 'ミズナミシ', '上野町', 'ウエノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県瑞浪市高月町', '21', '21208', '5096126', '岐阜県', 'ギフケン', '瑞浪市', 'ミズナミシ', '高月町', 'タカツキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県瑞浪市須野志町', '21', '21208', '5096127', '岐阜県', 'ギフケン', '瑞浪市', 'ミズナミシ', '須野志町', 'スノシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県瑞浪市宮前町', '21', '21208', '5096128', '岐阜県', 'ギフケン', '瑞浪市', 'ミズナミシ', '宮前町', 'ミヤマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県瑞浪市明世町月吉', '21', '21208', '5096131', '岐阜県', 'ギフケン', '瑞浪市', 'ミズナミシ', '明世町月吉', 'アキヨチョウツキヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県瑞浪市明世町山野内', '21', '21208', '5096132', '岐阜県', 'ギフケン', '瑞浪市', 'ミズナミシ', '明世町山野内', 'アキヨチョウヤマノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県瑞浪市明世町戸狩', '21', '21208', '5096133', '岐阜県', 'ギフケン', '瑞浪市', 'ミズナミシ', '明世町戸狩', 'アキヨチョウトガリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県瑞浪市松ケ瀬町', '21', '21208', '5096134', '岐阜県', 'ギフケン', '瑞浪市', 'ミズナミシ', '松ケ瀬町', 'マツガセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県瑞浪市薬師町', '21', '21208', '5096135', '岐阜県', 'ギフケン', '瑞浪市', 'ミズナミシ', '薬師町', 'ヤクシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県瑞浪市日吉町', '21', '21208', '5096251', '岐阜県', 'ギフケン', '瑞浪市', 'ミズナミシ', '日吉町', 'ヒヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県瑞浪市陶町猿爪', '21', '21208', '5096361', '岐阜県', 'ギフケン', '瑞浪市', 'ミズナミシ', '陶町猿爪', 'スエチョウマシヅメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県瑞浪市陶町水上', '21', '21208', '5096362', '岐阜県', 'ギフケン', '瑞浪市', 'ミズナミシ', '陶町水上', 'スエチョウミズカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県瑞浪市陶町大川', '21', '21208', '5096363', '岐阜県', 'ギフケン', '瑞浪市', 'ミズナミシ', '陶町大川', 'スエチョウオオカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県瑞浪市大湫町', '21', '21208', '5096471', '岐阜県', 'ギフケン', '瑞浪市', 'ミズナミシ', '大湫町', 'オオクテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県瑞浪市釜戸町', '21', '21208', '5096472', '岐阜県', 'ギフケン', '瑞浪市', 'ミズナミシ', '釜戸町', 'カマドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県恵那市武並町藤', '21', '21210', '5097121', '岐阜県', 'ギフケン', '恵那市', 'エナシ', '武並町藤', 'タケナミチョウフジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県恵那市武並町竹折', '21', '21210', '5097122', '岐阜県', 'ギフケン', '恵那市', 'エナシ', '武並町竹折', 'タケナミチョウタケオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県恵那市三郷町野井', '21', '21210', '5097123', '岐阜県', 'ギフケン', '恵那市', 'エナシ', '三郷町野井', 'ミサトチョウノイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県恵那市三郷町佐々良木', '21', '21210', '5097124', '岐阜県', 'ギフケン', '恵那市', 'エナシ', '三郷町佐々良木', 'ミサトチョウサザラギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県恵那市三郷町椋実', '21', '21210', '5097125', '岐阜県', 'ギフケン', '恵那市', 'エナシ', '三郷町椋実', 'ミサトチョウムクノミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県恵那市武並町新竹折', '21', '21210', '5097126', '岐阜県', 'ギフケン', '恵那市', 'エナシ', '武並町新竹折', 'タケナミチョウシンタケオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県恵那市', '21', '21210', '5097200', '岐阜県', 'ギフケン', '恵那市', 'エナシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('54464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県恵那市大井町', '21', '21210', '5097201', '岐阜県', 'ギフケン', '恵那市', 'エナシ', '大井町', 'オオイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県恵那市東野', '21', '21210', '5097202', '岐阜県', 'ギフケン', '恵那市', 'エナシ', '東野', 'ヒガシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県恵那市長島町正家', '21', '21210', '5097203', '岐阜県', 'ギフケン', '恵那市', 'エナシ', '長島町正家', 'オサシマチョウショウゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県恵那市長島町永田', '21', '21210', '5097204', '岐阜県', 'ギフケン', '恵那市', 'エナシ', '長島町永田', 'オサシマチョウナガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県恵那市長島町中野', '21', '21210', '5097205', '岐阜県', 'ギフケン', '恵那市', 'エナシ', '長島町中野', 'オサシマチョウナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県恵那市長島町久須見', '21', '21210', '5097206', '岐阜県', 'ギフケン', '恵那市', 'エナシ', '長島町久須見', 'オサシマチョウクスミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県恵那市笠置町河合', '21', '21210', '5097207', '岐阜県', 'ギフケン', '恵那市', 'エナシ', '笠置町河合', 'カサギチョウカワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県恵那市笠置町姫栗', '21', '21210', '5097208', '岐阜県', 'ギフケン', '恵那市', 'エナシ', '笠置町姫栗', 'カサギチョウヒメグリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県恵那市笠置町毛呂窪', '21', '21210', '5097209', '岐阜県', 'ギフケン', '恵那市', 'エナシ', '笠置町毛呂窪', 'カサギチョウケロクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県恵那市長島町鍋山', '21', '21210', '5097211', '岐阜県', 'ギフケン', '恵那市', 'エナシ', '長島町鍋山', 'オサシマチョウナベヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県中津川市阿木', '21', '21206', '5097321', '岐阜県', 'ギフケン', '中津川市', 'ナカツガワシ', '阿木', 'アギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県中津川市飯沼', '21', '21206', '5097322', '岐阜県', 'ギフケン', '中津川市', 'ナカツガワシ', '飯沼', 'イイヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県恵那市岩村町飯羽間', '21', '21210', '5097401', '岐阜県', 'ギフケン', '恵那市', 'エナシ', '岩村町飯羽間', 'イワムラチョウイイバマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県恵那市岩村町富田', '21', '21210', '5097402', '岐阜県', 'ギフケン', '恵那市', 'エナシ', '岩村町富田', 'イワムラチョウトミダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県恵那市岩村町', '21', '21210', '5097403', '岐阜県', 'ギフケン', '恵那市', 'エナシ', '岩村町', 'イワムラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県恵那市上矢作町木ノ実', '21', '21210', '5097501', '岐阜県', 'ギフケン', '恵那市', 'エナシ', '上矢作町', 'カミヤハギチョウ', null, null, '木ノ実', 'キノミ');
INSERT INTO `ms_addresses` VALUES ('54483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県恵那市上矢作町飯田洞', '21', '21210', '5097502', '岐阜県', 'ギフケン', '恵那市', 'エナシ', '上矢作町', 'カミヤハギチョウ', null, null, '飯田洞', 'イイダボラ');
INSERT INTO `ms_addresses` VALUES ('54484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県恵那市上矢作町達原', '21', '21210', '5097503', '岐阜県', 'ギフケン', '恵那市', 'エナシ', '上矢作町', 'カミヤハギチョウ', null, null, '達原', 'タツバラ');
INSERT INTO `ms_addresses` VALUES ('54485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県恵那市上矢作町小笹原', '21', '21210', '5097504', '岐阜県', 'ギフケン', '恵那市', 'エナシ', '上矢作町', 'カミヤハギチョウ', null, null, '小笹原', 'コザサハラ');
INSERT INTO `ms_addresses` VALUES ('54486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県恵那市上矢作町島', '21', '21210', '5097505', '岐阜県', 'ギフケン', '恵那市', 'エナシ', '上矢作町', 'カミヤハギチョウ', null, null, '島', 'シマ');
INSERT INTO `ms_addresses` VALUES ('54487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県恵那市上矢作町本郷', '21', '21210', '5097506', '岐阜県', 'ギフケン', '恵那市', 'エナシ', '上矢作町', 'カミヤハギチョウ', null, null, '本郷', 'ホンゴウ');
INSERT INTO `ms_addresses` VALUES ('54488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県恵那市上矢作町横道', '21', '21210', '5097507', '岐阜県', 'ギフケン', '恵那市', 'エナシ', '上矢作町', 'カミヤハギチョウ', null, null, '横道', 'ヨコミチ');
INSERT INTO `ms_addresses` VALUES ('54489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県恵那市上矢作町漆原', '21', '21210', '5097511', '岐阜県', 'ギフケン', '恵那市', 'エナシ', '上矢作町漆原', 'カミヤハギチョウウルシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県恵那市上矢作町下', '21', '21210', '5097512', '岐阜県', 'ギフケン', '恵那市', 'エナシ', '上矢作町下', 'カミヤハギチョウシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県恵那市上矢作町小田子', '21', '21210', '5097513', '岐阜県', 'ギフケン', '恵那市', 'エナシ', '上矢作町小田子', 'カミヤハギチョウコダコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県恵那市上矢作町', '21', '21210', '5097521', '岐阜県', 'ギフケン', '恵那市', 'エナシ', '上矢作町', 'カミヤハギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県恵那市山岡町久保原', '21', '21210', '5097601', '岐阜県', 'ギフケン', '恵那市', 'エナシ', '山岡町久保原', 'ヤマオカチョウクボハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県恵那市山岡町馬場山田', '21', '21210', '5097602', '岐阜県', 'ギフケン', '恵那市', 'エナシ', '山岡町馬場山田', 'ヤマオカチョウババヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県恵那市山岡町上手向', '21', '21210', '5097603', '岐阜県', 'ギフケン', '恵那市', 'エナシ', '山岡町上手向', 'ヤマオカチョウカミトウゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県恵那市山岡町釜屋', '21', '21210', '5097604', '岐阜県', 'ギフケン', '恵那市', 'エナシ', '山岡町釜屋', 'ヤマオカチョウカマヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県恵那市山岡町原', '21', '21210', '5097605', '岐阜県', 'ギフケン', '恵那市', 'エナシ', '山岡町原', 'ヤマオカチョウハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県恵那市山岡町田代', '21', '21210', '5097606', '岐阜県', 'ギフケン', '恵那市', 'エナシ', '山岡町田代', 'ヤマオカチョウタシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県恵那市山岡町下手向', '21', '21210', '5097607', '岐阜県', 'ギフケン', '恵那市', 'エナシ', '山岡町下手向', 'ヤマオカチョウシモトウゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県恵那市山岡町田沢', '21', '21210', '5097608', '岐阜県', 'ギフケン', '恵那市', 'エナシ', '山岡町田沢', 'ヤマオカチョウタザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県恵那市明智町野志', '21', '21210', '5097701', '岐阜県', 'ギフケン', '恵那市', 'エナシ', '明智町野志', 'アケチチョウノシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県恵那市明智町杉野', '21', '21210', '5097702', '岐阜県', 'ギフケン', '恵那市', 'エナシ', '明智町杉野', 'アケチチョウスギノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県恵那市明智町市場町', '21', '21210', '5097703', '岐阜県', 'ギフケン', '恵那市', 'エナシ', '明智町', 'アケチチョウ', null, null, '市場町', 'イチバチョウ');
INSERT INTO `ms_addresses` VALUES ('54507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県恵那市明智町駅前町', '21', '21210', '5097704', '岐阜県', 'ギフケン', '恵那市', 'エナシ', '明智町', 'アケチチョウ', null, null, '駅前町', 'エキマエチョウ');
INSERT INTO `ms_addresses` VALUES ('54508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県恵那市明智町新町', '21', '21210', '5097705', '岐阜県', 'ギフケン', '恵那市', 'エナシ', '明智町', 'アケチチョウ', null, null, '新町', 'シンマチ');
INSERT INTO `ms_addresses` VALUES ('54509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県恵那市明智町向町', '21', '21210', '5097706', '岐阜県', 'ギフケン', '恵那市', 'エナシ', '明智町', 'アケチチョウ', null, null, '向町', 'ムカイマチ');
INSERT INTO `ms_addresses` VALUES ('54510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県恵那市明智町滝坂住宅', '21', '21210', '5097707', '岐阜県', 'ギフケン', '恵那市', 'エナシ', '明智町', 'アケチチョウ', null, null, '滝坂住宅', 'タキザカジュウタク');
INSERT INTO `ms_addresses` VALUES ('54511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県恵那市明智町新井町', '21', '21210', '5097708', '岐阜県', 'ギフケン', '恵那市', 'エナシ', '明智町', 'アケチチョウ', null, null, '新井町', 'アライチョウ');
INSERT INTO `ms_addresses` VALUES ('54512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県恵那市明智町東方', '21', '21210', '5097711', '岐阜県', 'ギフケン', '恵那市', 'エナシ', '明智町東方', 'アケチチョウヒガシガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県恵那市明智町的場町', '21', '21210', '5097712', '岐阜県', 'ギフケン', '恵那市', 'エナシ', '明智町', 'アケチチョウ', null, null, '的場町', 'マトバチョウ');
INSERT INTO `ms_addresses` VALUES ('54514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県恵那市明智町片平町', '21', '21210', '5097713', '岐阜県', 'ギフケン', '恵那市', 'エナシ', '明智町', 'アケチチョウ', null, null, '片平町', 'カタヒラチョウ');
INSERT INTO `ms_addresses` VALUES ('54515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県恵那市明智町常盤町', '21', '21210', '5097714', '岐阜県', 'ギフケン', '恵那市', 'エナシ', '明智町', 'アケチチョウ', null, null, '常盤町', 'トキワチョウ');
INSERT INTO `ms_addresses` VALUES ('54516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県恵那市明智町東町', '21', '21210', '5097715', '岐阜県', 'ギフケン', '恵那市', 'エナシ', '明智町', 'アケチチョウ', null, null, '東町', 'ヒガシマチ');
INSERT INTO `ms_addresses` VALUES ('54517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県恵那市明智町本町', '21', '21210', '5097716', '岐阜県', 'ギフケン', '恵那市', 'エナシ', '明智町', 'アケチチョウ', null, null, '本町', 'ホンマチ');
INSERT INTO `ms_addresses` VALUES ('54518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県恵那市明智町宮町', '21', '21210', '5097717', '岐阜県', 'ギフケン', '恵那市', 'エナシ', '明智町', 'アケチチョウ', null, null, '宮町', 'ミヤマチ');
INSERT INTO `ms_addresses` VALUES ('54519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県恵那市明智町東山町', '21', '21210', '5097718', '岐阜県', 'ギフケン', '恵那市', 'エナシ', '明智町', 'アケチチョウ', null, null, '東山町', 'ヒガシヤマチョウ');
INSERT INTO `ms_addresses` VALUES ('54520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県恵那市明智町大泉', '21', '21210', '5097721', '岐阜県', 'ギフケン', '恵那市', 'エナシ', '明智町大泉', 'アケチチョウオオイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県恵那市明智町徳間町', '21', '21210', '5097722', '岐阜県', 'ギフケン', '恵那市', 'エナシ', '明智町', 'アケチチョウ', null, null, '徳間町', 'トクマチョウ');
INSERT INTO `ms_addresses` VALUES ('54522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県恵那市明智町大田', '21', '21210', '5097723', '岐阜県', 'ギフケン', '恵那市', 'エナシ', '明智町大田', 'アケチチョウオオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県恵那市明智町横通', '21', '21210', '5097724', '岐阜県', 'ギフケン', '恵那市', 'エナシ', '明智町横通', 'アケチチョウヨコドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県恵那市明智町阿妻', '21', '21210', '5097725', '岐阜県', 'ギフケン', '恵那市', 'エナシ', '明智町阿妻', 'アケチチョウアヅマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県恵那市明智町吉良見', '21', '21210', '5097726', '岐阜県', 'ギフケン', '恵那市', 'エナシ', '明智町吉良見', 'アケチチョウキラミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県恵那市明智町', '21', '21210', '5097731', '岐阜県', 'ギフケン', '恵那市', 'エナシ', '明智町', 'アケチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県恵那市串原中沢', '21', '21210', '5097801', '岐阜県', 'ギフケン', '恵那市', 'エナシ', '串原', 'クシハラ', null, null, '中沢', 'ナカサワ');
INSERT INTO `ms_addresses` VALUES ('54532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県恵那市串原平山', '21', '21210', '5097802', '岐阜県', 'ギフケン', '恵那市', 'エナシ', '串原', 'クシハラ', null, null, '平山', 'タイラヤマ');
INSERT INTO `ms_addresses` VALUES ('54533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県恵那市串原松本', '21', '21210', '5097803', '岐阜県', 'ギフケン', '恵那市', 'エナシ', '串原', 'クシハラ', null, null, '松本', 'マツモト');
INSERT INTO `ms_addresses` VALUES ('54534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県恵那市串原戸中', '21', '21210', '5097804', '岐阜県', 'ギフケン', '恵那市', 'エナシ', '串原', 'クシハラ', null, null, '戸中', 'トチュウ');
INSERT INTO `ms_addresses` VALUES ('54535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県恵那市串原峯', '21', '21210', '5097805', '岐阜県', 'ギフケン', '恵那市', 'エナシ', '串原', 'クシハラ', null, null, '峯', 'ミネ');
INSERT INTO `ms_addresses` VALUES ('54536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県恵那市串原松林', '21', '21210', '5097806', '岐阜県', 'ギフケン', '恵那市', 'エナシ', '串原', 'クシハラ', null, null, '松林', 'マツバヤシ');
INSERT INTO `ms_addresses` VALUES ('54537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県恵那市串原福原', '21', '21210', '5097811', '岐阜県', 'ギフケン', '恵那市', 'エナシ', '串原', 'クシハラ', null, null, '福原', 'フクバラ');
INSERT INTO `ms_addresses` VALUES ('54538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県恵那市串原森上', '21', '21210', '5097812', '岐阜県', 'ギフケン', '恵那市', 'エナシ', '串原', 'クシハラ', null, null, '森上', 'モリアゲ');
INSERT INTO `ms_addresses` VALUES ('54539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県恵那市串原大竹', '21', '21210', '5097813', '岐阜県', 'ギフケン', '恵那市', 'エナシ', '串原', 'クシハラ', null, null, '大竹', 'オオタケ');
INSERT INTO `ms_addresses` VALUES ('54540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県恵那市串原相走', '21', '21210', '5097814', '岐阜県', 'ギフケン', '恵那市', 'エナシ', '串原', 'クシハラ', null, null, '相走', 'アイバシリ');
INSERT INTO `ms_addresses` VALUES ('54541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県恵那市串原大野', '21', '21210', '5097815', '岐阜県', 'ギフケン', '恵那市', 'エナシ', '串原', 'クシハラ', null, null, '大野', 'オオノ');
INSERT INTO `ms_addresses` VALUES ('54542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県恵那市串原岩倉', '21', '21210', '5097816', '岐阜県', 'ギフケン', '恵那市', 'エナシ', '串原', 'クシハラ', null, null, '岩倉', 'イワクラ');
INSERT INTO `ms_addresses` VALUES ('54543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県恵那市串原大平', '21', '21210', '5097821', '岐阜県', 'ギフケン', '恵那市', 'エナシ', '串原', 'クシハラ', null, null, '大平', 'オオダイラ');
INSERT INTO `ms_addresses` VALUES ('54544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県恵那市串原柿畑', '21', '21210', '5097822', '岐阜県', 'ギフケン', '恵那市', 'エナシ', '串原', 'クシハラ', null, null, '柿畑', 'カキバタ');
INSERT INTO `ms_addresses` VALUES ('54545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県恵那市串原閑羅瀬', '21', '21210', '5097823', '岐阜県', 'ギフケン', '恵那市', 'エナシ', '串原', 'クシハラ', null, null, '閑羅瀬', 'シズラセ');
INSERT INTO `ms_addresses` VALUES ('54546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県恵那市串原大簗', '21', '21210', '5097824', '岐阜県', 'ギフケン', '恵那市', 'エナシ', '串原', 'クシハラ', null, null, '大簗', 'オオヤナ');
INSERT INTO `ms_addresses` VALUES ('54547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県恵那市串原川ケ渡', '21', '21210', '5097825', '岐阜県', 'ギフケン', '恵那市', 'エナシ', '串原', 'クシハラ', null, null, '川ケ渡', 'カワカド');
INSERT INTO `ms_addresses` VALUES ('54548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県恵那市串原木根', '21', '21210', '5097826', '岐阜県', 'ギフケン', '恵那市', 'エナシ', '串原', 'クシハラ', null, null, '木根', 'キネ');
INSERT INTO `ms_addresses` VALUES ('54549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県恵那市串原', '21', '21210', '5097831', '岐阜県', 'ギフケン', '恵那市', 'エナシ', '串原', 'クシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県恵那市中野方町', '21', '21210', '5098231', '岐阜県', 'ギフケン', '恵那市', 'エナシ', '中野方町', 'ナカノホウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県恵那市飯地町', '21', '21210', '5098232', '岐阜県', 'ギフケン', '恵那市', 'エナシ', '飯地町', 'イイジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県中津川市蛭川', '21', '21206', '5098301', '岐阜県', 'ギフケン', '中津川市', 'ナカツガワシ', '蛭川', 'ヒルカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県中津川市千旦林', '21', '21206', '5099131', '岐阜県', 'ギフケン', '中津川市', 'ナカツガワシ', '千旦林', 'センダンバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県中津川市茄子川', '21', '21206', '5099132', '岐阜県', 'ギフケン', '中津川市', 'ナカツガワシ', '茄子川', 'ナスビガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県中津川市川上', '21', '21206', '5099201', '岐阜県', 'ギフケン', '中津川市', 'ナカツガワシ', '川上', 'カワウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県中津川市上野', '21', '21206', '5099231', '岐阜県', 'ギフケン', '中津川市', 'ナカツガワシ', '上野', 'ウエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岐阜県中津川市坂下', '21', '21206', '5099232', '岐阜県', 'ギフケン', '中津川市', 'ナカツガワシ', '坂下', 'サカシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市', '24', '24202', '5100000', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('54568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県三重郡朝日町', '24', '24343', '5100000', '三重県', 'ミエケン', '三重郡朝日町', 'ミエグンアサヒチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('54569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県三重郡川越町', '24', '24344', '5100000', '三重県', 'ミエケン', '三重郡川越町', 'ミエグンカワゴエチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('54570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市八田', '24', '24202', '5100001', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '八田', 'ハッタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市羽津中', '24', '24202', '5100002', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '羽津中', 'ハヅナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市大宮町', '24', '24202', '5100003', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '大宮町', 'オオミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市大宮西町', '24', '24202', '5100004', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '大宮西町', 'オオミヤニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市山手町', '24', '24202', '5100005', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '山手町', 'ヤマテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市緑丘町', '24', '24202', '5100006', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '緑丘町', 'ミドリガオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市別名', '24', '24202', '5100007', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '別名', 'ベツメイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市南いかるが町', '24', '24202', '5100008', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '南いかるが町', 'ミナミイカルガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道室蘭市御崎町', '01', '01205', '0510001', '北海道', 'ホッカイドウ', '室蘭市', 'ムロランシ', '御崎町', 'ミサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市霞', '24', '24202', '5100011', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '霞', 'カスミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市羽津', '24', '24202', '5100012', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '羽津', 'ハヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市富士町', '24', '24202', '5100013', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '富士町', 'フジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市金場町', '24', '24202', '5100014', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '金場町', 'カネバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市城山町', '24', '24202', '5100015', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '城山町', 'シロヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市羽津山町', '24', '24202', '5100016', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '羽津山町', 'ハヅヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市羽津町', '24', '24202', '5100017', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '羽津町', 'ハヅチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市白須賀', '24', '24202', '5100018', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '白須賀', 'シラスカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道室蘭市御前水町', '01', '01205', '0510002', '北海道', 'ホッカイドウ', '室蘭市', 'ムロランシ', '御前水町', 'ゴゼンスイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市三郎町', '24', '24202', '5100021', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '三郎町', 'サブロウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市大協町', '24', '24202', '5100022', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '大協町', 'ダイキョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市午起', '24', '24202', '5100023', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '午起', 'ウマオコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市新浜町', '24', '24202', '5100024', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '新浜町', 'シンハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市東新町', '24', '24202', '5100025', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '東新町', 'トウシンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市高浜町', '24', '24202', '5100026', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '高浜町', 'タカハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市高浜新町', '24', '24202', '5100027', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '高浜新町', 'タカハマシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道室蘭市母恋南町', '01', '01205', '0510003', '北海道', 'ホッカイドウ', '室蘭市', 'ムロランシ', '母恋南町', 'ボコイミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市浜一色町', '24', '24202', '5100031', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '浜一色町', 'ハマイッシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市京町', '24', '24202', '5100032', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '京町', 'キョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市川原町', '24', '24202', '5100033', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '川原町', 'カワラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市滝川町', '24', '24202', '5100034', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '滝川町', 'タキガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市陶栄町', '24', '24202', '5100035', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '陶栄町', 'トウエイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道室蘭市母恋北町', '01', '01205', '0510004', '北海道', 'ホッカイドウ', '室蘭市', 'ムロランシ', '母恋北町', 'ボコイキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市稲葉町', '24', '24202', '5100041', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '稲葉町', 'イナバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市高砂町', '24', '24202', '5100042', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '高砂町', 'タカサゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市南納屋町', '24', '24202', '5100043', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '南納屋町', 'ミナミナヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市相生町', '24', '24202', '5100044', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '相生町', 'アイオイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市蔵町', '24', '24202', '5100045', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '蔵町', 'クラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市浜町', '24', '24202', '5100046', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '浜町', 'ハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市北納屋町', '24', '24202', '5100047', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '北納屋町', 'キタナヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市中納屋町', '24', '24202', '5100048', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '中納屋町', 'ナカナヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道室蘭市新富町', '01', '01205', '0510005', '北海道', 'ホッカイドウ', '室蘭市', 'ムロランシ', '新富町', 'シントミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市千歳町', '24', '24202', '5100051', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '千歳町', 'チトセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市末広町', '24', '24202', '5100052', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '末広町', 'スエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市曙', '24', '24202', '5100053', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '曙', 'アケボノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市曙町', '24', '24202', '5100054', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '曙町', 'アケボノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市寿町', '24', '24202', '5100055', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '寿町', 'コトブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市南起町', '24', '24202', '5100056', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '南起町', 'ミナミオコシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市昌栄町', '24', '24202', '5100057', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '昌栄町', 'ショウエイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市西末広町', '24', '24202', '5100058', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '西末広町', 'ニシスエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市尾上町', '24', '24202', '5100059', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '尾上町', 'オノエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道室蘭市茶津町', '01', '01205', '0510006', '北海道', 'ホッカイドウ', '室蘭市', 'ムロランシ', '茶津町', 'チャツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市朝日町', '24', '24202', '5100061', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '朝日町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市北浜田町', '24', '24202', '5100062', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '北浜田町', 'キタハマダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市十七軒町', '24', '24202', '5100063', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '十七軒町', 'ジュウシチケンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市新正', '24', '24202', '5100064', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '新正', 'シンショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市中浜田町', '24', '24202', '5100065', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '中浜田町', 'ナカハマダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市南浜田町', '24', '24202', '5100066', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '南浜田町', 'ミナミハマダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市浜田町', '24', '24202', '5100067', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '浜田町', 'ハマダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市三栄町', '24', '24202', '5100068', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '三栄町', 'サンエイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市幸町', '24', '24202', '5100069', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市西浦', '24', '24202', '5100071', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '西浦', 'ニシウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市九の城町', '24', '24202', '5100072', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '九の城町', 'クノシロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市西浜田町', '24', '24202', '5100073', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '西浜田町', 'ニシハマダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市鵜の森', '24', '24202', '5100074', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '鵜の森', 'ウノモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市安島', '24', '24202', '5100075', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '安島', 'ヤスジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市堀木', '24', '24202', '5100076', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '堀木', 'ホリキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市北町', '24', '24202', '5100081', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '北町', 'キタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市中部', '24', '24202', '5100082', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '中部', 'チュウブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市沖の島町', '24', '24202', '5100083', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '沖の島町', 'オキノシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市栄町', '24', '24202', '5100084', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市諏訪町', '24', '24202', '5100085', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '諏訪町', 'スワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市諏訪栄町', '24', '24202', '5100086', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '諏訪栄町', 'スワサカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市西新地', '24', '24202', '5100087', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '西新地', 'ニシシンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市元町', '24', '24202', '5100088', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '元町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市西町', '24', '24202', '5100089', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '西町', 'ニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市北浜町', '24', '24202', '5100091', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '北浜町', 'キタハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市新町', '24', '24202', '5100092', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '新町', 'シンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市本町', '24', '24202', '5100093', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市新々町', '24', '24202', '5100094', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '新々町', 'シンシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市元新町', '24', '24202', '5100095', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '元新町', 'モトシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市中町', '24', '24202', '5100096', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '中町', 'ナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市八幡町', '24', '24202', '5100097', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '八幡町', 'ハチマンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市北条町', '24', '24202', '5100098', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '北条町', 'キタジョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市楠町小倉', '24', '24202', '5100101', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '楠町小倉', 'クスチョウオグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市楠町吉崎', '24', '24202', '5100102', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '楠町吉崎', 'クスチョウヨシザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市楠町北五味塚', '24', '24202', '5100103', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '楠町北五味塚', 'クスチョウキタゴミヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市楠町南五味塚', '24', '24202', '5100104', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '楠町南五味塚', 'クスチョウミナミゴミヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市楠町南川', '24', '24202', '5100105', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '楠町南川', 'クスチョウミナミガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市楠町本郷', '24', '24202', '5100106', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '楠町本郷', 'クスチョウホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市楠町北一色', '24', '24202', '5100107', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '楠町北一色', 'クスチョウキタイッシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道室蘭市中央町', '01', '01205', '0510011', '北海道', 'ホッカイドウ', '室蘭市', 'ムロランシ', '中央町', 'チュウオウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道室蘭市山手町', '01', '01205', '0510012', '北海道', 'ホッカイドウ', '室蘭市', 'ムロランシ', '山手町', 'ヤマテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道室蘭市舟見町', '01', '01205', '0510013', '北海道', 'ホッカイドウ', '室蘭市', 'ムロランシ', '舟見町', 'フナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道室蘭市栄町', '01', '01205', '0510014', '北海道', 'ホッカイドウ', '室蘭市', 'ムロランシ', '栄町', 'サカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道室蘭市本町', '01', '01205', '0510015', '北海道', 'ホッカイドウ', '室蘭市', 'ムロランシ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道室蘭市幸町', '01', '01205', '0510016', '北海道', 'ホッカイドウ', '室蘭市', 'ムロランシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市稲生町', '24', '24207', '5100201', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '稲生町', 'イノウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市野町', '24', '24207', '5100202', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '野町', 'ノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市野村町', '24', '24207', '5100203', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '野村町', 'ノムラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市稲生西', '24', '24207', '5100204', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '稲生西', 'イノウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市稲生', '24', '24207', '5100205', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '稲生', 'イノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市稲生こがね園', '24', '24207', '5100206', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '稲生こがね園', 'イノウコガネエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市稲生塩屋', '24', '24207', '5100207', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '稲生塩屋', 'イノウシオヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市鈴鹿ハイツ', '24', '24207', '5100208', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '鈴鹿ハイツ', 'スズカハイツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道室蘭市緑町', '01', '01205', '0510021', '北海道', 'ホッカイドウ', '室蘭市', 'ムロランシ', '緑町', 'ミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市東旭が丘', '24', '24207', '5100211', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '東旭が丘', 'ヒガシアサヒガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市中旭が丘', '24', '24207', '5100212', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '中旭が丘', 'ナカアサヒガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市南旭が丘', '24', '24207', '5100213', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '南旭が丘', 'ミナミアサヒガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市野町中', '24', '24207', '5100216', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '野町中', 'ノマチナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市野町東', '24', '24207', '5100217', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '野町東', 'ノマチヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市野町西', '24', '24207', '5100218', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '野町西', 'ノマチニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市野町南', '24', '24207', '5100219', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '野町南', 'ノマチミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道室蘭市海岸町', '01', '01205', '0510022', '北海道', 'ホッカイドウ', '室蘭市', 'ムロランシ', '海岸町', 'カイガンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市北若松町', '24', '24207', '5100221', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '北若松町', 'キタワカマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市若松西', '24', '24207', '5100222', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '若松西', 'ワカマツニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市若松北', '24', '24207', '5100223', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '若松北', 'ワカマツキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市若松中', '24', '24207', '5100224', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '若松中', 'ワカマツナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市若松東', '24', '24207', '5100225', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '若松東', 'ワカマツヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市岸岡町', '24', '24207', '5100226', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '岸岡町', 'キシオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市南若松町', '24', '24207', '5100227', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '南若松町', 'ミナミワカマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道室蘭市入江町', '01', '01205', '0510023', '北海道', 'ホッカイドウ', '室蘭市', 'ムロランシ', '入江町', 'イリエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市江島台', '24', '24207', '5100231', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '江島台', 'エジマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市北江島町', '24', '24207', '5100232', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '北江島町', 'キタエジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市東江島町', '24', '24207', '5100233', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '東江島町', 'ヒガシエジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市江島本町', '24', '24207', '5100234', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '江島本町', 'エジマホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市南江島町', '24', '24207', '5100235', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '南江島町', 'ミナミエジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市中江島町', '24', '24207', '5100236', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '中江島町', 'ナカエジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市江島町', '24', '24207', '5100237', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '江島町', 'エジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道室蘭市幕西町', '01', '01205', '0510024', '北海道', 'ホッカイドウ', '室蘭市', 'ムロランシ', '幕西町', 'マクニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市白子駅前', '24', '24207', '5100241', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '白子駅前', 'シロコエキマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市白子本町', '24', '24207', '5100242', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '白子本町', 'シロコホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市白子', '24', '24207', '5100243', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '白子', 'シロコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市白子町', '24', '24207', '5100244', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '白子町', 'シロコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道室蘭市常盤町', '01', '01205', '0510025', '北海道', 'ホッカイドウ', '室蘭市', 'ムロランシ', '常盤町', 'トキワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市徳田町', '24', '24207', '5100251', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '徳田町', 'トクダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市五祝町', '24', '24207', '5100252', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '五祝町', 'イワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市寺家町', '24', '24207', '5100253', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '寺家町', 'ジケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市寺家', '24', '24207', '5100254', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '寺家', 'ジケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市磯山町', '24', '24207', '5100255', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '磯山町', 'イソヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市磯山', '24', '24207', '5100256', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '磯山', 'イソヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市東磯山', '24', '24207', '5100257', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '東磯山', 'ヒガシイソヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市秋永町', '24', '24207', '5100258', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '秋永町', 'アキナガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市中瀬古町', '24', '24207', '5100259', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '中瀬古町', 'ナカゼコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道室蘭市清水町', '01', '01205', '0510026', '北海道', 'ホッカイドウ', '室蘭市', 'ムロランシ', '清水町', 'シミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市御薗町', '24', '24207', '5100261', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '御薗町', 'ミソノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市越知町', '24', '24207', '5100262', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '越知町', 'オウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市郡山町', '24', '24207', '5100263', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '郡山町', 'コオリヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市徳居町', '24', '24207', '5100264', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '徳居町', 'トクスイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市三宅町', '24', '24207', '5100265', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '三宅町', 'ミヤケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市長法寺町', '24', '24207', '5100266', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '長法寺町', 'チョウボウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道室蘭市沢町', '01', '01205', '0510027', '北海道', 'ホッカイドウ', '室蘭市', 'ムロランシ', '沢町', 'サワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道室蘭市西小路町', '01', '01205', '0510028', '北海道', 'ホッカイドウ', '室蘭市', 'ムロランシ', '西小路町', 'ニシコウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市河芸町西千里', '24', '24201', '5100301', '三重県', 'ミエケン', '津市', 'ツシ', '河芸町西千里', 'カワゲチョウニシチサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市河芸町千里ケ丘', '24', '24201', '5100302', '三重県', 'ミエケン', '津市', 'ツシ', '河芸町千里ケ丘', 'カワゲチョウチサトガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市河芸町東千里', '24', '24201', '5100303', '三重県', 'ミエケン', '津市', 'ツシ', '河芸町東千里', 'カワゲチョウヒガシチサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市河芸町上野', '24', '24201', '5100304', '三重県', 'ミエケン', '津市', 'ツシ', '河芸町上野', 'カワゲチョウウエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市河芸町中別保', '24', '24201', '5100305', '三重県', 'ミエケン', '津市', 'ツシ', '河芸町中別保', 'カワゲチョウナカベッポ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市河芸町一色', '24', '24201', '5100306', '三重県', 'ミエケン', '津市', 'ツシ', '河芸町一色', 'カワゲチョウイッシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市河芸町影重', '24', '24201', '5100307', '三重県', 'ミエケン', '津市', 'ツシ', '河芸町影重', 'カワゲチョウカゲシゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市河芸町中瀬', '24', '24201', '5100308', '三重県', 'ミエケン', '津市', 'ツシ', '河芸町中瀬', 'カワゲチョウナカゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道室蘭市築地町', '01', '01205', '0510031', '北海道', 'ホッカイドウ', '室蘭市', 'ムロランシ', '築地町', 'ツキジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市河芸町三行', '24', '24201', '5100311', '三重県', 'ミエケン', '津市', 'ツシ', '河芸町三行', 'カワゲチョウミユキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市河芸町久知野', '24', '24201', '5100312', '三重県', 'ミエケン', '津市', 'ツシ', '河芸町久知野', 'カワゲチョウクチノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市河芸町赤部', '24', '24201', '5100313', '三重県', 'ミエケン', '津市', 'ツシ', '河芸町赤部', 'カワゲチョウアカブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市河芸町浜田', '24', '24201', '5100314', '三重県', 'ミエケン', '津市', 'ツシ', '河芸町浜田', 'カワゲチョウハマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市河芸町高佐', '24', '24201', '5100315', '三重県', 'ミエケン', '津市', 'ツシ', '河芸町高佐', 'カワゲチョウタカサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市河芸町南黒田', '24', '24201', '5100316', '三重県', 'ミエケン', '津市', 'ツシ', '河芸町南黒田', 'カワゲチョウミナミクロダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市河芸町北黒田', '24', '24201', '5100317', '三重県', 'ミエケン', '津市', 'ツシ', '河芸町北黒田', 'カワゲチョウキタクロダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市河芸町杜の街', '24', '24201', '5100318', '三重県', 'ミエケン', '津市', 'ツシ', '河芸町杜の街', 'カワゲチョウモリノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道室蘭市港南町', '01', '01205', '0510032', '北海道', 'ホッカイドウ', '室蘭市', 'ムロランシ', '港南町', 'コウナンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道室蘭市小橋内町', '01', '01205', '0510033', '北海道', 'ホッカイドウ', '室蘭市', 'ムロランシ', '小橋内町', 'オハシナイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道室蘭市増市町', '01', '01205', '0510034', '北海道', 'ホッカイドウ', '室蘭市', 'ムロランシ', '増市町', 'マスイチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道室蘭市絵鞆町', '01', '01205', '0510035', '北海道', 'ホッカイドウ', '室蘭市', 'ムロランシ', '絵鞆町', 'エトモチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道室蘭市祝津町', '01', '01205', '0510036', '北海道', 'ホッカイドウ', '室蘭市', 'ムロランシ', '祝津町', 'シュクヅチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市三ツ谷東町', '24', '24202', '5100801', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '三ツ谷東町', 'ミツヤヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市三ツ谷町', '24', '24202', '5100802', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '三ツ谷町', 'ミツヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市阿倉川町', '24', '24202', '5100803', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '阿倉川町', 'アクラガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市万古町', '24', '24202', '5100804', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '万古町', 'バンコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市東阿倉川', '24', '24202', '5100805', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '東阿倉川', 'ヒガシアクラガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市本郷町', '24', '24202', '5100806', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '本郷町', 'ホンゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市末永町', '24', '24202', '5100807', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '末永町', 'スエナガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市阿倉川新町', '24', '24202', '5100810', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '阿倉川新町', 'アクラガワシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市みゆきケ丘', '24', '24202', '5100811', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', 'みゆきケ丘', 'ミユキガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市西阿倉川', '24', '24202', '5100812', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '西阿倉川', 'ニシアクラガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市末永', '24', '24202', '5100813', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '末永', 'スエナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市清水町', '24', '24202', '5100814', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '清水町', 'シミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市野田', '24', '24202', '5100815', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '野田', 'ノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市久保田', '24', '24202', '5100821', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '久保田', 'クボタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市芝田', '24', '24202', '5100822', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '芝田', 'シバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市城北町', '24', '24202', '5100823', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '城北町', 'シロキタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市城東町', '24', '24202', '5100824', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '城東町', 'シロヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市赤堀新町', '24', '24202', '5100825', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '赤堀新町', 'アカホリシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市赤堀', '24', '24202', '5100826', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '赤堀', 'アカホリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市赤堀南町', '24', '24202', '5100827', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '赤堀南町', 'アカホリミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市石塚町', '24', '24202', '5100828', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '石塚町', 'イシヅカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市城西町', '24', '24202', '5100829', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '城西町', 'シロニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市西伊倉町', '24', '24202', '5100831', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '西伊倉町', 'ニシイグラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市伊倉', '24', '24202', '5100832', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '伊倉', 'イグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市中川原', '24', '24202', '5100833', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '中川原', 'ナカガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市ときわ', '24', '24202', '5100834', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', 'ときわ', 'トキワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市大井手', '24', '24202', '5100835', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '大井手', 'オオイデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市松本', '24', '24202', '5100836', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '松本', 'マツモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市西松本町', '24', '24202', '5100837', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '西松本町', 'ニシマツモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市南松本町', '24', '24202', '5100838', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '南松本町', 'ミナミマツモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市青葉町', '24', '24202', '5100839', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '青葉町', 'アオバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市三田町', '24', '24202', '5100841', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '三田町', 'ミタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市石原町', '24', '24202', '5100842', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '石原町', 'イシハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市宮東町', '24', '24202', '5100843', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '宮東町', 'ミヤヒガシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市宝町', '24', '24202', '5100844', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '宝町', 'タカラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市海山道町', '24', '24202', '5100845', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '海山道町', 'ミヤマドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市大井の川町', '24', '24202', '5100846', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '大井の川町', 'オオイノカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市大浜町', '24', '24202', '5100847', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '大浜町', 'オオハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市東邦町', '24', '24202', '5100848', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '東邦町', 'トウホウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市塩浜町', '24', '24202', '5100851', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '塩浜町', 'シオハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市浜旭町', '24', '24202', '5100852', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '浜旭町', 'ハマアサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市川合町', '24', '24202', '5100853', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '川合町', 'カワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市塩浜本町', '24', '24202', '5100854', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '塩浜本町', 'シオハマホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市馳出町', '24', '24202', '5100855', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '馳出町', 'ハセダシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市七つ屋町', '24', '24202', '5100856', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '七つ屋町', 'ナナツヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市高旭町', '24', '24202', '5100857', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '高旭町', 'タカアサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市柳町', '24', '24202', '5100861', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '柳町', 'ヤナギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市御薗町', '24', '24202', '5100862', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '御薗町', 'ミソノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市磯津', '24', '24202', '5100863', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '磯津', 'イソヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市大里町', '24', '24202', '5100863', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '大里町', 'オオザトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市塩浜', '24', '24202', '5100863', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '塩浜', 'シオハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市塩浜栄町', '24', '24202', '5100863', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '塩浜栄町', 'シオハマサカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市中里町', '24', '24202', '5100864', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '中里町', 'ナカザトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市小浜町', '24', '24202', '5100865', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '小浜町', 'コハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市大池町', '24', '24202', '5100866', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '大池町', 'オオイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市松泉町', '24', '24202', '5100867', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '松泉町', 'ショウセンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市馳出', '24', '24202', '5100868', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '馳出', 'ハセダシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市川尻町', '24', '24202', '5100871', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '川尻町', 'カワジリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市内堀町', '24', '24202', '5100872', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '内堀町', 'ウツボリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市貝塚町', '24', '24202', '5100873', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '貝塚町', 'カイヅカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市河原田町', '24', '24202', '5100874', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '河原田町', 'カワラダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市大治田', '24', '24202', '5100875', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '大治田', 'オバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市六呂見', '24', '24202', '5100881', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '六呂見', 'ロクロミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市追分', '24', '24202', '5100882', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '追分', 'オイワケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市泊小柳町', '24', '24202', '5100883', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '泊小柳町', 'トマリコヤナギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市泊町', '24', '24202', '5100884', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '泊町', 'トマリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市日永', '24', '24202', '5100885', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '日永', 'ヒナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市日永東', '24', '24202', '5100886', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '日永東', 'ヒナガヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市日永西', '24', '24202', '5100891', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '日永西', 'ヒナガニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市泊山崎町', '24', '24202', '5100892', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '泊山崎町', 'トマリヤマザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市前田町', '24', '24202', '5100893', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '前田町', 'マエダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市泊村', '24', '24202', '5100894', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '泊村', 'トマリムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市東日野', '24', '24202', '5100941', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '東日野', 'ヒガシヒノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市東日野町', '24', '24202', '5100942', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '東日野町', 'ヒガシヒノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市西日野町', '24', '24202', '5100943', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '西日野町', 'ニシヒノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市笹川', '24', '24202', '5100944', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '笹川', 'ササガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市高花平', '24', '24202', '5100945', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '高花平', 'タカハナダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市小林町', '24', '24202', '5100946', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '小林町', 'コバヤシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市八王子町', '24', '24202', '5100947', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '八王子町', 'ハチオウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市室山町', '24', '24202', '5100948', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '室山町', 'ムロヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市小古曽東', '24', '24202', '5100951', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '小古曽東', 'オゴソヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市小古曽町', '24', '24202', '5100952', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '小古曽町', 'オゴソチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市釆女が丘', '24', '24202', '5100953', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '釆女が丘', 'ウネメガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市釆女町', '24', '24202', '5100954', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '釆女町', 'ウネメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市北小松町', '24', '24202', '5100955', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '北小松町', 'キタコマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市貝家町', '24', '24202', '5100956', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '貝家町', 'カイゲチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市森カ山町', '24', '24202', '5100957', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '森カ山町', 'モリガヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市小古曽', '24', '24202', '5100958', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '小古曽', 'オゴソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市波木町', '24', '24202', '5100961', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '波木町', 'ハギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市波木が丘町', '24', '24202', '5100962', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '波木が丘町', 'ハギガオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市波木南台', '24', '24202', '5100963', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '波木南台', 'ハギミナミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市南小松町', '24', '24202', '5100971', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '南小松町', 'ミナミコマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県三重郡菰野町', '24', '24341', '5101200', '三重県', 'ミエケン', '三重郡菰野町', 'ミエグンコモノチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('54844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県三重郡菰野町池底', '24', '24341', '5101221', '三重県', 'ミエケン', '三重郡菰野町', 'ミエグンコモノチョウ', '池底', 'イケゾコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県三重郡菰野町大強原', '24', '24341', '5101222', '三重県', 'ミエケン', '三重郡菰野町', 'ミエグンコモノチョウ', '大強原', 'オオゴハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県三重郡菰野町諏訪', '24', '24341', '5101223', '三重県', 'ミエケン', '三重郡菰野町', 'ミエグンコモノチョウ', '諏訪', 'スワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県三重郡菰野町川北', '24', '24341', '5101224', '三重県', 'ミエケン', '三重郡菰野町', 'ミエグンコモノチョウ', '川北', 'カワキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県三重郡菰野町下村', '24', '24341', '5101225', '三重県', 'ミエケン', '三重郡菰野町', 'ミエグンコモノチョウ', '下村', 'シモムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県三重郡菰野町吉沢', '24', '24341', '5101226', '三重県', 'ミエケン', '三重郡菰野町', 'ミエグンコモノチョウ', '吉沢', 'ヨシザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県三重郡菰野町神森', '24', '24341', '5101231', '三重県', 'ミエケン', '三重郡菰野町', 'ミエグンコモノチョウ', '神森', 'カモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県三重郡菰野町宿野', '24', '24341', '5101232', '三重県', 'ミエケン', '三重郡菰野町', 'ミエグンコモノチョウ', '宿野', 'シュクノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県三重郡菰野町菰野', '24', '24341', '5101233', '三重県', 'ミエケン', '三重郡菰野町', 'ミエグンコモノチョウ', '菰野', 'コモノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県三重郡菰野町福村', '24', '24341', '5101234', '三重県', 'ミエケン', '三重郡菰野町', 'ミエグンコモノチョウ', '福村', 'フクムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県三重郡菰野町宝永台', '24', '24341', '5101235', '三重県', 'ミエケン', '三重郡菰野町', 'ミエグンコモノチョウ', '宝永台', 'ホウエイダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県三重郡菰野町初若の郷', '24', '24341', '5101236', '三重県', 'ミエケン', '三重郡菰野町', 'ミエグンコモノチョウ', '初若の郷', 'ハツワカノサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県三重郡菰野町大羽根園新林町', '24', '24341', '5101241', '三重県', 'ミエケン', '三重郡菰野町', 'ミエグンコモノチョウ', '大羽根園新林町', 'オオバネエンシンバヤシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県三重郡菰野町大羽根園柴垣町', '24', '24341', '5101242', '三重県', 'ミエケン', '三重郡菰野町', 'ミエグンコモノチョウ', '大羽根園柴垣町', 'オオバネエンシバガキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県三重郡菰野町大羽根園呉竹町', '24', '24341', '5101243', '三重県', 'ミエケン', '三重郡菰野町', 'ミエグンコモノチョウ', '大羽根園呉竹町', 'オオバネエンクレタケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県三重郡菰野町大羽根園並木通', '24', '24341', '5101244', '三重県', 'ミエケン', '三重郡菰野町', 'ミエグンコモノチョウ', '大羽根園並木通', 'オオバネエンナミキドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県三重郡菰野町大羽根園松ケ枝町', '24', '24341', '5101245', '三重県', 'ミエケン', '三重郡菰野町', 'ミエグンコモノチョウ', '大羽根園松ケ枝町', 'オオバネエンマツガエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県三重郡菰野町大羽根園青葉町', '24', '24341', '5101246', '三重県', 'ミエケン', '三重郡菰野町', 'ミエグンコモノチョウ', '大羽根園青葉町', 'オオバネエンアオバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県三重郡菰野町千草', '24', '24341', '5101251', '三重県', 'ミエケン', '三重郡菰野町', 'ミエグンコモノチョウ', '千草', 'チクサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県三重郡菰野町音羽', '24', '24341', '5101252', '三重県', 'ミエケン', '三重郡菰野町', 'ミエグンコモノチョウ', '音羽', 'オトワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県三重郡菰野町潤田', '24', '24341', '5101253', '三重県', 'ミエケン', '三重郡菰野町', 'ミエグンコモノチョウ', '潤田', 'ウルダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県三重郡菰野町永井', '24', '24341', '5101311', '三重県', 'ミエケン', '三重郡菰野町', 'ミエグンコモノチョウ', '永井', 'ナガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県三重郡菰野町竹成', '24', '24341', '5101312', '三重県', 'ミエケン', '三重郡菰野町', 'ミエグンコモノチョウ', '竹成', 'タケナリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県三重郡菰野町田口', '24', '24341', '5101321', '三重県', 'ミエケン', '三重郡菰野町', 'ミエグンコモノチョウ', '田口', 'タグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県三重郡菰野町田口新田', '24', '24341', '5101322', '三重県', 'ミエケン', '三重郡菰野町', 'ミエグンコモノチョウ', '田口新田', 'タグチシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県三重郡菰野町小島', '24', '24341', '5101323', '三重県', 'ミエケン', '三重郡菰野町', 'ミエグンコモノチョウ', '小島', 'オジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県三重郡菰野町田光', '24', '24341', '5101324', '三重県', 'ミエケン', '三重郡菰野町', 'ミエグンコモノチョウ', '田光', 'タビカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県三重郡菰野町榊', '24', '24341', '5101325', '三重県', 'ミエケン', '三重郡菰野町', 'ミエグンコモノチョウ', '榊', 'サカキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県三重郡菰野町杉谷', '24', '24341', '5101326', '三重県', 'ミエケン', '三重郡菰野町', 'ミエグンコモノチョウ', '杉谷', 'スギタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県三重郡菰野町根の平', '24', '24341', '5101327', '三重県', 'ミエケン', '三重郡菰野町', 'ミエグンコモノチョウ', '根の平', 'ネノヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県三重郡菰野町切畑', '24', '24341', '5101328', '三重県', 'ミエケン', '三重郡菰野町', 'ミエグンコモノチョウ', '切畑', 'キリハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市天カ須賀', '24', '24202', '5108001', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '天カ須賀', 'アマガスカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市天カ須賀新町', '24', '24202', '5108002', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '天カ須賀新町', 'アマガスカシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市住吉町', '24', '24202', '5108003', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '住吉町', 'スミヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市富田一色町', '24', '24202', '5108004', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '富田一色町', 'トミダイッシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市富双', '24', '24202', '5108005', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '富双', 'フソウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市東富田町', '24', '24202', '5108006', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '東富田町', 'ヒガシトミダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市富田浜元町', '24', '24202', '5108007', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '富田浜元町', 'トミダハマモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市富田浜町', '24', '24202', '5108008', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '富田浜町', 'トミダハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市浜園町', '24', '24202', '5108009', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '浜園町', 'ハマゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市東茂福町', '24', '24202', '5108011', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '東茂福町', 'ヒガシモチブクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市茂福町', '24', '24202', '5108012', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '茂福町', 'モチブクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市南富田町', '24', '24202', '5108013', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '南富田町', 'ミナミトミダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市富田', '24', '24202', '5108014', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '富田', 'トミダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市松原町', '24', '24202', '5108015', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '松原町', 'マツバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市富州原町', '24', '24202', '5108016', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '富州原町', 'トミスハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市平町', '24', '24202', '5108017', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '平町', 'タイラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市松寺', '24', '24202', '5108021', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '松寺', 'マツテラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市蒔田', '24', '24202', '5108022', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '蒔田', 'マキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市西富田', '24', '24202', '5108023', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '西富田', 'ニシトミダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市西富田町', '24', '24202', '5108024', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '西富田町', 'ニシトミダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市富田栄町', '24', '24202', '5108025', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '富田栄町', 'トミダサカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市十志町', '24', '24202', '5108026', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '十志町', 'ジュウシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市茂福', '24', '24202', '5108027', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '茂福', 'モチブク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市下之宮町', '24', '24202', '5108028', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '下之宮町', 'シモノミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市川北', '24', '24202', '5108031', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '川北', 'カワキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市川北町', '24', '24202', '5108032', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '川北町', 'カワキタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市下さざらい町', '24', '24202', '5108033', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '下さざらい町', 'シモサザライチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市大矢知町', '24', '24202', '5108034', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '大矢知町', 'オオヤチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市東垂坂町', '24', '24202', '5108035', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '東垂坂町', 'ヒガシタルサカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市南垂坂町', '24', '24202', '5108036', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '南垂坂町', 'ミナミタルサカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市垂坂町', '24', '24202', '5108037', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '垂坂町', 'タルサカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市垂坂新町', '24', '24202', '5108038', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '垂坂新町', 'タルサカシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市大矢知新町', '24', '24202', '5108039', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '大矢知新町', 'オオヤチシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県三重郡朝日町縄生', '24', '24343', '5108101', '三重県', 'ミエケン', '三重郡朝日町', 'ミエグンアサヒチョウ', '縄生', 'ナオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県三重郡朝日町小向', '24', '24343', '5108102', '三重県', 'ミエケン', '三重郡朝日町', 'ミエグンアサヒチョウ', '小向', 'オブケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県三重郡朝日町柿', '24', '24343', '5108103', '三重県', 'ミエケン', '三重郡朝日町', 'ミエグンアサヒチョウ', '柿', 'カキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県三重郡朝日町埋縄', '24', '24343', '5108104', '三重県', 'ミエケン', '三重郡朝日町', 'ミエグンアサヒチョウ', '埋縄', 'ウズナワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県三重郡川越町当新田', '24', '24344', '5108111', '三重県', 'ミエケン', '三重郡川越町', 'ミエグンカワゴエチョウ', '当新田', 'トウシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県三重郡川越町亀須新田', '24', '24344', '5108112', '三重県', 'ミエケン', '三重郡川越町', 'ミエグンカワゴエチョウ', '亀須新田', 'カメズシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県三重郡川越町亀尾新田', '24', '24344', '5108113', '三重県', 'ミエケン', '三重郡川越町', 'ミエグンカワゴエチョウ', '亀尾新田', 'カメオシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県三重郡川越町亀崎新田', '24', '24344', '5108114', '三重県', 'ミエケン', '三重郡川越町', 'ミエグンカワゴエチョウ', '亀崎新田', 'カメザキシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県三重郡川越町高松', '24', '24344', '5108121', '三重県', 'ミエケン', '三重郡川越町', 'ミエグンカワゴエチョウ', '高松', 'タカマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県三重郡川越町豊田', '24', '24344', '5108122', '三重県', 'ミエケン', '三重郡川越町', 'ミエグンカワゴエチョウ', '豊田', 'トヨダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県三重郡川越町豊田一色', '24', '24344', '5108123', '三重県', 'ミエケン', '三重郡川越町', 'ミエグンカワゴエチョウ', '豊田一色', 'トヨダイッシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県三重郡川越町南福崎', '24', '24344', '5108124', '三重県', 'ミエケン', '三重郡川越町', 'ミエグンカワゴエチョウ', '南福崎', 'ミナミフクサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県三重郡川越町北福崎', '24', '24344', '5108125', '三重県', 'ミエケン', '三重郡川越町', 'ミエグンカワゴエチョウ', '北福崎', 'キタフクサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市', '24', '24205', '5110000', '三重県', 'ミエケン', '桑名市', 'クワナシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('54961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市上之輪新田', '24', '24205', '5110001', '三重県', 'ミエケン', '桑名市', 'クワナシ', '上之輪新田', 'カミノワシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市福島', '24', '24205', '5110002', '三重県', 'ミエケン', '桑名市', 'クワナシ', '福島', 'フクジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市東太一丸', '24', '24205', '5110003', '三重県', 'ミエケン', '桑名市', 'クワナシ', '東太一丸', 'ヒガシタイチマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市住吉町', '24', '24205', '5110004', '三重県', 'ミエケン', '桑名市', 'クワナシ', '住吉町', 'スミヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市太一丸', '24', '24205', '5110005', '三重県', 'ミエケン', '桑名市', 'クワナシ', '太一丸', 'タイチマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市今北町', '24', '24205', '5110006', '三重県', 'ミエケン', '桑名市', 'クワナシ', '今北町', 'イマキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市参宮通', '24', '24205', '5110007', '三重県', 'ミエケン', '桑名市', 'クワナシ', '参宮通', 'サングウドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市蓮見町', '24', '24205', '5110008', '三重県', 'ミエケン', '桑名市', 'クワナシ', '蓮見町', 'ハスミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市桑名', '24', '24205', '5110009', '三重県', 'ミエケン', '桑名市', 'クワナシ', '桑名', 'クワナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市船馬町', '24', '24205', '5110011', '三重県', 'ミエケン', '桑名市', 'クワナシ', '船馬町', 'センバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市春日町', '24', '24205', '5110012', '三重県', 'ミエケン', '桑名市', 'クワナシ', '春日町', 'カスガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市宝殿町', '24', '24205', '5110013', '三重県', 'ミエケン', '桑名市', 'クワナシ', '宝殿町', 'ホウデンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市三崎通', '24', '24205', '5110014', '三重県', 'ミエケン', '桑名市', 'クワナシ', '三崎通', 'ミサキドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市殿町', '24', '24205', '5110015', '三重県', 'ミエケン', '桑名市', 'クワナシ', '殿町', 'トノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市相生町', '24', '24205', '5110016', '三重県', 'ミエケン', '桑名市', 'クワナシ', '相生町', 'アイオイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市今片町', '24', '24205', '5110017', '三重県', 'ミエケン', '桑名市', 'クワナシ', '今片町', 'イマカタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市今中町', '24', '24205', '5110018', '三重県', 'ミエケン', '桑名市', 'クワナシ', '今中町', 'イマナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市清水町', '24', '24205', '5110019', '三重県', 'ミエケン', '桑名市', 'クワナシ', '清水町', 'シミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市川口町', '24', '24205', '5110021', '三重県', 'ミエケン', '桑名市', 'クワナシ', '川口町', 'カワグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市江戸町', '24', '24205', '5110022', '三重県', 'ミエケン', '桑名市', 'クワナシ', '江戸町', 'エドマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市本町', '24', '24205', '5110023', '三重県', 'ミエケン', '桑名市', 'クワナシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市北魚町', '24', '24205', '5110024', '三重県', 'ミエケン', '桑名市', 'クワナシ', '北魚町', 'キタウオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市風呂町', '24', '24205', '5110025', '三重県', 'ミエケン', '桑名市', 'クワナシ', '風呂町', 'フロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市宮町', '24', '24205', '5110026', '三重県', 'ミエケン', '桑名市', 'クワナシ', '宮町', 'ミヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市福島新町', '24', '24205', '5110027', '三重県', 'ミエケン', '桑名市', 'クワナシ', '福島新町', 'フクジマシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市三之丸', '24', '24205', '5110031', '三重県', 'ミエケン', '桑名市', 'クワナシ', '三之丸', 'サンノマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市吉之丸', '24', '24205', '5110032', '三重県', 'ミエケン', '桑名市', 'クワナシ', '吉之丸', 'ヨシノマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市赤須賀', '24', '24205', '5110033', '三重県', 'ミエケン', '桑名市', 'クワナシ', '赤須賀', 'アカスカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市地蔵', '24', '24205', '5110034', '三重県', 'ミエケン', '桑名市', 'クワナシ', '地蔵', 'ジゾウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市東野', '24', '24205', '5110035', '三重県', 'ミエケン', '桑名市', 'クワナシ', '東野', 'ヒガシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市伊賀町', '24', '24205', '5110036', '三重県', 'ミエケン', '桑名市', 'クワナシ', '伊賀町', 'イガマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市元赤須賀', '24', '24205', '5110037', '三重県', 'ミエケン', '桑名市', 'クワナシ', '元赤須賀', 'モトアカスカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市内堀', '24', '24205', '5110038', '三重県', 'ミエケン', '桑名市', 'クワナシ', '内堀', 'ウチボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市京町', '24', '24205', '5110039', '三重県', 'ミエケン', '桑名市', 'クワナシ', '京町', 'キョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市外堀', '24', '24205', '5110041', '三重県', 'ミエケン', '桑名市', 'クワナシ', '外堀', 'ソトボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市柳原', '24', '24205', '5110042', '三重県', 'ミエケン', '桑名市', 'クワナシ', '柳原', 'ヤナギハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市新屋敷', '24', '24205', '5110043', '三重県', 'ミエケン', '桑名市', 'クワナシ', '新屋敷', 'シンヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市萱町', '24', '24205', '5110044', '三重県', 'ミエケン', '桑名市', 'クワナシ', '萱町', 'カヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('54999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市伝馬町', '24', '24205', '5110045', '三重県', 'ミエケン', '桑名市', 'クワナシ', '伝馬町', 'テンマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市一色町', '24', '24205', '5110046', '三重県', 'ミエケン', '桑名市', 'クワナシ', '一色町', 'イッシキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市鍛冶町', '24', '24205', '5110047', '三重県', 'ミエケン', '桑名市', 'クワナシ', '鍛冶町', 'カジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市新町', '24', '24205', '5110048', '三重県', 'ミエケン', '桑名市', 'クワナシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市八幡町', '24', '24205', '5110049', '三重県', 'ミエケン', '桑名市', 'クワナシ', '八幡町', 'ハチマンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市矢田磧', '24', '24205', '5110051', '三重県', 'ミエケン', '桑名市', 'クワナシ', '矢田磧', 'ヤダカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市相川町', '24', '24205', '5110052', '三重県', 'ミエケン', '桑名市', 'クワナシ', '相川町', 'アイカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市東鍋屋町', '24', '24205', '5110053', '三重県', 'ミエケン', '桑名市', 'クワナシ', '東鍋屋町', 'ヒガシナベヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市西鍋屋町', '24', '24205', '5110054', '三重県', 'ミエケン', '桑名市', 'クワナシ', '西鍋屋町', 'ニシナベヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市東矢田町', '24', '24205', '5110055', '三重県', 'ミエケン', '桑名市', 'クワナシ', '東矢田町', 'ヒガシヤダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市西矢田町', '24', '24205', '5110056', '三重県', 'ミエケン', '桑名市', 'クワナシ', '西矢田町', 'ニシヤダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市三ツ矢橋', '24', '24205', '5110057', '三重県', 'ミエケン', '桑名市', 'クワナシ', '三ツ矢橋', 'ミツヤバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市千代田町', '24', '24205', '5110058', '三重県', 'ミエケン', '桑名市', 'クワナシ', '千代田町', 'チヨダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市寿町', '24', '24205', '5110061', '三重県', 'ミエケン', '桑名市', 'クワナシ', '寿町', 'コトブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市常盤町', '24', '24205', '5110062', '三重県', 'ミエケン', '桑名市', 'クワナシ', '常盤町', 'トキワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市京橋町', '24', '24205', '5110063', '三重県', 'ミエケン', '桑名市', 'クワナシ', '京橋町', 'キョウバシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市新築町', '24', '24205', '5110064', '三重県', 'ミエケン', '桑名市', 'クワナシ', '新築町', 'シンチクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市大央町', '24', '24205', '5110065', '三重県', 'ミエケン', '桑名市', 'クワナシ', '大央町', 'ダイオウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市北鍋屋町', '24', '24205', '5110066', '三重県', 'ミエケン', '桑名市', 'クワナシ', '北鍋屋町', 'キタナベヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市掛樋', '24', '24205', '5110067', '三重県', 'ミエケン', '桑名市', 'クワナシ', '掛樋', 'カケヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市中央町', '24', '24205', '5110068', '三重県', 'ミエケン', '桑名市', 'クワナシ', '中央町', 'チュウオウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市新矢田', '24', '24205', '5110069', '三重県', 'ミエケン', '桑名市', 'クワナシ', '新矢田', 'シンヤダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市駅元町', '24', '24205', '5110071', '三重県', 'ミエケン', '桑名市', 'クワナシ', '駅元町', 'エキモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市堤原', '24', '24205', '5110072', '三重県', 'ミエケン', '桑名市', 'クワナシ', '堤原', 'ツツミハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市北寺町', '24', '24205', '5110073', '三重県', 'ミエケン', '桑名市', 'クワナシ', '北寺町', 'キタテラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市南寺町', '24', '24205', '5110074', '三重県', 'ミエケン', '桑名市', 'クワナシ', '南寺町', 'ミナミテラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市三栄町', '24', '24205', '5110075', '三重県', 'ミエケン', '桑名市', 'クワナシ', '三栄町', 'サンエイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市八間通', '24', '24205', '5110076', '三重県', 'ミエケン', '桑名市', 'クワナシ', '八間通', 'ハチケンドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市末広町', '24', '24205', '5110077', '三重県', 'ミエケン', '桑名市', 'クワナシ', '末広町', 'スエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市桑栄町', '24', '24205', '5110078', '三重県', 'ミエケン', '桑名市', 'クワナシ', '桑栄町', 'ソウエイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市有楽町', '24', '24205', '5110079', '三重県', 'ミエケン', '桑名市', 'クワナシ', '有楽町', 'ユウラクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市片町', '24', '24205', '5110081', '三重県', 'ミエケン', '桑名市', 'クワナシ', '片町', 'カタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市宮通', '24', '24205', '5110082', '三重県', 'ミエケン', '桑名市', 'クワナシ', '宮通', 'ミヤドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市職人町', '24', '24205', '5110083', '三重県', 'ミエケン', '桑名市', 'クワナシ', '職人町', 'ショクニンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市油町', '24', '24205', '5110084', '三重県', 'ミエケン', '桑名市', 'クワナシ', '油町', 'アブラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市紺屋町', '24', '24205', '5110085', '三重県', 'ミエケン', '桑名市', 'クワナシ', '紺屋町', 'コンヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市入江葭町', '24', '24205', '5110086', '三重県', 'ミエケン', '桑名市', 'クワナシ', '入江葭町', 'イリエヨシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市吉津屋町', '24', '24205', '5110087', '三重県', 'ミエケン', '桑名市', 'クワナシ', '吉津屋町', 'ヨツヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市南魚町', '24', '24205', '5110088', '三重県', 'ミエケン', '桑名市', 'クワナシ', '南魚町', 'ミナミウオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市田町', '24', '24205', '5110089', '三重県', 'ミエケン', '桑名市', 'クワナシ', '田町', 'タマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市多度町柚井', '24', '24205', '5110101', '三重県', 'ミエケン', '桑名市', 'クワナシ', '多度町柚井', 'タドチョウユイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市多度町香取', '24', '24205', '5110102', '三重県', 'ミエケン', '桑名市', 'クワナシ', '多度町香取', 'タドチョウカトリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市多度町戸津', '24', '24205', '5110103', '三重県', 'ミエケン', '桑名市', 'クワナシ', '多度町戸津', 'タドチョウトヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市多度町肱江', '24', '24205', '5110104', '三重県', 'ミエケン', '桑名市', 'クワナシ', '多度町肱江', 'タドチョウヒジエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市多度町小山', '24', '24205', '5110105', '三重県', 'ミエケン', '桑名市', 'クワナシ', '多度町小山', 'タドチョウオヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市多度町多度', '24', '24205', '5110106', '三重県', 'ミエケン', '桑名市', 'クワナシ', '多度町多度', 'タドチョウタド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市多度町平古', '24', '24205', '5110111', '三重県', 'ミエケン', '桑名市', 'クワナシ', '多度町平古', 'タドチョウヒラコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市多度町福永', '24', '24205', '5110112', '三重県', 'ミエケン', '桑名市', 'クワナシ', '多度町福永', 'タドチョウフクナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市多度町上之郷', '24', '24205', '5110113', '三重県', 'ミエケン', '桑名市', 'クワナシ', '多度町上之郷', 'タドチョウカミノゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市多度町中須', '24', '24205', '5110114', '三重県', 'ミエケン', '桑名市', 'クワナシ', '多度町中須', 'タドチョウナカズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市多度町南之郷', '24', '24205', '5110115', '三重県', 'ミエケン', '桑名市', 'クワナシ', '多度町南之郷', 'タドチョウミナミノゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市多度町大鳥居', '24', '24205', '5110116', '三重県', 'ミエケン', '桑名市', 'クワナシ', '多度町大鳥居', 'タドチョウオオドリイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市多度町下野代', '24', '24205', '5110117', '三重県', 'ミエケン', '桑名市', 'クワナシ', '多度町下野代', 'タドチョウシモノシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市多度町御衣野', '24', '24205', '5110118', '三重県', 'ミエケン', '桑名市', 'クワナシ', '多度町御衣野', 'タドチョウミゾノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市多度町美鹿', '24', '24205', '5110121', '三重県', 'ミエケン', '桑名市', 'クワナシ', '多度町美鹿', 'タドチョウビロク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市多度町古野', '24', '24205', '5110122', '三重県', 'ミエケン', '桑名市', 'クワナシ', '多度町古野', 'タドチョウコノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市多度町北猪飼', '24', '24205', '5110123', '三重県', 'ミエケン', '桑名市', 'クワナシ', '多度町北猪飼', 'タドチョウキタイカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市多度町猪飼', '24', '24205', '5110124', '三重県', 'ミエケン', '桑名市', 'クワナシ', '多度町猪飼', 'タドチョウイカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市多度町力尾', '24', '24205', '5110125', '三重県', 'ミエケン', '桑名市', 'クワナシ', '多度町力尾', 'タドチョウチカラオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県いなべ市', '24', '24214', '5110200', '三重県', 'ミエケン', 'いなべ市', 'イナベシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('55061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県員弁郡東員町', '24', '24324', '5110200', '三重県', 'ミエケン', '員弁郡東員町', 'イナベグントウインチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('55062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県いなべ市員弁町市之原', '24', '24214', '5110201', '三重県', 'ミエケン', 'いなべ市', 'イナベシ', '員弁町市之原', 'イナベチョウイチノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県いなべ市員弁町楚原', '24', '24214', '5110202', '三重県', 'ミエケン', 'いなべ市', 'イナベシ', '員弁町楚原', 'イナベチョウソハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県いなべ市員弁町畑新田', '24', '24214', '5110203', '三重県', 'ミエケン', 'いなべ市', 'イナベシ', '員弁町畑新田', 'イナベチョウハタシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県いなべ市員弁町石仏', '24', '24214', '5110204', '三重県', 'ミエケン', 'いなべ市', 'イナベシ', '員弁町石仏', 'イナベチョウイシボトケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県いなべ市員弁町笠田新田', '24', '24214', '5110205', '三重県', 'ミエケン', 'いなべ市', 'イナベシ', '員弁町笠田新田', 'イナベチョウカサダシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県いなべ市員弁町宇野', '24', '24214', '5110206', '三重県', 'ミエケン', 'いなべ市', 'イナベシ', '員弁町宇野', 'イナベチョウウノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県いなべ市員弁町上笠田', '24', '24214', '5110207', '三重県', 'ミエケン', 'いなべ市', 'イナベシ', '員弁町上笠田', 'イナベチョウカミカサダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県いなべ市員弁町坂東新田', '24', '24214', '5110208', '三重県', 'ミエケン', 'いなべ市', 'イナベシ', '員弁町坂東新田', 'イナベチョウバンドウシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県いなべ市員弁町松名新田', '24', '24214', '5110211', '三重県', 'ミエケン', 'いなべ市', 'イナベシ', '員弁町松名新田', 'イナベチョウマツナシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県いなべ市員弁町平古', '24', '24214', '5110212', '三重県', 'ミエケン', 'いなべ市', 'イナベシ', '員弁町平古', 'イナベチョウヒラコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県いなべ市員弁町暮明', '24', '24214', '5110213', '三重県', 'ミエケン', 'いなべ市', 'イナベシ', '員弁町暮明', 'イナベチョウクラガリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県いなべ市員弁町岡丁田', '24', '24214', '5110214', '三重県', 'ミエケン', 'いなべ市', 'イナベシ', '員弁町岡丁田', 'イナベチョウオカチョウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県いなべ市員弁町東一色', '24', '24214', '5110215', '三重県', 'ミエケン', 'いなべ市', 'イナベシ', '員弁町東一色', 'イナベチョウヒガシイッシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県いなべ市員弁町松之木', '24', '24214', '5110216', '三重県', 'ミエケン', 'いなべ市', 'イナベシ', '員弁町松之木', 'イナベチョウマツノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県いなべ市員弁町大泉新田', '24', '24214', '5110217', '三重県', 'ミエケン', 'いなべ市', 'イナベシ', '員弁町大泉新田', 'イナベチョウオオイズミシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県いなべ市員弁町下笠田', '24', '24214', '5110221', '三重県', 'ミエケン', 'いなべ市', 'イナベシ', '員弁町下笠田', 'イナベチョウシモカサダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県いなべ市員弁町御薗', '24', '24214', '5110222', '三重県', 'ミエケン', 'いなべ市', 'イナベシ', '員弁町御薗', 'イナベチョウミソノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県いなべ市員弁町北金井', '24', '24214', '5110223', '三重県', 'ミエケン', 'いなべ市', 'イナベシ', '員弁町北金井', 'イナベチョウキタカナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県いなべ市員弁町大泉', '24', '24214', '5110224', '三重県', 'ミエケン', 'いなべ市', 'イナベシ', '員弁町大泉', 'イナベチョウオオイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県いなべ市員弁町西方', '24', '24214', '5110225', '三重県', 'ミエケン', 'いなべ市', 'イナベシ', '員弁町西方', 'イナベチョウニシガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県員弁郡東員町笹尾西', '24', '24324', '5110231', '三重県', 'ミエケン', '員弁郡東員町', 'イナベグントウインチョウ', '笹尾西', 'ササオニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県員弁郡東員町笹尾東', '24', '24324', '5110232', '三重県', 'ミエケン', '員弁郡東員町', 'イナベグントウインチョウ', '笹尾東', 'ササオヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県員弁郡東員町城山', '24', '24324', '5110233', '三重県', 'ミエケン', '員弁郡東員町', 'イナベグントウインチョウ', '城山', 'シロヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県員弁郡東員町鳥取', '24', '24324', '5110241', '三重県', 'ミエケン', '員弁郡東員町', 'イナベグントウインチョウ', '鳥取', 'トットリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県員弁郡東員町六把野新田', '24', '24324', '5110242', '三重県', 'ミエケン', '員弁郡東員町', 'イナベグントウインチョウ', '六把野新田', 'ロッパノシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県員弁郡東員町穴太', '24', '24324', '5110243', '三重県', 'ミエケン', '員弁郡東員町', 'イナベグントウインチョウ', '穴太', 'アノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県員弁郡東員町大木', '24', '24324', '5110244', '三重県', 'ミエケン', '員弁郡東員町', 'イナベグントウインチョウ', '大木', 'オオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県員弁郡東員町八幡新田', '24', '24324', '5110245', '三重県', 'ミエケン', '員弁郡東員町', 'イナベグントウインチョウ', '八幡新田', 'ハチマンシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県員弁郡東員町北山田', '24', '24324', '5110251', '三重県', 'ミエケン', '員弁郡東員町', 'イナベグントウインチョウ', '北山田', 'キタヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県員弁郡東員町山田', '24', '24324', '5110251', '三重県', 'ミエケン', '員弁郡東員町', 'イナベグントウインチョウ', '山田', 'ヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県員弁郡東員町瀬古泉', '24', '24324', '5110252', '三重県', 'ミエケン', '員弁郡東員町', 'イナベグントウインチョウ', '瀬古泉', 'セコイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県員弁郡東員町筑紫', '24', '24324', '5110253', '三重県', 'ミエケン', '員弁郡東員町', 'イナベグントウインチョウ', '筑紫', 'ツクシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県員弁郡東員町中上', '24', '24324', '5110254', '三重県', 'ミエケン', '員弁郡東員町', 'イナベグントウインチョウ', '中上', 'ナカガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県員弁郡東員町長深', '24', '24324', '5110255', '三重県', 'ミエケン', '員弁郡東員町', 'イナベグントウインチョウ', '長深', 'ナガフケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県員弁郡東員町南大社', '24', '24324', '5110256', '三重県', 'ミエケン', '員弁郡東員町', 'イナベグントウインチョウ', '南大社', 'ミナミオオヤシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県員弁郡東員町北大社', '24', '24324', '5110257', '三重県', 'ミエケン', '員弁郡東員町', 'イナベグントウインチョウ', '北大社', 'キタオオヤシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県いなべ市大安町丹生川上', '24', '24214', '5110261', '三重県', 'ミエケン', 'いなべ市', 'イナベシ', '大安町丹生川上', 'ダイアンチョウニュウガワカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県いなべ市大安町丹生川中', '24', '24214', '5110262', '三重県', 'ミエケン', 'いなべ市', 'イナベシ', '大安町丹生川中', 'ダイアンチョウニュウガワナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県いなべ市大安町丹生川久下', '24', '24214', '5110263', '三重県', 'ミエケン', 'いなべ市', 'イナベシ', '大安町丹生川久下', 'ダイアンチョウニュウガワヒサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県いなべ市大安町石榑東', '24', '24214', '5110264', '三重県', 'ミエケン', 'いなべ市', 'イナベシ', '大安町石榑東', 'ダイアンチョウイシグレヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県いなべ市大安町石榑北', '24', '24214', '5110265', '三重県', 'ミエケン', 'いなべ市', 'イナベシ', '大安町石榑北', 'ダイアンチョウイシグレキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県いなべ市大安町石榑南', '24', '24214', '5110266', '三重県', 'ミエケン', 'いなべ市', 'イナベシ', '大安町石榑南', 'ダイアンチョウイシグレミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県いなべ市大安町石榑北山', '24', '24214', '5110267', '三重県', 'ミエケン', 'いなべ市', 'イナベシ', '大安町石榑北山', 'ダイアンチョウイシグレキタヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県いなべ市大安町片樋', '24', '24214', '5110271', '三重県', 'ミエケン', 'いなべ市', 'イナベシ', '大安町片樋', 'ダイアンチョウカタヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県いなべ市大安町高柳', '24', '24214', '5110272', '三重県', 'ミエケン', 'いなべ市', 'イナベシ', '大安町高柳', 'ダイアンチョウタカヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県いなべ市大安町平塚', '24', '24214', '5110273', '三重県', 'ミエケン', 'いなべ市', 'イナベシ', '大安町平塚', 'ダイアンチョウヒラツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県いなべ市大安町大井田', '24', '24214', '5110274', '三重県', 'ミエケン', 'いなべ市', 'イナベシ', '大安町大井田', 'ダイアンチョウオオイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県いなべ市大安町鍋坂', '24', '24214', '5110275', '三重県', 'ミエケン', 'いなべ市', 'イナベシ', '大安町鍋坂', 'ダイアンチョウナベサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県いなべ市大安町石榑下', '24', '24214', '5110276', '三重県', 'ミエケン', 'いなべ市', 'イナベシ', '大安町石榑下', 'ダイアンチョウイシグレシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県いなべ市大安町門前', '24', '24214', '5110281', '三重県', 'ミエケン', 'いなべ市', 'イナベシ', '大安町門前', 'ダイアンチョウモンゼン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県いなべ市大安町大泉', '24', '24214', '5110282', '三重県', 'ミエケン', 'いなべ市', 'イナベシ', '大安町大泉', 'ダイアンチョウオオイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県いなべ市大安町南金井', '24', '24214', '5110283', '三重県', 'ミエケン', 'いなべ市', 'イナベシ', '大安町南金井', 'ダイアンチョウミナミカナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県いなべ市大安町梅戸', '24', '24214', '5110284', '三重県', 'ミエケン', 'いなべ市', 'イナベシ', '大安町梅戸', 'ダイアンチョウウメド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県いなべ市大安町宇賀新田', '24', '24214', '5110285', '三重県', 'ミエケン', 'いなべ市', 'イナベシ', '大安町宇賀新田', 'ダイアンチョウウガシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県いなべ市大安町宇賀', '24', '24214', '5110286', '三重県', 'ミエケン', 'いなべ市', 'イナベシ', '大安町宇賀', 'ダイアンチョウウガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県いなべ市大安町中央ケ丘', '24', '24214', '5110287', '三重県', 'ミエケン', 'いなべ市', 'イナベシ', '大安町中央ケ丘', 'ダイアンチョウチュウオウガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県いなべ市北勢町川原', '24', '24214', '5110401', '三重県', 'ミエケン', 'いなべ市', 'イナベシ', '北勢町川原', 'ホクセイチョウカワハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県いなべ市北勢町千司久連新田', '24', '24214', '5110402', '三重県', 'ミエケン', 'いなべ市', 'イナベシ', '北勢町千司久連新田', 'ホクセイチョウセンジグレシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県いなべ市北勢町二之瀬', '24', '24214', '5110403', '三重県', 'ミエケン', 'いなべ市', 'イナベシ', '北勢町二之瀬', 'ホクセイチョウニノセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県いなべ市北勢町小原一色', '24', '24214', '5110404', '三重県', 'ミエケン', 'いなべ市', 'イナベシ', '北勢町小原一色', 'ホクセイチョウコハライッシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県いなべ市北勢町田辺', '24', '24214', '5110405', '三重県', 'ミエケン', 'いなべ市', 'イナベシ', '北勢町田辺', 'ホクセイチョウタナベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県いなべ市北勢町塩崎', '24', '24214', '5110406', '三重県', 'ミエケン', 'いなべ市', 'イナベシ', '北勢町塩崎', 'ホクセイチョウシオサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県いなべ市北勢町京ケ野新田', '24', '24214', '5110411', '三重県', 'ミエケン', 'いなべ市', 'イナベシ', '北勢町京ケ野新田', 'ホクセイチョウキョウガノシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県いなべ市北勢町向平', '24', '24214', '5110412', '三重県', 'ミエケン', 'いなべ市', 'イナベシ', '北勢町向平', 'ホクセイチョウムコヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県いなべ市北勢町畑毛', '24', '24214', '5110413', '三重県', 'ミエケン', 'いなべ市', 'イナベシ', '北勢町畑毛', 'ホクセイチョウハタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県いなべ市北勢町西貝野', '24', '24214', '5110414', '三重県', 'ミエケン', 'いなべ市', 'イナベシ', '北勢町西貝野', 'ホクセイチョウニシカイノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県いなべ市北勢町東貝野', '24', '24214', '5110415', '三重県', 'ミエケン', 'いなべ市', 'イナベシ', '北勢町東貝野', 'ホクセイチョウヒガシカイノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県いなべ市北勢町飯倉', '24', '24214', '5110416', '三重県', 'ミエケン', 'いなべ市', 'イナベシ', '北勢町飯倉', 'ホクセイチョウイグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県いなべ市北勢町瀬木', '24', '24214', '5110417', '三重県', 'ミエケン', 'いなべ市', 'イナベシ', '北勢町瀬木', 'ホクセイチョウセギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県いなべ市北勢町下平', '24', '24214', '5110418', '三重県', 'ミエケン', 'いなべ市', 'イナベシ', '北勢町下平', 'ホクセイチョウシモヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県いなべ市北勢町皷', '24', '24214', '5110421', '三重県', 'ミエケン', 'いなべ市', 'イナベシ', '北勢町皷', 'ホクセイチョウツヅミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県いなべ市北勢町北中津原', '24', '24214', '5110422', '三重県', 'ミエケン', 'いなべ市', 'イナベシ', '北勢町北中津原', 'ホクセイチョウキタナカツハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県いなべ市北勢町平野新田', '24', '24214', '5110423', '三重県', 'ミエケン', 'いなべ市', 'イナベシ', '北勢町平野新田', 'ホクセイチョウヒラノシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県いなべ市北勢町南中津原', '24', '24214', '5110424', '三重県', 'ミエケン', 'いなべ市', 'イナベシ', '北勢町南中津原', 'ホクセイチョウミナミナカツハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県いなべ市北勢町大辻新田', '24', '24214', '5110425', '三重県', 'ミエケン', 'いなべ市', 'イナベシ', '北勢町大辻新田', 'ホクセイチョウオオツジシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県いなべ市北勢町其原', '24', '24214', '5110426', '三重県', 'ミエケン', 'いなべ市', 'イナベシ', '北勢町其原', 'ホクセイチョウソノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県いなべ市北勢町麻生田', '24', '24214', '5110427', '三重県', 'ミエケン', 'いなべ市', 'イナベシ', '北勢町麻生田', 'ホクセイチョウオウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県いなべ市北勢町阿下喜', '24', '24214', '5110428', '三重県', 'ミエケン', 'いなべ市', 'イナベシ', '北勢町阿下喜', 'ホクセイチョウアゲキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県いなべ市北勢町別名', '24', '24214', '5110431', '三重県', 'ミエケン', 'いなべ市', 'イナベシ', '北勢町別名', 'ホクセイチョウベツミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県いなべ市北勢町東村', '24', '24214', '5110432', '三重県', 'ミエケン', 'いなべ市', 'イナベシ', '北勢町東村', 'ホクセイチョウヒガシムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県いなべ市北勢町中山', '24', '24214', '5110433', '三重県', 'ミエケン', 'いなべ市', 'イナベシ', '北勢町中山', 'ホクセイチョウナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県いなべ市北勢町麓村', '24', '24214', '5110434', '三重県', 'ミエケン', 'いなべ市', 'イナベシ', '北勢町麓村', 'ホクセイチョウフモトムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県いなべ市北勢町奥村', '24', '24214', '5110435', '三重県', 'ミエケン', 'いなべ市', 'イナベシ', '北勢町奥村', 'ホクセイチョウオクムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県いなべ市北勢町新町', '24', '24214', '5110436', '三重県', 'ミエケン', 'いなべ市', 'イナベシ', '北勢町新町', 'ホクセイチョウシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県いなべ市北勢町垣内', '24', '24214', '5110437', '三重県', 'ミエケン', 'いなべ市', 'イナベシ', '北勢町垣内', 'ホクセイチョウカイト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県いなべ市北勢町治田外面', '24', '24214', '5110438', '三重県', 'ミエケン', 'いなべ市', 'イナベシ', '北勢町治田外面', 'ホクセイチョウハッタドモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県いなべ市藤原町鼎', '24', '24214', '5110501', '三重県', 'ミエケン', 'いなべ市', 'イナベシ', '藤原町鼎', 'フジワラチョウカナエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県いなべ市藤原町上相場', '24', '24214', '5110502', '三重県', 'ミエケン', 'いなべ市', 'イナベシ', '藤原町上相場', 'フジワラチョウカミアイバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県いなべ市藤原町下相場', '24', '24214', '5110503', '三重県', 'ミエケン', 'いなべ市', 'イナベシ', '藤原町下相場', 'フジワラチョウシモアイバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県いなべ市藤原町川合', '24', '24214', '5110504', '三重県', 'ミエケン', 'いなべ市', 'イナベシ', '藤原町川合', 'フジワラチョウカワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県いなべ市藤原町日内', '24', '24214', '5110505', '三重県', 'ミエケン', 'いなべ市', 'イナベシ', '藤原町日内', 'フジワラチョウヒナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県いなべ市藤原町長尾', '24', '24214', '5110506', '三重県', 'ミエケン', 'いなべ市', 'イナベシ', '藤原町長尾', 'フジワラチョウナガオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県いなべ市藤原町上之山田', '24', '24214', '5110507', '三重県', 'ミエケン', 'いなべ市', 'イナベシ', '藤原町上之山田', 'フジワラチョウウエノヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県いなべ市藤原町藤ケ丘', '24', '24214', '5110508', '三重県', 'ミエケン', 'いなべ市', 'イナベシ', '藤原町藤ケ丘', 'フジワラチョウフジガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県いなべ市藤原町市場', '24', '24214', '5110511', '三重県', 'ミエケン', 'いなべ市', 'イナベシ', '藤原町市場', 'フジワラチョウイチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県いなべ市藤原町志礼石新田', '24', '24214', '5110512', '三重県', 'ミエケン', 'いなべ市', 'イナベシ', '藤原町志礼石新田', 'フジワラチョウシレイシシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県いなべ市藤原町下野尻', '24', '24214', '5110513', '三重県', 'ミエケン', 'いなべ市', 'イナベシ', '藤原町下野尻', 'フジワラチョウシモノジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県いなべ市藤原町石川', '24', '24214', '5110514', '三重県', 'ミエケン', 'いなべ市', 'イナベシ', '藤原町石川', 'フジワラチョウイシカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県いなべ市藤原町東禅寺', '24', '24214', '5110515', '三重県', 'ミエケン', 'いなべ市', 'イナベシ', '藤原町東禅寺', 'フジワラチョウトウゼンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県いなべ市藤原町西野尻', '24', '24214', '5110516', '三重県', 'ミエケン', 'いなべ市', 'イナベシ', '藤原町西野尻', 'フジワラチョウニシノジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県いなべ市藤原町大貝戸', '24', '24214', '5110517', '三重県', 'ミエケン', 'いなべ市', 'イナベシ', '藤原町大貝戸', 'フジワラチョウオオガイト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県いなべ市藤原町坂本', '24', '24214', '5110518', '三重県', 'ミエケン', 'いなべ市', 'イナベシ', '藤原町坂本', 'フジワラチョウサカモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県いなべ市藤原町別名', '24', '24214', '5110519', '三重県', 'ミエケン', 'いなべ市', 'イナベシ', '藤原町別名', 'フジワラチョウベツミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県いなべ市藤原町古田', '24', '24214', '5110521', '三重県', 'ミエケン', 'いなべ市', 'イナベシ', '藤原町古田', 'フジワラチョウフルタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県いなべ市藤原町篠立', '24', '24214', '5110522', '三重県', 'ミエケン', 'いなべ市', 'イナベシ', '藤原町篠立', 'フジワラチョウシノダチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県いなべ市藤原町本郷', '24', '24214', '5110523', '三重県', 'ミエケン', 'いなべ市', 'イナベシ', '藤原町本郷', 'フジワラチョウホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県いなべ市藤原町山口', '24', '24214', '5110524', '三重県', 'ミエケン', 'いなべ市', 'イナベシ', '藤原町山口', 'フジワラチョウヤマグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市今島', '24', '24205', '5110801', '三重県', 'ミエケン', '桑名市', 'クワナシ', '今島', 'イマジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市川崎町', '24', '24205', '5110802', '三重県', 'ミエケン', '桑名市', 'クワナシ', '川崎町', 'カワサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市枇杷島台', '24', '24205', '5110803', '三重県', 'ミエケン', '桑名市', 'クワナシ', '枇杷島台', 'ビワジマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市北川原台', '24', '24205', '5110804', '三重県', 'ミエケン', '桑名市', 'クワナシ', '北川原台', 'キタガワラダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市深谷町', '24', '24205', '5110805', '三重県', 'ミエケン', '桑名市', 'クワナシ', '深谷町', 'フカヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市東汰上', '24', '24205', '5110806', '三重県', 'ミエケン', '桑名市', 'クワナシ', '東汰上', 'ヒガシユリアゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市西汰上', '24', '24205', '5110807', '三重県', 'ミエケン', '桑名市', 'クワナシ', '西汰上', 'ニシユリアゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市下深谷部', '24', '24205', '5110808', '三重県', 'ミエケン', '桑名市', 'クワナシ', '下深谷部', 'シモフカヤベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市上深谷部', '24', '24205', '5110809', '三重県', 'ミエケン', '桑名市', 'クワナシ', '上深谷部', 'カミフカヤベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市清竹の丘', '24', '24205', '5110810', '三重県', 'ミエケン', '桑名市', 'クワナシ', '清竹の丘', 'キヨタケノオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市東方', '24', '24205', '5110811', '三重県', 'ミエケン', '桑名市', 'クワナシ', '東方', 'ヒガシカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市尾野山', '24', '24205', '5110812', '三重県', 'ミエケン', '桑名市', 'クワナシ', '尾野山', 'オノヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市桜通', '24', '24205', '5110813', '三重県', 'ミエケン', '桑名市', 'クワナシ', '桜通', 'サクラドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市松並町', '24', '24205', '5110814', '三重県', 'ミエケン', '桑名市', 'クワナシ', '松並町', 'マツナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市梅園通', '24', '24205', '5110815', '三重県', 'ミエケン', '桑名市', 'クワナシ', '梅園通', 'ウメゾノドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市汐見町', '24', '24205', '5110816', '三重県', 'ミエケン', '桑名市', 'クワナシ', '汐見町', 'シオミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市青葉町', '24', '24205', '5110817', '三重県', 'ミエケン', '桑名市', 'クワナシ', '青葉町', 'アオバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市高塚町', '24', '24205', '5110818', '三重県', 'ミエケン', '桑名市', 'クワナシ', '高塚町', 'タカツカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市北別所', '24', '24205', '5110819', '三重県', 'ミエケン', '桑名市', 'クワナシ', '北別所', 'キタベッシヨ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市矢田', '24', '24205', '5110821', '三重県', 'ミエケン', '桑名市', 'クワナシ', '矢田', 'ヤダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市馬道', '24', '24205', '5110822', '三重県', 'ミエケン', '桑名市', 'クワナシ', '馬道', 'ウマミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市明正町', '24', '24205', '5110823', '三重県', 'ミエケン', '桑名市', 'クワナシ', '明正町', 'メイセイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市繁松新田', '24', '24205', '5110824', '三重県', 'ミエケン', '桑名市', 'クワナシ', '繁松新田', 'シゲマツシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市上野', '24', '24205', '5110825', '三重県', 'ミエケン', '桑名市', 'クワナシ', '上野', 'ウエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市太夫', '24', '24205', '5110826', '三重県', 'ミエケン', '桑名市', 'クワナシ', '太夫', 'タユウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市霞町', '24', '24205', '5110827', '三重県', 'ミエケン', '桑名市', 'クワナシ', '霞町', 'カスミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市立花町', '24', '24205', '5110828', '三重県', 'ミエケン', '桑名市', 'クワナシ', '立花町', 'タチバナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市神楽町', '24', '24205', '5110829', '三重県', 'ミエケン', '桑名市', 'クワナシ', '神楽町', 'カグラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市益生町', '24', '24205', '5110831', '三重県', 'ミエケン', '桑名市', 'クワナシ', '益生町', 'マスオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市新地', '24', '24205', '5110832', '三重県', 'ミエケン', '桑名市', 'クワナシ', '新地', 'シンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市福江町', '24', '24205', '5110833', '三重県', 'ミエケン', '桑名市', 'クワナシ', '福江町', 'フクエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市大福', '24', '24205', '5110834', '三重県', 'ミエケン', '桑名市', 'クワナシ', '大福', 'ダイフク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市本願寺', '24', '24205', '5110835', '三重県', 'ミエケン', '桑名市', 'クワナシ', '本願寺', 'ホンガンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市江場', '24', '24205', '5110836', '三重県', 'ミエケン', '桑名市', 'クワナシ', '江場', 'エバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市小泉', '24', '24205', '5110837', '三重県', 'ミエケン', '桑名市', 'クワナシ', '小泉', 'コイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市和泉', '24', '24205', '5110838', '三重県', 'ミエケン', '桑名市', 'クワナシ', '和泉', 'イズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市安永', '24', '24205', '5110839', '三重県', 'ミエケン', '桑名市', 'クワナシ', '安永', 'ヤスナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市小貝須', '24', '24205', '5110841', '三重県', 'ミエケン', '桑名市', 'クワナシ', '小貝須', 'コガイス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市立田町', '24', '24205', '5110842', '三重県', 'ミエケン', '桑名市', 'クワナシ', '立田町', 'タツタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市太平町', '24', '24205', '5110843', '三重県', 'ミエケン', '桑名市', 'クワナシ', '太平町', 'タイヘイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市福岡町', '24', '24205', '5110844', '三重県', 'ミエケン', '桑名市', 'クワナシ', '福岡町', 'フクオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市福地', '24', '24205', '5110845', '三重県', 'ミエケン', '桑名市', 'クワナシ', '福地', 'フクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市城南萱町', '24', '24205', '5110846', '三重県', 'ミエケン', '桑名市', 'クワナシ', '城南萱町', 'ジョウナンカヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市福江', '24', '24205', '5110847', '三重県', 'ミエケン', '桑名市', 'クワナシ', '福江', 'フクエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市大貝須', '24', '24205', '5110848', '三重県', 'ミエケン', '桑名市', 'クワナシ', '大貝須', 'オオガイス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市希望ケ丘', '24', '24205', '5110851', '三重県', 'ミエケン', '桑名市', 'クワナシ', '希望ケ丘', 'キボウガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市西別所', '24', '24205', '5110851', '三重県', 'ミエケン', '桑名市', 'クワナシ', '西別所', 'ニシベッシヨ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市稗田', '24', '24205', '5110852', '三重県', 'ミエケン', '桑名市', 'クワナシ', '稗田', 'ヒエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市増田', '24', '24205', '5110853', '三重県', 'ミエケン', '桑名市', 'クワナシ', '増田', 'マスダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市蓮花寺', '24', '24205', '5110854', '三重県', 'ミエケン', '桑名市', 'クワナシ', '蓮花寺', 'レンゲジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市新倉持', '24', '24205', '5110855', '三重県', 'ミエケン', '桑名市', 'クワナシ', '新倉持', 'シンクラモチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市蠣塚新田', '24', '24205', '5110861', '三重県', 'ミエケン', '桑名市', 'クワナシ', '蠣塚新田', 'カキヅカシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市播磨', '24', '24205', '5110862', '三重県', 'ミエケン', '桑名市', 'クワナシ', '播磨', 'ハリマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市新西方', '24', '24205', '5110863', '三重県', 'ミエケン', '桑名市', 'クワナシ', '新西方', 'シンニシカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市西方', '24', '24205', '5110864', '三重県', 'ミエケン', '桑名市', 'クワナシ', '西方', 'ニシカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市藤が丘', '24', '24205', '5110865', '三重県', 'ミエケン', '桑名市', 'クワナシ', '藤が丘', 'フジガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市神成町', '24', '24205', '5110866', '三重県', 'ミエケン', '桑名市', 'クワナシ', '神成町', 'シンセイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市陽だまりの丘', '24', '24205', '5110867', '三重県', 'ミエケン', '桑名市', 'クワナシ', '陽だまりの丘', 'ヒダマリノオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市筒尾', '24', '24205', '5110901', '三重県', 'ミエケン', '桑名市', 'クワナシ', '筒尾', 'ツツオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市松ノ木', '24', '24205', '5110902', '三重県', 'ミエケン', '桑名市', 'クワナシ', '松ノ木', 'マツノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市大山田', '24', '24205', '5110903', '三重県', 'ミエケン', '桑名市', 'クワナシ', '大山田', 'オオヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市野田', '24', '24205', '5110904', '三重県', 'ミエケン', '桑名市', 'クワナシ', '野田', 'ノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市額田', '24', '24205', '5110911', '三重県', 'ミエケン', '桑名市', 'クワナシ', '額田', 'ヌカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市星川', '24', '24205', '5110912', '三重県', 'ミエケン', '桑名市', 'クワナシ', '星川', 'ホシカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市星見ケ丘', '24', '24205', '5110912', '三重県', 'ミエケン', '桑名市', 'クワナシ', '星見ケ丘', 'ホシミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市里町', '24', '24205', '5110913', '三重県', 'ミエケン', '桑名市', 'クワナシ', '里町', 'サトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市中山町', '24', '24205', '5110914', '三重県', 'ミエケン', '桑名市', 'クワナシ', '中山町', 'ナカヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市東金井', '24', '24205', '5110921', '三重県', 'ミエケン', '桑名市', 'クワナシ', '東金井', 'ヒガシカナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市西金井', '24', '24205', '5110922', '三重県', 'ミエケン', '桑名市', 'クワナシ', '西金井', 'ニシカナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市桑部', '24', '24205', '5110923', '三重県', 'ミエケン', '桑名市', 'クワナシ', '桑部', 'クワベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市能部', '24', '24205', '5110931', '三重県', 'ミエケン', '桑名市', 'クワナシ', '能部', 'ノンベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市東正和台', '24', '24205', '5110932', '三重県', 'ミエケン', '桑名市', 'クワナシ', '東正和台', 'ヒガシセイワダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市西正和台', '24', '24205', '5110933', '三重県', 'ミエケン', '桑名市', 'クワナシ', '西正和台', 'ニシセイワダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市赤尾', '24', '24205', '5110934', '三重県', 'ミエケン', '桑名市', 'クワナシ', '赤尾', 'アコオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市赤尾台', '24', '24205', '5110935', '三重県', 'ミエケン', '桑名市', 'クワナシ', '赤尾台', 'アコオダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市島田', '24', '24205', '5110936', '三重県', 'ミエケン', '桑名市', 'クワナシ', '島田', 'シマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市志知', '24', '24205', '5110937', '三重県', 'ミエケン', '桑名市', 'クワナシ', '志知', 'シチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市友村', '24', '24205', '5110938', '三重県', 'ミエケン', '桑名市', 'クワナシ', '友村', 'トモムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市坂井', '24', '24205', '5110939', '三重県', 'ミエケン', '桑名市', 'クワナシ', '坂井', 'サカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市嘉例川', '24', '24205', '5110941', '三重県', 'ミエケン', '桑名市', 'クワナシ', '嘉例川', 'カレガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市広見ケ丘', '24', '24205', '5110942', '三重県', 'ミエケン', '桑名市', 'クワナシ', '広見ケ丘', 'ヒロミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市森忠', '24', '24205', '5110943', '三重県', 'ミエケン', '桑名市', 'クワナシ', '森忠', 'モリタダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市芳ケ崎', '24', '24205', '5110944', '三重県', 'ミエケン', '桑名市', 'クワナシ', '芳ケ崎', 'ハガサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市筑紫', '24', '24205', '5110945', '三重県', 'ミエケン', '桑名市', 'クワナシ', '筑紫', 'ツクシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市五反田', '24', '24205', '5110946', '三重県', 'ミエケン', '桑名市', 'クワナシ', '五反田', 'ゴタンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市大仲新田', '24', '24205', '5110947', '三重県', 'ミエケン', '桑名市', 'クワナシ', '大仲新田', 'オオナカシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市長島町新所', '24', '24205', '5111101', '三重県', 'ミエケン', '桑名市', 'クワナシ', '長島町新所', 'ナガシマチョウシンショ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市長島町西川', '24', '24205', '5111102', '三重県', 'ミエケン', '桑名市', 'クワナシ', '長島町西川', 'ナガシマチョウニシカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市長島町中川', '24', '24205', '5111103', '三重県', 'ミエケン', '桑名市', 'クワナシ', '長島町中川', 'ナガシマチョウナカガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市長島町高座', '24', '24205', '5111104', '三重県', 'ミエケン', '桑名市', 'クワナシ', '長島町高座', 'ナガシマチョウコウザ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市長島町千倉', '24', '24205', '5111105', '三重県', 'ミエケン', '桑名市', 'クワナシ', '長島町千倉', 'ナガシマチョウチクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市長島町下坂手', '24', '24205', '5111106', '三重県', 'ミエケン', '桑名市', 'クワナシ', '長島町下坂手', 'ナガシマチョウシモサカテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市長島町上坂手', '24', '24205', '5111107', '三重県', 'ミエケン', '桑名市', 'クワナシ', '長島町上坂手', 'ナガシマチョウカミサカテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市長島町杉江', '24', '24205', '5111108', '三重県', 'ミエケン', '桑名市', 'クワナシ', '長島町杉江', 'ナガシマチョウスギエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市長島町松之木', '24', '24205', '5111109', '三重県', 'ミエケン', '桑名市', 'クワナシ', '長島町松之木', 'ナガシマチョウマツノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市長島町小島', '24', '24205', '5111111', '三重県', 'ミエケン', '桑名市', 'クワナシ', '長島町小島', 'ナガシマチョウコジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市長島町大倉', '24', '24205', '5111112', '三重県', 'ミエケン', '桑名市', 'クワナシ', '長島町大倉', 'ナガシマチョウオオクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市長島町押付', '24', '24205', '5111113', '三重県', 'ミエケン', '桑名市', 'クワナシ', '長島町押付', 'ナガシマチョウオシツケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市長島町長島下町', '24', '24205', '5111114', '三重県', 'ミエケン', '桑名市', 'クワナシ', '長島町長島下町', 'ナガシマチョウナガシマシモマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市長島町長島中町', '24', '24205', '5111115', '三重県', 'ミエケン', '桑名市', 'クワナシ', '長島町長島中町', 'ナガシマチョウナガシマナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市長島町長島萱町', '24', '24205', '5111116', '三重県', 'ミエケン', '桑名市', 'クワナシ', '長島町長島萱町', 'ナガシマチョウナガシマカヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市長島町東殿名', '24', '24205', '5111121', '三重県', 'ミエケン', '桑名市', 'クワナシ', '長島町東殿名', 'ナガシマチョウヒガシトノメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市長島町松ケ島', '24', '24205', '5111122', '三重県', 'ミエケン', '桑名市', 'クワナシ', '長島町松ケ島', 'ナガシマチョウマツガシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市長島町鎌ケ地', '24', '24205', '5111123', '三重県', 'ミエケン', '桑名市', 'クワナシ', '長島町鎌ケ地', 'ナガシマチョウカマガンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市長島町葭ケ須', '24', '24205', '5111124', '三重県', 'ミエケン', '桑名市', 'クワナシ', '長島町葭ケ須', 'ナガシマチョウヨシガス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市長島町源部外面', '24', '24205', '5111125', '三重県', 'ミエケン', '桑名市', 'クワナシ', '長島町源部外面', 'ナガシマチョウゲンベドモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市長島町又木', '24', '24205', '5111126', '三重県', 'ミエケン', '桑名市', 'クワナシ', '長島町又木', 'ナガシマチョウマタギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市長島町殿名', '24', '24205', '5111127', '三重県', 'ミエケン', '桑名市', 'クワナシ', '長島町殿名', 'ナガシマチョウトノメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市長島町又木市街', '24', '24205', '5111128', '三重県', 'ミエケン', '桑名市', 'クワナシ', '長島町又木市街', 'ナガシマチョウマタギシガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市長島町赤地', '24', '24205', '5111131', '三重県', 'ミエケン', '桑名市', 'クワナシ', '長島町赤地', 'ナガシマチョウアカジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市長島町福豊', '24', '24205', '5111132', '三重県', 'ミエケン', '桑名市', 'クワナシ', '長島町福豊', 'ナガシマチョウフクトヨ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市長島町横満蔵', '24', '24205', '5111133', '三重県', 'ミエケン', '桑名市', 'クワナシ', '長島町横満蔵', 'ナガシマチョウヨコマクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市長島町松蔭', '24', '24205', '5111134', '三重県', 'ミエケン', '桑名市', 'クワナシ', '長島町松蔭', 'ナガシマチョウマツカゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市長島町浦安', '24', '24205', '5111135', '三重県', 'ミエケン', '桑名市', 'クワナシ', '長島町浦安', 'ナガシマチョウウラヤス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市長島町白鶏', '24', '24205', '5111136', '三重県', 'ミエケン', '桑名市', 'クワナシ', '長島町白鶏', 'ナガシマチョウハッケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市長島町福吉', '24', '24205', '5111137', '三重県', 'ミエケン', '桑名市', 'クワナシ', '長島町福吉', 'ナガシマチョウフクヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市長島町間々', '24', '24205', '5111141', '三重県', 'ミエケン', '桑名市', 'クワナシ', '長島町間々', 'ナガシマチョウママ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市長島町出口', '24', '24205', '5111142', '三重県', 'ミエケン', '桑名市', 'クワナシ', '長島町出口', 'ナガシマチョウデグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市長島町西外面', '24', '24205', '5111143', '三重県', 'ミエケン', '桑名市', 'クワナシ', '長島町西外面', 'ナガシマチョウニシドモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市長島町駒江', '24', '24205', '5111144', '三重県', 'ミエケン', '桑名市', 'クワナシ', '長島町駒江', 'ナガシマチョウコマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市長島町大島', '24', '24205', '5111145', '三重県', 'ミエケン', '桑名市', 'クワナシ', '長島町大島', 'ナガシマチョウオオジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市長島町十日外面', '24', '24205', '5111146', '三重県', 'ミエケン', '桑名市', 'クワナシ', '長島町十日外面', 'ナガシマチョウトオカドモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市長島町平方', '24', '24205', '5111147', '三重県', 'ミエケン', '桑名市', 'クワナシ', '長島町平方', 'ナガシマチョウヒラカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市長島町北殿名', '24', '24205', '5111148', '三重県', 'ミエケン', '桑名市', 'クワナシ', '長島町北殿名', 'ナガシマチョウキタトノメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県桑名市長島町西外面市街', '24', '24205', '5111149', '三重県', 'ミエケン', '桑名市', 'クワナシ', '長島町西外面市街', 'ナガシマチョウニシドモシガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市水沢野田町', '24', '24202', '5120301', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '水沢野田町', 'スイザワノダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市大谷台', '24', '24202', '5120901', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '大谷台', 'オオタニダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市小杉町', '24', '24202', '5120902', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '小杉町', 'コスギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市小杉新町', '24', '24202', '5120903', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '小杉新町', 'コスギシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市東坂部町', '24', '24202', '5120904', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '東坂部町', 'ヒガシサカベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市坂部が丘', '24', '24202', '5120905', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '坂部が丘', 'サカベガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市山之一色町', '24', '24202', '5120906', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '山之一色町', 'ヤマノイッシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市東ケ谷', '24', '24202', '5120907', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '東ケ谷', 'ヒガシガタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市坂部台', '24', '24202', '5120908', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '坂部台', 'サカベダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市生桑町', '24', '24202', '5120911', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '生桑町', 'イクワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市三重', '24', '24202', '5120912', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '三重', 'ミエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市西坂部町', '24', '24202', '5120913', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '西坂部町', 'ニシサカベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市南坂部町', '24', '24202', '5120914', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '南坂部町', 'ミナミサカベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市尾平町', '24', '24202', '5120921', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '尾平町', 'オビラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市曽井町', '24', '24202', '5120922', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '曽井町', 'ソイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市高角町', '24', '24202', '5120923', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '高角町', 'タカツノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市寺方町', '24', '24202', '5120924', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '寺方町', 'テラガタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市菅原町', '24', '24202', '5120925', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '菅原町', 'スガハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市浮橋', '24', '24202', '5120931', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '浮橋', 'ウキハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市小生町', '24', '24202', '5120932', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '小生町', 'コモチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市三滝台', '24', '24202', '5120933', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '三滝台', 'ミタキダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市川島町', '24', '24202', '5120934', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '川島町', 'カワシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市川島新町', '24', '24202', '5120935', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '川島新町', 'カワシマシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市別山', '24', '24202', '5120936', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '別山', 'ベツヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市内山町', '24', '24202', '5121101', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '内山町', 'ウチヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市小山町', '24', '24202', '5121102', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '小山町', 'オヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市西山町', '24', '24202', '5121103', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '西山町', 'ニシヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市美里町', '24', '24202', '5121104', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '美里町', 'ミサトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市水沢町', '24', '24202', '5121105', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '水沢町', 'スイザワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市山田町', '24', '24202', '5121111', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '山田町', 'ヤマダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市鹿間町', '24', '24202', '5121113', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '鹿間町', 'シカマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市和無田町', '24', '24202', '5121114', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '和無田町', 'ワンダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市堂ケ山町', '24', '24202', '5121115', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '堂ケ山町', 'ドウガヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市六名町', '24', '24202', '5121116', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '六名町', 'ロクミョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市上海老町', '24', '24202', '5121201', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '上海老町', 'カミエビチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市あがたが丘', '24', '24202', '5121202', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', 'あがたが丘', 'アガタガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市下海老町', '24', '24202', '5121203', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '下海老町', 'シモエビチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市赤水町', '24', '24202', '5121204', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '赤水町', 'アコズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市平尾町', '24', '24202', '5121205', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '平尾町', 'ヒラオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市江村町', '24', '24202', '5121206', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '江村町', 'エムラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市黒田町', '24', '24202', '5121207', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '黒田町', 'クロダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市北野町', '24', '24202', '5121208', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '北野町', 'キタノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市桜町', '24', '24202', '5121211', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '桜町', 'サクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市智積町', '24', '24202', '5121212', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '智積町', 'チシャクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市桜台本町', '24', '24202', '5121213', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '桜台本町', 'サクラダイホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市桜台', '24', '24202', '5121214', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '桜台', 'サクラダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市桜新町', '24', '24202', '5121215', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '桜新町', 'サクラシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市桜花台', '24', '24202', '5121216', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '桜花台', 'オウカダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市高見台', '24', '24202', '5121301', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '高見台', 'タカミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市市場町', '24', '24202', '5121302', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '市場町', 'イチバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市小牧町', '24', '24202', '5121303', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '小牧町', 'コマキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市中野町', '24', '24202', '5121304', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '中野町', 'ナカノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市西村町', '24', '24202', '5121305', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '西村町', 'ニシムラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市まきの木台', '24', '24202', '5121306', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', 'まきの木台', 'マキノキダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市山分町', '24', '24202', '5128041', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '山分町', 'ヤマケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市平津町', '24', '24202', '5128042', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '平津町', 'ヘイヅチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市平津新町', '24', '24202', '5128043', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '平津新町', 'ヘイヅシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市中村町', '24', '24202', '5128044', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '中村町', 'ナカムラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市萱生町', '24', '24202', '5128045', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '萱生町', 'カヨウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市あかつき台', '24', '24202', '5128046', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', 'あかつき台', 'アカツキダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市八千代台', '24', '24202', '5128047', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '八千代台', 'ヤチヨダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市山城町', '24', '24202', '5128048', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '山城町', 'ヤマジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市北山町', '24', '24202', '5128051', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '北山町', 'キタヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市西大鐘町', '24', '24202', '5128052', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '西大鐘町', 'ニシオオガネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市大鐘町', '24', '24202', '5128053', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '大鐘町', 'オオガネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市朝明町', '24', '24202', '5128054', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '朝明町', 'アサケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市あさけが丘', '24', '24202', '5128055', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', 'あさけが丘', 'アサケガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市札場町', '24', '24202', '5128056', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '札場町', 'サツバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市広永町', '24', '24202', '5128061', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '広永町', 'ヒロナガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市黄金町', '24', '24202', '5128062', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '黄金町', 'コガネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市山村町', '24', '24202', '5128063', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '山村町', 'ヤマムラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市伊坂町', '24', '24202', '5128064', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '伊坂町', 'イサカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市千代田町', '24', '24202', '5128065', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '千代田町', 'チヨダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県四日市市伊坂台', '24', '24202', '5128066', '三重県', 'ミエケン', '四日市市', 'ヨッカイチシ', '伊坂台', 'イサカダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市', '24', '24207', '5130000', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('55397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市広瀬町', '24', '24207', '5130001', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '広瀬町', 'ヒロセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市津賀町', '24', '24207', '5130002', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '津賀町', 'ツガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市加佐登町', '24', '24207', '5130003', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '加佐登町', 'カサドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市加佐登', '24', '24207', '5130004', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '加佐登', 'カサド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市汲川原町', '24', '24207', '5130005', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '汲川原町', 'クミガワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市和泉町', '24', '24207', '5130006', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '和泉町', 'イズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市小田町', '24', '24207', '5130007', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '小田町', 'オダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市西冨田町', '24', '24207', '5130008', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '西冨田町', 'ニシトミダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市中冨田町', '24', '24207', '5130009', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '中冨田町', 'ナカトミダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市高塚町', '24', '24207', '5130011', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '高塚町', 'タカツカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市石薬師町', '24', '24207', '5130012', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '石薬師町', 'イシヤクシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市国分町', '24', '24207', '5130013', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '国分町', 'コクブチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市高岡町', '24', '24207', '5130014', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '高岡町', 'タカオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市木田町', '24', '24207', '5130015', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '木田町', 'キダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市山辺町', '24', '24207', '5130016', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '山辺町', 'ヤマベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市上野町', '24', '24207', '5130017', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '上野町', 'ウエノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市上田町', '24', '24207', '5130018', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '上田町', 'ウエダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市高岡台', '24', '24207', '5130019', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '高岡台', 'タカオカダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市甲斐町', '24', '24207', '5130021', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '甲斐町', 'カイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市野辺町', '24', '24207', '5130022', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '野辺町', 'ノンベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市河田町', '24', '24207', '5130023', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '河田町', 'コウダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市野辺', '24', '24207', '5130024', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '野辺', 'ノンベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市竹野', '24', '24207', '5130025', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '竹野', 'タケノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市竹野町', '24', '24207', '5130026', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '竹野町', 'タケノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市岡田', '24', '24207', '5130027', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '岡田', 'オカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市岡田町', '24', '24207', '5130028', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '岡田町', 'オカダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市一ノ宮町', '24', '24207', '5130031', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '一ノ宮町', 'イチノミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市池田町', '24', '24207', '5130032', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '池田町', 'イケダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市須賀町', '24', '24207', '5130033', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '須賀町', 'スカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市須賀', '24', '24207', '5130034', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '須賀', 'スカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市矢橋町', '24', '24207', '5130035', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '矢橋町', 'ヤバセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市矢橋', '24', '24207', '5130036', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '矢橋', 'ヤバセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市十宮', '24', '24207', '5130037', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '十宮', 'トミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市十宮町', '24', '24207', '5130038', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '十宮町', 'トミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市長太新町', '24', '24207', '5130041', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '長太新町', 'ナゴシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市長太旭町', '24', '24207', '5130042', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '長太旭町', 'ナゴアサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市長太栄町', '24', '24207', '5130043', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '長太栄町', 'ナゴサカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市北堀江町', '24', '24207', '5130044', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '北堀江町', 'キタホリエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市北堀江', '24', '24207', '5130045', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '北堀江', 'キタホリエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市南堀江', '24', '24207', '5130046', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '南堀江', 'ミナミホリエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市南堀江町', '24', '24207', '5130047', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '南堀江町', 'ミナミホリエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市南長太町', '24', '24207', '5130048', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '南長太町', 'ミナミナゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市北長太町', '24', '24207', '5130049', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '北長太町', 'キタナゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市下箕田町', '24', '24207', '5130051', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '下箕田町', 'シモミダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市下箕田', '24', '24207', '5130052', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '下箕田', 'シモミダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市中箕田町', '24', '24207', '5130053', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '中箕田町', 'ナカミダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市中箕田', '24', '24207', '5130054', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '中箕田', 'ナカミダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市上箕田町', '24', '24207', '5130055', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '上箕田町', 'カミミダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市上箕田', '24', '24207', '5130056', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '上箕田', 'カミミダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市南林崎町', '24', '24207', '5130057', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '南林崎町', 'ミナミハヤサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市林崎', '24', '24207', '5130058', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '林崎', 'ハヤサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市林崎町', '24', '24207', '5130059', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '林崎町', 'ハヤサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市神戸', '24', '24207', '5130801', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '神戸', 'カンベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市神戸本多町', '24', '24207', '5130801', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '神戸本多町', 'カンベホンダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市飯野寺家町', '24', '24207', '5130802', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '飯野寺家町', 'イイノジケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市三日市町', '24', '24207', '5130803', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '三日市町', 'ミッカイチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市三日市南', '24', '24207', '5130804', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '三日市南', 'ミッカイチミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市算所町', '24', '24207', '5130805', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '算所町', 'サンジョチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市算所', '24', '24207', '5130806', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '算所', 'サンジョ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市三日市', '24', '24207', '5130807', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '三日市', 'ミッカイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市西条町', '24', '24207', '5130808', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '西条町', 'ニシジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市西条', '24', '24207', '5130809', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '西条', 'ニシジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市柳町', '24', '24207', '5130811', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '柳町', 'ヤナギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市土師町', '24', '24207', '5130812', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '土師町', 'ハゼチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市北玉垣町', '24', '24207', '5130813', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '北玉垣町', 'キタタマガキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市東玉垣町', '24', '24207', '5130814', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '東玉垣町', 'ヒガシタマガキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市西玉垣町', '24', '24207', '5130815', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '西玉垣町', 'ニシタマガキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市南玉垣町', '24', '24207', '5130816', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '南玉垣町', 'ミナミタマガキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市桜島町', '24', '24207', '5130817', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '桜島町', 'サクラジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市安塚町', '24', '24207', '5130818', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '安塚町', 'ヤスヅカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市肥田町', '24', '24207', '5130819', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '肥田町', 'ヒダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市地子町', '24', '24207', '5130821', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '地子町', 'ジシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市末広町', '24', '24207', '5130822', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '末広町', 'スエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市道伯', '24', '24207', '5130823', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '道伯', 'ドウハク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市道伯町', '24', '24207', '5130824', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '道伯町', 'ドウハクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市住吉町', '24', '24207', '5130825', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '住吉町', 'スミヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市住吉', '24', '24207', '5130826', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '住吉', 'スミヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市大池', '24', '24207', '5130827', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '大池', 'オオイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市阿古曽町', '24', '24207', '5130828', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '阿古曽町', 'アコソチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市庄野町', '24', '24207', '5130831', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '庄野町', 'ショウノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市庄野東', '24', '24207', '5130832', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '庄野東', 'ショウノヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市庄野共進', '24', '24207', '5130833', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '庄野共進', 'ショウノキョウシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市庄野羽山', '24', '24207', '5130834', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '庄野羽山', 'ショウノハヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市平野町', '24', '24207', '5130835', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '平野町', 'ヒラノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市国府町', '24', '24207', '5130836', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '国府町', 'コウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市八野町', '24', '24207', '5130837', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '八野町', 'ハチノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市弓削町', '24', '24207', '5130841', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '弓削町', 'ユゲチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市弓削', '24', '24207', '5130842', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '弓削', 'ユゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市平田東町', '24', '24207', '5130843', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '平田東町', 'ヒラタヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市平田', '24', '24207', '5130844', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '平田', 'ヒラタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市平田新町', '24', '24207', '5130845', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '平田新町', 'ヒラタシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市平田中町', '24', '24207', '5130846', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '平田中町', 'ヒラタナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市平田町', '24', '24207', '5130847', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '平田町', 'ヒラタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市平田本町', '24', '24207', '5130848', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '平田本町', 'ヒラタホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市末広東', '24', '24207', '5130851', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '末広東', 'スエヒロヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市末広西', '24', '24207', '5130852', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '末広西', 'スエヒロニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市末広南', '24', '24207', '5130853', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '末広南', 'スエヒロミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市末広北', '24', '24207', '5130854', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '末広北', 'スエヒロキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市石垣', '24', '24207', '5130855', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '石垣', 'イシガキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市岸田町', '24', '24207', '5131121', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '岸田町', 'キシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市花川町', '24', '24207', '5131122', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '花川町', 'ハナガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市下大久保町', '24', '24207', '5131123', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '下大久保町', 'シモオオクボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市自由ヶ丘', '24', '24207', '5131124', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '自由ヶ丘', 'ジユウガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市', '24', '24201', '5140000', '三重県', 'ミエケン', '津市', 'ツシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('55519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市江戸橋', '24', '24201', '5140001', '三重県', 'ミエケン', '津市', 'ツシ', '江戸橋', 'エドバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市島崎町', '24', '24201', '5140002', '三重県', 'ミエケン', '津市', 'ツシ', '島崎町', 'シマザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市桜橋', '24', '24201', '5140003', '三重県', 'ミエケン', '津市', 'ツシ', '桜橋', 'サクラバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市栄町', '24', '24201', '5140004', '三重県', 'ミエケン', '津市', 'ツシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市鳥居町', '24', '24201', '5140005', '三重県', 'ミエケン', '津市', 'ツシ', '鳥居町', 'トリイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市広明町', '24', '24201', '5140006', '三重県', 'ミエケン', '津市', 'ツシ', '広明町', 'コウメイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市大谷町', '24', '24201', '5140007', '三重県', 'ミエケン', '津市', 'ツシ', '大谷町', 'オオタニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市上浜町', '24', '24201', '5140008', '三重県', 'ミエケン', '津市', 'ツシ', '上浜町', 'カミハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市羽所町', '24', '24201', '5140009', '三重県', 'ミエケン', '津市', 'ツシ', '羽所町', 'ハドコロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市なぎさまち', '24', '24201', '5140010', '三重県', 'ミエケン', '津市', 'ツシ', 'なぎさまち', 'ナギサマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市高洲町', '24', '24201', '5140011', '三重県', 'ミエケン', '津市', 'ツシ', '高洲町', 'タカスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市末広町', '24', '24201', '5140012', '三重県', 'ミエケン', '津市', 'ツシ', '末広町', 'スエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市海岸町', '24', '24201', '5140013', '三重県', 'ミエケン', '津市', 'ツシ', '海岸町', 'カイガンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市港町', '24', '24201', '5140014', '三重県', 'ミエケン', '津市', 'ツシ', '港町', 'ミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市寿町', '24', '24201', '5140015', '三重県', 'ミエケン', '津市', 'ツシ', '寿町', 'コトブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市乙部', '24', '24201', '5140016', '三重県', 'ミエケン', '津市', 'ツシ', '乙部', 'オトベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市相生町', '24', '24201', '5140017', '三重県', 'ミエケン', '津市', 'ツシ', '相生町', 'アイオイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市中河原', '24', '24201', '5140018', '三重県', 'ミエケン', '津市', 'ツシ', '中河原', 'ナカガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市住吉町', '24', '24201', '5140019', '三重県', 'ミエケン', '津市', 'ツシ', '住吉町', 'スミヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市万町津', '24', '24201', '5140021', '三重県', 'ミエケン', '津市', 'ツシ', '万町津', 'ヨロズマチツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市愛宕町', '24', '24201', '5140022', '三重県', 'ミエケン', '津市', 'ツシ', '愛宕町', 'アタゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市北町津', '24', '24201', '5140023', '三重県', 'ミエケン', '津市', 'ツシ', '北町津', 'キタマチツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市新立町津', '24', '24201', '5140024', '三重県', 'ミエケン', '津市', 'ツシ', '新立町津', 'シンタテマチツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市東町津', '24', '24201', '5140025', '三重県', 'ミエケン', '津市', 'ツシ', '東町津', 'ヒガシマチツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市新東町塔世', '24', '24201', '5140026', '三重県', 'ミエケン', '津市', 'ツシ', '新東町塔世', 'シンヒガシマチトウセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市大門', '24', '24201', '5140027', '三重県', 'ミエケン', '津市', 'ツシ', '大門', 'ダイモン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市東丸之内', '24', '24201', '5140028', '三重県', 'ミエケン', '津市', 'ツシ', '東丸之内', 'ヒガシマルノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市北丸之内', '24', '24201', '5140031', '三重県', 'ミエケン', '津市', 'ツシ', '北丸之内', 'キタマルノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市中央', '24', '24201', '5140032', '三重県', 'ミエケン', '津市', 'ツシ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市丸之内', '24', '24201', '5140033', '三重県', 'ミエケン', '津市', 'ツシ', '丸之内', 'マルノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市南丸之内', '24', '24201', '5140034', '三重県', 'ミエケン', '津市', 'ツシ', '南丸之内', 'ミナミマルノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市西丸之内', '24', '24201', '5140035', '三重県', 'ミエケン', '津市', 'ツシ', '西丸之内', 'ニシマルノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市丸之内養正町', '24', '24201', '5140036', '三重県', 'ミエケン', '津市', 'ツシ', '丸之内養正町', 'マルノウチヨウセイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市東古河町', '24', '24201', '5140037', '三重県', 'ミエケン', '津市', 'ツシ', '東古河町', 'ヒガシフルカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市西古河町', '24', '24201', '5140038', '三重県', 'ミエケン', '津市', 'ツシ', '西古河町', 'ニシフルカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市押加部町', '24', '24201', '5140039', '三重県', 'ミエケン', '津市', 'ツシ', '押加部町', 'オシカベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市八町', '24', '24201', '5140041', '三重県', 'ミエケン', '津市', 'ツシ', '八町', 'ハッチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市新町', '24', '24201', '5140042', '三重県', 'ミエケン', '津市', 'ツシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市南新町', '24', '24201', '5140043', '三重県', 'ミエケン', '津市', 'ツシ', '南新町', 'ミナミシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市川添町', '24', '24201', '5140044', '三重県', 'ミエケン', '津市', 'ツシ', '川添町', 'カワゾエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市美川町', '24', '24201', '5140045', '三重県', 'ミエケン', '津市', 'ツシ', '美川町', 'ミカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市大園町', '24', '24201', '5140046', '三重県', 'ミエケン', '津市', 'ツシ', '大園町', 'オオゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市桜田町', '24', '24201', '5140047', '三重県', 'ミエケン', '津市', 'ツシ', '桜田町', 'サクラダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市納所町', '24', '24201', '5140051', '三重県', 'ミエケン', '津市', 'ツシ', '納所町', 'ノウソチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市神納町', '24', '24201', '5140052', '三重県', 'ミエケン', '津市', 'ツシ', '神納町', 'カノウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市博多町', '24', '24201', '5140053', '三重県', 'ミエケン', '津市', 'ツシ', '博多町', 'ハカタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市神納', '24', '24201', '5140054', '三重県', 'ミエケン', '津市', 'ツシ', '神納', 'カノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市南河路', '24', '24201', '5140055', '三重県', 'ミエケン', '津市', 'ツシ', '南河路', 'ミナミコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市北河路町', '24', '24201', '5140056', '三重県', 'ミエケン', '津市', 'ツシ', '北河路町', 'キタコウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市一色町', '24', '24201', '5140057', '三重県', 'ミエケン', '津市', 'ツシ', '一色町', 'イッシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市安東町', '24', '24201', '5140058', '三重県', 'ミエケン', '津市', 'ツシ', '安東町', 'アントウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市一身田上津部田', '24', '24201', '5140061', '三重県', 'ミエケン', '津市', 'ツシ', '一身田上津部田', 'イッシンデンコウヅベタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市観音寺町', '24', '24201', '5140062', '三重県', 'ミエケン', '津市', 'ツシ', '観音寺町', 'カンオンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市渋見町', '24', '24201', '5140063', '三重県', 'ミエケン', '津市', 'ツシ', '渋見町', 'シブミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市長岡町', '24', '24201', '5140064', '三重県', 'ミエケン', '津市', 'ツシ', '長岡町', 'ナガオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市河辺町', '24', '24201', '5140065', '三重県', 'ミエケン', '津市', 'ツシ', '河辺町', 'コウベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市分部', '24', '24201', '5140071', '三重県', 'ミエケン', '津市', 'ツシ', '分部', 'ワケベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市小舟', '24', '24201', '5140072', '三重県', 'ミエケン', '津市', 'ツシ', '小舟', 'オブネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市殿村', '24', '24201', '5140073', '三重県', 'ミエケン', '津市', 'ツシ', '殿村', 'トノムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市片田長谷場町', '24', '24201', '5140074', '三重県', 'ミエケン', '津市', 'ツシ', '片田長谷場町', 'カタダハセバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市片田志袋町', '24', '24201', '5140075', '三重県', 'ミエケン', '津市', 'ツシ', '片田志袋町', 'カタダシブクロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市産品', '24', '24201', '5140076', '三重県', 'ミエケン', '津市', 'ツシ', '産品', 'ウブシナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市片田長谷町', '24', '24201', '5140077', '三重県', 'ミエケン', '津市', 'ツシ', '片田長谷町', 'カタダハセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市片田田中町', '24', '24201', '5140081', '三重県', 'ミエケン', '津市', 'ツシ', '片田田中町', 'カタダタナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市片田井戸町', '24', '24201', '5140082', '三重県', 'ミエケン', '津市', 'ツシ', '片田井戸町', 'カタダイドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市片田新町', '24', '24201', '5140083', '三重県', 'ミエケン', '津市', 'ツシ', '片田新町', 'カタダシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市片田町', '24', '24201', '5140084', '三重県', 'ミエケン', '津市', 'ツシ', '片田町', 'カタダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市片田久保町', '24', '24201', '5140085', '三重県', 'ミエケン', '津市', 'ツシ', '片田久保町', 'カタダクボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市片田薬王寺町', '24', '24201', '5140086', '三重県', 'ミエケン', '津市', 'ツシ', '片田薬王寺町', 'カタダヤクオウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市白塚町', '24', '24201', '5140101', '三重県', 'ミエケン', '津市', 'ツシ', '白塚町', 'シラツカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市栗真町屋町', '24', '24201', '5140102', '三重県', 'ミエケン', '津市', 'ツシ', '栗真町屋町', 'クリママチヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市栗真中山町', '24', '24201', '5140103', '三重県', 'ミエケン', '津市', 'ツシ', '栗真中山町', 'クリマナカヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市栗真小川町', '24', '24201', '5140104', '三重県', 'ミエケン', '津市', 'ツシ', '栗真小川町', 'クリマコガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市一身田平野', '24', '24201', '5140111', '三重県', 'ミエケン', '津市', 'ツシ', '一身田平野', 'イッシンデンヒラノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市一身田中野', '24', '24201', '5140112', '三重県', 'ミエケン', '津市', 'ツシ', '一身田中野', 'イッシンデンナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市一身田大古曽', '24', '24201', '5140113', '三重県', 'ミエケン', '津市', 'ツシ', '一身田大古曽', 'イッシンデンオオゴソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市一身田町', '24', '24201', '5140114', '三重県', 'ミエケン', '津市', 'ツシ', '一身田町', 'イッシンデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市一身田豊野', '24', '24201', '5140115', '三重県', 'ミエケン', '津市', 'ツシ', '一身田豊野', 'イッシンデントヨノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市夢が丘', '24', '24201', '5140116', '三重県', 'ミエケン', '津市', 'ツシ', '夢が丘', 'ユメガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市大里山室町', '24', '24201', '5140121', '三重県', 'ミエケン', '津市', 'ツシ', '大里山室町', 'オオザトヤマムロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市大里野田町', '24', '24201', '5140122', '三重県', 'ミエケン', '津市', 'ツシ', '大里野田町', 'オオザトノダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市大里小野田町', '24', '24201', '5140123', '三重県', 'ミエケン', '津市', 'ツシ', '大里小野田町', 'オオザトコノダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市大里川北町', '24', '24201', '5140124', '三重県', 'ミエケン', '津市', 'ツシ', '大里川北町', 'オオザトカワキタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市大里窪田町', '24', '24201', '5140125', '三重県', 'ミエケン', '津市', 'ツシ', '大里窪田町', 'オオザトクボタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市大里睦合町', '24', '24201', '5140126', '三重県', 'ミエケン', '津市', 'ツシ', '大里睦合町', 'オオザトムツアイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市あのつ台', '24', '24201', '5140131', '三重県', 'ミエケン', '津市', 'ツシ', 'あのつ台', 'アノツダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市雲出鋼管町', '24', '24201', '5140301', '三重県', 'ミエケン', '津市', 'ツシ', '雲出鋼管町', 'クモズコウカンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市雲出伊倉津町', '24', '24201', '5140302', '三重県', 'ミエケン', '津市', 'ツシ', '雲出伊倉津町', 'クモズイグラヅチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市雲出長常町', '24', '24201', '5140303', '三重県', 'ミエケン', '津市', 'ツシ', '雲出長常町', 'クモズナガツネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市雲出本郷町', '24', '24201', '5140304', '三重県', 'ミエケン', '津市', 'ツシ', '雲出本郷町', 'クモズホンゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市雲出島貫町', '24', '24201', '5140305', '三重県', 'ミエケン', '津市', 'ツシ', '雲出島貫町', 'クモズシマヌキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市香良洲町稲葉', '24', '24201', '5140311', '三重県', 'ミエケン', '津市', 'ツシ', '香良洲町', 'カラスチョウ', null, null, '稲葉', 'イナバ');
INSERT INTO `ms_addresses` VALUES ('55611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市香良洲町小松', '24', '24201', '5140312', '三重県', 'ミエケン', '津市', 'ツシ', '香良洲町', 'カラスチョウ', null, null, '小松', 'コマツ');
INSERT INTO `ms_addresses` VALUES ('55612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市香良洲町浜浦', '24', '24201', '5140313', '三重県', 'ミエケン', '津市', 'ツシ', '香良洲町', 'カラスチョウ', null, null, '浜浦', 'ハマウラ');
INSERT INTO `ms_addresses` VALUES ('55613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市香良洲町高砂', '24', '24201', '5140314', '三重県', 'ミエケン', '津市', 'ツシ', '香良洲町', 'カラスチョウ', null, null, '高砂', 'タカサゴ');
INSERT INTO `ms_addresses` VALUES ('55614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市香良洲町', '24', '24201', '5140315', '三重県', 'ミエケン', '津市', 'ツシ', '香良洲町', 'カラスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市香良洲町砂原', '24', '24201', '5140321', '三重県', 'ミエケン', '津市', 'ツシ', '香良洲町', 'カラスチョウ', null, null, '砂原', 'スナハラ');
INSERT INTO `ms_addresses` VALUES ('55616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市香良洲町馬場', '24', '24201', '5140323', '三重県', 'ミエケン', '津市', 'ツシ', '香良洲町', 'カラスチョウ', null, null, '馬場', 'ババ');
INSERT INTO `ms_addresses` VALUES ('55617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市香良洲町地家', '24', '24201', '5140324', '三重県', 'ミエケン', '津市', 'ツシ', '香良洲町', 'カラスチョウ', null, null, '地家', 'ジケ');
INSERT INTO `ms_addresses` VALUES ('55618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市香良洲町桜町', '24', '24201', '5140325', '三重県', 'ミエケン', '津市', 'ツシ', '香良洲町', 'カラスチョウ', null, null, '桜町', 'サクラマチ');
INSERT INTO `ms_addresses` VALUES ('55619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市香良洲町川原', '24', '24201', '5140326', '三重県', 'ミエケン', '津市', 'ツシ', '香良洲町', 'カラスチョウ', null, null, '川原', 'カワハラ');
INSERT INTO `ms_addresses` VALUES ('55625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市船頭町津興', '24', '24201', '5140801', '三重県', 'ミエケン', '津市', 'ツシ', '船頭町津興', 'センドウマチツオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市三重町津興', '24', '24201', '5140802', '三重県', 'ミエケン', '津市', 'ツシ', '三重町津興', 'ミエチョウツオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市柳山津興', '24', '24201', '5140803', '三重県', 'ミエケン', '津市', 'ツシ', '柳山津興', 'ヤナギヤマツオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市上弁財町津興', '24', '24201', '5140804', '三重県', 'ミエケン', '津市', 'ツシ', '上弁財町津興', 'カミベザイマチツオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市下弁財町津興', '24', '24201', '5140805', '三重県', 'ミエケン', '津市', 'ツシ', '下弁財町津興', 'シモベザイマチツオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市上弁財町', '24', '24201', '5140806', '三重県', 'ミエケン', '津市', 'ツシ', '上弁財町', 'カミベザイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市阿漕町', '24', '24201', '5140811', '三重県', 'ミエケン', '津市', 'ツシ', '阿漕町', 'アコギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市津興', '24', '24201', '5140812', '三重県', 'ミエケン', '津市', 'ツシ', '津興', 'ツオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市八幡町', '24', '24201', '5140813', '三重県', 'ミエケン', '津市', 'ツシ', '八幡町', 'ヤハタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市藤枝町', '24', '24201', '5140814', '三重県', 'ミエケン', '津市', 'ツシ', '藤枝町', 'フジエダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市藤方', '24', '24201', '5140815', '三重県', 'ミエケン', '津市', 'ツシ', '藤方', 'フジカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市高茶屋小森上野町', '24', '24201', '5140816', '三重県', 'ミエケン', '津市', 'ツシ', '高茶屋小森上野町', 'タカヂャヤコモリウエノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市高茶屋小森町', '24', '24201', '5140817', '三重県', 'ミエケン', '津市', 'ツシ', '高茶屋小森町', 'タカヂャヤコモリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市城山', '24', '24201', '5140818', '三重県', 'ミエケン', '津市', 'ツシ', '城山', 'シロヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市高茶屋', '24', '24201', '5140819', '三重県', 'ミエケン', '津市', 'ツシ', '高茶屋', 'タカヂャヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市垂水', '24', '24201', '5140821', '三重県', 'ミエケン', '津市', 'ツシ', '垂水', 'タルミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市南が丘', '24', '24201', '5140822', '三重県', 'ミエケン', '津市', 'ツシ', '南が丘', 'ミナミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市半田', '24', '24201', '5140823', '三重県', 'ミエケン', '津市', 'ツシ', '半田', 'ハンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市神戸', '24', '24201', '5140824', '三重県', 'ミエケン', '津市', 'ツシ', '神戸', 'カンベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市緑が丘', '24', '24201', '5140825', '三重県', 'ミエケン', '津市', 'ツシ', '緑が丘', 'ミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市野田', '24', '24201', '5140826', '三重県', 'ミエケン', '津市', 'ツシ', '野田', 'ノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市本町', '24', '24201', '5140831', '三重県', 'ミエケン', '津市', 'ツシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市南中央', '24', '24201', '5140832', '三重県', 'ミエケン', '津市', 'ツシ', '南中央', 'ミナミチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市西阿漕町岩田', '24', '24201', '5140833', '三重県', 'ミエケン', '津市', 'ツシ', '西阿漕町岩田', 'ニシアコギチョウイワタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市大倉', '24', '24201', '5140834', '三重県', 'ミエケン', '津市', 'ツシ', '大倉', 'オオクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市幸町', '24', '24201', '5140835', '三重県', 'ミエケン', '津市', 'ツシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市野崎垣内岩田', '24', '24201', '5140836', '三重県', 'ミエケン', '津市', 'ツシ', '野崎垣内岩田', 'ノザキガイトイワタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市修成町', '24', '24201', '5140837', '三重県', 'ミエケン', '津市', 'ツシ', '修成町', 'シュウセイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市岩田', '24', '24201', '5140838', '三重県', 'ミエケン', '津市', 'ツシ', '岩田', 'イワタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市久居明神町', '24', '24201', '5141101', '三重県', 'ミエケン', '津市', 'ツシ', '久居明神町', 'ヒサイミョウジンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市久居藤ケ丘町', '24', '24201', '5141102', '三重県', 'ミエケン', '津市', 'ツシ', '久居藤ケ丘町', 'ヒサイフジガオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市久居相川町', '24', '24201', '5141103', '三重県', 'ミエケン', '津市', 'ツシ', '久居相川町', 'ヒサイアイカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市久居持川町', '24', '24201', '5141104', '三重県', 'ミエケン', '津市', 'ツシ', '久居持川町', 'ヒサイモチカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市久居北口町', '24', '24201', '5141105', '三重県', 'ミエケン', '津市', 'ツシ', '久居北口町', 'ヒサイキタグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市久居寺町', '24', '24201', '5141106', '三重県', 'ミエケン', '津市', 'ツシ', '久居寺町', 'ヒサイテラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市久居中町', '24', '24201', '5141107', '三重県', 'ミエケン', '津市', 'ツシ', '久居中町', 'ヒサイナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市久居射場町', '24', '24201', '5141108', '三重県', 'ミエケン', '津市', 'ツシ', '久居射場町', 'ヒサイイバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市久居烏木町', '24', '24201', '5141109', '三重県', 'ミエケン', '津市', 'ツシ', '久居烏木町', 'ヒサイカラスギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市久居桜が丘町', '24', '24201', '5141111', '三重県', 'ミエケン', '津市', 'ツシ', '久居桜が丘町', 'ヒサイサクラガオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市久居小野辺町', '24', '24201', '5141112', '三重県', 'ミエケン', '津市', 'ツシ', '久居小野辺町', 'ヒサイコノンベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市久居野村町', '24', '24201', '5141113', '三重県', 'ミエケン', '津市', 'ツシ', '久居野村町', 'ヒサイノムラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市久居井戸山町', '24', '24201', '5141114', '三重県', 'ミエケン', '津市', 'ツシ', '久居井戸山町', 'ヒサイイドヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市木造町', '24', '24201', '5141115', '三重県', 'ミエケン', '津市', 'ツシ', '木造町', 'コツクリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市新家町', '24', '24201', '5141116', '三重県', 'ミエケン', '津市', 'ツシ', '新家町', 'ニノミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市久居野口町', '24', '24201', '5141117', '三重県', 'ミエケン', '津市', 'ツシ', '久居野口町', 'ヒサイノグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市久居新町', '24', '24201', '5141118', '三重県', 'ミエケン', '津市', 'ツシ', '久居新町', 'ヒサイシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市久居二ノ町', '24', '24201', '5141121', '三重県', 'ミエケン', '津市', 'ツシ', '久居二ノ町', 'ヒサイニノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市川方町', '24', '24201', '5141122', '三重県', 'ミエケン', '津市', 'ツシ', '川方町', 'カワカタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市牧町', '24', '24201', '5141123', '三重県', 'ミエケン', '津市', 'ツシ', '牧町', 'マキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市須ケ瀬町', '24', '24201', '5141124', '三重県', 'ミエケン', '津市', 'ツシ', '須ケ瀬町', 'スガゼチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市久居元町', '24', '24201', '5141125', '三重県', 'ミエケン', '津市', 'ツシ', '久居元町', 'ヒサイモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市久居西鷹跡町', '24', '24201', '5141131', '三重県', 'ミエケン', '津市', 'ツシ', '久居西鷹跡町', 'ヒサイニシタカトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市久居幸町', '24', '24201', '5141132', '三重県', 'ミエケン', '津市', 'ツシ', '久居幸町', 'ヒサイサヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市久居万町', '24', '24201', '5141133', '三重県', 'ミエケン', '津市', 'ツシ', '久居万町', 'ヒサイヨロズマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市久居旅籠町', '24', '24201', '5141134', '三重県', 'ミエケン', '津市', 'ツシ', '久居旅籠町', 'ヒサイハタゴマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市久居本町', '24', '24201', '5141135', '三重県', 'ミエケン', '津市', 'ツシ', '久居本町', 'ヒサイホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市久居東鷹跡町', '24', '24201', '5141136', '三重県', 'ミエケン', '津市', 'ツシ', '久居東鷹跡町', 'ヒサイヒガシタカトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市久居小戸木町', '24', '24201', '5141137', '三重県', 'ミエケン', '津市', 'ツシ', '久居小戸木町', 'ヒサイコベキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市戸木町', '24', '24201', '5141138', '三重県', 'ミエケン', '津市', 'ツシ', '戸木町', 'ヘキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市青葉台', '24', '24201', '5141139', '三重県', 'ミエケン', '津市', 'ツシ', '青葉台', 'アオバダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市榊原町', '24', '24201', '5141251', '三重県', 'ミエケン', '津市', 'ツシ', '榊原町', 'サカキバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市稲葉町', '24', '24201', '5141252', '三重県', 'ミエケン', '津市', 'ツシ', '稲葉町', 'イナバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市久居一色町', '24', '24201', '5141253', '三重県', 'ミエケン', '津市', 'ツシ', '久居一色町', 'ヒサイイッシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市森町', '24', '24201', '5141254', '三重県', 'ミエケン', '津市', 'ツシ', '森町', 'モリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市庄田町', '24', '24201', '5141255', '三重県', 'ミエケン', '津市', 'ツシ', '庄田町', 'ショウダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市中村町', '24', '24201', '5141256', '三重県', 'ミエケン', '津市', 'ツシ', '中村町', 'ナカムラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市大鳥町', '24', '24201', '5141257', '三重県', 'ミエケン', '津市', 'ツシ', '大鳥町', 'オオドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市久居緑が丘町', '24', '24201', '5141258', '三重県', 'ミエケン', '津市', 'ツシ', '久居緑が丘町', 'ヒサイミドリガオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市美里町高座原', '24', '24201', '5142101', '三重県', 'ミエケン', '津市', 'ツシ', '美里町高座原', 'ミサトチョウコウザワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市美里町船山', '24', '24201', '5142102', '三重県', 'ミエケン', '津市', 'ツシ', '美里町船山', 'ミサトチョウフナヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市美里町日南田', '24', '24201', '5142103', '三重県', 'ミエケン', '津市', 'ツシ', '美里町日南田', 'ミサトチョウヒナタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市美里町家所', '24', '24201', '5142104', '三重県', 'ミエケン', '津市', 'ツシ', '美里町家所', 'ミサトチョウイエドコロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市美里町五百野', '24', '24201', '5142105', '三重県', 'ミエケン', '津市', 'ツシ', '美里町五百野', 'ミサトチョウイオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市美里町足坂', '24', '24201', '5142106', '三重県', 'ミエケン', '津市', 'ツシ', '美里町足坂', 'ミサトチョウアシザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市美里町穴倉', '24', '24201', '5142107', '三重県', 'ミエケン', '津市', 'ツシ', '美里町穴倉', 'ミサトチョウアナクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市美里町平木', '24', '24201', '5142111', '三重県', 'ミエケン', '津市', 'ツシ', '美里町平木', 'ミサトチョウヒラギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市美里町北長野', '24', '24201', '5142112', '三重県', 'ミエケン', '津市', 'ツシ', '美里町北長野', 'ミサトチョウキタナガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市美里町三郷', '24', '24201', '5142113', '三重県', 'ミエケン', '津市', 'ツシ', '美里町三郷', 'ミサトチョウミサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市美里町南長野', '24', '24201', '5142114', '三重県', 'ミエケン', '津市', 'ツシ', '美里町南長野', 'ミサトチョウミナミナガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市美里町桂畑', '24', '24201', '5142115', '三重県', 'ミエケン', '津市', 'ツシ', '美里町桂畑', 'ミサトチョウカツラハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市芸濃町楠原', '24', '24201', '5142201', '三重県', 'ミエケン', '津市', 'ツシ', '芸濃町楠原', 'ゲイノウチョウクスワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市芸濃町林', '24', '24201', '5142202', '三重県', 'ミエケン', '津市', 'ツシ', '芸濃町林', 'ゲイノウチョウハヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市芸濃町中縄', '24', '24201', '5142203', '三重県', 'ミエケン', '津市', 'ツシ', '芸濃町中縄', 'ゲイノウチョウナカナワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市芸濃町雲林院', '24', '24201', '5142204', '三重県', 'ミエケン', '津市', 'ツシ', '芸濃町雲林院', 'ゲイノウチョウウジイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市芸濃町多門', '24', '24201', '5142205', '三重県', 'ミエケン', '津市', 'ツシ', '芸濃町多門', 'ゲイノウチョウタモン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市芸濃町小野平', '24', '24201', '5142206', '三重県', 'ミエケン', '津市', 'ツシ', '芸濃町小野平', 'ゲイノウチョウオノヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市芸濃町河内', '24', '24201', '5142207', '三重県', 'ミエケン', '津市', 'ツシ', '芸濃町河内', 'ゲイノウチョウコウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市芸濃町忍田', '24', '24201', '5142208', '三重県', 'ミエケン', '津市', 'ツシ', '芸濃町忍田', 'ゲイノウチョウオシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市芸濃町椋本', '24', '24201', '5142211', '三重県', 'ミエケン', '津市', 'ツシ', '芸濃町椋本', 'ゲイノウチョウムクモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市芸濃町岡本', '24', '24201', '5142212', '三重県', 'ミエケン', '津市', 'ツシ', '芸濃町岡本', 'ゲイノウチョウオカモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市芸濃町北神山', '24', '24201', '5142213', '三重県', 'ミエケン', '津市', 'ツシ', '芸濃町北神山', 'ゲイノウチョウキタコヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市芸濃町萩野', '24', '24201', '5142214', '三重県', 'ミエケン', '津市', 'ツシ', '芸濃町萩野', 'ゲイノウチョウハギノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市高野尾町', '24', '24201', '5142221', '三重県', 'ミエケン', '津市', 'ツシ', '高野尾町', 'タカノオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市安濃町荒木', '24', '24201', '5142301', '三重県', 'ミエケン', '津市', 'ツシ', '安濃町荒木', 'アノウチョウアラキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市安濃町安濃', '24', '24201', '5142302', '三重県', 'ミエケン', '津市', 'ツシ', '安濃町安濃', 'アノウチョウアノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市安濃町内多', '24', '24201', '5142303', '三重県', 'ミエケン', '津市', 'ツシ', '安濃町内多', 'アノウチョウウチダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市安濃町太田', '24', '24201', '5142304', '三重県', 'ミエケン', '津市', 'ツシ', '安濃町太田', 'アノウチョウオオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市安濃町清水', '24', '24201', '5142305', '三重県', 'ミエケン', '津市', 'ツシ', '安濃町清水', 'アノウチョウシミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市安濃町曽根', '24', '24201', '5142306', '三重県', 'ミエケン', '津市', 'ツシ', '安濃町曽根', 'アノウチョウソネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市安濃町浄土寺', '24', '24201', '5142307', '三重県', 'ミエケン', '津市', 'ツシ', '安濃町浄土寺', 'アノウチョウジョウドウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市安濃町川西', '24', '24201', '5142308', '三重県', 'ミエケン', '津市', 'ツシ', '安濃町川西', 'アノウチョウカワニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市安濃町神田', '24', '24201', '5142311', '三重県', 'ミエケン', '津市', 'ツシ', '安濃町神田', 'アノウチョウコウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市安濃町連部', '24', '24201', '5142312', '三重県', 'ミエケン', '津市', 'ツシ', '安濃町連部', 'アノウチョウツラベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市安濃町今徳', '24', '24201', '5142313', '三重県', 'ミエケン', '津市', 'ツシ', '安濃町今徳', 'アノウチョウコンドク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市安濃町妙法寺', '24', '24201', '5142314', '三重県', 'ミエケン', '津市', 'ツシ', '安濃町妙法寺', 'アノウチョウミョウホウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市安濃町光明寺', '24', '24201', '5142315', '三重県', 'ミエケン', '津市', 'ツシ', '安濃町光明寺', 'アノウチョウコウミョウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市安濃町南神山', '24', '24201', '5142316', '三重県', 'ミエケン', '津市', 'ツシ', '安濃町南神山', 'アノウチョウミナミコヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市安濃町前野', '24', '24201', '5142317', '三重県', 'ミエケン', '津市', 'ツシ', '安濃町前野', 'アノウチョウマエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市安濃町中川', '24', '24201', '5142318', '三重県', 'ミエケン', '津市', 'ツシ', '安濃町中川', 'アノウチョウナカガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市安濃町野口', '24', '24201', '5142321', '三重県', 'ミエケン', '津市', 'ツシ', '安濃町野口', 'アノウチョウノグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市安濃町戸島', '24', '24201', '5142322', '三重県', 'ミエケン', '津市', 'ツシ', '安濃町戸島', 'アノウチョウトシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市安濃町大塚', '24', '24201', '5142323', '三重県', 'ミエケン', '津市', 'ツシ', '安濃町大塚', 'アノウチョウオオツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市安濃町粟加', '24', '24201', '5142324', '三重県', 'ミエケン', '津市', 'ツシ', '安濃町粟加', 'アノウチョウオウカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市安濃町田端上野', '24', '24201', '5142325', '三重県', 'ミエケン', '津市', 'ツシ', '安濃町田端上野', 'アノウチョウタバタウエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市安濃町東観音寺', '24', '24201', '5142326', '三重県', 'ミエケン', '津市', 'ツシ', '安濃町東観音寺', 'アノウチョウトウカンオンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市安濃町安部', '24', '24201', '5142327', '三重県', 'ミエケン', '津市', 'ツシ', '安濃町安部', 'アノウチョウアベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市安濃町草生', '24', '24201', '5142328', '三重県', 'ミエケン', '津市', 'ツシ', '安濃町草生', 'アノウチョウクサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市', '24', '24204', '5150000', '三重県', 'ミエケン', '松阪市', 'マツサカシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('55808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市大口町', '24', '24204', '5150001', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '大口町', 'オオクチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市郷津町', '24', '24204', '5150002', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '郷津町', 'ゴウヅチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市朝日町一区', '24', '24204', '5150003', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '朝日町一区', 'アサヒマチ01ク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市朝日町', '24', '24204', '5150004', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '朝日町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市鎌田町', '24', '24204', '5150005', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '鎌田町', 'カマダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市石津町', '24', '24204', '5150006', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '石津町', 'イシヅチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市荒木町', '24', '24204', '5150007', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '荒木町', 'アラキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市高町', '24', '24204', '5150011', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '高町', 'タカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市東町', '24', '24204', '5150012', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '東町', 'ヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市幸生町', '24', '24204', '5150013', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '幸生町', 'コウセイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市若葉町', '24', '24204', '5150014', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '若葉町', 'ワカバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市宮町', '24', '24204', '5150015', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '宮町', 'ミヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市末広町', '24', '24204', '5150016', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '末広町', 'スエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市京町', '24', '24204', '5150017', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '京町', 'キョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市京町一区', '24', '24204', '5150018', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '京町一区', 'キョウマチ01ク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市中央町', '24', '24204', '5150019', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '中央町', 'チュウオウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市古井町', '24', '24204', '5150021', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '古井町', 'コイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市新屋敷町', '24', '24204', '5150022', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '新屋敷町', 'シンヤシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市下七見町', '24', '24204', '5150023', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '下七見町', 'シモナナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市大宮田町', '24', '24204', '5150024', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '大宮田町', 'オオミヤダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市和屋町', '24', '24204', '5150025', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '和屋町', 'ワヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市立田町', '24', '24204', '5150026', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '立田町', 'タツタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市朝田町', '24', '24204', '5150027', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '朝田町', 'アサダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市佐久米町', '24', '24204', '5150028', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '佐久米町', 'サクメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市西野々町', '24', '24204', '5150029', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '西野々町', 'ニシノノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市大津町', '24', '24204', '5150031', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '大津町', 'オオツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市田原町', '24', '24204', '5150032', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '田原町', 'タワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市垣鼻町', '24', '24204', '5150033', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '垣鼻町', 'カイバナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市南町', '24', '24204', '5150034', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '南町', 'ミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市長月町', '24', '24204', '5150035', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '長月町', 'チョウゲツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市平生町', '24', '24204', '5150036', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '平生町', 'ヒラオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市愛宕町', '24', '24204', '5150037', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '愛宕町', 'アタゴマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市挽木町', '24', '24204', '5150038', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '挽木町', 'ヒキギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市清生町', '24', '24204', '5150039', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '清生町', 'セイセイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市上川町', '24', '24204', '5150041', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '上川町', 'ウエガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市虹が丘町', '24', '24204', '5150042', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '虹が丘町', 'ニジガオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市下村町', '24', '24204', '5150043', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '下村町', 'シモムラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市久保町', '24', '24204', '5150044', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '久保町', 'クボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市駅部田町', '24', '24204', '5150045', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '駅部田町', 'マエノヘタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市南虹が丘町', '24', '24204', '5150046', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '南虹が丘町', 'ミナミニジガオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市光町', '24', '24204', '5150051', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '光町', 'ヒカリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市山室町', '24', '24204', '5150052', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '山室町', 'ヤマムロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市広陽町', '24', '24204', '5150053', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '広陽町', 'コウヨウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市立野町', '24', '24204', '5150054', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '立野町', 'タチノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市田村町', '24', '24204', '5150055', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '田村町', 'タムラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市宝塚町', '24', '24204', '5150056', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '宝塚町', 'タカラヅカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市御殿山町', '24', '24204', '5150057', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '御殿山町', 'ゴテンヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市黒田町', '24', '24204', '5150061', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '黒田町', 'クロダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市小黒田町', '24', '24204', '5150062', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '小黒田町', 'コクロダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市大黒田町', '24', '24204', '5150063', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '大黒田町', 'オオクロダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市五反田町', '24', '24204', '5150064', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '五反田町', 'ゴタンダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市五月町', '24', '24204', '5150065', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '五月町', 'サツキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市泉町', '24', '24204', '5150066', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '泉町', 'イズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市桜町', '24', '24204', '5150071', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '桜町', 'サクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市内五曲町', '24', '24204', '5150072', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '内五曲町', 'ウチゴマガリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市殿町', '24', '24204', '5150073', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '殿町', 'トノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市新座町', '24', '24204', '5150074', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '新座町', 'シンザマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市新町', '24', '24204', '5150075', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市白粉町', '24', '24204', '5150076', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '白粉町', 'オシロイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市茶与町', '24', '24204', '5150077', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '茶与町', 'チャヨマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市春日町', '24', '24204', '5150078', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '春日町', 'カスガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市本町', '24', '24204', '5150081', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市魚町', '24', '24204', '5150082', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '魚町', 'ウオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市中町', '24', '24204', '5150083', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '中町', 'ナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市日野町', '24', '24204', '5150084', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '日野町', 'ヒノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市湊町', '24', '24204', '5150085', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '湊町', 'ミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市五十鈴町', '24', '24204', '5150086', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '五十鈴町', 'イスズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市萌木町', '24', '24204', '5150087', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '萌木町', 'モエギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市木の郷町', '24', '24204', '5150088', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '木の郷町', 'キノサトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市東黒部町', '24', '24204', '5150101', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '東黒部町', 'ヒガシクロベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市松名瀬町', '24', '24204', '5150102', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '松名瀬町', 'マツナセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市西黒部町', '24', '24204', '5150103', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '西黒部町', 'ニシクロベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市高須町', '24', '24204', '5150104', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '高須町', 'タカスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市柿木原町', '24', '24204', '5150111', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '柿木原町', 'カキノキハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市土古路町', '24', '24204', '5150112', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '土古路町', 'トコロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市出間町', '24', '24204', '5150113', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '出間町', 'イズマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市大垣内町', '24', '24204', '5150114', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '大垣内町', 'オオガイトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市蓮花寺町', '24', '24204', '5150115', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '蓮花寺町', 'レンゲジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市牛草町', '24', '24204', '5150116', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '牛草町', 'ウシクサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市乙部町', '24', '24204', '5150117', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '乙部町', 'オトベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市垣内田町', '24', '24204', '5150118', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '垣内田町', 'カイトダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市神守町', '24', '24204', '5150119', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '神守町', 'カンモリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市東久保町', '24', '24204', '5150121', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '東久保町', 'ヒガシクボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市川島町', '24', '24204', '5150122', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '川島町', 'カワシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市新開町', '24', '24204', '5150123', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '新開町', 'シンガイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市保津町', '24', '24204', '5150124', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '保津町', 'ホウヅチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市腹太町', '24', '24204', '5150125', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '腹太町', 'ハラフトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市井口中町', '24', '24204', '5150126', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '井口中町', 'イグチナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市六根町', '24', '24204', '5150127', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '六根町', 'ロッコンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市魚見町', '24', '24204', '5150128', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '魚見町', 'ウオミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市上七見町', '24', '24204', '5150201', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '上七見町', 'カミナナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市菅生町', '24', '24204', '5150202', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '菅生町', 'スギュウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市清水町', '24', '24204', '5150203', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '清水町', 'シミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市櫛田町', '24', '24204', '5150204', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '櫛田町', 'クシダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市豊原町', '24', '24204', '5150205', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '豊原町', 'トヨハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市山下町', '24', '24204', '5150206', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '山下町', 'ヤマシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市安楽町', '24', '24204', '5150207', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '安楽町', 'アンラクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市山添町', '24', '24204', '5150208', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '山添町', 'ヤマゾエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市高木町', '24', '24204', '5150211', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '高木町', 'タカキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市稲木町', '24', '24204', '5150212', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '稲木町', 'イナギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市伊勢場町', '24', '24204', '5150213', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '伊勢場町', 'イセバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市法田町', '24', '24204', '5150214', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '法田町', 'ホウダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市横地町', '24', '24204', '5150215', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '横地町', 'ヨコチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市目田町', '24', '24204', '5150216', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '目田町', 'メダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市早馬瀬町', '24', '24204', '5150217', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '早馬瀬町', 'ハヤマゼチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡明和町', '24', '24442', '5150300', '三重県', 'ミエケン', '多気郡明和町', 'タキグンメイワチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('55914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡明和町大堀川新田', '24', '24442', '5150301', '三重県', 'ミエケン', '多気郡明和町', 'タキグンメイワチョウ', '大堀川新田', 'オオホリカワシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡明和町大淀', '24', '24442', '5150302', '三重県', 'ミエケン', '多気郡明和町', 'タキグンメイワチョウ', '大淀', 'オオヨド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡明和町山大淀', '24', '24442', '5150303', '三重県', 'ミエケン', '多気郡明和町', 'タキグンメイワチョウ', '山大淀', 'ヤマオオヨド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡明和町平尾', '24', '24442', '5150311', '三重県', 'ミエケン', '多気郡明和町', 'タキグンメイワチョウ', '平尾', 'ヒラオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡明和町上野', '24', '24442', '5150312', '三重県', 'ミエケン', '多気郡明和町', 'タキグンメイワチョウ', '上野', 'ウエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡明和町明星', '24', '24442', '5150313', '三重県', 'ミエケン', '多気郡明和町', 'タキグンメイワチョウ', '明星', 'ミョウジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡明和町新茶屋', '24', '24442', '5150314', '三重県', 'ミエケン', '多気郡明和町', 'タキグンメイワチョウ', '新茶屋', 'シンチャヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡明和町蓑村', '24', '24442', '5150315', '三重県', 'ミエケン', '多気郡明和町', 'タキグンメイワチョウ', '蓑村', 'ミノムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡明和町有爾中', '24', '24442', '5150316', '三重県', 'ミエケン', '多気郡明和町', 'タキグンメイワチョウ', '有爾中', 'ウニナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡明和町池村', '24', '24442', '5150317', '三重県', 'ミエケン', '多気郡明和町', 'タキグンメイワチョウ', '池村', 'イケムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡明和町斎宮', '24', '24442', '5150321', '三重県', 'ミエケン', '多気郡明和町', 'タキグンメイワチョウ', '斎宮', 'サイクウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡明和町上村', '24', '24442', '5150322', '三重県', 'ミエケン', '多気郡明和町', 'タキグンメイワチョウ', '上村', 'ウエムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡明和町岩内', '24', '24442', '5150323', '三重県', 'ミエケン', '多気郡明和町', 'タキグンメイワチョウ', '岩内', 'ヨウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡明和町金剛坂', '24', '24442', '5150324', '三重県', 'ミエケン', '多気郡明和町', 'タキグンメイワチョウ', '金剛坂', 'コンゴウザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡明和町竹川', '24', '24442', '5150325', '三重県', 'ミエケン', '多気郡明和町', 'タキグンメイワチョウ', '竹川', 'タケガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡明和町佐田', '24', '24442', '5150331', '三重県', 'ミエケン', '多気郡明和町', 'タキグンメイワチョウ', '佐田', 'サタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡明和町馬之上', '24', '24442', '5150332', '三重県', 'ミエケン', '多気郡明和町', 'タキグンメイワチョウ', '馬之上', 'ウマノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡明和町坂本', '24', '24442', '5150333', '三重県', 'ミエケン', '多気郡明和町', 'タキグンメイワチョウ', '坂本', 'サカモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡明和町中海', '24', '24442', '5150334', '三重県', 'ミエケン', '多気郡明和町', 'タキグンメイワチョウ', '中海', 'ナコミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡明和町北藤原', '24', '24442', '5150341', '三重県', 'ミエケン', '多気郡明和町', 'タキグンメイワチョウ', '北藤原', 'キタフジワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡明和町南藤原', '24', '24442', '5150342', '三重県', 'ミエケン', '多気郡明和町', 'タキグンメイワチョウ', '南藤原', 'ミナミフジワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡明和町内座', '24', '24442', '5150343', '三重県', 'ミエケン', '多気郡明和町', 'タキグンメイワチョウ', '内座', 'ナイザ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡明和町養川', '24', '24442', '5150344', '三重県', 'ミエケン', '多気郡明和町', 'タキグンメイワチョウ', '養川', 'ヨウカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡明和町田屋', '24', '24442', '5150345', '三重県', 'ミエケン', '多気郡明和町', 'タキグンメイワチョウ', '田屋', 'タヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡明和町前野', '24', '24442', '5150346', '三重県', 'ミエケン', '多気郡明和町', 'タキグンメイワチョウ', '前野', 'マエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡明和町志貴', '24', '24442', '5150347', '三重県', 'ミエケン', '多気郡明和町', 'タキグンメイワチョウ', '志貴', 'シキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡明和町中村', '24', '24442', '5150348', '三重県', 'ミエケン', '多気郡明和町', 'タキグンメイワチョウ', '中村', 'ナカムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡明和町川尻', '24', '24442', '5150349', '三重県', 'ミエケン', '多気郡明和町', 'タキグンメイワチョウ', '川尻', 'カワシリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡明和町浜田', '24', '24442', '5150351', '三重県', 'ミエケン', '多気郡明和町', 'タキグンメイワチョウ', '浜田', 'ハマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡明和町八木戸', '24', '24442', '5150352', '三重県', 'ミエケン', '多気郡明和町', 'タキグンメイワチョウ', '八木戸', 'ヤキド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡明和町根倉', '24', '24442', '5150353', '三重県', 'ミエケン', '多気郡明和町', 'タキグンメイワチョウ', '根倉', 'ネグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡明和町行部', '24', '24442', '5150354', '三重県', 'ミエケン', '多気郡明和町', 'タキグンメイワチョウ', '行部', 'ユクベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市有滝町', '24', '24203', '5150501', '三重県', 'ミエケン', '伊勢市', 'イセシ', '有滝町', 'アリタキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市東豊浜町', '24', '24203', '5150502', '三重県', 'ミエケン', '伊勢市', 'イセシ', '東豊浜町', 'ヒガシトヨハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市樫原町', '24', '24203', '5150503', '三重県', 'ミエケン', '伊勢市', 'イセシ', '樫原町', 'カシワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市磯町', '24', '24203', '5150504', '三重県', 'ミエケン', '伊勢市', 'イセシ', '磯町', 'イソチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市西豊浜町', '24', '24203', '5150505', '三重県', 'ミエケン', '伊勢市', 'イセシ', '西豊浜町', 'ニシトヨハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市植山町', '24', '24203', '5150506', '三重県', 'ミエケン', '伊勢市', 'イセシ', '植山町', 'ウエヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市村松町', '24', '24203', '5150507', '三重県', 'ミエケン', '伊勢市', 'イセシ', '村松町', 'ムラマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市柏町', '24', '24203', '5150508', '三重県', 'ミエケン', '伊勢市', 'イセシ', '柏町', 'カシワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市東大淀町', '24', '24203', '5150509', '三重県', 'ミエケン', '伊勢市', 'イセシ', '東大淀町', 'ヒガシオイズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市野村町', '24', '24203', '5150511', '三重県', 'ミエケン', '伊勢市', 'イセシ', '野村町', 'ノムラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市御薗町上條三軒屋', '24', '24203', '5150521', '三重県', 'ミエケン', '伊勢市', 'イセシ', '御薗町上條', 'ミソノチョウカミジョウ', null, null, '三軒屋', 'サンゲンヤ');
INSERT INTO `ms_addresses` VALUES ('55961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市新松ケ島町', '24', '24204', '5150801', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '新松ケ島町', 'シンマツガシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市猟師町', '24', '24204', '5150802', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '猟師町', 'リョウシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市町平尾町', '24', '24204', '5150803', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '町平尾町', 'マチビラオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市大平尾町', '24', '24204', '5150804', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '大平尾町', 'オオビラオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市塚本町', '24', '24204', '5150811', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '塚本町', 'ツカモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市船江町', '24', '24204', '5150812', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '船江町', 'フナエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市大塚町', '24', '24204', '5150813', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '大塚町', 'オオツカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市久保田町', '24', '24204', '5150814', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '久保田町', 'クボタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市西町', '24', '24204', '5150815', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '西町', 'ニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市西之庄町', '24', '24204', '5150816', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '西之庄町', 'ニシノショウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市井村町', '24', '24204', '5150817', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '井村町', 'イムラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市川井町', '24', '24204', '5150818', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '川井町', 'カワイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市外五曲町', '24', '24204', '5150821', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '外五曲町', 'ソトゴマガリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市大足町', '24', '24204', '5150822', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '大足町', 'オワセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市阿形町', '24', '24204', '5150823', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '阿形町', 'アガタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市平成町', '24', '24204', '5150824', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '平成町', 'ヘイセイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市藤之木町', '24', '24204', '5150825', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '藤之木町', 'フジノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市岡本町', '24', '24204', '5150831', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '岡本町', 'オカモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市丹生寺町', '24', '24204', '5150832', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '丹生寺町', 'ニュウデラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市西野町', '24', '24204', '5150833', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '西野町', 'ニシノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市岡山町', '24', '24204', '5150834', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '岡山町', 'オカヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市日丘町', '24', '24204', '5150835', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '日丘町', 'ヒオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市曲町', '24', '24204', '5150841', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '曲町', 'マガリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市田牧町', '24', '24204', '5150842', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '田牧町', 'タイラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市殿村町', '24', '24204', '5150843', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '殿村町', 'トノムラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市八重田町', '24', '24204', '5150844', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '八重田町', 'ヤエダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市伊勢寺町', '24', '24204', '5150845', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '伊勢寺町', 'イセデラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市深長町', '24', '24204', '5150846', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '深長町', 'フコサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市岩内町', '24', '24204', '5150847', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '岩内町', 'ヨウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市野村町', '24', '24204', '5150848', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '野村町', 'ノムラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市勢津町', '24', '24204', '5151101', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '勢津町', 'セイヅチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市矢津町', '24', '24204', '5151102', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '矢津町', 'ヤヅチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市笹川町', '24', '24204', '5151103', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '笹川町', 'ササガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市桂瀬町', '24', '24204', '5151104', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '桂瀬町', 'カツラセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市大河内町', '24', '24204', '5151105', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '大河内町', 'オカワチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市辻原町', '24', '24204', '5151106', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '辻原町', 'ツジワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市阪内町', '24', '24204', '5151107', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '阪内町', 'サカナイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市広瀬町', '24', '24204', '5151201', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '広瀬町', 'ヒロセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('55999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市茅原町', '24', '24204', '5151202', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '茅原町', 'チハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市六呂木町', '24', '24204', '5151203', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '六呂木町', 'ロクロギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市小片野町', '24', '24204', '5151204', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '小片野町', 'オカタノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市大石町', '24', '24204', '5151205', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '大石町', 'オイシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市飯南町深野', '24', '24204', '5151301', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '飯南町深野', 'イイナンチョウフカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市飯南町横野', '24', '24204', '5151302', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '飯南町横野', 'イイナンチョウヨコノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市飯南町下仁柿', '24', '24204', '5151303', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '飯南町下仁柿', 'イイナンチョウシモニガキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市飯南町上仁柿', '24', '24204', '5151304', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '飯南町上仁柿', 'イイナンチョウカミニガキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市飯南町粥見', '24', '24204', '5151411', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '飯南町粥見', 'イイナンチョウカユミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市飯南町向粥見', '24', '24204', '5151412', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '飯南町向粥見', 'イイナンチョウムコウカユミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市飯南町有間野', '24', '24204', '5151413', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '飯南町有間野', 'イイナンチョウアリマノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市飯高町下滝野', '24', '24204', '5151501', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '飯高町下滝野', 'イイタカチョウシモタキノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市飯高町宮前', '24', '24204', '5151502', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '飯高町宮前', 'イイタカチョウミヤマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市飯高町野々口', '24', '24204', '5151503', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '飯高町野々口', 'イイタカチョウノノグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市飯高町作滝', '24', '24204', '5151504', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '飯高町作滝', 'イイタカチョウサクタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市飯高町赤桶', '24', '24204', '5151505', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '飯高町赤桶', 'イイタカチョウアコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市飯高町田引', '24', '24204', '5151506', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '飯高町田引', 'イイタカチョウタビキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市飯高町七日市', '24', '24204', '5151611', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '飯高町七日市', 'イイタカチョウナノカイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市飯高町富永', '24', '24204', '5151612', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '飯高町富永', 'イイタカチョウトミナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市飯高町粟野', '24', '24204', '5151613', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '飯高町粟野', 'イイタカチョウアワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市飯高町宮本', '24', '24204', '5151614', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '飯高町宮本', 'イイタカチョウミヤモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市飯高町森', '24', '24204', '5151615', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '飯高町森', 'イイタカチョウモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市飯高町青田', '24', '24204', '5151616', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '飯高町青田', 'イイタカチョウオオダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市飯高町猿山', '24', '24204', '5151617', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '飯高町猿山', 'イイタカチョウエテヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市飯高町蓮', '24', '24204', '5151618', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '飯高町蓮', 'イイタカチョウハチス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市飯高町月出', '24', '24204', '5151721', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '飯高町月出', 'イイタカチョウツキデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市飯高町加波', '24', '24204', '5151722', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '飯高町加波', 'イイタカチョウカバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市飯高町乙栗子', '24', '24204', '5151723', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '飯高町乙栗子', 'イイタカチョウオトグルス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市飯高町桑原', '24', '24204', '5151724', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '飯高町桑原', 'イイタカチョウクワバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市飯高町波瀬', '24', '24204', '5151725', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '飯高町波瀬', 'イイタカチョウハゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市飯高町太良木', '24', '24204', '5151726', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '飯高町太良木', 'イイタカチョウタラキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市飯高町草鹿野', '24', '24204', '5151727', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '飯高町草鹿野', 'イイタカチョウソウガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市飯高町舟戸', '24', '24204', '5151731', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '飯高町舟戸', 'イイタカチョウフナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市飯高町落方', '24', '24204', '5151732', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '飯高町落方', 'イイタカチョウオチカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市飯高町栃谷', '24', '24204', '5151733', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '飯高町栃谷', 'イイタカチョウトチダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市飯高町木梶', '24', '24204', '5151734', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '飯高町木梶', 'イイタカチョウキカジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市星合町', '24', '24204', '5152101', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '星合町', 'ホシアイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市五主町', '24', '24204', '5152102', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '五主町', 'ゴヌシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市笠松町', '24', '24204', '5152103', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '笠松町', 'カサマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市小舟江町', '24', '24204', '5152104', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '小舟江町', 'コブナエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市肥留町', '24', '24204', '5152105', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '肥留町', 'ヒルチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市西肥留町', '24', '24204', '5152106', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '西肥留町', 'ニシヒルチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市舞出町', '24', '24204', '5152107', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '舞出町', 'マイデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市甚目町', '24', '24204', '5152108', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '甚目町', 'ハダメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市小野江町', '24', '24204', '5152109', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '小野江町', 'オノエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市中林町', '24', '24204', '5152111', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '中林町', 'ナカバヤシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市曽原町', '24', '24204', '5152112', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '曽原町', 'ソハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市喜多村新田町', '24', '24204', '5152113', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '喜多村新田町', 'キタムラシンデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市小津町', '24', '24204', '5152114', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '小津町', 'オヅチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市中道町', '24', '24204', '5152115', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '中道町', 'ナカミチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市市場庄町', '24', '24204', '5152121', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '市場庄町', 'イチバショウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市久米町', '24', '24204', '5152122', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '久米町', 'クメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市上ノ庄町', '24', '24204', '5152123', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '上ノ庄町', 'カミノショウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市中ノ庄町', '24', '24204', '5152124', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '中ノ庄町', 'ナカノショウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市六軒町', '24', '24204', '5152131', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '六軒町', 'ロッケンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市松崎浦町', '24', '24204', '5152132', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '松崎浦町', 'マツサキウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市松ケ島町', '24', '24204', '5152133', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '松ケ島町', 'マツガシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市嬉野島田町', '24', '24204', '5152301', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '嬉野島田町', 'ウレシノシマダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市嬉野天花寺町', '24', '24204', '5152302', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '嬉野天花寺町', 'ウレシノテンゲエジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市嬉野宮古町', '24', '24204', '5152303', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '嬉野宮古町', 'ウレシノミヤコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市嬉野平生町', '24', '24204', '5152304', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '嬉野平生町', 'ウレシノヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市嬉野一志町', '24', '24204', '5152305', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '嬉野一志町', 'ウレシノイチシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市嬉野黒田町', '24', '24204', '5152311', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '嬉野黒田町', 'ウレシノクロダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市嬉野見永町', '24', '24204', '5152312', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '嬉野見永町', 'ウレシノミナガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市嬉野川原木造町', '24', '24204', '5152313', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '嬉野川原木造町', 'ウレシノカワラコツクリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市嬉野新屋庄町', '24', '24204', '5152314', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '嬉野新屋庄町', 'ウレシノニワノショウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市嬉野小村町', '24', '24204', '5152315', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '嬉野小村町', 'ウレシノコムラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市嬉野川北町', '24', '24204', '5152316', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '嬉野川北町', 'ウレシノカワギタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市嬉野野田町', '24', '24204', '5152317', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '嬉野野田町', 'ウレシノノダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市嬉野中川町', '24', '24204', '5152321', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '嬉野中川町', 'ウレシノナカガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市嬉野須賀町', '24', '24204', '5152322', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '嬉野須賀町', 'ウレシノスカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市嬉野権現前町', '24', '24204', '5152323', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '嬉野権現前町', 'ウレシノゴンゲンマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市嬉野町', '24', '24204', '5152324', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '嬉野町', 'ウレシノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市嬉野中川新町', '24', '24204', '5152325', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '嬉野中川新町', 'ウレシノナカガワシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市嬉野須賀領町', '24', '24204', '5152331', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '嬉野須賀領町', 'ウレシノスカリョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市嬉野津屋城町', '24', '24204', '5152332', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '嬉野津屋城町', 'ウレシノツヤジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市嬉野田村町', '24', '24204', '5152333', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '嬉野田村町', 'ウレシノタムラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市嬉野黒野町', '24', '24204', '5152334', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '嬉野黒野町', 'ウレシノクロノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市嬉野算所町', '24', '24204', '5152335', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '嬉野算所町', 'ウレシノサンジョチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市小野町', '24', '24204', '5152341', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '小野町', 'オオノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市大阿坂町', '24', '24204', '5152342', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '大阿坂町', 'オオアザカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市小阿坂町', '24', '24204', '5152343', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '小阿坂町', 'コアザカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市美濃田町', '24', '24204', '5152344', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '美濃田町', 'ミノダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市嬉野井之上町', '24', '24204', '5152351', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '嬉野井之上町', 'ウレシノイノウエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市嬉野八田町', '24', '24204', '5152352', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '嬉野八田町', 'ウレシノハッタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市嬉野堀之内町', '24', '24204', '5152353', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '嬉野堀之内町', 'ウレシノホリノウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市嬉野下之庄町', '24', '24204', '5152354', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '嬉野下之庄町', 'ウレシノシモノショウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市嬉野薬王寺町', '24', '24204', '5152355', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '嬉野薬王寺町', 'ウレシノヤクオウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市嬉野上野町', '24', '24204', '5152356', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '嬉野上野町', 'ウレシノウエノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市嬉野神ノ木町', '24', '24204', '5152357', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '嬉野神ノ木町', 'ウレシノカミノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市嬉野釜生田町', '24', '24204', '5152401', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '嬉野釜生田町', 'ウレシノカモダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市嬉野森本町', '24', '24204', '5152402', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '嬉野森本町', 'ウレシノモリモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市嬉野岩倉町', '24', '24204', '5152403', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '嬉野岩倉町', 'ウレシノイワクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市嬉野上小川町', '24', '24204', '5152404', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '嬉野上小川町', 'ウレシノカミオガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市嬉野小原町', '24', '24204', '5152405', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '嬉野小原町', 'ウレシノオハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市嬉野合ケ野町', '24', '24204', '5152406', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '嬉野合ケ野町', 'ウレシノゴガノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市嬉野矢下町', '24', '24204', '5152407', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '嬉野矢下町', 'ウレシノヤオロシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市嬉野宮野町', '24', '24204', '5152408', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '嬉野宮野町', 'ウレシノミヤノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市嬉野滝之川町', '24', '24204', '5152409', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '嬉野滝之川町', 'ウレシノタキノガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市与原町', '24', '24204', '5152411', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '与原町', 'ヨハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市飯福田町', '24', '24204', '5152412', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '飯福田町', 'イフタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市後山町', '24', '24204', '5152413', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '後山町', 'ウシロヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市柚原町', '24', '24204', '5152414', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '柚原町', 'ユノハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市一志町庄村', '24', '24201', '5152501', '三重県', 'ミエケン', '津市', 'ツシ', '一志町庄村', 'イチシチョウショウムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市一志町其村', '24', '24201', '5152502', '三重県', 'ミエケン', '津市', 'ツシ', '一志町其村', 'イチシチョウソノムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市一志町日置', '24', '24201', '5152503', '三重県', 'ミエケン', '津市', 'ツシ', '一志町日置', 'イチシチョウヒオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市一志町高野', '24', '24201', '5152504', '三重県', 'ミエケン', '津市', 'ツシ', '一志町高野', 'イチシチョウタカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市一志町高野高野団地', '24', '24201', '5152504', '三重県', 'ミエケン', '津市', 'ツシ', '一志町高野', 'イチシチョウタカノ', null, null, '高野団地', 'タカノダンチ');
INSERT INTO `ms_addresses` VALUES ('56107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市一志町高野野田', '24', '24201', '5152504', '三重県', 'ミエケン', '津市', 'ツシ', '一志町高野', 'イチシチョウタカノ', null, null, '野田', 'ノダ');
INSERT INTO `ms_addresses` VALUES ('56108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市一志町小戸木', '24', '24201', '5152505', '三重県', 'ミエケン', '津市', 'ツシ', '一志町小戸木', 'イチシチョウコベキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市一志町片野', '24', '24201', '5152511', '三重県', 'ミエケン', '津市', 'ツシ', '一志町片野', 'イチシチョウカタノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市一志町新沢田', '24', '24201', '5152512', '三重県', 'ミエケン', '津市', 'ツシ', '一志町新沢田', 'イチシチョウシンサワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市一志町虹が丘', '24', '24201', '5152513', '三重県', 'ミエケン', '津市', 'ツシ', '一志町虹が丘', 'イチシチョウニジガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市一志町小山', '24', '24201', '5152514', '三重県', 'ミエケン', '津市', 'ツシ', '一志町小山', 'イチシチョウオヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市一志町小山小山台地', '24', '24201', '5152514', '三重県', 'ミエケン', '津市', 'ツシ', '一志町小山', 'イチシチョウオヤマ', null, null, '小山台地', 'オヤマダイチ');
INSERT INTO `ms_addresses` VALUES ('56114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市一志町八太', '24', '24201', '5152515', '三重県', 'ミエケン', '津市', 'ツシ', '一志町八太', 'イチシチョウハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市一志町八太一志団地', '24', '24201', '5152515', '三重県', 'ミエケン', '津市', 'ツシ', '一志町八太', 'イチシチョウハタ', null, null, '一志団地', 'イチシダンチ');
INSERT INTO `ms_addresses` VALUES ('56116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市一志町田尻', '24', '24201', '5152516', '三重県', 'ミエケン', '津市', 'ツシ', '一志町田尻', 'イチシチョウタジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市一志町みのりケ丘', '24', '24201', '5152517', '三重県', 'ミエケン', '津市', 'ツシ', '一志町みのりケ丘', 'イチシチョウミノリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市一志町井関', '24', '24201', '5152521', '三重県', 'ミエケン', '津市', 'ツシ', '一志町井関', 'イチシチョウイセギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市一志町波瀬', '24', '24201', '5152522', '三重県', 'ミエケン', '津市', 'ツシ', '一志町波瀬', 'イチシチョウハゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市一志町井生', '24', '24201', '5152523', '三重県', 'ミエケン', '津市', 'ツシ', '一志町井生', 'イチシチョウイウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市一志町大仰', '24', '24201', '5152524', '三重県', 'ミエケン', '津市', 'ツシ', '一志町大仰', 'イチシチョウオオノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市一志町石橋', '24', '24201', '5152525', '三重県', 'ミエケン', '津市', 'ツシ', '一志町石橋', 'イチシチョウイシバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市一志町其倉', '24', '24201', '5152526', '三重県', 'ミエケン', '津市', 'ツシ', '一志町其倉', 'イチシチョウソノクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市白山町三ケ野', '24', '24201', '5152601', '三重県', 'ミエケン', '津市', 'ツシ', '白山町三ケ野', 'ハクサンチョウミツガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市白山町二本木', '24', '24201', '5152602', '三重県', 'ミエケン', '津市', 'ツシ', '白山町二本木', 'ハクサンチョウニホンギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市白山町川口', '24', '24201', '5152603', '三重県', 'ミエケン', '津市', 'ツシ', '白山町川口', 'ハクサンチョウカワグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市白山町岡', '24', '24201', '5152604', '三重県', 'ミエケン', '津市', 'ツシ', '白山町岡', 'ハクサンチョウオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市白山台', '24', '24201', '5152605', '三重県', 'ミエケン', '津市', 'ツシ', '白山台', 'ハクサンダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市白山町南出', '24', '24201', '5152611', '三重県', 'ミエケン', '津市', 'ツシ', '白山町南出', 'ハクサンチョウミナミデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市白山町古市', '24', '24201', '5152612', '三重県', 'ミエケン', '津市', 'ツシ', '白山町古市', 'ハクサンチョウフルイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市白山町山田野', '24', '24201', '5152613', '三重県', 'ミエケン', '津市', 'ツシ', '白山町山田野', 'ハクサンチョウヤマダノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市白山町伊勢見', '24', '24201', '5152614', '三重県', 'ミエケン', '津市', 'ツシ', '白山町伊勢見', 'ハクサンチョウイセミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市白山町八対野', '24', '24201', '5152615', '三重県', 'ミエケン', '津市', 'ツシ', '白山町八対野', 'ハクサンチョウハッタイノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市白山町稲垣', '24', '24201', '5152616', '三重県', 'ミエケン', '津市', 'ツシ', '白山町稲垣', 'ハクサンチョウイナカケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市グリンタウン榊原', '24', '24201', '5152617', '三重県', 'ミエケン', '津市', 'ツシ', 'グリンタウン榊原', 'グリンタウンサカキバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市白山町佐田', '24', '24201', '5152621', '三重県', 'ミエケン', '津市', 'ツシ', '白山町佐田', 'ハクサンチョウサダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市白山町中ノ村', '24', '24201', '5152622', '三重県', 'ミエケン', '津市', 'ツシ', '白山町中ノ村', 'ハクサンチョウナカノムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市白山町上ノ村', '24', '24201', '5152623', '三重県', 'ミエケン', '津市', 'ツシ', '白山町上ノ村', 'ハクサンチョウカミノムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市白山町垣内', '24', '24201', '5152624', '三重県', 'ミエケン', '津市', 'ツシ', '白山町垣内', 'ハクサンチョウカイト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市白山町藤', '24', '24201', '5153131', '三重県', 'ミエケン', '津市', 'ツシ', '白山町藤', 'ハクサンチョウフジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市白山町北家城', '24', '24201', '5153132', '三重県', 'ミエケン', '津市', 'ツシ', '白山町北家城', 'ハクサンチョウキタイエキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市白山町南家城', '24', '24201', '5153133', '三重県', 'ミエケン', '津市', 'ツシ', '白山町南家城', 'ハクサンチョウミナミイエキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市白山町真見', '24', '24201', '5153134', '三重県', 'ミエケン', '津市', 'ツシ', '白山町真見', 'ハクサンチョウマミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市白山町二俣', '24', '24201', '5153135', '三重県', 'ミエケン', '津市', 'ツシ', '白山町二俣', 'ハクサンチョウフタマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市白山町福田山', '24', '24201', '5153136', '三重県', 'ミエケン', '津市', 'ツシ', '白山町福田山', 'ハクサンチョウフクタヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市白山町大原', '24', '24201', '5153137', '三重県', 'ミエケン', '津市', 'ツシ', '白山町大原', 'ハクサンチョウオオバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市白山町小杉', '24', '24201', '5153138', '三重県', 'ミエケン', '津市', 'ツシ', '白山町小杉', 'ハクサンチョウコスギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市白山町城立', '24', '24201', '5153139', '三重県', 'ミエケン', '津市', 'ツシ', '白山町城立', 'ハクサンチョウジョウリュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市美杉町竹原', '24', '24201', '5153201', '三重県', 'ミエケン', '津市', 'ツシ', '美杉町竹原', 'ミスギチョウタケハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市美杉町八手俣', '24', '24201', '5153202', '三重県', 'ミエケン', '津市', 'ツシ', '美杉町八手俣', 'ミスギチョウハテマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市美杉町下之川', '24', '24201', '5153203', '三重県', 'ミエケン', '津市', 'ツシ', '美杉町下之川', 'ミスギチョウシモノガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市美杉町下多気', '24', '24201', '5153311', '三重県', 'ミエケン', '津市', 'ツシ', '美杉町下多気', 'ミスギチョウシモタゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市美杉町上多気', '24', '24201', '5153312', '三重県', 'ミエケン', '津市', 'ツシ', '美杉町上多気', 'ミスギチョウカミタゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市美杉町丹生俣', '24', '24201', '5153313', '三重県', 'ミエケン', '津市', 'ツシ', '美杉町丹生俣', 'ミスギチョウニュウノマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市美杉町八知', '24', '24201', '5153421', '三重県', 'ミエケン', '津市', 'ツシ', '美杉町八知', 'ミスギチョウヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市美杉町奥津', '24', '24201', '5153531', '三重県', 'ミエケン', '津市', 'ツシ', '美杉町奥津', 'ミスギチョウオキツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市美杉町川上', '24', '24201', '5153532', '三重県', 'ミエケン', '津市', 'ツシ', '美杉町川上', 'ミスギチョウカワカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市美杉町石名原', '24', '24201', '5153533', '三重県', 'ミエケン', '津市', 'ツシ', '美杉町石名原', 'ミスギチョウイシナハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市美杉町杉平', '24', '24201', '5153534', '三重県', 'ミエケン', '津市', 'ツシ', '美杉町杉平', 'ミスギチョウスギヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市美杉町三多気', '24', '24201', '5153535', '三重県', 'ミエケン', '津市', 'ツシ', '美杉町三多気', 'ミスギチョウミタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県津市美杉町太郎生', '24', '24201', '5153536', '三重県', 'ミエケン', '津市', 'ツシ', '美杉町太郎生', 'ミスギチョウタロオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市', '24', '24203', '5160000', '三重県', 'ミエケン', '伊勢市', 'イセシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('56189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市大湊町', '24', '24203', '5160001', '三重県', 'ミエケン', '伊勢市', 'イセシ', '大湊町', 'オオミナトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市馬瀬町', '24', '24203', '5160002', '三重県', 'ミエケン', '伊勢市', 'イセシ', '馬瀬町', 'マゼチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市下野町', '24', '24203', '5160003', '三重県', 'ミエケン', '伊勢市', 'イセシ', '下野町', 'シモノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市神社港', '24', '24203', '5160004', '三重県', 'ミエケン', '伊勢市', 'イセシ', '神社港', 'カミヤシロコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市竹ケ鼻町', '24', '24203', '5160005', '三重県', 'ミエケン', '伊勢市', 'イセシ', '竹ケ鼻町', 'タケガハナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市田尻町', '24', '24203', '5160006', '三重県', 'ミエケン', '伊勢市', 'イセシ', '田尻町', 'タジリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市小木町', '24', '24203', '5160007', '三重県', 'ミエケン', '伊勢市', 'イセシ', '小木町', 'コウギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市船江', '24', '24203', '5160008', '三重県', 'ミエケン', '伊勢市', 'イセシ', '船江', 'フナエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市河崎', '24', '24203', '5160009', '三重県', 'ミエケン', '伊勢市', 'イセシ', '河崎', 'カワサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市一色町', '24', '24203', '5160011', '三重県', 'ミエケン', '伊勢市', 'イセシ', '一色町', 'イッシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市通町', '24', '24203', '5160012', '三重県', 'ミエケン', '伊勢市', 'イセシ', '通町', 'トオリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市鹿海町', '24', '24203', '5160013', '三重県', 'ミエケン', '伊勢市', 'イセシ', '鹿海町', 'カノミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市楠部町', '24', '24203', '5160014', '三重県', 'ミエケン', '伊勢市', 'イセシ', '楠部町', 'クスベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市久世戸町', '24', '24203', '5160015', '三重県', 'ミエケン', '伊勢市', 'イセシ', '久世戸町', 'クセドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市神田久志本町', '24', '24203', '5160016', '三重県', 'ミエケン', '伊勢市', 'イセシ', '神田久志本町', 'コウダクシモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市神久', '24', '24203', '5160017', '三重県', 'ミエケン', '伊勢市', 'イセシ', '神久', 'ジンキュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市黒瀬町', '24', '24203', '5160018', '三重県', 'ミエケン', '伊勢市', 'イセシ', '黒瀬町', 'クロセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市朝熊町', '24', '24203', '5160021', '三重県', 'ミエケン', '伊勢市', 'イセシ', '朝熊町', 'アサマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市一宇田町', '24', '24203', '5160022', '三重県', 'ミエケン', '伊勢市', 'イセシ', '一宇田町', 'イチウダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市宇治館町', '24', '24203', '5160023', '三重県', 'ミエケン', '伊勢市', 'イセシ', '宇治館町', 'ウジタチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市宇治今在家町', '24', '24203', '5160024', '三重県', 'ミエケン', '伊勢市', 'イセシ', '宇治今在家町', 'ウジイマザイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市宇治中之切町', '24', '24203', '5160025', '三重県', 'ミエケン', '伊勢市', 'イセシ', '宇治中之切町', 'ウジナカノキリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市宇治浦田', '24', '24203', '5160026', '三重県', 'ミエケン', '伊勢市', 'イセシ', '宇治浦田', 'ウジウラタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市桜木町', '24', '24203', '5160027', '三重県', 'ミエケン', '伊勢市', 'イセシ', '桜木町', 'サクラギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市中村町', '24', '24203', '5160028', '三重県', 'ミエケン', '伊勢市', 'イセシ', '中村町', 'ナカムラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市尾上町', '24', '24203', '5160031', '三重県', 'ミエケン', '伊勢市', 'イセシ', '尾上町', 'オノエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市倭町', '24', '24203', '5160032', '三重県', 'ミエケン', '伊勢市', 'イセシ', '倭町', 'ヤマトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市古市町', '24', '24203', '5160033', '三重県', 'ミエケン', '伊勢市', 'イセシ', '古市町', 'フルイチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市中之町', '24', '24203', '5160034', '三重県', 'ミエケン', '伊勢市', 'イセシ', '中之町', 'ナカノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市勢田町', '24', '24203', '5160035', '三重県', 'ミエケン', '伊勢市', 'イセシ', '勢田町', 'セイタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市岡本', '24', '24203', '5160036', '三重県', 'ミエケン', '伊勢市', 'イセシ', '岡本', 'オカモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市岩渕', '24', '24203', '5160037', '三重県', 'ミエケン', '伊勢市', 'イセシ', '岩渕', 'イワブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市岩渕町', '24', '24203', '5160038', '三重県', 'ミエケン', '伊勢市', 'イセシ', '岩渕町', 'イワブチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市常磐', '24', '24203', '5160041', '三重県', 'ミエケン', '伊勢市', 'イセシ', '常磐', 'トキワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市豊川町', '24', '24203', '5160042', '三重県', 'ミエケン', '伊勢市', 'イセシ', '豊川町', 'トヨカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市藤里町', '24', '24203', '5160043', '三重県', 'ミエケン', '伊勢市', 'イセシ', '藤里町', 'フジサトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市前山町', '24', '24203', '5160044', '三重県', 'ミエケン', '伊勢市', 'イセシ', '前山町', 'マエヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市旭町', '24', '24203', '5160045', '三重県', 'ミエケン', '伊勢市', 'イセシ', '旭町', 'アサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市辻久留町', '24', '24203', '5160046', '三重県', 'ミエケン', '伊勢市', 'イセシ', '辻久留町', 'ツジクルチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市常磐町', '24', '24203', '5160047', '三重県', 'ミエケン', '伊勢市', 'イセシ', '常磐町', 'トキワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市上地町', '24', '24203', '5160051', '三重県', 'ミエケン', '伊勢市', 'イセシ', '上地町', 'ウエジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市川端町', '24', '24203', '5160052', '三重県', 'ミエケン', '伊勢市', 'イセシ', '川端町', 'カワバタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市中須町', '24', '24203', '5160053', '三重県', 'ミエケン', '伊勢市', 'イセシ', '中須町', 'ナカズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市粟野町', '24', '24203', '5160054', '三重県', 'ミエケン', '伊勢市', 'イセシ', '粟野町', 'アワノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市宮川', '24', '24203', '5160061', '三重県', 'ミエケン', '伊勢市', 'イセシ', '宮川', 'ミヤガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市浦口', '24', '24203', '5160062', '三重県', 'ミエケン', '伊勢市', 'イセシ', '浦口', 'ウラグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市浦口町', '24', '24203', '5160063', '三重県', 'ミエケン', '伊勢市', 'イセシ', '浦口町', 'ウラグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市二俣', '24', '24203', '5160064', '三重県', 'ミエケン', '伊勢市', 'イセシ', '二俣', 'フタマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市二俣町', '24', '24203', '5160065', '三重県', 'ミエケン', '伊勢市', 'イセシ', '二俣町', 'フタマタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市辻久留', '24', '24203', '5160066', '三重県', 'ミエケン', '伊勢市', 'イセシ', '辻久留', 'ツジクル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市中島', '24', '24203', '5160067', '三重県', 'ミエケン', '伊勢市', 'イセシ', '中島', 'ナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市一之木', '24', '24203', '5160071', '三重県', 'ミエケン', '伊勢市', 'イセシ', '一之木', 'イチノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市宮後', '24', '24203', '5160072', '三重県', 'ミエケン', '伊勢市', 'イセシ', '宮後', 'ミヤジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市吹上', '24', '24203', '5160073', '三重県', 'ミエケン', '伊勢市', 'イセシ', '吹上', 'フキアゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市本町', '24', '24203', '5160074', '三重県', 'ミエケン', '伊勢市', 'イセシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市一志町', '24', '24203', '5160075', '三重県', 'ミエケン', '伊勢市', 'イセシ', '一志町', 'イチシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市八日市場町', '24', '24203', '5160076', '三重県', 'ミエケン', '伊勢市', 'イセシ', '八日市場町', 'ヨウカイチバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市宮町', '24', '24203', '5160077', '三重県', 'ミエケン', '伊勢市', 'イセシ', '宮町', 'ミヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市曽祢', '24', '24203', '5160078', '三重県', 'ミエケン', '伊勢市', 'イセシ', '曽祢', 'ソネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市大世古', '24', '24203', '5160079', '三重県', 'ミエケン', '伊勢市', 'イセシ', '大世古', 'オオゼコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡南伊勢町', '24', '24472', '5160100', '三重県', 'ミエケン', '度会郡南伊勢町', 'ワタライグンミナミイセチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('56250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡南伊勢町五ケ所浦', '24', '24472', '5160101', '三重県', 'ミエケン', '度会郡南伊勢町', 'ワタライグンミナミイセチョウ', '五ケ所浦', 'ゴカショウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡南伊勢町切原', '24', '24472', '5160102', '三重県', 'ミエケン', '度会郡南伊勢町', 'ワタライグンミナミイセチョウ', '切原', 'キリハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡南伊勢町泉', '24', '24472', '5160103', '三重県', 'ミエケン', '度会郡南伊勢町', 'ワタライグンミナミイセチョウ', '泉', 'イズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡南伊勢町神津佐', '24', '24472', '5160104', '三重県', 'ミエケン', '度会郡南伊勢町', 'ワタライグンミナミイセチョウ', '神津佐', 'コンサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡南伊勢町下津浦', '24', '24472', '5160105', '三重県', 'ミエケン', '度会郡南伊勢町', 'ワタライグンミナミイセチョウ', '下津浦', 'シモツウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡南伊勢町木谷', '24', '24472', '5160106', '三重県', 'ミエケン', '度会郡南伊勢町', 'ワタライグンミナミイセチョウ', '木谷', 'キダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡南伊勢町飯満', '24', '24472', '5160107', '三重県', 'ミエケン', '度会郡南伊勢町', 'ワタライグンミナミイセチョウ', '飯満', 'ハンマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡南伊勢町中津浜浦', '24', '24472', '5160108', '三重県', 'ミエケン', '度会郡南伊勢町', 'ワタライグンミナミイセチョウ', '中津浜浦', 'ナカツハマウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡南伊勢町船越', '24', '24472', '5160109', '三重県', 'ミエケン', '度会郡南伊勢町', 'ワタライグンミナミイセチョウ', '船越', 'フナコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡南伊勢町内瀬', '24', '24472', '5160111', '三重県', 'ミエケン', '度会郡南伊勢町', 'ワタライグンミナミイセチョウ', '内瀬', 'ナイゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡南伊勢町伊勢路', '24', '24472', '5160112', '三重県', 'ミエケン', '度会郡南伊勢町', 'ワタライグンミナミイセチョウ', '伊勢路', 'イセジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡南伊勢町斎田', '24', '24472', '5160113', '三重県', 'ミエケン', '度会郡南伊勢町', 'ワタライグンミナミイセチョウ', '斎田', 'サイタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡南伊勢町始神', '24', '24472', '5160114', '三重県', 'ミエケン', '度会郡南伊勢町', 'ワタライグンミナミイセチョウ', '始神', 'ハジカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡南伊勢町押渕', '24', '24472', '5160115', '三重県', 'ミエケン', '度会郡南伊勢町', 'ワタライグンミナミイセチョウ', '押渕', 'オシブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡南伊勢町迫間浦', '24', '24472', '5160116', '三重県', 'ミエケン', '度会郡南伊勢町', 'ワタライグンミナミイセチョウ', '迫間浦', 'ハサマウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡南伊勢町礫浦', '24', '24472', '5160117', '三重県', 'ミエケン', '度会郡南伊勢町', 'ワタライグンミナミイセチョウ', '礫浦', 'サザラウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡南伊勢町相賀浦', '24', '24472', '5160118', '三重県', 'ミエケン', '度会郡南伊勢町', 'ワタライグンミナミイセチョウ', '相賀浦', 'オウカウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡南伊勢町宿浦', '24', '24472', '5160221', '三重県', 'ミエケン', '度会郡南伊勢町', 'ワタライグンミナミイセチョウ', '宿浦', 'シュクウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡南伊勢町田曽浦', '24', '24472', '5160222', '三重県', 'ミエケン', '度会郡南伊勢町', 'ワタライグンミナミイセチョウ', '田曽浦', 'タソウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市御薗町小林', '24', '24203', '5160801', '三重県', 'ミエケン', '伊勢市', 'イセシ', '御薗町小林', 'ミソノチョウオハヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市御薗町新開', '24', '24203', '5160802', '三重県', 'ミエケン', '伊勢市', 'イセシ', '御薗町新開', 'ミソノチョウシンガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市御薗町王中島', '24', '24203', '5160803', '三重県', 'ミエケン', '伊勢市', 'イセシ', '御薗町王中島', 'ミソノチョウオウナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市御薗町長屋', '24', '24203', '5160804', '三重県', 'ミエケン', '伊勢市', 'イセシ', '御薗町長屋', 'ミソノチョウナガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市御薗町高向', '24', '24203', '5160805', '三重県', 'ミエケン', '伊勢市', 'イセシ', '御薗町高向', 'ミソノチョウタカブク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市御薗町上條', '24', '24203', '5160806', '三重県', 'ミエケン', '伊勢市', 'イセシ', '御薗町上條', 'ミソノチョウカミジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市大倉町', '24', '24203', '5161101', '三重県', 'ミエケン', '伊勢市', 'イセシ', '大倉町', 'オオクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市佐八町', '24', '24203', '5161102', '三重県', 'ミエケン', '伊勢市', 'イセシ', '佐八町', 'ソウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市津村町', '24', '24203', '5161103', '三重県', 'ミエケン', '伊勢市', 'イセシ', '津村町', 'ツムラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市上野町', '24', '24203', '5161104', '三重県', 'ミエケン', '伊勢市', 'イセシ', '上野町', 'ウエノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市矢持町', '24', '24203', '5161105', '三重県', 'ミエケン', '伊勢市', 'イセシ', '矢持町', 'ヤモチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市横輪町', '24', '24203', '5161106', '三重県', 'ミエケン', '伊勢市', 'イセシ', '横輪町', 'ヨコワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市神薗町', '24', '24203', '5161107', '三重県', 'ミエケン', '伊勢市', 'イセシ', '神薗町', 'カミソノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市円座町', '24', '24203', '5161108', '三重県', 'ミエケン', '伊勢市', 'イセシ', '円座町', 'エンザチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡度会町川口', '24', '24470', '5161231', '三重県', 'ミエケン', '度会郡度会町', 'ワタライグンワタライチョウ', '川口', 'カワグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡度会町栗原', '24', '24470', '5161232', '三重県', 'ミエケン', '度会郡度会町', 'ワタライグンワタライチョウ', '栗原', 'クリハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡度会町日向', '24', '24470', '5161233', '三重県', 'ミエケン', '度会郡度会町', 'ワタライグンワタライチョウ', '日向', 'ヒナタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡度会町火打石', '24', '24470', '5161234', '三重県', 'ミエケン', '度会郡度会町', 'ワタライグンワタライチョウ', '火打石', 'ヒウチイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡度会町駒ケ野', '24', '24470', '5161235', '三重県', 'ミエケン', '度会郡度会町', 'ワタライグンワタライチョウ', '駒ケ野', 'コマガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡度会町小川', '24', '24470', '5161236', '三重県', 'ミエケン', '度会郡度会町', 'ワタライグンワタライチョウ', '小川', 'オガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡度会町五ケ町', '24', '24470', '5161237', '三重県', 'ミエケン', '度会郡度会町', 'ワタライグンワタライチョウ', '五ケ町', 'ゴカノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡度会町中之郷', '24', '24470', '5161238', '三重県', 'ミエケン', '度会郡度会町', 'ワタライグンワタライチョウ', '中之郷', 'ナカノゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡度会町柳', '24', '24470', '5161241', '三重県', 'ミエケン', '度会郡度会町', 'ワタライグンワタライチョウ', '柳', 'ヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡度会町市場', '24', '24470', '5161242', '三重県', 'ミエケン', '度会郡度会町', 'ワタライグンワタライチョウ', '市場', 'イチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡度会町和井野', '24', '24470', '5161243', '三重県', 'ミエケン', '度会郡度会町', 'ワタライグンワタライチョウ', '和井野', 'ワイノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡度会町南中村', '24', '24470', '5161244', '三重県', 'ミエケン', '度会郡度会町', 'ワタライグンワタライチョウ', '南中村', 'ミナミナカムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡度会町川上', '24', '24470', '5161245', '三重県', 'ミエケン', '度会郡度会町', 'ワタライグンワタライチョウ', '川上', 'カワカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡度会町脇出', '24', '24470', '5161246', '三重県', 'ミエケン', '度会郡度会町', 'ワタライグンワタライチョウ', '脇出', 'ワキデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡度会町小萩', '24', '24470', '5161247', '三重県', 'ミエケン', '度会郡度会町', 'ワタライグンワタライチョウ', '小萩', 'コハギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡南伊勢町道方', '24', '24472', '5161301', '三重県', 'ミエケン', '度会郡南伊勢町', 'ワタライグンミナミイセチョウ', '道方', 'ミチカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡南伊勢町大江', '24', '24472', '5161302', '三重県', 'ミエケン', '度会郡南伊勢町', 'ワタライグンミナミイセチョウ', '大江', 'オオエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡南伊勢町道行竈', '24', '24472', '5161303', '三重県', 'ミエケン', '度会郡南伊勢町', 'ワタライグンミナミイセチョウ', '道行竈', 'ミチユクガマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡南伊勢町大方竈', '24', '24472', '5161304', '三重県', 'ミエケン', '度会郡南伊勢町', 'ワタライグンミナミイセチョウ', '大方竈', 'オオカタガマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡南伊勢町阿曽浦', '24', '24472', '5161305', '三重県', 'ミエケン', '度会郡南伊勢町', 'ワタライグンミナミイセチョウ', '阿曽浦', 'アソウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡南伊勢町慥柄浦', '24', '24472', '5161306', '三重県', 'ミエケン', '度会郡南伊勢町', 'ワタライグンミナミイセチョウ', '慥柄浦', 'タシカラウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡南伊勢町贄浦', '24', '24472', '5161307', '三重県', 'ミエケン', '度会郡南伊勢町', 'ワタライグンミナミイセチョウ', '贄浦', 'ニエウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡南伊勢町奈屋浦', '24', '24472', '5161308', '三重県', 'ミエケン', '度会郡南伊勢町', 'ワタライグンミナミイセチョウ', '奈屋浦', 'ナヤウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡南伊勢町東宮', '24', '24472', '5161309', '三重県', 'ミエケン', '度会郡南伊勢町', 'ワタライグンミナミイセチョウ', '東宮', 'トウグウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡南伊勢町河内', '24', '24472', '5161421', '三重県', 'ミエケン', '度会郡南伊勢町', 'ワタライグンミナミイセチョウ', '河内', 'コウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡南伊勢町神前浦', '24', '24472', '5161422', '三重県', 'ミエケン', '度会郡南伊勢町', 'ワタライグンミナミイセチョウ', '神前浦', 'カミサキウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡南伊勢町村山', '24', '24472', '5161423', '三重県', 'ミエケン', '度会郡南伊勢町', 'ワタライグンミナミイセチョウ', '村山', 'ムラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡南伊勢町方座浦', '24', '24472', '5161531', '三重県', 'ミエケン', '度会郡南伊勢町', 'ワタライグンミナミイセチョウ', '方座浦', 'ホウザウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡南伊勢町小方竈', '24', '24472', '5161532', '三重県', 'ミエケン', '度会郡南伊勢町', 'ワタライグンミナミイセチョウ', '小方竈', 'オガタガマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡南伊勢町栃木竈', '24', '24472', '5161533', '三重県', 'ミエケン', '度会郡南伊勢町', 'ワタライグンミナミイセチョウ', '栃木竈', 'トチノキガマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡南伊勢町古和浦', '24', '24472', '5161534', '三重県', 'ミエケン', '度会郡南伊勢町', 'ワタライグンミナミイセチョウ', '古和浦', 'コワウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡南伊勢町棚橋竈', '24', '24472', '5161535', '三重県', 'ミエケン', '度会郡南伊勢町', 'ワタライグンミナミイセチョウ', '棚橋竈', 'タナハシガマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡南伊勢町新桑竈', '24', '24472', '5161536', '三重県', 'ミエケン', '度会郡南伊勢町', 'ワタライグンミナミイセチョウ', '新桑竈', 'サラクワガマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡度会町', '24', '24470', '5162100', '三重県', 'ミエケン', '度会郡度会町', 'ワタライグンワタライチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('56326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡度会町葛原', '24', '24470', '5162101', '三重県', 'ミエケン', '度会郡度会町', 'ワタライグンワタライチョウ', '葛原', 'クズワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡度会町大野木', '24', '24470', '5162102', '三重県', 'ミエケン', '度会郡度会町', 'ワタライグンワタライチョウ', '大野木', 'オオノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡度会町棚橋', '24', '24470', '5162103', '三重県', 'ミエケン', '度会郡度会町', 'ワタライグンワタライチョウ', '棚橋', 'タナハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡度会町牧戸', '24', '24470', '5162104', '三重県', 'ミエケン', '度会郡度会町', 'ワタライグンワタライチョウ', '牧戸', 'マキド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡度会町平生', '24', '24470', '5162105', '三重県', 'ミエケン', '度会郡度会町', 'ワタライグンワタライチョウ', '平生', 'ヒロオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡度会町大久保', '24', '24470', '5162106', '三重県', 'ミエケン', '度会郡度会町', 'ワタライグンワタライチョウ', '大久保', 'オオクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡度会町立岡', '24', '24470', '5162107', '三重県', 'ミエケン', '度会郡度会町', 'ワタライグンワタライチョウ', '立岡', 'タチオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡度会町鮠川', '24', '24470', '5162108', '三重県', 'ミエケン', '度会郡度会町', 'ワタライグンワタライチョウ', '鮠川', 'ハイカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡度会町下久具', '24', '24470', '5162111', '三重県', 'ミエケン', '度会郡度会町', 'ワタライグンワタライチョウ', '下久具', 'シモクグ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡度会町上久具', '24', '24470', '5162112', '三重県', 'ミエケン', '度会郡度会町', 'ワタライグンワタライチョウ', '上久具', 'カミクグ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡度会町田間', '24', '24470', '5162113', '三重県', 'ミエケン', '度会郡度会町', 'ワタライグンワタライチョウ', '田間', 'タマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡度会町当津', '24', '24470', '5162114', '三重県', 'ミエケン', '度会郡度会町', 'ワタライグンワタライチョウ', '当津', 'トウヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡度会町長原', '24', '24470', '5162115', '三重県', 'ミエケン', '度会郡度会町', 'ワタライグンワタライチョウ', '長原', 'ナガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡度会町坂井', '24', '24470', '5162116', '三重県', 'ミエケン', '度会郡度会町', 'ワタライグンワタライチョウ', '坂井', 'サカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡度会町麻加江', '24', '24470', '5162117', '三重県', 'ミエケン', '度会郡度会町', 'ワタライグンワタライチョウ', '麻加江', 'マカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡度会町田口', '24', '24470', '5162118', '三重県', 'ミエケン', '度会郡度会町', 'ワタライグンワタライチョウ', '田口', 'タグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡度会町注連指', '24', '24470', '5162119', '三重県', 'ミエケン', '度会郡度会町', 'ワタライグンワタライチョウ', '注連指', 'シメサス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鳥羽市', '24', '24211', '5170000', '三重県', 'ミエケン', '鳥羽市', 'トバシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('56377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鳥羽市神島町', '24', '24211', '5170001', '三重県', 'ミエケン', '鳥羽市', 'トバシ', '神島町', 'カミジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鳥羽市答志町', '24', '24211', '5170002', '三重県', 'ミエケン', '鳥羽市', 'トバシ', '答志町', 'トウシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鳥羽市桃取町', '24', '24211', '5170003', '三重県', 'ミエケン', '鳥羽市', 'トバシ', '桃取町', 'モモトリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鳥羽市菅島町', '24', '24211', '5170004', '三重県', 'ミエケン', '鳥羽市', 'トバシ', '菅島町', 'スガシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鳥羽市坂手町', '24', '24211', '5170005', '三重県', 'ミエケン', '鳥羽市', 'トバシ', '坂手町', 'サカテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鳥羽市鳥羽', '24', '24211', '5170011', '三重県', 'ミエケン', '鳥羽市', 'トバシ', '鳥羽', 'トバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鳥羽市池上町', '24', '24211', '5170012', '三重県', 'ミエケン', '鳥羽市', 'トバシ', '池上町', 'イケガミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鳥羽市屋内町', '24', '24211', '5170013', '三重県', 'ミエケン', '鳥羽市', 'トバシ', '屋内町', 'ヤナイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鳥羽市堅神町', '24', '24211', '5170014', '三重県', 'ミエケン', '鳥羽市', 'トバシ', '堅神町', 'カタカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鳥羽市小浜町', '24', '24211', '5170015', '三重県', 'ミエケン', '鳥羽市', 'トバシ', '小浜町', 'オハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鳥羽市安楽島町', '24', '24211', '5170021', '三重県', 'ミエケン', '鳥羽市', 'トバシ', '安楽島町', 'アラシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鳥羽市大明東町', '24', '24211', '5170022', '三重県', 'ミエケン', '鳥羽市', 'トバシ', '大明東町', 'オアキヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鳥羽市大明西町', '24', '24211', '5170023', '三重県', 'ミエケン', '鳥羽市', 'トバシ', '大明西町', 'オアキニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鳥羽市高丘町', '24', '24211', '5170024', '三重県', 'ミエケン', '鳥羽市', 'トバシ', '高丘町', 'タカオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鳥羽市浦村町', '24', '24211', '5170025', '三重県', 'ミエケン', '鳥羽市', 'トバシ', '浦村町', 'ウラムラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鳥羽市石鏡町', '24', '24211', '5170026', '三重県', 'ミエケン', '鳥羽市', 'トバシ', '石鏡町', 'イジカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鳥羽市国崎町', '24', '24211', '5170031', '三重県', 'ミエケン', '鳥羽市', 'トバシ', '国崎町', 'クザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鳥羽市相差町', '24', '24211', '5170032', '三重県', 'ミエケン', '鳥羽市', 'トバシ', '相差町', 'オウサツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鳥羽市畔蛸町', '24', '24211', '5170033', '三重県', 'ミエケン', '鳥羽市', 'トバシ', '畔蛸町', 'アダコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鳥羽市千賀町', '24', '24211', '5170034', '三重県', 'ミエケン', '鳥羽市', 'トバシ', '千賀町', 'センガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鳥羽市堅子町', '24', '24211', '5170035', '三重県', 'ミエケン', '鳥羽市', 'トバシ', '堅子町', 'カタコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鳥羽市岩倉町', '24', '24211', '5170041', '三重県', 'ミエケン', '鳥羽市', 'トバシ', '岩倉町', 'イワクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鳥羽市松尾町', '24', '24211', '5170042', '三重県', 'ミエケン', '鳥羽市', 'トバシ', '松尾町', 'マツオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鳥羽市白木町', '24', '24211', '5170043', '三重県', 'ミエケン', '鳥羽市', 'トバシ', '白木町', 'シラキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鳥羽市河内町', '24', '24211', '5170044', '三重県', 'ミエケン', '鳥羽市', 'トバシ', '河内町', 'コウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鳥羽市船津町', '24', '24211', '5170045', '三重県', 'ミエケン', '鳥羽市', 'トバシ', '船津町', 'フナツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鳥羽市幸丘', '24', '24211', '5170046', '三重県', 'ミエケン', '鳥羽市', 'トバシ', '幸丘', 'サチガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鳥羽市若杉町', '24', '24211', '5170047', '三重県', 'ミエケン', '鳥羽市', 'トバシ', '若杉町', 'ワカスギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市朝熊町池の浦', '24', '24203', '5170081', '三重県', 'ミエケン', '伊勢市', 'イセシ', '朝熊町', 'アサマチョウ', null, null, '池の浦', 'イケノウラ');
INSERT INTO `ms_addresses` VALUES ('56406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市朝熊町箕曲瀬', '24', '24203', '5170081', '三重県', 'ミエケン', '伊勢市', 'イセシ', '朝熊町', 'アサマチョウ', null, null, '箕曲瀬', 'ミノセ');
INSERT INTO `ms_addresses` VALUES ('56407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県志摩市磯部町五知', '24', '24215', '5170201', '三重県', 'ミエケン', '志摩市', 'シマシ', '磯部町五知', 'イソベチョウゴチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県志摩市磯部町沓掛', '24', '24215', '5170202', '三重県', 'ミエケン', '志摩市', 'シマシ', '磯部町沓掛', 'イソベチョウクツカケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県志摩市磯部町山田', '24', '24215', '5170203', '三重県', 'ミエケン', '志摩市', 'シマシ', '磯部町山田', 'イソベチョウヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県志摩市磯部町的矢', '24', '24215', '5170204', '三重県', 'ミエケン', '志摩市', 'シマシ', '磯部町的矢', 'イソベチョウマトヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県志摩市磯部町渡鹿野', '24', '24215', '5170205', '三重県', 'ミエケン', '志摩市', 'シマシ', '磯部町渡鹿野', 'イソベチョウワタカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県志摩市磯部町飯浜', '24', '24215', '5170206', '三重県', 'ミエケン', '志摩市', 'シマシ', '磯部町飯浜', 'イソベチョウイイハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県志摩市磯部町下之郷', '24', '24215', '5170207', '三重県', 'ミエケン', '志摩市', 'シマシ', '磯部町下之郷', 'イソベチョウシモノゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県志摩市磯部町上之郷', '24', '24215', '5170208', '三重県', 'ミエケン', '志摩市', 'シマシ', '磯部町上之郷', 'イソベチョウカミノゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県志摩市磯部町恵利原', '24', '24215', '5170209', '三重県', 'ミエケン', '志摩市', 'シマシ', '磯部町恵利原', 'イソベチョウエリハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県志摩市磯部町三ケ所', '24', '24215', '5170211', '三重県', 'ミエケン', '志摩市', 'シマシ', '磯部町三ケ所', 'イソベチョウサンガショ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県志摩市磯部町坂崎', '24', '24215', '5170212', '三重県', 'ミエケン', '志摩市', 'シマシ', '磯部町坂崎', 'イソベチョウサカザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県志摩市磯部町穴川', '24', '24215', '5170213', '三重県', 'ミエケン', '志摩市', 'シマシ', '磯部町穴川', 'イソベチョウアナガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県志摩市磯部町迫間', '24', '24215', '5170214', '三重県', 'ミエケン', '志摩市', 'シマシ', '磯部町迫間', 'イソベチョウハサマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県志摩市磯部町檜山', '24', '24215', '5170215', '三重県', 'ミエケン', '志摩市', 'シマシ', '磯部町檜山', 'イソベチョウヒヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県志摩市磯部町栗木広', '24', '24215', '5170216', '三重県', 'ミエケン', '志摩市', 'シマシ', '磯部町栗木広', 'イソベチョウクリキヒロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県志摩市磯部町山原', '24', '24215', '5170217', '三重県', 'ミエケン', '志摩市', 'シマシ', '磯部町山原', 'イソベチョウヤマハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県志摩市磯部町築地', '24', '24215', '5170218', '三重県', 'ミエケン', '志摩市', 'シマシ', '磯部町築地', 'イソベチョウツイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県志摩市浜島町桧山路', '24', '24215', '5170401', '三重県', 'ミエケン', '志摩市', 'シマシ', '浜島町桧山路', 'ハマジマチョウヒヤマジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県志摩市浜島町塩屋', '24', '24215', '5170402', '三重県', 'ミエケン', '志摩市', 'シマシ', '浜島町塩屋', 'ハマジマチョウシオヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県志摩市浜島町迫子', '24', '24215', '5170403', '三重県', 'ミエケン', '志摩市', 'シマシ', '浜島町迫子', 'ハマジマチョウハザコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県志摩市浜島町浜島', '24', '24215', '5170404', '三重県', 'ミエケン', '志摩市', 'シマシ', '浜島町浜島', 'ハマジマチョウハマジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県志摩市浜島町南張', '24', '24215', '5170405', '三重県', 'ミエケン', '志摩市', 'シマシ', '浜島町南張', 'ハマジマチョウナンバリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県志摩市', '24', '24215', '5170500', '三重県', 'ミエケン', '志摩市', 'シマシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('56432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県志摩市阿児町鵜方', '24', '24215', '5170501', '三重県', 'ミエケン', '志摩市', 'シマシ', '阿児町鵜方', 'アゴチョウウガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県志摩市阿児町神明', '24', '24215', '5170502', '三重県', 'ミエケン', '志摩市', 'シマシ', '阿児町神明', 'アゴチョウシンメイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県志摩市阿児町立神', '24', '24215', '5170503', '三重県', 'ミエケン', '志摩市', 'シマシ', '阿児町立神', 'アゴチョウタテガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県志摩市阿児町志島', '24', '24215', '5170504', '三重県', 'ミエケン', '志摩市', 'シマシ', '阿児町志島', 'アゴチョウシジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県志摩市阿児町甲賀', '24', '24215', '5170505', '三重県', 'ミエケン', '志摩市', 'シマシ', '阿児町甲賀', 'アゴチョウコウカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県志摩市阿児町国府', '24', '24215', '5170506', '三重県', 'ミエケン', '志摩市', 'シマシ', '阿児町国府', 'アゴチョウコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県志摩市阿児町安乗', '24', '24215', '5170507', '三重県', 'ミエケン', '志摩市', 'シマシ', '阿児町安乗', 'アゴチョウアノリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県志摩市大王町畔名', '24', '24215', '5170601', '三重県', 'ミエケン', '志摩市', 'シマシ', '大王町畔名', 'ダイオウチョウアゼナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県志摩市大王町名田', '24', '24215', '5170602', '三重県', 'ミエケン', '志摩市', 'シマシ', '大王町名田', 'ダイオウチョウナタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県志摩市大王町波切', '24', '24215', '5170603', '三重県', 'ミエケン', '志摩市', 'シマシ', '大王町波切', 'ダイオウチョウナキリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県志摩市大王町船越', '24', '24215', '5170604', '三重県', 'ミエケン', '志摩市', 'シマシ', '大王町船越', 'ダイオウチョウフナコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県志摩市志摩町片田', '24', '24215', '5170701', '三重県', 'ミエケン', '志摩市', 'シマシ', '志摩町片田', 'シマチョウカタダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県志摩市志摩町布施田', '24', '24215', '5170702', '三重県', 'ミエケン', '志摩市', 'シマシ', '志摩町布施田', 'シマチョウフセダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県志摩市志摩町和具', '24', '24215', '5170703', '三重県', 'ミエケン', '志摩市', 'シマシ', '志摩町和具', 'シマチョウワグ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県志摩市志摩町越賀', '24', '24215', '5170704', '三重県', 'ミエケン', '志摩市', 'シマシ', '志摩町越賀', 'シマチョウコシカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県志摩市志摩町御座', '24', '24215', '5170705', '三重県', 'ミエケン', '志摩市', 'シマシ', '志摩町御座', 'シマチョウゴザ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市', '24', '24216', '5180000', '三重県', 'ミエケン', '伊賀市', 'イガシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('56452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市佐那具町', '24', '24216', '5180001', '三重県', 'ミエケン', '伊賀市', 'イガシ', '佐那具町', 'サナグチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市千歳', '24', '24216', '5180002', '三重県', 'ミエケン', '伊賀市', 'イガシ', '千歳', 'センザイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市一之宮', '24', '24216', '5180003', '三重県', 'ミエケン', '伊賀市', 'イガシ', '一之宮', 'イチノミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市寺田', '24', '24216', '5180004', '三重県', 'ミエケン', '伊賀市', 'イガシ', '寺田', 'テラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市高畑', '24', '24216', '5180005', '三重県', 'ミエケン', '伊賀市', 'イガシ', '高畑', 'タカハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市羽根', '24', '24216', '5180006', '三重県', 'ミエケン', '伊賀市', 'イガシ', '羽根', 'ハネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市服部町', '24', '24216', '5180007', '三重県', 'ミエケン', '伊賀市', 'イガシ', '服部町', 'ハツトリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市印代', '24', '24216', '5180008', '三重県', 'ミエケン', '伊賀市', 'イガシ', '印代', 'イジロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市外山', '24', '24216', '5180011', '三重県', 'ミエケン', '伊賀市', 'イガシ', '外山', 'トヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市坂之下', '24', '24216', '5180012', '三重県', 'ミエケン', '伊賀市', 'イガシ', '坂之下', 'サカノシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市東条', '24', '24216', '5180013', '三重県', 'ミエケン', '伊賀市', 'イガシ', '東条', 'ヒガシジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市西条', '24', '24216', '5180014', '三重県', 'ミエケン', '伊賀市', 'イガシ', '西条', 'ニシジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市土橋', '24', '24216', '5180015', '三重県', 'ミエケン', '伊賀市', 'イガシ', '土橋', 'ツチハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市山神', '24', '24216', '5180016', '三重県', 'ミエケン', '伊賀市', 'イガシ', '山神', 'ヤガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市大谷', '24', '24216', '5180017', '三重県', 'ミエケン', '伊賀市', 'イガシ', '大谷', 'オオタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市諏訪', '24', '24216', '5180021', '三重県', 'ミエケン', '伊賀市', 'イガシ', '諏訪', 'スワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市三田', '24', '24216', '5180022', '三重県', 'ミエケン', '伊賀市', 'イガシ', '三田', 'ミタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市野間', '24', '24216', '5180023', '三重県', 'ミエケン', '伊賀市', 'イガシ', '野間', 'ノマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市東高倉', '24', '24216', '5180024', '三重県', 'ミエケン', '伊賀市', 'イガシ', '東高倉', 'ヒガシタカクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市西高倉', '24', '24216', '5180025', '三重県', 'ミエケン', '伊賀市', 'イガシ', '西高倉', 'ニシタカクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市岩倉', '24', '24216', '5180026', '三重県', 'ミエケン', '伊賀市', 'イガシ', '岩倉', 'イワクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市西山', '24', '24216', '5180027', '三重県', 'ミエケン', '伊賀市', 'イガシ', '西山', 'ニシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市長田', '24', '24216', '5180031', '三重県', 'ミエケン', '伊賀市', 'イガシ', '長田', 'ナガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市朝屋', '24', '24216', '5180032', '三重県', 'ミエケン', '伊賀市', 'イガシ', '朝屋', 'チョウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市大野木', '24', '24216', '5180033', '三重県', 'ミエケン', '伊賀市', 'イガシ', '大野木', 'オオノギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市大内', '24', '24216', '5180034', '三重県', 'ミエケン', '伊賀市', 'イガシ', '大内', 'オオウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市七本木', '24', '24216', '5180035', '三重県', 'ミエケン', '伊賀市', 'イガシ', '七本木', 'シチホンギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市法花', '24', '24216', '5180036', '三重県', 'ミエケン', '伊賀市', 'イガシ', '法花', 'ホッケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市依那具', '24', '24216', '5180101', '三重県', 'ミエケン', '伊賀市', 'イガシ', '依那具', 'イナグ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市市部', '24', '24216', '5180102', '三重県', 'ミエケン', '伊賀市', 'イガシ', '市部', 'イチベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市沖', '24', '24216', '5180103', '三重県', 'ミエケン', '伊賀市', 'イガシ', '沖', 'オキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市摺見', '24', '24216', '5180104', '三重県', 'ミエケン', '伊賀市', 'イガシ', '摺見', 'スルミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市比自岐', '24', '24216', '5180105', '三重県', 'ミエケン', '伊賀市', 'イガシ', '比自岐', 'ヒジキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市岡波', '24', '24216', '5180106', '三重県', 'ミエケン', '伊賀市', 'イガシ', '岡波', 'オカナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市枅川', '24', '24216', '5180107', '三重県', 'ミエケン', '伊賀市', 'イガシ', '枅川', 'ヒジキガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市才良', '24', '24216', '5180108', '三重県', 'ミエケン', '伊賀市', 'イガシ', '才良', 'ザイリョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市下神戸', '24', '24216', '5180111', '三重県', 'ミエケン', '伊賀市', 'イガシ', '下神戸', 'シモカンベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市上林', '24', '24216', '5180112', '三重県', 'ミエケン', '伊賀市', 'イガシ', '上林', 'ウエバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市古郡', '24', '24216', '5180113', '三重県', 'ミエケン', '伊賀市', 'イガシ', '古郡', 'フルコオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市朝日ケ丘町', '24', '24216', '5180114', '三重県', 'ミエケン', '伊賀市', 'イガシ', '朝日ケ丘町', 'アサヒガオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市比土', '24', '24216', '5180115', '三重県', 'ミエケン', '伊賀市', 'イガシ', '比土', 'ヒド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市上神戸', '24', '24216', '5180116', '三重県', 'ミエケン', '伊賀市', 'イガシ', '上神戸', 'カミカンベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市上之庄', '24', '24216', '5180121', '三重県', 'ミエケン', '伊賀市', 'イガシ', '上之庄', 'カミノショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市笠部', '24', '24216', '5180122', '三重県', 'ミエケン', '伊賀市', 'イガシ', '笠部', 'カサベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市猪田', '24', '24216', '5180123', '三重県', 'ミエケン', '伊賀市', 'イガシ', '猪田', 'イダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市下郡', '24', '24216', '5180124', '三重県', 'ミエケン', '伊賀市', 'イガシ', '下郡', 'シモゴオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市上郡', '24', '24216', '5180125', '三重県', 'ミエケン', '伊賀市', 'イガシ', '上郡', 'カミゴオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市森寺', '24', '24216', '5180126', '三重県', 'ミエケン', '伊賀市', 'イガシ', '森寺', 'モリデラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市山出', '24', '24216', '5180127', '三重県', 'ミエケン', '伊賀市', 'イガシ', '山出', 'ヤマデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市ゆめが丘', '24', '24216', '5180131', '三重県', 'ミエケン', '伊賀市', 'イガシ', 'ゆめが丘', 'ユメガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市瀧', '24', '24216', '5180201', '三重県', 'ミエケン', '伊賀市', 'イガシ', '瀧', 'タキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市妙楽地', '24', '24216', '5180202', '三重県', 'ミエケン', '伊賀市', 'イガシ', '妙楽地', 'ミョウラクジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市勝地', '24', '24216', '5180203', '三重県', 'ミエケン', '伊賀市', 'イガシ', '勝地', 'カチジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市北山', '24', '24216', '5180204', '三重県', 'ミエケン', '伊賀市', 'イガシ', '北山', 'キタヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市伊勢路', '24', '24216', '5180205', '三重県', 'ミエケン', '伊賀市', 'イガシ', '伊勢路', 'イセジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市下川原', '24', '24216', '5180206', '三重県', 'ミエケン', '伊賀市', 'イガシ', '下川原', 'シモガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市奥鹿野', '24', '24216', '5180211', '三重県', 'ミエケン', '伊賀市', 'イガシ', '奥鹿野', 'オクガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市福川', '24', '24216', '5180212', '三重県', 'ミエケン', '伊賀市', 'イガシ', '福川', 'フクガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市諸木', '24', '24216', '5180213', '三重県', 'ミエケン', '伊賀市', 'イガシ', '諸木', 'モロキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市腰山', '24', '24216', '5180214', '三重県', 'ミエケン', '伊賀市', 'イガシ', '腰山', 'コシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市霧生', '24', '24216', '5180215', '三重県', 'ミエケン', '伊賀市', 'イガシ', '霧生', 'キリュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市高尾', '24', '24216', '5180216', '三重県', 'ミエケン', '伊賀市', 'イガシ', '高尾', 'タカオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市種生', '24', '24216', '5180217', '三重県', 'ミエケン', '伊賀市', 'イガシ', '種生', 'タナオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市川上', '24', '24216', '5180218', '三重県', 'ミエケン', '伊賀市', 'イガシ', '川上', 'カワカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市老川', '24', '24216', '5180219', '三重県', 'ミエケン', '伊賀市', 'イガシ', '老川', 'オイカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市別府', '24', '24216', '5180221', '三重県', 'ミエケン', '伊賀市', 'イガシ', '別府', 'ベフ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市寺脇', '24', '24216', '5180222', '三重県', 'ミエケン', '伊賀市', 'イガシ', '寺脇', 'テラワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市岡田', '24', '24216', '5180223', '三重県', 'ミエケン', '伊賀市', 'イガシ', '岡田', 'オカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市柏尾', '24', '24216', '5180224', '三重県', 'ミエケン', '伊賀市', 'イガシ', '柏尾', 'カシオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市桐ケ丘', '24', '24216', '5180225', '三重県', 'ミエケン', '伊賀市', 'イガシ', '桐ケ丘', 'キリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市阿保', '24', '24216', '5180226', '三重県', 'ミエケン', '伊賀市', 'イガシ', '阿保', 'アオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市青山羽根', '24', '24216', '5180227', '三重県', 'ミエケン', '伊賀市', 'イガシ', '青山羽根', 'アオヤマハネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市', '24', '24208', '5180400', '三重県', 'ミエケン', '名張市', 'ナバリシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('56531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市すずらん台東1番町', '24', '24208', '5180401', '三重県', 'ミエケン', '名張市', 'ナバリシ', 'すずらん台東1番町', 'スズランダイヒガシ01バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市すずらん台東2番町', '24', '24208', '5180402', '三重県', 'ミエケン', '名張市', 'ナバリシ', 'すずらん台東2番町', 'スズランダイヒガシ02バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市すずらん台東3番町', '24', '24208', '5180403', '三重県', 'ミエケン', '名張市', 'ナバリシ', 'すずらん台東3番町', 'スズランダイヒガシ03バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市すずらん台東4番町', '24', '24208', '5180404', '三重県', 'ミエケン', '名張市', 'ナバリシ', 'すずらん台東4番町', 'スズランダイヒガシ04バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市すずらん台東5番町', '24', '24208', '5180405', '三重県', 'ミエケン', '名張市', 'ナバリシ', 'すずらん台東5番町', 'スズランダイヒガシ05バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市すずらん台西1番町', '24', '24208', '5180406', '三重県', 'ミエケン', '名張市', 'ナバリシ', 'すずらん台西1番町', 'スズランダイニシ01バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市すずらん台西2番町', '24', '24208', '5180407', '三重県', 'ミエケン', '名張市', 'ナバリシ', 'すずらん台西2番町', 'スズランダイニシ02バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市すずらん台西3番町', '24', '24208', '5180408', '三重県', 'ミエケン', '名張市', 'ナバリシ', 'すずらん台西3番町', 'スズランダイニシ03バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市すずらん台西4番町', '24', '24208', '5180409', '三重県', 'ミエケン', '名張市', 'ナバリシ', 'すずらん台西4番町', 'スズランダイニシ04バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市滝之原', '24', '24208', '5180411', '三重県', 'ミエケン', '名張市', 'ナバリシ', '滝之原', 'タキノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市上比奈知', '24', '24208', '5180412', '三重県', 'ミエケン', '名張市', 'ナバリシ', '上比奈知', 'カミヒナチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市下比奈知', '24', '24208', '5180413', '三重県', 'ミエケン', '名張市', 'ナバリシ', '下比奈知', 'シモヒナチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市富貴ケ丘1番町', '24', '24208', '5180414', '三重県', 'ミエケン', '名張市', 'ナバリシ', '富貴ケ丘1番町', 'フキガオカ01バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市富貴ケ丘2番町', '24', '24208', '5180415', '三重県', 'ミエケン', '名張市', 'ナバリシ', '富貴ケ丘2番町', 'フキガオカ02バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市富貴ケ丘3番町', '24', '24208', '5180416', '三重県', 'ミエケン', '名張市', 'ナバリシ', '富貴ケ丘3番町', 'フキガオカ03バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市富貴ケ丘4番町', '24', '24208', '5180417', '三重県', 'ミエケン', '名張市', 'ナバリシ', '富貴ケ丘4番町', 'フキガオカ04バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市富貴ケ丘5番町', '24', '24208', '5180418', '三重県', 'ミエケン', '名張市', 'ナバリシ', '富貴ケ丘5番町', 'フキガオカ05バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市富貴ケ丘6番町', '24', '24208', '5180419', '三重県', 'ミエケン', '名張市', 'ナバリシ', '富貴ケ丘6番町', 'フキガオカ06バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市つつじが丘南1番町', '24', '24208', '5180421', '三重県', 'ミエケン', '名張市', 'ナバリシ', 'つつじが丘南1番町', 'ツツジガオカミナミ01バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市つつじが丘南2番町', '24', '24208', '5180422', '三重県', 'ミエケン', '名張市', 'ナバリシ', 'つつじが丘南2番町', 'ツツジガオカミナミ02バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市つつじが丘南3番町', '24', '24208', '5180423', '三重県', 'ミエケン', '名張市', 'ナバリシ', 'つつじが丘南3番町', 'ツツジガオカミナミ03バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市つつじが丘南4番町', '24', '24208', '5180424', '三重県', 'ミエケン', '名張市', 'ナバリシ', 'つつじが丘南4番町', 'ツツジガオカミナミ04バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市つつじが丘南5番町', '24', '24208', '5180425', '三重県', 'ミエケン', '名張市', 'ナバリシ', 'つつじが丘南5番町', 'ツツジガオカミナミ05バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市つつじが丘南6番町', '24', '24208', '5180426', '三重県', 'ミエケン', '名張市', 'ナバリシ', 'つつじが丘南6番町', 'ツツジガオカミナミ06バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市つつじが丘南7番町', '24', '24208', '5180427', '三重県', 'ミエケン', '名張市', 'ナバリシ', 'つつじが丘南7番町', 'ツツジガオカミナミ07バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市つつじが丘南8番町', '24', '24208', '5180428', '三重県', 'ミエケン', '名張市', 'ナバリシ', 'つつじが丘南8番町', 'ツツジガオカミナミ08バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市つつじが丘北10番町', '24', '24208', '5180430', '三重県', 'ミエケン', '名張市', 'ナバリシ', 'つつじが丘北10番町', 'ツツジガオカキタ10バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市つつじが丘北1番町', '24', '24208', '5180431', '三重県', 'ミエケン', '名張市', 'ナバリシ', 'つつじが丘北1番町', 'ツツジガオカキタ01バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市つつじが丘北2番町', '24', '24208', '5180432', '三重県', 'ミエケン', '名張市', 'ナバリシ', 'つつじが丘北2番町', 'ツツジガオカキタ02バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市つつじが丘北3番町', '24', '24208', '5180433', '三重県', 'ミエケン', '名張市', 'ナバリシ', 'つつじが丘北3番町', 'ツツジガオカキタ03バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市つつじが丘北4番町', '24', '24208', '5180434', '三重県', 'ミエケン', '名張市', 'ナバリシ', 'つつじが丘北4番町', 'ツツジガオカキタ04バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市つつじが丘北5番町', '24', '24208', '5180435', '三重県', 'ミエケン', '名張市', 'ナバリシ', 'つつじが丘北5番町', 'ツツジガオカキタ05バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市つつじが丘北6番町', '24', '24208', '5180436', '三重県', 'ミエケン', '名張市', 'ナバリシ', 'つつじが丘北6番町', 'ツツジガオカキタ06バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市つつじが丘北7番町', '24', '24208', '5180437', '三重県', 'ミエケン', '名張市', 'ナバリシ', 'つつじが丘北7番町', 'ツツジガオカキタ07バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市つつじが丘北8番町', '24', '24208', '5180438', '三重県', 'ミエケン', '名張市', 'ナバリシ', 'つつじが丘北8番町', 'ツツジガオカキタ08バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市つつじが丘北9番町', '24', '24208', '5180439', '三重県', 'ミエケン', '名張市', 'ナバリシ', 'つつじが丘北9番町', 'ツツジガオカキタ09バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市夏見', '24', '24208', '5180441', '三重県', 'ミエケン', '名張市', 'ナバリシ', '夏見', 'ナツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市中知山', '24', '24208', '5180442', '三重県', 'ミエケン', '名張市', 'ナバリシ', '中知山', 'ナカチヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市青蓮寺', '24', '24208', '5180443', '三重県', 'ミエケン', '名張市', 'ナバリシ', '青蓮寺', 'ショウレンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市箕曲中村', '24', '24208', '5180444', '三重県', 'ミエケン', '名張市', 'ナバリシ', '箕曲中村', 'ミノワナカムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市瀬古口', '24', '24208', '5180445', '三重県', 'ミエケン', '名張市', 'ナバリシ', '瀬古口', 'セコグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市南百合が丘', '24', '24208', '5180446', '三重県', 'ミエケン', '名張市', 'ナバリシ', '南百合が丘', 'ミナミユリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市春日丘1番町', '24', '24208', '5180453', '三重県', 'ミエケン', '名張市', 'ナバリシ', '春日丘1番町', 'カスガオカ01バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市春日丘2番町', '24', '24208', '5180454', '三重県', 'ミエケン', '名張市', 'ナバリシ', '春日丘2番町', 'カスガオカ02バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市春日丘3番町', '24', '24208', '5180455', '三重県', 'ミエケン', '名張市', 'ナバリシ', '春日丘3番町', 'カスガオカ03バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市春日丘4番町', '24', '24208', '5180456', '三重県', 'ミエケン', '名張市', 'ナバリシ', '春日丘4番町', 'カスガオカ04バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市春日丘5番町', '24', '24208', '5180457', '三重県', 'ミエケン', '名張市', 'ナバリシ', '春日丘5番町', 'カスガオカ05バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市春日丘6番町', '24', '24208', '5180458', '三重県', 'ミエケン', '名張市', 'ナバリシ', '春日丘6番町', 'カスガオカ06バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市春日丘7番町', '24', '24208', '5180459', '三重県', 'ミエケン', '名張市', 'ナバリシ', '春日丘7番町', 'カスガオカ07バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市赤目町すみれが丘', '24', '24208', '5180461', '三重県', 'ミエケン', '名張市', 'ナバリシ', '赤目町すみれが丘', 'アカメチョウスミレガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市赤目町星川', '24', '24208', '5180462', '三重県', 'ミエケン', '名張市', 'ナバリシ', '赤目町星川', 'アカメチョウホシカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市赤目町檀', '24', '24208', '5180463', '三重県', 'ミエケン', '名張市', 'ナバリシ', '赤目町檀', 'アカメチョウダン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市赤目町柏原', '24', '24208', '5180464', '三重県', 'ミエケン', '名張市', 'ナバリシ', '赤目町柏原', 'アカメチョウカシワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市赤目町丈六', '24', '24208', '5180465', '三重県', 'ミエケン', '名張市', 'ナバリシ', '赤目町丈六', 'アカメチョウジョウロク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市赤目町新川', '24', '24208', '5180466', '三重県', 'ミエケン', '名張市', 'ナバリシ', '赤目町新川', 'アカメチョウシンカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市赤目町相楽', '24', '24208', '5180467', '三重県', 'ミエケン', '名張市', 'ナバリシ', '赤目町相楽', 'アカメチョウサガラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市赤目町一ノ井', '24', '24208', '5180468', '三重県', 'ミエケン', '名張市', 'ナバリシ', '赤目町一ノ井', 'アカメチョウイチノイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市赤目町長坂', '24', '24208', '5180469', '三重県', 'ミエケン', '名張市', 'ナバリシ', '赤目町長坂', 'アカメチョウナガサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市百合が丘東1番町', '24', '24208', '5180471', '三重県', 'ミエケン', '名張市', 'ナバリシ', '百合が丘東1番町', 'ユリガオカヒガシ01バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市百合が丘東2番町', '24', '24208', '5180472', '三重県', 'ミエケン', '名張市', 'ナバリシ', '百合が丘東2番町', 'ユリガオカヒガシ02バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市百合が丘東3番町', '24', '24208', '5180473', '三重県', 'ミエケン', '名張市', 'ナバリシ', '百合が丘東3番町', 'ユリガオカヒガシ03バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市百合が丘東4番町', '24', '24208', '5180474', '三重県', 'ミエケン', '名張市', 'ナバリシ', '百合が丘東4番町', 'ユリガオカヒガシ04バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市百合が丘東5番町', '24', '24208', '5180475', '三重県', 'ミエケン', '名張市', 'ナバリシ', '百合が丘東5番町', 'ユリガオカヒガシ05バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市百合が丘東6番町', '24', '24208', '5180476', '三重県', 'ミエケン', '名張市', 'ナバリシ', '百合が丘東6番町', 'ユリガオカヒガシ06バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市百合が丘東7番町', '24', '24208', '5180477', '三重県', 'ミエケン', '名張市', 'ナバリシ', '百合が丘東7番町', 'ユリガオカヒガシ07バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市百合が丘東8番町', '24', '24208', '5180478', '三重県', 'ミエケン', '名張市', 'ナバリシ', '百合が丘東8番町', 'ユリガオカヒガシ08バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市百合が丘東9番町', '24', '24208', '5180479', '三重県', 'ミエケン', '名張市', 'ナバリシ', '百合が丘東9番町', 'ユリガオカヒガシ09バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市百合が丘西1番町', '24', '24208', '5180481', '三重県', 'ミエケン', '名張市', 'ナバリシ', '百合が丘西1番町', 'ユリガオカニシ01バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市百合が丘西2番町', '24', '24208', '5180482', '三重県', 'ミエケン', '名張市', 'ナバリシ', '百合が丘西2番町', 'ユリガオカニシ02バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市百合が丘西3番町', '24', '24208', '5180483', '三重県', 'ミエケン', '名張市', 'ナバリシ', '百合が丘西3番町', 'ユリガオカニシ03バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市百合が丘西4番町', '24', '24208', '5180484', '三重県', 'ミエケン', '名張市', 'ナバリシ', '百合が丘西4番町', 'ユリガオカニシ04バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市百合が丘西5番町', '24', '24208', '5180485', '三重県', 'ミエケン', '名張市', 'ナバリシ', '百合が丘西5番町', 'ユリガオカニシ05バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市百合が丘西6番町', '24', '24208', '5180486', '三重県', 'ミエケン', '名張市', 'ナバリシ', '百合が丘西6番町', 'ユリガオカニシ06バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市長瀬', '24', '24208', '5180501', '三重県', 'ミエケン', '名張市', 'ナバリシ', '長瀬', 'ナガセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市上長瀬', '24', '24208', '5180502', '三重県', 'ミエケン', '名張市', 'ナバリシ', '上長瀬', 'カミナガセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市布生', '24', '24208', '5180503', '三重県', 'ミエケン', '名張市', 'ナバリシ', '布生', 'フノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市神屋', '24', '24208', '5180504', '三重県', 'ミエケン', '名張市', 'ナバリシ', '神屋', 'カミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市奈垣', '24', '24208', '5180505', '三重県', 'ミエケン', '名張市', 'ナバリシ', '奈垣', 'ナガキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市南古山', '24', '24208', '5180601', '三重県', 'ミエケン', '名張市', 'ナバリシ', '南古山', 'ミナミフルヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市東田原', '24', '24208', '5180602', '三重県', 'ミエケン', '名張市', 'ナバリシ', '東田原', 'ヒガシタワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市西原町', '24', '24208', '5180603', '三重県', 'ミエケン', '名張市', 'ナバリシ', '西原町', 'ニシワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市さつき台', '24', '24208', '5180604', '三重県', 'ミエケン', '名張市', 'ナバリシ', 'さつき台', 'サツキダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市八幡', '24', '24208', '5180605', '三重県', 'ミエケン', '名張市', 'ナバリシ', '八幡', 'ヤバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市薦生', '24', '24208', '5180606', '三重県', 'ミエケン', '名張市', 'ナバリシ', '薦生', 'コモオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市家野', '24', '24208', '5180607', '三重県', 'ミエケン', '名張市', 'ナバリシ', '家野', 'イエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市葛尾', '24', '24208', '5180607', '三重県', 'ミエケン', '名張市', 'ナバリシ', '葛尾', 'クズオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市鵜山', '24', '24208', '5180608', '三重県', 'ミエケン', '名張市', 'ナバリシ', '鵜山', 'ウヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市西田原', '24', '24208', '5180609', '三重県', 'ミエケン', '名張市', 'ナバリシ', '西田原', 'ニシタワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市美旗町藤が丘', '24', '24208', '5180610', '三重県', 'ミエケン', '名張市', 'ナバリシ', '美旗町藤が丘', 'ミハタチョウフジガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市新田', '24', '24208', '5180611', '三重県', 'ミエケン', '名張市', 'ナバリシ', '新田', 'シンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市下小波田', '24', '24208', '5180612', '三重県', 'ミエケン', '名張市', 'ナバリシ', '下小波田', 'シモオバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市上小波田', '24', '24208', '5180613', '三重県', 'ミエケン', '名張市', 'ナバリシ', '上小波田', 'カミオバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市美旗町池の台西', '24', '24208', '5180614', '三重県', 'ミエケン', '名張市', 'ナバリシ', '美旗町池の台西', 'ミハタチョウイケノダイニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市美旗町池の台東', '24', '24208', '5180614', '三重県', 'ミエケン', '名張市', 'ナバリシ', '美旗町池の台東', 'ミハタチョウイケノダイヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市美旗中村', '24', '24208', '5180615', '三重県', 'ミエケン', '名張市', 'ナバリシ', '美旗中村', 'ミハタナカムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市美旗町南西原', '24', '24208', '5180616', '三重県', 'ミエケン', '名張市', 'ナバリシ', '美旗町南西原', 'ミハタチョウミナミニシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市美旗町中1番', '24', '24208', '5180617', '三重県', 'ミエケン', '名張市', 'ナバリシ', '美旗町中1番', 'ミハタチョウナカ01バン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市美旗町中2番', '24', '24208', '5180618', '三重県', 'ミエケン', '名張市', 'ナバリシ', '美旗町中2番', 'ミハタチョウナカ02バン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市美旗町中3番', '24', '24208', '5180619', '三重県', 'ミエケン', '名張市', 'ナバリシ', '美旗町中3番', 'ミハタチョウナカ03バン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市桔梗が丘1番町', '24', '24208', '5180621', '三重県', 'ミエケン', '名張市', 'ナバリシ', '桔梗が丘1番町', 'キキョウガオカ01バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市桔梗が丘2番町', '24', '24208', '5180622', '三重県', 'ミエケン', '名張市', 'ナバリシ', '桔梗が丘2番町', 'キキョウガオカ02バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市桔梗が丘3番町', '24', '24208', '5180623', '三重県', 'ミエケン', '名張市', 'ナバリシ', '桔梗が丘3番町', 'キキョウガオカ03バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市桔梗が丘4番町', '24', '24208', '5180624', '三重県', 'ミエケン', '名張市', 'ナバリシ', '桔梗が丘4番町', 'キキョウガオカ04バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市桔梗が丘5番町', '24', '24208', '5180625', '三重県', 'ミエケン', '名張市', 'ナバリシ', '桔梗が丘5番町', 'キキョウガオカ05バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市桔梗が丘6番町', '24', '24208', '5180626', '三重県', 'ミエケン', '名張市', 'ナバリシ', '桔梗が丘6番町', 'キキョウガオカ06バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市桔梗が丘7番町', '24', '24208', '5180627', '三重県', 'ミエケン', '名張市', 'ナバリシ', '桔梗が丘7番町', 'キキョウガオカ07バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市桔梗が丘8番町', '24', '24208', '5180628', '三重県', 'ミエケン', '名張市', 'ナバリシ', '桔梗が丘8番町', 'キキョウガオカ08バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市桔梗が丘南1番町', '24', '24208', '5180631', '三重県', 'ミエケン', '名張市', 'ナバリシ', '桔梗が丘南1番町', 'キキョウガオカミナミ01バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市桔梗が丘南2番町', '24', '24208', '5180632', '三重県', 'ミエケン', '名張市', 'ナバリシ', '桔梗が丘南2番町', 'キキョウガオカミナミ02バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市桔梗が丘南3番町', '24', '24208', '5180633', '三重県', 'ミエケン', '名張市', 'ナバリシ', '桔梗が丘南3番町', 'キキョウガオカミナミ03バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市桔梗が丘南4番町', '24', '24208', '5180634', '三重県', 'ミエケン', '名張市', 'ナバリシ', '桔梗が丘南4番町', 'キキョウガオカミナミ04バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市桔梗が丘西1番町', '24', '24208', '5180641', '三重県', 'ミエケン', '名張市', 'ナバリシ', '桔梗が丘西1番町', 'キキョウガオカニシ01バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市桔梗が丘西2番町', '24', '24208', '5180642', '三重県', 'ミエケン', '名張市', 'ナバリシ', '桔梗が丘西2番町', 'キキョウガオカニシ02バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市桔梗が丘西3番町', '24', '24208', '5180643', '三重県', 'ミエケン', '名張市', 'ナバリシ', '桔梗が丘西3番町', 'キキョウガオカニシ03バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市桔梗が丘西4番町', '24', '24208', '5180644', '三重県', 'ミエケン', '名張市', 'ナバリシ', '桔梗が丘西4番町', 'キキョウガオカニシ04バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市桔梗が丘西5番町', '24', '24208', '5180645', '三重県', 'ミエケン', '名張市', 'ナバリシ', '桔梗が丘西5番町', 'キキョウガオカニシ05バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市桔梗が丘西6番町', '24', '24208', '5180646', '三重県', 'ミエケン', '名張市', 'ナバリシ', '桔梗が丘西6番町', 'キキョウガオカニシ06バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市桔梗が丘西7番町', '24', '24208', '5180647', '三重県', 'ミエケン', '名張市', 'ナバリシ', '桔梗が丘西7番町', 'キキョウガオカニシ07バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市鴻之台1番町', '24', '24208', '5180701', '三重県', 'ミエケン', '名張市', 'ナバリシ', '鴻之台1番町', 'コウノダイ01バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市鴻之台2番町', '24', '24208', '5180702', '三重県', 'ミエケン', '名張市', 'ナバリシ', '鴻之台2番町', 'コウノダイ02バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市鴻之台3番町', '24', '24208', '5180703', '三重県', 'ミエケン', '名張市', 'ナバリシ', '鴻之台3番町', 'コウノダイ03バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市鴻之台4番町', '24', '24208', '5180704', '三重県', 'ミエケン', '名張市', 'ナバリシ', '鴻之台4番町', 'コウノダイ04バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市鴻之台5番町', '24', '24208', '5180705', '三重県', 'ミエケン', '名張市', 'ナバリシ', '鴻之台5番町', 'コウノダイ05バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市上八町', '24', '24208', '5180710', '三重県', 'ミエケン', '名張市', 'ナバリシ', '上八町', 'カミハッチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市東町', '24', '24208', '5180711', '三重県', 'ミエケン', '名張市', 'ナバリシ', '東町', 'ヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市桜ケ丘', '24', '24208', '5180712', '三重県', 'ミエケン', '名張市', 'ナバリシ', '桜ケ丘', 'サクラガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市平尾', '24', '24208', '5180713', '三重県', 'ミエケン', '名張市', 'ナバリシ', '平尾', 'ヒラオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市鍛冶町', '24', '24208', '5180714', '三重県', 'ミエケン', '名張市', 'ナバリシ', '鍛冶町', 'カジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市柳原町', '24', '24208', '5180715', '三重県', 'ミエケン', '名張市', 'ナバリシ', '柳原町', 'ヤナギハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市上本町', '24', '24208', '5180716', '三重県', 'ミエケン', '名張市', 'ナバリシ', '上本町', 'ウエホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市中町', '24', '24208', '5180717', '三重県', 'ミエケン', '名張市', 'ナバリシ', '中町', 'ナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市丸之内', '24', '24208', '5180718', '三重県', 'ミエケン', '名張市', 'ナバリシ', '丸之内', 'マルノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市栄町', '24', '24208', '5180719', '三重県', 'ミエケン', '名張市', 'ナバリシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市朝日町', '24', '24208', '5180721', '三重県', 'ミエケン', '名張市', 'ナバリシ', '朝日町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市松崎町', '24', '24208', '5180722', '三重県', 'ミエケン', '名張市', 'ナバリシ', '松崎町', 'マツサキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市木屋町', '24', '24208', '5180723', '三重県', 'ミエケン', '名張市', 'ナバリシ', '木屋町', 'キヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市榊町', '24', '24208', '5180724', '三重県', 'ミエケン', '名張市', 'ナバリシ', '榊町', 'サカキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市元町', '24', '24208', '5180725', '三重県', 'ミエケン', '名張市', 'ナバリシ', '元町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市本町', '24', '24208', '5180726', '三重県', 'ミエケン', '名張市', 'ナバリシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市新町', '24', '24208', '5180727', '三重県', 'ミエケン', '名張市', 'ナバリシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市豊後町', '24', '24208', '5180728', '三重県', 'ミエケン', '名張市', 'ナバリシ', '豊後町', 'ブンゴマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市南町', '24', '24208', '5180729', '三重県', 'ミエケン', '名張市', 'ナバリシ', '南町', 'ミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市夏秋', '24', '24208', '5180731', '三重県', 'ミエケン', '名張市', 'ナバリシ', '夏秋', 'ナツアキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市松原町', '24', '24208', '5180732', '三重県', 'ミエケン', '名張市', 'ナバリシ', '松原町', 'マツバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市大屋戸', '24', '24208', '5180733', '三重県', 'ミエケン', '名張市', 'ナバリシ', '大屋戸', 'オヤド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市黒田', '24', '24208', '5180734', '三重県', 'ミエケン', '名張市', 'ナバリシ', '黒田', 'クロダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市結馬', '24', '24208', '5180735', '三重県', 'ミエケン', '名張市', 'ナバリシ', '結馬', 'ケチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市井手', '24', '24208', '5180736', '三重県', 'ミエケン', '名張市', 'ナバリシ', '井手', 'イデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市安部田', '24', '24208', '5180737', '三重県', 'ミエケン', '名張市', 'ナバリシ', '安部田', 'アベタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市短野', '24', '24208', '5180738', '三重県', 'ミエケン', '名張市', 'ナバリシ', '短野', 'ミジカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市下三谷', '24', '24208', '5180739', '三重県', 'ミエケン', '名張市', 'ナバリシ', '下三谷', 'シモミタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市梅が丘北5番町', '24', '24208', '5180740', '三重県', 'ミエケン', '名張市', 'ナバリシ', '梅が丘北5番町', 'ウメガオカキタ05バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市梅が丘南1番町', '24', '24208', '5180741', '三重県', 'ミエケン', '名張市', 'ナバリシ', '梅が丘南1番町', 'ウメガオカミナミ01バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市梅が丘南2番町', '24', '24208', '5180742', '三重県', 'ミエケン', '名張市', 'ナバリシ', '梅が丘南2番町', 'ウメガオカミナミ02バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市梅が丘南3番町', '24', '24208', '5180743', '三重県', 'ミエケン', '名張市', 'ナバリシ', '梅が丘南3番町', 'ウメガオカミナミ03バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市梅が丘南4番町', '24', '24208', '5180744', '三重県', 'ミエケン', '名張市', 'ナバリシ', '梅が丘南4番町', 'ウメガオカミナミ04バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市梅が丘南5番町', '24', '24208', '5180745', '三重県', 'ミエケン', '名張市', 'ナバリシ', '梅が丘南5番町', 'ウメガオカミナミ05バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市梅が丘北1番町', '24', '24208', '5180746', '三重県', 'ミエケン', '名張市', 'ナバリシ', '梅が丘北1番町', 'ウメガオカキタ01バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市梅が丘北2番町', '24', '24208', '5180747', '三重県', 'ミエケン', '名張市', 'ナバリシ', '梅が丘北2番町', 'ウメガオカキタ02バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市梅が丘北3番町', '24', '24208', '5180748', '三重県', 'ミエケン', '名張市', 'ナバリシ', '梅が丘北3番町', 'ウメガオカキタ03バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市梅が丘北4番町', '24', '24208', '5180749', '三重県', 'ミエケン', '名張市', 'ナバリシ', '梅が丘北4番町', 'ウメガオカキタ04バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市蔵持町芝出', '24', '24208', '5180751', '三重県', 'ミエケン', '名張市', 'ナバリシ', '蔵持町芝出', 'クラモチチョウシバデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市蔵持町原出', '24', '24208', '5180752', '三重県', 'ミエケン', '名張市', 'ナバリシ', '蔵持町原出', 'クラモチチョウハラデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市蔵持町里', '24', '24208', '5180753', '三重県', 'ミエケン', '名張市', 'ナバリシ', '蔵持町里', 'クラモチチョウサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市緑が丘西', '24', '24208', '5180754', '三重県', 'ミエケン', '名張市', 'ナバリシ', '緑が丘西', 'ミドリガオカニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市緑が丘中', '24', '24208', '5180755', '三重県', 'ミエケン', '名張市', 'ナバリシ', '緑が丘中', 'ミドリガオカナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市緑が丘東', '24', '24208', '5180756', '三重県', 'ミエケン', '名張市', 'ナバリシ', '緑が丘東', 'ミドリガオカヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市竜口', '24', '24208', '5180761', '三重県', 'ミエケン', '名張市', 'ナバリシ', '竜口', 'リュウグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市上三谷', '24', '24208', '5180762', '三重県', 'ミエケン', '名張市', 'ナバリシ', '上三谷', 'カミミタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市矢川', '24', '24208', '5180763', '三重県', 'ミエケン', '名張市', 'ナバリシ', '矢川', 'ヤガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市希央台1番町', '24', '24208', '5180771', '三重県', 'ミエケン', '名張市', 'ナバリシ', '希央台1番町', 'キオウダイ01バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市希央台2番町', '24', '24208', '5180772', '三重県', 'ミエケン', '名張市', 'ナバリシ', '希央台2番町', 'キオウダイ02バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市希央台3番町', '24', '24208', '5180773', '三重県', 'ミエケン', '名張市', 'ナバリシ', '希央台3番町', 'キオウダイ03バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市希央台4番町', '24', '24208', '5180774', '三重県', 'ミエケン', '名張市', 'ナバリシ', '希央台4番町', 'キオウダイ04バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県名張市希央台5番町', '24', '24208', '5180775', '三重県', 'ミエケン', '名張市', 'ナバリシ', '希央台5番町', 'キオウダイ05バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市平野見能', '24', '24216', '5180801', '三重県', 'ミエケン', '伊賀市', 'イガシ', '平野見能', 'ヒラノミノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市平野樋之口', '24', '24216', '5180802', '三重県', 'ミエケン', '伊賀市', 'イガシ', '平野樋之口', 'ヒラノヒノクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市平野六反田', '24', '24216', '5180804', '三重県', 'ミエケン', '伊賀市', 'イガシ', '平野六反田', 'ヒラノロクタンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市平野上川原', '24', '24216', '5180807', '三重県', 'ミエケン', '伊賀市', 'イガシ', '平野上川原', 'ヒラノカミガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市平野蔵垣内', '24', '24216', '5180808', '三重県', 'ミエケン', '伊賀市', 'イガシ', '平野蔵垣内', 'ヒラノクラガイト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市西明寺', '24', '24216', '5180809', '三重県', 'ミエケン', '伊賀市', 'イガシ', '西明寺', 'サイミョウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市平野東町', '24', '24216', '5180810', '三重県', 'ミエケン', '伊賀市', 'イガシ', '平野東町', 'ヒラノヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市喰代', '24', '24216', '5180811', '三重県', 'ミエケン', '伊賀市', 'イガシ', '喰代', 'ホウジロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市高山', '24', '24216', '5180812', '三重県', 'ミエケン', '伊賀市', 'イガシ', '高山', 'タカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市蓮池', '24', '24216', '5180813', '三重県', 'ミエケン', '伊賀市', 'イガシ', '蓮池', 'ハスイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市上友生', '24', '24216', '5180814', '三重県', 'ミエケン', '伊賀市', 'イガシ', '上友生', 'カミトモノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市界外', '24', '24216', '5180815', '三重県', 'ミエケン', '伊賀市', 'イガシ', '界外', 'カイゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市中友生', '24', '24216', '5180816', '三重県', 'ミエケン', '伊賀市', 'イガシ', '中友生', 'ナカトモノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市下友生', '24', '24216', '5180817', '三重県', 'ミエケン', '伊賀市', 'イガシ', '下友生', 'シモトモノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市荒木', '24', '24216', '5180818', '三重県', 'ミエケン', '伊賀市', 'イガシ', '荒木', 'アラキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市平野西町', '24', '24216', '5180820', '三重県', 'ミエケン', '伊賀市', 'イガシ', '平野西町', 'ヒラノニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市生琉里', '24', '24216', '5180821', '三重県', 'ミエケン', '伊賀市', 'イガシ', '生琉里', 'フルサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市問屋町', '24', '24216', '5180822', '三重県', 'ミエケン', '伊賀市', 'イガシ', '問屋町', 'トンヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市四十九町', '24', '24216', '5180823', '三重県', 'ミエケン', '伊賀市', 'イガシ', '四十九町', 'シジュクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市守田町', '24', '24216', '5180824', '三重県', 'ミエケン', '伊賀市', 'イガシ', '守田町', 'モリタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市小田町', '24', '24216', '5180825', '三重県', 'ミエケン', '伊賀市', 'イガシ', '小田町', 'オタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市平野北谷', '24', '24216', '5180826', '三重県', 'ミエケン', '伊賀市', 'イガシ', '平野北谷', 'ヒラノキタダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市平野清水', '24', '24216', '5180827', '三重県', 'ミエケン', '伊賀市', 'イガシ', '平野清水', 'ヒラノショウズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市平野中川原', '24', '24216', '5180828', '三重県', 'ミエケン', '伊賀市', 'イガシ', '平野中川原', 'ヒラノナカガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市平野山之下', '24', '24216', '5180829', '三重県', 'ミエケン', '伊賀市', 'イガシ', '平野山之下', 'ヒラノヤマノシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市平野城北町', '24', '24216', '5180830', '三重県', 'ミエケン', '伊賀市', 'イガシ', '平野城北町', 'ヒラノジョウホクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市上野農人町', '24', '24216', '5180831', '三重県', 'ミエケン', '伊賀市', 'イガシ', '上野農人町', 'ウエノノウニンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市上野車坂町', '24', '24216', '5180832', '三重県', 'ミエケン', '伊賀市', 'イガシ', '上野車坂町', 'ウエノクルマザカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市緑ケ丘東町', '24', '24216', '5180833', '三重県', 'ミエケン', '伊賀市', 'イガシ', '緑ケ丘東町', 'ミドリガオカヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市緑ケ丘中町', '24', '24216', '5180834', '三重県', 'ミエケン', '伊賀市', 'イガシ', '緑ケ丘中町', 'ミドリガオカナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市緑ケ丘南町', '24', '24216', '5180835', '三重県', 'ミエケン', '伊賀市', 'イガシ', '緑ケ丘南町', 'ミドリガオカミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市緑ケ丘本町', '24', '24216', '5180836', '三重県', 'ミエケン', '伊賀市', 'イガシ', '緑ケ丘本町', 'ミドリガオカホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市緑ケ丘西町', '24', '24216', '5180837', '三重県', 'ミエケン', '伊賀市', 'イガシ', '緑ケ丘西町', 'ミドリガオカニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市上野茅町', '24', '24216', '5180838', '三重県', 'ミエケン', '伊賀市', 'イガシ', '上野茅町', 'ウエノカヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市上野田端町', '24', '24216', '5180839', '三重県', 'ミエケン', '伊賀市', 'イガシ', '上野田端町', 'ウエノタバタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市陽光台', '24', '24216', '5180840', '三重県', 'ミエケン', '伊賀市', 'イガシ', '陽光台', 'ヨウコウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市上野恵美須町', '24', '24216', '5180841', '三重県', 'ミエケン', '伊賀市', 'イガシ', '上野恵美須町', 'ウエノエビスマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市上野桑町', '24', '24216', '5180842', '三重県', 'ミエケン', '伊賀市', 'イガシ', '上野桑町', 'ウエノクワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市久米町', '24', '24216', '5180843', '三重県', 'ミエケン', '伊賀市', 'イガシ', '久米町', 'クメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市八幡町', '24', '24216', '5180844', '三重県', 'ミエケン', '伊賀市', 'イガシ', '八幡町', 'ヤハタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市木興町', '24', '24216', '5180845', '三重県', 'ミエケン', '伊賀市', 'イガシ', '木興町', 'キコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市上野愛宕町', '24', '24216', '5180846', '三重県', 'ミエケン', '伊賀市', 'イガシ', '上野愛宕町', 'ウエノアタゴマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市上野鉄砲町', '24', '24216', '5180847', '三重県', 'ミエケン', '伊賀市', 'イガシ', '上野鉄砲町', 'ウエノテッポウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市上野西日南町', '24', '24216', '5180848', '三重県', 'ミエケン', '伊賀市', 'イガシ', '上野西日南町', 'ウエノニシヒナタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市上野東日南町', '24', '24216', '5180849', '三重県', 'ミエケン', '伊賀市', 'イガシ', '上野東日南町', 'ウエノヒガシヒナタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市上野寺町', '24', '24216', '5180851', '三重県', 'ミエケン', '伊賀市', 'イガシ', '上野寺町', 'ウエノテラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市上野伊予町', '24', '24216', '5180852', '三重県', 'ミエケン', '伊賀市', 'イガシ', '上野伊予町', 'ウエノイヨマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市上野池町', '24', '24216', '5180853', '三重県', 'ミエケン', '伊賀市', 'イガシ', '上野池町', 'ウエノイケマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市上野忍町', '24', '24216', '5180854', '三重県', 'ミエケン', '伊賀市', 'イガシ', '上野忍町', 'ウエノシノビチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市上野万町', '24', '24216', '5180855', '三重県', 'ミエケン', '伊賀市', 'イガシ', '上野万町', 'ウエノヨロズマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市上野徳居町', '24', '24216', '5180856', '三重県', 'ミエケン', '伊賀市', 'イガシ', '上野徳居町', 'ウエノトクイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市上野三之西町', '24', '24216', '5180857', '三重県', 'ミエケン', '伊賀市', 'イガシ', '上野三之西町', 'ウエノサンノニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市上野紺屋町', '24', '24216', '5180858', '三重県', 'ミエケン', '伊賀市', 'イガシ', '上野紺屋町', 'ウエノコンヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市上野相生町', '24', '24216', '5180859', '三重県', 'ミエケン', '伊賀市', 'イガシ', '上野相生町', 'ウエノアイオイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市上野東町', '24', '24216', '5180861', '三重県', 'ミエケン', '伊賀市', 'イガシ', '上野東町', 'ウエノヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市上野片原町', '24', '24216', '5180862', '三重県', 'ミエケン', '伊賀市', 'イガシ', '上野片原町', 'ウエノカタハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市上野新町', '24', '24216', '5180863', '三重県', 'ミエケン', '伊賀市', 'イガシ', '上野新町', 'ウエノシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市上野鍛冶町', '24', '24216', '5180864', '三重県', 'ミエケン', '伊賀市', 'イガシ', '上野鍛冶町', 'ウエノカジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市上野魚町', '24', '24216', '5180865', '三重県', 'ミエケン', '伊賀市', 'イガシ', '上野魚町', 'ウエノウオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市上野小玉町', '24', '24216', '5180866', '三重県', 'ミエケン', '伊賀市', 'イガシ', '上野小玉町', 'ウエノコダマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市上野福居町', '24', '24216', '5180867', '三重県', 'ミエケン', '伊賀市', 'イガシ', '上野福居町', 'ウエノフクイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市上野西町', '24', '24216', '5180868', '三重県', 'ミエケン', '伊賀市', 'イガシ', '上野西町', 'ウエノニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市上野中町', '24', '24216', '5180869', '三重県', 'ミエケン', '伊賀市', 'イガシ', '上野中町', 'ウエノナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市上野赤坂町', '24', '24216', '5180871', '三重県', 'ミエケン', '伊賀市', 'イガシ', '上野赤坂町', 'ウエノアカサカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市上野玄蕃町', '24', '24216', '5180872', '三重県', 'ミエケン', '伊賀市', 'イガシ', '上野玄蕃町', 'ウエノゲンバマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市上野丸之内', '24', '24216', '5180873', '三重県', 'ミエケン', '伊賀市', 'イガシ', '上野丸之内', 'ウエノマルノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市上野幸坂町', '24', '24216', '5180874', '三重県', 'ミエケン', '伊賀市', 'イガシ', '上野幸坂町', 'ウエノコウサカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市上野向島町', '24', '24216', '5180875', '三重県', 'ミエケン', '伊賀市', 'イガシ', '上野向島町', 'ウエノムカイジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市上野下幸坂町', '24', '24216', '5180877', '三重県', 'ミエケン', '伊賀市', 'イガシ', '上野下幸坂町', 'ウエノシモコウサカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市上野西大手町', '24', '24216', '5180878', '三重県', 'ミエケン', '伊賀市', 'イガシ', '上野西大手町', 'ウエノニシオオテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市菖蒲池', '24', '24216', '5181141', '三重県', 'ミエケン', '伊賀市', 'イガシ', '菖蒲池', 'ショウブイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市古山界外', '24', '24216', '5181142', '三重県', 'ミエケン', '伊賀市', 'イガシ', '古山界外', 'フルヤマカイゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市鍛冶屋', '24', '24216', '5181143', '三重県', 'ミエケン', '伊賀市', 'イガシ', '鍛冶屋', 'カジヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市東谷', '24', '24216', '5181144', '三重県', 'ミエケン', '伊賀市', 'イガシ', '東谷', 'ヒガシダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市安場', '24', '24216', '5181145', '三重県', 'ミエケン', '伊賀市', 'イガシ', '安場', 'ヤスバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市湯屋谷', '24', '24216', '5181146', '三重県', 'ミエケン', '伊賀市', 'イガシ', '湯屋谷', 'ユヤダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市蔵縄手', '24', '24216', '5181147', '三重県', 'ミエケン', '伊賀市', 'イガシ', '蔵縄手', 'クラナワテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市白樫', '24', '24216', '5181151', '三重県', 'ミエケン', '伊賀市', 'イガシ', '白樫', 'シラカシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市予野', '24', '24216', '5181152', '三重県', 'ミエケン', '伊賀市', 'イガシ', '予野', 'ヨノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市桂', '24', '24216', '5181153', '三重県', 'ミエケン', '伊賀市', 'イガシ', '桂', 'カツラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市大滝', '24', '24216', '5181154', '三重県', 'ミエケン', '伊賀市', 'イガシ', '大滝', 'オオタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市治田', '24', '24216', '5181155', '三重県', 'ミエケン', '伊賀市', 'イガシ', '治田', 'ハッタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市西湯舟', '24', '24216', '5181301', '三重県', 'ミエケン', '伊賀市', 'イガシ', '西湯舟', 'ニシユブネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市東湯舟', '24', '24216', '5181302', '三重県', 'ミエケン', '伊賀市', 'イガシ', '東湯舟', 'ヒガシユブネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市上友田', '24', '24216', '5181303', '三重県', 'ミエケン', '伊賀市', 'イガシ', '上友田', 'カミトモダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市中友田', '24', '24216', '5181304', '三重県', 'ミエケン', '伊賀市', 'イガシ', '中友田', 'ナカトモダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市下友田', '24', '24216', '5181305', '三重県', 'ミエケン', '伊賀市', 'イガシ', '下友田', 'シモトモダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市湯舟', '24', '24216', '5181306', '三重県', 'ミエケン', '伊賀市', 'イガシ', '湯舟', 'ユブネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市東山タウン', '24', '24216', '5181307', '三重県', 'ミエケン', '伊賀市', 'イガシ', '東山タウン', 'ヒガシヤマタウン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市馬田', '24', '24216', '5181311', '三重県', 'ミエケン', '伊賀市', 'イガシ', '馬田', 'バタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市田中', '24', '24216', '5181312', '三重県', 'ミエケン', '伊賀市', 'イガシ', '田中', 'タナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市馬場', '24', '24216', '5181313', '三重県', 'ミエケン', '伊賀市', 'イガシ', '馬場', 'ババ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市円徳院', '24', '24216', '5181314', '三重県', 'ミエケン', '伊賀市', 'イガシ', '円徳院', 'エントクイン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市川合', '24', '24216', '5181315', '三重県', 'ミエケン', '伊賀市', 'イガシ', '川合', 'カワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市阿山ハイツ', '24', '24216', '5181316', '三重県', 'ミエケン', '伊賀市', 'イガシ', '阿山ハイツ', 'アヤマハイツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市大江', '24', '24216', '5181317', '三重県', 'ミエケン', '伊賀市', 'イガシ', '大江', 'オオエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市波敷野', '24', '24216', '5181318', '三重県', 'ミエケン', '伊賀市', 'イガシ', '波敷野', 'ハジキノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市千貝', '24', '24216', '5181319', '三重県', 'ミエケン', '伊賀市', 'イガシ', '千貝', 'セガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市内保', '24', '24216', '5181321', '三重県', 'ミエケン', '伊賀市', 'イガシ', '内保', 'ウチホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市玉滝', '24', '24216', '5181322', '三重県', 'ミエケン', '伊賀市', 'イガシ', '玉滝', 'タマタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市石川', '24', '24216', '5181323', '三重県', 'ミエケン', '伊賀市', 'イガシ', '石川', 'イシカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市音羽', '24', '24216', '5181324', '三重県', 'ミエケン', '伊賀市', 'イガシ', '音羽', 'オトワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市丸柱', '24', '24216', '5181325', '三重県', 'ミエケン', '伊賀市', 'イガシ', '丸柱', 'マルバシラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市槇山', '24', '24216', '5181326', '三重県', 'ミエケン', '伊賀市', 'イガシ', '槇山', 'マキヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市千戸', '24', '24216', '5181401', '三重県', 'ミエケン', '伊賀市', 'イガシ', '千戸', 'センド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市炊村', '24', '24216', '5181403', '三重県', 'ミエケン', '伊賀市', 'イガシ', '炊村', 'カシキムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市甲野', '24', '24216', '5181404', '三重県', 'ミエケン', '伊賀市', 'イガシ', '甲野', 'コウノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市鳳凰寺', '24', '24216', '5181405', '三重県', 'ミエケン', '伊賀市', 'イガシ', '鳳凰寺', 'ボウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市中村', '24', '24216', '5181406', '三重県', 'ミエケン', '伊賀市', 'イガシ', '中村', 'ナカムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市出後', '24', '24216', '5181407', '三重県', 'ミエケン', '伊賀市', 'イガシ', '出後', 'イズゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市畑村', '24', '24216', '5181408', '三重県', 'ミエケン', '伊賀市', 'イガシ', '畑村', 'ハタムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市上阿波', '24', '24216', '5181412', '三重県', 'ミエケン', '伊賀市', 'イガシ', '上阿波', 'カミアワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市猿野', '24', '24216', '5181414', '三重県', 'ミエケン', '伊賀市', 'イガシ', '猿野', 'マシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市下阿波', '24', '24216', '5181416', '三重県', 'ミエケン', '伊賀市', 'イガシ', '下阿波', 'シモアワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市富永', '24', '24216', '5181417', '三重県', 'ミエケン', '伊賀市', 'イガシ', '富永', 'トミナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市真泥', '24', '24216', '5181421', '三重県', 'ミエケン', '伊賀市', 'イガシ', '真泥', 'ミドロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市平田', '24', '24216', '5181422', '三重県', 'ミエケン', '伊賀市', 'イガシ', '平田', 'ヒラタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市富岡', '24', '24216', '5181424', '三重県', 'ミエケン', '伊賀市', 'イガシ', '富岡', 'トミオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市川北', '24', '24216', '5181425', '三重県', 'ミエケン', '伊賀市', 'イガシ', '川北', 'カワキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市広瀬', '24', '24216', '5181426', '三重県', 'ミエケン', '伊賀市', 'イガシ', '広瀬', 'ヒロセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市奥馬野', '24', '24216', '5181427', '三重県', 'ミエケン', '伊賀市', 'イガシ', '奥馬野', 'オクバノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市中馬野', '24', '24216', '5181428', '三重県', 'ミエケン', '伊賀市', 'イガシ', '中馬野', 'ナカバノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市坂下', '24', '24216', '5181429', '三重県', 'ミエケン', '伊賀市', 'イガシ', '坂下', 'サカゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県亀山市', '24', '24210', '5190100', '三重県', 'ミエケン', '亀山市', 'カメヤマシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('56852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県亀山市井田川町', '24', '24210', '5190101', '三重県', 'ミエケン', '亀山市', 'カメヤマシ', '井田川町', 'イダガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県亀山市和田町', '24', '24210', '5190102', '三重県', 'ミエケン', '亀山市', 'カメヤマシ', '和田町', 'ワダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県亀山市川合町', '24', '24210', '5190103', '三重県', 'ミエケン', '亀山市', 'カメヤマシ', '川合町', 'カワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県亀山市椿世町', '24', '24210', '5190104', '三重県', 'ミエケン', '亀山市', 'カメヤマシ', '椿世町', 'ツバイソチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県亀山市みずほ台', '24', '24210', '5190105', '三重県', 'ミエケン', '亀山市', 'カメヤマシ', 'みずほ台', 'ミズホダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県亀山市みどり町', '24', '24210', '5190106', '三重県', 'ミエケン', '亀山市', 'カメヤマシ', 'みどり町', 'ミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県亀山市栄町', '24', '24210', '5190111', '三重県', 'ミエケン', '亀山市', 'カメヤマシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県亀山市上野町', '24', '24210', '5190112', '三重県', 'ミエケン', '亀山市', 'カメヤマシ', '上野町', 'ウエノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県亀山市小下町', '24', '24210', '5190113', '三重県', 'ミエケン', '亀山市', 'カメヤマシ', '小下町', 'コミザチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県亀山市南鹿島町', '24', '24210', '5190114', '三重県', 'ミエケン', '亀山市', 'カメヤマシ', '南鹿島町', 'ミナミカシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県亀山市北鹿島町', '24', '24210', '5190115', '三重県', 'ミエケン', '亀山市', 'カメヤマシ', '北鹿島町', 'キタカシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県亀山市本町', '24', '24210', '5190116', '三重県', 'ミエケン', '亀山市', 'カメヤマシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県亀山市北山町', '24', '24210', '5190117', '三重県', 'ミエケン', '亀山市', 'カメヤマシ', '北山町', 'キタヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県亀山市北町', '24', '24210', '5190118', '三重県', 'ミエケン', '亀山市', 'カメヤマシ', '北町', 'キタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県亀山市高塚町', '24', '24210', '5190119', '三重県', 'ミエケン', '亀山市', 'カメヤマシ', '高塚町', 'タカツカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県亀山市江ケ室', '24', '24210', '5190121', '三重県', 'ミエケン', '亀山市', 'カメヤマシ', '江ケ室', 'エガムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県亀山市東台町', '24', '24210', '5190122', '三重県', 'ミエケン', '亀山市', 'カメヤマシ', '東台町', 'ヒガシダイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県亀山市渋倉町', '24', '24210', '5190123', '三重県', 'ミエケン', '亀山市', 'カメヤマシ', '渋倉町', 'シブクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県亀山市東御幸町', '24', '24210', '5190124', '三重県', 'ミエケン', '亀山市', 'カメヤマシ', '東御幸町', 'ヒガシミユキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県亀山市東町', '24', '24210', '5190125', '三重県', 'ミエケン', '亀山市', 'カメヤマシ', '東町', 'ヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県亀山市東丸町', '24', '24210', '5190126', '三重県', 'ミエケン', '亀山市', 'カメヤマシ', '東丸町', 'ヒガシマルチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県亀山市中屋敷町', '24', '24210', '5190127', '三重県', 'ミエケン', '亀山市', 'カメヤマシ', '中屋敷町', 'ナカヤシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県亀山市井尻町', '24', '24210', '5190131', '三重県', 'ミエケン', '亀山市', 'カメヤマシ', '井尻町', 'イジリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県亀山市菅内町', '24', '24210', '5190132', '三重県', 'ミエケン', '亀山市', 'カメヤマシ', '菅内町', 'スガウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県亀山市下庄町', '24', '24210', '5190133', '三重県', 'ミエケン', '亀山市', 'カメヤマシ', '下庄町', 'シモノショウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県亀山市中庄町', '24', '24210', '5190134', '三重県', 'ミエケン', '亀山市', 'カメヤマシ', '中庄町', 'ナカノショウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県亀山市三寺町', '24', '24210', '5190135', '三重県', 'ミエケン', '亀山市', 'カメヤマシ', '三寺町', 'ミツデラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県亀山市田茂町', '24', '24210', '5190136', '三重県', 'ミエケン', '亀山市', 'カメヤマシ', '田茂町', 'タモチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県亀山市阿野田町', '24', '24210', '5190137', '三重県', 'ミエケン', '亀山市', 'カメヤマシ', '阿野田町', 'アノダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県亀山市海本町', '24', '24210', '5190141', '三重県', 'ミエケン', '亀山市', 'カメヤマシ', '海本町', 'カイモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県亀山市天神', '24', '24210', '5190142', '三重県', 'ミエケン', '亀山市', 'カメヤマシ', '天神', 'テンジン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県亀山市安知本町', '24', '24210', '5190143', '三重県', 'ミエケン', '亀山市', 'カメヤマシ', '安知本町', 'アチモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県亀山市楠平尾町', '24', '24210', '5190144', '三重県', 'ミエケン', '亀山市', 'カメヤマシ', '楠平尾町', 'クスビラオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県亀山市和賀町', '24', '24210', '5190145', '三重県', 'ミエケン', '亀山市', 'カメヤマシ', '和賀町', 'ワガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県亀山市野村町', '24', '24210', '5190146', '三重県', 'ミエケン', '亀山市', 'カメヤマシ', '野村町', 'ノムラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県亀山市山下町', '24', '24210', '5190147', '三重県', 'ミエケン', '亀山市', 'カメヤマシ', '山下町', 'ヤマシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県亀山市木下町', '24', '24210', '5190148', '三重県', 'ミエケン', '亀山市', 'カメヤマシ', '木下町', 'コノシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県亀山市若山町', '24', '24210', '5190151', '三重県', 'ミエケン', '亀山市', 'カメヤマシ', '若山町', 'ワカヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県亀山市本丸町', '24', '24210', '5190152', '三重県', 'ミエケン', '亀山市', 'カメヤマシ', '本丸町', 'ホンマルチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県亀山市西町', '24', '24210', '5190153', '三重県', 'ミエケン', '亀山市', 'カメヤマシ', '西町', 'ニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県亀山市南崎町', '24', '24210', '5190154', '三重県', 'ミエケン', '亀山市', 'カメヤマシ', '南崎町', 'ミナミザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県亀山市御幸町', '24', '24210', '5190155', '三重県', 'ミエケン', '亀山市', 'カメヤマシ', '御幸町', 'ミユキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県亀山市南野町', '24', '24210', '5190156', '三重県', 'ミエケン', '亀山市', 'カメヤマシ', '南野町', 'ミナミノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県亀山市北野町', '24', '24210', '5190157', '三重県', 'ミエケン', '亀山市', 'カメヤマシ', '北野町', 'キタノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県亀山市市ケ坂町', '24', '24210', '5190158', '三重県', 'ミエケン', '亀山市', 'カメヤマシ', '市ケ坂町', 'イチガサカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県亀山市西丸町', '24', '24210', '5190159', '三重県', 'ミエケン', '亀山市', 'カメヤマシ', '西丸町', 'ニシマルチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県亀山市小川町', '24', '24210', '5190161', '三重県', 'ミエケン', '亀山市', 'カメヤマシ', '小川町', 'オガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県亀山市住山町', '24', '24210', '5190162', '三重県', 'ミエケン', '亀山市', 'カメヤマシ', '住山町', 'スミヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県亀山市亀田町', '24', '24210', '5190163', '三重県', 'ミエケン', '亀山市', 'カメヤマシ', '亀田町', 'カメダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県亀山市羽若町', '24', '24210', '5190164', '三重県', 'ミエケン', '亀山市', 'カメヤマシ', '羽若町', 'ハワカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県亀山市野村', '24', '24210', '5190165', '三重県', 'ミエケン', '亀山市', 'カメヤマシ', '野村', 'ノムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県亀山市布気町', '24', '24210', '5190166', '三重県', 'ミエケン', '亀山市', 'カメヤマシ', '布気町', 'フケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県亀山市小野町', '24', '24210', '5190167', '三重県', 'ミエケン', '亀山市', 'カメヤマシ', '小野町', 'オノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県亀山市太岡寺町', '24', '24210', '5190168', '三重県', 'ミエケン', '亀山市', 'カメヤマシ', '太岡寺町', 'タイコウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県亀山市白木町', '24', '24210', '5190169', '三重県', 'ミエケン', '亀山市', 'カメヤマシ', '白木町', 'シラキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県亀山市アイリス町', '24', '24210', '5190171', '三重県', 'ミエケン', '亀山市', 'カメヤマシ', 'アイリス町', 'アイリスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県亀山市みずきが丘', '24', '24210', '5190181', '三重県', 'ミエケン', '亀山市', 'カメヤマシ', 'みずきが丘', 'ミズキガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県亀山市川崎町', '24', '24210', '5190211', '三重県', 'ミエケン', '亀山市', 'カメヤマシ', '川崎町', 'カワサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県亀山市能褒野町', '24', '24210', '5190212', '三重県', 'ミエケン', '亀山市', 'カメヤマシ', '能褒野町', 'ノボノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県亀山市田村町', '24', '24210', '5190213', '三重県', 'ミエケン', '亀山市', 'カメヤマシ', '田村町', 'タムラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県亀山市長明寺町', '24', '24210', '5190214', '三重県', 'ミエケン', '亀山市', 'カメヤマシ', '長明寺町', 'チョウミョウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県亀山市太森町', '24', '24210', '5190215', '三重県', 'ミエケン', '亀山市', 'カメヤマシ', '太森町', 'フトモリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県亀山市辺法寺町', '24', '24210', '5190221', '三重県', 'ミエケン', '亀山市', 'カメヤマシ', '辺法寺町', 'ヘンボウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県亀山市両尾町', '24', '24210', '5190222', '三重県', 'ミエケン', '亀山市', 'カメヤマシ', '両尾町', 'フタオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県亀山市安坂山町', '24', '24210', '5190223', '三重県', 'ミエケン', '亀山市', 'カメヤマシ', '安坂山町', 'アサカヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市西庄内町', '24', '24207', '5190271', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '西庄内町', 'ニシショウナイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市東庄内町', '24', '24207', '5190272', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '東庄内町', 'ヒガシショウナイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市大久保町', '24', '24207', '5190311', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '大久保町', 'オオクボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市椿一宮町', '24', '24207', '5190312', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '椿一宮町', 'ツバキイチミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市追分町', '24', '24207', '5190313', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '追分町', 'オイワケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市長沢町', '24', '24207', '5190314', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '長沢町', 'ナガサワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市山本町', '24', '24207', '5190315', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '山本町', 'ヤマモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市小岐須町', '24', '24207', '5190316', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '小岐須町', 'オギスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市深溝町', '24', '24207', '5190321', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '深溝町', 'フカミゾチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市三畑町', '24', '24207', '5190322', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '三畑町', 'ミハタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市伊船町', '24', '24207', '5190323', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '伊船町', 'イフナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県鈴鹿市小社町', '24', '24207', '5190324', '三重県', 'ミエケン', '鈴鹿市', 'スズカシ', '小社町', 'コヤシロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡玉城町', '24', '24461', '5190400', '三重県', 'ミエケン', '度会郡玉城町', 'ワタライグンタマキチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('56937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡玉城町世古', '24', '24461', '5190401', '三重県', 'ミエケン', '度会郡玉城町', 'ワタライグンタマキチョウ', '世古', 'セコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡玉城町門前', '24', '24461', '5190402', '三重県', 'ミエケン', '度会郡玉城町', 'ワタライグンタマキチョウ', '門前', 'モンゼン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡玉城町井倉', '24', '24461', '5190403', '三重県', 'ミエケン', '度会郡玉城町', 'ワタライグンタマキチョウ', '井倉', 'イグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡玉城町長更', '24', '24461', '5190404', '三重県', 'ミエケン', '度会郡玉城町', 'ワタライグンタマキチョウ', '長更', 'ナガフケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡玉城町日向', '24', '24461', '5190405', '三重県', 'ミエケン', '度会郡玉城町', 'ワタライグンタマキチョウ', '日向', 'ヒュウガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡玉城町岡村', '24', '24461', '5190406', '三重県', 'ミエケン', '度会郡玉城町', 'ワタライグンタマキチョウ', '岡村', 'オカムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡玉城町玉川', '24', '24461', '5190407', '三重県', 'ミエケン', '度会郡玉城町', 'ワタライグンタマキチョウ', '玉川', 'タマガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡玉城町坂本', '24', '24461', '5190408', '三重県', 'ミエケン', '度会郡玉城町', 'ワタライグンタマキチョウ', '坂本', 'サカモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡玉城町久保', '24', '24461', '5190411', '三重県', 'ミエケン', '度会郡玉城町', 'ワタライグンタマキチョウ', '久保', 'クボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡玉城町中楽', '24', '24461', '5190412', '三重県', 'ミエケン', '度会郡玉城町', 'ワタライグンタマキチョウ', '中楽', 'チュウラク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡玉城町妙法寺', '24', '24461', '5190413', '三重県', 'ミエケン', '度会郡玉城町', 'ワタライグンタマキチョウ', '妙法寺', 'ミョウホウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡玉城町佐田', '24', '24461', '5190414', '三重県', 'ミエケン', '度会郡玉城町', 'ワタライグンタマキチョウ', '佐田', 'サタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡玉城町田丸', '24', '24461', '5190415', '三重県', 'ミエケン', '度会郡玉城町', 'ワタライグンタマキチョウ', '田丸', 'タマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡玉城町下田辺', '24', '24461', '5190416', '三重県', 'ミエケン', '度会郡玉城町', 'ワタライグンタマキチョウ', '下田辺', 'シモタヌイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡玉城町上田辺', '24', '24461', '5190417', '三重県', 'ミエケン', '度会郡玉城町', 'ワタライグンタマキチョウ', '上田辺', 'カミタヌイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡玉城町富岡', '24', '24461', '5190421', '三重県', 'ミエケン', '度会郡玉城町', 'ワタライグンタマキチョウ', '富岡', 'トミオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡玉城町小社曽根', '24', '24461', '5190422', '三重県', 'ミエケン', '度会郡玉城町', 'ワタライグンタマキチョウ', '小社曽根', 'オゴソソネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡玉城町昼田', '24', '24461', '5190423', '三重県', 'ミエケン', '度会郡玉城町', 'ワタライグンタマキチョウ', '昼田', 'ヒルダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡玉城町山岡', '24', '24461', '5190424', '三重県', 'ミエケン', '度会郡玉城町', 'ワタライグンタマキチョウ', '山岡', 'ヤマオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡玉城町岩出', '24', '24461', '5190425', '三重県', 'ミエケン', '度会郡玉城町', 'ワタライグンタマキチョウ', '岩出', 'イワデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡玉城町中角', '24', '24461', '5190426', '三重県', 'ミエケン', '度会郡玉城町', 'ワタライグンタマキチョウ', '中角', 'ナカツノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡玉城町宮古', '24', '24461', '5190427', '三重県', 'ミエケン', '度会郡玉城町', 'ワタライグンタマキチョウ', '宮古', 'ミヤコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡玉城町岡出', '24', '24461', '5190428', '三重県', 'ミエケン', '度会郡玉城町', 'ワタライグンタマキチョウ', '岡出', 'オカデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡玉城町蚊野', '24', '24461', '5190431', '三重県', 'ミエケン', '度会郡玉城町', 'ワタライグンタマキチョウ', '蚊野', 'カノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡玉城町野篠', '24', '24461', '5190432', '三重県', 'ミエケン', '度会郡玉城町', 'ワタライグンタマキチョウ', '野篠', 'ノジノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡玉城町勝田', '24', '24461', '5190433', '三重県', 'ミエケン', '度会郡玉城町', 'ワタライグンタマキチョウ', '勝田', 'カツタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡玉城町田宮寺', '24', '24461', '5190434', '三重県', 'ミエケン', '度会郡玉城町', 'ワタライグンタマキチョウ', '田宮寺', 'タミヤジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡玉城町矢野', '24', '24461', '5190435', '三重県', 'ミエケン', '度会郡玉城町', 'ワタライグンタマキチョウ', '矢野', 'ヤノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡玉城町山神', '24', '24461', '5190436', '三重県', 'ミエケン', '度会郡玉城町', 'ワタライグンタマキチョウ', '山神', 'ヤマカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡玉城町積良', '24', '24461', '5190437', '三重県', 'ミエケン', '度会郡玉城町', 'ワタライグンタマキチョウ', '積良', 'ツムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡玉城町原', '24', '24461', '5190438', '三重県', 'ミエケン', '度会郡玉城町', 'ワタライグンタマキチョウ', '原', 'ハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市小俣町明野', '24', '24203', '5190501', '三重県', 'ミエケン', '伊勢市', 'イセシ', '小俣町明野', 'オバタチョウアケノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市小俣町相合', '24', '24203', '5190502', '三重県', 'ミエケン', '伊勢市', 'イセシ', '小俣町相合', 'オバタチョウソウゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市小俣町元町', '24', '24203', '5190503', '三重県', 'ミエケン', '伊勢市', 'イセシ', '小俣町元町', 'オバタチョウモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市小俣町宮前', '24', '24203', '5190504', '三重県', 'ミエケン', '伊勢市', 'イセシ', '小俣町宮前', 'オバタチョウミヤマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市小俣町本町', '24', '24203', '5190505', '三重県', 'ミエケン', '伊勢市', 'イセシ', '小俣町本町', 'オバタチョウホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市小俣町湯田', '24', '24203', '5190506', '三重県', 'ミエケン', '伊勢市', 'イセシ', '小俣町湯田', 'オバタチョウユタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市小俣町新村', '24', '24203', '5190507', '三重県', 'ミエケン', '伊勢市', 'イセシ', '小俣町新村', 'オバタチョウシムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市二見町松下', '24', '24203', '5190601', '三重県', 'ミエケン', '伊勢市', 'イセシ', '二見町松下', 'フタミチョウマツシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市二見町江', '24', '24203', '5190602', '三重県', 'ミエケン', '伊勢市', 'イセシ', '二見町江', 'フタミチョウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市二見町三津', '24', '24203', '5190603', '三重県', 'ミエケン', '伊勢市', 'イセシ', '二見町三津', 'フタミチョウミツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市二見町山田原', '24', '24203', '5190604', '三重県', 'ミエケン', '伊勢市', 'イセシ', '二見町山田原', 'フタミチョウヤマダハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市二見町溝口', '24', '24203', '5190605', '三重県', 'ミエケン', '伊勢市', 'イセシ', '二見町溝口', 'フタミチョウミゾグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市二見町荘', '24', '24203', '5190606', '三重県', 'ミエケン', '伊勢市', 'イセシ', '二見町荘', 'フタミチョウショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市二見町西', '24', '24203', '5190607', '三重県', 'ミエケン', '伊勢市', 'イセシ', '二見町西', 'フタミチョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市二見町今一色', '24', '24203', '5190608', '三重県', 'ミエケン', '伊勢市', 'イセシ', '二見町今一色', 'フタミチョウイマイシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市二見町茶屋', '24', '24203', '5190609', '三重県', 'ミエケン', '伊勢市', 'イセシ', '二見町茶屋', 'フタミチョウチャヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊勢市二見町光の街', '24', '24203', '5190611', '三重県', 'ミエケン', '伊勢市', 'イセシ', '二見町光の街', 'フタミチョウヒカリノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県亀山市関町坂下', '24', '24210', '5191101', '三重県', 'ミエケン', '亀山市', 'カメヤマシ', '関町坂下', 'セキチョウサカシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県亀山市関町沓掛', '24', '24210', '5191102', '三重県', 'ミエケン', '亀山市', 'カメヤマシ', '関町沓掛', 'セキチョウクツカケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県亀山市関町市瀬', '24', '24210', '5191103', '三重県', 'ミエケン', '亀山市', 'カメヤマシ', '関町市瀬', 'セキチョウイチノセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県亀山市関町白木一色', '24', '24210', '5191104', '三重県', 'ミエケン', '亀山市', 'カメヤマシ', '関町白木一色', 'セキチョウシラキイッシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県亀山市関町鷲山', '24', '24210', '5191105', '三重県', 'ミエケン', '亀山市', 'カメヤマシ', '関町鷲山', 'セキチョウワシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('56999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県亀山市関町会下', '24', '24210', '5191106', '三重県', 'ミエケン', '亀山市', 'カメヤマシ', '関町会下', 'セキチョウエゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県亀山市関町木崎', '24', '24210', '5191107', '三重県', 'ミエケン', '亀山市', 'カメヤマシ', '関町木崎', 'セキチョウコザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県亀山市関町小野', '24', '24210', '5191108', '三重県', 'ミエケン', '亀山市', 'カメヤマシ', '関町小野', 'セキチョウオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県亀山市関町新所', '24', '24210', '5191111', '三重県', 'ミエケン', '亀山市', 'カメヤマシ', '関町新所', 'セキチョウシンジョ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県亀山市関町中町', '24', '24210', '5191112', '三重県', 'ミエケン', '亀山市', 'カメヤマシ', '関町中町', 'セキチョウナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県亀山市関町古厩', '24', '24210', '5191113', '三重県', 'ミエケン', '亀山市', 'カメヤマシ', '関町古厩', 'セキチョウフルマヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県亀山市関町萩原', '24', '24210', '5191114', '三重県', 'ミエケン', '亀山市', 'カメヤマシ', '関町萩原', 'セキチョウハギワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県亀山市関町福徳', '24', '24210', '5191115', '三重県', 'ミエケン', '亀山市', 'カメヤマシ', '関町福徳', 'セキチョウフクトク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県亀山市関町久我', '24', '24210', '5191116', '三重県', 'ミエケン', '亀山市', 'カメヤマシ', '関町久我', 'セキチョウクガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県亀山市関町泉ケ丘', '24', '24210', '5191117', '三重県', 'ミエケン', '亀山市', 'カメヤマシ', '関町泉ケ丘', 'セキチョウイズミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県亀山市関町富士ハイツ', '24', '24210', '5191118', '三重県', 'ミエケン', '亀山市', 'カメヤマシ', '関町富士ハイツ', 'セキチョウフジハイツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県亀山市関ケ丘', '24', '24210', '5191119', '三重県', 'ミエケン', '亀山市', 'カメヤマシ', '関ケ丘', 'セキガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県亀山市加太梶ケ坂', '24', '24210', '5191121', '三重県', 'ミエケン', '亀山市', 'カメヤマシ', '加太梶ケ坂', 'カブトカジガサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県亀山市加太市場', '24', '24210', '5191122', '三重県', 'ミエケン', '亀山市', 'カメヤマシ', '加太市場', 'カブトイチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県亀山市関町金場', '24', '24210', '5191123', '三重県', 'ミエケン', '亀山市', 'カメヤマシ', '関町金場', 'セキチョウカネバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県亀山市関町越川', '24', '24210', '5191124', '三重県', 'ミエケン', '亀山市', 'カメヤマシ', '関町越川', 'セキチョウエチガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県亀山市加太向井', '24', '24210', '5191125', '三重県', 'ミエケン', '亀山市', 'カメヤマシ', '加太向井', 'カブトムカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県亀山市加太神武', '24', '24210', '5191126', '三重県', 'ミエケン', '亀山市', 'カメヤマシ', '加太神武', 'カブトジンム', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県亀山市加太中在家', '24', '24210', '5191127', '三重県', 'ミエケン', '亀山市', 'カメヤマシ', '加太中在家', 'カブトナカザイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県亀山市加太北在家', '24', '24210', '5191128', '三重県', 'ミエケン', '亀山市', 'カメヤマシ', '加太北在家', 'カブトキタザイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県亀山市加太板屋', '24', '24210', '5191129', '三重県', 'ミエケン', '亀山市', 'カメヤマシ', '加太板屋', 'カブトイタヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市一ツ家', '24', '24216', '5191401', '三重県', 'ミエケン', '伊賀市', 'イガシ', '一ツ家', 'ヒトツヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市柘植町', '24', '24216', '5191402', '三重県', 'ミエケン', '伊賀市', 'イガシ', '柘植町', 'ツゲマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市上村', '24', '24216', '5191403', '三重県', 'ミエケン', '伊賀市', 'イガシ', '上村', 'ウエムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市中柘植', '24', '24216', '5191404', '三重県', 'ミエケン', '伊賀市', 'イガシ', '中柘植', 'ナカツゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市野村', '24', '24216', '5191405', '三重県', 'ミエケン', '伊賀市', 'イガシ', '野村', 'ノムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市小杉', '24', '24216', '5191406', '三重県', 'ミエケン', '伊賀市', 'イガシ', '小杉', 'コスギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市楯岡', '24', '24216', '5191411', '三重県', 'ミエケン', '伊賀市', 'イガシ', '楯岡', 'タテオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市下柘植', '24', '24216', '5191412', '三重県', 'ミエケン', '伊賀市', 'イガシ', '下柘植', 'シモツゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市愛田', '24', '24216', '5191413', '三重県', 'ミエケン', '伊賀市', 'イガシ', '愛田', 'アイタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市御代', '24', '24216', '5191414', '三重県', 'ミエケン', '伊賀市', 'イガシ', '御代', 'ミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市柏野', '24', '24216', '5191415', '三重県', 'ミエケン', '伊賀市', 'イガシ', '柏野', 'カシワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市新堂', '24', '24216', '5191416', '三重県', 'ミエケン', '伊賀市', 'イガシ', '新堂', 'シンドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市山畑', '24', '24216', '5191421', '三重県', 'ミエケン', '伊賀市', 'イガシ', '山畑', 'ヤバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市希望ケ丘東', '24', '24216', '5191422', '三重県', 'ミエケン', '伊賀市', 'イガシ', '希望ケ丘東', 'キボウガオカヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市希望ケ丘西', '24', '24216', '5191423', '三重県', 'ミエケン', '伊賀市', 'イガシ', '希望ケ丘西', 'キボウガオカニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市川東', '24', '24216', '5191424', '三重県', 'ミエケン', '伊賀市', 'イガシ', '川東', 'カワヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市川西', '24', '24216', '5191425', '三重県', 'ミエケン', '伊賀市', 'イガシ', '川西', 'カワニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市西之澤', '24', '24216', '5191426', '三重県', 'ミエケン', '伊賀市', 'イガシ', '西之澤', 'ニシノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市島ケ原川南', '24', '24216', '5191701', '三重県', 'ミエケン', '伊賀市', 'イガシ', '島ケ原', 'シマガハラ', null, null, '川南', 'カワミナミ');
INSERT INTO `ms_addresses` VALUES ('57040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市島ケ原不見上', '24', '24216', '5191702', '三重県', 'ミエケン', '伊賀市', 'イガシ', '島ケ原', 'シマガハラ', null, null, '不見上', 'フケンジョウ');
INSERT INTO `ms_addresses` VALUES ('57041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市島ケ原山菅', '24', '24216', '5191703', '三重県', 'ミエケン', '伊賀市', 'イガシ', '島ケ原', 'シマガハラ', null, null, '山菅', 'ヤマスゲ');
INSERT INTO `ms_addresses` VALUES ('57042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市島ケ原町', '24', '24216', '5191704', '三重県', 'ミエケン', '伊賀市', 'イガシ', '島ケ原', 'シマガハラ', null, null, '町', 'マチ');
INSERT INTO `ms_addresses` VALUES ('57043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市島ケ原中村', '24', '24216', '5191705', '三重県', 'ミエケン', '伊賀市', 'イガシ', '島ケ原', 'シマガハラ', null, null, '中村', 'ナカムラ');
INSERT INTO `ms_addresses` VALUES ('57044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市島ケ原奥村', '24', '24216', '5191706', '三重県', 'ミエケン', '伊賀市', 'イガシ', '島ケ原', 'シマガハラ', null, null, '奥村', 'オクムラ');
INSERT INTO `ms_addresses` VALUES ('57045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市島ケ原大道', '24', '24216', '5191707', '三重県', 'ミエケン', '伊賀市', 'イガシ', '島ケ原', 'シマガハラ', null, null, '大道', 'オオドウ');
INSERT INTO `ms_addresses` VALUES ('57046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市島ケ原中矢', '24', '24216', '5191708', '三重県', 'ミエケン', '伊賀市', 'イガシ', '島ケ原', 'シマガハラ', null, null, '中矢', 'ナカヤ');
INSERT INTO `ms_addresses` VALUES ('57047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県伊賀市島ケ原', '24', '24216', '5191711', '三重県', 'ミエケン', '伊賀市', 'イガシ', '島ケ原', 'シマガハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡多気町', '24', '24441', '5192100', '三重県', 'ミエケン', '多気郡多気町', 'タキグンタキチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('57049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市上蛸路町', '24', '24204', '5192141', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '上蛸路町', 'カミタコジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市下蛸路町', '24', '24204', '5192142', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '下蛸路町', 'シモタコジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市中万町', '24', '24204', '5192143', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '中万町', 'チュウマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市八太町', '24', '24204', '5192144', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '八太町', 'ハッタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市射和町', '24', '24204', '5192145', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '射和町', 'イザワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市阿波曽町', '24', '24204', '5192146', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '阿波曽町', 'アワソチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市庄町', '24', '24204', '5192147', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '庄町', 'ショウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県松阪市御麻生薗町', '24', '24204', '5192148', '三重県', 'ミエケン', '松阪市', 'マツサカシ', '御麻生薗町', 'ミオゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡多気町朝長', '24', '24441', '5192151', '三重県', 'ミエケン', '多気郡多気町', 'タキグンタキチョウ', '朝長', 'アサオサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡多気町弟国', '24', '24441', '5192152', '三重県', 'ミエケン', '多気郡多気町', 'タキグンタキチョウ', '弟国', 'オウグニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡多気町河田', '24', '24441', '5192153', '三重県', 'ミエケン', '多気郡多気町', 'タキグンタキチョウ', '河田', 'コウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡多気町多気', '24', '24441', '5192154', '三重県', 'ミエケン', '多気郡多気町', 'タキグンタキチョウ', '多気', 'タキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡多気町東池上', '24', '24441', '5192155', '三重県', 'ミエケン', '多気郡多気町', 'タキグンタキチョウ', '東池上', 'ヒガシイケベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡多気町西池上', '24', '24441', '5192156', '三重県', 'ミエケン', '多気郡多気町', 'タキグンタキチョウ', '西池上', 'ニシイケベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡多気町五佐奈', '24', '24441', '5192157', '三重県', 'ミエケン', '多気郡多気町', 'タキグンタキチョウ', '五佐奈', 'ゴサナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡多気町荒蒔', '24', '24441', '5192158', '三重県', 'ミエケン', '多気郡多気町', 'タキグンタキチョウ', '荒蒔', 'アラマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡多気町兄国', '24', '24441', '5192159', '三重県', 'ミエケン', '多気郡多気町', 'タキグンタキチョウ', '兄国', 'エクニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡多気町土羽', '24', '24441', '5192161', '三重県', 'ミエケン', '多気郡多気町', 'タキグンタキチョウ', '土羽', 'トバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡多気町笠木', '24', '24441', '5192162', '三重県', 'ミエケン', '多気郡多気町', 'タキグンタキチョウ', '笠木', 'カサギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡多気町矢田', '24', '24441', '5192163', '三重県', 'ミエケン', '多気郡多気町', 'タキグンタキチョウ', '矢田', 'ヤタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡多気町森荘', '24', '24441', '5192164', '三重県', 'ミエケン', '多気郡多気町', 'タキグンタキチョウ', '森荘', 'モリショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡多気町田中', '24', '24441', '5192165', '三重県', 'ミエケン', '多気郡多気町', 'タキグンタキチョウ', '田中', 'タナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡多気町野中', '24', '24441', '5192166', '三重県', 'ミエケン', '多気郡多気町', 'タキグンタキチョウ', '野中', 'ノナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡多気町相鹿瀬', '24', '24441', '5192167', '三重県', 'ミエケン', '多気郡多気町', 'タキグンタキチョウ', '相鹿瀬', 'オウカセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡多気町西山', '24', '24441', '5192171', '三重県', 'ミエケン', '多気郡多気町', 'タキグンタキチョウ', '西山', 'ニシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡多気町四神田', '24', '24441', '5192172', '三重県', 'ミエケン', '多気郡多気町', 'タキグンタキチョウ', '四神田', 'シコウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡多気町油夫', '24', '24441', '5192173', '三重県', 'ミエケン', '多気郡多気町', 'タキグンタキチョウ', '油夫', 'ユブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡多気町五桂', '24', '24441', '5192174', '三重県', 'ミエケン', '多気郡多気町', 'タキグンタキチョウ', '五桂', 'ゴカツラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡多気町前村', '24', '24441', '5192175', '三重県', 'ミエケン', '多気郡多気町', 'タキグンタキチョウ', '前村', 'マエムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡多気町長谷', '24', '24441', '5192176', '三重県', 'ミエケン', '多気郡多気町', 'タキグンタキチョウ', '長谷', 'ハセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡多気町神坂', '24', '24441', '5192177', '三重県', 'ミエケン', '多気郡多気町', 'タキグンタキチョウ', '神坂', 'コウザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡多気町平谷', '24', '24441', '5192178', '三重県', 'ミエケン', '多気郡多気町', 'タキグンタキチョウ', '平谷', 'ヒラダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡多気町仁田', '24', '24441', '5192179', '三重県', 'ミエケン', '多気郡多気町', 'タキグンタキチョウ', '仁田', 'ニタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡多気町相可', '24', '24441', '5192181', '三重県', 'ミエケン', '多気郡多気町', 'タキグンタキチョウ', '相可', 'オウカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡多気町相可台', '24', '24441', '5192182', '三重県', 'ミエケン', '多気郡多気町', 'タキグンタキチョウ', '相可台', 'オウカダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡多気町四疋田', '24', '24441', '5192183', '三重県', 'ミエケン', '多気郡多気町', 'タキグンタキチョウ', '四疋田', 'シヒキダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡多気町三疋田', '24', '24441', '5192184', '三重県', 'ミエケン', '多気郡多気町', 'タキグンタキチョウ', '三疋田', 'サンビキダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡多気町佐伯中', '24', '24441', '5192185', '三重県', 'ミエケン', '多気郡多気町', 'タキグンタキチョウ', '佐伯中', 'サエキナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡多気町井内林', '24', '24441', '5192186', '三重県', 'ミエケン', '多気郡多気町', 'タキグンタキチョウ', '井内林', 'イノウチバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡多気町鍬形', '24', '24441', '5192187', '三重県', 'ミエケン', '多気郡多気町', 'タキグンタキチョウ', '鍬形', 'クワガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡多気町牧', '24', '24441', '5192188', '三重県', 'ミエケン', '多気郡多気町', 'タキグンタキチョウ', '牧', 'マキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡多気町津留', '24', '24441', '5192189', '三重県', 'ミエケン', '多気郡多気町', 'タキグンタキチョウ', '津留', 'ツル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡多気町上出江', '24', '24441', '5192201', '三重県', 'ミエケン', '多気郡多気町', 'タキグンタキチョウ', '上出江', 'カミイズエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡多気町下出江', '24', '24441', '5192202', '三重県', 'ミエケン', '多気郡多気町', 'タキグンタキチョウ', '下出江', 'シモイズエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡多気町片野', '24', '24441', '5192203', '三重県', 'ミエケン', '多気郡多気町', 'タキグンタキチョウ', '片野', 'カタノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡多気町波多瀬', '24', '24441', '5192204', '三重県', 'ミエケン', '多気郡多気町', 'タキグンタキチョウ', '波多瀬', 'ハタセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡多気町丹生', '24', '24441', '5192211', '三重県', 'ミエケン', '多気郡多気町', 'タキグンタキチョウ', '丹生', 'ニウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡多気町色太', '24', '24441', '5192212', '三重県', 'ミエケン', '多気郡多気町', 'タキグンタキチョウ', '色太', 'シキフト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡多気町土屋', '24', '24441', '5192213', '三重県', 'ミエケン', '多気郡多気町', 'タキグンタキチョウ', '土屋', 'ツチヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡多気町車川', '24', '24441', '5192214', '三重県', 'ミエケン', '多気郡多気町', 'タキグンタキチョウ', '車川', 'クルマガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡多気町朝柄', '24', '24441', '5192215', '三重県', 'ミエケン', '多気郡多気町', 'タキグンタキチョウ', '朝柄', 'アサガラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡多気町古江', '24', '24441', '5192216', '三重県', 'ミエケン', '多気郡多気町', 'タキグンタキチョウ', '古江', 'フルエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡大台町', '24', '24443', '5192400', '三重県', 'ミエケン', '多気郡大台町', 'タキグンオオダイチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('57103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡大台町長ケ', '24', '24443', '5192401', '三重県', 'ミエケン', '多気郡大台町', 'タキグンオオダイチョウ', '長ケ', 'ナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡大台町下三瀬', '24', '24443', '5192402', '三重県', 'ミエケン', '多気郡大台町', 'タキグンオオダイチョウ', '下三瀬', 'シモミセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡大台町上三瀬', '24', '24443', '5192403', '三重県', 'ミエケン', '多気郡大台町', 'タキグンオオダイチョウ', '上三瀬', 'カミミセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡大台町佐原', '24', '24443', '5192404', '三重県', 'ミエケン', '多気郡大台町', 'タキグンオオダイチョウ', '佐原', 'サワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡大台町弥起井', '24', '24443', '5192405', '三重県', 'ミエケン', '多気郡大台町', 'タキグンオオダイチョウ', '弥起井', 'ヤキイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡大台町上菅', '24', '24443', '5192411', '三重県', 'ミエケン', '多気郡大台町', 'タキグンオオダイチョウ', '上菅', 'カミスガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡大台町川合', '24', '24443', '5192412', '三重県', 'ミエケン', '多気郡大台町', 'タキグンオオダイチョウ', '川合', 'カワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡大台町下菅', '24', '24443', '5192412', '三重県', 'ミエケン', '多気郡大台町', 'タキグンオオダイチョウ', '下菅', 'シモスガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡大台町菅合', '24', '24443', '5192412', '三重県', 'ミエケン', '多気郡大台町', 'タキグンオオダイチョウ', '菅合', 'スガアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡大台町滝広', '24', '24443', '5192412', '三重県', 'ミエケン', '多気郡大台町', 'タキグンオオダイチョウ', '滝広', 'タキヒロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡大台町大ケ所', '24', '24443', '5192413', '三重県', 'ミエケン', '多気郡大台町', 'タキグンオオダイチョウ', '大ケ所', 'オオガショ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡大台町千代', '24', '24443', '5192421', '三重県', 'ミエケン', '多気郡大台町', 'タキグンオオダイチョウ', '千代', 'センダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡大台町柳原', '24', '24443', '5192422', '三重県', 'ミエケン', '多気郡大台町', 'タキグンオオダイチョウ', '柳原', 'ヤナギハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡大台町新田', '24', '24443', '5192423', '三重県', 'ミエケン', '多気郡大台町', 'タキグンオオダイチョウ', '新田', 'シンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡大台町栃原', '24', '24443', '5192424', '三重県', 'ミエケン', '多気郡大台町', 'タキグンオオダイチョウ', '栃原', 'トチハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡大台町神瀬', '24', '24443', '5192425', '三重県', 'ミエケン', '多気郡大台町', 'タキグンオオダイチョウ', '神瀬', 'カミゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡大台町下楠', '24', '24443', '5192426', '三重県', 'ミエケン', '多気郡大台町', 'タキグンオオダイチョウ', '下楠', 'シモクス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡大台町上楠', '24', '24443', '5192427', '三重県', 'ミエケン', '多気郡大台町', 'タキグンオオダイチョウ', '上楠', 'カミクス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡大台町粟生', '24', '24443', '5192428', '三重県', 'ミエケン', '多気郡大台町', 'タキグンオオダイチョウ', '粟生', 'アオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡大台町高奈', '24', '24443', '5192429', '三重県', 'ミエケン', '多気郡大台町', 'タキグンオオダイチョウ', '高奈', 'タカナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡大台町下真手', '24', '24443', '5192501', '三重県', 'ミエケン', '多気郡大台町', 'タキグンオオダイチョウ', '下真手', 'シモマテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡大台町上真手', '24', '24443', '5192502', '三重県', 'ミエケン', '多気郡大台町', 'タキグンオオダイチョウ', '上真手', 'カミマテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡大台町本田木屋', '24', '24443', '5192503', '三重県', 'ミエケン', '多気郡大台町', 'タキグンオオダイチョウ', '本田木屋', 'ホンダゴヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡大台町小切畑', '24', '24443', '5192504', '三重県', 'ミエケン', '多気郡大台町', 'タキグンオオダイチョウ', '小切畑', 'コギリハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡大台町江馬', '24', '24443', '5192505', '三重県', 'ミエケン', '多気郡大台町', 'タキグンオオダイチョウ', '江馬', 'エマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡大台町天ケ瀬', '24', '24443', '5192506', '三重県', 'ミエケン', '多気郡大台町', 'タキグンオオダイチョウ', '天ケ瀬', 'アマガセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡大台町栗谷', '24', '24443', '5192507', '三重県', 'ミエケン', '多気郡大台町', 'タキグンオオダイチョウ', '栗谷', 'クリダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡大台町菅木屋', '24', '24443', '5192511', '三重県', 'ミエケン', '多気郡大台町', 'タキグンオオダイチョウ', '菅木屋', 'スガゴヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡大台町清滝', '24', '24443', '5192512', '三重県', 'ミエケン', '多気郡大台町', 'タキグンオオダイチョウ', '清滝', 'キヨタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡大台町薗', '24', '24443', '5192513', '三重県', 'ミエケン', '多気郡大台町', 'タキグンオオダイチョウ', '薗', 'ソノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡大台町茂原', '24', '24443', '5192514', '三重県', 'ミエケン', '多気郡大台町', 'タキグンオオダイチョウ', '茂原', 'モバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡大台町熊内', '24', '24443', '5192515', '三重県', 'ミエケン', '多気郡大台町', 'タキグンオオダイチョウ', '熊内', 'クモチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡大台町唐櫃', '24', '24443', '5192516', '三重県', 'ミエケン', '多気郡大台町', 'タキグンオオダイチョウ', '唐櫃', 'カラト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡大台町南', '24', '24443', '5192517', '三重県', 'ミエケン', '多気郡大台町', 'タキグンオオダイチョウ', '南', 'ミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡大台町大井', '24', '24443', '5192518', '三重県', 'ミエケン', '多気郡大台町', 'タキグンオオダイチョウ', '大井', 'オオイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡大台町明豆', '24', '24443', '5192521', '三重県', 'ミエケン', '多気郡大台町', 'タキグンオオダイチョウ', '明豆', 'ミョウズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡大台町御棟', '24', '24443', '5192522', '三重県', 'ミエケン', '多気郡大台町', 'タキグンオオダイチョウ', '御棟', 'オムナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡大台町小滝', '24', '24443', '5192523', '三重県', 'ミエケン', '多気郡大台町', 'タキグンオオダイチョウ', '小滝', 'コタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡大台町神滝', '24', '24443', '5192524', '三重県', 'ミエケン', '多気郡大台町', 'タキグンオオダイチョウ', '神滝', 'コウタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡大台町滝谷', '24', '24443', '5192525', '三重県', 'ミエケン', '多気郡大台町', 'タキグンオオダイチョウ', '滝谷', 'タキヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡大台町岩井', '24', '24443', '5192631', '三重県', 'ミエケン', '多気郡大台町', 'タキグンオオダイチョウ', '岩井', 'イワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡大台町桧原', '24', '24443', '5192632', '三重県', 'ミエケン', '多気郡大台町', 'タキグンオオダイチョウ', '桧原', 'キソハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡大台町久豆', '24', '24443', '5192633', '三重県', 'ミエケン', '多気郡大台町', 'タキグンオオダイチョウ', '久豆', 'クズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県多気郡大台町大杉', '24', '24443', '5192634', '三重県', 'ミエケン', '多気郡大台町', 'タキグンオオダイチョウ', '大杉', 'オオスギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡大紀町', '24', '24471', '5192700', '三重県', 'ミエケン', '度会郡大紀町', 'ワタライグンタイキチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('57150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡大紀町船木', '24', '24471', '5192701', '三重県', 'ミエケン', '度会郡大紀町', 'ワタライグンタイキチョウ', '船木', 'フナキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡大紀町三瀬川', '24', '24471', '5192702', '三重県', 'ミエケン', '度会郡大紀町', 'ワタライグンタイキチョウ', '三瀬川', 'ミセガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡大紀町滝原', '24', '24471', '5192703', '三重県', 'ミエケン', '度会郡大紀町', 'ワタライグンタイキチョウ', '滝原', 'タキハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡大紀町阿曽', '24', '24471', '5192704', '三重県', 'ミエケン', '度会郡大紀町', 'ワタライグンタイキチョウ', '阿曽', 'アソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡大紀町野原', '24', '24471', '5192731', '三重県', 'ミエケン', '度会郡大紀町', 'ワタライグンタイキチョウ', '野原', 'ノワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡大紀町野添', '24', '24471', '5192732', '三重県', 'ミエケン', '度会郡大紀町', 'ワタライグンタイキチョウ', '野添', 'ノゾエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡大紀町金輪', '24', '24471', '5192733', '三重県', 'ミエケン', '度会郡大紀町', 'ワタライグンタイキチョウ', '金輪', 'カナワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡大紀町永会', '24', '24471', '5192734', '三重県', 'ミエケン', '度会郡大紀町', 'ワタライグンタイキチョウ', '永会', 'エイカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡大紀町神原', '24', '24471', '5192735', '三重県', 'ミエケン', '度会郡大紀町', 'ワタライグンタイキチョウ', '神原', 'コノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡大紀町打見', '24', '24471', '5192736', '三重県', 'ミエケン', '度会郡大紀町', 'ワタライグンタイキチョウ', '打見', 'ウチミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡大紀町柏野', '24', '24471', '5192801', '三重県', 'ミエケン', '度会郡大紀町', 'ワタライグンタイキチョウ', '柏野', 'カシワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡大紀町崎', '24', '24471', '5192802', '三重県', 'ミエケン', '度会郡大紀町', 'ワタライグンタイキチョウ', '崎', 'サキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡大紀町錦', '24', '24471', '5192911', '三重県', 'ミエケン', '度会郡大紀町', 'ワタライグンタイキチョウ', '錦', 'ニシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県度会郡大紀町大内山', '24', '24471', '5193111', '三重県', 'ミエケン', '度会郡大紀町', 'ワタライグンタイキチョウ', '大内山', 'オオウチヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県北牟婁郡紀北町紀伊長島区十須', '24', '24543', '5193201', '三重県', 'ミエケン', '北牟婁郡紀北町', 'キタムログンキホクチョウ', '紀伊長島区十須', 'キイナガシマクジュウス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県北牟婁郡紀北町紀伊長島区大原', '24', '24543', '5193202', '三重県', 'ミエケン', '北牟婁郡紀北町', 'キタムログンキホクチョウ', '紀伊長島区大原', 'キイナガシマクオオハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県北牟婁郡紀北町紀伊長島区島原', '24', '24543', '5193203', '三重県', 'ミエケン', '北牟婁郡紀北町', 'キタムログンキホクチョウ', '紀伊長島区島原', 'キイナガシマクシマバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県北牟婁郡紀北町紀伊長島区東長島', '24', '24543', '5193204', '三重県', 'ミエケン', '北牟婁郡紀北町', 'キタムログンキホクチョウ', '紀伊長島区東長島', 'キイナガシマクヒガシナガシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県北牟婁郡紀北町紀伊長島区長島', '24', '24543', '5193205', '三重県', 'ミエケン', '北牟婁郡紀北町', 'キタムログンキホクチョウ', '紀伊長島区長島', 'キイナガシマクナガシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県北牟婁郡紀北町紀伊長島区海野', '24', '24543', '5193206', '三重県', 'ミエケン', '北牟婁郡紀北町', 'キタムログンキホクチョウ', '紀伊長島区海野', 'キイナガシマクカイノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県北牟婁郡紀北町紀伊長島区道瀬', '24', '24543', '5193207', '三重県', 'ミエケン', '北牟婁郡紀北町', 'キタムログンキホクチョウ', '紀伊長島区道瀬', 'キイナガシマクドウゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県北牟婁郡紀北町紀伊長島区三浦', '24', '24543', '5193208', '三重県', 'ミエケン', '北牟婁郡紀北町', 'キタムログンキホクチョウ', '紀伊長島区三浦', 'キイナガシマクミウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県北牟婁郡紀北町紀伊長島区古里', '24', '24543', '5193209', '三重県', 'ミエケン', '北牟婁郡紀北町', 'キタムログンキホクチョウ', '紀伊長島区古里', 'キイナガシマクフルサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県北牟婁郡紀北町', '24', '24543', '5193400', '三重県', 'ミエケン', '北牟婁郡紀北町', 'キタムログンキホクチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('57175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県北牟婁郡紀北町海山区馬瀬', '24', '24543', '5193401', '三重県', 'ミエケン', '北牟婁郡紀北町', 'キタムログンキホクチョウ', '海山区馬瀬', 'ミヤマクウマゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県北牟婁郡紀北町海山区河内', '24', '24543', '5193402', '三重県', 'ミエケン', '北牟婁郡紀北町', 'キタムログンキホクチョウ', '海山区河内', 'ミヤマクコウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県北牟婁郡紀北町海山区上里', '24', '24543', '5193403', '三重県', 'ミエケン', '北牟婁郡紀北町', 'キタムログンキホクチョウ', '海山区上里', 'ミヤマクカミザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県北牟婁郡紀北町海山区中里', '24', '24543', '5193404', '三重県', 'ミエケン', '北牟婁郡紀北町', 'キタムログンキホクチョウ', '海山区中里', 'ミヤマクナカザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県北牟婁郡紀北町海山区船津', '24', '24543', '5193405', '三重県', 'ミエケン', '北牟婁郡紀北町', 'キタムログンキホクチョウ', '海山区船津', 'ミヤマクフナツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県北牟婁郡紀北町海山区相賀', '24', '24543', '5193406', '三重県', 'ミエケン', '北牟婁郡紀北町', 'キタムログンキホクチョウ', '海山区相賀', 'ミヤマクアイガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県北牟婁郡紀北町海山区小山浦', '24', '24543', '5193407', '三重県', 'ミエケン', '北牟婁郡紀北町', 'キタムログンキホクチョウ', '海山区小山浦', 'ミヤマクオヤマウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県北牟婁郡紀北町海山区便ノ山', '24', '24543', '5193408', '三重県', 'ミエケン', '北牟婁郡紀北町', 'キタムログンキホクチョウ', '海山区便ノ山', 'ミヤマクビンノヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県北牟婁郡紀北町海山区白浦', '24', '24543', '5193411', '三重県', 'ミエケン', '北牟婁郡紀北町', 'キタムログンキホクチョウ', '海山区白浦', 'ミヤマクシロウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県北牟婁郡紀北町海山区島勝浦', '24', '24543', '5193412', '三重県', 'ミエケン', '北牟婁郡紀北町', 'キタムログンキホクチョウ', '海山区島勝浦', 'ミヤマクシマカツウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県北牟婁郡紀北町海山区引本浦', '24', '24543', '5193413', '三重県', 'ミエケン', '北牟婁郡紀北町', 'キタムログンキホクチョウ', '海山区引本浦', 'ミヤマクヒキモトウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県北牟婁郡紀北町海山区小浦', '24', '24543', '5193414', '三重県', 'ミエケン', '北牟婁郡紀北町', 'キタムログンキホクチョウ', '海山区小浦', 'ミヤマクオウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県北牟婁郡紀北町海山区矢口浦', '24', '24543', '5193415', '三重県', 'ミエケン', '北牟婁郡紀北町', 'キタムログンキホクチョウ', '海山区矢口浦', 'ミヤマクヤグチウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県尾鷲市須賀利町', '24', '24209', '5193421', '三重県', 'ミエケン', '尾鷲市', 'オワセシ', '須賀利町', 'スガリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県尾鷲市', '24', '24209', '5193600', '三重県', 'ミエケン', '尾鷲市', 'オワセシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('57191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県尾鷲市南浦天満', '24', '24209', '5193601', '三重県', 'ミエケン', '尾鷲市', 'オワセシ', '南浦', 'ミナミウラ', null, null, '天満', 'テンマ');
INSERT INTO `ms_addresses` VALUES ('57192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県尾鷲市天満浦', '24', '24209', '5193602', '三重県', 'ミエケン', '尾鷲市', 'オワセシ', '天満浦', 'テンマウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県尾鷲市港町', '24', '24209', '5193604', '三重県', 'ミエケン', '尾鷲市', 'オワセシ', '港町', 'ミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県尾鷲市中井町', '24', '24209', '5193605', '三重県', 'ミエケン', '尾鷲市', 'オワセシ', '中井町', 'ナカイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県尾鷲市北浦町', '24', '24209', '5193606', '三重県', 'ミエケン', '尾鷲市', 'オワセシ', '北浦町', 'キタウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県尾鷲市北浦東町', '24', '24209', '5193609', '三重県', 'ミエケン', '尾鷲市', 'オワセシ', '北浦東町', 'キタウラヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県尾鷲市北浦西町', '24', '24209', '5193610', '三重県', 'ミエケン', '尾鷲市', 'オワセシ', '北浦西町', 'キタウラニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県尾鷲市朝日町', '24', '24209', '5193611', '三重県', 'ミエケン', '尾鷲市', 'オワセシ', '朝日町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県尾鷲市林町', '24', '24209', '5193612', '三重県', 'ミエケン', '尾鷲市', 'オワセシ', '林町', 'ハヤシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県尾鷲市瀬木山町', '24', '24209', '5193613', '三重県', 'ミエケン', '尾鷲市', 'オワセシ', '瀬木山町', 'セギヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県尾鷲市南浦林', '24', '24209', '5193613', '三重県', 'ミエケン', '尾鷲市', 'オワセシ', '南浦', 'ミナミウラ', null, null, '林', 'ハヤシ');
INSERT INTO `ms_addresses` VALUES ('57202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県尾鷲市南陽町', '24', '24209', '5193614', '三重県', 'ミエケン', '尾鷲市', 'オワセシ', '南陽町', 'ナンヨウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県尾鷲市中央町', '24', '24209', '5193615', '三重県', 'ミエケン', '尾鷲市', 'オワセシ', '中央町', 'チュウオウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県尾鷲市中村町', '24', '24209', '5193616', '三重県', 'ミエケン', '尾鷲市', 'オワセシ', '中村町', 'ナカムラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県尾鷲市野地町', '24', '24209', '5193617', '三重県', 'ミエケン', '尾鷲市', 'オワセシ', '野地町', 'ノジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県尾鷲市栄町', '24', '24209', '5193618', '三重県', 'ミエケン', '尾鷲市', 'オワセシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県尾鷲市馬越町', '24', '24209', '5193619', '三重県', 'ミエケン', '尾鷲市', 'オワセシ', '馬越町', 'マゴセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県尾鷲市座ノ下町', '24', '24209', '5193620', '三重県', 'ミエケン', '尾鷲市', 'オワセシ', '座ノ下町', 'ザノシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県尾鷲市行野浦', '24', '24209', '5193621', '三重県', 'ミエケン', '尾鷲市', 'オワセシ', '行野浦', 'ユクノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県尾鷲市大曽根浦', '24', '24209', '5193623', '三重県', 'ミエケン', '尾鷲市', 'オワセシ', '大曽根浦', 'オオソネウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県尾鷲市向井', '24', '24209', '5193625', '三重県', 'ミエケン', '尾鷲市', 'オワセシ', '向井', 'ムカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県尾鷲市国市松泉町', '24', '24209', '5193626', '三重県', 'ミエケン', '尾鷲市', 'オワセシ', '国市松泉町', 'クニシショウセンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県尾鷲市南浦矢浜', '24', '24209', '5193634', '三重県', 'ミエケン', '尾鷲市', 'オワセシ', '南浦', 'ミナミウラ', null, null, '矢浜', 'ヤノハマ');
INSERT INTO `ms_addresses` VALUES ('57214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県尾鷲市光ケ丘', '24', '24209', '5193637', '三重県', 'ミエケン', '尾鷲市', 'オワセシ', '光ケ丘', 'ヒカリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県尾鷲市新田町', '24', '24209', '5193638', '三重県', 'ミエケン', '尾鷲市', 'オワセシ', '新田町', 'シンデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県尾鷲市中川', '24', '24209', '5193639', '三重県', 'ミエケン', '尾鷲市', 'オワセシ', '中川', 'ナカガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県尾鷲市桂ケ丘', '24', '24209', '5193640', '三重県', 'ミエケン', '尾鷲市', 'オワセシ', '桂ケ丘', 'カツラガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県尾鷲市大滝町', '24', '24209', '5193642', '三重県', 'ミエケン', '尾鷲市', 'オワセシ', '大滝町', 'オオタキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県尾鷲市南浦小原野', '24', '24209', '5193643', '三重県', 'ミエケン', '尾鷲市', 'オワセシ', '南浦', 'ミナミウラ', null, null, '小原野', 'オバラノ');
INSERT INTO `ms_addresses` VALUES ('57220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県尾鷲市泉町', '24', '24209', '5193646', '三重県', 'ミエケン', '尾鷲市', 'オワセシ', '泉町', 'イズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県尾鷲市小川西町', '24', '24209', '5193647', '三重県', 'ミエケン', '尾鷲市', 'オワセシ', '小川西町', 'コガワニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県尾鷲市小川東町', '24', '24209', '5193648', '三重県', 'ミエケン', '尾鷲市', 'オワセシ', '小川東町', 'コガワヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県尾鷲市末広町', '24', '24209', '5193651', '三重県', 'ミエケン', '尾鷲市', 'オワセシ', '末広町', 'スエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県尾鷲市古戸町', '24', '24209', '5193652', '三重県', 'ミエケン', '尾鷲市', 'オワセシ', '古戸町', 'コドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県尾鷲市上野町', '24', '24209', '5193653', '三重県', 'ミエケン', '尾鷲市', 'オワセシ', '上野町', 'ウエノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県尾鷲市南浦倉ノ谷', '24', '24209', '5193656', '三重県', 'ミエケン', '尾鷲市', 'オワセシ', '南浦', 'ミナミウラ', null, null, '倉ノ谷', 'クラノタニ');
INSERT INTO `ms_addresses` VALUES ('57227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県尾鷲市倉ノ谷町', '24', '24209', '5193658', '三重県', 'ミエケン', '尾鷲市', 'オワセシ', '倉ノ谷町', 'クラノタニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県尾鷲市古戸野町', '24', '24209', '5193659', '三重県', 'ミエケン', '尾鷲市', 'オワセシ', '古戸野町', 'コドノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県尾鷲市宮ノ上町', '24', '24209', '5193663', '三重県', 'ミエケン', '尾鷲市', 'オワセシ', '宮ノ上町', 'ミヤノウエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県尾鷲市坂場町', '24', '24209', '5193664', '三重県', 'ミエケン', '尾鷲市', 'オワセシ', '坂場町', 'サカバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県尾鷲市坂場西町', '24', '24209', '5193666', '三重県', 'ミエケン', '尾鷲市', 'オワセシ', '坂場西町', 'サカバニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県尾鷲市中井浦坂場', '24', '24209', '5193666', '三重県', 'ミエケン', '尾鷲市', 'オワセシ', '中井浦', 'ナカイウラ', null, null, '坂場', 'サカバ');
INSERT INTO `ms_addresses` VALUES ('57233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県尾鷲市南浦クチスボ', '24', '24209', '5193667', '三重県', 'ミエケン', '尾鷲市', 'オワセシ', '南浦', 'ミナミウラ', null, null, 'クチスボ', 'クチスボ');
INSERT INTO `ms_addresses` VALUES ('57234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県尾鷲市矢浜', '24', '24209', '5193671', '三重県', 'ミエケン', '尾鷲市', 'オワセシ', '矢浜', 'ヤノハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県尾鷲市矢浜岡崎町', '24', '24209', '5193672', '三重県', 'ミエケン', '尾鷲市', 'オワセシ', '矢浜岡崎町', 'ヤノハマオカザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県尾鷲市矢浜大道', '24', '24209', '5193673', '三重県', 'ミエケン', '尾鷲市', 'オワセシ', '矢浜大道', 'ヤノハマオオミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県尾鷲市矢浜真砂', '24', '24209', '5193674', '三重県', 'ミエケン', '尾鷲市', 'オワセシ', '矢浜真砂', 'ヤノハママサゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県尾鷲市九鬼町', '24', '24209', '5193701', '三重県', 'ミエケン', '尾鷲市', 'オワセシ', '九鬼町', 'クキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県尾鷲市早田町', '24', '24209', '5193702', '三重県', 'ミエケン', '尾鷲市', 'オワセシ', '早田町', 'ハイダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県尾鷲市三木里町', '24', '24209', '5193811', '三重県', 'ミエケン', '尾鷲市', 'オワセシ', '三木里町', 'ミキサトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県尾鷲市名柄町', '24', '24209', '5193812', '三重県', 'ミエケン', '尾鷲市', 'オワセシ', '名柄町', 'ナガラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県尾鷲市小脇町', '24', '24209', '5193813', '三重県', 'ミエケン', '尾鷲市', 'オワセシ', '小脇町', 'コワキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県尾鷲市三木浦町', '24', '24209', '5193814', '三重県', 'ミエケン', '尾鷲市', 'オワセシ', '三木浦町', 'ミキウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県尾鷲市賀田町', '24', '24209', '5193921', '三重県', 'ミエケン', '尾鷲市', 'オワセシ', '賀田町', 'カタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県尾鷲市古江町', '24', '24209', '5193922', '三重県', 'ミエケン', '尾鷲市', 'オワセシ', '古江町', 'フルエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県尾鷲市梶賀町', '24', '24209', '5193923', '三重県', 'ミエケン', '尾鷲市', 'オワセシ', '梶賀町', 'カジカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県尾鷲市曽根町', '24', '24209', '5193924', '三重県', 'ミエケン', '尾鷲市', 'オワセシ', '曽根町', 'ソネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県熊野市須野町', '24', '24212', '5194201', '三重県', 'ミエケン', '熊野市', 'クマノシ', '須野町', 'スノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県熊野市甫母町', '24', '24212', '5194202', '三重県', 'ミエケン', '熊野市', 'クマノシ', '甫母町', 'ホボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県熊野市二木島里町', '24', '24212', '5194203', '三重県', 'ミエケン', '熊野市', 'クマノシ', '二木島里町', 'ニギシマサトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県熊野市二木島町', '24', '24212', '5194204', '三重県', 'ミエケン', '熊野市', 'クマノシ', '二木島町', 'ニギシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県熊野市遊木町', '24', '24212', '5194205', '三重県', 'ミエケン', '熊野市', 'クマノシ', '遊木町', 'ユキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県熊野市新鹿町', '24', '24212', '5194206', '三重県', 'ミエケン', '熊野市', 'クマノシ', '新鹿町', 'アタシカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県熊野市波田須町', '24', '24212', '5194207', '三重県', 'ミエケン', '熊野市', 'クマノシ', '波田須町', 'ハダスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県熊野市', '24', '24212', '5194300', '三重県', 'ミエケン', '熊野市', 'クマノシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('57261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県熊野市磯崎町', '24', '24212', '5194321', '三重県', 'ミエケン', '熊野市', 'クマノシ', '磯崎町', 'イソザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県熊野市大泊町', '24', '24212', '5194322', '三重県', 'ミエケン', '熊野市', 'クマノシ', '大泊町', 'オオドマリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県熊野市木本町', '24', '24212', '5194323', '三重県', 'ミエケン', '熊野市', 'クマノシ', '木本町', 'キノモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県熊野市井戸町', '24', '24212', '5194324', '三重県', 'ミエケン', '熊野市', 'クマノシ', '井戸町', 'イドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県熊野市有馬町', '24', '24212', '5194325', '三重県', 'ミエケン', '熊野市', 'クマノシ', '有馬町', 'アリマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県熊野市久生屋町', '24', '24212', '5194326', '三重県', 'ミエケン', '熊野市', 'クマノシ', '久生屋町', 'クシヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県熊野市金山町', '24', '24212', '5194327', '三重県', 'ミエケン', '熊野市', 'クマノシ', '金山町', 'カナヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県熊野市神川町花知', '24', '24212', '5194441', '三重県', 'ミエケン', '熊野市', 'クマノシ', '神川町花知', 'カミカワチョウハナジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県熊野市神川町神上', '24', '24212', '5194442', '三重県', 'ミエケン', '熊野市', 'クマノシ', '神川町神上', 'カミカワチョウコウノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県熊野市神川町柳谷', '24', '24212', '5194443', '三重県', 'ミエケン', '熊野市', 'クマノシ', '神川町柳谷', 'カミカワチョウヤナギダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県熊野市神川町長原', '24', '24212', '5194444', '三重県', 'ミエケン', '熊野市', 'クマノシ', '神川町長原', 'カミカワチョウナガハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県熊野市育生町粉所', '24', '24212', '5194445', '三重県', 'ミエケン', '熊野市', 'クマノシ', '育生町粉所', 'イクセイチョウコドコロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県熊野市育生町赤倉', '24', '24212', '5194446', '三重県', 'ミエケン', '熊野市', 'クマノシ', '育生町赤倉', 'イクセイチョウアカグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県熊野市育生町尾川', '24', '24212', '5194447', '三重県', 'ミエケン', '熊野市', 'クマノシ', '育生町尾川', 'イクセイチョウオガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県熊野市育生町大井', '24', '24212', '5194448', '三重県', 'ミエケン', '熊野市', 'クマノシ', '育生町大井', 'イクセイチョウオオイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県熊野市育生町長井', '24', '24212', '5194449', '三重県', 'ミエケン', '熊野市', 'クマノシ', '育生町長井', 'イクセイチョウナガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県熊野市飛鳥町大又', '24', '24212', '5194561', '三重県', 'ミエケン', '熊野市', 'クマノシ', '飛鳥町大又', 'アスカチョウオオマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県熊野市飛鳥町小又', '24', '24212', '5194562', '三重県', 'ミエケン', '熊野市', 'クマノシ', '飛鳥町小又', 'アスカチョウコマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県熊野市飛鳥町小阪', '24', '24212', '5194563', '三重県', 'ミエケン', '熊野市', 'クマノシ', '飛鳥町小阪', 'アスカチョウコザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県熊野市飛鳥町佐渡', '24', '24212', '5194564', '三重県', 'ミエケン', '熊野市', 'クマノシ', '飛鳥町佐渡', 'アスカチョウサワタリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県熊野市飛鳥町野口', '24', '24212', '5194565', '三重県', 'ミエケン', '熊野市', 'クマノシ', '飛鳥町野口', 'アスカチョウノグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県熊野市飛鳥町神山', '24', '24212', '5194566', '三重県', 'ミエケン', '熊野市', 'クマノシ', '飛鳥町神山', 'アスカチョウコウノヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県熊野市五郷町桃崎', '24', '24212', '5194671', '三重県', 'ミエケン', '熊野市', 'クマノシ', '五郷町桃崎', 'イサトチョウモモザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県熊野市五郷町湯谷', '24', '24212', '5194672', '三重県', 'ミエケン', '熊野市', 'クマノシ', '五郷町湯谷', 'イサトチョウユノタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県熊野市五郷町寺谷', '24', '24212', '5194673', '三重県', 'ミエケン', '熊野市', 'クマノシ', '五郷町寺谷', 'イサトチョウテラダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県熊野市五郷町和田', '24', '24212', '5194674', '三重県', 'ミエケン', '熊野市', 'クマノシ', '五郷町和田', 'イサトチョウワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県熊野市五郷町大井谷', '24', '24212', '5194675', '三重県', 'ミエケン', '熊野市', 'クマノシ', '五郷町大井谷', 'イサトチョウオオイダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県南牟婁郡御浜町', '24', '24561', '5195200', '三重県', 'ミエケン', '南牟婁郡御浜町', 'ミナミムログンミハマチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('57294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県南牟婁郡御浜町神木', '24', '24561', '5195201', '三重県', 'ミエケン', '南牟婁郡御浜町', 'ミナミムログンミハマチョウ', '神木', 'コウノギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県南牟婁郡御浜町志原', '24', '24561', '5195202', '三重県', 'ミエケン', '南牟婁郡御浜町', 'ミナミムログンミハマチョウ', '志原', 'シワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県南牟婁郡御浜町下市木', '24', '24561', '5195203', '三重県', 'ミエケン', '南牟婁郡御浜町', 'ミナミムログンミハマチョウ', '下市木', 'シモイチギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県南牟婁郡御浜町萩内', '24', '24561', '5195203', '三重県', 'ミエケン', '南牟婁郡御浜町', 'ミナミムログンミハマチョウ', '萩内', 'ハギウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県南牟婁郡御浜町阿田和', '24', '24561', '5195204', '三重県', 'ミエケン', '南牟婁郡御浜町', 'ミナミムログンミハマチョウ', '阿田和', 'アタワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県南牟婁郡御浜町阿田和平見', '24', '24561', '5195204', '三重県', 'ミエケン', '南牟婁郡御浜町', 'ミナミムログンミハマチョウ', '阿田和', 'アタワ', null, null, '平見', 'ヒラミ');
INSERT INTO `ms_addresses` VALUES ('57300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県南牟婁郡御浜町山地', '24', '24561', '5195204', '三重県', 'ミエケン', '南牟婁郡御浜町', 'ミナミムログンミハマチョウ', '山地', 'ヤマヂ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県南牟婁郡御浜町引作', '24', '24561', '5195205', '三重県', 'ミエケン', '南牟婁郡御浜町', 'ミナミムログンミハマチョウ', '引作', 'ヒキツクリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県南牟婁郡御浜町柿原', '24', '24561', '5195206', '三重県', 'ミエケン', '南牟婁郡御浜町', 'ミナミムログンミハマチョウ', '柿原', 'カキハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県南牟婁郡御浜町上市木', '24', '24561', '5195211', '三重県', 'ミエケン', '南牟婁郡御浜町', 'ミナミムログンミハマチョウ', '上市木', 'カミイチギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県南牟婁郡御浜町阪本', '24', '24561', '5195321', '三重県', 'ミエケン', '南牟婁郡御浜町', 'ミナミムログンミハマチョウ', '阪本', 'サカモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県南牟婁郡御浜町上野', '24', '24561', '5195322', '三重県', 'ミエケン', '南牟婁郡御浜町', 'ミナミムログンミハマチョウ', '上野', 'ウワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県南牟婁郡御浜町西原', '24', '24561', '5195323', '三重県', 'ミエケン', '南牟婁郡御浜町', 'ミナミムログンミハマチョウ', '西原', 'ニシノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県南牟婁郡御浜町中立', '24', '24561', '5195324', '三重県', 'ミエケン', '南牟婁郡御浜町', 'ミナミムログンミハマチョウ', '中立', 'ナカダチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県南牟婁郡御浜町片川', '24', '24561', '5195325', '三重県', 'ミエケン', '南牟婁郡御浜町', 'ミナミムログンミハマチョウ', '片川', 'カタカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県南牟婁郡御浜町栗須', '24', '24561', '5195326', '三重県', 'ミエケン', '南牟婁郡御浜町', 'ミナミムログンミハマチョウ', '栗須', 'クルス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県南牟婁郡御浜町川瀬', '24', '24561', '5195327', '三重県', 'ミエケン', '南牟婁郡御浜町', 'ミナミムログンミハマチョウ', '川瀬', 'カワセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県熊野市紀和町小森', '24', '24212', '5195401', '三重県', 'ミエケン', '熊野市', 'クマノシ', '紀和町小森', 'キワチョウコモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県熊野市紀和町平谷', '24', '24212', '5195402', '三重県', 'ミエケン', '熊野市', 'クマノシ', '紀和町平谷', 'キワチョウヒラタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県熊野市紀和町長尾', '24', '24212', '5195403', '三重県', 'ミエケン', '熊野市', 'クマノシ', '紀和町長尾', 'キワチョウナガオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県熊野市紀和町赤木', '24', '24212', '5195404', '三重県', 'ミエケン', '熊野市', 'クマノシ', '紀和町赤木', 'キワチョウアカギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県熊野市紀和町丸山', '24', '24212', '5195405', '三重県', 'ミエケン', '熊野市', 'クマノシ', '紀和町丸山', 'キワチョウマルヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県熊野市紀和町矢ノ川', '24', '24212', '5195406', '三重県', 'ミエケン', '熊野市', 'クマノシ', '紀和町矢ノ川', 'キワチョウヤノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県熊野市紀和町木津呂', '24', '24212', '5195411', '三重県', 'ミエケン', '熊野市', 'クマノシ', '紀和町木津呂', 'キワチョウキヅロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県熊野市紀和町大栗須', '24', '24212', '5195412', '三重県', 'ミエケン', '熊野市', 'クマノシ', '紀和町大栗須', 'キワチョウオオグルス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県熊野市紀和町板屋', '24', '24212', '5195413', '三重県', 'ミエケン', '熊野市', 'クマノシ', '紀和町板屋', 'キワチョウイタヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県熊野市紀和町小栗須', '24', '24212', '5195414', '三重県', 'ミエケン', '熊野市', 'クマノシ', '紀和町小栗須', 'キワチョウコグルス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県熊野市紀和町大河内', '24', '24212', '5195415', '三重県', 'ミエケン', '熊野市', 'クマノシ', '紀和町大河内', 'キワチョウオコチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県熊野市紀和町湯ノ口', '24', '24212', '5195416', '三重県', 'ミエケン', '熊野市', 'クマノシ', '紀和町湯ノ口', 'キワチョウユノクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県熊野市紀和町小川口', '24', '24212', '5195417', '三重県', 'ミエケン', '熊野市', 'クマノシ', '紀和町小川口', 'キワチョウコガワグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県南牟婁郡紀宝町', '24', '24562', '5195700', '三重県', 'ミエケン', '南牟婁郡紀宝町', 'ミナミムログンキホウチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('57333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県南牟婁郡紀宝町鵜殿', '24', '24562', '5195701', '三重県', 'ミエケン', '南牟婁郡紀宝町', 'ミナミムログンキホウチョウ', '鵜殿', 'ウドノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県南牟婁郡紀宝町井田', '24', '24562', '5195711', '三重県', 'ミエケン', '南牟婁郡紀宝町', 'ミナミムログンキホウチョウ', '井田', 'イダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県南牟婁郡紀宝町神内', '24', '24562', '5195712', '三重県', 'ミエケン', '南牟婁郡紀宝町', 'ミナミムログンキホウチョウ', '神内', 'コウノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県南牟婁郡紀宝町成川', '24', '24562', '5195713', '三重県', 'ミエケン', '南牟婁郡紀宝町', 'ミナミムログンキホウチョウ', '成川', 'ナルカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県南牟婁郡紀宝町鮒田', '24', '24562', '5195714', '三重県', 'ミエケン', '南牟婁郡紀宝町', 'ミナミムログンキホウチョウ', '鮒田', 'フナダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県南牟婁郡紀宝町高岡', '24', '24562', '5195715', '三重県', 'ミエケン', '南牟婁郡紀宝町', 'ミナミムログンキホウチョウ', '高岡', 'タカオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県南牟婁郡紀宝町北桧杖', '24', '24562', '5195716', '三重県', 'ミエケン', '南牟婁郡紀宝町', 'ミナミムログンキホウチョウ', '北桧杖', 'キタヒヅエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県南牟婁郡紀宝町瀬原', '24', '24562', '5195717', '三重県', 'ミエケン', '南牟婁郡紀宝町', 'ミナミムログンキホウチョウ', '瀬原', 'セバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県南牟婁郡紀宝町浅里', '24', '24562', '5195718', '三重県', 'ミエケン', '南牟婁郡紀宝町', 'ミナミムログンキホウチョウ', '浅里', 'アサリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県南牟婁郡紀宝町桐原', '24', '24562', '5195831', '三重県', 'ミエケン', '南牟婁郡紀宝町', 'ミナミムログンキホウチョウ', '桐原', 'キリハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県南牟婁郡紀宝町阪松原', '24', '24562', '5195832', '三重県', 'ミエケン', '南牟婁郡紀宝町', 'ミナミムログンキホウチョウ', '阪松原', 'サカマツバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県南牟婁郡紀宝町平尾井', '24', '24562', '5195833', '三重県', 'ミエケン', '南牟婁郡紀宝町', 'ミナミムログンキホウチョウ', '平尾井', 'ヒラオイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県南牟婁郡紀宝町井内', '24', '24562', '5195834', '三重県', 'ミエケン', '南牟婁郡紀宝町', 'ミナミムログンキホウチョウ', '井内', 'イナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県南牟婁郡紀宝町大里', '24', '24562', '5195835', '三重県', 'ミエケン', '南牟婁郡紀宝町', 'ミナミムログンキホウチョウ', '大里', 'オオザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道伊達市', '01', '01233', '0520000', '北海道', 'ホッカイドウ', '伊達市', 'ダテシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('57348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市', '25', '25201', '5200000', '滋賀県', 'シガケン', '大津市', 'オオツシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('57349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市蓮池町', '25', '25201', '5200001', '滋賀県', 'シガケン', '大津市', 'オオツシ', '蓮池町', 'ハスイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市際川', '25', '25201', '5200002', '滋賀県', 'シガケン', '大津市', 'オオツシ', '際川', 'サイガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市あかね町', '25', '25201', '5200003', '滋賀県', 'シガケン', '大津市', 'オオツシ', 'あかね町', 'アカネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市見世', '25', '25201', '5200004', '滋賀県', 'シガケン', '大津市', 'オオツシ', '見世', 'ミセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市高砂町', '25', '25201', '5200005', '滋賀県', 'シガケン', '大津市', 'オオツシ', '高砂町', 'タカサゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市滋賀里', '25', '25201', '5200006', '滋賀県', 'シガケン', '大津市', 'オオツシ', '滋賀里', 'シガサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道伊達市喜門別町', '01', '01233', '0520001', '北海道', 'ホッカイドウ', '伊達市', 'ダテシ', '喜門別町', 'キモンベツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道伊達市志門気町', '01', '01233', '0520001', '北海道', 'ホッカイドウ', '伊達市', 'ダテシ', '志門気町', 'シモンケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市南志賀', '25', '25201', '5200011', '滋賀県', 'シガケン', '大津市', 'オオツシ', '南志賀', 'ミナミシガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市鏡が浜', '25', '25201', '5200012', '滋賀県', 'シガケン', '大津市', 'オオツシ', '鏡が浜', 'カガミガハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市勧学', '25', '25201', '5200013', '滋賀県', 'シガケン', '大津市', 'オオツシ', '勧学', 'カンガク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市柳川', '25', '25201', '5200014', '滋賀県', 'シガケン', '大津市', 'オオツシ', '柳川', 'ヤナガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市神宮町', '25', '25201', '5200015', '滋賀県', 'シガケン', '大津市', 'オオツシ', '神宮町', 'ジングウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市比叡平', '25', '25201', '5200016', '滋賀県', 'シガケン', '大津市', 'オオツシ', '比叡平', 'ヒエイダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市山中町', '25', '25201', '5200017', '滋賀県', 'シガケン', '大津市', 'オオツシ', '山中町', 'ヤマナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道伊達市乾町', '01', '01233', '0520002', '北海道', 'ホッカイドウ', '伊達市', 'ダテシ', '乾町', 'イヌイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市二本松', '25', '25201', '5200021', '滋賀県', 'シガケン', '大津市', 'オオツシ', '二本松', 'ニホンマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市柳が崎', '25', '25201', '5200022', '滋賀県', 'シガケン', '大津市', 'オオツシ', '柳が崎', 'ヤナガサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市茶が崎', '25', '25201', '5200023', '滋賀県', 'シガケン', '大津市', 'オオツシ', '茶が崎', 'チャガサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市松山町', '25', '25201', '5200024', '滋賀県', 'シガケン', '大津市', 'オオツシ', '松山町', 'マツヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市皇子が丘', '25', '25201', '5200025', '滋賀県', 'シガケン', '大津市', 'オオツシ', '皇子が丘', 'オウジガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市桜野町', '25', '25201', '5200026', '滋賀県', 'シガケン', '大津市', 'オオツシ', '桜野町', 'サクラノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市錦織', '25', '25201', '5200027', '滋賀県', 'シガケン', '大津市', 'オオツシ', '錦織', 'ニシコオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市千石台', '25', '25201', '5200028', '滋賀県', 'シガケン', '大津市', 'オオツシ', '千石台', 'センゴクダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道伊達市幌美内町', '01', '01233', '0520003', '北海道', 'ホッカイドウ', '伊達市', 'ダテシ', '幌美内町', 'ホロビナイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市尾花川', '25', '25201', '5200031', '滋賀県', 'シガケン', '大津市', 'オオツシ', '尾花川', 'オバナガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市観音寺', '25', '25201', '5200032', '滋賀県', 'シガケン', '大津市', 'オオツシ', '観音寺', 'カンノンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市大門通', '25', '25201', '5200033', '滋賀県', 'シガケン', '大津市', 'オオツシ', '大門通', 'ダイモンドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市三井寺町', '25', '25201', '5200034', '滋賀県', 'シガケン', '大津市', 'オオツシ', '三井寺町', 'ミイデラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市小関町', '25', '25201', '5200035', '滋賀県', 'シガケン', '大津市', 'オオツシ', '小関町', 'コゼキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市園城寺町', '25', '25201', '5200036', '滋賀県', 'シガケン', '大津市', 'オオツシ', '園城寺町', 'オンジョウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市御陵町', '25', '25201', '5200037', '滋賀県', 'シガケン', '大津市', 'オオツシ', '御陵町', 'ゴリョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市山上町', '25', '25201', '5200038', '滋賀県', 'シガケン', '大津市', 'オオツシ', '山上町', 'ヤマガミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道伊達市萩原町', '01', '01233', '0520004', '北海道', 'ホッカイドウ', '伊達市', 'ダテシ', '萩原町', 'ハギワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市浜町', '25', '25201', '5200041', '滋賀県', 'シガケン', '大津市', 'オオツシ', '浜町', 'ハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市島の関', '25', '25201', '5200042', '滋賀県', 'シガケン', '大津市', 'オオツシ', '島の関', 'シマノセキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市中央', '25', '25201', '5200043', '滋賀県', 'シガケン', '大津市', 'オオツシ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市京町', '25', '25201', '5200044', '滋賀県', 'シガケン', '大津市', 'オオツシ', '京町', 'キョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市札の辻', '25', '25201', '5200045', '滋賀県', 'シガケン', '大津市', 'オオツシ', '札の辻', 'フダノツジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市長等', '25', '25201', '5200046', '滋賀県', 'シガケン', '大津市', 'オオツシ', '長等', 'ナガラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市浜大津', '25', '25201', '5200047', '滋賀県', 'シガケン', '大津市', 'オオツシ', '浜大津', 'ハマオオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道伊達市清住町', '01', '01233', '0520005', '北海道', 'ホッカイドウ', '伊達市', 'ダテシ', '清住町', 'キヨズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市梅林', '25', '25201', '5200051', '滋賀県', 'シガケン', '大津市', 'オオツシ', '梅林', 'ウメバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市朝日が丘', '25', '25201', '5200052', '滋賀県', 'シガケン', '大津市', 'オオツシ', '朝日が丘', 'アサヒガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市音羽台', '25', '25201', '5200053', '滋賀県', 'シガケン', '大津市', 'オオツシ', '音羽台', 'オトワダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市逢坂', '25', '25201', '5200054', '滋賀県', 'シガケン', '大津市', 'オオツシ', '逢坂', 'オウサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市春日町', '25', '25201', '5200055', '滋賀県', 'シガケン', '大津市', 'オオツシ', '春日町', 'カスガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市末広町', '25', '25201', '5200056', '滋賀県', 'シガケン', '大津市', 'オオツシ', '末広町', 'スエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市御幸町', '25', '25201', '5200057', '滋賀県', 'シガケン', '大津市', 'オオツシ', '御幸町', 'ミユキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道伊達市東関内町', '01', '01233', '0520006', '北海道', 'ホッカイドウ', '伊達市', 'ダテシ', '東関内町', 'ヒガシセキナイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市神出開町', '25', '25201', '5200061', '滋賀県', 'シガケン', '大津市', 'オオツシ', '神出開町', 'カミデヒラキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市大谷町', '25', '25201', '5200062', '滋賀県', 'シガケン', '大津市', 'オオツシ', '大谷町', 'オオタニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市横木', '25', '25201', '5200063', '滋賀県', 'シガケン', '大津市', 'オオツシ', '横木', 'ヨコギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市追分町', '25', '25201', '5200064', '滋賀県', 'シガケン', '大津市', 'オオツシ', '追分町', 'オイワケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市稲葉台', '25', '25201', '5200065', '滋賀県', 'シガケン', '大津市', 'オオツシ', '稲葉台', 'イナバダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市茶戸町', '25', '25201', '5200066', '滋賀県', 'シガケン', '大津市', 'オオツシ', '茶戸町', 'チャドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市藤尾奥町', '25', '25201', '5200067', '滋賀県', 'シガケン', '大津市', 'オオツシ', '藤尾奥町', 'フジオオクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道伊達市西関内町', '01', '01233', '0520007', '北海道', 'ホッカイドウ', '伊達市', 'ダテシ', '西関内町', 'ニシセキナイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道伊達市上館山町', '01', '01233', '0520008', '北海道', 'ホッカイドウ', '伊達市', 'ダテシ', '上館山町', 'カミタテヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市雄琴', '25', '25201', '5200101', '滋賀県', 'シガケン', '大津市', 'オオツシ', '雄琴', 'オゴト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市苗鹿', '25', '25201', '5200102', '滋賀県', 'シガケン', '大津市', 'オオツシ', '苗鹿', 'ノウカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市木の岡町', '25', '25201', '5200103', '滋賀県', 'シガケン', '大津市', 'オオツシ', '木の岡町', 'コノオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市比叡辻', '25', '25201', '5200104', '滋賀県', 'シガケン', '大津市', 'オオツシ', '比叡辻', 'ヒエイツジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市下阪本', '25', '25201', '5200105', '滋賀県', 'シガケン', '大津市', 'オオツシ', '下阪本', 'シモサカモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市唐崎', '25', '25201', '5200106', '滋賀県', 'シガケン', '大津市', 'オオツシ', '唐崎', 'カラサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市雄琴北', '25', '25201', '5200107', '滋賀県', 'シガケン', '大津市', 'オオツシ', '雄琴北', 'オゴトキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道伊達市竹原町', '01', '01233', '0520011', '北海道', 'ホッカイドウ', '伊達市', 'ダテシ', '竹原町', 'タケハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市千野', '25', '25201', '5200111', '滋賀県', 'シガケン', '大津市', 'オオツシ', '千野', 'チノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市日吉台', '25', '25201', '5200112', '滋賀県', 'シガケン', '大津市', 'オオツシ', '日吉台', 'ヒヨシダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市坂本', '25', '25201', '5200113', '滋賀県', 'シガケン', '大津市', 'オオツシ', '坂本', 'サカモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市穴太', '25', '25201', '5200114', '滋賀県', 'シガケン', '大津市', 'オオツシ', '穴太', 'アノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市弥生町', '25', '25201', '5200115', '滋賀県', 'シガケン', '大津市', 'オオツシ', '弥生町', 'ヤヨイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市坂本本町', '25', '25201', '5200116', '滋賀県', 'シガケン', '大津市', 'オオツシ', '坂本本町', 'サカモトホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道伊達市松ケ枝町', '01', '01233', '0520012', '北海道', 'ホッカイドウ', '伊達市', 'ダテシ', '松ケ枝町', 'マツガエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道伊達市弄月町', '01', '01233', '0520013', '北海道', 'ホッカイドウ', '伊達市', 'ダテシ', '弄月町', 'ロウゲツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道伊達市舟岡町', '01', '01233', '0520014', '北海道', 'ホッカイドウ', '伊達市', 'ダテシ', '舟岡町', 'フナオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道伊達市旭町', '01', '01233', '0520015', '北海道', 'ホッカイドウ', '伊達市', 'ダテシ', '旭町', 'アサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道伊達市東浜町', '01', '01233', '0520016', '北海道', 'ホッカイドウ', '伊達市', 'ダテシ', '東浜町', 'ヒガシハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道伊達市末永町', '01', '01233', '0520021', '北海道', 'ホッカイドウ', '伊達市', 'ダテシ', '末永町', 'スエナガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道伊達市梅本町', '01', '01233', '0520022', '北海道', 'ホッカイドウ', '伊達市', 'ダテシ', '梅本町', 'ウメモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市緑町', '25', '25201', '5200221', '滋賀県', 'シガケン', '大津市', 'オオツシ', '緑町', 'ミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市花園町', '25', '25201', '5200222', '滋賀県', 'シガケン', '大津市', 'オオツシ', '花園町', 'ハナゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市美空町', '25', '25201', '5200223', '滋賀県', 'シガケン', '大津市', 'オオツシ', '美空町', 'ミソラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市向陽町', '25', '25201', '5200224', '滋賀県', 'シガケン', '大津市', 'オオツシ', '向陽町', 'コウヨウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市清風町', '25', '25201', '5200225', '滋賀県', 'シガケン', '大津市', 'オオツシ', '清風町', 'セイフウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市陽明町', '25', '25201', '5200226', '滋賀県', 'シガケン', '大津市', 'オオツシ', '陽明町', 'ヨウメイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市清和町', '25', '25201', '5200227', '滋賀県', 'シガケン', '大津市', 'オオツシ', '清和町', 'セイワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道伊達市元町', '01', '01233', '0520023', '北海道', 'ホッカイドウ', '伊達市', 'ダテシ', '元町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市真野普門', '25', '25201', '5200231', '滋賀県', 'シガケン', '大津市', 'オオツシ', '真野普門', 'マノフモン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市真野', '25', '25201', '5200232', '滋賀県', 'シガケン', '大津市', 'オオツシ', '真野', 'マノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市真野谷口町', '25', '25201', '5200233', '滋賀県', 'シガケン', '大津市', 'オオツシ', '真野谷口町', 'マノタニグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市真野家田町', '25', '25201', '5200234', '滋賀県', 'シガケン', '大津市', 'オオツシ', '真野家田町', 'マノイエダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市真野大野', '25', '25201', '5200235', '滋賀県', 'シガケン', '大津市', 'オオツシ', '真野大野', 'マノオオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市真野佐川町', '25', '25201', '5200236', '滋賀県', 'シガケン', '大津市', 'オオツシ', '真野佐川町', 'マノサガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道伊達市鹿島町', '01', '01233', '0520024', '北海道', 'ホッカイドウ', '伊達市', 'ダテシ', '鹿島町', 'カシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市今堅田', '25', '25201', '5200241', '滋賀県', 'シガケン', '大津市', 'オオツシ', '今堅田', 'イマカタタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市本堅田', '25', '25201', '5200242', '滋賀県', 'シガケン', '大津市', 'オオツシ', '本堅田', 'ホンカタタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市堅田', '25', '25201', '5200243', '滋賀県', 'シガケン', '大津市', 'オオツシ', '堅田', 'カタタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市衣川', '25', '25201', '5200244', '滋賀県', 'シガケン', '大津市', 'オオツシ', '衣川', 'キヌガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市仰木町', '25', '25201', '5200245', '滋賀県', 'シガケン', '大津市', 'オオツシ', '仰木町', 'オオギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市仰木の里', '25', '25201', '5200246', '滋賀県', 'シガケン', '大津市', 'オオツシ', '仰木の里', 'オオギノサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市仰木', '25', '25201', '5200247', '滋賀県', 'シガケン', '大津市', 'オオツシ', '仰木', 'オオギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市仰木の里東', '25', '25201', '5200248', '滋賀県', 'シガケン', '大津市', 'オオツシ', '仰木の里東', 'オオギノサトヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道伊達市網代町', '01', '01233', '0520025', '北海道', 'ホッカイドウ', '伊達市', 'ダテシ', '網代町', 'アジロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道伊達市錦町', '01', '01233', '0520026', '北海道', 'ホッカイドウ', '伊達市', 'ダテシ', '錦町', 'ニシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道伊達市大町', '01', '01233', '0520027', '北海道', 'ホッカイドウ', '伊達市', 'ダテシ', '大町', 'オオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道伊達市館山町', '01', '01233', '0520031', '北海道', 'ホッカイドウ', '伊達市', 'ダテシ', '館山町', 'タテヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道伊達市山下町', '01', '01233', '0520032', '北海道', 'ホッカイドウ', '伊達市', 'ダテシ', '山下町', 'ヤマシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道伊達市西浜町', '01', '01233', '0520033', '北海道', 'ホッカイドウ', '伊達市', 'ダテシ', '西浜町', 'ニシハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道伊達市館山下町', '01', '01233', '0520034', '北海道', 'ホッカイドウ', '伊達市', 'ダテシ', '館山下町', 'タテヤマシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道伊達市長和町', '01', '01233', '0520035', '北海道', 'ホッカイドウ', '伊達市', 'ダテシ', '長和町', 'ナガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市伊香立北在地町', '25', '25201', '5200351', '滋賀県', 'シガケン', '大津市', 'オオツシ', '伊香立北在地町', 'イカダチキタザイジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市伊香立下在地町', '25', '25201', '5200352', '滋賀県', 'シガケン', '大津市', 'オオツシ', '伊香立下在地町', 'イカダチシモザイジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市伊香立向在地町', '25', '25201', '5200353', '滋賀県', 'シガケン', '大津市', 'オオツシ', '伊香立向在地町', 'イカダチムカイザイジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市伊香立南庄町', '25', '25201', '5200354', '滋賀県', 'シガケン', '大津市', 'オオツシ', '伊香立南庄町', 'イカダチミナミショウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市伊香立生津町', '25', '25201', '5200355', '滋賀県', 'シガケン', '大津市', 'オオツシ', '伊香立生津町', 'イカダチナマヅチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市伊香立上在地町', '25', '25201', '5200356', '滋賀県', 'シガケン', '大津市', 'オオツシ', '伊香立上在地町', 'イカダチカミザイジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道伊達市上長和町', '01', '01233', '0520036', '北海道', 'ホッカイドウ', '伊達市', 'ダテシ', '上長和町', 'カミナガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市伊香立途中町', '25', '25201', '5200361', '滋賀県', 'シガケン', '大津市', 'オオツシ', '伊香立途中町', 'イカダチトチュウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市伊香立上龍華町', '25', '25201', '5200362', '滋賀県', 'シガケン', '大津市', 'オオツシ', '伊香立上龍華町', 'イカダチカミリュウゲチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市伊香立下龍華町', '25', '25201', '5200363', '滋賀県', 'シガケン', '大津市', 'オオツシ', '伊香立下龍華町', 'イカダチシモリュウゲチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区久多川合町', '26', '26103', '5200461', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '久多川合町', 'クタカワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区久多下の町', '26', '26103', '5200462', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '久多下の町', 'クタシモノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区久多宮の町', '26', '26103', '5200463', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '久多宮の町', 'クタミヤノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区久多中の町', '26', '26103', '5200464', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '久多中の町', 'クタナカノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区久多上の町', '26', '26103', '5200465', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '久多上の町', 'クタカミノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市葛川細川町', '25', '25201', '5200471', '滋賀県', 'シガケン', '大津市', 'オオツシ', '葛川細川町', 'カツラガワホソカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市葛川貫井町', '25', '25201', '5200472', '滋賀県', 'シガケン', '大津市', 'オオツシ', '葛川貫井町', 'カツラガワヌクイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市葛川梅ノ木町', '25', '25201', '5200473', '滋賀県', 'シガケン', '大津市', 'オオツシ', '葛川梅ノ木町', 'カツラガワウメノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市葛川町居町', '25', '25201', '5200474', '滋賀県', 'シガケン', '大津市', 'オオツシ', '葛川町居町', 'カツラガワマチイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市葛川坊村町', '25', '25201', '5200475', '滋賀県', 'シガケン', '大津市', 'オオツシ', '葛川坊村町', 'カツラガワボウムラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市葛川中村町', '25', '25201', '5200476', '滋賀県', 'シガケン', '大津市', 'オオツシ', '葛川中村町', 'カツラガワナカムラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市葛川木戸口町', '25', '25201', '5200477', '滋賀県', 'シガケン', '大津市', 'オオツシ', '葛川木戸口町', 'カツラガワキドグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市葛川坂下町', '25', '25201', '5200478', '滋賀県', 'シガケン', '大津市', 'オオツシ', '葛川坂下町', 'カツラガワサカシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市北小松', '25', '25201', '5200501', '滋賀県', 'シガケン', '大津市', 'オオツシ', '北小松', 'キタコマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市南小松', '25', '25201', '5200502', '滋賀県', 'シガケン', '大津市', 'オオツシ', '南小松', 'ミナミコマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市北比良', '25', '25201', '5200503', '滋賀県', 'シガケン', '大津市', 'オオツシ', '北比良', 'キタヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市南比良', '25', '25201', '5200511', '滋賀県', 'シガケン', '大津市', 'オオツシ', '南比良', 'ミナミヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市大物', '25', '25201', '5200512', '滋賀県', 'シガケン', '大津市', 'オオツシ', '大物', 'ダイモツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市荒川', '25', '25201', '5200513', '滋賀県', 'シガケン', '大津市', 'オオツシ', '荒川', 'アラカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市木戸', '25', '25201', '5200514', '滋賀県', 'シガケン', '大津市', 'オオツシ', '木戸', 'キド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市八屋戸', '25', '25201', '5200515', '滋賀県', 'シガケン', '大津市', 'オオツシ', '八屋戸', 'ハチヤド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市南船路', '25', '25201', '5200516', '滋賀県', 'シガケン', '大津市', 'オオツシ', '南船路', 'ミナミフナジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市和邇北浜', '25', '25201', '5200521', '滋賀県', 'シガケン', '大津市', 'オオツシ', '和邇北浜', 'ワニキタハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市和邇中浜', '25', '25201', '5200522', '滋賀県', 'シガケン', '大津市', 'オオツシ', '和邇中浜', 'ワニナカハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市和邇南浜', '25', '25201', '5200523', '滋賀県', 'シガケン', '大津市', 'オオツシ', '和邇南浜', 'ワニミナミハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市和邇今宿', '25', '25201', '5200524', '滋賀県', 'シガケン', '大津市', 'オオツシ', '和邇今宿', 'ワニイマジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市小野', '25', '25201', '5200525', '滋賀県', 'シガケン', '大津市', 'オオツシ', '小野', 'オノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市和邇中', '25', '25201', '5200526', '滋賀県', 'シガケン', '大津市', 'オオツシ', '和邇中', 'ワニナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市栗原', '25', '25201', '5200527', '滋賀県', 'シガケン', '大津市', 'オオツシ', '栗原', 'クリハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市和邇高城', '25', '25201', '5200528', '滋賀県', 'シガケン', '大津市', 'オオツシ', '和邇高城', 'ワニタカシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市和邇春日', '25', '25201', '5200529', '滋賀県', 'シガケン', '大津市', 'オオツシ', '和邇春日', 'ワニカスガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市水明', '25', '25201', '5200531', '滋賀県', 'シガケン', '大津市', 'オオツシ', '水明', 'スイメイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市湖青', '25', '25201', '5200532', '滋賀県', 'シガケン', '大津市', 'オオツシ', '湖青', 'コセイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市朝日', '25', '25201', '5200533', '滋賀県', 'シガケン', '大津市', 'オオツシ', '朝日', 'アサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市におの浜', '25', '25201', '5200801', '滋賀県', 'シガケン', '大津市', 'オオツシ', 'におの浜', 'ニオノハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市馬場', '25', '25201', '5200802', '滋賀県', 'シガケン', '大津市', 'オオツシ', '馬場', 'バンバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市竜が丘', '25', '25201', '5200803', '滋賀県', 'シガケン', '大津市', 'オオツシ', '竜が丘', 'タツガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市本宮', '25', '25201', '5200804', '滋賀県', 'シガケン', '大津市', 'オオツシ', '本宮', 'モトミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市石場', '25', '25201', '5200805', '滋賀県', 'シガケン', '大津市', 'オオツシ', '石場', 'イシバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市打出浜', '25', '25201', '5200806', '滋賀県', 'シガケン', '大津市', 'オオツシ', '打出浜', 'ウチデハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市松本', '25', '25201', '5200807', '滋賀県', 'シガケン', '大津市', 'オオツシ', '松本', 'マツモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市由美浜', '25', '25201', '5200811', '滋賀県', 'シガケン', '大津市', 'オオツシ', '由美浜', 'ユミハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市木下町', '25', '25201', '5200812', '滋賀県', 'シガケン', '大津市', 'オオツシ', '木下町', 'キノシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市丸の内町', '25', '25201', '5200813', '滋賀県', 'シガケン', '大津市', 'オオツシ', '丸の内町', 'マルノウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市本丸町', '25', '25201', '5200814', '滋賀県', 'シガケン', '大津市', 'オオツシ', '本丸町', 'ホンマルチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市膳所', '25', '25201', '5200815', '滋賀県', 'シガケン', '大津市', 'オオツシ', '膳所', 'ゼゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市相模町', '25', '25201', '5200816', '滋賀県', 'シガケン', '大津市', 'オオツシ', '相模町', 'サガミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市昭和町', '25', '25201', '5200817', '滋賀県', 'シガケン', '大津市', 'オオツシ', '昭和町', 'ショウワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市西の庄', '25', '25201', '5200818', '滋賀県', 'シガケン', '大津市', 'オオツシ', '西の庄', 'ニシノショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市湖城が丘', '25', '25201', '5200821', '滋賀県', 'シガケン', '大津市', 'オオツシ', '湖城が丘', 'コジョウガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市秋葉台', '25', '25201', '5200822', '滋賀県', 'シガケン', '大津市', 'オオツシ', '秋葉台', 'アキバダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市膳所上別保町', '25', '25201', '5200823', '滋賀県', 'シガケン', '大津市', 'オオツシ', '膳所上別保町', 'ゼゼカミベッポチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市膳所平尾町', '25', '25201', '5200824', '滋賀県', 'シガケン', '大津市', 'オオツシ', '膳所平尾町', 'ゼゼヒラオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市膳所池ノ内町', '25', '25201', '5200825', '滋賀県', 'シガケン', '大津市', 'オオツシ', '膳所池ノ内町', 'ゼゼイケノウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市鶴の里', '25', '25201', '5200826', '滋賀県', 'シガケン', '大津市', 'オオツシ', '鶴の里', 'ツルノサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市池の里', '25', '25201', '5200827', '滋賀県', 'シガケン', '大津市', 'オオツシ', '池の里', 'イケノサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市松原町', '25', '25201', '5200831', '滋賀県', 'シガケン', '大津市', 'オオツシ', '松原町', 'マツバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市粟津町', '25', '25201', '5200832', '滋賀県', 'シガケン', '大津市', 'オオツシ', '粟津町', 'アワヅチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市晴嵐', '25', '25201', '5200833', '滋賀県', 'シガケン', '大津市', 'オオツシ', '晴嵐', 'セイラン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市御殿浜', '25', '25201', '5200834', '滋賀県', 'シガケン', '大津市', 'オオツシ', '御殿浜', 'ゴテンハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市別保', '25', '25201', '5200835', '滋賀県', 'シガケン', '大津市', 'オオツシ', '別保', 'ベツポ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市杉浦町', '25', '25201', '5200836', '滋賀県', 'シガケン', '大津市', 'オオツシ', '杉浦町', 'スギウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市中庄', '25', '25201', '5200837', '滋賀県', 'シガケン', '大津市', 'オオツシ', '中庄', 'ナカショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市美崎町', '25', '25201', '5200841', '滋賀県', 'シガケン', '大津市', 'オオツシ', '美崎町', 'ミサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市園山', '25', '25201', '5200842', '滋賀県', 'シガケン', '大津市', 'オオツシ', '園山', 'ソノヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市北大路', '25', '25201', '5200843', '滋賀県', 'シガケン', '大津市', 'オオツシ', '北大路', 'キタオオジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市国分', '25', '25201', '5200844', '滋賀県', 'シガケン', '大津市', 'オオツシ', '国分', 'コクブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市若葉台', '25', '25201', '5200845', '滋賀県', 'シガケン', '大津市', 'オオツシ', '若葉台', 'ワカバダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市富士見台', '25', '25201', '5200846', '滋賀県', 'シガケン', '大津市', 'オオツシ', '富士見台', 'フジミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市唐橋町', '25', '25201', '5200851', '滋賀県', 'シガケン', '大津市', 'オオツシ', '唐橋町', 'カラハシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市田辺町', '25', '25201', '5200852', '滋賀県', 'シガケン', '大津市', 'オオツシ', '田辺町', 'タナベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市螢谷', '25', '25201', '5200853', '滋賀県', 'シガケン', '大津市', 'オオツシ', '螢谷', 'ホタルダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市鳥居川町', '25', '25201', '5200854', '滋賀県', 'シガケン', '大津市', 'オオツシ', '鳥居川町', 'トリイガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市栄町', '25', '25201', '5200855', '滋賀県', 'シガケン', '大津市', 'オオツシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市光が丘町', '25', '25201', '5200856', '滋賀県', 'シガケン', '大津市', 'オオツシ', '光が丘町', 'ヒカリガオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市石山千町', '25', '25201', '5200860', '滋賀県', 'シガケン', '大津市', 'オオツシ', '石山千町', 'イシヤマセンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市石山寺', '25', '25201', '5200861', '滋賀県', 'シガケン', '大津市', 'オオツシ', '石山寺', 'イシヤマデラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市平津', '25', '25201', '5200862', '滋賀県', 'シガケン', '大津市', 'オオツシ', '平津', 'ヒラツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市千町', '25', '25201', '5200863', '滋賀県', 'シガケン', '大津市', 'オオツシ', '千町', 'センチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市赤尾町', '25', '25201', '5200864', '滋賀県', 'シガケン', '大津市', 'オオツシ', '赤尾町', 'アカオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市南郷', '25', '25201', '5200865', '滋賀県', 'シガケン', '大津市', 'オオツシ', '南郷', 'ナンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市石山寺辺町', '25', '25201', '5200866', '滋賀県', 'シガケン', '大津市', 'オオツシ', '石山寺辺町', 'イシヤマテラベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市大平', '25', '25201', '5200867', '滋賀県', 'シガケン', '大津市', 'オオツシ', '大平', 'オオヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市石山外畑町', '25', '25201', '5200868', '滋賀県', 'シガケン', '大津市', 'オオツシ', '石山外畑町', 'イシヤマソトハタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市石山内畑町', '25', '25201', '5200869', '滋賀県', 'シガケン', '大津市', 'オオツシ', '石山内畑町', 'イシヤマウチハタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道有珠郡壮瞥町', '01', '01575', '0520100', '北海道', 'ホッカイドウ', '有珠郡壮瞥町', 'ウスグンソウベツチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('57560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道有珠郡壮瞥町滝之町', '01', '01575', '0520101', '北海道', 'ホッカイドウ', '有珠郡壮瞥町', 'ウスグンソウベツチョウ', '滝之町', 'タキノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道有珠郡壮瞥町昭和新山', '01', '01575', '0520102', '北海道', 'ホッカイドウ', '有珠郡壮瞥町', 'ウスグンソウベツチョウ', '昭和新山', 'ショウワシンザン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道有珠郡壮瞥町壮瞥温泉', '01', '01575', '0520103', '北海道', 'ホッカイドウ', '有珠郡壮瞥町', 'ウスグンソウベツチョウ', '壮瞥温泉', 'ソウベツオンセン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道有珠郡壮瞥町東湖畔', '01', '01575', '0520104', '北海道', 'ホッカイドウ', '有珠郡壮瞥町', 'ウスグンソウベツチョウ', '東湖畔', 'ヒガシコハン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道有珠郡壮瞥町仲洞爺', '01', '01575', '0520105', '北海道', 'ホッカイドウ', '有珠郡壮瞥町', 'ウスグンソウベツチョウ', '仲洞爺', 'ナカトウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道有珠郡壮瞥町立香', '01', '01575', '0520106', '北海道', 'ホッカイドウ', '有珠郡壮瞥町', 'ウスグンソウベツチョウ', '立香', 'タツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道有珠郡壮瞥町洞爺湖温泉', '01', '01575', '0520107', '北海道', 'ホッカイドウ', '有珠郡壮瞥町', 'ウスグンソウベツチョウ', '洞爺湖温泉', 'トウヤコオンセン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市', '25', '25212', '5201100', '滋賀県', 'シガケン', '高島市', 'タカシマシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('57568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市武曽横山', '25', '25212', '5201101', '滋賀県', 'シガケン', '高島市', 'タカシマシ', '武曽横山', 'ムソヨコヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市野田', '25', '25212', '5201102', '滋賀県', 'シガケン', '高島市', 'タカシマシ', '野田', 'ノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市宮野', '25', '25212', '5201103', '滋賀県', 'シガケン', '高島市', 'タカシマシ', '宮野', 'ミヤノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道有珠郡壮瞥町上久保内', '01', '01575', '0520111', '北海道', 'ホッカイドウ', '有珠郡壮瞥町', 'ウスグンソウベツチョウ', '上久保内', 'カミクボナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市鴨', '25', '25212', '5201111', '滋賀県', 'シガケン', '高島市', 'タカシマシ', '鴨', 'カモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市永田', '25', '25212', '5201112', '滋賀県', 'シガケン', '高島市', 'タカシマシ', '永田', 'ナガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道有珠郡壮瞥町久保内', '01', '01575', '0520112', '北海道', 'ホッカイドウ', '有珠郡壮瞥町', 'ウスグンソウベツチョウ', '久保内', 'クボナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市勝野', '25', '25212', '5201121', '滋賀県', 'シガケン', '高島市', 'タカシマシ', '勝野', 'カツノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市鵜川', '25', '25212', '5201122', '滋賀県', 'シガケン', '高島市', 'タカシマシ', '鵜川', 'ウカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市城山台', '25', '25212', '5201123', '滋賀県', 'シガケン', '高島市', 'タカシマシ', '城山台', 'シロヤマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道有珠郡壮瞥町蟠渓', '01', '01575', '0520113', '北海道', 'ホッカイドウ', '有珠郡壮瞥町', 'ウスグンソウベツチョウ', '蟠渓', 'バンケイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市音羽', '25', '25212', '5201131', '滋賀県', 'シガケン', '高島市', 'タカシマシ', '音羽', 'オトワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市拝戸', '25', '25212', '5201132', '滋賀県', 'シガケン', '高島市', 'タカシマシ', '拝戸', 'ハイド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市鴨川平', '25', '25212', '5201133', '滋賀県', 'シガケン', '高島市', 'タカシマシ', '鴨川平', 'カモガワダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道有珠郡壮瞥町幸内', '01', '01575', '0520114', '北海道', 'ホッカイドウ', '有珠郡壮瞥町', 'ウスグンソウベツチョウ', '幸内', 'コウナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市高島', '25', '25212', '5201141', '滋賀県', 'シガケン', '高島市', 'タカシマシ', '高島', 'タカシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市鹿ケ瀬', '25', '25212', '5201142', '滋賀県', 'シガケン', '高島市', 'タカシマシ', '鹿ケ瀬', 'シシガセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市黒谷', '25', '25212', '5201143', '滋賀県', 'シガケン', '高島市', 'タカシマシ', '黒谷', 'クロダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市畑', '25', '25212', '5201144', '滋賀県', 'シガケン', '高島市', 'タカシマシ', '畑', 'ハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道有珠郡壮瞥町弁景', '01', '01575', '0520115', '北海道', 'ホッカイドウ', '有珠郡壮瞥町', 'ウスグンソウベツチョウ', '弁景', 'ベンケイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道有珠郡壮瞥町南久保内', '01', '01575', '0520116', '北海道', 'ホッカイドウ', '有珠郡壮瞥町', 'ウスグンソウベツチョウ', '南久保内', 'ミナミクボナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市安曇川町上古賀', '25', '25212', '5201201', '滋賀県', 'シガケン', '高島市', 'タカシマシ', '安曇川町上古賀', 'アドガワチョウカミコガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市安曇川町下古賀', '25', '25212', '5201202', '滋賀県', 'シガケン', '高島市', 'タカシマシ', '安曇川町下古賀', 'アドガワチョウシモコガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市安曇川町南古賀', '25', '25212', '5201203', '滋賀県', 'シガケン', '高島市', 'タカシマシ', '安曇川町南古賀', 'アドガワチョウミナミコガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市安曇川町中野', '25', '25212', '5201204', '滋賀県', 'シガケン', '高島市', 'タカシマシ', '安曇川町中野', 'アドガワチョウナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市安曇川町長尾', '25', '25212', '5201205', '滋賀県', 'シガケン', '高島市', 'タカシマシ', '安曇川町長尾', 'アドガワチョウナガオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市安曇川町常磐木', '25', '25212', '5201211', '滋賀県', 'シガケン', '高島市', 'タカシマシ', '安曇川町常磐木', 'アドガワチョウトキワギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市安曇川町西万木', '25', '25212', '5201212', '滋賀県', 'シガケン', '高島市', 'タカシマシ', '安曇川町西万木', 'アドガワチョウニシユルギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市安曇川町五番領', '25', '25212', '5201213', '滋賀県', 'シガケン', '高島市', 'タカシマシ', '安曇川町五番領', 'アドガワチョウゴバンリョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市安曇川町末広', '25', '25212', '5201214', '滋賀県', 'シガケン', '高島市', 'タカシマシ', '安曇川町末広', 'アドガワチョウスエヒロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市安曇川町三尾里', '25', '25212', '5201215', '滋賀県', 'シガケン', '高島市', 'タカシマシ', '安曇川町三尾里', 'アドガワチョウミオザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市安曇川町中央', '25', '25212', '5201216', '滋賀県', 'シガケン', '高島市', 'タカシマシ', '安曇川町中央', 'アドガワチョウチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市安曇川町田中', '25', '25212', '5201217', '滋賀県', 'シガケン', '高島市', 'タカシマシ', '安曇川町田中', 'アドガワチョウタナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市安曇川町青柳', '25', '25212', '5201221', '滋賀県', 'シガケン', '高島市', 'タカシマシ', '安曇川町青柳', 'アドガワチョウアオヤギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市安曇川町横江', '25', '25212', '5201222', '滋賀県', 'シガケン', '高島市', 'タカシマシ', '安曇川町横江', 'アドガワチョウヨコエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市安曇川町下小川', '25', '25212', '5201223', '滋賀県', 'シガケン', '高島市', 'タカシマシ', '安曇川町下小川', 'アドガワチョウシモオガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市安曇川町上小川', '25', '25212', '5201224', '滋賀県', 'シガケン', '高島市', 'タカシマシ', '安曇川町上小川', 'アドガワチョウカミオガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市安曇川町川島', '25', '25212', '5201231', '滋賀県', 'シガケン', '高島市', 'タカシマシ', '安曇川町川島', 'アドガワチョウカワシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市安曇川町北船木', '25', '25212', '5201232', '滋賀県', 'シガケン', '高島市', 'タカシマシ', '安曇川町北船木', 'アドガワチョウキタフナキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市安曇川町南船木', '25', '25212', '5201233', '滋賀県', 'シガケン', '高島市', 'タカシマシ', '安曇川町南船木', 'アドガワチョウミナミフナキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市安曇川町四津川', '25', '25212', '5201234', '滋賀県', 'シガケン', '高島市', 'タカシマシ', '安曇川町四津川', 'アドガワチョウヨツガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市安曇川町横江浜', '25', '25212', '5201235', '滋賀県', 'シガケン', '高島市', 'タカシマシ', '安曇川町横江浜', 'アドガワチョウヨコエハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市朽木市場', '25', '25212', '5201401', '滋賀県', 'シガケン', '高島市', 'タカシマシ', '朽木市場', 'クツキイチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市朽木荒川', '25', '25212', '5201411', '滋賀県', 'シガケン', '高島市', 'タカシマシ', '朽木荒川', 'クツキアラカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市朽木野尻', '25', '25212', '5201412', '滋賀県', 'シガケン', '高島市', 'タカシマシ', '朽木野尻', 'クツキノジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市朽木上野', '25', '25212', '5201413', '滋賀県', 'シガケン', '高島市', 'タカシマシ', '朽木上野', 'クツキウエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市朽木宮前坊', '25', '25212', '5201414', '滋賀県', 'シガケン', '高島市', 'タカシマシ', '朽木宮前坊', 'クツキミヤマエボウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市朽木柏', '25', '25212', '5201415', '滋賀県', 'シガケン', '高島市', 'タカシマシ', '朽木柏', 'クツキカセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市朽木岩瀬', '25', '25212', '5201421', '滋賀県', 'シガケン', '高島市', 'タカシマシ', '朽木岩瀬', 'クツキイワセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市朽木古川', '25', '25212', '5201422', '滋賀県', 'シガケン', '高島市', 'タカシマシ', '朽木古川', 'クツキフルカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市朽木大野', '25', '25212', '5201423', '滋賀県', 'シガケン', '高島市', 'タカシマシ', '朽木大野', 'クツキオオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市朽木村井', '25', '25212', '5201424', '滋賀県', 'シガケン', '高島市', 'タカシマシ', '朽木村井', 'クツキムライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市朽木栃生', '25', '25212', '5201425', '滋賀県', 'シガケン', '高島市', 'タカシマシ', '朽木栃生', 'クツキトチュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市朽木小川', '25', '25212', '5201431', '滋賀県', 'シガケン', '高島市', 'タカシマシ', '朽木小川', 'クツキコガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市朽木平良', '25', '25212', '5201432', '滋賀県', 'シガケン', '高島市', 'タカシマシ', '朽木平良', 'クツキヘラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市朽木桑原', '25', '25212', '5201433', '滋賀県', 'シガケン', '高島市', 'タカシマシ', '朽木桑原', 'クツキクワバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市朽木古屋', '25', '25212', '5201441', '滋賀県', 'シガケン', '高島市', 'タカシマシ', '朽木古屋', 'クツキフルヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市朽木生杉', '25', '25212', '5201442', '滋賀県', 'シガケン', '高島市', 'タカシマシ', '朽木生杉', 'クツキオイスギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市朽木小入谷', '25', '25212', '5201443', '滋賀県', 'シガケン', '高島市', 'タカシマシ', '朽木小入谷', 'クツキオニュウダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市朽木中牧', '25', '25212', '5201444', '滋賀県', 'シガケン', '高島市', 'タカシマシ', '朽木中牧', 'クツキナカマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市朽木麻生', '25', '25212', '5201451', '滋賀県', 'シガケン', '高島市', 'タカシマシ', '朽木麻生', 'クツキアソウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市朽木地子原', '25', '25212', '5201452', '滋賀県', 'シガケン', '高島市', 'タカシマシ', '朽木地子原', 'クツキジシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市朽木雲洞谷', '25', '25212', '5201453', '滋賀県', 'シガケン', '高島市', 'タカシマシ', '朽木雲洞谷', 'クツキウトウダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市朽木能家', '25', '25212', '5201454', '滋賀県', 'シガケン', '高島市', 'タカシマシ', '朽木能家', 'クツキノウゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市朽木木地山', '25', '25212', '5201455', '滋賀県', 'シガケン', '高島市', 'タカシマシ', '朽木木地山', 'クツキキジヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市新旭町旭', '25', '25212', '5201501', '滋賀県', 'シガケン', '高島市', 'タカシマシ', '新旭町旭', 'シンアサヒチョウアサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市新旭町針江', '25', '25212', '5201502', '滋賀県', 'シガケン', '高島市', 'タカシマシ', '新旭町針江', 'シンアサヒチョウハリエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市新旭町深溝', '25', '25212', '5201503', '滋賀県', 'シガケン', '高島市', 'タカシマシ', '新旭町深溝', 'シンアサヒチョウフカミゾ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市新旭町藁園', '25', '25212', '5201511', '滋賀県', 'シガケン', '高島市', 'タカシマシ', '新旭町藁園', 'シンアサヒチョウワラソノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市新旭町太田', '25', '25212', '5201512', '滋賀県', 'シガケン', '高島市', 'タカシマシ', '新旭町太田', 'シンアサヒチョウオオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市新旭町北畑', '25', '25212', '5201521', '滋賀県', 'シガケン', '高島市', 'タカシマシ', '新旭町北畑', 'シンアサヒチョウキタバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市新旭町新庄', '25', '25212', '5201522', '滋賀県', 'シガケン', '高島市', 'タカシマシ', '新旭町新庄', 'シンアサヒチョウシンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市新旭町饗庭', '25', '25212', '5201531', '滋賀県', 'シガケン', '高島市', 'タカシマシ', '新旭町饗庭', 'シンアサヒチョウアイバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市新旭町熊野本', '25', '25212', '5201532', '滋賀県', 'シガケン', '高島市', 'タカシマシ', '新旭町熊野本', 'シンアサヒチョウクマノモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市新旭町安井川', '25', '25212', '5201533', '滋賀県', 'シガケン', '高島市', 'タカシマシ', '新旭町安井川', 'シンアサヒチョウヤスイガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市今津町深清水', '25', '25212', '5201601', '滋賀県', 'シガケン', '高島市', 'タカシマシ', '今津町深清水', 'イマヅチョウフカシミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市今津町桂', '25', '25212', '5201602', '滋賀県', 'シガケン', '高島市', 'タカシマシ', '今津町桂', 'イマヅチョウカツラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市今津町北仰', '25', '25212', '5201603', '滋賀県', 'シガケン', '高島市', 'タカシマシ', '今津町北仰', 'イマヅチョウキトゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市今津町浜分', '25', '25212', '5201604', '滋賀県', 'シガケン', '高島市', 'タカシマシ', '今津町浜分', 'イマヅチョウハマブン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市今津町南新保', '25', '25212', '5201605', '滋賀県', 'シガケン', '高島市', 'タカシマシ', '今津町南新保', 'イマヅチョウミナミシンボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市今津町弘川', '25', '25212', '5201611', '滋賀県', 'シガケン', '高島市', 'タカシマシ', '今津町弘川', 'イマヅチョウヒロカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市今津町下弘部', '25', '25212', '5201612', '滋賀県', 'シガケン', '高島市', 'タカシマシ', '今津町下弘部', 'イマヅチョウシモヒロベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市今津町上弘部', '25', '25212', '5201613', '滋賀県', 'シガケン', '高島市', 'タカシマシ', '今津町上弘部', 'イマヅチョウカミヒロベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市今津町藺生', '25', '25212', '5201614', '滋賀県', 'シガケン', '高島市', 'タカシマシ', '今津町藺生', 'イマヅチョウユウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市今津町今津', '25', '25212', '5201621', '滋賀県', 'シガケン', '高島市', 'タカシマシ', '今津町今津', 'イマヅチョウイマヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市今津町中沼', '25', '25212', '5201622', '滋賀県', 'シガケン', '高島市', 'タカシマシ', '今津町中沼', 'イマヅチョウナカヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市今津町住吉', '25', '25212', '5201623', '滋賀県', 'シガケン', '高島市', 'タカシマシ', '今津町住吉', 'イマヅチョウスミヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市今津町名小路', '25', '25212', '5201631', '滋賀県', 'シガケン', '高島市', 'タカシマシ', '今津町名小路', 'イマヅチョウナコジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市今津町桜町', '25', '25212', '5201632', '滋賀県', 'シガケン', '高島市', 'タカシマシ', '今津町桜町', 'イマヅチョウサクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市今津町松陽台', '25', '25212', '5201633', '滋賀県', 'シガケン', '高島市', 'タカシマシ', '今津町松陽台', 'イマヅチョウショウヨウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市今津町大供大門', '25', '25212', '5201634', '滋賀県', 'シガケン', '高島市', 'タカシマシ', '今津町大供大門', 'イマヅチョウオオトモダイモン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市今津町大供', '25', '25212', '5201635', '滋賀県', 'シガケン', '高島市', 'タカシマシ', '今津町大供', 'イマヅチョウオオトモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市今津町舟橋', '25', '25212', '5201636', '滋賀県', 'シガケン', '高島市', 'タカシマシ', '今津町舟橋', 'イマヅチョウフナバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市今津町南生見', '25', '25212', '5201641', '滋賀県', 'シガケン', '高島市', 'タカシマシ', '今津町南生見', 'イマヅチョウミナミウミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市今津町北生見', '25', '25212', '5201642', '滋賀県', 'シガケン', '高島市', 'タカシマシ', '今津町北生見', 'イマヅチョウキタウミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市今津町保坂', '25', '25212', '5201643', '滋賀県', 'シガケン', '高島市', 'タカシマシ', '今津町保坂', 'イマヅチョウホウザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市今津町途中谷', '25', '25212', '5201644', '滋賀県', 'シガケン', '高島市', 'タカシマシ', '今津町途中谷', 'イマヅチョウトチュウダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市今津町椋川', '25', '25212', '5201645', '滋賀県', 'シガケン', '高島市', 'タカシマシ', '今津町椋川', 'イマヅチョウムクガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市今津町杉山', '25', '25212', '5201646', '滋賀県', 'シガケン', '高島市', 'タカシマシ', '今津町杉山', 'イマヅチョウスギヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市今津町天増川', '25', '25212', '5201647', '滋賀県', 'シガケン', '高島市', 'タカシマシ', '今津町天増川', 'イマヅチョウアマスガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市今津町角川', '25', '25212', '5201648', '滋賀県', 'シガケン', '高島市', 'タカシマシ', '今津町角川', 'イマヅチョウツノガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市今津町酒波', '25', '25212', '5201651', '滋賀県', 'シガケン', '高島市', 'タカシマシ', '今津町酒波', 'イマヅチョウサナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市今津町福岡', '25', '25212', '5201652', '滋賀県', 'シガケン', '高島市', 'タカシマシ', '今津町福岡', 'イマヅチョウフクオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市今津町岸脇', '25', '25212', '5201653', '滋賀県', 'シガケン', '高島市', 'タカシマシ', '今津町岸脇', 'イマヅチョウキシワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市今津町梅原', '25', '25212', '5201654', '滋賀県', 'シガケン', '高島市', 'タカシマシ', '今津町梅原', 'イマヅチョウウメハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市今津町日置前', '25', '25212', '5201655', '滋賀県', 'シガケン', '高島市', 'タカシマシ', '今津町日置前', 'イマヅチョウヒオキマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市マキノ町在原', '25', '25212', '5201801', '滋賀県', 'シガケン', '高島市', 'タカシマシ', 'マキノ町在原', 'マキノチョウアリハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市マキノ町野口', '25', '25212', '5201802', '滋賀県', 'シガケン', '高島市', 'タカシマシ', 'マキノ町野口', 'マキノチョウノグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市マキノ町小荒路', '25', '25212', '5201803', '滋賀県', 'シガケン', '高島市', 'タカシマシ', 'マキノ町小荒路', 'マキノチョウコアラジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市マキノ町浦', '25', '25212', '5201804', '滋賀県', 'シガケン', '高島市', 'タカシマシ', 'マキノ町浦', 'マキノチョウウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市マキノ町下', '25', '25212', '5201805', '滋賀県', 'シガケン', '高島市', 'タカシマシ', 'マキノ町下', 'マキノチョウシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市マキノ町山中', '25', '25212', '5201806', '滋賀県', 'シガケン', '高島市', 'タカシマシ', 'マキノ町山中', 'マキノチョウヤマナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市マキノ町海津', '25', '25212', '5201811', '滋賀県', 'シガケン', '高島市', 'タカシマシ', 'マキノ町海津', 'マキノチョウカイヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市マキノ町西浜', '25', '25212', '5201812', '滋賀県', 'シガケン', '高島市', 'タカシマシ', 'マキノ町西浜', 'マキノチョウニシハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市マキノ町高木浜', '25', '25212', '5201813', '滋賀県', 'シガケン', '高島市', 'タカシマシ', 'マキノ町高木浜', 'マキノチョウタカギハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市マキノ町知内', '25', '25212', '5201814', '滋賀県', 'シガケン', '高島市', 'タカシマシ', 'マキノ町知内', 'マキノチョウチナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市マキノ町沢', '25', '25212', '5201821', '滋賀県', 'シガケン', '高島市', 'タカシマシ', 'マキノ町沢', 'マキノチョウサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市マキノ町新保', '25', '25212', '5201822', '滋賀県', 'シガケン', '高島市', 'タカシマシ', 'マキノ町新保', 'マキノチョウシンボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市マキノ町中庄', '25', '25212', '5201823', '滋賀県', 'シガケン', '高島市', 'タカシマシ', 'マキノ町中庄', 'マキノチョウナカショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市マキノ町大沼', '25', '25212', '5201824', '滋賀県', 'シガケン', '高島市', 'タカシマシ', 'マキノ町大沼', 'マキノチョウオオヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市マキノ町森西', '25', '25212', '5201825', '滋賀県', 'シガケン', '高島市', 'タカシマシ', 'マキノ町森西', 'マキノチョウモリニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市マキノ町辻', '25', '25212', '5201826', '滋賀県', 'シガケン', '高島市', 'タカシマシ', 'マキノ町辻', 'マキノチョウツジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市マキノ町上開田', '25', '25212', '5201831', '滋賀県', 'シガケン', '高島市', 'タカシマシ', 'マキノ町上開田', 'マキノチョウカミカイデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市マキノ町下開田', '25', '25212', '5201832', '滋賀県', 'シガケン', '高島市', 'タカシマシ', 'マキノ町下開田', 'マキノチョウシモカイデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市マキノ町蛭口', '25', '25212', '5201833', '滋賀県', 'シガケン', '高島市', 'タカシマシ', 'マキノ町蛭口', 'マキノチョウヒルグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市マキノ町寺久保', '25', '25212', '5201834', '滋賀県', 'シガケン', '高島市', 'タカシマシ', 'マキノ町寺久保', 'マキノチョウテラクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市マキノ町石庭', '25', '25212', '5201835', '滋賀県', 'シガケン', '高島市', 'タカシマシ', 'マキノ町石庭', 'マキノチョウイシバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市マキノ町牧野', '25', '25212', '5201836', '滋賀県', 'シガケン', '高島市', 'タカシマシ', 'マキノ町牧野', 'マキノチョウマキノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県高島市マキノ町白谷', '25', '25212', '5201837', '滋賀県', 'シガケン', '高島市', 'タカシマシ', 'マキノ町白谷', 'マキノチョウシラタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市青山', '25', '25201', '5202101', '滋賀県', 'シガケン', '大津市', 'オオツシ', '青山', 'アオヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市松が丘', '25', '25201', '5202102', '滋賀県', 'シガケン', '大津市', 'オオツシ', '松が丘', 'マツガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市桐生', '25', '25201', '5202111', '滋賀県', 'シガケン', '大津市', 'オオツシ', '桐生', 'キリュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市牧', '25', '25201', '5202112', '滋賀県', 'シガケン', '大津市', 'オオツシ', '牧', 'マキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市平野', '25', '25201', '5202113', '滋賀県', 'シガケン', '大津市', 'オオツシ', '平野', 'ヒラノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市中野', '25', '25201', '5202114', '滋賀県', 'シガケン', '大津市', 'オオツシ', '中野', 'ナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市新免', '25', '25201', '5202115', '滋賀県', 'シガケン', '大津市', 'オオツシ', '新免', 'シンメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市堂', '25', '25201', '5202116', '滋賀県', 'シガケン', '大津市', 'オオツシ', '堂', 'ドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市芝原', '25', '25201', '5202117', '滋賀県', 'シガケン', '大津市', 'オオツシ', '芝原', 'シバハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市大鳥居', '25', '25201', '5202118', '滋賀県', 'シガケン', '大津市', 'オオツシ', '大鳥居', 'オオドリイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市瀬田月輪町', '25', '25201', '5202121', '滋賀県', 'シガケン', '大津市', 'オオツシ', '瀬田月輪町', 'セタツキノワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市瀬田南大萱町', '25', '25201', '5202122', '滋賀県', 'シガケン', '大津市', 'オオツシ', '瀬田南大萱町', 'セタミナミオオガヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市瀬田大江町', '25', '25201', '5202123', '滋賀県', 'シガケン', '大津市', 'オオツシ', '瀬田大江町', 'セタオオエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市瀬田神領町', '25', '25201', '5202124', '滋賀県', 'シガケン', '大津市', 'オオツシ', '瀬田神領町', 'セタジンリョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市瀬田橋本町', '25', '25201', '5202125', '滋賀県', 'シガケン', '大津市', 'オオツシ', '瀬田橋本町', 'セタハシモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市三大寺', '25', '25201', '5202131', '滋賀県', 'シガケン', '大津市', 'オオツシ', '三大寺', 'サンダイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市神領', '25', '25201', '5202132', '滋賀県', 'シガケン', '大津市', 'オオツシ', '神領', 'ジンリョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市野郷原', '25', '25201', '5202133', '滋賀県', 'シガケン', '大津市', 'オオツシ', '野郷原', 'ノゴウハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市瀬田', '25', '25201', '5202134', '滋賀県', 'シガケン', '大津市', 'オオツシ', '瀬田', 'セタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市松陽', '25', '25201', '5202135', '滋賀県', 'シガケン', '大津市', 'オオツシ', '松陽', 'ショウヨウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市大江', '25', '25201', '5202141', '滋賀県', 'シガケン', '大津市', 'オオツシ', '大江', 'オオエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市玉野浦', '25', '25201', '5202142', '滋賀県', 'シガケン', '大津市', 'オオツシ', '玉野浦', 'タマノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市萱野浦', '25', '25201', '5202143', '滋賀県', 'シガケン', '大津市', 'オオツシ', '萱野浦', 'カヤノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市大萱', '25', '25201', '5202144', '滋賀県', 'シガケン', '大津市', 'オオツシ', '大萱', 'オオガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市大将軍', '25', '25201', '5202145', '滋賀県', 'シガケン', '大津市', 'オオツシ', '大将軍', 'ダイショウグン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市栗林町', '25', '25201', '5202151', '滋賀県', 'シガケン', '大津市', 'オオツシ', '栗林町', 'クリバヤシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市月輪', '25', '25201', '5202152', '滋賀県', 'シガケン', '大津市', 'オオツシ', '月輪', 'ツキノワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市一里山', '25', '25201', '5202153', '滋賀県', 'シガケン', '大津市', 'オオツシ', '一里山', 'イチリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市上田上桐生町', '25', '25201', '5202161', '滋賀県', 'シガケン', '大津市', 'オオツシ', '上田上桐生町', 'カミタナカミキリュウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市上田上牧町', '25', '25201', '5202162', '滋賀県', 'シガケン', '大津市', 'オオツシ', '上田上牧町', 'カミタナカミマキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市上田上平野町', '25', '25201', '5202163', '滋賀県', 'シガケン', '大津市', 'オオツシ', '上田上平野町', 'カミタナカミヒラノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市上田上中野町', '25', '25201', '5202164', '滋賀県', 'シガケン', '大津市', 'オオツシ', '上田上中野町', 'カミタナカミナカノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市上田上新免町', '25', '25201', '5202165', '滋賀県', 'シガケン', '大津市', 'オオツシ', '上田上新免町', 'カミタナカミシンメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市上田上堂町', '25', '25201', '5202166', '滋賀県', 'シガケン', '大津市', 'オオツシ', '上田上堂町', 'カミタナカミドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市上田上芝原町', '25', '25201', '5202167', '滋賀県', 'シガケン', '大津市', 'オオツシ', '上田上芝原町', 'カミタナカミシバハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市大石曾束', '25', '25201', '5202261', '滋賀県', 'シガケン', '大津市', 'オオツシ', '大石曾束', 'オオイシソツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市大石曾束町', '25', '25201', '5202261', '滋賀県', 'シガケン', '大津市', 'オオツシ', '大石曾束町', 'オオイシソツカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市大石淀', '25', '25201', '5202262', '滋賀県', 'シガケン', '大津市', 'オオツシ', '大石淀', 'オオイシヨド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市大石淀町', '25', '25201', '5202262', '滋賀県', 'シガケン', '大津市', 'オオツシ', '大石淀町', 'オオイシヨドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市大石中', '25', '25201', '5202263', '滋賀県', 'シガケン', '大津市', 'オオツシ', '大石中', 'オオイシナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市大石東', '25', '25201', '5202264', '滋賀県', 'シガケン', '大津市', 'オオツシ', '大石東', 'オオイシヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市大石富川', '25', '25201', '5202265', '滋賀県', 'シガケン', '大津市', 'オオツシ', '大石富川', 'オオイシトミカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市大石富川町', '25', '25201', '5202265', '滋賀県', 'シガケン', '大津市', 'オオツシ', '大石富川町', 'オオイシトミカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市大石龍門', '25', '25201', '5202266', '滋賀県', 'シガケン', '大津市', 'オオツシ', '大石龍門', 'オオイシリュウモン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市大石小田原', '25', '25201', '5202267', '滋賀県', 'シガケン', '大津市', 'オオツシ', '大石小田原', 'オオイシオダワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市大石小田原町', '25', '25201', '5202267', '滋賀県', 'シガケン', '大津市', 'オオツシ', '大石小田原町', 'オオイシオダワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市稲津', '25', '25201', '5202271', '滋賀県', 'シガケン', '大津市', 'オオツシ', '稲津', 'イナヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市石居', '25', '25201', '5202272', '滋賀県', 'シガケン', '大津市', 'オオツシ', '石居', 'イシズエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市羽栗', '25', '25201', '5202273', '滋賀県', 'シガケン', '大津市', 'オオツシ', '羽栗', 'ハグリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市森', '25', '25201', '5202274', '滋賀県', 'シガケン', '大津市', 'オオツシ', '森', 'モリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市枝', '25', '25201', '5202275', '滋賀県', 'シガケン', '大津市', 'オオツシ', '枝', 'エダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市里', '25', '25201', '5202276', '滋賀県', 'シガケン', '大津市', 'オオツシ', '里', 'サト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市関津', '25', '25201', '5202277', '滋賀県', 'シガケン', '大津市', 'オオツシ', '関津', 'セキノツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市太子', '25', '25201', '5202278', '滋賀県', 'シガケン', '大津市', 'オオツシ', '太子', 'タイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県大津市黒津', '25', '25201', '5202279', '滋賀県', 'シガケン', '大津市', 'オオツシ', '黒津', 'クロヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県野洲市', '25', '25210', '5202300', '滋賀県', 'シガケン', '野洲市', 'ヤスシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('57763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県野洲市小南', '25', '25210', '5202301', '滋賀県', 'シガケン', '野洲市', 'ヤスシ', '小南', 'コミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県野洲市高木', '25', '25210', '5202302', '滋賀県', 'シガケン', '野洲市', 'ヤスシ', '高木', 'タカギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県野洲市中北', '25', '25210', '5202303', '滋賀県', 'シガケン', '野洲市', 'ヤスシ', '中北', 'ナカキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県野洲市永原', '25', '25210', '5202304', '滋賀県', 'シガケン', '野洲市', 'ヤスシ', '永原', 'ナガハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県野洲市北', '25', '25210', '5202305', '滋賀県', 'シガケン', '野洲市', 'ヤスシ', '北', 'キタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県野洲市長島', '25', '25210', '5202311', '滋賀県', 'シガケン', '野洲市', 'ヤスシ', '長島', 'ナガシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県野洲市入町', '25', '25210', '5202312', '滋賀県', 'シガケン', '野洲市', 'ヤスシ', '入町', 'イリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県野洲市大篠原', '25', '25210', '5202313', '滋賀県', 'シガケン', '野洲市', 'ヤスシ', '大篠原', 'オオシノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県野洲市小堤', '25', '25210', '5202314', '滋賀県', 'シガケン', '野洲市', 'ヤスシ', '小堤', 'コヅツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県野洲市辻町', '25', '25210', '5202315', '滋賀県', 'シガケン', '野洲市', 'ヤスシ', '辻町', 'ツジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県野洲市上屋', '25', '25210', '5202316', '滋賀県', 'シガケン', '野洲市', 'ヤスシ', '上屋', 'カミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県野洲市北桜', '25', '25210', '5202321', '滋賀県', 'シガケン', '野洲市', 'ヤスシ', '北桜', 'キタザクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県野洲市南桜', '25', '25210', '5202322', '滋賀県', 'シガケン', '野洲市', 'ヤスシ', '南桜', 'ミナミザクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県野洲市三上', '25', '25210', '5202323', '滋賀県', 'シガケン', '野洲市', 'ヤスシ', '三上', 'ミカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県野洲市近江富士', '25', '25210', '5202324', '滋賀県', 'シガケン', '野洲市', 'ヤスシ', '近江富士', 'オウミフジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県野洲市小篠原', '25', '25210', '5202331', '滋賀県', 'シガケン', '野洲市', 'ヤスシ', '小篠原', 'コシノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県野洲市妙光寺', '25', '25210', '5202332', '滋賀県', 'シガケン', '野洲市', 'ヤスシ', '妙光寺', 'ミョウコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県野洲市栄', '25', '25210', '5202333', '滋賀県', 'シガケン', '野洲市', 'ヤスシ', '栄', 'サカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県野洲市行畑', '25', '25210', '5202341', '滋賀県', 'シガケン', '野洲市', 'ヤスシ', '行畑', 'ユキハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県野洲市野洲', '25', '25210', '5202342', '滋賀県', 'シガケン', '野洲市', 'ヤスシ', '野洲', 'ヤス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県野洲市大畑', '25', '25210', '5202343', '滋賀県', 'シガケン', '野洲市', 'ヤスシ', '大畑', 'オオハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県野洲市冨波甲', '25', '25210', '5202351', '滋賀県', 'シガケン', '野洲市', 'ヤスシ', '冨波甲', 'トバコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県野洲市冨波乙', '25', '25210', '5202352', '滋賀県', 'シガケン', '野洲市', 'ヤスシ', '冨波乙', 'トバオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県野洲市久野部', '25', '25210', '5202353', '滋賀県', 'シガケン', '野洲市', 'ヤスシ', '久野部', 'クノベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県野洲市北野', '25', '25210', '5202361', '滋賀県', 'シガケン', '野洲市', 'ヤスシ', '北野', 'キタノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県野洲市市三宅', '25', '25210', '5202362', '滋賀県', 'シガケン', '野洲市', 'ヤスシ', '市三宅', 'イチミヤケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県野洲市竹生', '25', '25210', '5202363', '滋賀県', 'シガケン', '野洲市', 'ヤスシ', '竹生', 'タケジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県野洲市五之里', '25', '25210', '5202364', '滋賀県', 'シガケン', '野洲市', 'ヤスシ', '五之里', 'ゴノリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県野洲市安治', '25', '25210', '5202411', '滋賀県', 'シガケン', '野洲市', 'ヤスシ', '安治', 'アワジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県野洲市六条', '25', '25210', '5202412', '滋賀県', 'シガケン', '野洲市', 'ヤスシ', '六条', 'ロクジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県野洲市吉地', '25', '25210', '5202413', '滋賀県', 'シガケン', '野洲市', 'ヤスシ', '吉地', 'ヨシジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県野洲市井口', '25', '25210', '5202414', '滋賀県', 'シガケン', '野洲市', 'ヤスシ', '井口', 'イノクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県野洲市須原', '25', '25210', '5202415', '滋賀県', 'シガケン', '野洲市', 'ヤスシ', '須原', 'スワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県野洲市堤', '25', '25210', '5202416', '滋賀県', 'シガケン', '野洲市', 'ヤスシ', '堤', 'ツツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県野洲市下堤', '25', '25210', '5202417', '滋賀県', 'シガケン', '野洲市', 'ヤスシ', '下堤', 'シモヅツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県野洲市野田', '25', '25210', '5202421', '滋賀県', 'シガケン', '野洲市', 'ヤスシ', '野田', 'ノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県野洲市比留田', '25', '25210', '5202422', '滋賀県', 'シガケン', '野洲市', 'ヤスシ', '比留田', 'ヒルタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県野洲市西河原', '25', '25210', '5202423', '滋賀県', 'シガケン', '野洲市', 'ヤスシ', '西河原', 'ニシガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県野洲市五条', '25', '25210', '5202424', '滋賀県', 'シガケン', '野洲市', 'ヤスシ', '五条', 'ゴジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県野洲市木部', '25', '25210', '5202431', '滋賀県', 'シガケン', '野洲市', 'ヤスシ', '木部', 'キベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県野洲市虫生', '25', '25210', '5202432', '滋賀県', 'シガケン', '野洲市', 'ヤスシ', '虫生', 'ムシュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県野洲市八夫', '25', '25210', '5202433', '滋賀県', 'シガケン', '野洲市', 'ヤスシ', '八夫', 'ヤブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県野洲市比江', '25', '25210', '5202434', '滋賀県', 'シガケン', '野洲市', 'ヤスシ', '比江', 'ヒエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県野洲市乙窪', '25', '25210', '5202435', '滋賀県', 'シガケン', '野洲市', 'ヤスシ', '乙窪', 'オチクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県野洲市北比江', '25', '25210', '5202436', '滋賀県', 'シガケン', '野洲市', 'ヤスシ', '北比江', 'キタヒエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県野洲市小比江', '25', '25210', '5202437', '滋賀県', 'シガケン', '野洲市', 'ヤスシ', '小比江', 'コビエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県蒲生郡竜王町', '25', '25384', '5202500', '滋賀県', 'シガケン', '蒲生郡竜王町', 'ガモウグンリュウオウチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('57815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県蒲生郡竜王町弓削', '25', '25384', '5202501', '滋賀県', 'シガケン', '蒲生郡竜王町', 'ガモウグンリュウオウチョウ', '弓削', 'ユゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県蒲生郡竜王町庄', '25', '25384', '5202502', '滋賀県', 'シガケン', '蒲生郡竜王町', 'ガモウグンリュウオウチョウ', '庄', 'ショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県蒲生郡竜王町信濃', '25', '25384', '5202503', '滋賀県', 'シガケン', '蒲生郡竜王町', 'ガモウグンリュウオウチョウ', '信濃', 'シナノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県蒲生郡竜王町川上', '25', '25384', '5202504', '滋賀県', 'シガケン', '蒲生郡竜王町', 'ガモウグンリュウオウチョウ', '川上', 'カワカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県蒲生郡竜王町林', '25', '25384', '5202511', '滋賀県', 'シガケン', '蒲生郡竜王町', 'ガモウグンリュウオウチョウ', '林', 'ハヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県蒲生郡竜王町駕輿丁', '25', '25384', '5202512', '滋賀県', 'シガケン', '蒲生郡竜王町', 'ガモウグンリュウオウチョウ', '駕輿丁', 'カヨチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県蒲生郡竜王町島', '25', '25384', '5202513', '滋賀県', 'シガケン', '蒲生郡竜王町', 'ガモウグンリュウオウチョウ', '島', 'シマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県蒲生郡竜王町橋本', '25', '25384', '5202514', '滋賀県', 'シガケン', '蒲生郡竜王町', 'ガモウグンリュウオウチョウ', '橋本', 'ハシモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県蒲生郡竜王町川守', '25', '25384', '5202521', '滋賀県', 'シガケン', '蒲生郡竜王町', 'ガモウグンリュウオウチョウ', '川守', 'カワモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県蒲生郡竜王町岩井', '25', '25384', '5202522', '滋賀県', 'シガケン', '蒲生郡竜王町', 'ガモウグンリュウオウチョウ', '岩井', 'イワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県蒲生郡竜王町田中', '25', '25384', '5202523', '滋賀県', 'シガケン', '蒲生郡竜王町', 'ガモウグンリュウオウチョウ', '田中', 'タナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県蒲生郡竜王町綾戸', '25', '25384', '5202524', '滋賀県', 'シガケン', '蒲生郡竜王町', 'ガモウグンリュウオウチョウ', '綾戸', 'アヤド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県蒲生郡竜王町山之上', '25', '25384', '5202531', '滋賀県', 'シガケン', '蒲生郡竜王町', 'ガモウグンリュウオウチョウ', '山之上', 'ヤマノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県蒲生郡竜王町岡屋', '25', '25384', '5202541', '滋賀県', 'シガケン', '蒲生郡竜王町', 'ガモウグンリュウオウチョウ', '岡屋', 'オカヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県蒲生郡竜王町山中', '25', '25384', '5202542', '滋賀県', 'シガケン', '蒲生郡竜王町', 'ガモウグンリュウオウチョウ', '山中', 'ヤマナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県蒲生郡竜王町薬師', '25', '25384', '5202551', '滋賀県', 'シガケン', '蒲生郡竜王町', 'ガモウグンリュウオウチョウ', '薬師', 'クズシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県蒲生郡竜王町小口', '25', '25384', '5202552', '滋賀県', 'シガケン', '蒲生郡竜王町', 'ガモウグンリュウオウチョウ', '小口', 'オグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県蒲生郡竜王町須恵', '25', '25384', '5202561', '滋賀県', 'シガケン', '蒲生郡竜王町', 'ガモウグンリュウオウチョウ', '須恵', 'スエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県蒲生郡竜王町鵜川', '25', '25384', '5202562', '滋賀県', 'シガケン', '蒲生郡竜王町', 'ガモウグンリュウオウチョウ', '鵜川', 'ウカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県蒲生郡竜王町七里', '25', '25384', '5202563', '滋賀県', 'シガケン', '蒲生郡竜王町', 'ガモウグンリュウオウチョウ', '七里', 'シチリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県蒲生郡竜王町山面', '25', '25384', '5202564', '滋賀県', 'シガケン', '蒲生郡竜王町', 'ガモウグンリュウオウチョウ', '山面', 'ヤマヅラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県蒲生郡竜王町西横関', '25', '25384', '5202571', '滋賀県', 'シガケン', '蒲生郡竜王町', 'ガモウグンリュウオウチョウ', '西横関', 'ニシヨコゼキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県蒲生郡竜王町西川', '25', '25384', '5202572', '滋賀県', 'シガケン', '蒲生郡竜王町', 'ガモウグンリュウオウチョウ', '西川', 'ニシガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県蒲生郡竜王町鏡', '25', '25384', '5202573', '滋賀県', 'シガケン', '蒲生郡竜王町', 'ガモウグンリュウオウチョウ', '鏡', 'カガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県栗東市', '25', '25208', '5203000', '滋賀県', 'シガケン', '栗東市', 'リットウシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('57844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県栗東市東坂', '25', '25208', '5203001', '滋賀県', 'シガケン', '栗東市', 'リットウシ', '東坂', 'ヒガシサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県栗東市観音寺', '25', '25208', '5203002', '滋賀県', 'シガケン', '栗東市', 'リットウシ', '観音寺', 'カンオンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県栗東市荒張', '25', '25208', '5203003', '滋賀県', 'シガケン', '栗東市', 'リットウシ', '荒張', 'アラハリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県栗東市上砥山', '25', '25208', '5203004', '滋賀県', 'シガケン', '栗東市', 'リットウシ', '上砥山', 'カミトヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県栗東市御園', '25', '25208', '5203005', '滋賀県', 'シガケン', '栗東市', 'リットウシ', '御園', 'ミソノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県栗東市井上', '25', '25208', '5203006', '滋賀県', 'シガケン', '栗東市', 'リットウシ', '井上', 'イノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道伊達市大滝区本町', '01', '01233', '0520301', '北海道', 'ホッカイドウ', '伊達市', 'ダテシ', '大滝区本町', 'オオタキクホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県栗東市下戸山', '25', '25208', '5203011', '滋賀県', 'シガケン', '栗東市', 'リットウシ', '下戸山', 'シモドヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県栗東市岡', '25', '25208', '5203012', '滋賀県', 'シガケン', '栗東市', 'リットウシ', '岡', 'オカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県栗東市目川', '25', '25208', '5203013', '滋賀県', 'シガケン', '栗東市', 'リットウシ', '目川', 'メガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県栗東市川辺', '25', '25208', '5203014', '滋賀県', 'シガケン', '栗東市', 'リットウシ', '川辺', 'カワヅラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県栗東市安養寺', '25', '25208', '5203015', '滋賀県', 'シガケン', '栗東市', 'リットウシ', '安養寺', 'アンヨウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県栗東市小野', '25', '25208', '5203016', '滋賀県', 'シガケン', '栗東市', 'リットウシ', '小野', 'オノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県栗東市六地蔵', '25', '25208', '5203017', '滋賀県', 'シガケン', '栗東市', 'リットウシ', '六地蔵', 'ロクジゾウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道伊達市大滝区清陵町', '01', '01233', '0520302', '北海道', 'ホッカイドウ', '伊達市', 'ダテシ', '大滝区清陵町', 'オオタキクセイリョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県栗東市蜂屋', '25', '25208', '5203021', '滋賀県', 'シガケン', '栗東市', 'リットウシ', '蜂屋', 'ハチヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県栗東市上鈎', '25', '25208', '5203022', '滋賀県', 'シガケン', '栗東市', 'リットウシ', '上鈎', 'カミマガリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県栗東市坊袋', '25', '25208', '5203023', '滋賀県', 'シガケン', '栗東市', 'リットウシ', '坊袋', 'ボウブクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県栗東市小柿', '25', '25208', '5203024', '滋賀県', 'シガケン', '栗東市', 'リットウシ', '小柿', 'オガキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県栗東市中沢', '25', '25208', '5203025', '滋賀県', 'シガケン', '栗東市', 'リットウシ', '中沢', 'ナカザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県栗東市下鈎', '25', '25208', '5203026', '滋賀県', 'シガケン', '栗東市', 'リットウシ', '下鈎', 'シモマガリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県栗東市野尻', '25', '25208', '5203027', '滋賀県', 'シガケン', '栗東市', 'リットウシ', '野尻', 'ノジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道伊達市大滝区三階滝町', '01', '01233', '0520303', '北海道', 'ホッカイドウ', '伊達市', 'ダテシ', '大滝区三階滝町', 'オオタキクサンガイタキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県栗東市綣', '25', '25208', '5203031', '滋賀県', 'シガケン', '栗東市', 'リットウシ', '綣', 'ヘソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県栗東市苅原', '25', '25208', '5203032', '滋賀県', 'シガケン', '栗東市', 'リットウシ', '苅原', 'カリハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県栗東市笠川', '25', '25208', '5203033', '滋賀県', 'シガケン', '栗東市', 'リットウシ', '笠川', 'カサガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県栗東市小平井', '25', '25208', '5203034', '滋賀県', 'シガケン', '栗東市', 'リットウシ', '小平井', 'コビライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県栗東市霊仙寺', '25', '25208', '5203035', '滋賀県', 'シガケン', '栗東市', 'リットウシ', '霊仙寺', 'リョウセンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県栗東市十里', '25', '25208', '5203036', '滋賀県', 'シガケン', '栗東市', 'リットウシ', '十里', 'ジュウリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県栗東市北中小路', '25', '25208', '5203037', '滋賀県', 'シガケン', '栗東市', 'リットウシ', '北中小路', 'キタナカコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県栗東市出庭', '25', '25208', '5203041', '滋賀県', 'シガケン', '栗東市', 'リットウシ', '出庭', 'デバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県栗東市辻', '25', '25208', '5203042', '滋賀県', 'シガケン', '栗東市', 'リットウシ', '辻', 'ツジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県栗東市林', '25', '25208', '5203043', '滋賀県', 'シガケン', '栗東市', 'リットウシ', '林', 'ハヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県栗東市伊勢落', '25', '25208', '5203044', '滋賀県', 'シガケン', '栗東市', 'リットウシ', '伊勢落', 'イセオチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県栗東市高野', '25', '25208', '5203045', '滋賀県', 'シガケン', '栗東市', 'リットウシ', '高野', 'タカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県栗東市大橋', '25', '25208', '5203046', '滋賀県', 'シガケン', '栗東市', 'リットウシ', '大橋', 'オオハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県栗東市手原', '25', '25208', '5203047', '滋賀県', 'シガケン', '栗東市', 'リットウシ', '手原', 'テハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県湖南市石部', '25', '25211', '5203101', '滋賀県', 'シガケン', '湖南市', 'コナンシ', '石部', 'イシベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県湖南市宮の森', '25', '25211', '5203102', '滋賀県', 'シガケン', '湖南市', 'コナンシ', '宮の森', 'ミヤノモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県湖南市宝来坂', '25', '25211', '5203103', '滋賀県', 'シガケン', '湖南市', 'コナンシ', '宝来坂', 'ホウライザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県湖南市岡出', '25', '25211', '5203104', '滋賀県', 'シガケン', '湖南市', 'コナンシ', '岡出', 'オカデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県湖南市石部西', '25', '25211', '5203105', '滋賀県', 'シガケン', '湖南市', 'コナンシ', '石部西', 'イシベニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県湖南市石部中央', '25', '25211', '5203106', '滋賀県', 'シガケン', '湖南市', 'コナンシ', '石部中央', 'イシベチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県湖南市石部東', '25', '25211', '5203107', '滋賀県', 'シガケン', '湖南市', 'コナンシ', '石部東', 'イシベヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県湖南市石部南', '25', '25211', '5203108', '滋賀県', 'シガケン', '湖南市', 'コナンシ', '石部南', 'イシベミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県湖南市石部が丘', '25', '25211', '5203109', '滋賀県', 'シガケン', '湖南市', 'コナンシ', '石部が丘', 'イシベガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道伊達市大滝区本郷町', '01', '01233', '0520311', '北海道', 'ホッカイドウ', '伊達市', 'ダテシ', '大滝区本郷町', 'オオタキクホンゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県湖南市東寺', '25', '25211', '5203111', '滋賀県', 'シガケン', '湖南市', 'コナンシ', '東寺', 'ヒガシテラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県湖南市丸山', '25', '25211', '5203112', '滋賀県', 'シガケン', '湖南市', 'コナンシ', '丸山', 'マルヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県湖南市石部北', '25', '25211', '5203113', '滋賀県', 'シガケン', '湖南市', 'コナンシ', '石部北', 'イシベキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県湖南市石部口', '25', '25211', '5203114', '滋賀県', 'シガケン', '湖南市', 'コナンシ', '石部口', 'イシベグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県湖南市石部緑台', '25', '25211', '5203115', '滋賀県', 'シガケン', '湖南市', 'コナンシ', '石部緑台', 'イシベミドリダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県湖南市雨山', '25', '25211', '5203116', '滋賀県', 'シガケン', '湖南市', 'コナンシ', '雨山', 'アメヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道伊達市大滝区上野町', '01', '01233', '0520312', '北海道', 'ホッカイドウ', '伊達市', 'ダテシ', '大滝区上野町', 'オオタキクウエノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県湖南市西寺', '25', '25211', '5203121', '滋賀県', 'シガケン', '湖南市', 'コナンシ', '西寺', 'ニシテラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道伊達市大滝区大成町', '01', '01233', '0520313', '北海道', 'ホッカイドウ', '伊達市', 'ダテシ', '大滝区大成町', 'オオタキクタイセイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道伊達市大滝区円山町', '01', '01233', '0520314', '北海道', 'ホッカイドウ', '伊達市', 'ダテシ', '大滝区円山町', 'オオタキクマルヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道伊達市大滝区昭園町', '01', '01233', '0520315', '北海道', 'ホッカイドウ', '伊達市', 'ダテシ', '大滝区昭園町', 'オオタキクショウエンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道伊達市大滝区北湯沢温泉町', '01', '01233', '0520316', '北海道', 'ホッカイドウ', '伊達市', 'ダテシ', '大滝区北湯沢温泉町', 'オオタキクキタユザワオンセンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道伊達市大滝区優徳町', '01', '01233', '0520317', '北海道', 'ホッカイドウ', '伊達市', 'ダテシ', '大滝区優徳町', 'オオタキクユウトクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県湖南市', '25', '25211', '5203200', '滋賀県', 'シガケン', '湖南市', 'コナンシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('57919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県湖南市下田', '25', '25211', '5203201', '滋賀県', 'シガケン', '湖南市', 'コナンシ', '下田', 'シモダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県湖南市西峰町', '25', '25211', '5203202', '滋賀県', 'シガケン', '湖南市', 'コナンシ', '西峰町', 'ニシミネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県湖南市日枝町', '25', '25211', '5203203', '滋賀県', 'シガケン', '湖南市', 'コナンシ', '日枝町', 'ヒエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県湖南市高松町', '25', '25211', '5203211', '滋賀県', 'シガケン', '湖南市', 'コナンシ', '高松町', 'タカマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県湖南市小砂町', '25', '25211', '5203212', '滋賀県', 'シガケン', '湖南市', 'コナンシ', '小砂町', 'コスナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県湖南市大池町', '25', '25211', '5203213', '滋賀県', 'シガケン', '湖南市', 'コナンシ', '大池町', 'オオイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県湖南市梅影町', '25', '25211', '5203214', '滋賀県', 'シガケン', '湖南市', 'コナンシ', '梅影町', 'ウメカゲチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県湖南市水戸町', '25', '25211', '5203215', '滋賀県', 'シガケン', '湖南市', 'コナンシ', '水戸町', 'ミトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県湖南市若竹町', '25', '25211', '5203216', '滋賀県', 'シガケン', '湖南市', 'コナンシ', '若竹町', 'ワカタケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県湖南市三雲', '25', '25211', '5203221', '滋賀県', 'シガケン', '湖南市', 'コナンシ', '三雲', 'ミクモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県湖南市吉永', '25', '25211', '5203222', '滋賀県', 'シガケン', '湖南市', 'コナンシ', '吉永', 'ヨシナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県湖南市夏見', '25', '25211', '5203223', '滋賀県', 'シガケン', '湖南市', 'コナンシ', '夏見', 'ナツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県湖南市針', '25', '25211', '5203231', '滋賀県', 'シガケン', '湖南市', 'コナンシ', '針', 'ハリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県湖南市平松', '25', '25211', '5203232', '滋賀県', 'シガケン', '湖南市', 'コナンシ', '平松', 'ヒラマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県湖南市柑子袋', '25', '25211', '5203233', '滋賀県', 'シガケン', '湖南市', 'コナンシ', '柑子袋', 'コウジブクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県湖南市中央', '25', '25211', '5203234', '滋賀県', 'シガケン', '湖南市', 'コナンシ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県湖南市平松北', '25', '25211', '5203235', '滋賀県', 'シガケン', '湖南市', 'コナンシ', '平松北', 'ヒラマツキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県湖南市北山台', '25', '25211', '5203241', '滋賀県', 'シガケン', '湖南市', 'コナンシ', '北山台', 'キタヤマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県湖南市菩提寺', '25', '25211', '5203242', '滋賀県', 'シガケン', '湖南市', 'コナンシ', '菩提寺', 'ボダイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県湖南市菩提寺新町', '25', '25211', '5203243', '滋賀県', 'シガケン', '湖南市', 'コナンシ', '菩提寺新町', 'ボダイジシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県湖南市サイドタウン', '25', '25211', '5203244', '滋賀県', 'シガケン', '湖南市', 'コナンシ', 'サイドタウン', 'サイドタウン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県湖南市近江台', '25', '25211', '5203245', '滋賀県', 'シガケン', '湖南市', 'コナンシ', '近江台', 'オウミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県湖南市朝国', '25', '25211', '5203251', '滋賀県', 'シガケン', '湖南市', 'コナンシ', '朝国', 'アサクニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県湖南市岩根', '25', '25211', '5203252', '滋賀県', 'シガケン', '湖南市', 'コナンシ', '岩根', 'イワネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県湖南市正福寺', '25', '25211', '5203253', '滋賀県', 'シガケン', '湖南市', 'コナンシ', '正福寺', 'ショウフクジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県湖南市岩根中央', '25', '25211', '5203254', '滋賀県', 'シガケン', '湖南市', 'コナンシ', '岩根中央', 'イワネチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市甲南町寺庄', '25', '25209', '5203301', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '甲南町寺庄', 'コウナンチョウテラショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市甲南町池田', '25', '25209', '5203302', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '甲南町池田', 'コウナンチョウイケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市甲南町上馬杉', '25', '25209', '5203303', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '甲南町上馬杉', 'コウナンチョウカミマスギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市甲南町下馬杉', '25', '25209', '5203304', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '甲南町下馬杉', 'コウナンチョウシモマスギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市甲南町野川', '25', '25209', '5203305', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '甲南町野川', 'コウナンチョウノガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市甲南町柑子', '25', '25209', '5203306', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '甲南町柑子', 'コウナンチョウコオジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市甲南町野尻', '25', '25209', '5203307', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '甲南町野尻', 'コウナンチョウノジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市甲南町野田', '25', '25209', '5203308', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '甲南町野田', 'コウナンチョウノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市甲南町竜法師', '25', '25209', '5203311', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '甲南町竜法師', 'コウナンチョウリュウボウシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市甲南町磯尾', '25', '25209', '5203312', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '甲南町磯尾', 'コウナンチョウイソオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市甲南町新治', '25', '25209', '5203313', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '甲南町新治', 'コウナンチョウシンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市甲南町杉谷', '25', '25209', '5203314', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '甲南町杉谷', 'コウナンチョウスギタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市甲南町塩野', '25', '25209', '5203315', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '甲南町塩野', 'コウナンチョウシオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市甲南町市原', '25', '25209', '5203316', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '甲南町市原', 'コウナンチョウイチハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市甲南町葛木', '25', '25209', '5203321', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '甲南町葛木', 'コウナンチョウカヅラキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市甲南町深川', '25', '25209', '5203322', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '甲南町深川', 'コウナンチョウフカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市甲南町深川市場', '25', '25209', '5203323', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '甲南町深川市場', 'コウナンチョウフカワイチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市甲南町森尻', '25', '25209', '5203324', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '甲南町森尻', 'コウナンチョウモリシリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市甲南町宝木', '25', '25209', '5203325', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '甲南町宝木', 'コウナンチョウホウノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市甲南町耕心', '25', '25209', '5203326', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '甲南町耕心', 'コウナンチョウコウシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市甲南町稗谷', '25', '25209', '5203331', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '甲南町稗谷', 'コウナンチョウヒエダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市甲南町希望ケ丘本町', '25', '25209', '5203332', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '甲南町希望ケ丘本町', 'コウナンチョウキボウガオカホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市甲南町希望ケ丘', '25', '25209', '5203333', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '甲南町希望ケ丘', 'コウナンチョウキボウガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市甲賀町岩室', '25', '25209', '5203401', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '甲賀町岩室', 'コウカチョウイワムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市甲賀町小佐治', '25', '25209', '5203402', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '甲賀町小佐治', 'コウカチョウコサジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市甲賀町鳥居野', '25', '25209', '5203403', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '甲賀町鳥居野', 'コウカチョウトリイノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市甲賀町神保', '25', '25209', '5203404', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '甲賀町神保', 'コウカチョウジンボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市甲賀町隠岐', '25', '25209', '5203405', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '甲賀町隠岐', 'コウカチョウオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市甲賀町神', '25', '25209', '5203411', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '甲賀町神', 'コウカチョウカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市甲賀町櫟野', '25', '25209', '5203412', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '甲賀町櫟野', 'コウカチョウイチノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市甲賀町油日', '25', '25209', '5203413', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '甲賀町油日', 'コウカチョウアブラヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市甲賀町大久保', '25', '25209', '5203414', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '甲賀町大久保', 'コウカチョウオオクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市甲賀町大原上田', '25', '25209', '5203415', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '甲賀町大原上田', 'コウカチョウオオハラウエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市甲賀町上野', '25', '25209', '5203421', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '甲賀町上野', 'コウカチョウウエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市甲賀町和田', '25', '25209', '5203422', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '甲賀町和田', 'コウカチョウワタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市甲賀町五反田', '25', '25209', '5203423', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '甲賀町五反田', 'コウカチョウゴタンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市甲賀町高嶺', '25', '25209', '5203424', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '甲賀町高嶺', 'コウカチョウタカミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市甲賀町毛枚', '25', '25209', '5203425', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '甲賀町毛枚', 'コウカチョウモビラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市甲賀町田堵野', '25', '25209', '5203426', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '甲賀町田堵野', 'コウカチョウタドノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市甲賀町鹿深台', '25', '25209', '5203427', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '甲賀町鹿深台', 'コウカチョウカフカダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市甲賀町大原中', '25', '25209', '5203431', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '甲賀町大原中', 'コウカチョウオオハラナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市甲賀町滝', '25', '25209', '5203432', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '甲賀町滝', 'コウカチョウタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市甲賀町大原市場', '25', '25209', '5203433', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '甲賀町大原市場', 'コウカチョウオオハライチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市甲賀町高野', '25', '25209', '5203434', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '甲賀町高野', 'コウカチョウタカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市甲賀町相模', '25', '25209', '5203435', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '甲賀町相模', 'コウカチョウサガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('57996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市甲賀町拝坂', '25', '25209', '5203436', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '甲賀町拝坂', 'コウカチョウハイサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県米原市', '25', '25214', '5210000', '滋賀県', 'シガケン', '米原市', 'マイバラシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('58021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県米原市朝妻筑摩', '25', '25214', '5210001', '滋賀県', 'シガケン', '米原市', 'マイバラシ', '朝妻筑摩', 'アサヅマチクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県米原市上多良', '25', '25214', '5210002', '滋賀県', 'シガケン', '米原市', 'マイバラシ', '上多良', 'カミタラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県米原市入江', '25', '25214', '5210003', '滋賀県', 'シガケン', '米原市', 'マイバラシ', '入江', 'イリエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県米原市磯', '25', '25214', '5210004', '滋賀県', 'シガケン', '米原市', 'マイバラシ', '磯', 'イソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県米原市中多良', '25', '25214', '5210011', '滋賀県', 'シガケン', '米原市', 'マイバラシ', '中多良', 'ナカタラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県米原市米原', '25', '25214', '5210012', '滋賀県', 'シガケン', '米原市', 'マイバラシ', '米原', 'マイハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県米原市梅ケ原', '25', '25214', '5210013', '滋賀県', 'シガケン', '米原市', 'マイバラシ', '梅ケ原', 'ウメガハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県米原市梅ケ原栄', '25', '25214', '5210014', '滋賀県', 'シガケン', '米原市', 'マイバラシ', '梅ケ原栄', 'ウメガハラサカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県米原市米原西', '25', '25214', '5210015', '滋賀県', 'シガケン', '米原市', 'マイバラシ', '米原西', 'マイバラニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県米原市下多良', '25', '25214', '5210016', '滋賀県', 'シガケン', '米原市', 'マイバラシ', '下多良', 'シモタラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県米原市河南', '25', '25214', '5210021', '滋賀県', 'シガケン', '米原市', 'マイバラシ', '河南', 'カワナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県米原市樋口', '25', '25214', '5210022', '滋賀県', 'シガケン', '米原市', 'マイバラシ', '樋口', 'ヒグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県米原市三吉', '25', '25214', '5210023', '滋賀県', 'シガケン', '米原市', 'マイバラシ', '三吉', 'ミヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県米原市西坂', '25', '25214', '5210024', '滋賀県', 'シガケン', '米原市', 'マイバラシ', '西坂', 'ニシサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県米原市番場', '25', '25214', '5210025', '滋賀県', 'シガケン', '米原市', 'マイバラシ', '番場', 'バンバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県米原市一色', '25', '25214', '5210031', '滋賀県', 'シガケン', '米原市', 'マイバラシ', '一色', 'イッシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県米原市枝折', '25', '25214', '5210032', '滋賀県', 'シガケン', '米原市', 'マイバラシ', '枝折', 'シオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県米原市上丹生', '25', '25214', '5210033', '滋賀県', 'シガケン', '米原市', 'マイバラシ', '上丹生', 'カミニュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県米原市下丹生', '25', '25214', '5210034', '滋賀県', 'シガケン', '米原市', 'マイバラシ', '下丹生', 'シモニュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県米原市醒井', '25', '25214', '5210035', '滋賀県', 'シガケン', '米原市', 'マイバラシ', '醒井', 'サメガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県米原市長沢', '25', '25214', '5210061', '滋賀県', 'シガケン', '米原市', 'マイバラシ', '長沢', 'ナガサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県米原市宇賀野', '25', '25214', '5210062', '滋賀県', 'シガケン', '米原市', 'マイバラシ', '宇賀野', 'ウカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県米原市飯', '25', '25214', '5210063', '滋賀県', 'シガケン', '米原市', 'マイバラシ', '飯', 'イ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県米原市世継', '25', '25214', '5210064', '滋賀県', 'シガケン', '米原市', 'マイバラシ', '世継', 'ヨツギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県米原市舟崎', '25', '25214', '5210071', '滋賀県', 'シガケン', '米原市', 'マイバラシ', '舟崎', 'フナサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県米原市顔戸', '25', '25214', '5210072', '滋賀県', 'シガケン', '米原市', 'マイバラシ', '顔戸', 'ゴウド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県米原市箕浦', '25', '25214', '5210073', '滋賀県', 'シガケン', '米原市', 'マイバラシ', '箕浦', 'ミノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県米原市高溝', '25', '25214', '5210074', '滋賀県', 'シガケン', '米原市', 'マイバラシ', '高溝', 'タカミゾ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県米原市多和田', '25', '25214', '5210081', '滋賀県', 'シガケン', '米原市', 'マイバラシ', '多和田', 'タワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県米原市能登瀬', '25', '25214', '5210082', '滋賀県', 'シガケン', '米原市', 'マイバラシ', '能登瀬', 'ノトセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県米原市新庄', '25', '25214', '5210083', '滋賀県', 'シガケン', '米原市', 'マイバラシ', '新庄', 'シンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県米原市日光寺', '25', '25214', '5210084', '滋賀県', 'シガケン', '米原市', 'マイバラシ', '日光寺', 'ニッコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県米原市岩脇', '25', '25214', '5210091', '滋賀県', 'シガケン', '米原市', 'マイバラシ', '岩脇', 'イオギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県米原市西円寺', '25', '25214', '5210092', '滋賀県', 'シガケン', '米原市', 'マイバラシ', '西円寺', 'サイエンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県米原市寺倉', '25', '25214', '5210093', '滋賀県', 'シガケン', '米原市', 'マイバラシ', '寺倉', 'テラクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県米原市長久寺', '25', '25214', '5210201', '滋賀県', 'シガケン', '米原市', 'マイバラシ', '長久寺', 'チョウキュウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県米原市柏原', '25', '25214', '5210202', '滋賀県', 'シガケン', '米原市', 'マイバラシ', '柏原', 'カシワバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県米原市清滝', '25', '25214', '5210203', '滋賀県', 'シガケン', '米原市', 'マイバラシ', '清滝', 'キヨタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県米原市梓河内', '25', '25214', '5210211', '滋賀県', 'シガケン', '米原市', 'マイバラシ', '梓河内', 'アンサカワチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県米原市本郷', '25', '25214', '5210212', '滋賀県', 'シガケン', '米原市', 'マイバラシ', '本郷', 'ホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県米原市堂谷', '25', '25214', '5210213', '滋賀県', 'シガケン', '米原市', 'マイバラシ', '堂谷', 'ドウダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県米原市大鹿', '25', '25214', '5210214', '滋賀県', 'シガケン', '米原市', 'マイバラシ', '大鹿', 'オオシカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県米原市山室', '25', '25214', '5210215', '滋賀県', 'シガケン', '米原市', 'マイバラシ', '山室', 'ヤマムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県米原市菅江', '25', '25214', '5210216', '滋賀県', 'シガケン', '米原市', 'マイバラシ', '菅江', 'スエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県米原市北方', '25', '25214', '5210217', '滋賀県', 'シガケン', '米原市', 'マイバラシ', '北方', 'キタガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県米原市志賀谷', '25', '25214', '5210218', '滋賀県', 'シガケン', '米原市', 'マイバラシ', '志賀谷', 'シガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県米原市加勢野', '25', '25214', '5210219', '滋賀県', 'シガケン', '米原市', 'マイバラシ', '加勢野', 'カセノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県米原市池下', '25', '25214', '5210221', '滋賀県', 'シガケン', '米原市', 'マイバラシ', '池下', 'イケシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県米原市天満', '25', '25214', '5210222', '滋賀県', 'シガケン', '米原市', 'マイバラシ', '天満', 'テンマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県米原市本市場', '25', '25214', '5210223', '滋賀県', 'シガケン', '米原市', 'マイバラシ', '本市場', 'モトイチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県米原市夫馬', '25', '25214', '5210224', '滋賀県', 'シガケン', '米原市', 'マイバラシ', '夫馬', 'ブマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県米原市市場', '25', '25214', '5210225', '滋賀県', 'シガケン', '米原市', 'マイバラシ', '市場', 'イチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県米原市朝日', '25', '25214', '5210226', '滋賀県', 'シガケン', '米原市', 'マイバラシ', '朝日', 'アサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県米原市烏脇', '25', '25214', '5210227', '滋賀県', 'シガケン', '米原市', 'マイバラシ', '烏脇', 'カラスワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県米原市村居田', '25', '25214', '5210231', '滋賀県', 'シガケン', '米原市', 'マイバラシ', '村居田', 'ムライダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県米原市坂口', '25', '25214', '5210232', '滋賀県', 'シガケン', '米原市', 'マイバラシ', '坂口', 'サカグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県米原市野一色', '25', '25214', '5210233', '滋賀県', 'シガケン', '米原市', 'マイバラシ', '野一色', 'ノイシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県米原市井之口', '25', '25214', '5210234', '滋賀県', 'シガケン', '米原市', 'マイバラシ', '井之口', 'イノクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県米原市小田', '25', '25214', '5210235', '滋賀県', 'シガケン', '米原市', 'マイバラシ', '小田', 'ヤナイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県米原市間田', '25', '25214', '5210236', '滋賀県', 'シガケン', '米原市', 'マイバラシ', '間田', 'ハサマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県米原市西山', '25', '25214', '5210241', '滋賀県', 'シガケン', '米原市', 'マイバラシ', '西山', 'ニシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県米原市長岡', '25', '25214', '5210242', '滋賀県', 'シガケン', '米原市', 'マイバラシ', '長岡', 'ナガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県米原市万願寺', '25', '25214', '5210243', '滋賀県', 'シガケン', '米原市', 'マイバラシ', '万願寺', 'マンガンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県米原市大野木', '25', '25214', '5210244', '滋賀県', 'シガケン', '米原市', 'マイバラシ', '大野木', 'オオノギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県米原市須川', '25', '25214', '5210245', '滋賀県', 'シガケン', '米原市', 'マイバラシ', '須川', 'スガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県米原市甲津原', '25', '25214', '5210301', '滋賀県', 'シガケン', '米原市', 'マイバラシ', '甲津原', 'コウヅハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県米原市曲谷', '25', '25214', '5210302', '滋賀県', 'シガケン', '米原市', 'マイバラシ', '曲谷', 'マガタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県米原市甲賀', '25', '25214', '5210303', '滋賀県', 'シガケン', '米原市', 'マイバラシ', '甲賀', 'コウガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県米原市吉槻', '25', '25214', '5210304', '滋賀県', 'シガケン', '米原市', 'マイバラシ', '吉槻', 'ヨシツキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県米原市上板並', '25', '25214', '5210305', '滋賀県', 'シガケン', '米原市', 'マイバラシ', '上板並', 'カミイタナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県米原市下板並', '25', '25214', '5210306', '滋賀県', 'シガケン', '米原市', 'マイバラシ', '下板並', 'シモイタナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県米原市大久保', '25', '25214', '5210307', '滋賀県', 'シガケン', '米原市', 'マイバラシ', '大久保', 'オオクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県米原市小泉', '25', '25214', '5210308', '滋賀県', 'シガケン', '米原市', 'マイバラシ', '小泉', 'コイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県米原市伊吹', '25', '25214', '5210311', '滋賀県', 'シガケン', '米原市', 'マイバラシ', '伊吹', 'イブキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県米原市上野', '25', '25214', '5210312', '滋賀県', 'シガケン', '米原市', 'マイバラシ', '上野', 'ウエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県米原市弥高', '25', '25214', '5210313', '滋賀県', 'シガケン', '米原市', 'マイバラシ', '弥高', 'ヤタカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県米原市春照', '25', '25214', '5210314', '滋賀県', 'シガケン', '米原市', 'マイバラシ', '春照', 'スイジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県米原市高番', '25', '25214', '5210321', '滋賀県', 'シガケン', '米原市', 'マイバラシ', '高番', 'タカバン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県米原市杉沢', '25', '25214', '5210322', '滋賀県', 'シガケン', '米原市', 'マイバラシ', '杉沢', 'スギサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県米原市村木', '25', '25214', '5210323', '滋賀県', 'シガケン', '米原市', 'マイバラシ', '村木', 'ムラギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県米原市大清水', '25', '25214', '5210324', '滋賀県', 'シガケン', '米原市', 'マイバラシ', '大清水', 'オオシミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県米原市藤川', '25', '25214', '5210325', '滋賀県', 'シガケン', '米原市', 'マイバラシ', '藤川', 'フジカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県米原市寺林', '25', '25214', '5210326', '滋賀県', 'シガケン', '米原市', 'マイバラシ', '寺林', 'テラバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県米原市上平寺', '25', '25214', '5210327', '滋賀県', 'シガケン', '米原市', 'マイバラシ', '上平寺', 'ジョウヘイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市石寺町', '25', '25202', '5211101', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '石寺町', 'イシデラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市下岡部町', '25', '25202', '5211102', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '下岡部町', 'シモオカベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市上岡部町', '25', '25202', '5211103', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '上岡部町', 'カミオカベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市出路町', '25', '25202', '5211104', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '出路町', 'デッチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市田原町', '25', '25202', '5211105', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '田原町', 'タワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市稲里町', '25', '25202', '5211111', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '稲里町', 'イナサトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市金沢町', '25', '25202', '5211112', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '金沢町', 'カナザワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市稲部町', '25', '25202', '5211113', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '稲部町', 'イナベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市彦富町', '25', '25202', '5211114', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '彦富町', 'ヒコトミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市金田町', '25', '25202', '5211115', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '金田町', 'カネダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市海瀬町', '25', '25202', '5211121', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '海瀬町', 'カイゼチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市三津町', '25', '25202', '5211122', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '三津町', 'ミツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市肥田町', '25', '25202', '5211123', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '肥田町', 'ヒダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市野良田町', '25', '25202', '5211124', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '野良田町', 'ノラダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市稲枝町', '25', '25202', '5211125', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '稲枝町', 'イナエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市服部町', '25', '25202', '5211126', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '服部町', 'ハツトリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市上稲葉町', '25', '25202', '5211131', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '上稲葉町', 'カミイナバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市下稲葉町', '25', '25202', '5211132', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '下稲葉町', 'シモイナバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市本庄町', '25', '25202', '5211133', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '本庄町', 'ホンジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市田附町', '25', '25202', '5211134', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '田附町', 'タヅケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市新海町', '25', '25202', '5211135', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '新海町', 'シンガイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市新海浜', '25', '25202', '5211136', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '新海浜', 'シンガイハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市甲崎町', '25', '25202', '5211141', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '甲崎町', 'コウザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市下西川町', '25', '25202', '5211142', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '下西川町', 'シモニシガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市上西川町', '25', '25202', '5211143', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '上西川町', 'カミニシガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市普光寺町', '25', '25202', '5211144', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '普光寺町', 'フコウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市南三ツ谷町', '25', '25202', '5211145', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '南三ツ谷町', 'ミナミミツヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市柳川町', '25', '25202', '5211146', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '柳川町', 'ヤナガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市薩摩町', '25', '25202', '5211147', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '薩摩町', 'サツマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市新宮町', '25', '25213', '5211201', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '新宮町', 'シングウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市阿弥陀堂町', '25', '25213', '5211202', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '阿弥陀堂町', 'アミダドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市川南町', '25', '25213', '5211203', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '川南町', 'カワミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市小川町', '25', '25213', '5211204', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '小川町', 'オガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市躰光寺町', '25', '25213', '5211205', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '躰光寺町', 'タイコウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市今町', '25', '25213', '5211211', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '今町', 'イマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市種町', '25', '25213', '5211212', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '種町', 'タネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市神郷町', '25', '25213', '5211213', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '神郷町', 'ジンゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市長勝寺町', '25', '25213', '5211214', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '長勝寺町', 'チョウショウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市佐生町', '25', '25213', '5211215', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '佐生町', 'サソチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市垣見町', '25', '25213', '5211221', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '垣見町', 'カキミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市佐野町', '25', '25213', '5211222', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '佐野町', 'サノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市猪子町', '25', '25213', '5211223', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '猪子町', 'イノコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市林町', '25', '25213', '5211224', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '林町', 'ハヤシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市山路町', '25', '25213', '5211225', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '山路町', 'ヤマジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市能登川町', '25', '25213', '5211231', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '能登川町', 'ノトガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市北須田町', '25', '25213', '5211232', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '北須田町', 'キタスダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市南須田町', '25', '25213', '5211233', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '南須田町', 'ミナミスダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市きぬがさ町', '25', '25213', '5211234', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', 'きぬがさ町', 'キヌガサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市伊庭町', '25', '25213', '5211235', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '伊庭町', 'イバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市乙女浜町', '25', '25213', '5211241', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '乙女浜町', 'オトメハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市福堂町', '25', '25213', '5211242', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '福堂町', 'フクドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市栗見新田町', '25', '25213', '5211243', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '栗見新田町', 'クリミシンデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市大中町', '25', '25213', '5211244', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '大中町', 'ダイナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市栗見出在家町', '25', '25213', '5211245', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '栗見出在家町', 'クリミデザイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県蒲生郡安土町', '25', '25381', '5211300', '滋賀県', 'シガケン', '蒲生郡安土町', 'ガモウグンアヅチチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('58165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県蒲生郡安土町大中', '25', '25381', '5211301', '滋賀県', 'シガケン', '蒲生郡安土町', 'ガモウグンアヅチチョウ', '大中', 'ダイナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県蒲生郡安土町下豊浦', '25', '25381', '5211311', '滋賀県', 'シガケン', '蒲生郡安土町', 'ガモウグンアヅチチョウ', '下豊浦', 'シモトイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県蒲生郡安土町桑実寺', '25', '25381', '5211321', '滋賀県', 'シガケン', '蒲生郡安土町', 'ガモウグンアヅチチョウ', '桑実寺', 'クワノミジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県蒲生郡安土町宮津', '25', '25381', '5211322', '滋賀県', 'シガケン', '蒲生郡安土町', 'ガモウグンアヅチチョウ', '宮津', 'ミヤヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県蒲生郡安土町石寺', '25', '25381', '5211331', '滋賀県', 'シガケン', '蒲生郡安土町', 'ガモウグンアヅチチョウ', '石寺', 'イシデラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県蒲生郡安土町東老蘇', '25', '25381', '5211332', '滋賀県', 'シガケン', '蒲生郡安土町', 'ガモウグンアヅチチョウ', '東老蘇', 'ヒガシオイソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県蒲生郡安土町内野', '25', '25381', '5211333', '滋賀県', 'シガケン', '蒲生郡安土町', 'ガモウグンアヅチチョウ', '内野', 'ウチノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県蒲生郡安土町西老蘇', '25', '25381', '5211334', '滋賀県', 'シガケン', '蒲生郡安土町', 'ガモウグンアヅチチョウ', '西老蘇', 'ニシオイソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県蒲生郡安土町上豊浦', '25', '25381', '5211341', '滋賀県', 'シガケン', '蒲生郡安土町', 'ガモウグンアヅチチョウ', '上豊浦', 'カミトヨウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県蒲生郡安土町上出', '25', '25381', '5211342', '滋賀県', 'シガケン', '蒲生郡安土町', 'ガモウグンアヅチチョウ', '上出', 'カミデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県蒲生郡安土町小中', '25', '25381', '5211343', '滋賀県', 'シガケン', '蒲生郡安土町', 'ガモウグンアヅチチョウ', '小中', 'コナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県蒲生郡安土町中屋', '25', '25381', '5211344', '滋賀県', 'シガケン', '蒲生郡安土町', 'ガモウグンアヅチチョウ', '中屋', 'ナカヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県蒲生郡安土町慈恩寺', '25', '25381', '5211345', '滋賀県', 'シガケン', '蒲生郡安土町', 'ガモウグンアヅチチョウ', '慈恩寺', 'ジオンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県蒲生郡安土町香庄', '25', '25381', '5211346', '滋賀県', 'シガケン', '蒲生郡安土町', 'ガモウグンアヅチチョウ', '香庄', 'コノショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県蒲生郡安土町常楽寺', '25', '25381', '5211351', '滋賀県', 'シガケン', '蒲生郡安土町', 'ガモウグンアヅチチョウ', '常楽寺', 'ジョウラクジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市', '25', '25202', '5220000', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('58187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市尾末町', '25', '25202', '5220001', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '尾末町', 'オスエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市松原', '25', '25202', '5220002', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '松原', 'マツバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市松原町', '25', '25202', '5220002', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '松原町', 'マツバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市宮田町', '25', '25202', '5220003', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '宮田町', 'ミヤタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市鳥居本町', '25', '25202', '5220004', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '鳥居本町', 'トリイモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市小野町', '25', '25202', '5220005', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '小野町', 'オノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市佐和山町', '25', '25202', '5220006', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '佐和山町', 'サワヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市古沢町', '25', '25202', '5220007', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '古沢町', 'フルサワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市安清東町', '25', '25202', '5220008', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '安清東町', 'ヤスキヨヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市外町', '25', '25202', '5220009', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '外町', 'トマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市下矢倉町', '25', '25202', '5220011', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '下矢倉町', 'シモヤグラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市甲田町', '25', '25202', '5220012', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '甲田町', 'コウタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市中山町', '25', '25202', '5220013', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '中山町', 'ナカヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市善谷町', '25', '25202', '5220014', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '善谷町', 'ゼンダニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市荘厳寺町', '25', '25202', '5220015', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '荘厳寺町', 'ショウゴンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市武奈町', '25', '25202', '5220016', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '武奈町', 'ブナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市男鬼町', '25', '25202', '5220017', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '男鬼町', 'オオリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市仏生寺町', '25', '25202', '5220018', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '仏生寺町', 'ブツショウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市笹尾町', '25', '25202', '5220019', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '笹尾町', 'ササオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市幸町', '25', '25202', '5220021', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市里根町', '25', '25202', '5220022', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '里根町', 'サトネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市原町', '25', '25202', '5220023', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '原町', 'ハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市正法寺町', '25', '25202', '5220024', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '正法寺町', 'ショウボウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市野田山町', '25', '25202', '5220025', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '野田山町', 'ノダヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市大堀町', '25', '25202', '5220026', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '大堀町', 'オオボリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市東沼波町', '25', '25202', '5220027', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '東沼波町', 'ヒガシノナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市地蔵町', '25', '25202', '5220029', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '地蔵町', 'ジゾウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市芹中町', '25', '25202', '5220031', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '芹中町', 'セリナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市芹町', '25', '25202', '5220032', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '芹町', 'セリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市芹川町', '25', '25202', '5220033', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '芹川町', 'セリカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市大橋町', '25', '25202', '5220034', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '大橋町', 'オオハシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市元岡町', '25', '25202', '5220035', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '元岡町', 'モトオカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市沼波町', '25', '25202', '5220036', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '沼波町', 'ノナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市岡町', '25', '25202', '5220037', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '岡町', 'オカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市西沼波町', '25', '25202', '5220038', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '西沼波町', 'ニシノナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市山之脇町', '25', '25202', '5220038', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '山之脇町', 'ヤマノワキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市和田町', '25', '25202', '5220039', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '和田町', 'ワダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市平田町', '25', '25202', '5220041', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '平田町', 'ヒラタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市戸賀町', '25', '25202', '5220042', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '戸賀町', 'トガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市小泉町', '25', '25202', '5220043', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '小泉町', 'コイズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市竹ケ鼻町', '25', '25202', '5220044', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '竹ケ鼻町', 'タケガハナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市宇尾町', '25', '25202', '5220045', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '宇尾町', 'ウオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市甘呂町', '25', '25202', '5220046', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '甘呂町', 'カンロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市日夏町', '25', '25202', '5220047', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '日夏町', 'ヒナツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市中藪', '25', '25202', '5220051', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '中藪', 'ナカヤブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市中藪町', '25', '25202', '5220051', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '中藪町', 'ナカヤブチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市長曽根南町', '25', '25202', '5220052', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '長曽根南町', 'ナガソネミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市大藪町', '25', '25202', '5220053', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '大藪町', 'オオヤブチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市西今町', '25', '25202', '5220054', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '西今町', 'ニシイマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市野瀬町', '25', '25202', '5220055', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '野瀬町', 'ノセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市開出今町', '25', '25202', '5220056', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '開出今町', 'カイデイマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市八坂町', '25', '25202', '5220057', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '八坂町', 'ハッサカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市須越町', '25', '25202', '5220058', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '須越町', 'スゴシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市三津屋町', '25', '25202', '5220059', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '三津屋町', 'ミツヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市金亀町', '25', '25202', '5220061', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '金亀町', 'コンキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市立花町', '25', '25202', '5220062', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '立花町', 'タチバナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市中央町', '25', '25202', '5220063', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '中央町', 'チュウオウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市本町', '25', '25202', '5220064', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市池州町', '25', '25202', '5220065', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '池州町', 'イケスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市栄町', '25', '25202', '5220066', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市長曽根町', '25', '25202', '5220067', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '長曽根町', 'ナガソネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市城町', '25', '25202', '5220068', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '城町', 'シロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市馬場', '25', '25202', '5220069', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '馬場', 'バンバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市元町', '25', '25202', '5220071', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '元町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市船町', '25', '25202', '5220072', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '船町', 'フナマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市旭町', '25', '25202', '5220073', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '旭町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市大東町', '25', '25202', '5220074', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '大東町', 'ダイトウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市佐和町', '25', '25202', '5220075', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '佐和町', 'サワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市京町', '25', '25202', '5220081', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '京町', 'キョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市安清町', '25', '25202', '5220082', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '安清町', 'ヤスキヨチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市河原', '25', '25202', '5220083', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '河原', 'カワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市橋向町', '25', '25202', '5220084', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '橋向町', 'ハシムカイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市新町', '25', '25202', '5220085', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市後三条町', '25', '25202', '5220086', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '後三条町', 'ゴサンジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市芹橋', '25', '25202', '5220087', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '芹橋', 'セリバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市銀座町', '25', '25202', '5220088', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '銀座町', 'ギンザチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市錦町', '25', '25202', '5220089', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '錦町', 'ニシキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県犬上郡甲良町', '25', '25442', '5220200', '滋賀県', 'シガケン', '犬上郡甲良町', 'イヌカミグンコウラチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('58265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市高宮町', '25', '25202', '5220201', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '高宮町', 'タカミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市法士町', '25', '25202', '5220211', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '法士町', 'ホウゼチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市葛籠町', '25', '25202', '5220212', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '葛籠町', 'ツズラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市西葛籠町', '25', '25202', '5220213', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '西葛籠町', 'ニシツズラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市出町', '25', '25202', '5220214', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '出町', 'デマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市野口町', '25', '25202', '5220221', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '野口町', 'ノグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市南川瀬町', '25', '25202', '5220222', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '南川瀬町', 'ミナミカワセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市川瀬馬場町', '25', '25202', '5220223', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '川瀬馬場町', 'カワセババチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市極楽寺町', '25', '25202', '5220231', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '極楽寺町', 'ゴクラクジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市蓮台寺町', '25', '25202', '5220232', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '蓮台寺町', 'レンダイジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市辻堂町', '25', '25202', '5220233', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '辻堂町', 'ツジドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市森堂町', '25', '25202', '5220234', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '森堂町', 'モリドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市金剛寺町', '25', '25202', '5220235', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '金剛寺町', 'コンゴウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市犬方町', '25', '25202', '5220236', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '犬方町', 'イヌカタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市堀町', '25', '25202', '5220237', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '堀町', 'ホリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市広野町', '25', '25202', '5220238', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '広野町', 'コウノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市宇尾町', '25', '25202', '5220239', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '宇尾町', 'ウオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県犬上郡甲良町呉竹', '25', '25442', '5220241', '滋賀県', 'シガケン', '犬上郡甲良町', 'イヌカミグンコウラチョウ', '呉竹', 'クレタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県犬上郡甲良町尼子', '25', '25442', '5220242', '滋賀県', 'シガケン', '犬上郡甲良町', 'イヌカミグンコウラチョウ', '尼子', 'アマゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県犬上郡甲良町小川原', '25', '25442', '5220243', '滋賀県', 'シガケン', '犬上郡甲良町', 'イヌカミグンコウラチョウ', '小川原', 'コガワハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県犬上郡甲良町在士', '25', '25442', '5220244', '滋賀県', 'シガケン', '犬上郡甲良町', 'イヌカミグンコウラチョウ', '在士', 'ザイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県犬上郡甲良町北落', '25', '25442', '5220251', '滋賀県', 'シガケン', '犬上郡甲良町', 'イヌカミグンコウラチョウ', '北落', 'キタオチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県犬上郡甲良町金屋', '25', '25442', '5220252', '滋賀県', 'シガケン', '犬上郡甲良町', 'イヌカミグンコウラチョウ', '金屋', 'カナヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県犬上郡甲良町正楽寺', '25', '25442', '5220253', '滋賀県', 'シガケン', '犬上郡甲良町', 'イヌカミグンコウラチョウ', '正楽寺', 'ショウラクジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県犬上郡甲良町池寺', '25', '25442', '5220254', '滋賀県', 'シガケン', '犬上郡甲良町', 'イヌカミグンコウラチョウ', '池寺', 'イケデラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県犬上郡甲良町長寺', '25', '25442', '5220261', '滋賀県', 'シガケン', '犬上郡甲良町', 'イヌカミグンコウラチョウ', '長寺', 'オサデラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県犬上郡甲良町横関', '25', '25442', '5220262', '滋賀県', 'シガケン', '犬上郡甲良町', 'イヌカミグンコウラチョウ', '横関', 'ヨコゼキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県犬上郡甲良町法養寺', '25', '25442', '5220263', '滋賀県', 'シガケン', '犬上郡甲良町', 'イヌカミグンコウラチョウ', '法養寺', 'ホウヨウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県犬上郡甲良町下之郷', '25', '25442', '5220271', '滋賀県', 'シガケン', '犬上郡甲良町', 'イヌカミグンコウラチョウ', '下之郷', 'シモノゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県犬上郡多賀町', '25', '25443', '5220300', '滋賀県', 'シガケン', '犬上郡多賀町', 'イヌカミグンタガチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('58297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県犬上郡多賀町河内', '25', '25443', '5220301', '滋賀県', 'シガケン', '犬上郡多賀町', 'イヌカミグンタガチョウ', '河内', 'カワチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県犬上郡多賀町向之倉', '25', '25443', '5220302', '滋賀県', 'シガケン', '犬上郡多賀町', 'イヌカミグンタガチョウ', '向之倉', 'ムカイノクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県犬上郡多賀町屏風', '25', '25443', '5220303', '滋賀県', 'シガケン', '犬上郡多賀町', 'イヌカミグンタガチョウ', '屏風', 'ビョウブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県犬上郡多賀町後谷', '25', '25443', '5220304', '滋賀県', 'シガケン', '犬上郡多賀町', 'イヌカミグンタガチョウ', '後谷', 'ウシロダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県犬上郡多賀町甲頭倉', '25', '25443', '5220305', '滋賀県', 'シガケン', '犬上郡多賀町', 'イヌカミグンタガチョウ', '甲頭倉', 'コウズクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県犬上郡多賀町霊仙', '25', '25443', '5220306', '滋賀県', 'シガケン', '犬上郡多賀町', 'イヌカミグンタガチョウ', '霊仙', 'リョウゼン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県犬上郡多賀町五僧', '25', '25443', '5220311', '滋賀県', 'シガケン', '犬上郡多賀町', 'イヌカミグンタガチョウ', '五僧', 'ゴソウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県犬上郡多賀町保月', '25', '25443', '5220312', '滋賀県', 'シガケン', '犬上郡多賀町', 'イヌカミグンタガチョウ', '保月', 'ホウヅキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県犬上郡多賀町杉', '25', '25443', '5220313', '滋賀県', 'シガケン', '犬上郡多賀町', 'イヌカミグンタガチョウ', '杉', 'スギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県犬上郡多賀町四手', '25', '25443', '5220314', '滋賀県', 'シガケン', '犬上郡多賀町', 'イヌカミグンタガチョウ', '四手', 'シデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県犬上郡多賀町大岡', '25', '25443', '5220315', '滋賀県', 'シガケン', '犬上郡多賀町', 'イヌカミグンタガチョウ', '大岡', 'オオオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県犬上郡多賀町栗栖', '25', '25443', '5220316', '滋賀県', 'シガケン', '犬上郡多賀町', 'イヌカミグンタガチョウ', '栗栖', 'クルス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県犬上郡多賀町一円', '25', '25443', '5220317', '滋賀県', 'シガケン', '犬上郡多賀町', 'イヌカミグンタガチョウ', '一円', 'イチエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県犬上郡多賀町水谷', '25', '25443', '5220318', '滋賀県', 'シガケン', '犬上郡多賀町', 'イヌカミグンタガチョウ', '水谷', 'スイダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県犬上郡多賀町桃原', '25', '25443', '5220319', '滋賀県', 'シガケン', '犬上郡多賀町', 'イヌカミグンタガチョウ', '桃原', 'モバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県犬上郡多賀町大君ケ畑', '25', '25443', '5220321', '滋賀県', 'シガケン', '犬上郡多賀町', 'イヌカミグンタガチョウ', '大君ケ畑', 'オジガハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県犬上郡多賀町佐目', '25', '25443', '5220322', '滋賀県', 'シガケン', '犬上郡多賀町', 'イヌカミグンタガチョウ', '佐目', 'サメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県犬上郡多賀町一之瀬', '25', '25443', '5220323', '滋賀県', 'シガケン', '犬上郡多賀町', 'イヌカミグンタガチョウ', '一之瀬', 'イチノセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県犬上郡多賀町川相', '25', '25443', '5220324', '滋賀県', 'シガケン', '犬上郡多賀町', 'イヌカミグンタガチョウ', '川相', 'カワナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県犬上郡多賀町小原', '25', '25443', '5220325', '滋賀県', 'シガケン', '犬上郡多賀町', 'イヌカミグンタガチョウ', '小原', 'コハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県犬上郡多賀町霜ケ原', '25', '25443', '5220326', '滋賀県', 'シガケン', '犬上郡多賀町', 'イヌカミグンタガチョウ', '霜ケ原', 'シモガハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県犬上郡多賀町南後谷', '25', '25443', '5220327', '滋賀県', 'シガケン', '犬上郡多賀町', 'イヌカミグンタガチョウ', '南後谷', 'ミナミウシロダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県犬上郡多賀町大杉', '25', '25443', '5220331', '滋賀県', 'シガケン', '犬上郡多賀町', 'イヌカミグンタガチョウ', '大杉', 'オオスギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県犬上郡多賀町樋田', '25', '25443', '5220332', '滋賀県', 'シガケン', '犬上郡多賀町', 'イヌカミグンタガチョウ', '樋田', 'ヒダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県犬上郡多賀町萱原', '25', '25443', '5220333', '滋賀県', 'シガケン', '犬上郡多賀町', 'イヌカミグンタガチョウ', '萱原', 'カイハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県犬上郡多賀町仏ケ後', '25', '25443', '5220334', '滋賀県', 'シガケン', '犬上郡多賀町', 'イヌカミグンタガチョウ', '仏ケ後', 'ホトケラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県犬上郡多賀町藤瀬', '25', '25443', '5220335', '滋賀県', 'シガケン', '犬上郡多賀町', 'イヌカミグンタガチョウ', '藤瀬', 'フジセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県犬上郡多賀町楢崎', '25', '25443', '5220336', '滋賀県', 'シガケン', '犬上郡多賀町', 'イヌカミグンタガチョウ', '楢崎', 'ナラサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県犬上郡多賀町富之尾', '25', '25443', '5220337', '滋賀県', 'シガケン', '犬上郡多賀町', 'イヌカミグンタガチョウ', '富之尾', 'トミノオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県犬上郡多賀町壺', '25', '25443', '5220338', '滋賀県', 'シガケン', '犬上郡多賀町', 'イヌカミグンタガチョウ', '壺', 'ツボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県犬上郡多賀町多賀', '25', '25443', '5220341', '滋賀県', 'シガケン', '犬上郡多賀町', 'イヌカミグンタガチョウ', '多賀', 'タガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県犬上郡多賀町敏満寺', '25', '25443', '5220342', '滋賀県', 'シガケン', '犬上郡多賀町', 'イヌカミグンタガチョウ', '敏満寺', 'ビンマンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県犬上郡多賀町猿木', '25', '25443', '5220343', '滋賀県', 'シガケン', '犬上郡多賀町', 'イヌカミグンタガチョウ', '猿木', 'サルギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県犬上郡多賀町八重練', '25', '25443', '5220351', '滋賀県', 'シガケン', '犬上郡多賀町', 'イヌカミグンタガチョウ', '八重練', 'ヤエネリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県犬上郡多賀町久徳', '25', '25443', '5220352', '滋賀県', 'シガケン', '犬上郡多賀町', 'イヌカミグンタガチョウ', '久徳', 'キュウトク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県犬上郡多賀町月之木', '25', '25443', '5220353', '滋賀県', 'シガケン', '犬上郡多賀町', 'イヌカミグンタガチョウ', '月之木', 'ツキノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県犬上郡多賀町土田', '25', '25443', '5220354', '滋賀県', 'シガケン', '犬上郡多賀町', 'イヌカミグンタガチョウ', '土田', 'ツチダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県犬上郡多賀町中川原', '25', '25443', '5220355', '滋賀県', 'シガケン', '犬上郡多賀町', 'イヌカミグンタガチョウ', '中川原', 'ナカガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県犬上郡多賀町木曽', '25', '25443', '5220356', '滋賀県', 'シガケン', '犬上郡多賀町', 'イヌカミグンタガチョウ', '木曽', 'キソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市', '25', '25204', '5230000', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('58349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市金剛寺町', '25', '25204', '5230001', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '金剛寺町', 'コンゴウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市野田町', '25', '25204', '5230002', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '野田町', 'ノダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市御所内町', '25', '25204', '5230003', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '御所内町', 'ゴショウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市西生来町', '25', '25204', '5230004', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '西生来町', 'ニショウライチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市末広町', '25', '25204', '5230005', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '末広町', 'スエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市友定町', '25', '25204', '5230011', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '友定町', 'トモサダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市武佐町', '25', '25204', '5230012', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '武佐町', 'ムサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市長光寺町', '25', '25204', '5230013', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '長光寺町', 'チョウコウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市西宿町', '25', '25204', '5230014', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '西宿町', 'ニシジュクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市上田町', '25', '25204', '5230015', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '上田町', 'ウエダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市千僧供町', '25', '25204', '5230016', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '千僧供町', 'センゾクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市長福寺町', '25', '25204', '5230021', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '長福寺町', 'チョウフクジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市馬淵町', '25', '25204', '5230022', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '馬淵町', 'マブチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市倉橋部町', '25', '25204', '5230023', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '倉橋部町', 'クラハシベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市浄土寺町', '25', '25204', '5230024', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '浄土寺町', 'ジョウドジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市新巻町', '25', '25204', '5230025', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '新巻町', 'シンマキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市上畑町', '25', '25204', '5230026', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '上畑町', 'ウエハタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市東川町', '25', '25204', '5230027', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '東川町', 'ヒガシガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市堀上町', '25', '25204', '5230031', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '堀上町', 'ホリカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市白鳥町', '25', '25204', '5230032', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '白鳥町', 'シラトリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市日吉野町', '25', '25204', '5230033', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '日吉野町', 'ヒヨノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市若宮町', '25', '25204', '5230034', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '若宮町', 'ワカミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市東横関町', '25', '25204', '5230035', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '東横関町', 'ヒガシヨコゼキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市竹町', '25', '25204', '5230036', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '竹町', 'タケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市東町', '25', '25204', '5230037', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '東町', 'ヒガシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市中小森町', '25', '25204', '5230041', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '中小森町', 'ナカコモリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市大森町', '25', '25204', '5230042', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '大森町', 'オオモリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市池田本町', '25', '25204', '5230043', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '池田本町', 'イケダホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市篠原町', '25', '25204', '5230044', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '篠原町', 'シノハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市安養寺町', '25', '25204', '5230045', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '安養寺町', 'アンヨウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市上野町', '25', '25204', '5230046', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '上野町', 'ウエノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市川原町', '25', '25204', '5230047', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '川原町', 'カワラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市緑町', '25', '25204', '5230048', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '緑町', 'ミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市八木町', '25', '25204', '5230051', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '八木町', 'ヤギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市赤尾町', '25', '25204', '5230052', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '赤尾町', 'アコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市益田町', '25', '25204', '5230053', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '益田町', 'マスダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市森尻町', '25', '25204', '5230054', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '森尻町', 'モリジリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市柳町', '25', '25204', '5230055', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '柳町', 'ヤナギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市古川町', '25', '25204', '5230056', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '古川町', 'フルカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市田中江町', '25', '25204', '5230057', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '田中江町', 'タナカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市加茂町', '25', '25204', '5230058', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '加茂町', 'カモチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市江頭町', '25', '25204', '5230061', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '江頭町', 'エガシラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市丸の内町', '25', '25204', '5230062', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '丸の内町', 'マルノウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市十王町', '25', '25204', '5230063', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '十王町', 'ジュウオウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市小田町', '25', '25204', '5230064', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '小田町', 'オダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市大房町', '25', '25204', '5230071', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '大房町', 'オオブサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市牧町', '25', '25204', '5230072', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '牧町', 'マキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市元水茎町', '25', '25204', '5230073', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '元水茎町', 'モトスイケイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市水茎町', '25', '25204', '5230074', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '水茎町', 'スイケイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市野村町', '25', '25204', '5230075', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '野村町', 'ノムラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市佐波江町', '25', '25204', '5230076', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '佐波江町', 'サバエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市新栄町', '25', '25204', '5230081', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '新栄町', 'シンサカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市土田町', '25', '25204', '5230082', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '土田町', 'ツチダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市小船木町', '25', '25204', '5230083', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '小船木町', 'コブナキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市船木町', '25', '25204', '5230084', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '船木町', 'フナキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市南津田町', '25', '25204', '5230085', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '南津田町', 'ミナミツダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市津田町', '25', '25204', '5230086', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '津田町', 'ツダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市北津田町', '25', '25204', '5230087', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '北津田町', 'キタツダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市沖島町', '25', '25204', '5230801', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '沖島町', 'オキシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市大中町', '25', '25204', '5230802', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '大中町', 'ダイナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市白王町', '25', '25204', '5230803', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '白王町', 'シラオウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市島町', '25', '25204', '5230804', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '島町', 'シマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市円山町', '25', '25204', '5230805', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '円山町', 'マルヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市北之庄町', '25', '25204', '5230806', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '北之庄町', 'キタノショウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市中之庄町', '25', '25204', '5230807', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '中之庄町', 'ナカノショウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市長命寺町', '25', '25204', '5230808', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '長命寺町', 'チョウメイジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市長田町', '25', '25204', '5230811', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '長田町', 'オサダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市杉森町', '25', '25204', '5230812', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '杉森町', 'スギノモリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市西本郷町', '25', '25204', '5230813', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '西本郷町', 'ニシホンゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市南本郷町', '25', '25204', '5230814', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '南本郷町', 'ミナミホンゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市若葉町', '25', '25204', '5230815', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '若葉町', 'ワカバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市西庄町', '25', '25204', '5230816', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '西庄町', 'ニシノショウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市浅小井町', '25', '25204', '5230817', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '浅小井町', 'アサゴイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市西本郷町東', '25', '25204', '5230818', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '西本郷町東', 'ニシホンゴウチョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市西本郷町西', '25', '25204', '5230819', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '西本郷町西', 'ニシホンゴウチョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市多賀町', '25', '25204', '5230821', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '多賀町', 'タガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市船町', '25', '25204', '5230822', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '船町', 'フナマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市生須町', '25', '25204', '5230823', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '生須町', 'イケスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市大工町', '25', '25204', '5230824', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '大工町', 'ダイクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市新左衛門町', '25', '25204', '5230825', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '新左衛門町', 'シンザエモンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市薬師町', '25', '25204', '5230826', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '薬師町', 'ヤクシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市鉄炮町', '25', '25204', '5230827', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '鉄炮町', 'テッポウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市宮内町', '25', '25204', '5230828', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '宮内町', 'ミヤウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市玉屋町', '25', '25204', '5230831', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '玉屋町', 'タマヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市江南町', '25', '25204', '5230832', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '江南町', 'エナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市鍜治屋町', '25', '25204', '5230833', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '鍜治屋町', 'カジヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市東畳屋町', '25', '25204', '5230834', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '東畳屋町', 'ヒガシタタミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市西畳屋町', '25', '25204', '5230835', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '西畳屋町', 'ニシタタミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市間之町', '25', '25204', '5230836', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '間之町', 'アイノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市大杉町', '25', '25204', '5230837', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '大杉町', 'オオスギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市慈恩寺町元', '25', '25204', '5230841', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '慈恩寺町元', 'ジオンジチョウモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市慈恩寺町中', '25', '25204', '5230842', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '慈恩寺町中', 'ジオンジチョウナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市慈恩寺町上', '25', '25204', '5230843', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '慈恩寺町上', 'ジオンジチョウカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市博労町元', '25', '25204', '5230844', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '博労町元', 'バクロチョウモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市博労町中', '25', '25204', '5230845', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '博労町中', 'バクロチョウナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市博労町上', '25', '25204', '5230846', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '博労町上', 'バクロチョウカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市永原町元', '25', '25204', '5230847', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '永原町元', 'ナガハラチョウモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市永原町中', '25', '25204', '5230848', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '永原町中', 'ナガハラチョウナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市永原町上', '25', '25204', '5230849', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '永原町上', 'ナガハラチョウカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市市井町', '25', '25204', '5230851', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '市井町', 'イチイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市鍵之手町', '25', '25204', '5230852', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '鍵之手町', 'カギノテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市縄手町元', '25', '25204', '5230853', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '縄手町元', 'ナワテチョウモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市縄手町中', '25', '25204', '5230854', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '縄手町中', 'ナワテチョウナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市縄手町末', '25', '25204', '5230855', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '縄手町末', 'ナワテチョウスエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市音羽町', '25', '25204', '5230856', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '音羽町', 'オトワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市八幡町', '25', '25204', '5230857', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '八幡町', 'ハチマンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市仲屋町元', '25', '25204', '5230861', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '仲屋町元', 'スワイチョウモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市仲屋町中', '25', '25204', '5230862', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '仲屋町中', 'スワイチョウナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市仲屋町上', '25', '25204', '5230863', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '仲屋町上', 'スワイチョウカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市為心町元', '25', '25204', '5230864', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '為心町元', 'イシンチョウモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市為心町中', '25', '25204', '5230865', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '為心町中', 'イシンチョウナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市為心町上', '25', '25204', '5230866', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '為心町上', 'イシンチョウカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市魚屋町元', '25', '25204', '5230867', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '魚屋町元', 'ウワイチョウモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市魚屋町中', '25', '25204', '5230868', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '魚屋町中', 'ウワイチョウナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市魚屋町上', '25', '25204', '5230869', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '魚屋町上', 'ウワイチョウカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市新町', '25', '25204', '5230871', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市玉木町', '25', '25204', '5230872', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '玉木町', 'タマキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市正神町', '25', '25204', '5230873', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '正神町', 'ショウガミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市小幡町中', '25', '25204', '5230874', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '小幡町中', 'オバタチョウナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市小幡町上', '25', '25204', '5230875', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '小幡町上', 'オバタチョウカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市本町', '25', '25204', '5230876', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市池田町', '25', '25204', '5230877', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '池田町', 'イケダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市佐久間町', '25', '25204', '5230881', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '佐久間町', 'サクマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市元玉屋町', '25', '25204', '5230882', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '元玉屋町', 'モトタマヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市北元町', '25', '25204', '5230883', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '北元町', 'キタモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市北末町', '25', '25204', '5230884', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '北末町', 'キタスエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市板屋町', '25', '25204', '5230885', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '板屋町', 'イタヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市西末町', '25', '25204', '5230886', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '西末町', 'ニシスエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市西元町', '25', '25204', '5230887', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '西元町', 'ニシモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市孫平治町', '25', '25204', '5230888', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '孫平治町', 'マゴヘイジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市日杉町', '25', '25204', '5230889', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '日杉町', 'ヒスギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市鷹飼町', '25', '25204', '5230891', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '鷹飼町', 'タカカイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市出町', '25', '25204', '5230892', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '出町', 'デマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市桜宮町', '25', '25204', '5230893', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '桜宮町', 'サクラミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市中村町', '25', '25204', '5230894', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '中村町', 'ナカムラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市宇津呂町', '25', '25204', '5230895', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '宇津呂町', 'ウツロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市鷹飼町北', '25', '25204', '5230896', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '鷹飼町北', 'タカカイチョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市鷹飼町東', '25', '25204', '5230897', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '鷹飼町東', 'タカカイチョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県近江八幡市鷹飼町南', '25', '25204', '5230898', '滋賀県', 'シガケン', '近江八幡市', 'オウミハチマンシ', '鷹飼町南', 'タカカイチョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県守山市', '25', '25207', '5240000', '滋賀県', 'シガケン', '守山市', 'モリヤマシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('58497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県守山市川田町', '25', '25207', '5240001', '滋賀県', 'シガケン', '守山市', 'モリヤマシ', '川田町', 'カワタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県守山市小島町', '25', '25207', '5240002', '滋賀県', 'シガケン', '守山市', 'モリヤマシ', '小島町', 'コジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県守山市中町', '25', '25207', '5240003', '滋賀県', 'シガケン', '守山市', 'モリヤマシ', '中町', 'ナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県守山市笠原町', '25', '25207', '5240004', '滋賀県', 'シガケン', '守山市', 'モリヤマシ', '笠原町', 'カサハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県守山市今市町', '25', '25207', '5240011', '滋賀県', 'シガケン', '守山市', 'モリヤマシ', '今市町', 'イマイチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県守山市播磨田町', '25', '25207', '5240012', '滋賀県', 'シガケン', '守山市', 'モリヤマシ', '播磨田町', 'ハリマダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県守山市下之郷', '25', '25207', '5240013', '滋賀県', 'シガケン', '守山市', 'モリヤマシ', '下之郷', 'シモノゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県守山市下之郷町', '25', '25207', '5240013', '滋賀県', 'シガケン', '守山市', 'モリヤマシ', '下之郷町', 'シモノゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県守山市石田町', '25', '25207', '5240014', '滋賀県', 'シガケン', '守山市', 'モリヤマシ', '石田町', 'イシダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県守山市矢島町', '25', '25207', '5240015', '滋賀県', 'シガケン', '守山市', 'モリヤマシ', '矢島町', 'ヤジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県守山市荒見町', '25', '25207', '5240016', '滋賀県', 'シガケン', '守山市', 'モリヤマシ', '荒見町', 'アラミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県守山市吉身', '25', '25207', '5240021', '滋賀県', 'シガケン', '守山市', 'モリヤマシ', '吉身', 'ヨシミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県守山市吉身町', '25', '25207', '5240021', '滋賀県', 'シガケン', '守山市', 'モリヤマシ', '吉身町', 'ヨシミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県守山市守山', '25', '25207', '5240022', '滋賀県', 'シガケン', '守山市', 'モリヤマシ', '守山', 'モリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県守山市守山町', '25', '25207', '5240022', '滋賀県', 'シガケン', '守山市', 'モリヤマシ', '守山町', 'モリヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県守山市立入町', '25', '25207', '5240031', '滋賀県', 'シガケン', '守山市', 'モリヤマシ', '立入町', 'タテイリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県守山市岡町', '25', '25207', '5240032', '滋賀県', 'シガケン', '守山市', 'モリヤマシ', '岡町', 'オカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県守山市浮気町', '25', '25207', '5240033', '滋賀県', 'シガケン', '守山市', 'モリヤマシ', '浮気町', 'フケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県守山市千代町', '25', '25207', '5240034', '滋賀県', 'シガケン', '守山市', 'モリヤマシ', '千代町', 'チシロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県守山市阿村町', '25', '25207', '5240035', '滋賀県', 'シガケン', '守山市', 'モリヤマシ', '阿村町', 'アムラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県守山市伊勢町', '25', '25207', '5240036', '滋賀県', 'シガケン', '守山市', 'モリヤマシ', '伊勢町', 'イセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県守山市梅田町', '25', '25207', '5240037', '滋賀県', 'シガケン', '守山市', 'モリヤマシ', '梅田町', 'ウメダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県守山市勝部', '25', '25207', '5240041', '滋賀県', 'シガケン', '守山市', 'モリヤマシ', '勝部', 'カツベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県守山市勝部町', '25', '25207', '5240041', '滋賀県', 'シガケン', '守山市', 'モリヤマシ', '勝部町', 'カツベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県守山市焔魔堂町', '25', '25207', '5240042', '滋賀県', 'シガケン', '守山市', 'モリヤマシ', '焔魔堂町', 'エンマドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県守山市二町町', '25', '25207', '5240043', '滋賀県', 'シガケン', '守山市', 'モリヤマシ', '二町町', 'フタマチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県守山市古高町', '25', '25207', '5240044', '滋賀県', 'シガケン', '守山市', 'モリヤマシ', '古高町', 'フルタカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県守山市金森町', '25', '25207', '5240045', '滋賀県', 'シガケン', '守山市', 'モリヤマシ', '金森町', 'カネガモリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県守山市今宿', '25', '25207', '5240046', '滋賀県', 'シガケン', '守山市', 'モリヤマシ', '今宿', 'イマジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県守山市今宿町', '25', '25207', '5240046', '滋賀県', 'シガケン', '守山市', 'モリヤマシ', '今宿町', 'イマジュクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県守山市三宅町', '25', '25207', '5240051', '滋賀県', 'シガケン', '守山市', 'モリヤマシ', '三宅町', 'ミヤケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県守山市大門町', '25', '25207', '5240052', '滋賀県', 'シガケン', '守山市', 'モリヤマシ', '大門町', 'ダイモンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県守山市横江町', '25', '25207', '5240053', '滋賀県', 'シガケン', '守山市', 'モリヤマシ', '横江町', 'ヨコエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県守山市大林町', '25', '25207', '5240054', '滋賀県', 'シガケン', '守山市', 'モリヤマシ', '大林町', 'オオバヤシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県守山市十二里町', '25', '25207', '5240055', '滋賀県', 'シガケン', '守山市', 'モリヤマシ', '十二里町', 'ジュウニリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県守山市赤野井町', '25', '25207', '5240061', '滋賀県', 'シガケン', '守山市', 'モリヤマシ', '赤野井町', 'アカノイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県守山市杉江町', '25', '25207', '5240062', '滋賀県', 'シガケン', '守山市', 'モリヤマシ', '杉江町', 'スギエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県守山市欲賀町', '25', '25207', '5240063', '滋賀県', 'シガケン', '守山市', 'モリヤマシ', '欲賀町', 'ホシカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県守山市森川原町', '25', '25207', '5240064', '滋賀県', 'シガケン', '守山市', 'モリヤマシ', '森川原町', 'モリカワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県守山市山賀町', '25', '25207', '5240065', '滋賀県', 'シガケン', '守山市', 'モリヤマシ', '山賀町', 'ヤマガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県守山市今浜町', '25', '25207', '5240101', '滋賀県', 'シガケン', '守山市', 'モリヤマシ', '今浜町', 'イマハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県守山市水保町', '25', '25207', '5240102', '滋賀県', 'シガケン', '守山市', 'モリヤマシ', '水保町', 'ミズホチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県守山市洲本町', '25', '25207', '5240103', '滋賀県', 'シガケン', '守山市', 'モリヤマシ', '洲本町', 'スモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県守山市木浜町', '25', '25207', '5240104', '滋賀県', 'シガケン', '守山市', 'モリヤマシ', '木浜町', 'コノハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県野洲市吉川', '25', '25210', '5240201', '滋賀県', 'シガケン', '野洲市', 'ヤスシ', '吉川', 'ヨシカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県野洲市菖蒲', '25', '25210', '5240202', '滋賀県', 'シガケン', '野洲市', 'ヤスシ', '菖蒲', 'アヤメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県野洲市喜合', '25', '25210', '5240203', '滋賀県', 'シガケン', '野洲市', 'ヤスシ', '喜合', 'キゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県守山市小浜町', '25', '25207', '5240211', '滋賀県', 'シガケン', '守山市', 'モリヤマシ', '小浜町', 'コバマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県守山市服部町', '25', '25207', '5240212', '滋賀県', 'シガケン', '守山市', 'モリヤマシ', '服部町', 'ハットリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県守山市新庄町', '25', '25207', '5240213', '滋賀県', 'シガケン', '守山市', 'モリヤマシ', '新庄町', 'シンジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県守山市立田町', '25', '25207', '5240214', '滋賀県', 'シガケン', '守山市', 'モリヤマシ', '立田町', 'タツタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県守山市幸津川町', '25', '25207', '5240215', '滋賀県', 'シガケン', '守山市', 'モリヤマシ', '幸津川町', 'サヅカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県草津市', '25', '25206', '5250000', '滋賀県', 'シガケン', '草津市', 'クサツシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('58555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県草津市下物町', '25', '25206', '5250001', '滋賀県', 'シガケン', '草津市', 'クサツシ', '下物町', 'オロシモチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県草津市芦浦町', '25', '25206', '5250002', '滋賀県', 'シガケン', '草津市', 'クサツシ', '芦浦町', 'アシウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県草津市長束町', '25', '25206', '5250003', '滋賀県', 'シガケン', '草津市', 'クサツシ', '長束町', 'ナツカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県草津市上寺町', '25', '25206', '5250004', '滋賀県', 'シガケン', '草津市', 'クサツシ', '上寺町', 'カミデラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県草津市志那町', '25', '25206', '5250005', '滋賀県', 'シガケン', '草津市', 'クサツシ', '志那町', 'シナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県草津市志那中町', '25', '25206', '5250006', '滋賀県', 'シガケン', '草津市', 'クサツシ', '志那中町', 'シナナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県草津市下寺町', '25', '25206', '5250007', '滋賀県', 'シガケン', '草津市', 'クサツシ', '下寺町', 'シモデラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県草津市片岡町', '25', '25206', '5250011', '滋賀県', 'シガケン', '草津市', 'クサツシ', '片岡町', 'カタオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県草津市穴村町', '25', '25206', '5250012', '滋賀県', 'シガケン', '草津市', 'クサツシ', '穴村町', 'アナムラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県草津市新堂町', '25', '25206', '5250013', '滋賀県', 'シガケン', '草津市', 'クサツシ', '新堂町', 'シンドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県草津市駒井沢町', '25', '25206', '5250014', '滋賀県', 'シガケン', '草津市', 'クサツシ', '駒井沢町', 'コマイザワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県草津市集町', '25', '25206', '5250015', '滋賀県', 'シガケン', '草津市', 'クサツシ', '集町', 'アツマリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県草津市北大萱町', '25', '25206', '5250016', '滋賀県', 'シガケン', '草津市', 'クサツシ', '北大萱町', 'キタオオガヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県草津市川原', '25', '25206', '5250021', '滋賀県', 'シガケン', '草津市', 'クサツシ', '川原', 'カワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県草津市川原町', '25', '25206', '5250022', '滋賀県', 'シガケン', '草津市', 'クサツシ', '川原町', 'カワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県草津市平井', '25', '25206', '5250023', '滋賀県', 'シガケン', '草津市', 'クサツシ', '平井', 'ヒライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県草津市平井町', '25', '25206', '5250024', '滋賀県', 'シガケン', '草津市', 'クサツシ', '平井町', 'ヒライチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県草津市西渋川', '25', '25206', '5250025', '滋賀県', 'シガケン', '草津市', 'クサツシ', '西渋川', 'ニシシブカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県草津市渋川', '25', '25206', '5250026', '滋賀県', 'シガケン', '草津市', 'クサツシ', '渋川', 'シブカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県草津市野村', '25', '25206', '5250027', '滋賀県', 'シガケン', '草津市', 'クサツシ', '野村', 'ノムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県草津市上笠', '25', '25206', '5250028', '滋賀県', 'シガケン', '草津市', 'クサツシ', '上笠', 'カミガサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県草津市下笠町', '25', '25206', '5250029', '滋賀県', 'シガケン', '草津市', 'クサツシ', '下笠町', 'シモガサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県草津市若竹町', '25', '25206', '5250031', '滋賀県', 'シガケン', '草津市', 'クサツシ', '若竹町', 'ワカタケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県草津市大路', '25', '25206', '5250032', '滋賀県', 'シガケン', '草津市', 'クサツシ', '大路', 'オオジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県草津市東草津', '25', '25206', '5250033', '滋賀県', 'シガケン', '草津市', 'クサツシ', '東草津', 'ヒガシクサツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県草津市草津', '25', '25206', '5250034', '滋賀県', 'シガケン', '草津市', 'クサツシ', '草津', 'クサツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県草津市西草津', '25', '25206', '5250035', '滋賀県', 'シガケン', '草津市', 'クサツシ', '西草津', 'ニシクサツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県草津市草津町', '25', '25206', '5250036', '滋賀県', 'シガケン', '草津市', 'クサツシ', '草津町', 'クサツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県草津市西大路町', '25', '25206', '5250037', '滋賀県', 'シガケン', '草津市', 'クサツシ', '西大路町', 'ニシオオジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県草津市青地町', '25', '25206', '5250041', '滋賀県', 'シガケン', '草津市', 'クサツシ', '青地町', 'アオジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県草津市山寺町', '25', '25206', '5250042', '滋賀県', 'シガケン', '草津市', 'クサツシ', '山寺町', 'ヤマデラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県草津市馬場町', '25', '25206', '5250043', '滋賀県', 'シガケン', '草津市', 'クサツシ', '馬場町', 'バンバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県草津市岡本町', '25', '25206', '5250044', '滋賀県', 'シガケン', '草津市', 'クサツシ', '岡本町', 'オカモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県草津市若草', '25', '25206', '5250045', '滋賀県', 'シガケン', '草津市', 'クサツシ', '若草', 'ワカクサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県草津市追分町', '25', '25206', '5250046', '滋賀県', 'シガケン', '草津市', 'クサツシ', '追分町', 'オイワケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県草津市木川町', '25', '25206', '5250051', '滋賀県', 'シガケン', '草津市', 'クサツシ', '木川町', 'キノカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県草津市西矢倉', '25', '25206', '5250052', '滋賀県', 'シガケン', '草津市', 'クサツシ', '西矢倉', 'ニシヤグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県草津市矢倉', '25', '25206', '5250053', '滋賀県', 'シガケン', '草津市', 'クサツシ', '矢倉', 'ヤグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県草津市東矢倉', '25', '25206', '5250054', '滋賀県', 'シガケン', '草津市', 'クサツシ', '東矢倉', 'ヒガシヤグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県草津市野路町', '25', '25206', '5250055', '滋賀県', 'シガケン', '草津市', 'クサツシ', '野路町', 'ノジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県草津市南笠町', '25', '25206', '5250056', '滋賀県', 'シガケン', '草津市', 'クサツシ', '南笠町', 'ミナミガサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県草津市桜ケ丘', '25', '25206', '5250057', '滋賀県', 'シガケン', '草津市', 'クサツシ', '桜ケ丘', 'サクラガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県草津市野路東', '25', '25206', '5250058', '滋賀県', 'シガケン', '草津市', 'クサツシ', '野路東', 'ノジヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県草津市野路', '25', '25206', '5250059', '滋賀県', 'シガケン', '草津市', 'クサツシ', '野路', 'ノジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県草津市北山田町', '25', '25206', '5250061', '滋賀県', 'シガケン', '草津市', 'クサツシ', '北山田町', 'キタヤマダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県草津市山田町', '25', '25206', '5250062', '滋賀県', 'シガケン', '草津市', 'クサツシ', '山田町', 'ヤマダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県草津市南山田町', '25', '25206', '5250063', '滋賀県', 'シガケン', '草津市', 'クサツシ', '南山田町', 'ミナミヤマダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県草津市御倉町', '25', '25206', '5250064', '滋賀県', 'シガケン', '草津市', 'クサツシ', '御倉町', 'ミクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県草津市橋岡町', '25', '25206', '5250065', '滋賀県', 'シガケン', '草津市', 'クサツシ', '橋岡町', 'ハシオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県草津市矢橋町', '25', '25206', '5250066', '滋賀県', 'シガケン', '草津市', 'クサツシ', '矢橋町', 'ヤバセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県草津市新浜町', '25', '25206', '5250067', '滋賀県', 'シガケン', '草津市', 'クサツシ', '新浜町', 'シンハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県草津市南笠東', '25', '25206', '5250071', '滋賀県', 'シガケン', '草津市', 'クサツシ', '南笠東', 'ミナミガサヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県草津市笠山', '25', '25206', '5250072', '滋賀県', 'シガケン', '草津市', 'クサツシ', '笠山', 'カサヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市', '25', '25203', '5260000', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('58625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市国友町', '25', '25203', '5260001', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '国友町', 'クニトモチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市保田町', '25', '25203', '5260002', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '保田町', 'ホウデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市泉町', '25', '25203', '5260003', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '泉町', 'イズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市小沢町', '25', '25203', '5260004', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '小沢町', 'コザワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市下之郷町', '25', '25203', '5260005', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '下之郷町', 'シモノゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市新庄馬場町', '25', '25203', '5260011', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '新庄馬場町', 'シンジョウバンバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市新庄中町', '25', '25203', '5260012', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '新庄中町', 'シンジョウナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市新庄寺町', '25', '25203', '5260013', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '新庄寺町', 'シンジョウテラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市口分田町', '25', '25203', '5260014', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '口分田町', 'クモデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市神照町', '25', '25203', '5260015', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '神照町', 'カミテルチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市十里町', '25', '25203', '5260016', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '十里町', 'ジュウリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市相撲町', '25', '25203', '5260017', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '相撲町', 'スマイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市森町', '25', '25203', '5260018', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '森町', 'モリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市八幡中山町', '25', '25203', '5260021', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '八幡中山町', 'ヤワタナカヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市中山町', '25', '25203', '5260022', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '中山町', 'ナカヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市三ツ矢町', '25', '25203', '5260023', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '三ツ矢町', 'ミツヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市三ツ矢元町', '25', '25203', '5260024', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '三ツ矢元町', 'ミツヤモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市分木町', '25', '25203', '5260025', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '分木町', 'ブンギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市八幡東町', '25', '25203', '5260031', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '八幡東町', 'ヤワタヒガシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市南高田町', '25', '25203', '5260032', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '南高田町', 'ミナミタカダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市平方町', '25', '25203', '5260033', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '平方町', 'ヒラカタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市弥高町', '25', '25203', '5260034', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '弥高町', 'ヤタカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市平方南町', '25', '25203', '5260035', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '平方南町', 'ヒラカタミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市地福寺町', '25', '25203', '5260036', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '地福寺町', 'ジフクジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市高田町', '25', '25203', '5260037', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '高田町', 'タカダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市四ツ塚町', '25', '25203', '5260041', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '四ツ塚町', 'ヨツヅカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市勝町', '25', '25203', '5260042', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '勝町', 'カツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市大戌亥町', '25', '25203', '5260043', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '大戌亥町', 'オオイヌイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市下坂中町', '25', '25203', '5260044', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '下坂中町', 'シモサカナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市寺田町', '25', '25203', '5260045', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '寺田町', 'テラダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市高橋町', '25', '25203', '5260046', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '高橋町', 'タカハシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市下坂浜町', '25', '25203', '5260047', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '下坂浜町', 'シモサカハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市一の宮町', '25', '25203', '5260051', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '一の宮町', 'イチノミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市神前町', '25', '25203', '5260052', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '神前町', 'シンゼンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市宮前町', '25', '25203', '5260053', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '宮前町', 'ミヤマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市大宮町', '25', '25203', '5260054', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '大宮町', 'オオミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市三和町', '25', '25203', '5260055', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '三和町', 'サンワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市朝日町', '25', '25203', '5260056', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '朝日町', 'アサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市北船町', '25', '25203', '5260057', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '北船町', 'キタフナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市南呉服町', '25', '25203', '5260058', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '南呉服町', 'ミナミゴフクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市元浜町', '25', '25203', '5260059', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '元浜町', 'モトハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市祇園町', '25', '25203', '5260061', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '祇園町', 'ギオンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市列見町', '25', '25203', '5260062', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '列見町', 'レツケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市末広町', '25', '25203', '5260063', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '末広町', 'スエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市殿町', '25', '25203', '5260064', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '殿町', 'トノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市公園町', '25', '25203', '5260065', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '公園町', 'コウエンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市大島町', '25', '25203', '5260066', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '大島町', 'オオシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市港町', '25', '25203', '5260067', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '港町', 'ミナトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市鐘紡町', '25', '25203', '5260068', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '鐘紡町', 'カネボウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市錦織町', '25', '25203', '5260101', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '錦織町', 'ニシコオリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市落合町', '25', '25203', '5260102', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '落合町', 'オチアイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市曽根町', '25', '25203', '5260103', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '曽根町', 'ソネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市御館', '25', '25203', '5260104', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '御館', 'ミタチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市細江町', '25', '25203', '5260105', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '細江町', 'ホソエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市野寺町', '25', '25203', '5260106', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '野寺町', 'ノデラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市新居町', '25', '25203', '5260107', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '新居町', 'ニノイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市難波町', '25', '25203', '5260108', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '難波町', 'ナンバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市川道町', '25', '25203', '5260111', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '川道町', 'カワミチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市鶴が島', '25', '25203', '5260112', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '鶴が島', 'ツルガシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市南浜町', '25', '25203', '5260113', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '南浜町', 'ミナミハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市中浜', '25', '25203', '5260114', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '中浜', 'ナカハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市大浜町', '25', '25203', '5260115', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '大浜町', 'オオハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市八木浜町', '25', '25203', '5260116', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '八木浜町', 'ヤギハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市十九町', '25', '25203', '5260121', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '十九町', 'ジュックチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市上八木町', '25', '25203', '5260122', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '上八木町', 'カミヤギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市下八木町', '25', '25203', '5260123', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '下八木町', 'シモヤギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市早崎町', '25', '25203', '5260124', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '早崎町', 'ハヤザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市益田町', '25', '25203', '5260125', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '益田町', 'マスダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市安養寺町', '25', '25203', '5260126', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '安養寺町', 'アンヨウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市富田町', '25', '25203', '5260131', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '富田町', 'トンダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市香花寺町', '25', '25203', '5260132', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '香花寺町', 'コウケイジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市稲葉町', '25', '25203', '5260133', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '稲葉町', 'イナバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市小観音寺町', '25', '25203', '5260134', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '小観音寺町', 'コカンノンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市弓削町', '25', '25203', '5260135', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '弓削町', 'ユウゲチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市高山町', '25', '25203', '5260201', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '高山町', 'タカヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市草野町', '25', '25203', '5260202', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '草野町', 'クサノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市野瀬町', '25', '25203', '5260203', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '野瀬町', 'ノセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市鍛冶屋町', '25', '25203', '5260204', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '鍛冶屋町', 'カジヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市岡谷町', '25', '25203', '5260205', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '岡谷町', 'オカダニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市郷野町', '25', '25203', '5260206', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '郷野町', 'ゴウノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市太田町', '25', '25203', '5260207', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '太田町', 'オオタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市西村町', '25', '25203', '5260208', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '西村町', 'ニシムラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市寺師町', '25', '25203', '5260209', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '寺師町', 'テラシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市飯山町', '25', '25203', '5260211', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '飯山町', 'イヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市徳山町', '25', '25203', '5260212', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '徳山町', 'トクヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市醍醐町', '25', '25203', '5260213', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '醍醐町', 'ダイゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市北ノ郷町', '25', '25203', '5260214', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '北ノ郷町', 'キタノゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市当目町', '25', '25203', '5260215', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '当目町', 'トウメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市大門町', '25', '25203', '5260216', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '大門町', 'ダイモンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市乗倉町', '25', '25203', '5260217', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '乗倉町', 'ノセクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市小野寺町', '25', '25203', '5260221', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '小野寺町', 'オノデラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市浅井高原', '25', '25203', '5260222', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '浅井高原', 'アザイコウゲン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市法楽寺町', '25', '25203', '5260223', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '法楽寺町', 'ホウラクジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市東野町', '25', '25203', '5260224', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '東野町', 'ヒガシノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市南郷町', '25', '25203', '5260225', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '南郷町', 'ナンゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市東主計町', '25', '25203', '5260226', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '東主計町', 'ヒガシカズエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市西主計町', '25', '25203', '5260227', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '西主計町', 'ニシカズエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市北池町', '25', '25203', '5260231', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '北池町', 'キタイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市南池町', '25', '25203', '5260232', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '南池町', 'ミナミイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市今荘町', '25', '25203', '5260233', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '今荘町', 'イマジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市相撲庭町', '25', '25203', '5260234', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '相撲庭町', 'スマイニワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市佐野町', '25', '25203', '5260235', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '佐野町', 'サノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市野村町', '25', '25203', '5260236', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '野村町', 'ノムラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市新三田', '25', '25203', '5260241', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '新三田', 'シンミタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市三田町', '25', '25203', '5260242', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '三田町', 'ミタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市大路町', '25', '25203', '5260243', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '大路町', 'オチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市内保町', '25', '25203', '5260244', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '内保町', 'ウチボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市湯次町', '25', '25203', '5260245', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '湯次町', 'ユスキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市西新三田', '25', '25203', '5260246', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '西新三田', 'ニシシンミタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市大依町', '25', '25203', '5260251', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '大依町', 'オオヨリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市八島町', '25', '25203', '5260252', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '八島町', 'ヤシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市平塚町', '25', '25203', '5260253', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '平塚町', 'ヒラツカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市尊野町', '25', '25203', '5260254', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '尊野町', 'ソンノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市西野町', '25', '25203', '5260255', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '西野町', 'ニシノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市尊勝寺町', '25', '25203', '5260256', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '尊勝寺町', 'ソンショウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市山ノ前町', '25', '25203', '5260257', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '山ノ前町', 'ヤマノマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市竜安寺町', '25', '25203', '5260261', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '竜安寺町', 'リュウアンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市黒部町', '25', '25203', '5260262', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '黒部町', 'クロベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市小室町', '25', '25203', '5260263', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '小室町', 'コムロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市上野町', '25', '25203', '5260264', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '上野町', 'ウワノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市木尾町', '25', '25203', '5260265', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '木尾町', 'キオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市野田町', '25', '25203', '5260266', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '野田町', 'ノダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市力丸町', '25', '25203', '5260267', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '力丸町', 'リキマルチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市谷口町', '25', '25203', '5260271', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '谷口町', 'タニグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市北野町', '25', '25203', '5260272', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '北野町', 'キタノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市高畑町', '25', '25203', '5260273', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '高畑町', 'タカハタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市池奥町', '25', '25203', '5260274', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '池奥町', 'イケオクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市瓜生町', '25', '25203', '5260275', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '瓜生町', 'ウリュウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市田川町', '25', '25203', '5260276', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '田川町', 'タガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市須賀谷町', '25', '25203', '5260277', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '須賀谷町', 'スガタニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市千草町', '25', '25203', '5260801', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '千草町', 'チクサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市東上坂町', '25', '25203', '5260802', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '東上坂町', 'ヒガシコウザカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市西上坂町', '25', '25203', '5260803', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '西上坂町', 'ニシコウザカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市加納町', '25', '25203', '5260804', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '加納町', 'カノウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市榎木町', '25', '25203', '5260805', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '榎木町', 'エノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市今町', '25', '25203', '5260806', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '今町', 'イマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市垣籠町', '25', '25203', '5260811', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '垣籠町', 'カイゴメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市保多町', '25', '25203', '5260812', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '保多町', 'ホダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市堀部町', '25', '25203', '5260813', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '堀部町', 'ホリベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市石田町', '25', '25203', '5260814', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '石田町', 'イシダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市八条町', '25', '25203', '5260815', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '八条町', 'ハチジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市今川町', '25', '25203', '5260816', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '今川町', 'イマガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市七条町', '25', '25203', '5260817', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '七条町', 'シチジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市本庄町', '25', '25203', '5260821', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '本庄町', 'ホンジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市鳥羽上町', '25', '25203', '5260822', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '鳥羽上町', 'トバカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市常喜町', '25', '25203', '5260823', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '常喜町', 'ジョウギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市名越町', '25', '25203', '5260824', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '名越町', 'ナゴシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市布勢町', '25', '25203', '5260825', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '布勢町', 'フセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市小一条町', '25', '25203', '5260826', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '小一条町', 'コイチジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市加田今町', '25', '25203', '5260827', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '加田今町', 'カダイマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市加田町', '25', '25203', '5260828', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '加田町', 'カダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市田村町', '25', '25203', '5260829', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '田村町', 'タムラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市宮司町', '25', '25203', '5260831', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '宮司町', 'ミヤシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市大東町', '25', '25203', '5260832', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '大東町', 'オオヒガシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市永久寺町', '25', '25203', '5260833', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '永久寺町', 'エイキュウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市大辰巳町', '25', '25203', '5260834', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '大辰巳町', 'オオタツミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市室町', '25', '25203', '5260835', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '室町', 'ムロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市新栄町', '25', '25203', '5260841', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '新栄町', 'ニイサカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市春近町', '25', '25203', '5260842', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '春近町', 'ハルチカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市南小足町', '25', '25203', '5260843', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '南小足町', 'ミナミコアシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市南田附町', '25', '25203', '5260844', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '南田附町', 'ミナミタヅケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市小堀町', '25', '25203', '5260845', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '小堀町', 'コボリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市川崎町', '25', '25203', '5260846', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '川崎町', 'カワサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県長浜市山階町', '25', '25203', '5260847', '滋賀県', 'シガケン', '長浜市', 'ナガハマシ', '山階町', 'ヤマシナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市', '25', '25213', '5270000', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('58799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市建部下野町', '25', '25213', '5270001', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '建部下野町', 'タテベシモノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市建部上中町', '25', '25213', '5270002', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '建部上中町', 'タテベカミナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市建部北町', '25', '25213', '5270003', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '建部北町', 'タテベキタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市建部堺町', '25', '25213', '5270004', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '建部堺町', 'タテベサカイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市建部南町', '25', '25213', '5270005', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '建部南町', 'タテベミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市建部日吉町', '25', '25213', '5270006', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '建部日吉町', 'タテベヒヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市建部瓦屋寺町', '25', '25213', '5270007', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '建部瓦屋寺町', 'タテベカワラヤジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市八日市浜野町', '25', '25213', '5270011', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '八日市浜野町', 'ヨウカイチハマノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市八日市本町', '25', '25213', '5270012', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '八日市本町', 'ヨウカイチホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市東中野町', '25', '25213', '5270013', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '東中野町', 'ヒガシナカノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市西中野町', '25', '25213', '5270014', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '西中野町', 'ニシナカノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市中野町', '25', '25213', '5270015', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '中野町', 'ナカノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市今崎町', '25', '25213', '5270016', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '今崎町', 'イマサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市昭和町', '25', '25213', '5270017', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '昭和町', 'ショウワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市八日市清水', '25', '25213', '5270018', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '八日市清水', 'ヨウカイチシミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市八日市松尾町', '25', '25213', '5270019', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '八日市松尾町', 'ヨウカイチマツオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市八日市東浜町', '25', '25213', '5270021', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '八日市東浜町', 'ヨウカイチヒガシハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市八日市上之町', '25', '25213', '5270022', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '八日市上之町', 'ヨウカイチカミノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市八日市緑町', '25', '25213', '5270023', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '八日市緑町', 'ヨウカイチミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市札の辻', '25', '25213', '5270024', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '札の辻', 'フダノツジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市八日市東本町', '25', '25213', '5270025', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '八日市東本町', 'ヨウカイチヒガシホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市八日市野々宮町', '25', '25213', '5270026', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '八日市野々宮町', 'ヨウカイチノノミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市栄町', '25', '25213', '5270027', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市八日市金屋', '25', '25213', '5270028', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '八日市金屋', 'ヨウカイチカナヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市八日市町', '25', '25213', '5270029', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '八日市町', 'ヨウカイチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市幸町', '25', '25213', '5270031', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市春日町', '25', '25213', '5270032', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '春日町', 'カスガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市東沖野', '25', '25213', '5270033', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '東沖野', 'ヒガシオキノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市沖野', '25', '25213', '5270034', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '沖野', 'オキノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市ひばり丘町', '25', '25213', '5270035', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', 'ひばり丘町', 'ヒバリオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市聖和町', '25', '25213', '5270036', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '聖和町', 'セイワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市東今崎町', '25', '25213', '5270037', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '東今崎町', 'ヒガシイマサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市聖徳町', '25', '25213', '5270038', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '聖徳町', 'セイトクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市青葉町', '25', '25213', '5270039', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '青葉町', 'アオバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市川合寺町', '25', '25213', '5270041', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '川合寺町', 'カワイデラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市外町', '25', '25213', '5270042', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '外町', 'トノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市神田町', '25', '25213', '5270043', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '神田町', 'ジンデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市五智町', '25', '25213', '5270044', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '五智町', 'ゴチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市中小路町', '25', '25213', '5270045', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '中小路町', 'ナコオジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市妙法寺町', '25', '25213', '5270046', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '妙法寺町', 'ミョウホウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市野村町', '25', '25213', '5270047', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '野村町', 'ノムラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市林田町', '25', '25213', '5270051', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '林田町', 'ハヤシダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市寺町', '25', '25213', '5270052', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '寺町', 'テラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市今代町', '25', '25213', '5270053', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '今代町', 'イマダイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市池田町', '25', '25213', '5270054', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '池田町', 'イケダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市瓜生津町', '25', '25213', '5270055', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '瓜生津町', 'ウリウヅチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市御園町', '25', '25213', '5270056', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '御園町', 'ミソノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市岡田町', '25', '25213', '5270057', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '岡田町', 'オカダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市土器町', '25', '25213', '5270061', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '土器町', 'ドキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市上大森町', '25', '25213', '5270062', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '上大森町', 'カミオオモリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市大森町', '25', '25213', '5270063', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '大森町', 'オオモリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市尻無町', '25', '25213', '5270064', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '尻無町', 'シナシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市下二俣町', '25', '25213', '5270065', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '下二俣町', 'シモフタマタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市柴原南町', '25', '25213', '5270066', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '柴原南町', 'シバハラミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市芝原町', '25', '25213', '5270067', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '芝原町', 'シバハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市今堀町', '25', '25213', '5270071', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '今堀町', 'イマボリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市布引台', '25', '25213', '5270072', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '布引台', 'ヌノビキダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市蛇溝町', '25', '25213', '5270073', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '蛇溝町', 'ヘビミゾチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市市辺町', '25', '25213', '5270074', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '市辺町', 'イチノベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市三津屋町', '25', '25213', '5270075', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '三津屋町', 'ミツヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市野口町', '25', '25213', '5270076', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '野口町', 'ノグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市布施町', '25', '25213', '5270081', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '布施町', 'フセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市上羽田町', '25', '25213', '5270082', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '上羽田町', 'カミハネダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市柏木町', '25', '25213', '5270083', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '柏木町', 'カシワギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市中羽田町', '25', '25213', '5270084', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '中羽田町', 'ナカハネダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市下羽田町', '25', '25213', '5270085', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '下羽田町', 'シモハネダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市上平木町', '25', '25213', '5270086', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '上平木町', 'カミヒラギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市平田町', '25', '25213', '5270087', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '平田町', 'ヒラタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市小脇町', '25', '25213', '5270091', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '小脇町', 'オワキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市小今町', '25', '25213', '5270092', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '小今町', 'コイマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市糠塚町', '25', '25213', '5270093', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '糠塚町', 'ヌカヅカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市祇園町', '25', '25213', '5270101', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '祇園町', 'ギオンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市平柳町', '25', '25213', '5270102', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '平柳町', 'ヒラヤナギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市湯屋町', '25', '25213', '5270103', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '湯屋町', 'ユヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市読合堂町', '25', '25213', '5270104', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '読合堂町', 'ヨミアイドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市中里町', '25', '25213', '5270105', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '中里町', 'ナカザトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市僧坊町', '25', '25213', '5270106', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '僧坊町', 'ソウボウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市今在家町', '25', '25213', '5270107', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '今在家町', 'イマザイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市小八木町', '25', '25213', '5270108', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '小八木町', 'コヤギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市北花沢町', '25', '25213', '5270111', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '北花沢町', 'キタハナザワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市南花沢町', '25', '25213', '5270112', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '南花沢町', 'ミナミハナザワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市池庄町', '25', '25213', '5270113', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '池庄町', 'イケショウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市大沢町', '25', '25213', '5270114', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '大沢町', 'オオザワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市下里町', '25', '25213', '5270115', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '下里町', 'シモザトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市小池町', '25', '25213', '5270121', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '小池町', 'コイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市長町', '25', '25213', '5270122', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '長町', 'オサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市中岸本町', '25', '25213', '5270123', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '中岸本町', 'ナカギシモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市下岸本町', '25', '25213', '5270124', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '下岸本町', 'シモギシモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市小田苅町', '25', '25213', '5270125', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '小田苅町', 'コタカリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市大清水町', '25', '25213', '5270126', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '大清水町', 'オオシュウズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市南清水町', '25', '25213', '5270127', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '南清水町', 'ミナミシュウズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市清水中町', '25', '25213', '5270128', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '清水中町', 'シュウズナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市北清水町', '25', '25213', '5270129', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '北清水町', 'キタシュウズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市勝堂町', '25', '25213', '5270131', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '勝堂町', 'ショウドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市下一色町', '25', '25213', '5270132', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '下一色町', 'シモイシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市中一色町', '25', '25213', '5270133', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '中一色町', 'ナカイシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市平松町', '25', '25213', '5270134', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '平松町', 'ヒラマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市横溝町', '25', '25213', '5270135', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '横溝町', 'ヨコミゾチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市南菩提寺町', '25', '25213', '5270136', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '南菩提寺町', 'ミナミボダイジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市西菩提寺町', '25', '25213', '5270137', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '西菩提寺町', 'ニシボダイジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市北菩提寺町', '25', '25213', '5270138', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '北菩提寺町', 'キタボダイジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市百済寺甲町', '25', '25213', '5270141', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '百済寺甲町', 'ヒャクサイジコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市上山町', '25', '25213', '5270142', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '上山町', 'カミヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市百済寺本町', '25', '25213', '5270143', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '百済寺本町', 'ヒャクサイジホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市百済寺町', '25', '25213', '5270144', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '百済寺町', 'ヒャクサイジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市北坂町', '25', '25213', '5270145', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '北坂町', 'キタサカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市市ケ原町', '25', '25213', '5270151', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '市ケ原町', 'イチガハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市大覚寺町', '25', '25213', '5270152', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '大覚寺町', 'ダイカクジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市平尾町', '25', '25213', '5270153', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '平尾町', 'ヒラオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市園町', '25', '25213', '5270154', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '園町', 'ソノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市大林町', '25', '25213', '5270155', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '大林町', 'オオバヤシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市上中野町', '25', '25213', '5270156', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '上中野町', 'ウエナカノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市下中野町', '25', '25213', '5270157', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '下中野町', 'シモナカノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市中戸町', '25', '25213', '5270161', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '中戸町', 'ナカトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市妹町', '25', '25213', '5270162', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '妹町', 'イモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市曽根町', '25', '25213', '5270163', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '曽根町', 'ソネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市青山町', '25', '25213', '5270164', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '青山町', 'アオヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市小倉町', '25', '25213', '5270165', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '小倉町', 'オグラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市愛東外町', '25', '25213', '5270166', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '愛東外町', 'アイトウトノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市池之尻町', '25', '25213', '5270171', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '池之尻町', 'イケノシリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市鯰江町', '25', '25213', '5270172', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '鯰江町', 'ナマズエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市上岸本町', '25', '25213', '5270173', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '上岸本町', 'カミギシモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市大萩町', '25', '25213', '5270174', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '大萩町', 'オオハギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市梅林町', '25', '25213', '5270175', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '梅林町', 'ウメバヤシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市蛭谷町', '25', '25213', '5270201', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '蛭谷町', 'ヒルタニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市君ケ畑町', '25', '25213', '5270202', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '君ケ畑町', 'キミガハタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市箕川町', '25', '25213', '5270203', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '箕川町', 'ミノガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市政所町', '25', '25213', '5270204', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '政所町', 'マンドコロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市黄和田町', '25', '25213', '5270205', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '黄和田町', 'キワダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市杠葉尾町', '25', '25213', '5270206', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '杠葉尾町', 'ユズリオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市蓼畑町', '25', '25213', '5270207', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '蓼畑町', 'タテハタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市萱尾町', '25', '25213', '5270208', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '萱尾町', 'カヤオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市佐目町', '25', '25213', '5270209', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '佐目町', 'サメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市永源寺相谷町', '25', '25213', '5270211', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '永源寺相谷町', 'エイゲンジアイダニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市永源寺高野町', '25', '25213', '5270212', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '永源寺高野町', 'エイゲンジタカノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市和南町', '25', '25213', '5270213', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '和南町', 'ワナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市甲津畑町', '25', '25213', '5270214', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '甲津畑町', 'コウヅハタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市九居瀬町', '25', '25213', '5270215', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '九居瀬町', 'クイゼチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市茨川町', '25', '25213', '5270216', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '茨川町', 'イバラガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市上二俣町', '25', '25213', '5270221', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '上二俣町', 'カミフタマタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市池之脇町', '25', '25213', '5270222', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '池之脇町', 'イケノワキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市高木町', '25', '25213', '5270223', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '高木町', 'タカギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市市原野町', '25', '25213', '5270224', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '市原野町', 'イチハラノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市新出町', '25', '25213', '5270225', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '新出町', 'シンデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市一式町', '25', '25213', '5270226', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '一式町', 'イッシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市石谷町', '25', '25213', '5270227', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '石谷町', 'イシダニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市如来町', '25', '25213', '5270228', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '如来町', 'ニョライチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市山上町', '25', '25213', '5270231', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '山上町', 'ヤマカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市青野町', '25', '25213', '5270232', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '青野町', 'アオノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市', '25', '25209', '5280000', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('58967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市水口町中畑', '25', '25209', '5280001', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '水口町中畑', 'ミナクチチョウナカハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市水口町今郷', '25', '25209', '5280002', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '水口町今郷', 'ミナクチチョウイマゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市水口町和野', '25', '25209', '5280003', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '水口町和野', 'ミナクチチョウワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市水口町嶬峨', '25', '25209', '5280004', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '水口町嶬峨', 'ミナクチチョウギカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市水口町水口', '25', '25209', '5280005', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '水口町水口', 'ミナクチチョウミナクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市水口町元町', '25', '25209', '5280006', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '水口町元町', 'ミナクチチョウモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市水口町新城', '25', '25209', '5280007', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '水口町新城', 'ミナクチチョウシンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市水口町高塚', '25', '25209', '5280011', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '水口町高塚', 'ミナクチチョウタカツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市水口町暁', '25', '25209', '5280012', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '水口町暁', 'ミナクチチョウアカツキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市水口町宮の前', '25', '25209', '5280013', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '水口町宮の前', 'ミナクチチョウミヤノマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市水口町鹿深', '25', '25209', '5280014', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '水口町鹿深', 'ミナクチチョウロクシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市水口町松栄', '25', '25209', '5280015', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '水口町松栄', 'ミナクチチョウショウエイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市水口町神明', '25', '25209', '5280016', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '水口町神明', 'ミナクチチョウシンメイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市水口町京町', '25', '25209', '5280017', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '水口町京町', 'ミナクチチョウキョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市水口町的場', '25', '25209', '5280020', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '水口町的場', 'ミナクチチョウマトバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市水口町八光', '25', '25209', '5280021', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '水口町八光', 'ミナクチチョウハッコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市水口町梅が丘', '25', '25209', '5280022', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '水口町梅が丘', 'ミナクチチョウウメガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市水口町本丸', '25', '25209', '5280023', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '水口町本丸', 'ミナクチチョウホンマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市水口町中邸', '25', '25209', '5280024', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '水口町中邸', 'ミナクチチョウナカヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市水口町西林口', '25', '25209', '5280025', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '水口町西林口', 'ミナクチチョウニシハヤシグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市水口町東林口', '25', '25209', '5280026', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '水口町東林口', 'ミナクチチョウヒガシハヤシグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市水口町城内', '25', '25209', '5280027', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '水口町城内', 'ミナクチチョウジョウナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市水口町城東', '25', '25209', '5280028', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '水口町城東', 'ミナクチチョウジョウトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市水口町南林口', '25', '25209', '5280029', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '水口町南林口', 'ミナクチチョウミナミハヤシグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市水口町本町', '25', '25209', '5280031', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '水口町本町', 'ミナクチチョウホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市水口町八坂', '25', '25209', '5280032', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '水口町八坂', 'ミナクチチョウヤサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市水口町綾野', '25', '25209', '5280033', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '水口町綾野', 'ミナクチチョウアヤノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市水口町日電', '25', '25209', '5280034', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '水口町日電', 'ミナクチチョウニチデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市水口町名坂', '25', '25209', '5280035', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '水口町名坂', 'ミナクチチョウナサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市水口町東名坂', '25', '25209', '5280036', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '水口町東名坂', 'ミナクチチョウヒガシナサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市水口町本綾野', '25', '25209', '5280037', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '水口町本綾野', 'ミナクチチョウモトアヤノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市水口町新町', '25', '25209', '5280038', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '水口町新町', 'ミナクチチョウシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('58999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市水口町虫生野', '25', '25209', '5280041', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '水口町虫生野', 'ミナクチチョウムショウノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市水口町虫生野中央', '25', '25209', '5280042', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '水口町虫生野中央', 'ミナクチチョウムショウノチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市水口町杣中', '25', '25209', '5280043', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '水口町杣中', 'ミナクチチョウソマナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市水口町山上', '25', '25209', '5280044', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '水口町山上', 'ミナクチチョウヤマガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市水口町牛飼', '25', '25209', '5280045', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '水口町牛飼', 'ミナクチチョウウシカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市水口町三大寺', '25', '25209', '5280046', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '水口町三大寺', 'ミナクチチョウサンダイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市水口町岩坂', '25', '25209', '5280047', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '水口町岩坂', 'ミナクチチョウイワサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市水口町高山', '25', '25209', '5280048', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '水口町高山', 'ミナクチチョウタカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市水口町貴生川', '25', '25209', '5280049', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '水口町貴生川', 'ミナクチチョウキブカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市水口町北内貴', '25', '25209', '5280051', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '水口町北内貴', 'ミナクチチョウキタナイキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市水口町宇川', '25', '25209', '5280052', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '水口町宇川', 'ミナクチチョウウカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市水口町宇田', '25', '25209', '5280053', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '水口町宇田', 'ミナクチチョウウツタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市水口町酒人', '25', '25209', '5280054', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '水口町酒人', 'ミナクチチョウサコウド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市水口町植', '25', '25209', '5280055', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '水口町植', 'ミナクチチョウウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市水口町泉', '25', '25209', '5280056', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '水口町泉', 'ミナクチチョウイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市水口町北脇', '25', '25209', '5280057', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '水口町北脇', 'ミナクチチョウキタワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市水口町北泉', '25', '25209', '5280058', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '水口町北泉', 'ミナクチチョウキタイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市水口町笹が丘', '25', '25209', '5280061', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '水口町笹が丘', 'ミナクチチョウササガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市水口町さつきが丘', '25', '25209', '5280062', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '水口町さつきが丘', 'ミナクチチョウサツキガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市水口町下山', '25', '25209', '5280063', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '水口町下山', 'ミナクチチョウシモヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市水口町伴中山', '25', '25209', '5280064', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '水口町伴中山', 'ミナクチチョウバンナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市水口町春日', '25', '25209', '5280065', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '水口町春日', 'ミナクチチョウカスガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市水口町八田', '25', '25209', '5280066', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '水口町八田', 'ミナクチチョウハッタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市水口町山', '25', '25209', '5280067', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '水口町山', 'ミナクチチョウヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市水口町ひのきが丘', '25', '25209', '5280068', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '水口町ひのきが丘', 'ミナクチチョウヒノキガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市水口町虫生野虹の町', '25', '25209', '5280069', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '水口町虫生野虹の町', 'ミナクチチョウムショウノニジノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市水口町秋葉', '25', '25209', '5280071', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '水口町秋葉', 'ミナクチチョウアキバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市水口町朝日が丘', '25', '25209', '5280072', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '水口町朝日が丘', 'ミナクチチョウアサヒガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市水口町古城が丘', '25', '25209', '5280073', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '水口町古城が丘', 'ミナクチチョウコジョウガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市水口町松尾', '25', '25209', '5280074', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '水口町松尾', 'ミナクチチョウマツオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市土山町大河原', '25', '25209', '5280201', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '土山町大河原', 'ツチヤマチョウオオカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市土山町鮎河', '25', '25209', '5280202', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '土山町鮎河', 'ツチヤマチョウアユカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市土山町黒滝', '25', '25209', '5280203', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '土山町黒滝', 'ツチヤマチョウクロタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市土山町山女原', '25', '25209', '5280204', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '土山町山女原', 'ツチヤマチョウアケビハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市土山町笹路', '25', '25209', '5280205', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '土山町笹路', 'ツチヤマチョウソソロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市土山町山中', '25', '25209', '5280206', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '土山町山中', 'ツチヤマチョウヤマナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市土山町猪鼻', '25', '25209', '5280207', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '土山町猪鼻', 'ツチヤマチョウイノハナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市土山町黒川', '25', '25209', '5280208', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '土山町黒川', 'ツチヤマチョウクロカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市土山町北土山', '25', '25209', '5280211', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '土山町北土山', 'ツチヤマチョウキタツチヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市土山町南土山', '25', '25209', '5280212', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '土山町南土山', 'ツチヤマチョウミナミツチヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市土山町大澤', '25', '25209', '5280213', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '土山町大澤', 'ツチヤマチョウオオザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市土山町青土', '25', '25209', '5280221', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '土山町青土', 'ツチヤマチョウオオヅチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市土山町平子', '25', '25209', '5280222', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '土山町平子', 'ツチヤマチョウヒラコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市土山町瀬ノ音', '25', '25209', '5280223', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '土山町瀬ノ音', 'ツチヤマチョウセノオト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市土山町野上野', '25', '25209', '5280224', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '土山町野上野', 'ツチヤマチョウノガミノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市土山町頓宮', '25', '25209', '5280231', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '土山町頓宮', 'ツチヤマチョウトングウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市土山町前野', '25', '25209', '5280232', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '土山町前野', 'ツチヤマチョウマエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市土山町市場', '25', '25209', '5280233', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '土山町市場', 'ツチヤマチョウイチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市土山町徳原', '25', '25209', '5280234', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '土山町徳原', 'ツチヤマチョウトクハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市土山町大野', '25', '25209', '5280235', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '土山町大野', 'ツチヤマチョウオオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東浅井郡虎姫町', '25', '25482', '5290100', '滋賀県', 'シガケン', '東浅井郡虎姫町', 'ヒガシアザイグントラヒメチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('59064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東浅井郡虎姫町唐国', '25', '25482', '5290101', '滋賀県', 'シガケン', '東浅井郡虎姫町', 'ヒガシアザイグントラヒメチョウ', '唐国', 'カラクニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東浅井郡虎姫町月ケ瀬', '25', '25482', '5290102', '滋賀県', 'シガケン', '東浅井郡虎姫町', 'ヒガシアザイグントラヒメチョウ', '月ケ瀬', 'ツキガセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東浅井郡虎姫町中野', '25', '25482', '5290103', '滋賀県', 'シガケン', '東浅井郡虎姫町', 'ヒガシアザイグントラヒメチョウ', '中野', 'ナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東浅井郡虎姫町三川', '25', '25482', '5290111', '滋賀県', 'シガケン', '東浅井郡虎姫町', 'ヒガシアザイグントラヒメチョウ', '三川', 'ミカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東浅井郡虎姫町宮部', '25', '25482', '5290112', '滋賀県', 'シガケン', '東浅井郡虎姫町', 'ヒガシアザイグントラヒメチョウ', '宮部', 'ミヤベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東浅井郡虎姫町大井', '25', '25482', '5290113', '滋賀県', 'シガケン', '東浅井郡虎姫町', 'ヒガシアザイグントラヒメチョウ', '大井', 'オオイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東浅井郡虎姫町五', '25', '25482', '5290121', '滋賀県', 'シガケン', '東浅井郡虎姫町', 'ヒガシアザイグントラヒメチョウ', '五', 'ゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東浅井郡虎姫町酢', '25', '25482', '5290122', '滋賀県', 'シガケン', '東浅井郡虎姫町', 'ヒガシアザイグントラヒメチョウ', '酢', 'ス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東浅井郡虎姫町西大井', '25', '25482', '5290123', '滋賀県', 'シガケン', '東浅井郡虎姫町', 'ヒガシアザイグントラヒメチョウ', '西大井', 'ニシオオイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東浅井郡虎姫町柿ノ木', '25', '25482', '5290131', '滋賀県', 'シガケン', '東浅井郡虎姫町', 'ヒガシアザイグントラヒメチョウ', '柿ノ木', 'カキノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東浅井郡虎姫町長田', '25', '25482', '5290132', '滋賀県', 'シガケン', '東浅井郡虎姫町', 'ヒガシアザイグントラヒメチョウ', '長田', 'ナガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東浅井郡虎姫町旭町', '25', '25482', '5290133', '滋賀県', 'シガケン', '東浅井郡虎姫町', 'ヒガシアザイグントラヒメチョウ', '旭町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東浅井郡虎姫町五村', '25', '25482', '5290141', '滋賀県', 'シガケン', '東浅井郡虎姫町', 'ヒガシアザイグントラヒメチョウ', '五村', 'ゴムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東浅井郡虎姫町田', '25', '25482', '5290142', '滋賀県', 'シガケン', '東浅井郡虎姫町', 'ヒガシアザイグントラヒメチョウ', '田', 'タ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東浅井郡虎姫町本町', '25', '25482', '5290143', '滋賀県', 'シガケン', '東浅井郡虎姫町', 'ヒガシアザイグントラヒメチョウ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東浅井郡虎姫町大寺', '25', '25482', '5290144', '滋賀県', 'シガケン', '東浅井郡虎姫町', 'ヒガシアザイグントラヒメチョウ', '大寺', 'ダイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県伊香郡高月町', '25', '25501', '5290200', '滋賀県', 'シガケン', '伊香郡高月町', 'イカグンタカツキチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('59081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県伊香郡高月町横山', '25', '25501', '5290201', '滋賀県', 'シガケン', '伊香郡高月町', 'イカグンタカツキチョウ', '横山', 'ヨコヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県伊香郡高月町東高田', '25', '25501', '5290202', '滋賀県', 'シガケン', '伊香郡高月町', 'イカグンタカツキチョウ', '東高田', 'ヒガシタカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県伊香郡高月町磯野', '25', '25501', '5290203', '滋賀県', 'シガケン', '伊香郡高月町', 'イカグンタカツキチョウ', '磯野', 'イソノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県伊香郡高月町布施', '25', '25501', '5290204', '滋賀県', 'シガケン', '伊香郡高月町', 'イカグンタカツキチョウ', '布施', 'フセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県伊香郡高月町唐川', '25', '25501', '5290205', '滋賀県', 'シガケン', '伊香郡高月町', 'イカグンタカツキチョウ', '唐川', 'カラカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県伊香郡高月町保延寺', '25', '25501', '5290211', '滋賀県', 'シガケン', '伊香郡高月町', 'イカグンタカツキチョウ', '保延寺', 'ホウエンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県伊香郡高月町井口', '25', '25501', '5290212', '滋賀県', 'シガケン', '伊香郡高月町', 'イカグンタカツキチョウ', '井口', 'イノクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県伊香郡高月町持寺', '25', '25501', '5290213', '滋賀県', 'シガケン', '伊香郡高月町', 'イカグンタカツキチョウ', '持寺', 'モチデラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県伊香郡高月町洞戸', '25', '25501', '5290214', '滋賀県', 'シガケン', '伊香郡高月町', 'イカグンタカツキチョウ', '洞戸', 'ホラド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県伊香郡高月町尾山', '25', '25501', '5290215', '滋賀県', 'シガケン', '伊香郡高月町', 'イカグンタカツキチョウ', '尾山', 'オヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県伊香郡高月町高野', '25', '25501', '5290221', '滋賀県', 'シガケン', '伊香郡高月町', 'イカグンタカツキチョウ', '高野', 'タカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県伊香郡高月町雨森', '25', '25501', '5290222', '滋賀県', 'シガケン', '伊香郡高月町', 'イカグンタカツキチョウ', '雨森', 'アメモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県伊香郡高月町馬上', '25', '25501', '5290223', '滋賀県', 'シガケン', '伊香郡高月町', 'イカグンタカツキチョウ', '馬上', 'マケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県伊香郡高月町森本', '25', '25501', '5290231', '滋賀県', 'シガケン', '伊香郡高月町', 'イカグンタカツキチョウ', '森本', 'モリモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県伊香郡高月町落川', '25', '25501', '5290232', '滋賀県', 'シガケン', '伊香郡高月町', 'イカグンタカツキチョウ', '落川', 'オチカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県伊香郡高月町渡岸寺', '25', '25501', '5290233', '滋賀県', 'シガケン', '伊香郡高月町', 'イカグンタカツキチョウ', '渡岸寺', 'ドウガンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県伊香郡高月町柏原', '25', '25501', '5290234', '滋賀県', 'シガケン', '伊香郡高月町', 'イカグンタカツキチョウ', '柏原', 'カシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県伊香郡高月町高月', '25', '25501', '5290241', '滋賀県', 'シガケン', '伊香郡高月町', 'イカグンタカツキチョウ', '高月', 'タカツキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県伊香郡高月町宇根', '25', '25501', '5290251', '滋賀県', 'シガケン', '伊香郡高月町', 'イカグンタカツキチョウ', '宇根', 'ウネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県伊香郡高月町東阿閉', '25', '25501', '5290252', '滋賀県', 'シガケン', '伊香郡高月町', 'イカグンタカツキチョウ', '東阿閉', 'ヒガシアツジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県伊香郡高月町西阿閉', '25', '25501', '5290253', '滋賀県', 'シガケン', '伊香郡高月町', 'イカグンタカツキチョウ', '西阿閉', 'ニシアツジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県伊香郡高月町東物部', '25', '25501', '5290261', '滋賀県', 'シガケン', '伊香郡高月町', 'イカグンタカツキチョウ', '東物部', 'ヒガシモノベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県伊香郡高月町西物部', '25', '25501', '5290262', '滋賀県', 'シガケン', '伊香郡高月町', 'イカグンタカツキチョウ', '西物部', 'ニシモノベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県伊香郡高月町東柳野', '25', '25501', '5290263', '滋賀県', 'シガケン', '伊香郡高月町', 'イカグンタカツキチョウ', '東柳野', 'ヒガシヤナギノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県伊香郡高月町柳野中', '25', '25501', '5290264', '滋賀県', 'シガケン', '伊香郡高月町', 'イカグンタカツキチョウ', '柳野中', 'ヤナギノナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県伊香郡高月町西柳野', '25', '25501', '5290265', '滋賀県', 'シガケン', '伊香郡高月町', 'イカグンタカツキチョウ', '西柳野', 'ニシヤナギノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県伊香郡高月町熊野', '25', '25501', '5290271', '滋賀県', 'シガケン', '伊香郡高月町', 'イカグンタカツキチョウ', '熊野', 'クマノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県伊香郡高月町片山', '25', '25501', '5290272', '滋賀県', 'シガケン', '伊香郡高月町', 'イカグンタカツキチョウ', '片山', 'カタヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県伊香郡高月町西野', '25', '25501', '5290273', '滋賀県', 'シガケン', '伊香郡高月町', 'イカグンタカツキチョウ', '西野', 'ニシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県伊香郡高月町松尾', '25', '25501', '5290274', '滋賀県', 'シガケン', '伊香郡高月町', 'イカグンタカツキチョウ', '松尾', 'マツオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県伊香郡高月町重則', '25', '25501', '5290275', '滋賀県', 'シガケン', '伊香郡高月町', 'イカグンタカツキチョウ', '重則', 'シゲノリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東浅井郡湖北町', '25', '25483', '5290300', '滋賀県', 'シガケン', '東浅井郡湖北町', 'ヒガシアザイグンコホクチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('59114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東浅井郡湖北町上山田', '25', '25483', '5290301', '滋賀県', 'シガケン', '東浅井郡湖北町', 'ヒガシアザイグンコホクチョウ', '上山田', 'カミヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東浅井郡湖北町下山田', '25', '25483', '5290302', '滋賀県', 'シガケン', '東浅井郡湖北町', 'ヒガシアザイグンコホクチョウ', '下山田', 'シモヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東浅井郡湖北町二俣', '25', '25483', '5290303', '滋賀県', 'シガケン', '東浅井郡湖北町', 'ヒガシアザイグンコホクチョウ', '二俣', 'フタマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東浅井郡湖北町丁野', '25', '25483', '5290304', '滋賀県', 'シガケン', '東浅井郡湖北町', 'ヒガシアザイグンコホクチョウ', '丁野', 'ヨウノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東浅井郡湖北町美濃山', '25', '25483', '5290311', '滋賀県', 'シガケン', '東浅井郡湖北町', 'ヒガシアザイグンコホクチョウ', '美濃山', 'ミノヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東浅井郡湖北町郡上', '25', '25483', '5290312', '滋賀県', 'シガケン', '東浅井郡湖北町', 'ヒガシアザイグンコホクチョウ', '郡上', 'グジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東浅井郡湖北町伊部', '25', '25483', '5290313', '滋賀県', 'シガケン', '東浅井郡湖北町', 'ヒガシアザイグンコホクチョウ', '伊部', 'イベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東浅井郡湖北町留目', '25', '25483', '5290314', '滋賀県', 'シガケン', '東浅井郡湖北町', 'ヒガシアザイグンコホクチョウ', '留目', 'トドメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東浅井郡湖北町別所', '25', '25483', '5290315', '滋賀県', 'シガケン', '東浅井郡湖北町', 'ヒガシアザイグンコホクチョウ', '別所', 'ベッシヨ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東浅井郡湖北町河毛', '25', '25483', '5290316', '滋賀県', 'シガケン', '東浅井郡湖北町', 'ヒガシアザイグンコホクチョウ', '河毛', 'カワケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東浅井郡湖北町山脇', '25', '25483', '5290317', '滋賀県', 'シガケン', '東浅井郡湖北町', 'ヒガシアザイグンコホクチョウ', '山脇', 'ヤマワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東浅井郡湖北町賀', '25', '25483', '5290321', '滋賀県', 'シガケン', '東浅井郡湖北町', 'ヒガシアザイグンコホクチョウ', '賀', 'カ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東浅井郡湖北町小今', '25', '25483', '5290322', '滋賀県', 'シガケン', '東浅井郡湖北町', 'ヒガシアザイグンコホクチョウ', '小今', 'コイマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東浅井郡湖北町八日市', '25', '25483', '5290331', '滋賀県', 'シガケン', '東浅井郡湖北町', 'ヒガシアザイグンコホクチョウ', '八日市', 'ヨウカイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東浅井郡湖北町青名', '25', '25483', '5290332', '滋賀県', 'シガケン', '東浅井郡湖北町', 'ヒガシアザイグンコホクチョウ', '青名', 'アオナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東浅井郡湖北町今', '25', '25483', '5290333', '滋賀県', 'シガケン', '東浅井郡湖北町', 'ヒガシアザイグンコホクチョウ', '今', 'イマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東浅井郡湖北町沢', '25', '25483', '5290334', '滋賀県', 'シガケン', '東浅井郡湖北町', 'ヒガシアザイグンコホクチョウ', '沢', 'サワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東浅井郡湖北町猫口', '25', '25483', '5290335', '滋賀県', 'シガケン', '東浅井郡湖北町', 'ヒガシアザイグンコホクチョウ', '猫口', 'ネコグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東浅井郡湖北町速水', '25', '25483', '5290341', '滋賀県', 'シガケン', '東浅井郡湖北町', 'ヒガシアザイグンコホクチョウ', '速水', 'ハヤミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東浅井郡湖北町高田', '25', '25483', '5290342', '滋賀県', 'シガケン', '東浅井郡湖北町', 'ヒガシアザイグンコホクチョウ', '高田', 'タカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東浅井郡湖北町小倉', '25', '25483', '5290343', '滋賀県', 'シガケン', '東浅井郡湖北町', 'ヒガシアザイグンコホクチョウ', '小倉', 'オグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東浅井郡湖北町馬渡', '25', '25483', '5290344', '滋賀県', 'シガケン', '東浅井郡湖北町', 'ヒガシアザイグンコホクチョウ', '馬渡', 'モウタリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東浅井郡湖北町大安寺', '25', '25483', '5290345', '滋賀県', 'シガケン', '東浅井郡湖北町', 'ヒガシアザイグンコホクチョウ', '大安寺', 'ダイアンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東浅井郡湖北町南速水', '25', '25483', '5290346', '滋賀県', 'シガケン', '東浅井郡湖北町', 'ヒガシアザイグンコホクチョウ', '南速水', 'ミナミハヤミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東浅井郡湖北町大光寺', '25', '25483', '5290351', '滋賀県', 'シガケン', '東浅井郡湖北町', 'ヒガシアザイグンコホクチョウ', '大光寺', 'ダイコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東浅井郡湖北町五坪', '25', '25483', '5290352', '滋賀県', 'シガケン', '東浅井郡湖北町', 'ヒガシアザイグンコホクチョウ', '五坪', 'ゴノツボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東浅井郡湖北町田中', '25', '25483', '5290353', '滋賀県', 'シガケン', '東浅井郡湖北町', 'ヒガシアザイグンコホクチョウ', '田中', 'タナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東浅井郡湖北町山本', '25', '25483', '5290354', '滋賀県', 'シガケン', '東浅井郡湖北町', 'ヒガシアザイグンコホクチョウ', '山本', 'ヤマモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東浅井郡湖北町石川', '25', '25483', '5290361', '滋賀県', 'シガケン', '東浅井郡湖北町', 'ヒガシアザイグンコホクチョウ', '石川', 'イシカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東浅井郡湖北町津里', '25', '25483', '5290362', '滋賀県', 'シガケン', '東浅井郡湖北町', 'ヒガシアザイグンコホクチョウ', '津里', 'ツノサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東浅井郡湖北町東尾上', '25', '25483', '5290363', '滋賀県', 'シガケン', '東浅井郡湖北町', 'ヒガシアザイグンコホクチョウ', '東尾上', 'ヒガシオノエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東浅井郡湖北町尾上', '25', '25483', '5290364', '滋賀県', 'シガケン', '東浅井郡湖北町', 'ヒガシアザイグンコホクチョウ', '尾上', 'オノエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東浅井郡湖北町今西', '25', '25483', '5290365', '滋賀県', 'シガケン', '東浅井郡湖北町', 'ヒガシアザイグンコホクチョウ', '今西', 'イマニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東浅井郡湖北町延勝寺', '25', '25483', '5290366', '滋賀県', 'シガケン', '東浅井郡湖北町', 'ヒガシアザイグンコホクチョウ', '延勝寺', 'エンショウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東浅井郡湖北町海老江', '25', '25483', '5290367', '滋賀県', 'シガケン', '東浅井郡湖北町', 'ヒガシアザイグンコホクチョウ', '海老江', 'エビエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県伊香郡木之本町', '25', '25502', '5290400', '滋賀県', 'シガケン', '伊香郡木之本町', 'イカグンキノモトチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('59150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県伊香郡木之本町金居原', '25', '25502', '5290401', '滋賀県', 'シガケン', '伊香郡木之本町', 'イカグンキノモトチョウ', '金居原', 'カネイハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県伊香郡木之本町杉野', '25', '25502', '5290402', '滋賀県', 'シガケン', '伊香郡木之本町', 'イカグンキノモトチョウ', '杉野', 'スギノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県伊香郡木之本町音羽', '25', '25502', '5290403', '滋賀県', 'シガケン', '伊香郡木之本町', 'イカグンキノモトチョウ', '音羽', 'オトワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県伊香郡木之本町杉本', '25', '25502', '5290404', '滋賀県', 'シガケン', '伊香郡木之本町', 'イカグンキノモトチョウ', '杉本', 'スギモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県伊香郡木之本町古橋', '25', '25502', '5290411', '滋賀県', 'シガケン', '伊香郡木之本町', 'イカグンキノモトチョウ', '古橋', 'フルハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県伊香郡木之本町石道', '25', '25502', '5290412', '滋賀県', 'シガケン', '伊香郡木之本町', 'イカグンキノモトチョウ', '石道', 'イシミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県伊香郡木之本町小山', '25', '25502', '5290413', '滋賀県', 'シガケン', '伊香郡木之本町', 'イカグンキノモトチョウ', '小山', 'コヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県伊香郡木之本町川合', '25', '25502', '5290414', '滋賀県', 'シガケン', '伊香郡木之本町', 'イカグンキノモトチョウ', '川合', 'カワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県伊香郡木之本町大見', '25', '25502', '5290415', '滋賀県', 'シガケン', '伊香郡木之本町', 'イカグンキノモトチョウ', '大見', 'オオミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県伊香郡木之本町アツトリ', '25', '25502', '5290421', '滋賀県', 'シガケン', '伊香郡木之本町', 'イカグンキノモトチョウ', 'アツトリ', 'アツトリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県伊香郡木之本町田部', '25', '25502', '5290422', '滋賀県', 'シガケン', '伊香郡木之本町', 'イカグンキノモトチョウ', '田部', 'タベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県伊香郡木之本町千田', '25', '25502', '5290423', '滋賀県', 'シガケン', '伊香郡木之本町', 'イカグンキノモトチョウ', '千田', 'センダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県伊香郡木之本町廣瀬', '25', '25502', '5290424', '滋賀県', 'シガケン', '伊香郡木之本町', 'イカグンキノモトチョウ', '廣瀬', 'ヒロセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県伊香郡木之本町木之本', '25', '25502', '5290425', '滋賀県', 'シガケン', '伊香郡木之本町', 'イカグンキノモトチョウ', '木之本', 'キノモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県伊香郡木之本町黒田', '25', '25502', '5290426', '滋賀県', 'シガケン', '伊香郡木之本町', 'イカグンキノモトチョウ', '黒田', 'クロダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県伊香郡木之本町大音', '25', '25502', '5290431', '滋賀県', 'シガケン', '伊香郡木之本町', 'イカグンキノモトチョウ', '大音', 'オオト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県伊香郡木之本町田居', '25', '25502', '5290432', '滋賀県', 'シガケン', '伊香郡木之本町', 'イカグンキノモトチョウ', '田居', 'タイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県伊香郡木之本町西山', '25', '25502', '5290433', '滋賀県', 'シガケン', '伊香郡木之本町', 'イカグンキノモトチョウ', '西山', 'ニシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県伊香郡木之本町北布施', '25', '25502', '5290434', '滋賀県', 'シガケン', '伊香郡木之本町', 'イカグンキノモトチョウ', '北布施', 'キタフセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県伊香郡木之本町赤尾', '25', '25502', '5290435', '滋賀県', 'シガケン', '伊香郡木之本町', 'イカグンキノモトチョウ', '赤尾', 'アカオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県伊香郡木之本町山梨子', '25', '25502', '5290436', '滋賀県', 'シガケン', '伊香郡木之本町', 'イカグンキノモトチョウ', '山梨子', 'ヤマナシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県伊香郡木之本町飯浦', '25', '25502', '5290437', '滋賀県', 'シガケン', '伊香郡木之本町', 'イカグンキノモトチョウ', '飯浦', 'ハンノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県伊香郡余呉町', '25', '25503', '5290500', '滋賀県', 'シガケン', '伊香郡余呉町', 'イカグンヨゴチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('59176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県伊香郡余呉町針川', '25', '25503', '5290501', '滋賀県', 'シガケン', '伊香郡余呉町', 'イカグンヨゴチョウ', '針川', 'ハリカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県伊香郡余呉町尾羽梨', '25', '25503', '5290502', '滋賀県', 'シガケン', '伊香郡余呉町', 'イカグンヨゴチョウ', '尾羽梨', 'オバナシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県伊香郡余呉町奥川並', '25', '25503', '5290503', '滋賀県', 'シガケン', '伊香郡余呉町', 'イカグンヨゴチョウ', '奥川並', 'オクカワナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県伊香郡余呉町田戸', '25', '25503', '5290504', '滋賀県', 'シガケン', '伊香郡余呉町', 'イカグンヨゴチョウ', '田戸', 'タド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県伊香郡余呉町小原', '25', '25503', '5290505', '滋賀県', 'シガケン', '伊香郡余呉町', 'イカグンヨゴチョウ', '小原', 'オハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県伊香郡余呉町鷲見', '25', '25503', '5290506', '滋賀県', 'シガケン', '伊香郡余呉町', 'イカグンヨゴチョウ', '鷲見', 'ワシミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県伊香郡余呉町菅並', '25', '25503', '5290511', '滋賀県', 'シガケン', '伊香郡余呉町', 'イカグンヨゴチョウ', '菅並', 'スガナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県伊香郡余呉町上丹生', '25', '25503', '5290512', '滋賀県', 'シガケン', '伊香郡余呉町', 'イカグンヨゴチョウ', '上丹生', 'カミニウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県伊香郡余呉町摺墨', '25', '25503', '5290513', '滋賀県', 'シガケン', '伊香郡余呉町', 'イカグンヨゴチョウ', '摺墨', 'スルスミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県伊香郡余呉町下丹生', '25', '25503', '5290514', '滋賀県', 'シガケン', '伊香郡余呉町', 'イカグンヨゴチョウ', '下丹生', 'シモニウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県伊香郡余呉町中之郷', '25', '25503', '5290515', '滋賀県', 'シガケン', '伊香郡余呉町', 'イカグンヨゴチョウ', '中之郷', 'ナカノゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県伊香郡余呉町下余呉', '25', '25503', '5290521', '滋賀県', 'シガケン', '伊香郡余呉町', 'イカグンヨゴチョウ', '下余呉', 'シモヨゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県伊香郡余呉町坂口', '25', '25503', '5290522', '滋賀県', 'シガケン', '伊香郡余呉町', 'イカグンヨゴチョウ', '坂口', 'サカグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県伊香郡余呉町川並', '25', '25503', '5290523', '滋賀県', 'シガケン', '伊香郡余呉町', 'イカグンヨゴチョウ', '川並', 'カワナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県伊香郡余呉町八戸', '25', '25503', '5290524', '滋賀県', 'シガケン', '伊香郡余呉町', 'イカグンヨゴチョウ', '八戸', 'ヤト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県伊香郡余呉町文室', '25', '25503', '5290525', '滋賀県', 'シガケン', '伊香郡余呉町', 'イカグンヨゴチョウ', '文室', 'フムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県伊香郡余呉町国安', '25', '25503', '5290526', '滋賀県', 'シガケン', '伊香郡余呉町', 'イカグンヨゴチョウ', '国安', 'クニヤス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県伊香郡余呉町東野', '25', '25503', '5290527', '滋賀県', 'シガケン', '伊香郡余呉町', 'イカグンヨゴチョウ', '東野', 'ヒガシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県伊香郡余呉町中河内', '25', '25503', '5290531', '滋賀県', 'シガケン', '伊香郡余呉町', 'イカグンヨゴチョウ', '中河内', 'ナカカワチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県伊香郡余呉町椿坂', '25', '25503', '5290532', '滋賀県', 'シガケン', '伊香郡余呉町', 'イカグンヨゴチョウ', '椿坂', 'ツバキサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県伊香郡余呉町柳ケ瀬', '25', '25503', '5290533', '滋賀県', 'シガケン', '伊香郡余呉町', 'イカグンヨゴチョウ', '柳ケ瀬', 'ヤナガセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県伊香郡余呉町小谷', '25', '25503', '5290534', '滋賀県', 'シガケン', '伊香郡余呉町', 'イカグンヨゴチョウ', '小谷', 'オオタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県伊香郡余呉町今市', '25', '25503', '5290535', '滋賀県', 'シガケン', '伊香郡余呉町', 'イカグンヨゴチョウ', '今市', 'イマイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県伊香郡余呉町池原', '25', '25503', '5290536', '滋賀県', 'シガケン', '伊香郡余呉町', 'イカグンヨゴチョウ', '池原', 'イケハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県伊香郡余呉町新堂', '25', '25503', '5290537', '滋賀県', 'シガケン', '伊香郡余呉町', 'イカグンヨゴチョウ', '新堂', 'シンドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県伊香郡木之本町飯浦坂尻', '25', '25502', '5290541', '滋賀県', 'シガケン', '伊香郡木之本町', 'イカグンキノモトチョウ', '飯浦', 'ハンノウラ', null, null, '坂尻', 'サカジリ');
INSERT INTO `ms_addresses` VALUES ('59202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県伊香郡西浅井町', '25', '25504', '5290700', '滋賀県', 'シガケン', '伊香郡西浅井町', 'イカグンニシアザイチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('59203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県伊香郡西浅井町塩津浜', '25', '25504', '5290701', '滋賀県', 'シガケン', '伊香郡西浅井町', 'イカグンニシアザイチョウ', '塩津浜', 'シオツハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県伊香郡西浅井町祝山', '25', '25504', '5290702', '滋賀県', 'シガケン', '伊香郡西浅井町', 'イカグンニシアザイチョウ', '祝山', 'ホリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県伊香郡西浅井町野坂', '25', '25504', '5290703', '滋賀県', 'シガケン', '伊香郡西浅井町', 'イカグンニシアザイチョウ', '野坂', 'ノザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県伊香郡西浅井町塩津中', '25', '25504', '5290704', '滋賀県', 'シガケン', '伊香郡西浅井町', 'イカグンニシアザイチョウ', '塩津中', 'シオツナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県伊香郡西浅井町横波', '25', '25504', '5290705', '滋賀県', 'シガケン', '伊香郡西浅井町', 'イカグンニシアザイチョウ', '横波', 'ヨコナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県伊香郡西浅井町余', '25', '25504', '5290706', '滋賀県', 'シガケン', '伊香郡西浅井町', 'イカグンニシアザイチョウ', '余', 'ヨ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県伊香郡西浅井町集福寺', '25', '25504', '5290707', '滋賀県', 'シガケン', '伊香郡西浅井町', 'イカグンニシアザイチョウ', '集福寺', 'シュウフクジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県伊香郡西浅井町沓掛', '25', '25504', '5290708', '滋賀県', 'シガケン', '伊香郡西浅井町', 'イカグンニシアザイチョウ', '沓掛', 'クツカケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県伊香郡西浅井町岩熊', '25', '25504', '5290711', '滋賀県', 'シガケン', '伊香郡西浅井町', 'イカグンニシアザイチョウ', '岩熊', 'ヤノクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県伊香郡西浅井町月出', '25', '25504', '5290712', '滋賀県', 'シガケン', '伊香郡西浅井町', 'イカグンニシアザイチョウ', '月出', 'ツキデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県伊香郡西浅井町八田部', '25', '25504', '5290713', '滋賀県', 'シガケン', '伊香郡西浅井町', 'イカグンニシアザイチョウ', '八田部', 'ハタベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県伊香郡西浅井町小山', '25', '25504', '5290714', '滋賀県', 'シガケン', '伊香郡西浅井町', 'イカグンニシアザイチョウ', '小山', 'オヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県伊香郡西浅井町山田', '25', '25504', '5290715', '滋賀県', 'シガケン', '伊香郡西浅井町', 'イカグンニシアザイチョウ', '山田', 'ヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県伊香郡西浅井町大浦', '25', '25504', '5290721', '滋賀県', 'シガケン', '伊香郡西浅井町', 'イカグンニシアザイチョウ', '大浦', 'オオウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県伊香郡西浅井町庄', '25', '25504', '5290722', '滋賀県', 'シガケン', '伊香郡西浅井町', 'イカグンニシアザイチョウ', '庄', 'ショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県伊香郡西浅井町中', '25', '25504', '5290723', '滋賀県', 'シガケン', '伊香郡西浅井町', 'イカグンニシアザイチョウ', '中', 'ナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県伊香郡西浅井町山門', '25', '25504', '5290724', '滋賀県', 'シガケン', '伊香郡西浅井町', 'イカグンニシアザイチョウ', '山門', 'ヤマカド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県伊香郡西浅井町黒山', '25', '25504', '5290725', '滋賀県', 'シガケン', '伊香郡西浅井町', 'イカグンニシアザイチョウ', '黒山', 'クロヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県伊香郡西浅井町菅浦', '25', '25504', '5290726', '滋賀県', 'シガケン', '伊香郡西浅井町', 'イカグンニシアザイチョウ', '菅浦', 'スガウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県犬上郡豊郷町', '25', '25441', '5291100', '滋賀県', 'シガケン', '犬上郡豊郷町', 'イヌカミグントヨサトチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('59224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市楡町', '25', '25202', '5291151', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '楡町', 'ニレチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市安食中町', '25', '25202', '5291152', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '安食中町', 'アンジキナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市太堂町', '25', '25202', '5291153', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '太堂町', 'タイドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市千尋町', '25', '25202', '5291154', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '千尋町', 'チヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市賀田山町', '25', '25202', '5291155', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '賀田山町', 'カタヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県彦根市清崎町', '25', '25202', '5291156', '滋賀県', 'シガケン', '彦根市', 'ヒコネシ', '清崎町', 'キヨサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県犬上郡豊郷町四十九院', '25', '25441', '5291161', '滋賀県', 'シガケン', '犬上郡豊郷町', 'イヌカミグントヨサトチョウ', '四十九院', 'シジュクイン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県犬上郡豊郷町八町', '25', '25441', '5291162', '滋賀県', 'シガケン', '犬上郡豊郷町', 'イヌカミグントヨサトチョウ', '八町', 'ハッチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県犬上郡豊郷町雨降野', '25', '25441', '5291163', '滋賀県', 'シガケン', '犬上郡豊郷町', 'イヌカミグントヨサトチョウ', '雨降野', 'アメフリノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県犬上郡豊郷町日栄', '25', '25441', '5291164', '滋賀県', 'シガケン', '犬上郡豊郷町', 'イヌカミグントヨサトチョウ', '日栄', 'ヒエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県犬上郡豊郷町吉田', '25', '25441', '5291165', '滋賀県', 'シガケン', '犬上郡豊郷町', 'イヌカミグントヨサトチョウ', '吉田', 'ヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県犬上郡豊郷町上枝', '25', '25441', '5291166', '滋賀県', 'シガケン', '犬上郡豊郷町', 'イヌカミグントヨサトチョウ', '上枝', 'カミエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県犬上郡豊郷町杉', '25', '25441', '5291167', '滋賀県', 'シガケン', '犬上郡豊郷町', 'イヌカミグントヨサトチョウ', '杉', 'スギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県犬上郡豊郷町八目', '25', '25441', '5291168', '滋賀県', 'シガケン', '犬上郡豊郷町', 'イヌカミグントヨサトチョウ', '八目', 'ハチメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県犬上郡豊郷町石畑', '25', '25441', '5291169', '滋賀県', 'シガケン', '犬上郡豊郷町', 'イヌカミグントヨサトチョウ', '石畑', 'イシバタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県犬上郡豊郷町安食西', '25', '25441', '5291171', '滋賀県', 'シガケン', '犬上郡豊郷町', 'イヌカミグントヨサトチョウ', '安食西', 'アンジキニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県犬上郡豊郷町安食南', '25', '25441', '5291172', '滋賀県', 'シガケン', '犬上郡豊郷町', 'イヌカミグントヨサトチョウ', '安食南', 'アンジキミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県犬上郡豊郷町高野瀬', '25', '25441', '5291173', '滋賀県', 'シガケン', '犬上郡豊郷町', 'イヌカミグントヨサトチョウ', '高野瀬', 'タカノセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県犬上郡豊郷町下枝', '25', '25441', '5291174', '滋賀県', 'シガケン', '犬上郡豊郷町', 'イヌカミグントヨサトチョウ', '下枝', 'シモエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県犬上郡豊郷町沢', '25', '25441', '5291175', '滋賀県', 'シガケン', '犬上郡豊郷町', 'イヌカミグントヨサトチョウ', '沢', 'サワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県犬上郡豊郷町大町', '25', '25441', '5291176', '滋賀県', 'シガケン', '犬上郡豊郷町', 'イヌカミグントヨサトチョウ', '大町', 'オオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県犬上郡豊郷町三ツ池', '25', '25441', '5291177', '滋賀県', 'シガケン', '犬上郡豊郷町', 'イヌカミグントヨサトチョウ', '三ツ池', 'ミツイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県愛知郡愛荘町斧磨', '25', '25425', '5291201', '滋賀県', 'シガケン', '愛知郡愛荘町', 'エチグンアイショウチョウ', '斧磨', 'ヨキトギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県愛知郡愛荘町松尾寺', '25', '25425', '5291202', '滋賀県', 'シガケン', '愛知郡愛荘町', 'エチグンアイショウチョウ', '松尾寺', 'マツオジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県愛知郡愛荘町上蚊野', '25', '25425', '5291203', '滋賀県', 'シガケン', '愛知郡愛荘町', 'エチグンアイショウチョウ', '上蚊野', 'カミガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県愛知郡愛荘町蚊野外', '25', '25425', '5291204', '滋賀県', 'シガケン', '愛知郡愛荘町', 'エチグンアイショウチョウ', '蚊野外', 'カノトノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県愛知郡愛荘町軽野', '25', '25425', '5291205', '滋賀県', 'シガケン', '愛知郡愛荘町', 'エチグンアイショウチョウ', '軽野', 'カルノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県愛知郡愛荘町蚊野', '25', '25425', '5291206', '滋賀県', 'シガケン', '愛知郡愛荘町', 'エチグンアイショウチョウ', '蚊野', 'カノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県愛知郡愛荘町岩倉', '25', '25425', '5291207', '滋賀県', 'シガケン', '愛知郡愛荘町', 'エチグンアイショウチョウ', '岩倉', 'イワクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県愛知郡愛荘町竹原', '25', '25425', '5291208', '滋賀県', 'シガケン', '愛知郡愛荘町', 'エチグンアイショウチョウ', '竹原', 'タケハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県愛知郡愛荘町香之庄', '25', '25425', '5291211', '滋賀県', 'シガケン', '愛知郡愛荘町', 'エチグンアイショウチョウ', '香之庄', 'コノショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県愛知郡愛荘町元持', '25', '25425', '5291212', '滋賀県', 'シガケン', '愛知郡愛荘町', 'エチグンアイショウチョウ', '元持', 'モトモチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県愛知郡愛荘町沖', '25', '25425', '5291213', '滋賀県', 'シガケン', '愛知郡愛荘町', 'エチグンアイショウチョウ', '沖', 'オキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県愛知郡愛荘町宮後', '25', '25425', '5291214', '滋賀県', 'シガケン', '愛知郡愛荘町', 'エチグンアイショウチョウ', '宮後', 'ミヤウシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県愛知郡愛荘町下八木', '25', '25425', '5291221', '滋賀県', 'シガケン', '愛知郡愛荘町', 'エチグンアイショウチョウ', '下八木', 'シモヤギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県愛知郡愛荘町北八木', '25', '25425', '5291222', '滋賀県', 'シガケン', '愛知郡愛荘町', 'エチグンアイショウチョウ', '北八木', 'キタヤギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県愛知郡愛荘町島川', '25', '25425', '5291223', '滋賀県', 'シガケン', '愛知郡愛荘町', 'エチグンアイショウチョウ', '島川', 'シマガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県愛知郡愛荘町長塚', '25', '25425', '5291224', '滋賀県', 'シガケン', '愛知郡愛荘町', 'エチグンアイショウチョウ', '長塚', 'ナガツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県愛知郡愛荘町栗田', '25', '25425', '5291225', '滋賀県', 'シガケン', '愛知郡愛荘町', 'エチグンアイショウチョウ', '栗田', 'クリタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県愛知郡愛荘町南野々目', '25', '25425', '5291226', '滋賀県', 'シガケン', '愛知郡愛荘町', 'エチグンアイショウチョウ', '南野々目', 'ミナミノノメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県愛知郡愛荘町野々目', '25', '25425', '5291227', '滋賀県', 'シガケン', '愛知郡愛荘町', 'エチグンアイショウチョウ', '野々目', 'ノノメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県愛知郡愛荘町矢守', '25', '25425', '5291228', '滋賀県', 'シガケン', '愛知郡愛荘町', 'エチグンアイショウチョウ', '矢守', 'ヤモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県愛知郡愛荘町円城寺', '25', '25425', '5291231', '滋賀県', 'シガケン', '愛知郡愛荘町', 'エチグンアイショウチョウ', '円城寺', 'エンジョウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県愛知郡愛荘町常安寺', '25', '25425', '5291232', '滋賀県', 'シガケン', '愛知郡愛荘町', 'エチグンアイショウチョウ', '常安寺', 'ジョウアンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県愛知郡愛荘町東出', '25', '25425', '5291233', '滋賀県', 'シガケン', '愛知郡愛荘町', 'エチグンアイショウチョウ', '東出', 'ヒガシデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県愛知郡愛荘町安孫子', '25', '25425', '5291234', '滋賀県', 'シガケン', '愛知郡愛荘町', 'エチグンアイショウチョウ', '安孫子', 'アビコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県愛知郡愛荘町目加田', '25', '25425', '5291235', '滋賀県', 'シガケン', '愛知郡愛荘町', 'エチグンアイショウチョウ', '目加田', 'メカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県愛知郡愛荘町深草', '25', '25425', '5291236', '滋賀県', 'シガケン', '愛知郡愛荘町', 'エチグンアイショウチョウ', '深草', 'フコソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県愛知郡愛荘町西出', '25', '25425', '5291237', '滋賀県', 'シガケン', '愛知郡愛荘町', 'エチグンアイショウチョウ', '西出', 'ニシデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県愛知郡愛荘町', '25', '25425', '5291300', '滋賀県', 'シガケン', '愛知郡愛荘町', 'エチグンアイショウチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('59275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県愛知郡愛荘町山川原', '25', '25425', '5291301', '滋賀県', 'シガケン', '愛知郡愛荘町', 'エチグンアイショウチョウ', '山川原', 'ヤマガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県愛知郡愛荘町川原', '25', '25425', '5291302', '滋賀県', 'シガケン', '愛知郡愛荘町', 'エチグンアイショウチョウ', '川原', 'カワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県愛知郡愛荘町長野', '25', '25425', '5291303', '滋賀県', 'シガケン', '愛知郡愛荘町', 'エチグンアイショウチョウ', '長野', 'ナガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県愛知郡愛荘町石橋', '25', '25425', '5291311', '滋賀県', 'シガケン', '愛知郡愛荘町', 'エチグンアイショウチョウ', '石橋', 'イシハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県愛知郡愛荘町川久保', '25', '25425', '5291312', '滋賀県', 'シガケン', '愛知郡愛荘町', 'エチグンアイショウチョウ', '川久保', 'カワクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県愛知郡愛荘町市', '25', '25425', '5291313', '滋賀県', 'シガケン', '愛知郡愛荘町', 'エチグンアイショウチョウ', '市', 'イチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県愛知郡愛荘町中宿', '25', '25425', '5291314', '滋賀県', 'シガケン', '愛知郡愛荘町', 'エチグンアイショウチョウ', '中宿', 'ナカジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県愛知郡愛荘町沓掛', '25', '25425', '5291315', '滋賀県', 'シガケン', '愛知郡愛荘町', 'エチグンアイショウチョウ', '沓掛', 'クツカケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県愛知郡愛荘町豊満', '25', '25425', '5291321', '滋賀県', 'シガケン', '愛知郡愛荘町', 'エチグンアイショウチョウ', '豊満', 'トヨミツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県愛知郡愛荘町平居', '25', '25425', '5291322', '滋賀県', 'シガケン', '愛知郡愛荘町', 'エチグンアイショウチョウ', '平居', 'ヒライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県愛知郡愛荘町畑田', '25', '25425', '5291323', '滋賀県', 'シガケン', '愛知郡愛荘町', 'エチグンアイショウチョウ', '畑田', 'ハタケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県愛知郡愛荘町苅間', '25', '25425', '5291324', '滋賀県', 'シガケン', '愛知郡愛荘町', 'エチグンアイショウチョウ', '苅間', 'カリマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県愛知郡愛荘町東円堂', '25', '25425', '5291325', '滋賀県', 'シガケン', '愛知郡愛荘町', 'エチグンアイショウチョウ', '東円堂', 'トウエンドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県愛知郡愛荘町愛知川', '25', '25425', '5291331', '滋賀県', 'シガケン', '愛知郡愛荘町', 'エチグンアイショウチョウ', '愛知川', 'エチガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市五個荘石馬寺町', '25', '25213', '5291401', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '五個荘石馬寺町', 'ゴカショウイシバジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市五個荘七里町', '25', '25213', '5291402', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '五個荘七里町', 'ゴカショウシチリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市五個荘日吉町', '25', '25213', '5291403', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '五個荘日吉町', 'ゴカショウヒヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市宮荘町', '25', '25213', '5291404', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '宮荘町', 'ミヤショウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市五個荘金堂町', '25', '25213', '5291405', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '五個荘金堂町', 'ゴカショウコンドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市五個荘河曲町', '25', '25213', '5291411', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '五個荘河曲町', 'ゴカショウカマガリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市五個荘和田町', '25', '25213', '5291412', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '五個荘和田町', 'ゴカショウワダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市五個荘簗瀬町', '25', '25213', '5291413', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '五個荘簗瀬町', 'ゴカショウヤナゼチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市五個荘中町', '25', '25213', '5291414', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '五個荘中町', 'ゴカショウナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市五個荘五位田町', '25', '25213', '5291415', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '五個荘五位田町', 'ゴカショウゴイデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市五個荘竜田町', '25', '25213', '5291421', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '五個荘竜田町', 'ゴカショウタツタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市五個荘小幡町', '25', '25213', '5291422', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '五個荘小幡町', 'ゴカショウオバタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市五個荘奥町', '25', '25213', '5291423', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '五個荘奥町', 'ゴカショウオクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市五個荘三俣町', '25', '25213', '5291424', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '五個荘三俣町', 'ゴカショウミツマタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市五個荘石川町', '25', '25213', '5291425', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '五個荘石川町', 'ゴカショウイシカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市五個荘山本町', '25', '25213', '5291431', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '五個荘山本町', 'ゴカショウヤマモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市五個荘新堂町', '25', '25213', '5291432', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '五個荘新堂町', 'ゴカショウシンドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市五個荘木流町', '25', '25213', '5291433', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '五個荘木流町', 'ゴカショウキナガセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市五個荘平阪町', '25', '25213', '5291434', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '五個荘平阪町', 'ゴカショウヒラサカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市五個荘伊野部町', '25', '25213', '5291435', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '五個荘伊野部町', 'ゴカショウイノベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市五個荘川並町', '25', '25213', '5291441', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '五個荘川並町', 'ゴカショウカワナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市五個荘塚本町', '25', '25213', '5291442', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '五個荘塚本町', 'ゴカショウツカモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市五個荘北町屋町', '25', '25213', '5291443', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '五個荘北町屋町', 'ゴカショウキタマチヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市五個荘石塚町', '25', '25213', '5291444', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '五個荘石塚町', 'ゴカショウイシヅカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市五個荘清水鼻町', '25', '25213', '5291445', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '五個荘清水鼻町', 'ゴカショウシミズハナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市石塔町', '25', '25213', '5291501', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '石塔町', 'イシドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市平林町', '25', '25213', '5291502', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '平林町', 'ヒラバヤシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市綺田町', '25', '25213', '5291503', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '綺田町', 'カバタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市蒲生寺町', '25', '25213', '5291504', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '蒲生寺町', 'ガモウテラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市桜川東町', '25', '25213', '5291511', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '桜川東町', 'サクラガワヒガシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市大塚町', '25', '25213', '5291512', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '大塚町', 'オオツカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市田井町', '25', '25213', '5291513', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '田井町', 'タイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市蒲生大森町', '25', '25213', '5291514', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '蒲生大森町', 'ガモウオオモリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市蒲生岡本町', '25', '25213', '5291521', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '蒲生岡本町', 'ガモウオカモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市鋳物師町', '25', '25213', '5291522', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '鋳物師町', 'イモノシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市上麻生町', '25', '25213', '5291523', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '上麻生町', 'カミアソウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市下麻生町', '25', '25213', '5291524', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '下麻生町', 'シモアソウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市市子川原町', '25', '25213', '5291531', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '市子川原町', 'イチコカワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市市子松井町', '25', '25213', '5291532', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '市子松井町', 'イチコマツイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市市子沖町', '25', '25213', '5291533', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '市子沖町', 'イチコオキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市鈴町', '25', '25213', '5291534', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '鈴町', 'スズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市上南町', '25', '25213', '5291535', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '上南町', 'カミナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市合戸町', '25', '25213', '5291536', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '合戸町', 'ゴウドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市市子殿町', '25', '25213', '5291537', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '市子殿町', 'イチコトノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市蒲生堂町', '25', '25213', '5291541', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '蒲生堂町', 'カモウドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市宮川町', '25', '25213', '5291551', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '宮川町', 'ミヤガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市稲垂町', '25', '25213', '5291561', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '稲垂町', 'イナタリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市木村町', '25', '25213', '5291562', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '木村町', 'キムラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市横山町', '25', '25213', '5291563', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '横山町', 'ヨコヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市宮井町', '25', '25213', '5291564', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '宮井町', 'ミヤイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市外原町', '25', '25213', '5291565', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '外原町', 'トノハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市葛巻町', '25', '25213', '5291566', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '葛巻町', 'カズラマキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市川合町', '25', '25213', '5291571', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '川合町', 'カワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県東近江市桜川西町', '25', '25213', '5291572', '滋賀県', 'シガケン', '東近江市', 'ヒガシオウミシ', '桜川西町', 'サクラガワニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県蒲生郡日野町', '25', '25383', '5291600', '滋賀県', 'シガケン', '蒲生郡日野町', 'ガモウグンヒノチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('59358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県蒲生郡日野町松尾', '25', '25383', '5291601', '滋賀県', 'シガケン', '蒲生郡日野町', 'ガモウグンヒノチョウ', '松尾', 'マツオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県蒲生郡日野町河原', '25', '25383', '5291602', '滋賀県', 'シガケン', '蒲生郡日野町', 'ガモウグンヒノチョウ', '河原', 'カワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県蒲生郡日野町大窪', '25', '25383', '5291603', '滋賀県', 'シガケン', '蒲生郡日野町', 'ガモウグンヒノチョウ', '大窪', 'オオクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県蒲生郡日野町村井', '25', '25383', '5291604', '滋賀県', 'シガケン', '蒲生郡日野町', 'ガモウグンヒノチョウ', '村井', 'ムライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県蒲生郡日野町小井口', '25', '25383', '5291605', '滋賀県', 'シガケン', '蒲生郡日野町', 'ガモウグンヒノチョウ', '小井口', 'オイグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県蒲生郡日野町寺尻', '25', '25383', '5291606', '滋賀県', 'シガケン', '蒲生郡日野町', 'ガモウグンヒノチョウ', '寺尻', 'テラジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県蒲生郡日野町木津', '25', '25383', '5291607', '滋賀県', 'シガケン', '蒲生郡日野町', 'ガモウグンヒノチョウ', '木津', 'キヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県蒲生郡日野町大谷', '25', '25383', '5291608', '滋賀県', 'シガケン', '蒲生郡日野町', 'ガモウグンヒノチョウ', '大谷', 'オオタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県蒲生郡日野町中道', '25', '25383', '5291609', '滋賀県', 'シガケン', '蒲生郡日野町', 'ガモウグンヒノチョウ', '中道', 'ナカミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県蒲生郡日野町奥之池', '25', '25383', '5291610', '滋賀県', 'シガケン', '蒲生郡日野町', 'ガモウグンヒノチョウ', '奥之池', 'オクノイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県蒲生郡日野町杣', '25', '25383', '5291611', '滋賀県', 'シガケン', '蒲生郡日野町', 'ガモウグンヒノチョウ', '杣', 'ソマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県蒲生郡日野町杉', '25', '25383', '5291612', '滋賀県', 'シガケン', '蒲生郡日野町', 'ガモウグンヒノチョウ', '杉', 'スギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県蒲生郡日野町川原', '25', '25383', '5291613', '滋賀県', 'シガケン', '蒲生郡日野町', 'ガモウグンヒノチョウ', '川原', 'カワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県蒲生郡日野町原', '25', '25383', '5291614', '滋賀県', 'シガケン', '蒲生郡日野町', 'ガモウグンヒノチョウ', '原', 'ハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県蒲生郡日野町小野', '25', '25383', '5291615', '滋賀県', 'シガケン', '蒲生郡日野町', 'ガモウグンヒノチョウ', '小野', 'コノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県蒲生郡日野町奥師', '25', '25383', '5291616', '滋賀県', 'シガケン', '蒲生郡日野町', 'ガモウグンヒノチョウ', '奥師', 'オクシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県蒲生郡日野町中之郷', '25', '25383', '5291617', '滋賀県', 'シガケン', '蒲生郡日野町', 'ガモウグンヒノチョウ', '中之郷', 'ナカノゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県蒲生郡日野町鳥居平', '25', '25383', '5291618', '滋賀県', 'シガケン', '蒲生郡日野町', 'ガモウグンヒノチョウ', '鳥居平', 'トリイヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県蒲生郡日野町佐久良', '25', '25383', '5291619', '滋賀県', 'シガケン', '蒲生郡日野町', 'ガモウグンヒノチョウ', '佐久良', 'サクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県蒲生郡日野町西明寺', '25', '25383', '5291621', '滋賀県', 'シガケン', '蒲生郡日野町', 'ガモウグンヒノチョウ', '西明寺', 'サイミョウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県蒲生郡日野町北畑', '25', '25383', '5291622', '滋賀県', 'シガケン', '蒲生郡日野町', 'ガモウグンヒノチョウ', '北畑', 'キタバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県蒲生郡日野町熊野', '25', '25383', '5291623', '滋賀県', 'シガケン', '蒲生郡日野町', 'ガモウグンヒノチョウ', '熊野', 'クマノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県蒲生郡日野町平子', '25', '25383', '5291624', '滋賀県', 'シガケン', '蒲生郡日野町', 'ガモウグンヒノチョウ', '平子', 'ヒラコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県蒲生郡日野町蔵王', '25', '25383', '5291625', '滋賀県', 'シガケン', '蒲生郡日野町', 'ガモウグンヒノチョウ', '蔵王', 'ザオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県蒲生郡日野町音羽', '25', '25383', '5291626', '滋賀県', 'シガケン', '蒲生郡日野町', 'ガモウグンヒノチョウ', '音羽', 'オトワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県蒲生郡日野町仁本木', '25', '25383', '5291627', '滋賀県', 'シガケン', '蒲生郡日野町', 'ガモウグンヒノチョウ', '仁本木', 'ニホンギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県蒲生郡日野町西大路', '25', '25383', '5291628', '滋賀県', 'シガケン', '蒲生郡日野町', 'ガモウグンヒノチョウ', '西大路', 'ニシオオジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県蒲生郡日野町鎌掛', '25', '25383', '5291631', '滋賀県', 'シガケン', '蒲生郡日野町', 'ガモウグンヒノチョウ', '鎌掛', 'カイガケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県蒲生郡日野町上駒月', '25', '25383', '5291632', '滋賀県', 'シガケン', '蒲生郡日野町', 'ガモウグンヒノチョウ', '上駒月', 'カミコマヅキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県蒲生郡日野町下駒月', '25', '25383', '5291633', '滋賀県', 'シガケン', '蒲生郡日野町', 'ガモウグンヒノチョウ', '下駒月', 'シモコマヅキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県蒲生郡日野町深山口', '25', '25383', '5291634', '滋賀県', 'シガケン', '蒲生郡日野町', 'ガモウグンヒノチョウ', '深山口', 'ミヤマグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県蒲生郡日野町迫', '25', '25383', '5291635', '滋賀県', 'シガケン', '蒲生郡日野町', 'ガモウグンヒノチョウ', '迫', 'ハサマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県蒲生郡日野町清田', '25', '25383', '5291636', '滋賀県', 'シガケン', '蒲生郡日野町', 'ガモウグンヒノチョウ', '清田', 'キヨタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県蒲生郡日野町日田', '25', '25383', '5291641', '滋賀県', 'シガケン', '蒲生郡日野町', 'ガモウグンヒノチョウ', '日田', 'ヒダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県蒲生郡日野町上野田', '25', '25383', '5291642', '滋賀県', 'シガケン', '蒲生郡日野町', 'ガモウグンヒノチョウ', '上野田', 'コウズケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県蒲生郡日野町里口', '25', '25383', '5291643', '滋賀県', 'シガケン', '蒲生郡日野町', 'ガモウグンヒノチョウ', '里口', 'サトグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県蒲生郡日野町内池', '25', '25383', '5291644', '滋賀県', 'シガケン', '蒲生郡日野町', 'ガモウグンヒノチョウ', '内池', 'ウチイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県蒲生郡日野町十禅師', '25', '25383', '5291645', '滋賀県', 'シガケン', '蒲生郡日野町', 'ガモウグンヒノチョウ', '十禅師', 'ジュウゼンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県蒲生郡日野町猫田', '25', '25383', '5291646', '滋賀県', 'シガケン', '蒲生郡日野町', 'ガモウグンヒノチョウ', '猫田', 'ネコダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県蒲生郡日野町別所', '25', '25383', '5291647', '滋賀県', 'シガケン', '蒲生郡日野町', 'ガモウグンヒノチョウ', '別所', 'ベッシヨ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県蒲生郡日野町いせの', '25', '25383', '5291648', '滋賀県', 'シガケン', '蒲生郡日野町', 'ガモウグンヒノチョウ', 'いせの', 'イセノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県蒲生郡日野町山本', '25', '25383', '5291651', '滋賀県', 'シガケン', '蒲生郡日野町', 'ガモウグンヒノチョウ', '山本', 'ヤマモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県蒲生郡日野町小御門', '25', '25383', '5291652', '滋賀県', 'シガケン', '蒲生郡日野町', 'ガモウグンヒノチョウ', '小御門', 'コミカド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県蒲生郡日野町三十坪', '25', '25383', '5291653', '滋賀県', 'シガケン', '蒲生郡日野町', 'ガモウグンヒノチョウ', '三十坪', 'ミソツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県蒲生郡日野町小谷', '25', '25383', '5291654', '滋賀県', 'シガケン', '蒲生郡日野町', 'ガモウグンヒノチョウ', '小谷', 'コダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県蒲生郡日野町石原', '25', '25383', '5291655', '滋賀県', 'シガケン', '蒲生郡日野町', 'ガモウグンヒノチョウ', '石原', 'イシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県蒲生郡日野町増田', '25', '25383', '5291656', '滋賀県', 'シガケン', '蒲生郡日野町', 'ガモウグンヒノチョウ', '増田', 'マシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県蒲生郡日野町豊田', '25', '25383', '5291657', '滋賀県', 'シガケン', '蒲生郡日野町', 'ガモウグンヒノチョウ', '豊田', 'トヨタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県蒲生郡日野町中山', '25', '25383', '5291658', '滋賀県', 'シガケン', '蒲生郡日野町', 'ガモウグンヒノチョウ', '中山', 'ナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県蒲生郡日野町安部居', '25', '25383', '5291661', '滋賀県', 'シガケン', '蒲生郡日野町', 'ガモウグンヒノチョウ', '安部居', 'アベイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県蒲生郡日野町中在寺', '25', '25383', '5291662', '滋賀県', 'シガケン', '蒲生郡日野町', 'ガモウグンヒノチョウ', '中在寺', 'ナカザイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県蒲生郡日野町北脇', '25', '25383', '5291663', '滋賀県', 'シガケン', '蒲生郡日野町', 'ガモウグンヒノチョウ', '北脇', 'キタワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県蒲生郡日野町蓮花寺', '25', '25383', '5291664', '滋賀県', 'シガケン', '蒲生郡日野町', 'ガモウグンヒノチョウ', '蓮花寺', 'レンゲジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県蒲生郡日野町野出', '25', '25383', '5291665', '滋賀県', 'シガケン', '蒲生郡日野町', 'ガモウグンヒノチョウ', '野出', 'ノデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市信楽町宮町', '25', '25209', '5291801', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '信楽町宮町', 'シガラキチョウミヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市信楽町黄瀬', '25', '25209', '5291802', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '信楽町黄瀬', 'シガラキチョウキノセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市信楽町牧', '25', '25209', '5291803', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '信楽町牧', 'シガラキチョウマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市信楽町勅旨', '25', '25209', '5291804', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '信楽町勅旨', 'シガラキチョウチョクシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市信楽町江田', '25', '25209', '5291811', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '信楽町江田', 'シガラキチョウエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市信楽町神山', '25', '25209', '5291812', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '信楽町神山', 'シガラキチョウコウヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市信楽町畑', '25', '25209', '5291813', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '信楽町畑', 'シガラキチョウハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市信楽町田代', '25', '25209', '5291814', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '信楽町田代', 'シガラキチョウタシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市信楽町多羅尾', '25', '25209', '5291821', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '信楽町多羅尾', 'シガラキチョウタラオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市信楽町西', '25', '25209', '5291831', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '信楽町西', 'シガラキチョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市信楽町小川出', '25', '25209', '5291832', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '信楽町小川出', 'シガラキチョウオガワデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市信楽町小川', '25', '25209', '5291833', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '信楽町小川', 'シガラキチョウオガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市信楽町杉山', '25', '25209', '5291834', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '信楽町杉山', 'シガラキチョウスギヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市信楽町中野', '25', '25209', '5291835', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '信楽町中野', 'シガラキチョウナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市信楽町柞原', '25', '25209', '5291836', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '信楽町柞原', 'シガラキチョウホソハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市信楽町上朝宮', '25', '25209', '5291841', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '信楽町上朝宮', 'シガラキチョウカミアサミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市信楽町下朝宮', '25', '25209', '5291842', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '信楽町下朝宮', 'シガラキチョウシモアサミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市信楽町宮尻', '25', '25209', '5291843', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '信楽町宮尻', 'シガラキチョウミヤジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '滋賀県甲賀市信楽町長野', '25', '25209', '5291851', '滋賀県', 'シガケン', '甲賀市', 'コウカシ', '信楽町長野', 'シガラキチョウナガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫小牧市', '01', '01213', '0530000', '北海道', 'ホッカイドウ', '苫小牧市', 'トマコマイシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('59435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区', '27', '27127', '5300000', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('59436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区梅田', '27', '27127', '5300001', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '梅田', 'ウメダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区曽根崎新地', '27', '27127', '5300002', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '曽根崎新地', 'ソネザキシンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区堂島', '27', '27127', '5300003', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '堂島', 'ドウジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区堂島浜', '27', '27127', '5300004', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '堂島浜', 'ドウジマハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区中之島', '27', '27127', '5300005', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '中之島', 'ナカノシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫小牧市一本松町', '01', '01213', '0530001', '北海道', 'ホッカイドウ', '苫小牧市', 'トマコマイシ', '一本松町', 'イッポンマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区大深町', '27', '27127', '5300011', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '大深町', 'オオフカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区芝田', '27', '27127', '5300012', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '芝田', 'シバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区茶屋町', '27', '27127', '5300013', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '茶屋町', 'チャヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区鶴野町', '27', '27127', '5300014', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '鶴野町', 'ツルノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区中崎西', '27', '27127', '5300015', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '中崎西', 'ナカザキニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区中崎', '27', '27127', '5300016', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '中崎', 'ナカザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区角田町', '27', '27127', '5300017', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '角田町', 'カクダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区小松原町', '27', '27127', '5300018', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '小松原町', 'コマツバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫小牧市晴海町', '01', '01213', '0530002', '北海道', 'ホッカイドウ', '苫小牧市', 'トマコマイシ', '晴海町', 'ハルミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区浮田', '27', '27127', '5300021', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '浮田', 'ウキダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区浪花町', '27', '27127', '5300022', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '浪花町', 'ナニワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区黒崎町', '27', '27127', '5300023', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '黒崎町', 'クロサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区山崎町', '27', '27127', '5300024', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '山崎町', 'ヤマザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区扇町', '27', '27127', '5300025', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '扇町', 'オウギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区神山町', '27', '27127', '5300026', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '神山町', 'カミヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区堂山町', '27', '27127', '5300027', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '堂山町', 'ドウヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区万歳町', '27', '27127', '5300028', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '万歳町', 'バンザイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫小牧市入船町', '01', '01213', '0530003', '北海道', 'ホッカイドウ', '苫小牧市', 'トマコマイシ', '入船町', 'イリフネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区菅栄町', '27', '27127', '5300031', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '菅栄町', 'カンエイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区樋之口町', '27', '27127', '5300032', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '樋之口町', 'ヒノクチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区池田町', '27', '27127', '5300033', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '池田町', 'イケダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区錦町', '27', '27127', '5300034', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '錦町', 'ニシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区同心', '27', '27127', '5300035', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '同心', 'ドウシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区与力町', '27', '27127', '5300036', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '与力町', 'ヨリキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区松ケ枝町', '27', '27127', '5300037', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '松ケ枝町', 'マツガエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区紅梅町', '27', '27127', '5300038', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '紅梅町', 'コウバイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫小牧市港町', '01', '01213', '0530004', '北海道', 'ホッカイドウ', '苫小牧市', 'トマコマイシ', '港町', 'ミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区天神橋1丁目', '27', '27127', '5300041', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '天神橋', 'テンジンバシ', null, null, '1丁目', '01チョウメ');
INSERT INTO `ms_addresses` VALUES ('59470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区天神橋2丁目', '27', '27127', '5300041', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '天神橋', 'テンジンバシ', null, null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('59471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区天神橋3丁目', '27', '27127', '5300041', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '天神橋', 'テンジンバシ', null, null, '3丁目', '03チョウメ');
INSERT INTO `ms_addresses` VALUES ('59472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区天神橋4丁目', '27', '27127', '5300041', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '天神橋', 'テンジンバシ', null, null, '4丁目', '04チョウメ');
INSERT INTO `ms_addresses` VALUES ('59473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区天神橋5丁目', '27', '27127', '5300041', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '天神橋', 'テンジンバシ', null, null, '5丁目', '05チョウメ');
INSERT INTO `ms_addresses` VALUES ('59474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区天神橋6丁目', '27', '27127', '5300041', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '天神橋', 'テンジンバシ', null, null, '6丁目', '06チョウメ');
INSERT INTO `ms_addresses` VALUES ('59475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区天満橋', '27', '27127', '5300042', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '天満橋', 'テンマバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区天満', '27', '27127', '5300043', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '天満', 'テンマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区東天満', '27', '27127', '5300044', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '東天満', 'ヒガシテンマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区天神西町', '27', '27127', '5300045', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '天神西町', 'テンジンニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区菅原町', '27', '27127', '5300046', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '菅原町', 'スガハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区西天満', '27', '27127', '5300047', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '西天満', 'ニシテンマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫小牧市元中野町', '01', '01213', '0530005', '北海道', 'ホッカイドウ', '苫小牧市', 'トマコマイシ', '元中野町', 'モトナカノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区太融寺町', '27', '27127', '5300051', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '太融寺町', 'タイユウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区南扇町', '27', '27127', '5300052', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '南扇町', 'ミナミオウギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区末広町', '27', '27127', '5300053', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '末広町', 'スエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区南森町', '27', '27127', '5300054', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '南森町', 'ミナミモリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区野崎町', '27', '27127', '5300055', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '野崎町', 'ノザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区兎我野町', '27', '27127', '5300056', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '兎我野町', 'トガノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区曽根崎', '27', '27127', '5300057', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '曽根崎', 'ソネザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫小牧市新中野町', '01', '01213', '0530006', '北海道', 'ホッカイドウ', '苫小牧市', 'トマコマイシ', '新中野町', 'シンナカノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫小牧市船見町', '01', '01213', '0530007', '北海道', 'ホッカイドウ', '苫小牧市', 'トマコマイシ', '船見町', 'フナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫小牧市末広町', '01', '01213', '0530011', '北海道', 'ホッカイドウ', '苫小牧市', 'トマコマイシ', '末広町', 'スエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫小牧市汐見町', '01', '01213', '0530012', '北海道', 'ホッカイドウ', '苫小牧市', 'トマコマイシ', '汐見町', 'シオミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫小牧市高砂町', '01', '01213', '0530013', '北海道', 'ホッカイドウ', '苫小牧市', 'トマコマイシ', '高砂町', 'タカサゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫小牧市浜町', '01', '01213', '0530014', '北海道', 'ホッカイドウ', '苫小牧市', 'トマコマイシ', '浜町', 'ハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫小牧市本幸町', '01', '01213', '0530015', '北海道', 'ホッカイドウ', '苫小牧市', 'トマコマイシ', '本幸町', 'ホンコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫小牧市寿町', '01', '01213', '0530016', '北海道', 'ホッカイドウ', '苫小牧市', 'トマコマイシ', '寿町', 'コトブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫小牧市栄町', '01', '01213', '0530017', '北海道', 'ホッカイドウ', '苫小牧市', 'トマコマイシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫小牧市旭町', '01', '01213', '0530018', '北海道', 'ホッカイドウ', '苫小牧市', 'トマコマイシ', '旭町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫小牧市若草町', '01', '01213', '0530021', '北海道', 'ホッカイドウ', '苫小牧市', 'トマコマイシ', '若草町', 'ワカクサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫小牧市表町', '01', '01213', '0530022', '北海道', 'ホッカイドウ', '苫小牧市', 'トマコマイシ', '表町', 'オモテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫小牧市錦町', '01', '01213', '0530023', '北海道', 'ホッカイドウ', '苫小牧市', 'トマコマイシ', '錦町', 'ニシキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫小牧市大町', '01', '01213', '0530024', '北海道', 'ホッカイドウ', '苫小牧市', 'トマコマイシ', '大町', 'オオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫小牧市本町', '01', '01213', '0530025', '北海道', 'ホッカイドウ', '苫小牧市', 'トマコマイシ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫小牧市幸町', '01', '01213', '0530026', '北海道', 'ホッカイドウ', '苫小牧市', 'トマコマイシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫小牧市王子町', '01', '01213', '0530027', '北海道', 'ホッカイドウ', '苫小牧市', 'トマコマイシ', '王子町', 'オウジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫小牧市春日町', '01', '01213', '0530031', '北海道', 'ホッカイドウ', '苫小牧市', 'トマコマイシ', '春日町', 'カスガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫小牧市緑町', '01', '01213', '0530032', '北海道', 'ホッカイドウ', '苫小牧市', 'トマコマイシ', '緑町', 'ミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫小牧市木場町', '01', '01213', '0530033', '北海道', 'ホッカイドウ', '苫小牧市', 'トマコマイシ', '木場町', 'キバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫小牧市清水町', '01', '01213', '0530034', '北海道', 'ホッカイドウ', '苫小牧市', 'トマコマイシ', '清水町', 'シミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫小牧市高丘', '01', '01213', '0530035', '北海道', 'ホッカイドウ', '苫小牧市', 'トマコマイシ', '高丘', 'タカオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫小牧市美園町', '01', '01213', '0530041', '北海道', 'ホッカイドウ', '苫小牧市', 'トマコマイシ', '美園町', 'ミソノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫小牧市三光町', '01', '01213', '0530042', '北海道', 'ホッカイドウ', '苫小牧市', 'トマコマイシ', '三光町', 'サンコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫小牧市日の出町', '01', '01213', '0530043', '北海道', 'ホッカイドウ', '苫小牧市', 'トマコマイシ', '日の出町', 'ヒノデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫小牧市音羽町', '01', '01213', '0530044', '北海道', 'ホッカイドウ', '苫小牧市', 'トマコマイシ', '音羽町', 'オトワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫小牧市双葉町', '01', '01213', '0530045', '北海道', 'ホッカイドウ', '苫小牧市', 'トマコマイシ', '双葉町', 'フタバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫小牧市住吉町', '01', '01213', '0530046', '北海道', 'ホッカイドウ', '苫小牧市', 'トマコマイシ', '住吉町', 'スミヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫小牧市泉町', '01', '01213', '0530047', '北海道', 'ホッカイドウ', '苫小牧市', 'トマコマイシ', '泉町', 'イズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫小牧市明野元町', '01', '01213', '0530051', '北海道', 'ホッカイドウ', '苫小牧市', 'トマコマイシ', '明野元町', 'アケノモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫小牧市新開町', '01', '01213', '0530052', '北海道', 'ホッカイドウ', '苫小牧市', 'トマコマイシ', '新開町', 'シンカイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫小牧市柳町', '01', '01213', '0530053', '北海道', 'ホッカイドウ', '苫小牧市', 'トマコマイシ', '柳町', 'ヤナギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫小牧市明野新町', '01', '01213', '0530054', '北海道', 'ホッカイドウ', '苫小牧市', 'トマコマイシ', '明野新町', 'アケノシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫小牧市新明町', '01', '01213', '0530055', '北海道', 'ホッカイドウ', '苫小牧市', 'トマコマイシ', '新明町', 'シンメイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫小牧市あけぼの町3丁目', '01', '01213', '0530056', '北海道', 'ホッカイドウ', '苫小牧市', 'トマコマイシ', 'あけぼの町', 'アケボノチョウ', null, null, '3丁目', '03チョウメ');
INSERT INTO `ms_addresses` VALUES ('59524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫小牧市あけぼの町4丁目', '01', '01213', '0530056', '北海道', 'ホッカイドウ', '苫小牧市', 'トマコマイシ', 'あけぼの町', 'アケボノチョウ', null, null, '4丁目', '04チョウメ');
INSERT INTO `ms_addresses` VALUES ('59525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫小牧市あけぼの町5丁目', '01', '01213', '0530056', '北海道', 'ホッカイドウ', '苫小牧市', 'トマコマイシ', 'あけぼの町', 'アケボノチョウ', null, null, '5丁目', '05チョウメ');
INSERT INTO `ms_addresses` VALUES ('59526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区天満橋OAPタワー　1階', '27', '27127', '5306001', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '天満橋', 'テンマバシ', null, null, 'OAPタワー　1階', 'OAPタワー　01カイ');
INSERT INTO `ms_addresses` VALUES ('59527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区天満橋OAPタワー　2階', '27', '27127', '5306002', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '天満橋', 'テンマバシ', null, null, 'OAPタワー　2階', 'OAPタワー　02カイ');
INSERT INTO `ms_addresses` VALUES ('59528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区天満橋OAPタワー　3階', '27', '27127', '5306003', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '天満橋', 'テンマバシ', null, null, 'OAPタワー　3階', 'OAPタワー　03カイ');
INSERT INTO `ms_addresses` VALUES ('59529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区天満橋OAPタワー　4階', '27', '27127', '5306004', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '天満橋', 'テンマバシ', null, null, 'OAPタワー　4階', 'OAPタワー　04カイ');
INSERT INTO `ms_addresses` VALUES ('59530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区天満橋OAPタワー　5階', '27', '27127', '5306005', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '天満橋', 'テンマバシ', null, null, 'OAPタワー　5階', 'OAPタワー　05カイ');
INSERT INTO `ms_addresses` VALUES ('59531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区天満橋OAPタワー　6階', '27', '27127', '5306006', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '天満橋', 'テンマバシ', null, null, 'OAPタワー　6階', 'OAPタワー　06カイ');
INSERT INTO `ms_addresses` VALUES ('59532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区天満橋OAPタワー　7階', '27', '27127', '5306007', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '天満橋', 'テンマバシ', null, null, 'OAPタワー　7階', 'OAPタワー　07カイ');
INSERT INTO `ms_addresses` VALUES ('59533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区天満橋OAPタワー　8階', '27', '27127', '5306008', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '天満橋', 'テンマバシ', null, null, 'OAPタワー　8階', 'OAPタワー　08カイ');
INSERT INTO `ms_addresses` VALUES ('59534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区天満橋OAPタワー　9階', '27', '27127', '5306009', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '天満橋', 'テンマバシ', null, null, 'OAPタワー　9階', 'OAPタワー　09カイ');
INSERT INTO `ms_addresses` VALUES ('59535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区天満橋OAPタワー　10階', '27', '27127', '5306010', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '天満橋', 'テンマバシ', null, null, 'OAPタワー　10階', 'OAPタワー　10カイ');
INSERT INTO `ms_addresses` VALUES ('59536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区天満橋OAPタワー　11階', '27', '27127', '5306011', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '天満橋', 'テンマバシ', null, null, 'OAPタワー　11階', 'OAPタワー　11カイ');
INSERT INTO `ms_addresses` VALUES ('59537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区天満橋OAPタワー　12階', '27', '27127', '5306012', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '天満橋', 'テンマバシ', null, null, 'OAPタワー　12階', 'OAPタワー　12カイ');
INSERT INTO `ms_addresses` VALUES ('59538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区天満橋OAPタワー　13階', '27', '27127', '5306013', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '天満橋', 'テンマバシ', null, null, 'OAPタワー　13階', 'OAPタワー　13カイ');
INSERT INTO `ms_addresses` VALUES ('59539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区天満橋OAPタワー　14階', '27', '27127', '5306014', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '天満橋', 'テンマバシ', null, null, 'OAPタワー　14階', 'OAPタワー　14カイ');
INSERT INTO `ms_addresses` VALUES ('59540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区天満橋OAPタワー　15階', '27', '27127', '5306015', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '天満橋', 'テンマバシ', null, null, 'OAPタワー　15階', 'OAPタワー　15カイ');
INSERT INTO `ms_addresses` VALUES ('59541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区天満橋OAPタワー　16階', '27', '27127', '5306016', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '天満橋', 'テンマバシ', null, null, 'OAPタワー　16階', 'OAPタワー　16カイ');
INSERT INTO `ms_addresses` VALUES ('59542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区天満橋OAPタワー　17階', '27', '27127', '5306017', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '天満橋', 'テンマバシ', null, null, 'OAPタワー　17階', 'OAPタワー　17カイ');
INSERT INTO `ms_addresses` VALUES ('59543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区天満橋OAPタワー　18階', '27', '27127', '5306018', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '天満橋', 'テンマバシ', null, null, 'OAPタワー　18階', 'OAPタワー　18カイ');
INSERT INTO `ms_addresses` VALUES ('59544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区天満橋OAPタワー　19階', '27', '27127', '5306019', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '天満橋', 'テンマバシ', null, null, 'OAPタワー　19階', 'OAPタワー　19カイ');
INSERT INTO `ms_addresses` VALUES ('59545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区天満橋OAPタワー　20階', '27', '27127', '5306020', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '天満橋', 'テンマバシ', null, null, 'OAPタワー　20階', 'OAPタワー　20カイ');
INSERT INTO `ms_addresses` VALUES ('59546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区天満橋OAPタワー　21階', '27', '27127', '5306021', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '天満橋', 'テンマバシ', null, null, 'OAPタワー　21階', 'OAPタワー　21カイ');
INSERT INTO `ms_addresses` VALUES ('59547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区天満橋OAPタワー　22階', '27', '27127', '5306022', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '天満橋', 'テンマバシ', null, null, 'OAPタワー　22階', 'OAPタワー　22カイ');
INSERT INTO `ms_addresses` VALUES ('59548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区天満橋OAPタワー　23階', '27', '27127', '5306023', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '天満橋', 'テンマバシ', null, null, 'OAPタワー　23階', 'OAPタワー　23カイ');
INSERT INTO `ms_addresses` VALUES ('59549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区天満橋OAPタワー　24階', '27', '27127', '5306024', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '天満橋', 'テンマバシ', null, null, 'OAPタワー　24階', 'OAPタワー　24カイ');
INSERT INTO `ms_addresses` VALUES ('59550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区天満橋OAPタワー　25階', '27', '27127', '5306025', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '天満橋', 'テンマバシ', null, null, 'OAPタワー　25階', 'OAPタワー　25カイ');
INSERT INTO `ms_addresses` VALUES ('59551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区天満橋OAPタワー　26階', '27', '27127', '5306026', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '天満橋', 'テンマバシ', null, null, 'OAPタワー　26階', 'OAPタワー　26カイ');
INSERT INTO `ms_addresses` VALUES ('59552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区天満橋OAPタワー　27階', '27', '27127', '5306027', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '天満橋', 'テンマバシ', null, null, 'OAPタワー　27階', 'OAPタワー　27カイ');
INSERT INTO `ms_addresses` VALUES ('59553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区天満橋OAPタワー　28階', '27', '27127', '5306028', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '天満橋', 'テンマバシ', null, null, 'OAPタワー　28階', 'OAPタワー　28カイ');
INSERT INTO `ms_addresses` VALUES ('59554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区天満橋OAPタワー　29階', '27', '27127', '5306029', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '天満橋', 'テンマバシ', null, null, 'OAPタワー　29階', 'OAPタワー　29カイ');
INSERT INTO `ms_addresses` VALUES ('59555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区天満橋OAPタワー　30階', '27', '27127', '5306030', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '天満橋', 'テンマバシ', null, null, 'OAPタワー　30階', 'OAPタワー　30カイ');
INSERT INTO `ms_addresses` VALUES ('59556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区天満橋OAPタワー　31階', '27', '27127', '5306031', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '天満橋', 'テンマバシ', null, null, 'OAPタワー　31階', 'OAPタワー　31カイ');
INSERT INTO `ms_addresses` VALUES ('59557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区天満橋OAPタワー　32階', '27', '27127', '5306032', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '天満橋', 'テンマバシ', null, null, 'OAPタワー　32階', 'OAPタワー　32カイ');
INSERT INTO `ms_addresses` VALUES ('59558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区天満橋OAPタワー　33階', '27', '27127', '5306033', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '天満橋', 'テンマバシ', null, null, 'OAPタワー　33階', 'OAPタワー　33カイ');
INSERT INTO `ms_addresses` VALUES ('59559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区天満橋OAPタワー　34階', '27', '27127', '5306034', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '天満橋', 'テンマバシ', null, null, 'OAPタワー　34階', 'OAPタワー　34カイ');
INSERT INTO `ms_addresses` VALUES ('59560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区天満橋OAPタワー　35階', '27', '27127', '5306035', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '天満橋', 'テンマバシ', null, null, 'OAPタワー　35階', 'OAPタワー　35カイ');
INSERT INTO `ms_addresses` VALUES ('59561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区天満橋OAPタワー　36階', '27', '27127', '5306036', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '天満橋', 'テンマバシ', null, null, 'OAPタワー　36階', 'OAPタワー　36カイ');
INSERT INTO `ms_addresses` VALUES ('59562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区天満橋OAPタワー　37階', '27', '27127', '5306037', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '天満橋', 'テンマバシ', null, null, 'OAPタワー　37階', 'OAPタワー　37カイ');
INSERT INTO `ms_addresses` VALUES ('59563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区天満橋OAPタワー　38階', '27', '27127', '5306038', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '天満橋', 'テンマバシ', null, null, 'OAPタワー　38階', 'OAPタワー　38カイ');
INSERT INTO `ms_addresses` VALUES ('59564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区天満橋OAPタワー　39階', '27', '27127', '5306039', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '天満橋', 'テンマバシ', null, null, 'OAPタワー　39階', 'OAPタワー　39カイ');
INSERT INTO `ms_addresses` VALUES ('59565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区天満橋OAPタワー　', '27', '27127', '5306090', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '天満橋', 'テンマバシ', null, null, 'OAPタワー　', 'OAPタワー　');
INSERT INTO `ms_addresses` VALUES ('59566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区中之島中之島ダイビル　1階', '27', '27127', '5306101', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '中之島', 'ナカノシマ', null, null, '中之島ダイビル　1階', 'ナカノシマダイビル　01カイ');
INSERT INTO `ms_addresses` VALUES ('59567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区中之島中之島ダイビル　2階', '27', '27127', '5306102', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '中之島', 'ナカノシマ', null, null, '中之島ダイビル　2階', 'ナカノシマダイビル　02カイ');
INSERT INTO `ms_addresses` VALUES ('59568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区中之島中之島ダイビル　3階', '27', '27127', '5306103', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '中之島', 'ナカノシマ', null, null, '中之島ダイビル　3階', 'ナカノシマダイビル　03カイ');
INSERT INTO `ms_addresses` VALUES ('59569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区中之島中之島ダイビル　4階', '27', '27127', '5306104', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '中之島', 'ナカノシマ', null, null, '中之島ダイビル　4階', 'ナカノシマダイビル　04カイ');
INSERT INTO `ms_addresses` VALUES ('59570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区中之島中之島ダイビル　5階', '27', '27127', '5306105', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '中之島', 'ナカノシマ', null, null, '中之島ダイビル　5階', 'ナカノシマダイビル　05カイ');
INSERT INTO `ms_addresses` VALUES ('59571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区中之島中之島ダイビル　6階', '27', '27127', '5306106', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '中之島', 'ナカノシマ', null, null, '中之島ダイビル　6階', 'ナカノシマダイビル　06カイ');
INSERT INTO `ms_addresses` VALUES ('59572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区中之島中之島ダイビル　7階', '27', '27127', '5306107', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '中之島', 'ナカノシマ', null, null, '中之島ダイビル　7階', 'ナカノシマダイビル　07カイ');
INSERT INTO `ms_addresses` VALUES ('59573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区中之島中之島ダイビル　8階', '27', '27127', '5306108', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '中之島', 'ナカノシマ', null, null, '中之島ダイビル　8階', 'ナカノシマダイビル　08カイ');
INSERT INTO `ms_addresses` VALUES ('59574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区中之島中之島ダイビル　9階', '27', '27127', '5306109', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '中之島', 'ナカノシマ', null, null, '中之島ダイビル　9階', 'ナカノシマダイビル　09カイ');
INSERT INTO `ms_addresses` VALUES ('59575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区中之島中之島ダイビル　10階', '27', '27127', '5306110', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '中之島', 'ナカノシマ', null, null, '中之島ダイビル　10階', 'ナカノシマダイビル　10カイ');
INSERT INTO `ms_addresses` VALUES ('59576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区中之島中之島ダイビル　11階', '27', '27127', '5306111', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '中之島', 'ナカノシマ', null, null, '中之島ダイビル　11階', 'ナカノシマダイビル　11カイ');
INSERT INTO `ms_addresses` VALUES ('59577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区中之島中之島ダイビル　12階', '27', '27127', '5306112', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '中之島', 'ナカノシマ', null, null, '中之島ダイビル　12階', 'ナカノシマダイビル　12カイ');
INSERT INTO `ms_addresses` VALUES ('59578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区中之島中之島ダイビル　13階', '27', '27127', '5306113', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '中之島', 'ナカノシマ', null, null, '中之島ダイビル　13階', 'ナカノシマダイビル　13カイ');
INSERT INTO `ms_addresses` VALUES ('59579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区中之島中之島ダイビル　14階', '27', '27127', '5306114', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '中之島', 'ナカノシマ', null, null, '中之島ダイビル　14階', 'ナカノシマダイビル　14カイ');
INSERT INTO `ms_addresses` VALUES ('59580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区中之島中之島ダイビル　15階', '27', '27127', '5306115', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '中之島', 'ナカノシマ', null, null, '中之島ダイビル　15階', 'ナカノシマダイビル　15カイ');
INSERT INTO `ms_addresses` VALUES ('59581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区中之島中之島ダイビル　16階', '27', '27127', '5306116', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '中之島', 'ナカノシマ', null, null, '中之島ダイビル　16階', 'ナカノシマダイビル　16カイ');
INSERT INTO `ms_addresses` VALUES ('59582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区中之島中之島ダイビル　17階', '27', '27127', '5306117', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '中之島', 'ナカノシマ', null, null, '中之島ダイビル　17階', 'ナカノシマダイビル　17カイ');
INSERT INTO `ms_addresses` VALUES ('59583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区中之島中之島ダイビル　18階', '27', '27127', '5306118', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '中之島', 'ナカノシマ', null, null, '中之島ダイビル　18階', 'ナカノシマダイビル　18カイ');
INSERT INTO `ms_addresses` VALUES ('59584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区中之島中之島ダイビル　19階', '27', '27127', '5306119', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '中之島', 'ナカノシマ', null, null, '中之島ダイビル　19階', 'ナカノシマダイビル　19カイ');
INSERT INTO `ms_addresses` VALUES ('59585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区中之島中之島ダイビル　20階', '27', '27127', '5306120', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '中之島', 'ナカノシマ', null, null, '中之島ダイビル　20階', 'ナカノシマダイビル　20カイ');
INSERT INTO `ms_addresses` VALUES ('59586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区中之島中之島ダイビル　21階', '27', '27127', '5306121', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '中之島', 'ナカノシマ', null, null, '中之島ダイビル　21階', 'ナカノシマダイビル　21カイ');
INSERT INTO `ms_addresses` VALUES ('59587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区中之島中之島ダイビル　22階', '27', '27127', '5306122', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '中之島', 'ナカノシマ', null, null, '中之島ダイビル　22階', 'ナカノシマダイビル　22カイ');
INSERT INTO `ms_addresses` VALUES ('59588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区中之島中之島ダイビル　23階', '27', '27127', '5306123', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '中之島', 'ナカノシマ', null, null, '中之島ダイビル　23階', 'ナカノシマダイビル　23カイ');
INSERT INTO `ms_addresses` VALUES ('59589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区中之島中之島ダイビル　24階', '27', '27127', '5306124', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '中之島', 'ナカノシマ', null, null, '中之島ダイビル　24階', 'ナカノシマダイビル　24カイ');
INSERT INTO `ms_addresses` VALUES ('59590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区中之島中之島ダイビル　25階', '27', '27127', '5306125', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '中之島', 'ナカノシマ', null, null, '中之島ダイビル　25階', 'ナカノシマダイビル　25カイ');
INSERT INTO `ms_addresses` VALUES ('59591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区中之島中之島ダイビル　26階', '27', '27127', '5306126', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '中之島', 'ナカノシマ', null, null, '中之島ダイビル　26階', 'ナカノシマダイビル　26カイ');
INSERT INTO `ms_addresses` VALUES ('59592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区中之島中之島ダイビル　27階', '27', '27127', '5306127', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '中之島', 'ナカノシマ', null, null, '中之島ダイビル　27階', 'ナカノシマダイビル　27カイ');
INSERT INTO `ms_addresses` VALUES ('59593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区中之島中之島ダイビル　28階', '27', '27127', '5306128', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '中之島', 'ナカノシマ', null, null, '中之島ダイビル　28階', 'ナカノシマダイビル　28カイ');
INSERT INTO `ms_addresses` VALUES ('59594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区中之島中之島ダイビル　29階', '27', '27127', '5306129', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '中之島', 'ナカノシマ', null, null, '中之島ダイビル　29階', 'ナカノシマダイビル　29カイ');
INSERT INTO `ms_addresses` VALUES ('59595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区中之島中之島ダイビル　30階', '27', '27127', '5306130', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '中之島', 'ナカノシマ', null, null, '中之島ダイビル　30階', 'ナカノシマダイビル　30カイ');
INSERT INTO `ms_addresses` VALUES ('59596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区中之島中之島ダイビル　31階', '27', '27127', '5306131', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '中之島', 'ナカノシマ', null, null, '中之島ダイビル　31階', 'ナカノシマダイビル　31カイ');
INSERT INTO `ms_addresses` VALUES ('59597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区中之島中之島ダイビル　32階', '27', '27127', '5306132', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '中之島', 'ナカノシマ', null, null, '中之島ダイビル　32階', 'ナカノシマダイビル　32カイ');
INSERT INTO `ms_addresses` VALUES ('59598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区中之島中之島ダイビル　33階', '27', '27127', '5306133', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '中之島', 'ナカノシマ', null, null, '中之島ダイビル　33階', 'ナカノシマダイビル　33カイ');
INSERT INTO `ms_addresses` VALUES ('59599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区中之島中之島ダイビル　34階', '27', '27127', '5306134', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '中之島', 'ナカノシマ', null, null, '中之島ダイビル　34階', 'ナカノシマダイビル　34カイ');
INSERT INTO `ms_addresses` VALUES ('59600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区中之島中之島ダイビル　35階', '27', '27127', '5306135', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '中之島', 'ナカノシマ', null, null, '中之島ダイビル　35階', 'ナカノシマダイビル　35カイ');
INSERT INTO `ms_addresses` VALUES ('59601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区中之島中之島ダイビル　', '27', '27127', '5306190', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '中之島', 'ナカノシマ', null, null, '中之島ダイビル　', 'ナカノシマダイビル　');
INSERT INTO `ms_addresses` VALUES ('59602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫小牧市白金町', '01', '01213', '0530801', '北海道', 'ホッカイドウ', '苫小牧市', 'トマコマイシ', '白金町', 'シロガネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫小牧市弥生町', '01', '01213', '0530802', '北海道', 'ホッカイドウ', '苫小牧市', 'トマコマイシ', '弥生町', 'ヤヨイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫小牧市矢代町', '01', '01213', '0530803', '北海道', 'ホッカイドウ', '苫小牧市', 'トマコマイシ', '矢代町', 'ヤシロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫小牧市元町', '01', '01213', '0530804', '北海道', 'ホッカイドウ', '苫小牧市', 'トマコマイシ', '元町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫小牧市新富町', '01', '01213', '0530805', '北海道', 'ホッカイドウ', '苫小牧市', 'トマコマイシ', '新富町', 'シントミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫小牧市大成町', '01', '01213', '0530806', '北海道', 'ホッカイドウ', '苫小牧市', 'トマコマイシ', '大成町', 'タイセイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫小牧市青葉町', '01', '01213', '0530807', '北海道', 'ホッカイドウ', '苫小牧市', 'トマコマイシ', '青葉町', 'アオバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫小牧市光洋町', '01', '01213', '0530811', '北海道', 'ホッカイドウ', '苫小牧市', 'トマコマイシ', '光洋町', 'コウヨウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫小牧市有明町', '01', '01213', '0530812', '北海道', 'ホッカイドウ', '苫小牧市', 'トマコマイシ', '有明町', 'アリアケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫小牧市小糸井町', '01', '01213', '0530813', '北海道', 'ホッカイドウ', '苫小牧市', 'トマコマイシ', '小糸井町', 'コイトイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫小牧市糸井', '01', '01213', '0530814', '北海道', 'ホッカイドウ', '苫小牧市', 'トマコマイシ', '糸井', 'イトイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫小牧市永福町', '01', '01213', '0530815', '北海道', 'ホッカイドウ', '苫小牧市', 'トマコマイシ', '永福町', 'エイフクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫小牧市日吉町', '01', '01213', '0530816', '北海道', 'ホッカイドウ', '苫小牧市', 'トマコマイシ', '日吉町', 'ヒヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫小牧市しらかば町', '01', '01213', '0530821', '北海道', 'ホッカイドウ', '苫小牧市', 'トマコマイシ', 'しらかば町', 'シラカバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫小牧市川沿町', '01', '01213', '0530822', '北海道', 'ホッカイドウ', '苫小牧市', 'トマコマイシ', '川沿町', 'カワゾエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫小牧市柏木町', '01', '01213', '0530823', '北海道', 'ホッカイドウ', '苫小牧市', 'トマコマイシ', '柏木町', 'カシワギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫小牧市豊川町', '01', '01213', '0530831', '北海道', 'ホッカイドウ', '苫小牧市', 'トマコマイシ', '豊川町', 'トヨカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫小牧市桜木町', '01', '01213', '0530832', '北海道', 'ホッカイドウ', '苫小牧市', 'トマコマイシ', '桜木町', 'サクラギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫小牧市日新町', '01', '01213', '0530833', '北海道', 'ホッカイドウ', '苫小牧市', 'トマコマイシ', '日新町', 'ニッシンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫小牧市松風町', '01', '01213', '0530841', '北海道', 'ホッカイドウ', '苫小牧市', 'トマコマイシ', '松風町', 'マツカゼチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫小牧市有珠の沢町', '01', '01213', '0530842', '北海道', 'ホッカイドウ', '苫小牧市', 'トマコマイシ', '有珠の沢町', 'ウスノサワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫小牧市桜坂町', '01', '01213', '0530843', '北海道', 'ホッカイドウ', '苫小牧市', 'トマコマイシ', '桜坂町', 'サクラザカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫小牧市宮の森町', '01', '01213', '0530844', '北海道', 'ホッカイドウ', '苫小牧市', 'トマコマイシ', '宮の森町', 'ミヤノモリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫小牧市はまなす町1丁目', '01', '01213', '0530845', '北海道', 'ホッカイドウ', '苫小牧市', 'トマコマイシ', 'はまなす町', 'ハマナスチョウ', null, null, '1丁目', '01チョウメ');
INSERT INTO `ms_addresses` VALUES ('59674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫小牧市山手町', '01', '01213', '0530851', '北海道', 'ホッカイドウ', '苫小牧市', 'トマコマイシ', '山手町', 'ヤマテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫小牧市北光町', '01', '01213', '0530852', '北海道', 'ホッカイドウ', '苫小牧市', 'トマコマイシ', '北光町', 'ホッコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫小牧市花園町', '01', '01213', '0530853', '北海道', 'ホッカイドウ', '苫小牧市', 'トマコマイシ', '花園町', 'ハナゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫小牧市啓北町', '01', '01213', '0530854', '北海道', 'ホッカイドウ', '苫小牧市', 'トマコマイシ', '啓北町', 'ケイホクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫小牧市見山町', '01', '01213', '0530855', '北海道', 'ホッカイドウ', '苫小牧市', 'トマコマイシ', '見山町', 'ミヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区天神橋7丁目', '27', '27127', '5310041', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '天神橋', 'テンジンバシ', null, null, '7丁目', '07チョウメ');
INSERT INTO `ms_addresses` VALUES ('59718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区天神橋8丁目', '27', '27127', '5310041', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '天神橋', 'テンジンバシ', null, null, '8丁目', '08チョウメ');
INSERT INTO `ms_addresses` VALUES ('59719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区長柄西', '27', '27127', '5310061', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '長柄西', 'ナガラニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区長柄中', '27', '27127', '5310062', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '長柄中', 'ナガラナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区長柄東', '27', '27127', '5310063', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '長柄東', 'ナガラヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区国分寺', '27', '27127', '5310064', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '国分寺', 'コクブンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区中津', '27', '27127', '5310071', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '中津', 'ナカツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区豊崎', '27', '27127', '5310072', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '豊崎', 'トヨサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区本庄西', '27', '27127', '5310073', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '本庄西', 'ホンジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区本庄東', '27', '27127', '5310074', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '本庄東', 'ホンジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区大淀南', '27', '27127', '5310075', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '大淀南', 'オオヨドミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区大淀中', '27', '27127', '5310076', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '大淀中', 'オオヨドナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区大淀北', '27', '27127', '5310077', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '大淀北', 'オオヨドキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区大淀中梅田スカイビルタワーイースト　1階', '27', '27127', '5316001', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '大淀中', 'オオヨドナカ', null, null, '梅田スカイビルタワーイースト　1階', 'ウメダスカイビルタワーイースト　01カイ');
INSERT INTO `ms_addresses` VALUES ('59731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区大淀中梅田スカイビルタワーイースト　2階', '27', '27127', '5316002', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '大淀中', 'オオヨドナカ', null, null, '梅田スカイビルタワーイースト　2階', 'ウメダスカイビルタワーイースト　02カイ');
INSERT INTO `ms_addresses` VALUES ('59732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区大淀中梅田スカイビルタワーイースト　3階', '27', '27127', '5316003', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '大淀中', 'オオヨドナカ', null, null, '梅田スカイビルタワーイースト　3階', 'ウメダスカイビルタワーイースト　03カイ');
INSERT INTO `ms_addresses` VALUES ('59733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区大淀中梅田スカイビルタワーイースト　4階', '27', '27127', '5316004', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '大淀中', 'オオヨドナカ', null, null, '梅田スカイビルタワーイースト　4階', 'ウメダスカイビルタワーイースト　04カイ');
INSERT INTO `ms_addresses` VALUES ('59734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区大淀中梅田スカイビルタワーイースト　5階', '27', '27127', '5316005', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '大淀中', 'オオヨドナカ', null, null, '梅田スカイビルタワーイースト　5階', 'ウメダスカイビルタワーイースト　05カイ');
INSERT INTO `ms_addresses` VALUES ('59735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区大淀中梅田スカイビルタワーイースト　6階', '27', '27127', '5316006', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '大淀中', 'オオヨドナカ', null, null, '梅田スカイビルタワーイースト　6階', 'ウメダスカイビルタワーイースト　06カイ');
INSERT INTO `ms_addresses` VALUES ('59736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区大淀中梅田スカイビルタワーイースト　7階', '27', '27127', '5316007', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '大淀中', 'オオヨドナカ', null, null, '梅田スカイビルタワーイースト　7階', 'ウメダスカイビルタワーイースト　07カイ');
INSERT INTO `ms_addresses` VALUES ('59737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区大淀中梅田スカイビルタワーイースト　8階', '27', '27127', '5316008', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '大淀中', 'オオヨドナカ', null, null, '梅田スカイビルタワーイースト　8階', 'ウメダスカイビルタワーイースト　08カイ');
INSERT INTO `ms_addresses` VALUES ('59738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区大淀中梅田スカイビルタワーイースト　9階', '27', '27127', '5316009', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '大淀中', 'オオヨドナカ', null, null, '梅田スカイビルタワーイースト　9階', 'ウメダスカイビルタワーイースト　09カイ');
INSERT INTO `ms_addresses` VALUES ('59739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区大淀中梅田スカイビルタワーイースト　10階', '27', '27127', '5316010', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '大淀中', 'オオヨドナカ', null, null, '梅田スカイビルタワーイースト　10階', 'ウメダスカイビルタワーイースト　10カイ');
INSERT INTO `ms_addresses` VALUES ('59740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区大淀中梅田スカイビルタワーイースト　11階', '27', '27127', '5316011', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '大淀中', 'オオヨドナカ', null, null, '梅田スカイビルタワーイースト　11階', 'ウメダスカイビルタワーイースト　11カイ');
INSERT INTO `ms_addresses` VALUES ('59741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区大淀中梅田スカイビルタワーイースト　12階', '27', '27127', '5316012', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '大淀中', 'オオヨドナカ', null, null, '梅田スカイビルタワーイースト　12階', 'ウメダスカイビルタワーイースト　12カイ');
INSERT INTO `ms_addresses` VALUES ('59742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区大淀中梅田スカイビルタワーイースト　13階', '27', '27127', '5316013', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '大淀中', 'オオヨドナカ', null, null, '梅田スカイビルタワーイースト　13階', 'ウメダスカイビルタワーイースト　13カイ');
INSERT INTO `ms_addresses` VALUES ('59743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区大淀中梅田スカイビルタワーイースト　14階', '27', '27127', '5316014', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '大淀中', 'オオヨドナカ', null, null, '梅田スカイビルタワーイースト　14階', 'ウメダスカイビルタワーイースト　14カイ');
INSERT INTO `ms_addresses` VALUES ('59744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区大淀中梅田スカイビルタワーイースト　15階', '27', '27127', '5316015', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '大淀中', 'オオヨドナカ', null, null, '梅田スカイビルタワーイースト　15階', 'ウメダスカイビルタワーイースト　15カイ');
INSERT INTO `ms_addresses` VALUES ('59745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区大淀中梅田スカイビルタワーイースト　16階', '27', '27127', '5316016', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '大淀中', 'オオヨドナカ', null, null, '梅田スカイビルタワーイースト　16階', 'ウメダスカイビルタワーイースト　16カイ');
INSERT INTO `ms_addresses` VALUES ('59746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区大淀中梅田スカイビルタワーイースト　17階', '27', '27127', '5316017', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '大淀中', 'オオヨドナカ', null, null, '梅田スカイビルタワーイースト　17階', 'ウメダスカイビルタワーイースト　17カイ');
INSERT INTO `ms_addresses` VALUES ('59747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区大淀中梅田スカイビルタワーイースト　18階', '27', '27127', '5316018', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '大淀中', 'オオヨドナカ', null, null, '梅田スカイビルタワーイースト　18階', 'ウメダスカイビルタワーイースト　18カイ');
INSERT INTO `ms_addresses` VALUES ('59748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区大淀中梅田スカイビルタワーイースト　19階', '27', '27127', '5316019', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '大淀中', 'オオヨドナカ', null, null, '梅田スカイビルタワーイースト　19階', 'ウメダスカイビルタワーイースト　19カイ');
INSERT INTO `ms_addresses` VALUES ('59749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区大淀中梅田スカイビルタワーイースト　20階', '27', '27127', '5316020', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '大淀中', 'オオヨドナカ', null, null, '梅田スカイビルタワーイースト　20階', 'ウメダスカイビルタワーイースト　20カイ');
INSERT INTO `ms_addresses` VALUES ('59750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区大淀中梅田スカイビルタワーイースト　21階', '27', '27127', '5316021', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '大淀中', 'オオヨドナカ', null, null, '梅田スカイビルタワーイースト　21階', 'ウメダスカイビルタワーイースト　21カイ');
INSERT INTO `ms_addresses` VALUES ('59751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区大淀中梅田スカイビルタワーイースト　22階', '27', '27127', '5316022', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '大淀中', 'オオヨドナカ', null, null, '梅田スカイビルタワーイースト　22階', 'ウメダスカイビルタワーイースト　22カイ');
INSERT INTO `ms_addresses` VALUES ('59752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区大淀中梅田スカイビルタワーイースト　23階', '27', '27127', '5316023', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '大淀中', 'オオヨドナカ', null, null, '梅田スカイビルタワーイースト　23階', 'ウメダスカイビルタワーイースト　23カイ');
INSERT INTO `ms_addresses` VALUES ('59753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区大淀中梅田スカイビルタワーイースト　24階', '27', '27127', '5316024', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '大淀中', 'オオヨドナカ', null, null, '梅田スカイビルタワーイースト　24階', 'ウメダスカイビルタワーイースト　24カイ');
INSERT INTO `ms_addresses` VALUES ('59754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区大淀中梅田スカイビルタワーイースト　25階', '27', '27127', '5316025', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '大淀中', 'オオヨドナカ', null, null, '梅田スカイビルタワーイースト　25階', 'ウメダスカイビルタワーイースト　25カイ');
INSERT INTO `ms_addresses` VALUES ('59755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区大淀中梅田スカイビルタワーイースト　26階', '27', '27127', '5316026', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '大淀中', 'オオヨドナカ', null, null, '梅田スカイビルタワーイースト　26階', 'ウメダスカイビルタワーイースト　26カイ');
INSERT INTO `ms_addresses` VALUES ('59756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区大淀中梅田スカイビルタワーイースト　27階', '27', '27127', '5316027', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '大淀中', 'オオヨドナカ', null, null, '梅田スカイビルタワーイースト　27階', 'ウメダスカイビルタワーイースト　27カイ');
INSERT INTO `ms_addresses` VALUES ('59757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区大淀中梅田スカイビルタワーイースト　28階', '27', '27127', '5316028', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '大淀中', 'オオヨドナカ', null, null, '梅田スカイビルタワーイースト　28階', 'ウメダスカイビルタワーイースト　28カイ');
INSERT INTO `ms_addresses` VALUES ('59758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区大淀中梅田スカイビルタワーイースト　29階', '27', '27127', '5316029', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '大淀中', 'オオヨドナカ', null, null, '梅田スカイビルタワーイースト　29階', 'ウメダスカイビルタワーイースト　29カイ');
INSERT INTO `ms_addresses` VALUES ('59759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区大淀中梅田スカイビルタワーイースト　30階', '27', '27127', '5316030', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '大淀中', 'オオヨドナカ', null, null, '梅田スカイビルタワーイースト　30階', 'ウメダスカイビルタワーイースト　30カイ');
INSERT INTO `ms_addresses` VALUES ('59760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区大淀中梅田スカイビルタワーイースト　31階', '27', '27127', '5316031', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '大淀中', 'オオヨドナカ', null, null, '梅田スカイビルタワーイースト　31階', 'ウメダスカイビルタワーイースト　31カイ');
INSERT INTO `ms_addresses` VALUES ('59761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区大淀中梅田スカイビルタワーイースト　32階', '27', '27127', '5316032', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '大淀中', 'オオヨドナカ', null, null, '梅田スカイビルタワーイースト　32階', 'ウメダスカイビルタワーイースト　32カイ');
INSERT INTO `ms_addresses` VALUES ('59762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区大淀中梅田スカイビルタワーイースト　33階', '27', '27127', '5316033', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '大淀中', 'オオヨドナカ', null, null, '梅田スカイビルタワーイースト　33階', 'ウメダスカイビルタワーイースト　33カイ');
INSERT INTO `ms_addresses` VALUES ('59763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区大淀中梅田スカイビルタワーイースト　34階', '27', '27127', '5316034', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '大淀中', 'オオヨドナカ', null, null, '梅田スカイビルタワーイースト　34階', 'ウメダスカイビルタワーイースト　34カイ');
INSERT INTO `ms_addresses` VALUES ('59764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区大淀中梅田スカイビルタワーイースト　35階', '27', '27127', '5316035', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '大淀中', 'オオヨドナカ', null, null, '梅田スカイビルタワーイースト　35階', 'ウメダスカイビルタワーイースト　35カイ');
INSERT INTO `ms_addresses` VALUES ('59765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区大淀中梅田スカイビルタワーイースト　36階', '27', '27127', '5316036', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '大淀中', 'オオヨドナカ', null, null, '梅田スカイビルタワーイースト　36階', 'ウメダスカイビルタワーイースト　36カイ');
INSERT INTO `ms_addresses` VALUES ('59766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区大淀中梅田スカイビルタワーイースト　37階', '27', '27127', '5316037', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '大淀中', 'オオヨドナカ', null, null, '梅田スカイビルタワーイースト　37階', 'ウメダスカイビルタワーイースト　37カイ');
INSERT INTO `ms_addresses` VALUES ('59767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区大淀中梅田スカイビルタワーイースト　38階', '27', '27127', '5316038', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '大淀中', 'オオヨドナカ', null, null, '梅田スカイビルタワーイースト　38階', 'ウメダスカイビルタワーイースト　38カイ');
INSERT INTO `ms_addresses` VALUES ('59768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区大淀中梅田スカイビルタワーイースト　39階', '27', '27127', '5316039', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '大淀中', 'オオヨドナカ', null, null, '梅田スカイビルタワーイースト　39階', 'ウメダスカイビルタワーイースト　39カイ');
INSERT INTO `ms_addresses` VALUES ('59769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区大淀中梅田スカイビルタワーイースト　', '27', '27127', '5316090', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '大淀中', 'オオヨドナカ', null, null, '梅田スカイビルタワーイースト　', 'ウメダスカイビルタワーイースト　');
INSERT INTO `ms_addresses` VALUES ('59770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区大淀中梅田スカイビルタワーウエスト　1階', '27', '27127', '5316101', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '大淀中', 'オオヨドナカ', null, null, '梅田スカイビルタワーウエスト　1階', 'ウメダスカイビルタワーウエスト　01カイ');
INSERT INTO `ms_addresses` VALUES ('59771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区大淀中梅田スカイビルタワーウエスト　2階', '27', '27127', '5316102', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '大淀中', 'オオヨドナカ', null, null, '梅田スカイビルタワーウエスト　2階', 'ウメダスカイビルタワーウエスト　02カイ');
INSERT INTO `ms_addresses` VALUES ('59772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区大淀中梅田スカイビルタワーウエスト　3階', '27', '27127', '5316103', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '大淀中', 'オオヨドナカ', null, null, '梅田スカイビルタワーウエスト　3階', 'ウメダスカイビルタワーウエスト　03カイ');
INSERT INTO `ms_addresses` VALUES ('59773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区大淀中梅田スカイビルタワーウエスト　4階', '27', '27127', '5316104', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '大淀中', 'オオヨドナカ', null, null, '梅田スカイビルタワーウエスト　4階', 'ウメダスカイビルタワーウエスト　04カイ');
INSERT INTO `ms_addresses` VALUES ('59774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区大淀中梅田スカイビルタワーウエスト　5階', '27', '27127', '5316105', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '大淀中', 'オオヨドナカ', null, null, '梅田スカイビルタワーウエスト　5階', 'ウメダスカイビルタワーウエスト　05カイ');
INSERT INTO `ms_addresses` VALUES ('59775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区大淀中梅田スカイビルタワーウエスト　6階', '27', '27127', '5316106', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '大淀中', 'オオヨドナカ', null, null, '梅田スカイビルタワーウエスト　6階', 'ウメダスカイビルタワーウエスト　06カイ');
INSERT INTO `ms_addresses` VALUES ('59776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区大淀中梅田スカイビルタワーウエスト　7階', '27', '27127', '5316107', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '大淀中', 'オオヨドナカ', null, null, '梅田スカイビルタワーウエスト　7階', 'ウメダスカイビルタワーウエスト　07カイ');
INSERT INTO `ms_addresses` VALUES ('59777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区大淀中梅田スカイビルタワーウエスト　8階', '27', '27127', '5316108', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '大淀中', 'オオヨドナカ', null, null, '梅田スカイビルタワーウエスト　8階', 'ウメダスカイビルタワーウエスト　08カイ');
INSERT INTO `ms_addresses` VALUES ('59778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区大淀中梅田スカイビルタワーウエスト　9階', '27', '27127', '5316109', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '大淀中', 'オオヨドナカ', null, null, '梅田スカイビルタワーウエスト　9階', 'ウメダスカイビルタワーウエスト　09カイ');
INSERT INTO `ms_addresses` VALUES ('59779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区大淀中梅田スカイビルタワーウエスト　10階', '27', '27127', '5316110', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '大淀中', 'オオヨドナカ', null, null, '梅田スカイビルタワーウエスト　10階', 'ウメダスカイビルタワーウエスト　10カイ');
INSERT INTO `ms_addresses` VALUES ('59780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区大淀中梅田スカイビルタワーウエスト　11階', '27', '27127', '5316111', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '大淀中', 'オオヨドナカ', null, null, '梅田スカイビルタワーウエスト　11階', 'ウメダスカイビルタワーウエスト　11カイ');
INSERT INTO `ms_addresses` VALUES ('59781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区大淀中梅田スカイビルタワーウエスト　12階', '27', '27127', '5316112', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '大淀中', 'オオヨドナカ', null, null, '梅田スカイビルタワーウエスト　12階', 'ウメダスカイビルタワーウエスト　12カイ');
INSERT INTO `ms_addresses` VALUES ('59782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区大淀中梅田スカイビルタワーウエスト　13階', '27', '27127', '5316113', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '大淀中', 'オオヨドナカ', null, null, '梅田スカイビルタワーウエスト　13階', 'ウメダスカイビルタワーウエスト　13カイ');
INSERT INTO `ms_addresses` VALUES ('59783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区大淀中梅田スカイビルタワーウエスト　14階', '27', '27127', '5316114', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '大淀中', 'オオヨドナカ', null, null, '梅田スカイビルタワーウエスト　14階', 'ウメダスカイビルタワーウエスト　14カイ');
INSERT INTO `ms_addresses` VALUES ('59784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区大淀中梅田スカイビルタワーウエスト　15階', '27', '27127', '5316115', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '大淀中', 'オオヨドナカ', null, null, '梅田スカイビルタワーウエスト　15階', 'ウメダスカイビルタワーウエスト　15カイ');
INSERT INTO `ms_addresses` VALUES ('59785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区大淀中梅田スカイビルタワーウエスト　16階', '27', '27127', '5316116', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '大淀中', 'オオヨドナカ', null, null, '梅田スカイビルタワーウエスト　16階', 'ウメダスカイビルタワーウエスト　16カイ');
INSERT INTO `ms_addresses` VALUES ('59786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区大淀中梅田スカイビルタワーウエスト　17階', '27', '27127', '5316117', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '大淀中', 'オオヨドナカ', null, null, '梅田スカイビルタワーウエスト　17階', 'ウメダスカイビルタワーウエスト　17カイ');
INSERT INTO `ms_addresses` VALUES ('59787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区大淀中梅田スカイビルタワーウエスト　18階', '27', '27127', '5316118', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '大淀中', 'オオヨドナカ', null, null, '梅田スカイビルタワーウエスト　18階', 'ウメダスカイビルタワーウエスト　18カイ');
INSERT INTO `ms_addresses` VALUES ('59788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区大淀中梅田スカイビルタワーウエスト　19階', '27', '27127', '5316119', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '大淀中', 'オオヨドナカ', null, null, '梅田スカイビルタワーウエスト　19階', 'ウメダスカイビルタワーウエスト　19カイ');
INSERT INTO `ms_addresses` VALUES ('59789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区大淀中梅田スカイビルタワーウエスト　20階', '27', '27127', '5316120', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '大淀中', 'オオヨドナカ', null, null, '梅田スカイビルタワーウエスト　20階', 'ウメダスカイビルタワーウエスト　20カイ');
INSERT INTO `ms_addresses` VALUES ('59790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区大淀中梅田スカイビルタワーウエスト　21階', '27', '27127', '5316121', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '大淀中', 'オオヨドナカ', null, null, '梅田スカイビルタワーウエスト　21階', 'ウメダスカイビルタワーウエスト　21カイ');
INSERT INTO `ms_addresses` VALUES ('59791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区大淀中梅田スカイビルタワーウエスト　22階', '27', '27127', '5316122', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '大淀中', 'オオヨドナカ', null, null, '梅田スカイビルタワーウエスト　22階', 'ウメダスカイビルタワーウエスト　22カイ');
INSERT INTO `ms_addresses` VALUES ('59792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区大淀中梅田スカイビルタワーウエスト　23階', '27', '27127', '5316123', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '大淀中', 'オオヨドナカ', null, null, '梅田スカイビルタワーウエスト　23階', 'ウメダスカイビルタワーウエスト　23カイ');
INSERT INTO `ms_addresses` VALUES ('59793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区大淀中梅田スカイビルタワーウエスト　24階', '27', '27127', '5316124', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '大淀中', 'オオヨドナカ', null, null, '梅田スカイビルタワーウエスト　24階', 'ウメダスカイビルタワーウエスト　24カイ');
INSERT INTO `ms_addresses` VALUES ('59794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区大淀中梅田スカイビルタワーウエスト　25階', '27', '27127', '5316125', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '大淀中', 'オオヨドナカ', null, null, '梅田スカイビルタワーウエスト　25階', 'ウメダスカイビルタワーウエスト　25カイ');
INSERT INTO `ms_addresses` VALUES ('59795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区大淀中梅田スカイビルタワーウエスト　26階', '27', '27127', '5316126', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '大淀中', 'オオヨドナカ', null, null, '梅田スカイビルタワーウエスト　26階', 'ウメダスカイビルタワーウエスト　26カイ');
INSERT INTO `ms_addresses` VALUES ('59796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区大淀中梅田スカイビルタワーウエスト　27階', '27', '27127', '5316127', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '大淀中', 'オオヨドナカ', null, null, '梅田スカイビルタワーウエスト　27階', 'ウメダスカイビルタワーウエスト　27カイ');
INSERT INTO `ms_addresses` VALUES ('59797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区大淀中梅田スカイビルタワーウエスト　28階', '27', '27127', '5316128', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '大淀中', 'オオヨドナカ', null, null, '梅田スカイビルタワーウエスト　28階', 'ウメダスカイビルタワーウエスト　28カイ');
INSERT INTO `ms_addresses` VALUES ('59798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区大淀中梅田スカイビルタワーウエスト　29階', '27', '27127', '5316129', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '大淀中', 'オオヨドナカ', null, null, '梅田スカイビルタワーウエスト　29階', 'ウメダスカイビルタワーウエスト　29カイ');
INSERT INTO `ms_addresses` VALUES ('59799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区大淀中梅田スカイビルタワーウエスト　30階', '27', '27127', '5316130', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '大淀中', 'オオヨドナカ', null, null, '梅田スカイビルタワーウエスト　30階', 'ウメダスカイビルタワーウエスト　30カイ');
INSERT INTO `ms_addresses` VALUES ('59800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区大淀中梅田スカイビルタワーウエスト　31階', '27', '27127', '5316131', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '大淀中', 'オオヨドナカ', null, null, '梅田スカイビルタワーウエスト　31階', 'ウメダスカイビルタワーウエスト　31カイ');
INSERT INTO `ms_addresses` VALUES ('59801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区大淀中梅田スカイビルタワーウエスト　32階', '27', '27127', '5316132', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '大淀中', 'オオヨドナカ', null, null, '梅田スカイビルタワーウエスト　32階', 'ウメダスカイビルタワーウエスト　32カイ');
INSERT INTO `ms_addresses` VALUES ('59802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区大淀中梅田スカイビルタワーウエスト　33階', '27', '27127', '5316133', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '大淀中', 'オオヨドナカ', null, null, '梅田スカイビルタワーウエスト　33階', 'ウメダスカイビルタワーウエスト　33カイ');
INSERT INTO `ms_addresses` VALUES ('59803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区大淀中梅田スカイビルタワーウエスト　34階', '27', '27127', '5316134', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '大淀中', 'オオヨドナカ', null, null, '梅田スカイビルタワーウエスト　34階', 'ウメダスカイビルタワーウエスト　34カイ');
INSERT INTO `ms_addresses` VALUES ('59804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区大淀中梅田スカイビルタワーウエスト　35階', '27', '27127', '5316135', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '大淀中', 'オオヨドナカ', null, null, '梅田スカイビルタワーウエスト　35階', 'ウメダスカイビルタワーウエスト　35カイ');
INSERT INTO `ms_addresses` VALUES ('59805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区大淀中梅田スカイビルタワーウエスト　36階', '27', '27127', '5316136', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '大淀中', 'オオヨドナカ', null, null, '梅田スカイビルタワーウエスト　36階', 'ウメダスカイビルタワーウエスト　36カイ');
INSERT INTO `ms_addresses` VALUES ('59806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区大淀中梅田スカイビルタワーウエスト　37階', '27', '27127', '5316137', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '大淀中', 'オオヨドナカ', null, null, '梅田スカイビルタワーウエスト　37階', 'ウメダスカイビルタワーウエスト　37カイ');
INSERT INTO `ms_addresses` VALUES ('59807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区大淀中梅田スカイビルタワーウエスト　38階', '27', '27127', '5316138', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '大淀中', 'オオヨドナカ', null, null, '梅田スカイビルタワーウエスト　38階', 'ウメダスカイビルタワーウエスト　38カイ');
INSERT INTO `ms_addresses` VALUES ('59808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区大淀中梅田スカイビルタワーウエスト　39階', '27', '27127', '5316139', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '大淀中', 'オオヨドナカ', null, null, '梅田スカイビルタワーウエスト　39階', 'ウメダスカイビルタワーウエスト　39カイ');
INSERT INTO `ms_addresses` VALUES ('59809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市北区大淀中梅田スカイビルタワーウエスト　', '27', '27127', '5316190', '大阪府', 'オオサカフ', '大阪市北区', 'オオサカシキタク', '大淀中', 'オオヨドナカ', null, null, '梅田スカイビルタワーウエスト　', 'ウメダスカイビルタワーウエスト　');
INSERT INTO `ms_addresses` VALUES ('59816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市淀川区', '27', '27123', '5320000', '大阪府', 'オオサカフ', '大阪市淀川区', 'オオサカシヨドガワク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('59817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市淀川区十八条', '27', '27123', '5320001', '大阪府', 'オオサカフ', '大阪市淀川区', 'オオサカシヨドガワク', '十八条', 'ジュウハチジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市淀川区東三国', '27', '27123', '5320002', '大阪府', 'オオサカフ', '大阪市淀川区', 'オオサカシヨドガワク', '東三国', 'ヒガシミクニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市淀川区宮原', '27', '27123', '5320003', '大阪府', 'オオサカフ', '大阪市淀川区', 'オオサカシヨドガワク', '宮原', 'ミヤハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市淀川区西宮原', '27', '27123', '5320004', '大阪府', 'オオサカフ', '大阪市淀川区', 'オオサカシヨドガワク', '西宮原', 'ニシミヤハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市淀川区三国本町', '27', '27123', '5320005', '大阪府', 'オオサカフ', '大阪市淀川区', 'オオサカシヨドガワク', '三国本町', 'ミクニホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市淀川区西三国', '27', '27123', '5320006', '大阪府', 'オオサカフ', '大阪市淀川区', 'オオサカシヨドガワク', '西三国', 'ニシミクニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市淀川区西中島', '27', '27123', '5320011', '大阪府', 'オオサカフ', '大阪市淀川区', 'オオサカシヨドガワク', '西中島', 'ニシナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市淀川区木川東', '27', '27123', '5320012', '大阪府', 'オオサカフ', '大阪市淀川区', 'オオサカシヨドガワク', '木川東', 'キカワヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市淀川区木川西', '27', '27123', '5320013', '大阪府', 'オオサカフ', '大阪市淀川区', 'オオサカシヨドガワク', '木川西', 'キカワニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市淀川区田川北', '27', '27123', '5320021', '大阪府', 'オオサカフ', '大阪市淀川区', 'オオサカシヨドガワク', '田川北', 'タガワキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市淀川区野中南', '27', '27123', '5320022', '大阪府', 'オオサカフ', '大阪市淀川区', 'オオサカシヨドガワク', '野中南', 'ノナカミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市淀川区十三東', '27', '27123', '5320023', '大阪府', 'オオサカフ', '大阪市淀川区', 'オオサカシヨドガワク', '十三東', 'ジュウソウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市淀川区十三本町', '27', '27123', '5320024', '大阪府', 'オオサカフ', '大阪市淀川区', 'オオサカシヨドガワク', '十三本町', 'ジュウソウホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市淀川区新北野', '27', '27123', '5320025', '大阪府', 'オオサカフ', '大阪市淀川区', 'オオサカシヨドガワク', '新北野', 'シンキタノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市淀川区塚本', '27', '27123', '5320026', '大阪府', 'オオサカフ', '大阪市淀川区', 'オオサカシヨドガワク', '塚本', 'ツカモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市淀川区田川', '27', '27123', '5320027', '大阪府', 'オオサカフ', '大阪市淀川区', 'オオサカシヨドガワク', '田川', 'タガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市淀川区十三元今里', '27', '27123', '5320028', '大阪府', 'オオサカフ', '大阪市淀川区', 'オオサカシヨドガワク', '十三元今里', 'ジュウソウモトイマザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市淀川区加島', '27', '27123', '5320031', '大阪府', 'オオサカフ', '大阪市淀川区', 'オオサカシヨドガワク', '加島', 'カシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市淀川区三津屋北', '27', '27123', '5320032', '大阪府', 'オオサカフ', '大阪市淀川区', 'オオサカシヨドガワク', '三津屋北', 'ミツヤキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市淀川区新高', '27', '27123', '5320033', '大阪府', 'オオサカフ', '大阪市淀川区', 'オオサカシヨドガワク', '新高', 'ニイタカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市淀川区野中北', '27', '27123', '5320034', '大阪府', 'オオサカフ', '大阪市淀川区', 'オオサカシヨドガワク', '野中北', 'ノナカキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市淀川区三津屋南', '27', '27123', '5320035', '大阪府', 'オオサカフ', '大阪市淀川区', 'オオサカシヨドガワク', '三津屋南', 'ミツヤミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市淀川区三津屋中', '27', '27123', '5320036', '大阪府', 'オオサカフ', '大阪市淀川区', 'オオサカシヨドガワク', '三津屋中', 'ミツヤナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市東淀川区', '27', '27114', '5330000', '大阪府', 'オオサカフ', '大阪市東淀川区', 'オオサカシヒガシヨドガワク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('59859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市東淀川区井高野', '27', '27114', '5330001', '大阪府', 'オオサカフ', '大阪市東淀川区', 'オオサカシヒガシヨドガワク', '井高野', 'イタカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市東淀川区北江口', '27', '27114', '5330002', '大阪府', 'オオサカフ', '大阪市東淀川区', 'オオサカシヒガシヨドガワク', '北江口', 'キタエグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市東淀川区南江口', '27', '27114', '5330003', '大阪府', 'オオサカフ', '大阪市東淀川区', 'オオサカシヒガシヨドガワク', '南江口', 'ミナミエグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市東淀川区小松', '27', '27114', '5330004', '大阪府', 'オオサカフ', '大阪市東淀川区', 'オオサカシヒガシヨドガワク', '小松', 'コマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市東淀川区瑞光', '27', '27114', '5330005', '大阪府', 'オオサカフ', '大阪市東淀川区', 'オオサカシヒガシヨドガワク', '瑞光', 'ズイコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市東淀川区上新庄', '27', '27114', '5330006', '大阪府', 'オオサカフ', '大阪市東淀川区', 'オオサカシヒガシヨドガワク', '上新庄', 'カミシンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市東淀川区相川', '27', '27114', '5330007', '大阪府', 'オオサカフ', '大阪市東淀川区', 'オオサカシヒガシヨドガワク', '相川', 'アイカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市東淀川区大桐', '27', '27114', '5330011', '大阪府', 'オオサカフ', '大阪市東淀川区', 'オオサカシヒガシヨドガワク', '大桐', 'ダイドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市東淀川区大道南', '27', '27114', '5330012', '大阪府', 'オオサカフ', '大阪市東淀川区', 'オオサカシヒガシヨドガワク', '大道南', 'ダイドウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市東淀川区豊里', '27', '27114', '5330013', '大阪府', 'オオサカフ', '大阪市東淀川区', 'オオサカシヒガシヨドガワク', '豊里', 'トヨサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市東淀川区豊新', '27', '27114', '5330014', '大阪府', 'オオサカフ', '大阪市東淀川区', 'オオサカシヒガシヨドガワク', '豊新', 'ホウシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市東淀川区大隅', '27', '27114', '5330015', '大阪府', 'オオサカフ', '大阪市東淀川区', 'オオサカシヒガシヨドガワク', '大隅', 'オオスミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市東淀川区下新庄', '27', '27114', '5330021', '大阪府', 'オオサカフ', '大阪市東淀川区', 'オオサカシヒガシヨドガワク', '下新庄', 'シモシンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市東淀川区菅原', '27', '27114', '5330022', '大阪府', 'オオサカフ', '大阪市東淀川区', 'オオサカシヒガシヨドガワク', '菅原', 'スガハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市東淀川区東淡路', '27', '27114', '5330023', '大阪府', 'オオサカフ', '大阪市東淀川区', 'オオサカシヒガシヨドガワク', '東淡路', 'ヒガシアワジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市東淀川区柴島', '27', '27114', '5330024', '大阪府', 'オオサカフ', '大阪市東淀川区', 'オオサカシヒガシヨドガワク', '柴島', 'クニジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市東淀川区西淡路', '27', '27114', '5330031', '大阪府', 'オオサカフ', '大阪市東淀川区', 'オオサカシヒガシヨドガワク', '西淡路', 'ニシアワジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市東淀川区淡路', '27', '27114', '5330032', '大阪府', 'オオサカフ', '大阪市東淀川区', 'オオサカシヒガシヨドガワク', '淡路', 'アワジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市東淀川区東中島', '27', '27114', '5330033', '大阪府', 'オオサカフ', '大阪市東淀川区', 'オオサカシヒガシヨドガワク', '東中島', 'ヒガシナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市都島区', '27', '27102', '5340000', '大阪府', 'オオサカフ', '大阪市都島区', 'オオサカシミヤコジマク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('59885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市都島区毛馬町', '27', '27102', '5340001', '大阪府', 'オオサカフ', '大阪市都島区', 'オオサカシミヤコジマク', '毛馬町', 'ケマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市都島区大東町', '27', '27102', '5340002', '大阪府', 'オオサカフ', '大阪市都島区', 'オオサカシミヤコジマク', '大東町', 'ダイトウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市都島区高倉町', '27', '27102', '5340011', '大阪府', 'オオサカフ', '大阪市都島区', 'オオサカシミヤコジマク', '高倉町', 'タカクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市都島区御幸町', '27', '27102', '5340012', '大阪府', 'オオサカフ', '大阪市都島区', 'オオサカシミヤコジマク', '御幸町', 'ミユキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市都島区内代町', '27', '27102', '5340013', '大阪府', 'オオサカフ', '大阪市都島区', 'オオサカシミヤコジマク', '内代町', 'ウチンダイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市都島区都島北通', '27', '27102', '5340014', '大阪府', 'オオサカフ', '大阪市都島区', 'オオサカシミヤコジマク', '都島北通', 'ミヤコジマキタドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市都島区善源寺町', '27', '27102', '5340015', '大阪府', 'オオサカフ', '大阪市都島区', 'オオサカシミヤコジマク', '善源寺町', 'ゼンゲンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市都島区友渕町', '27', '27102', '5340016', '大阪府', 'オオサカフ', '大阪市都島区', 'オオサカシミヤコジマク', '友渕町', 'トモブチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市都島区都島本通', '27', '27102', '5340021', '大阪府', 'オオサカフ', '大阪市都島区', 'オオサカシミヤコジマク', '都島本通', 'ミヤコジマホンドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市都島区都島中通', '27', '27102', '5340022', '大阪府', 'オオサカフ', '大阪市都島区', 'オオサカシミヤコジマク', '都島中通', 'ミヤコジマナカドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市都島区都島南通', '27', '27102', '5340023', '大阪府', 'オオサカフ', '大阪市都島区', 'オオサカシミヤコジマク', '都島南通', 'ミヤコジマミナミドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市都島区東野田町', '27', '27102', '5340024', '大阪府', 'オオサカフ', '大阪市都島区', 'オオサカシミヤコジマク', '東野田町', 'ヒガシノダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市都島区片町', '27', '27102', '5340025', '大阪府', 'オオサカフ', '大阪市都島区', 'オオサカシミヤコジマク', '片町', 'カタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市都島区網島町', '27', '27102', '5340026', '大阪府', 'オオサカフ', '大阪市都島区', 'オオサカシミヤコジマク', '網島町', 'アミジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市都島区中野町', '27', '27102', '5340027', '大阪府', 'オオサカフ', '大阪市都島区', 'オオサカシミヤコジマク', '中野町', 'ナカノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市旭区', '27', '27117', '5350000', '大阪府', 'オオサカフ', '大阪市旭区', 'オオサカシアサヒク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('59904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市旭区太子橋', '27', '27117', '5350001', '大阪府', 'オオサカフ', '大阪市旭区', 'オオサカシアサヒク', '太子橋', 'タイシバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市旭区大宮', '27', '27117', '5350002', '大阪府', 'オオサカフ', '大阪市旭区', 'オオサカシアサヒク', '大宮', 'オオミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市旭区中宮', '27', '27117', '5350003', '大阪府', 'オオサカフ', '大阪市旭区', 'オオサカシアサヒク', '中宮', 'ナカミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市旭区生江', '27', '27117', '5350004', '大阪府', 'オオサカフ', '大阪市旭区', 'オオサカシアサヒク', '生江', 'イクエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市旭区赤川', '27', '27117', '5350005', '大阪府', 'オオサカフ', '大阪市旭区', 'オオサカシアサヒク', '赤川', 'アカガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市旭区今市', '27', '27117', '5350011', '大阪府', 'オオサカフ', '大阪市旭区', 'オオサカシアサヒク', '今市', 'イマイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市旭区千林', '27', '27117', '5350012', '大阪府', 'オオサカフ', '大阪市旭区', 'オオサカシアサヒク', '千林', 'センバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市旭区森小路', '27', '27117', '5350013', '大阪府', 'オオサカフ', '大阪市旭区', 'オオサカシアサヒク', '森小路', 'モリショウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市旭区清水', '27', '27117', '5350021', '大阪府', 'オオサカフ', '大阪市旭区', 'オオサカシアサヒク', '清水', 'シミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市旭区新森', '27', '27117', '5350022', '大阪府', 'オオサカフ', '大阪市旭区', 'オオサカシアサヒク', '新森', 'シンモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市旭区高殿', '27', '27117', '5350031', '大阪府', 'オオサカフ', '大阪市旭区', 'オオサカシアサヒク', '高殿', 'タカドノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市城東区', '27', '27118', '5360000', '大阪府', 'オオサカフ', '大阪市城東区', 'オオサカシジョウトウク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('59919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市城東区古市', '27', '27118', '5360001', '大阪府', 'オオサカフ', '大阪市城東区', 'オオサカシジョウトウク', '古市', 'フルイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市城東区今福東', '27', '27118', '5360002', '大阪府', 'オオサカフ', '大阪市城東区', 'オオサカシジョウトウク', '今福東', 'イマフクヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市城東区今福南', '27', '27118', '5360003', '大阪府', 'オオサカフ', '大阪市城東区', 'オオサカシジョウトウク', '今福南', 'イマフクミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市城東区今福西', '27', '27118', '5360004', '大阪府', 'オオサカフ', '大阪市城東区', 'オオサカシジョウトウク', '今福西', 'イマフクニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市城東区中央', '27', '27118', '5360005', '大阪府', 'オオサカフ', '大阪市城東区', 'オオサカシジョウトウク', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市城東区野江', '27', '27118', '5360006', '大阪府', 'オオサカフ', '大阪市城東区', 'オオサカシジョウトウク', '野江', 'ノエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市城東区成育', '27', '27118', '5360007', '大阪府', 'オオサカフ', '大阪市城東区', 'オオサカシジョウトウク', '成育', 'セイイク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市城東区関目', '27', '27118', '5360008', '大阪府', 'オオサカフ', '大阪市城東区', 'オオサカシジョウトウク', '関目', 'セキメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市城東区放出西', '27', '27118', '5360011', '大阪府', 'オオサカフ', '大阪市城東区', 'オオサカシジョウトウク', '放出西', 'ハナテンニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市城東区天王田', '27', '27118', '5360012', '大阪府', 'オオサカフ', '大阪市城東区', 'オオサカシジョウトウク', '天王田', 'テンノウデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市城東区鴫野東', '27', '27118', '5360013', '大阪府', 'オオサカフ', '大阪市城東区', 'オオサカシジョウトウク', '鴫野東', 'シギノヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市城東区鴫野西', '27', '27118', '5360014', '大阪府', 'オオサカフ', '大阪市城東区', 'オオサカシジョウトウク', '鴫野西', 'シギノニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市城東区新喜多', '27', '27118', '5360015', '大阪府', 'オオサカフ', '大阪市城東区', 'オオサカシジョウトウク', '新喜多', 'シギタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市城東区蒲生', '27', '27118', '5360016', '大阪府', 'オオサカフ', '大阪市城東区', 'オオサカシジョウトウク', '蒲生', 'ガモウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市城東区新喜多東', '27', '27118', '5360017', '大阪府', 'オオサカフ', '大阪市城東区', 'オオサカシジョウトウク', '新喜多東', 'シギタヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市城東区諏訪', '27', '27118', '5360021', '大阪府', 'オオサカフ', '大阪市城東区', 'オオサカシジョウトウク', '諏訪', 'スワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市城東区永田', '27', '27118', '5360022', '大阪府', 'オオサカフ', '大阪市城東区', 'オオサカシジョウトウク', '永田', 'ナガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市城東区東中浜', '27', '27118', '5360023', '大阪府', 'オオサカフ', '大阪市城東区', 'オオサカシジョウトウク', '東中浜', 'ヒガシナカハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市城東区中浜', '27', '27118', '5360024', '大阪府', 'オオサカフ', '大阪市城東区', 'オオサカシジョウトウク', '中浜', 'ナカハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市城東区森之宮', '27', '27118', '5360025', '大阪府', 'オオサカフ', '大阪市城東区', 'オオサカシジョウトウク', '森之宮', 'モリノミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市東成区', '27', '27115', '5370000', '大阪府', 'オオサカフ', '大阪市東成区', 'オオサカシヒガシナリク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('59957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市東成区深江北', '27', '27115', '5370001', '大阪府', 'オオサカフ', '大阪市東成区', 'オオサカシヒガシナリク', '深江北', 'フカエキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市東成区深江南', '27', '27115', '5370002', '大阪府', 'オオサカフ', '大阪市東成区', 'オオサカシヒガシナリク', '深江南', 'フカエミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市東成区神路', '27', '27115', '5370003', '大阪府', 'オオサカフ', '大阪市東成区', 'オオサカシヒガシナリク', '神路', 'カミジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市東成区東今里', '27', '27115', '5370011', '大阪府', 'オオサカフ', '大阪市東成区', 'オオサカシヒガシナリク', '東今里', 'ヒガシイマザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市東成区大今里', '27', '27115', '5370012', '大阪府', 'オオサカフ', '大阪市東成区', 'オオサカシヒガシナリク', '大今里', 'オオイマザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市東成区大今里南', '27', '27115', '5370013', '大阪府', 'オオサカフ', '大阪市東成区', 'オオサカシヒガシナリク', '大今里南', 'オオイマザトミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市東成区大今里西', '27', '27115', '5370014', '大阪府', 'オオサカフ', '大阪市東成区', 'オオサカシヒガシナリク', '大今里西', 'オオイマザトニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市東成区東中本', '27', '27115', '5370021', '大阪府', 'オオサカフ', '大阪市東成区', 'オオサカシヒガシナリク', '東中本', 'ヒガシナカモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市東成区中本', '27', '27115', '5370022', '大阪府', 'オオサカフ', '大阪市東成区', 'オオサカシヒガシナリク', '中本', 'ナカモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市東成区玉津', '27', '27115', '5370023', '大阪府', 'オオサカフ', '大阪市東成区', 'オオサカシヒガシナリク', '玉津', 'タマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市東成区東小橋', '27', '27115', '5370024', '大阪府', 'オオサカフ', '大阪市東成区', 'オオサカシヒガシナリク', '東小橋', 'ヒガシオバセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市東成区中道', '27', '27115', '5370025', '大阪府', 'オオサカフ', '大阪市東成区', 'オオサカシヒガシナリク', '中道', 'ナカミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市鶴見区', '27', '27124', '5380000', '大阪府', 'オオサカフ', '大阪市鶴見区', 'オオサカシツルミク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('59973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市鶴見区茨田大宮', '27', '27124', '5380031', '大阪府', 'オオサカフ', '大阪市鶴見区', 'オオサカシツルミク', '茨田大宮', 'マッタオオミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市鶴見区安田', '27', '27124', '5380032', '大阪府', 'オオサカフ', '大阪市鶴見区', 'オオサカシツルミク', '安田', 'ヤスダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市鶴見区中茶屋', '27', '27124', '5380033', '大阪府', 'オオサカフ', '大阪市鶴見区', 'オオサカシツルミク', '中茶屋', 'ナカノチャヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市鶴見区徳庵', '27', '27124', '5380034', '大阪府', 'オオサカフ', '大阪市鶴見区', 'オオサカシツルミク', '徳庵', 'トクアン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市鶴見区浜', '27', '27124', '5380035', '大阪府', 'オオサカフ', '大阪市鶴見区', 'オオサカシツルミク', '浜', 'ハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市鶴見区緑地公園', '27', '27124', '5380036', '大阪府', 'オオサカフ', '大阪市鶴見区', 'オオサカシツルミク', '緑地公園', 'リョクチコウエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市鶴見区焼野', '27', '27124', '5380037', '大阪府', 'オオサカフ', '大阪市鶴見区', 'オオサカシツルミク', '焼野', 'ヤケノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市鶴見区今津北', '27', '27124', '5380041', '大阪府', 'オオサカフ', '大阪市鶴見区', 'オオサカシツルミク', '今津北', 'イマヅキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市鶴見区今津中', '27', '27124', '5380042', '大阪府', 'オオサカフ', '大阪市鶴見区', 'オオサカシツルミク', '今津中', 'イマヅナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市鶴見区今津南', '27', '27124', '5380043', '大阪府', 'オオサカフ', '大阪市鶴見区', 'オオサカシツルミク', '今津南', 'イマヅミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市鶴見区放出東', '27', '27124', '5380044', '大阪府', 'オオサカフ', '大阪市鶴見区', 'オオサカシツルミク', '放出東', 'ハナテンヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市鶴見区諸口', '27', '27124', '5380051', '大阪府', 'オオサカフ', '大阪市鶴見区', 'オオサカシツルミク', '諸口', 'モロクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市鶴見区横堤', '27', '27124', '5380052', '大阪府', 'オオサカフ', '大阪市鶴見区', 'オオサカシツルミク', '横堤', 'ヨコヅツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市鶴見区鶴見', '27', '27124', '5380053', '大阪府', 'オオサカフ', '大阪市鶴見区', 'オオサカシツルミク', '鶴見', 'ツルミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('59987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市鶴見区緑', '27', '27124', '5380054', '大阪府', 'オオサカフ', '大阪市鶴見区', 'オオサカシツルミク', '緑', 'ミドリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区', '27', '27128', '5390000', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('60018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡むかわ町', '01', '01586', '0540000', '北海道', 'ホッカイドウ', '勇払郡むかわ町', 'ユウフツグンムカワチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('60019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見', '27', '27128', '5400001', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区大阪城', '27', '27128', '5400002', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '大阪城', 'オオサカジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区森ノ宮中央', '27', '27128', '5400003', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '森ノ宮中央', 'モリノミヤチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区玉造', '27', '27128', '5400004', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '玉造', 'タマツクリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区上町', '27', '27128', '5400005', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '上町', 'ウエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区法円坂', '27', '27128', '5400006', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '法円坂', 'ホウエンザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区馬場町', '27', '27128', '5400007', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '馬場町', 'バンバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区大手前', '27', '27128', '5400008', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '大手前', 'オオテマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡むかわ町旭岡', '01', '01586', '0540001', '北海道', 'ホッカイドウ', '勇払郡むかわ町', 'ユウフツグンムカワチョウ', '旭岡', 'アサヒオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区材木町', '27', '27128', '5400010', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '材木町', 'ザイモクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区農人橋', '27', '27128', '5400011', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '農人橋', 'ノウニンバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区谷町1丁目', '27', '27128', '5400012', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '谷町', 'タニマチ', null, null, '1丁目', '01チョウメ');
INSERT INTO `ms_addresses` VALUES ('60031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区谷町2丁目', '27', '27128', '5400012', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '谷町', 'タニマチ', null, null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('60032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区谷町3丁目', '27', '27128', '5400012', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '谷町', 'タニマチ', null, null, '3丁目', '03チョウメ');
INSERT INTO `ms_addresses` VALUES ('60033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区谷町4丁目', '27', '27128', '5400012', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '谷町', 'タニマチ', null, null, '4丁目', '04チョウメ');
INSERT INTO `ms_addresses` VALUES ('60034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区谷町5丁目', '27', '27128', '5400012', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '谷町', 'タニマチ', null, null, '5丁目', '05チョウメ');
INSERT INTO `ms_addresses` VALUES ('60035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区内久宝寺町', '27', '27128', '5400013', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '内久宝寺町', 'ウチキュウホウジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区龍造寺町', '27', '27128', '5400014', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '龍造寺町', 'リュウゾウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区十二軒町', '27', '27128', '5400015', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '十二軒町', 'ジュウニケンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区神崎町', '27', '27128', '5400016', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '神崎町', 'カンザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区松屋町住吉', '27', '27128', '5400017', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '松屋町住吉', 'マツヤマチスミヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区粉川町', '27', '27128', '5400018', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '粉川町', 'コカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区和泉町', '27', '27128', '5400019', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '和泉町', 'イズミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡むかわ町春日', '01', '01586', '0540002', '北海道', 'ホッカイドウ', '勇払郡むかわ町', 'ユウフツグンムカワチョウ', '春日', 'カスガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区大手通', '27', '27128', '5400021', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '大手通', 'オオテドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区糸屋町', '27', '27128', '5400022', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '糸屋町', 'イトヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区北新町', '27', '27128', '5400023', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '北新町', 'キタシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区南新町', '27', '27128', '5400024', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '南新町', 'ミナミシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区徳井町', '27', '27128', '5400025', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '徳井町', 'トクイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区内本町', '27', '27128', '5400026', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '内本町', 'ウチホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区鎗屋町', '27', '27128', '5400027', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '鎗屋町', 'ヤリヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区常盤町', '27', '27128', '5400028', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '常盤町', 'トキワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区本町橋', '27', '27128', '5400029', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '本町橋', 'ホンマチバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡むかわ町豊城', '01', '01586', '0540003', '北海道', 'ホッカイドウ', '勇払郡むかわ町', 'ユウフツグンムカワチョウ', '豊城', 'トヨシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区北浜東', '27', '27128', '5400031', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '北浜東', 'キタハマヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区天満橋京町', '27', '27128', '5400032', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '天満橋京町', 'テンマバシキョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区石町', '27', '27128', '5400033', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '石町', 'コクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区島町', '27', '27128', '5400034', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '島町', 'シママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区釣鐘町', '27', '27128', '5400035', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '釣鐘町', 'ツリガネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区船越町', '27', '27128', '5400036', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '船越町', 'フナコシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区内平野町', '27', '27128', '5400037', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '内平野町', 'ウチヒラノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区内淡路町', '27', '27128', '5400038', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '内淡路町', 'ウチアワジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区東高麗橋', '27', '27128', '5400039', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '東高麗橋', 'ヒガシコウライバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡むかわ町田浦', '01', '01586', '0540004', '北海道', 'ホッカイドウ', '勇払郡むかわ町', 'ユウフツグンムカワチョウ', '田浦', 'タウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡むかわ町二宮', '01', '01586', '0540005', '北海道', 'ホッカイドウ', '勇払郡むかわ町', 'ユウフツグンムカワチョウ', '二宮', 'ニノミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡むかわ町有明', '01', '01586', '0540011', '北海道', 'ホッカイドウ', '勇払郡むかわ町', 'ユウフツグンムカワチョウ', '有明', 'アリアケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡むかわ町生田', '01', '01586', '0540012', '北海道', 'ホッカイドウ', '勇払郡むかわ町', 'ユウフツグンムカワチョウ', '生田', 'イクタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡むかわ町花岡', '01', '01586', '0540013', '北海道', 'ホッカイドウ', '勇払郡むかわ町', 'ユウフツグンムカワチョウ', '花岡', 'ハナオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡むかわ町米原', '01', '01586', '0540014', '北海道', 'ホッカイドウ', '勇払郡むかわ町', 'ユウフツグンムカワチョウ', '米原', 'ヨネハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡むかわ町汐見', '01', '01586', '0540015', '北海道', 'ホッカイドウ', '勇払郡むかわ町', 'ユウフツグンムカワチョウ', '汐見', 'シオミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡むかわ町宮戸', '01', '01586', '0540016', '北海道', 'ホッカイドウ', '勇払郡むかわ町', 'ユウフツグンムカワチョウ', '宮戸', 'ミヤト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡むかわ町大原', '01', '01586', '0540021', '北海道', 'ホッカイドウ', '勇払郡むかわ町', 'ユウフツグンムカワチョウ', '大原', 'オオハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡むかわ町花園', '01', '01586', '0540022', '北海道', 'ホッカイドウ', '勇払郡むかわ町', 'ユウフツグンムカワチョウ', '花園', 'ハナゾノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡むかわ町末広', '01', '01586', '0540023', '北海道', 'ホッカイドウ', '勇払郡むかわ町', 'ユウフツグンムカワチョウ', '末広', 'スエヒロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡むかわ町青葉', '01', '01586', '0540031', '北海道', 'ホッカイドウ', '勇払郡むかわ町', 'ユウフツグンムカワチョウ', '青葉', 'アオバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡むかわ町福住', '01', '01586', '0540032', '北海道', 'ホッカイドウ', '勇払郡むかわ町', 'ユウフツグンムカワチョウ', '福住', 'フクズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡むかわ町松風', '01', '01586', '0540041', '北海道', 'ホッカイドウ', '勇払郡むかわ町', 'ユウフツグンムカワチョウ', '松風', 'マツカゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡むかわ町美幸', '01', '01586', '0540042', '北海道', 'ホッカイドウ', '勇払郡むかわ町', 'ユウフツグンムカワチョウ', '美幸', 'ミユキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡むかわ町文京', '01', '01586', '0540051', '北海道', 'ホッカイドウ', '勇払郡むかわ町', 'ユウフツグンムカワチョウ', '文京', 'ブンキョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡むかわ町大成', '01', '01586', '0540052', '北海道', 'ホッカイドウ', '勇払郡むかわ町', 'ユウフツグンムカワチョウ', '大成', 'タイセイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡むかわ町洋光', '01', '01586', '0540061', '北海道', 'ホッカイドウ', '勇払郡むかわ町', 'ユウフツグンムカワチョウ', '洋光', 'ヨウコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡むかわ町若草', '01', '01586', '0540062', '北海道', 'ホッカイドウ', '勇払郡むかわ町', 'ユウフツグンムカワチョウ', '若草', 'ワカクサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡むかわ町駒場', '01', '01586', '0540063', '北海道', 'ホッカイドウ', '勇払郡むかわ町', 'ユウフツグンムカワチョウ', '駒場', 'コマバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡むかわ町晴海', '01', '01586', '0540064', '北海道', 'ホッカイドウ', '勇払郡むかわ町', 'ユウフツグンムカワチョウ', '晴海', 'ハルミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡むかわ町穂別栄', '01', '01586', '0540141', '北海道', 'ホッカイドウ', '勇払郡むかわ町', 'ユウフツグンムカワチョウ', '穂別栄', 'ホベツサカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡むかわ町穂別仁和', '01', '01586', '0540142', '北海道', 'ホッカイドウ', '勇払郡むかわ町', 'ユウフツグンムカワチョウ', '穂別仁和', 'ホベツニワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡むかわ町穂別和泉', '01', '01586', '0540143', '北海道', 'ホッカイドウ', '勇払郡むかわ町', 'ユウフツグンムカワチョウ', '穂別和泉', 'ホベツイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡むかわ町穂別豊田', '01', '01586', '0540144', '北海道', 'ホッカイドウ', '勇払郡むかわ町', 'ユウフツグンムカワチョウ', '穂別豊田', 'ホベツトヨタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡むかわ町穂別稲里', '01', '01586', '0540201', '北海道', 'ホッカイドウ', '勇払郡むかわ町', 'ユウフツグンムカワチョウ', '穂別稲里', 'ホベツイナサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡むかわ町穂別長和', '01', '01586', '0540202', '北海道', 'ホッカイドウ', '勇払郡むかわ町', 'ユウフツグンムカワチョウ', '穂別長和', 'ホベツオサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡むかわ町穂別豊田新興', '01', '01586', '0540203', '北海道', 'ホッカイドウ', '勇払郡むかわ町', 'ユウフツグンムカワチョウ', '穂別豊田', 'ホベツトヨタ', null, null, '新興', 'シンコウ');
INSERT INTO `ms_addresses` VALUES ('60090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡むかわ町穂別平丘川向', '01', '01586', '0540204', '北海道', 'ホッカイドウ', '勇払郡むかわ町', 'ユウフツグンムカワチョウ', '穂別平丘', 'ホベツヒラオカ', null, null, '川向', 'カワムカイ');
INSERT INTO `ms_addresses` VALUES ('60091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡むかわ町穂別', '01', '01586', '0540211', '北海道', 'ホッカイドウ', '勇払郡むかわ町', 'ユウフツグンムカワチョウ', '穂別', 'ホベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡むかわ町穂別福山', '01', '01586', '0540361', '北海道', 'ホッカイドウ', '勇払郡むかわ町', 'ユウフツグンムカワチョウ', '穂別福山', 'ホベツフクヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡むかわ町穂別安住', '01', '01586', '0540362', '北海道', 'ホッカイドウ', '勇払郡むかわ町', 'ユウフツグンムカワチョウ', '穂別安住', 'ホベツアズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡むかわ町穂別平丘', '01', '01586', '0540363', '北海道', 'ホッカイドウ', '勇払郡むかわ町', 'ユウフツグンムカワチョウ', '穂別平丘', 'ホベツヒラオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡むかわ町穂別富内', '01', '01586', '0540364', '北海道', 'ホッカイドウ', '勇払郡むかわ町', 'ユウフツグンムカワチョウ', '穂別富内', 'ホベツトミウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見クリスタルタワー　1階', '27', '27128', '5406001', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'クリスタルタワー　1階', 'クリスタルタワー　01カイ');
INSERT INTO `ms_addresses` VALUES ('60097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見クリスタルタワー　2階', '27', '27128', '5406002', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'クリスタルタワー　2階', 'クリスタルタワー　02カイ');
INSERT INTO `ms_addresses` VALUES ('60098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見クリスタルタワー　3階', '27', '27128', '5406003', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'クリスタルタワー　3階', 'クリスタルタワー　03カイ');
INSERT INTO `ms_addresses` VALUES ('60099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見クリスタルタワー　4階', '27', '27128', '5406004', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'クリスタルタワー　4階', 'クリスタルタワー　04カイ');
INSERT INTO `ms_addresses` VALUES ('60100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見クリスタルタワー　5階', '27', '27128', '5406005', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'クリスタルタワー　5階', 'クリスタルタワー　05カイ');
INSERT INTO `ms_addresses` VALUES ('60101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見クリスタルタワー　6階', '27', '27128', '5406006', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'クリスタルタワー　6階', 'クリスタルタワー　06カイ');
INSERT INTO `ms_addresses` VALUES ('60102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見クリスタルタワー　7階', '27', '27128', '5406007', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'クリスタルタワー　7階', 'クリスタルタワー　07カイ');
INSERT INTO `ms_addresses` VALUES ('60103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見クリスタルタワー　8階', '27', '27128', '5406008', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'クリスタルタワー　8階', 'クリスタルタワー　08カイ');
INSERT INTO `ms_addresses` VALUES ('60104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見クリスタルタワー　9階', '27', '27128', '5406009', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'クリスタルタワー　9階', 'クリスタルタワー　09カイ');
INSERT INTO `ms_addresses` VALUES ('60105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見クリスタルタワー　10階', '27', '27128', '5406010', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'クリスタルタワー　10階', 'クリスタルタワー　10カイ');
INSERT INTO `ms_addresses` VALUES ('60106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見クリスタルタワー　11階', '27', '27128', '5406011', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'クリスタルタワー　11階', 'クリスタルタワー　11カイ');
INSERT INTO `ms_addresses` VALUES ('60107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見クリスタルタワー　12階', '27', '27128', '5406012', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'クリスタルタワー　12階', 'クリスタルタワー　12カイ');
INSERT INTO `ms_addresses` VALUES ('60108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見クリスタルタワー　13階', '27', '27128', '5406013', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'クリスタルタワー　13階', 'クリスタルタワー　13カイ');
INSERT INTO `ms_addresses` VALUES ('60109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見クリスタルタワー　14階', '27', '27128', '5406014', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'クリスタルタワー　14階', 'クリスタルタワー　14カイ');
INSERT INTO `ms_addresses` VALUES ('60110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見クリスタルタワー　15階', '27', '27128', '5406015', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'クリスタルタワー　15階', 'クリスタルタワー　15カイ');
INSERT INTO `ms_addresses` VALUES ('60111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見クリスタルタワー　16階', '27', '27128', '5406016', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'クリスタルタワー　16階', 'クリスタルタワー　16カイ');
INSERT INTO `ms_addresses` VALUES ('60112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見クリスタルタワー　17階', '27', '27128', '5406017', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'クリスタルタワー　17階', 'クリスタルタワー　17カイ');
INSERT INTO `ms_addresses` VALUES ('60113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見クリスタルタワー　18階', '27', '27128', '5406018', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'クリスタルタワー　18階', 'クリスタルタワー　18カイ');
INSERT INTO `ms_addresses` VALUES ('60114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見クリスタルタワー　19階', '27', '27128', '5406019', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'クリスタルタワー　19階', 'クリスタルタワー　19カイ');
INSERT INTO `ms_addresses` VALUES ('60115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見クリスタルタワー　20階', '27', '27128', '5406020', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'クリスタルタワー　20階', 'クリスタルタワー　20カイ');
INSERT INTO `ms_addresses` VALUES ('60116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見クリスタルタワー　21階', '27', '27128', '5406021', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'クリスタルタワー　21階', 'クリスタルタワー　21カイ');
INSERT INTO `ms_addresses` VALUES ('60117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見クリスタルタワー　22階', '27', '27128', '5406022', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'クリスタルタワー　22階', 'クリスタルタワー　22カイ');
INSERT INTO `ms_addresses` VALUES ('60118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見クリスタルタワー　23階', '27', '27128', '5406023', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'クリスタルタワー　23階', 'クリスタルタワー　23カイ');
INSERT INTO `ms_addresses` VALUES ('60119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見クリスタルタワー　24階', '27', '27128', '5406024', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'クリスタルタワー　24階', 'クリスタルタワー　24カイ');
INSERT INTO `ms_addresses` VALUES ('60120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見クリスタルタワー　25階', '27', '27128', '5406025', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'クリスタルタワー　25階', 'クリスタルタワー　25カイ');
INSERT INTO `ms_addresses` VALUES ('60121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見クリスタルタワー　26階', '27', '27128', '5406026', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'クリスタルタワー　26階', 'クリスタルタワー　26カイ');
INSERT INTO `ms_addresses` VALUES ('60122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見クリスタルタワー　27階', '27', '27128', '5406027', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'クリスタルタワー　27階', 'クリスタルタワー　27カイ');
INSERT INTO `ms_addresses` VALUES ('60123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見クリスタルタワー　28階', '27', '27128', '5406028', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'クリスタルタワー　28階', 'クリスタルタワー　28カイ');
INSERT INTO `ms_addresses` VALUES ('60124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見クリスタルタワー　29階', '27', '27128', '5406029', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'クリスタルタワー　29階', 'クリスタルタワー　29カイ');
INSERT INTO `ms_addresses` VALUES ('60125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見クリスタルタワー　30階', '27', '27128', '5406030', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'クリスタルタワー　30階', 'クリスタルタワー　30カイ');
INSERT INTO `ms_addresses` VALUES ('60126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見クリスタルタワー　31階', '27', '27128', '5406031', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'クリスタルタワー　31階', 'クリスタルタワー　31カイ');
INSERT INTO `ms_addresses` VALUES ('60127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見クリスタルタワー　32階', '27', '27128', '5406032', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'クリスタルタワー　32階', 'クリスタルタワー　32カイ');
INSERT INTO `ms_addresses` VALUES ('60128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見クリスタルタワー　33階', '27', '27128', '5406033', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'クリスタルタワー　33階', 'クリスタルタワー　33カイ');
INSERT INTO `ms_addresses` VALUES ('60129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見クリスタルタワー　34階', '27', '27128', '5406034', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'クリスタルタワー　34階', 'クリスタルタワー　34カイ');
INSERT INTO `ms_addresses` VALUES ('60130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見クリスタルタワー　35階', '27', '27128', '5406035', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'クリスタルタワー　35階', 'クリスタルタワー　35カイ');
INSERT INTO `ms_addresses` VALUES ('60131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見クリスタルタワー　36階', '27', '27128', '5406036', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'クリスタルタワー　36階', 'クリスタルタワー　36カイ');
INSERT INTO `ms_addresses` VALUES ('60132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見クリスタルタワー　37階', '27', '27128', '5406037', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'クリスタルタワー　37階', 'クリスタルタワー　37カイ');
INSERT INTO `ms_addresses` VALUES ('60133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見クリスタルタワー　', '27', '27128', '5406090', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'クリスタルタワー　', 'クリスタルタワー　');
INSERT INTO `ms_addresses` VALUES ('60134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見MIDタワー　1階', '27', '27128', '5406101', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'MIDタワー　1階', 'エムアイディタワー　01カイ');
INSERT INTO `ms_addresses` VALUES ('60135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見MIDタワー　2階', '27', '27128', '5406102', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'MIDタワー　2階', 'エムアイディタワー　02カイ');
INSERT INTO `ms_addresses` VALUES ('60136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見MIDタワー　3階', '27', '27128', '5406103', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'MIDタワー　3階', 'エムアイディタワー　03カイ');
INSERT INTO `ms_addresses` VALUES ('60137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見MIDタワー　4階', '27', '27128', '5406104', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'MIDタワー　4階', 'エムアイディタワー　04カイ');
INSERT INTO `ms_addresses` VALUES ('60138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見MIDタワー　5階', '27', '27128', '5406105', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'MIDタワー　5階', 'エムアイディタワー　05カイ');
INSERT INTO `ms_addresses` VALUES ('60139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見MIDタワー　6階', '27', '27128', '5406106', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'MIDタワー　6階', 'エムアイディタワー　06カイ');
INSERT INTO `ms_addresses` VALUES ('60140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見MIDタワー　7階', '27', '27128', '5406107', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'MIDタワー　7階', 'エムアイディタワー　07カイ');
INSERT INTO `ms_addresses` VALUES ('60141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見MIDタワー　8階', '27', '27128', '5406108', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'MIDタワー　8階', 'エムアイディタワー　08カイ');
INSERT INTO `ms_addresses` VALUES ('60142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見MIDタワー　9階', '27', '27128', '5406109', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'MIDタワー　9階', 'エムアイディタワー　09カイ');
INSERT INTO `ms_addresses` VALUES ('60143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見MIDタワー　10階', '27', '27128', '5406110', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'MIDタワー　10階', 'エムアイディタワー　10カイ');
INSERT INTO `ms_addresses` VALUES ('60144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見MIDタワー　11階', '27', '27128', '5406111', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'MIDタワー　11階', 'エムアイディタワー　11カイ');
INSERT INTO `ms_addresses` VALUES ('60145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見MIDタワー　12階', '27', '27128', '5406112', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'MIDタワー　12階', 'エムアイディタワー　12カイ');
INSERT INTO `ms_addresses` VALUES ('60146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見MIDタワー　13階', '27', '27128', '5406113', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'MIDタワー　13階', 'エムアイディタワー　13カイ');
INSERT INTO `ms_addresses` VALUES ('60147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見MIDタワー　14階', '27', '27128', '5406114', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'MIDタワー　14階', 'エムアイディタワー　14カイ');
INSERT INTO `ms_addresses` VALUES ('60148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見MIDタワー　15階', '27', '27128', '5406115', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'MIDタワー　15階', 'エムアイディタワー　15カイ');
INSERT INTO `ms_addresses` VALUES ('60149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見MIDタワー　16階', '27', '27128', '5406116', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'MIDタワー　16階', 'エムアイディタワー　16カイ');
INSERT INTO `ms_addresses` VALUES ('60150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見MIDタワー　17階', '27', '27128', '5406117', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'MIDタワー　17階', 'エムアイディタワー　17カイ');
INSERT INTO `ms_addresses` VALUES ('60151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見MIDタワー　18階', '27', '27128', '5406118', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'MIDタワー　18階', 'エムアイディタワー　18カイ');
INSERT INTO `ms_addresses` VALUES ('60152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見MIDタワー　19階', '27', '27128', '5406119', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'MIDタワー　19階', 'エムアイディタワー　19カイ');
INSERT INTO `ms_addresses` VALUES ('60153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見MIDタワー　20階', '27', '27128', '5406120', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'MIDタワー　20階', 'エムアイディタワー　20カイ');
INSERT INTO `ms_addresses` VALUES ('60154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見MIDタワー　21階', '27', '27128', '5406121', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'MIDタワー　21階', 'エムアイディタワー　21カイ');
INSERT INTO `ms_addresses` VALUES ('60155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見MIDタワー　22階', '27', '27128', '5406122', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'MIDタワー　22階', 'エムアイディタワー　22カイ');
INSERT INTO `ms_addresses` VALUES ('60156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見MIDタワー　23階', '27', '27128', '5406123', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'MIDタワー　23階', 'エムアイディタワー　23カイ');
INSERT INTO `ms_addresses` VALUES ('60157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見MIDタワー　24階', '27', '27128', '5406124', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'MIDタワー　24階', 'エムアイディタワー　24カイ');
INSERT INTO `ms_addresses` VALUES ('60158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見MIDタワー　25階', '27', '27128', '5406125', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'MIDタワー　25階', 'エムアイディタワー　25カイ');
INSERT INTO `ms_addresses` VALUES ('60159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見MIDタワー　26階', '27', '27128', '5406126', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'MIDタワー　26階', 'エムアイディタワー　26カイ');
INSERT INTO `ms_addresses` VALUES ('60160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見MIDタワー　27階', '27', '27128', '5406127', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'MIDタワー　27階', 'エムアイディタワー　27カイ');
INSERT INTO `ms_addresses` VALUES ('60161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見MIDタワー　28階', '27', '27128', '5406128', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'MIDタワー　28階', 'エムアイディタワー　28カイ');
INSERT INTO `ms_addresses` VALUES ('60162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見MIDタワー　29階', '27', '27128', '5406129', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'MIDタワー　29階', 'エムアイディタワー　29カイ');
INSERT INTO `ms_addresses` VALUES ('60163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見MIDタワー　30階', '27', '27128', '5406130', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'MIDタワー　30階', 'エムアイディタワー　30カイ');
INSERT INTO `ms_addresses` VALUES ('60164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見MIDタワー　31階', '27', '27128', '5406131', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'MIDタワー　31階', 'エムアイディタワー　31カイ');
INSERT INTO `ms_addresses` VALUES ('60165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見MIDタワー　32階', '27', '27128', '5406132', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'MIDタワー　32階', 'エムアイディタワー　32カイ');
INSERT INTO `ms_addresses` VALUES ('60166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見MIDタワー　33階', '27', '27128', '5406133', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'MIDタワー　33階', 'エムアイディタワー　33カイ');
INSERT INTO `ms_addresses` VALUES ('60167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見MIDタワー　34階', '27', '27128', '5406134', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'MIDタワー　34階', 'エムアイディタワー　34カイ');
INSERT INTO `ms_addresses` VALUES ('60168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見MIDタワー　35階', '27', '27128', '5406135', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'MIDタワー　35階', 'エムアイディタワー　35カイ');
INSERT INTO `ms_addresses` VALUES ('60169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見MIDタワー　36階', '27', '27128', '5406136', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'MIDタワー　36階', 'エムアイディタワー　36カイ');
INSERT INTO `ms_addresses` VALUES ('60170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見MIDタワー　37階', '27', '27128', '5406137', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'MIDタワー　37階', 'エムアイディタワー　37カイ');
INSERT INTO `ms_addresses` VALUES ('60171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見MIDタワー　38階', '27', '27128', '5406138', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'MIDタワー　38階', 'エムアイディタワー　38カイ');
INSERT INTO `ms_addresses` VALUES ('60172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見MIDタワー　', '27', '27128', '5406190', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'MIDタワー　', 'エムアイディタワー　');
INSERT INTO `ms_addresses` VALUES ('60173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見パナソニックタワー　1階', '27', '27128', '5406201', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'パナソニックタワー　1階', 'パナソニックタワー　01カイ');
INSERT INTO `ms_addresses` VALUES ('60174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見パナソニックタワー　2階', '27', '27128', '5406202', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'パナソニックタワー　2階', 'パナソニックタワー　02カイ');
INSERT INTO `ms_addresses` VALUES ('60175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見パナソニックタワー　3階', '27', '27128', '5406203', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'パナソニックタワー　3階', 'パナソニックタワー　03カイ');
INSERT INTO `ms_addresses` VALUES ('60176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見パナソニックタワー　4階', '27', '27128', '5406204', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'パナソニックタワー　4階', 'パナソニックタワー　04カイ');
INSERT INTO `ms_addresses` VALUES ('60177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見パナソニックタワー　5階', '27', '27128', '5406205', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'パナソニックタワー　5階', 'パナソニックタワー　05カイ');
INSERT INTO `ms_addresses` VALUES ('60178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見パナソニックタワー　6階', '27', '27128', '5406206', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'パナソニックタワー　6階', 'パナソニックタワー　06カイ');
INSERT INTO `ms_addresses` VALUES ('60179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見パナソニックタワー　7階', '27', '27128', '5406207', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'パナソニックタワー　7階', 'パナソニックタワー　07カイ');
INSERT INTO `ms_addresses` VALUES ('60180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見パナソニックタワー　8階', '27', '27128', '5406208', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'パナソニックタワー　8階', 'パナソニックタワー　08カイ');
INSERT INTO `ms_addresses` VALUES ('60181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見パナソニックタワー　9階', '27', '27128', '5406209', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'パナソニックタワー　9階', 'パナソニックタワー　09カイ');
INSERT INTO `ms_addresses` VALUES ('60182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見パナソニックタワー　10階', '27', '27128', '5406210', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'パナソニックタワー　10階', 'パナソニックタワー　10カイ');
INSERT INTO `ms_addresses` VALUES ('60183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見パナソニックタワー　11階', '27', '27128', '5406211', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'パナソニックタワー　11階', 'パナソニックタワー　11カイ');
INSERT INTO `ms_addresses` VALUES ('60184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見パナソニックタワー　12階', '27', '27128', '5406212', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'パナソニックタワー　12階', 'パナソニックタワー　12カイ');
INSERT INTO `ms_addresses` VALUES ('60185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見パナソニックタワー　13階', '27', '27128', '5406213', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'パナソニックタワー　13階', 'パナソニックタワー　13カイ');
INSERT INTO `ms_addresses` VALUES ('60186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見パナソニックタワー　14階', '27', '27128', '5406214', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'パナソニックタワー　14階', 'パナソニックタワー　14カイ');
INSERT INTO `ms_addresses` VALUES ('60187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見パナソニックタワー　15階', '27', '27128', '5406215', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'パナソニックタワー　15階', 'パナソニックタワー　15カイ');
INSERT INTO `ms_addresses` VALUES ('60188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見パナソニックタワー　16階', '27', '27128', '5406216', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'パナソニックタワー　16階', 'パナソニックタワー　16カイ');
INSERT INTO `ms_addresses` VALUES ('60189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見パナソニックタワー　17階', '27', '27128', '5406217', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'パナソニックタワー　17階', 'パナソニックタワー　17カイ');
INSERT INTO `ms_addresses` VALUES ('60190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見パナソニックタワー　18階', '27', '27128', '5406218', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'パナソニックタワー　18階', 'パナソニックタワー　18カイ');
INSERT INTO `ms_addresses` VALUES ('60191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見パナソニックタワー　19階', '27', '27128', '5406219', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'パナソニックタワー　19階', 'パナソニックタワー　19カイ');
INSERT INTO `ms_addresses` VALUES ('60192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見パナソニックタワー　20階', '27', '27128', '5406220', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'パナソニックタワー　20階', 'パナソニックタワー　20カイ');
INSERT INTO `ms_addresses` VALUES ('60193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見パナソニックタワー　21階', '27', '27128', '5406221', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'パナソニックタワー　21階', 'パナソニックタワー　21カイ');
INSERT INTO `ms_addresses` VALUES ('60194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見パナソニックタワー　22階', '27', '27128', '5406222', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'パナソニックタワー　22階', 'パナソニックタワー　22カイ');
INSERT INTO `ms_addresses` VALUES ('60195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見パナソニックタワー　23階', '27', '27128', '5406223', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'パナソニックタワー　23階', 'パナソニックタワー　23カイ');
INSERT INTO `ms_addresses` VALUES ('60196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見パナソニックタワー　24階', '27', '27128', '5406224', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'パナソニックタワー　24階', 'パナソニックタワー　24カイ');
INSERT INTO `ms_addresses` VALUES ('60197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見パナソニックタワー　25階', '27', '27128', '5406225', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'パナソニックタワー　25階', 'パナソニックタワー　25カイ');
INSERT INTO `ms_addresses` VALUES ('60198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見パナソニックタワー　26階', '27', '27128', '5406226', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'パナソニックタワー　26階', 'パナソニックタワー　26カイ');
INSERT INTO `ms_addresses` VALUES ('60199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見パナソニックタワー　27階', '27', '27128', '5406227', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'パナソニックタワー　27階', 'パナソニックタワー　27カイ');
INSERT INTO `ms_addresses` VALUES ('60200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見パナソニックタワー　28階', '27', '27128', '5406228', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'パナソニックタワー　28階', 'パナソニックタワー　28カイ');
INSERT INTO `ms_addresses` VALUES ('60201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見パナソニックタワー　29階', '27', '27128', '5406229', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'パナソニックタワー　29階', 'パナソニックタワー　29カイ');
INSERT INTO `ms_addresses` VALUES ('60202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見パナソニックタワー　30階', '27', '27128', '5406230', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'パナソニックタワー　30階', 'パナソニックタワー　30カイ');
INSERT INTO `ms_addresses` VALUES ('60203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見パナソニックタワー　31階', '27', '27128', '5406231', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'パナソニックタワー　31階', 'パナソニックタワー　31カイ');
INSERT INTO `ms_addresses` VALUES ('60204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見パナソニックタワー　32階', '27', '27128', '5406232', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'パナソニックタワー　32階', 'パナソニックタワー　32カイ');
INSERT INTO `ms_addresses` VALUES ('60205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見パナソニックタワー　33階', '27', '27128', '5406233', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'パナソニックタワー　33階', 'パナソニックタワー　33カイ');
INSERT INTO `ms_addresses` VALUES ('60206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見パナソニックタワー　34階', '27', '27128', '5406234', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'パナソニックタワー　34階', 'パナソニックタワー　34カイ');
INSERT INTO `ms_addresses` VALUES ('60207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見パナソニックタワー　35階', '27', '27128', '5406235', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'パナソニックタワー　35階', 'パナソニックタワー　35カイ');
INSERT INTO `ms_addresses` VALUES ('60208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見パナソニックタワー　36階', '27', '27128', '5406236', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'パナソニックタワー　36階', 'パナソニックタワー　36カイ');
INSERT INTO `ms_addresses` VALUES ('60209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見パナソニックタワー　37階', '27', '27128', '5406237', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'パナソニックタワー　37階', 'パナソニックタワー　37カイ');
INSERT INTO `ms_addresses` VALUES ('60210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見パナソニックタワー　38階', '27', '27128', '5406238', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'パナソニックタワー　38階', 'パナソニックタワー　38カイ');
INSERT INTO `ms_addresses` VALUES ('60211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見パナソニックタワー　', '27', '27128', '5406290', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, 'パナソニックタワー　', 'パナソニックタワー　');
INSERT INTO `ms_addresses` VALUES ('60212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見松下IMPビル　1階', '27', '27128', '5406301', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, '松下IMPビル　1階', 'マツシタアイエムピービル　01カイ');
INSERT INTO `ms_addresses` VALUES ('60213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見松下IMPビル　2階', '27', '27128', '5406302', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, '松下IMPビル　2階', 'マツシタアイエムピービル　02カイ');
INSERT INTO `ms_addresses` VALUES ('60214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見松下IMPビル　3階', '27', '27128', '5406303', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, '松下IMPビル　3階', 'マツシタアイエムピービル　03カイ');
INSERT INTO `ms_addresses` VALUES ('60215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見松下IMPビル　4階', '27', '27128', '5406304', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, '松下IMPビル　4階', 'マツシタアイエムピービル　04カイ');
INSERT INTO `ms_addresses` VALUES ('60216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見松下IMPビル　5階', '27', '27128', '5406305', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, '松下IMPビル　5階', 'マツシタアイエムピービル　05カイ');
INSERT INTO `ms_addresses` VALUES ('60217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見松下IMPビル　6階', '27', '27128', '5406306', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, '松下IMPビル　6階', 'マツシタアイエムピービル　06カイ');
INSERT INTO `ms_addresses` VALUES ('60218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見松下IMPビル　7階', '27', '27128', '5406307', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, '松下IMPビル　7階', 'マツシタアイエムピービル　07カイ');
INSERT INTO `ms_addresses` VALUES ('60219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見松下IMPビル　8階', '27', '27128', '5406308', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, '松下IMPビル　8階', 'マツシタアイエムピービル　08カイ');
INSERT INTO `ms_addresses` VALUES ('60220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見松下IMPビル　9階', '27', '27128', '5406309', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, '松下IMPビル　9階', 'マツシタアイエムピービル　09カイ');
INSERT INTO `ms_addresses` VALUES ('60221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見松下IMPビル　10階', '27', '27128', '5406310', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, '松下IMPビル　10階', 'マツシタアイエムピービル　10カイ');
INSERT INTO `ms_addresses` VALUES ('60222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見松下IMPビル　11階', '27', '27128', '5406311', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, '松下IMPビル　11階', 'マツシタアイエムピービル　11カイ');
INSERT INTO `ms_addresses` VALUES ('60223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見松下IMPビル　12階', '27', '27128', '5406312', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, '松下IMPビル　12階', 'マツシタアイエムピービル　12カイ');
INSERT INTO `ms_addresses` VALUES ('60224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見松下IMPビル　13階', '27', '27128', '5406313', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, '松下IMPビル　13階', 'マツシタアイエムピービル　13カイ');
INSERT INTO `ms_addresses` VALUES ('60225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見松下IMPビル　14階', '27', '27128', '5406314', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, '松下IMPビル　14階', 'マツシタアイエムピービル　14カイ');
INSERT INTO `ms_addresses` VALUES ('60226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見松下IMPビル　15階', '27', '27128', '5406315', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, '松下IMPビル　15階', 'マツシタアイエムピービル　15カイ');
INSERT INTO `ms_addresses` VALUES ('60227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見松下IMPビル　16階', '27', '27128', '5406316', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, '松下IMPビル　16階', 'マツシタアイエムピービル　16カイ');
INSERT INTO `ms_addresses` VALUES ('60228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見松下IMPビル　17階', '27', '27128', '5406317', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, '松下IMPビル　17階', 'マツシタアイエムピービル　17カイ');
INSERT INTO `ms_addresses` VALUES ('60229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見松下IMPビル　18階', '27', '27128', '5406318', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, '松下IMPビル　18階', 'マツシタアイエムピービル　18カイ');
INSERT INTO `ms_addresses` VALUES ('60230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見松下IMPビル　19階', '27', '27128', '5406319', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, '松下IMPビル　19階', 'マツシタアイエムピービル　19カイ');
INSERT INTO `ms_addresses` VALUES ('60231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見松下IMPビル　20階', '27', '27128', '5406320', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, '松下IMPビル　20階', 'マツシタアイエムピービル　20カイ');
INSERT INTO `ms_addresses` VALUES ('60232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見松下IMPビル　21階', '27', '27128', '5406321', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, '松下IMPビル　21階', 'マツシタアイエムピービル　21カイ');
INSERT INTO `ms_addresses` VALUES ('60233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見松下IMPビル　22階', '27', '27128', '5406322', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, '松下IMPビル　22階', 'マツシタアイエムピービル　22カイ');
INSERT INTO `ms_addresses` VALUES ('60234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見松下IMPビル　23階', '27', '27128', '5406323', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, '松下IMPビル　23階', 'マツシタアイエムピービル　23カイ');
INSERT INTO `ms_addresses` VALUES ('60235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見松下IMPビル　24階', '27', '27128', '5406324', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, '松下IMPビル　24階', 'マツシタアイエムピービル　24カイ');
INSERT INTO `ms_addresses` VALUES ('60236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見松下IMPビル　25階', '27', '27128', '5406325', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, '松下IMPビル　25階', 'マツシタアイエムピービル　25カイ');
INSERT INTO `ms_addresses` VALUES ('60237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見松下IMPビル　26階', '27', '27128', '5406326', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, '松下IMPビル　26階', 'マツシタアイエムピービル　26カイ');
INSERT INTO `ms_addresses` VALUES ('60238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区城見松下IMPビル　', '27', '27128', '5406390', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '城見', 'シロミ', null, null, '松下IMPビル　', 'マツシタアイエムピービル　');
INSERT INTO `ms_addresses` VALUES ('60297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区北浜', '27', '27128', '5410041', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '北浜', 'キタハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区今橋', '27', '27128', '5410042', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '今橋', 'イマバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区高麗橋', '27', '27128', '5410043', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '高麗橋', 'コウライバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区伏見町', '27', '27128', '5410044', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '伏見町', 'フシミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区道修町', '27', '27128', '5410045', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '道修町', 'ドショウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区平野町', '27', '27128', '5410046', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '平野町', 'ヒラノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区淡路町', '27', '27128', '5410047', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '淡路町', 'アワジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区瓦町', '27', '27128', '5410048', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '瓦町', 'カワラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区備後町', '27', '27128', '5410051', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '備後町', 'ビンゴマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区安土町', '27', '27128', '5410052', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '安土町', 'アヅチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区本町', '27', '27128', '5410053', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区南本町', '27', '27128', '5410054', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '南本町', 'ミナミホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区船場中央', '27', '27128', '5410055', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '船場中央', 'センバチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区久太郎町', '27', '27128', '5410056', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '久太郎町', 'キュウタロウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区北久宝寺町', '27', '27128', '5410057', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '北久宝寺町', 'キタキュウホウジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区南久宝寺町', '27', '27128', '5410058', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '南久宝寺町', 'ミナミキュウホウジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区博労町', '27', '27128', '5410059', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '博労町', 'バクロウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区谷町6丁目', '27', '27128', '5420012', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '谷町', 'タニマチ', null, null, '6丁目', '06チョウメ');
INSERT INTO `ms_addresses` VALUES ('60379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区谷町7丁目', '27', '27128', '5420012', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '谷町', 'タニマチ', null, null, '7丁目', '07チョウメ');
INSERT INTO `ms_addresses` VALUES ('60380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区谷町8丁目', '27', '27128', '5420012', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '谷町', 'タニマチ', null, null, '8丁目', '08チョウメ');
INSERT INTO `ms_addresses` VALUES ('60381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区谷町9丁目', '27', '27128', '5420012', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '谷町', 'タニマチ', null, null, '9丁目', '09チョウメ');
INSERT INTO `ms_addresses` VALUES ('60382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区安堂寺町', '27', '27128', '5420061', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '安堂寺町', 'アンドウジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区上本町西', '27', '27128', '5420062', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '上本町西', 'ウエホンマチニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区東平', '27', '27128', '5420063', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '東平', 'トウヘイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区上汐', '27', '27128', '5420064', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '上汐', 'ウエシオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区中寺', '27', '27128', '5420065', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '中寺', 'ナカデラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区瓦屋町', '27', '27128', '5420066', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '瓦屋町', 'カワラヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区松屋町', '27', '27128', '5420067', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '松屋町', 'マツヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区道頓堀', '27', '27128', '5420071', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '道頓堀', 'ドウトンボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区高津', '27', '27128', '5420072', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '高津', 'コウヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区日本橋', '27', '27128', '5420073', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '日本橋', 'ニッポンバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区千日前', '27', '27128', '5420074', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '千日前', 'センニチマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区難波千日前', '27', '27128', '5420075', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '難波千日前', 'ナンバセンニチマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区難波', '27', '27128', '5420076', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '難波', 'ナンバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区道頓堀1丁目東', '27', '27128', '5420077', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '道頓堀', 'ドウトンボリ', null, null, '1丁目東', '01チョウメヒガシ');
INSERT INTO `ms_addresses` VALUES ('60396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区南船場', '27', '27128', '5420081', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '南船場', 'ミナミセンバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区島之内', '27', '27128', '5420082', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '島之内', 'シマノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区東心斎橋', '27', '27128', '5420083', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '東心斎橋', 'ヒガシシンサイバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区宗右衛門町', '27', '27128', '5420084', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '宗右衛門町', 'ソウエモンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区心斎橋筋', '27', '27128', '5420085', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '心斎橋筋', 'シンサイバシスジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市中央区西心斎橋', '27', '27128', '5420086', '大阪府', 'オオサカフ', '大阪市中央区', 'オオサカシチュウオウク', '西心斎橋', 'ニシシンサイバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市天王寺区', '27', '27109', '5430000', '大阪府', 'オオサカフ', '大阪市天王寺区', 'オオサカシテンノウジク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('60429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市天王寺区上本町', '27', '27109', '5430001', '大阪府', 'オオサカフ', '大阪市天王寺区', 'オオサカシテンノウジク', '上本町', 'ウエホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市天王寺区上汐', '27', '27109', '5430002', '大阪府', 'オオサカフ', '大阪市天王寺区', 'オオサカシテンノウジク', '上汐', 'ウエシオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市天王寺区清水谷町', '27', '27109', '5430011', '大阪府', 'オオサカフ', '大阪市天王寺区', 'オオサカシテンノウジク', '清水谷町', 'シミズダニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市天王寺区空堀町', '27', '27109', '5430012', '大阪府', 'オオサカフ', '大阪市天王寺区', 'オオサカシテンノウジク', '空堀町', 'カラホリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市天王寺区玉造本町', '27', '27109', '5430013', '大阪府', 'オオサカフ', '大阪市天王寺区', 'オオサカシテンノウジク', '玉造本町', 'タマツクリホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市天王寺区玉造元町', '27', '27109', '5430014', '大阪府', 'オオサカフ', '大阪市天王寺区', 'オオサカシテンノウジク', '玉造元町', 'タマツクリモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市天王寺区真田山町', '27', '27109', '5430015', '大阪府', 'オオサカフ', '大阪市天王寺区', 'オオサカシテンノウジク', '真田山町', 'サナダヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市天王寺区餌差町', '27', '27109', '5430016', '大阪府', 'オオサカフ', '大阪市天王寺区', 'オオサカシテンノウジク', '餌差町', 'エサシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市天王寺区城南寺町', '27', '27109', '5430017', '大阪府', 'オオサカフ', '大阪市天王寺区', 'オオサカシテンノウジク', '城南寺町', 'ジョウナンテラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市天王寺区空清町', '27', '27109', '5430018', '大阪府', 'オオサカフ', '大阪市天王寺区', 'オオサカシテンノウジク', '空清町', 'カラキヨチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市天王寺区東高津町', '27', '27109', '5430021', '大阪府', 'オオサカフ', '大阪市天王寺区', 'オオサカシテンノウジク', '東高津町', 'ヒガシコウヅチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市天王寺区味原本町', '27', '27109', '5430022', '大阪府', 'オオサカフ', '大阪市天王寺区', 'オオサカシテンノウジク', '味原本町', 'アジハラホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市天王寺区味原町', '27', '27109', '5430023', '大阪府', 'オオサカフ', '大阪市天王寺区', 'オオサカシテンノウジク', '味原町', 'アジハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市天王寺区舟橋町', '27', '27109', '5430024', '大阪府', 'オオサカフ', '大阪市天王寺区', 'オオサカシテンノウジク', '舟橋町', 'フナハシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市天王寺区下味原町', '27', '27109', '5430025', '大阪府', 'オオサカフ', '大阪市天王寺区', 'オオサカシテンノウジク', '下味原町', 'シモアジハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市天王寺区東上町', '27', '27109', '5430026', '大阪府', 'オオサカフ', '大阪市天王寺区', 'オオサカシテンノウジク', '東上町', 'トウジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市天王寺区筆ケ崎町', '27', '27109', '5430027', '大阪府', 'オオサカフ', '大阪市天王寺区', 'オオサカシテンノウジク', '筆ケ崎町', 'フデガサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市天王寺区小橋町', '27', '27109', '5430028', '大阪府', 'オオサカフ', '大阪市天王寺区', 'オオサカシテンノウジク', '小橋町', 'オバセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市天王寺区石ケ辻町', '27', '27109', '5430031', '大阪府', 'オオサカフ', '大阪市天王寺区', 'オオサカシテンノウジク', '石ケ辻町', 'イシガツジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市天王寺区細工谷', '27', '27109', '5430032', '大阪府', 'オオサカフ', '大阪市天王寺区', 'オオサカシテンノウジク', '細工谷', 'サイクダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市天王寺区堂ケ芝', '27', '27109', '5430033', '大阪府', 'オオサカフ', '大阪市天王寺区', 'オオサカシテンノウジク', '堂ケ芝', 'ドウガシバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市天王寺区松ケ鼻町', '27', '27109', '5430034', '大阪府', 'オオサカフ', '大阪市天王寺区', 'オオサカシテンノウジク', '松ケ鼻町', 'マツガハナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市天王寺区北山町', '27', '27109', '5430035', '大阪府', 'オオサカフ', '大阪市天王寺区', 'オオサカシテンノウジク', '北山町', 'キタヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市天王寺区小宮町', '27', '27109', '5430036', '大阪府', 'オオサカフ', '大阪市天王寺区', 'オオサカシテンノウジク', '小宮町', 'コミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市天王寺区上之宮町', '27', '27109', '5430037', '大阪府', 'オオサカフ', '大阪市天王寺区', 'オオサカシテンノウジク', '上之宮町', 'ウエノミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市天王寺区真法院町', '27', '27109', '5430041', '大阪府', 'オオサカフ', '大阪市天王寺区', 'オオサカシテンノウジク', '真法院町', 'シンポウインチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市天王寺区烏ケ辻', '27', '27109', '5430042', '大阪府', 'オオサカフ', '大阪市天王寺区', 'オオサカシテンノウジク', '烏ケ辻', 'カラスガツジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市天王寺区勝山', '27', '27109', '5430043', '大阪府', 'オオサカフ', '大阪市天王寺区', 'オオサカシテンノウジク', '勝山', 'カツヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市天王寺区国分町', '27', '27109', '5430044', '大阪府', 'オオサカフ', '大阪市天王寺区', 'オオサカシテンノウジク', '国分町', 'コクブチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市天王寺区寺田町', '27', '27109', '5430045', '大阪府', 'オオサカフ', '大阪市天王寺区', 'オオサカシテンノウジク', '寺田町', 'テラダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市天王寺区四天王寺', '27', '27109', '5430051', '大阪府', 'オオサカフ', '大阪市天王寺区', 'オオサカシテンノウジク', '四天王寺', 'シテンノウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市天王寺区大道', '27', '27109', '5430052', '大阪府', 'オオサカフ', '大阪市天王寺区', 'オオサカシテンノウジク', '大道', 'ダイドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市天王寺区北河堀町', '27', '27109', '5430053', '大阪府', 'オオサカフ', '大阪市天王寺区', 'オオサカシテンノウジク', '北河堀町', 'キタカワホリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市天王寺区南河堀町', '27', '27109', '5430054', '大阪府', 'オオサカフ', '大阪市天王寺区', 'オオサカシテンノウジク', '南河堀町', 'ミナミカワホリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市天王寺区悲田院町', '27', '27109', '5430055', '大阪府', 'オオサカフ', '大阪市天王寺区', 'オオサカシテンノウジク', '悲田院町', 'ヒデンインチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市天王寺区堀越町', '27', '27109', '5430056', '大阪府', 'オオサカフ', '大阪市天王寺区', 'オオサカシテンノウジク', '堀越町', 'ホリコシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市天王寺区伶人町', '27', '27109', '5430061', '大阪府', 'オオサカフ', '大阪市天王寺区', 'オオサカシテンノウジク', '伶人町', 'レイニンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市天王寺区逢阪', '27', '27109', '5430062', '大阪府', 'オオサカフ', '大阪市天王寺区', 'オオサカシテンノウジク', '逢阪', 'オウサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市天王寺区茶臼山町', '27', '27109', '5430063', '大阪府', 'オオサカフ', '大阪市天王寺区', 'オオサカシテンノウジク', '茶臼山町', 'チャウスヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市天王寺区生玉町', '27', '27109', '5430071', '大阪府', 'オオサカフ', '大阪市天王寺区', 'オオサカシテンノウジク', '生玉町', 'イクタマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市天王寺区生玉前町', '27', '27109', '5430072', '大阪府', 'オオサカフ', '大阪市天王寺区', 'オオサカシテンノウジク', '生玉前町', 'イクタママエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市天王寺区生玉寺町', '27', '27109', '5430073', '大阪府', 'オオサカフ', '大阪市天王寺区', 'オオサカシテンノウジク', '生玉寺町', 'イクタマテラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市天王寺区六万体町', '27', '27109', '5430074', '大阪府', 'オオサカフ', '大阪市天王寺区', 'オオサカシテンノウジク', '六万体町', 'ロクマンタイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市天王寺区夕陽丘町', '27', '27109', '5430075', '大阪府', 'オオサカフ', '大阪市天王寺区', 'オオサカシテンノウジク', '夕陽丘町', 'ユウヒガオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市天王寺区下寺町', '27', '27109', '5430076', '大阪府', 'オオサカフ', '大阪市天王寺区', 'オオサカシテンノウジク', '下寺町', 'シタデラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市生野区', '27', '27116', '5440000', '大阪府', 'オオサカフ', '大阪市生野区', 'オオサカシイクノク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('60486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市生野区新今里', '27', '27116', '5440001', '大阪府', 'オオサカフ', '大阪市生野区', 'オオサカシイクノク', '新今里', 'シンイマザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市生野区小路', '27', '27116', '5440002', '大阪府', 'オオサカフ', '大阪市生野区', 'オオサカシイクノク', '小路', 'ショウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市生野区小路東', '27', '27116', '5440003', '大阪府', 'オオサカフ', '大阪市生野区', 'オオサカシイクノク', '小路東', 'ショウジヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市生野区巽北', '27', '27116', '5440004', '大阪府', 'オオサカフ', '大阪市生野区', 'オオサカシイクノク', '巽北', 'タツミキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市生野区中川', '27', '27116', '5440005', '大阪府', 'オオサカフ', '大阪市生野区', 'オオサカシイクノク', '中川', 'ナカガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市生野区中川東', '27', '27116', '5440006', '大阪府', 'オオサカフ', '大阪市生野区', 'オオサカシイクノク', '中川東', 'ナカガワヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市生野区田島', '27', '27116', '5440011', '大阪府', 'オオサカフ', '大阪市生野区', 'オオサカシイクノク', '田島', 'タジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市生野区巽西', '27', '27116', '5440012', '大阪府', 'オオサカフ', '大阪市生野区', 'オオサカシイクノク', '巽西', 'タツミニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市生野区巽中', '27', '27116', '5440013', '大阪府', 'オオサカフ', '大阪市生野区', 'オオサカシイクノク', '巽中', 'タツミナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市生野区巽東', '27', '27116', '5440014', '大阪府', 'オオサカフ', '大阪市生野区', 'オオサカシイクノク', '巽東', 'タツミヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市生野区巽南', '27', '27116', '5440015', '大阪府', 'オオサカフ', '大阪市生野区', 'オオサカシイクノク', '巽南', 'タツミミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市生野区勝山南', '27', '27116', '5440021', '大阪府', 'オオサカフ', '大阪市生野区', 'オオサカシイクノク', '勝山南', 'カツヤマミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市生野区舎利寺', '27', '27116', '5440022', '大阪府', 'オオサカフ', '大阪市生野区', 'オオサカシイクノク', '舎利寺', 'シャリジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市生野区林寺', '27', '27116', '5440023', '大阪府', 'オオサカフ', '大阪市生野区', 'オオサカシイクノク', '林寺', 'ハヤシジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市生野区生野西', '27', '27116', '5440024', '大阪府', 'オオサカフ', '大阪市生野区', 'オオサカシイクノク', '生野西', 'イクノニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市生野区生野東', '27', '27116', '5440025', '大阪府', 'オオサカフ', '大阪市生野区', 'オオサカシイクノク', '生野東', 'イクノヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市生野区鶴橋', '27', '27116', '5440031', '大阪府', 'オオサカフ', '大阪市生野区', 'オオサカシイクノク', '鶴橋', 'ツルハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市生野区中川西', '27', '27116', '5440032', '大阪府', 'オオサカフ', '大阪市生野区', 'オオサカシイクノク', '中川西', 'ナカガワニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市生野区勝山北', '27', '27116', '5440033', '大阪府', 'オオサカフ', '大阪市生野区', 'オオサカシイクノク', '勝山北', 'カツヤマキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市生野区桃谷', '27', '27116', '5440034', '大阪府', 'オオサカフ', '大阪市生野区', 'オオサカシイクノク', '桃谷', 'モモダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市阿倍野区', '27', '27119', '5450000', '大阪府', 'オオサカフ', '大阪市阿倍野区', 'オオサカシアベノク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('60510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市阿倍野区天王寺町北', '27', '27119', '5450001', '大阪府', 'オオサカフ', '大阪市阿倍野区', 'オオサカシアベノク', '天王寺町北', 'テンノウジチョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市阿倍野区天王寺町南', '27', '27119', '5450002', '大阪府', 'オオサカフ', '大阪市阿倍野区', 'オオサカシアベノク', '天王寺町南', 'テンノウジチョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市阿倍野区美章園', '27', '27119', '5450003', '大阪府', 'オオサカフ', '大阪市阿倍野区', 'オオサカシアベノク', '美章園', 'ビショウエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市阿倍野区文の里', '27', '27119', '5450004', '大阪府', 'オオサカフ', '大阪市阿倍野区', 'オオサカシアベノク', '文の里', 'フミノサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市阿倍野区三明町', '27', '27119', '5450005', '大阪府', 'オオサカフ', '大阪市阿倍野区', 'オオサカシアベノク', '三明町', 'サンメイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市阿倍野区昭和町', '27', '27119', '5450011', '大阪府', 'オオサカフ', '大阪市阿倍野区', 'オオサカシアベノク', '昭和町', 'ショウワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市阿倍野区桃ケ池町', '27', '27119', '5450012', '大阪府', 'オオサカフ', '大阪市阿倍野区', 'オオサカシアベノク', '桃ケ池町', 'モモガイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市阿倍野区長池町', '27', '27119', '5450013', '大阪府', 'オオサカフ', '大阪市阿倍野区', 'オオサカシアベノク', '長池町', 'ナガイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市阿倍野区西田辺町', '27', '27119', '5450014', '大阪府', 'オオサカフ', '大阪市阿倍野区', 'オオサカシアベノク', '西田辺町', 'ニシタナベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市阿倍野区阪南町', '27', '27119', '5450021', '大阪府', 'オオサカフ', '大阪市阿倍野区', 'オオサカシアベノク', '阪南町', 'ハンナンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市阿倍野区播磨町', '27', '27119', '5450022', '大阪府', 'オオサカフ', '大阪市阿倍野区', 'オオサカシアベノク', '播磨町', 'ハリマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市阿倍野区王子町', '27', '27119', '5450023', '大阪府', 'オオサカフ', '大阪市阿倍野区', 'オオサカシアベノク', '王子町', 'オウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市阿倍野区橋本町', '27', '27119', '5450031', '大阪府', 'オオサカフ', '大阪市阿倍野区', 'オオサカシアベノク', '橋本町', 'ハシモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市阿倍野区晴明通', '27', '27119', '5450032', '大阪府', 'オオサカフ', '大阪市阿倍野区', 'オオサカシアベノク', '晴明通', 'セイメイドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市阿倍野区相生通', '27', '27119', '5450033', '大阪府', 'オオサカフ', '大阪市阿倍野区', 'オオサカシアベノク', '相生通', 'アイオイドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市阿倍野区阿倍野元町', '27', '27119', '5450034', '大阪府', 'オオサカフ', '大阪市阿倍野区', 'オオサカシアベノク', '阿倍野元町', 'アベノモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市阿倍野区北畠', '27', '27119', '5450035', '大阪府', 'オオサカフ', '大阪市阿倍野区', 'オオサカシアベノク', '北畠', 'キタバタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市阿倍野区万代', '27', '27119', '5450036', '大阪府', 'オオサカフ', '大阪市阿倍野区', 'オオサカシアベノク', '万代', 'バンダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市阿倍野区帝塚山', '27', '27119', '5450037', '大阪府', 'オオサカフ', '大阪市阿倍野区', 'オオサカシアベノク', '帝塚山', 'テヅカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市阿倍野区共立通', '27', '27119', '5450041', '大阪府', 'オオサカフ', '大阪市阿倍野区', 'オオサカシアベノク', '共立通', 'キョウリツドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市阿倍野区丸山通', '27', '27119', '5450042', '大阪府', 'オオサカフ', '大阪市阿倍野区', 'オオサカシアベノク', '丸山通', 'マルヤマドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市阿倍野区松虫通', '27', '27119', '5450043', '大阪府', 'オオサカフ', '大阪市阿倍野区', 'オオサカシアベノク', '松虫通', 'マツムシドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市阿倍野区旭町', '27', '27119', '5450051', '大阪府', 'オオサカフ', '大阪市阿倍野区', 'オオサカシアベノク', '旭町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市阿倍野区阿倍野筋', '27', '27119', '5450052', '大阪府', 'オオサカフ', '大阪市阿倍野区', 'オオサカシアベノク', '阿倍野筋', 'アベノスジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市阿倍野区松崎町', '27', '27119', '5450053', '大阪府', 'オオサカフ', '大阪市阿倍野区', 'オオサカシアベノク', '松崎町', 'マツザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市東住吉区', '27', '27121', '5460000', '大阪府', 'オオサカフ', '大阪市東住吉区', 'オオサカシヒガシスミヨシク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('60545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市東住吉区今林', '27', '27121', '5460001', '大阪府', 'オオサカフ', '大阪市東住吉区', 'オオサカシヒガシスミヨシク', '今林', 'イマバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市東住吉区杭全', '27', '27121', '5460002', '大阪府', 'オオサカフ', '大阪市東住吉区', 'オオサカシヒガシスミヨシク', '杭全', 'クマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市東住吉区今川', '27', '27121', '5460003', '大阪府', 'オオサカフ', '大阪市東住吉区', 'オオサカシヒガシスミヨシク', '今川', 'イマガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市東住吉区針中野', '27', '27121', '5460011', '大阪府', 'オオサカフ', '大阪市東住吉区', 'オオサカシヒガシスミヨシク', '針中野', 'ハリナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市東住吉区中野', '27', '27121', '5460012', '大阪府', 'オオサカフ', '大阪市東住吉区', 'オオサカシヒガシスミヨシク', '中野', 'ナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市東住吉区湯里', '27', '27121', '5460013', '大阪府', 'オオサカフ', '大阪市東住吉区', 'オオサカシヒガシスミヨシク', '湯里', 'ユザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市東住吉区鷹合', '27', '27121', '5460014', '大阪府', 'オオサカフ', '大阪市東住吉区', 'オオサカシヒガシスミヨシク', '鷹合', 'タカアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市東住吉区照ケ丘矢田', '27', '27121', '5460021', '大阪府', 'オオサカフ', '大阪市東住吉区', 'オオサカシヒガシスミヨシク', '照ケ丘矢田', 'テルガオカヤタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市東住吉区住道矢田', '27', '27121', '5460022', '大阪府', 'オオサカフ', '大阪市東住吉区', 'オオサカシヒガシスミヨシク', '住道矢田', 'スンジヤタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市東住吉区矢田', '27', '27121', '5460023', '大阪府', 'オオサカフ', '大阪市東住吉区', 'オオサカシヒガシスミヨシク', '矢田', 'ヤタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市東住吉区公園南矢田', '27', '27121', '5460024', '大阪府', 'オオサカフ', '大阪市東住吉区', 'オオサカシヒガシスミヨシク', '公園南矢田', 'コウエンミナミヤタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市東住吉区田辺', '27', '27121', '5460031', '大阪府', 'オオサカフ', '大阪市東住吉区', 'オオサカシヒガシスミヨシク', '田辺', 'タナベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市東住吉区東田辺', '27', '27121', '5460032', '大阪府', 'オオサカフ', '大阪市東住吉区', 'オオサカシヒガシスミヨシク', '東田辺', 'ヒガシタナベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市東住吉区南田辺', '27', '27121', '5460033', '大阪府', 'オオサカフ', '大阪市東住吉区', 'オオサカシヒガシスミヨシク', '南田辺', 'ミナミタナベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市東住吉区長居公園', '27', '27121', '5460034', '大阪府', 'オオサカフ', '大阪市東住吉区', 'オオサカシヒガシスミヨシク', '長居公園', 'ナガイコウエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市東住吉区山坂', '27', '27121', '5460035', '大阪府', 'オオサカフ', '大阪市東住吉区', 'オオサカシヒガシスミヨシク', '山坂', 'ヤマサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市東住吉区桑津', '27', '27121', '5460041', '大阪府', 'オオサカフ', '大阪市東住吉区', 'オオサカシヒガシスミヨシク', '桑津', 'クワヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市東住吉区西今川', '27', '27121', '5460042', '大阪府', 'オオサカフ', '大阪市東住吉区', 'オオサカシヒガシスミヨシク', '西今川', 'ニシイマガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市東住吉区駒川', '27', '27121', '5460043', '大阪府', 'オオサカフ', '大阪市東住吉区', 'オオサカシヒガシスミヨシク', '駒川', 'コマガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市東住吉区北田辺', '27', '27121', '5460044', '大阪府', 'オオサカフ', '大阪市東住吉区', 'オオサカシヒガシスミヨシク', '北田辺', 'キタタナベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市平野区', '27', '27126', '5470000', '大阪府', 'オオサカフ', '大阪市平野区', 'オオサカシヒラノク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('60567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市平野区加美北', '27', '27126', '5470001', '大阪府', 'オオサカフ', '大阪市平野区', 'オオサカシヒラノク', '加美北', 'カミキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市平野区加美東', '27', '27126', '5470002', '大阪府', 'オオサカフ', '大阪市平野区', 'オオサカシヒラノク', '加美東', 'カミヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市平野区加美南', '27', '27126', '5470003', '大阪府', 'オオサカフ', '大阪市平野区', 'オオサカシヒラノク', '加美南', 'カミミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市平野区加美鞍作', '27', '27126', '5470004', '大阪府', 'オオサカフ', '大阪市平野区', 'オオサカシヒラノク', '加美鞍作', 'カミクラツクリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市平野区加美西', '27', '27126', '5470005', '大阪府', 'オオサカフ', '大阪市平野区', 'オオサカシヒラノク', '加美西', 'カミニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市平野区加美正覚寺', '27', '27126', '5470006', '大阪府', 'オオサカフ', '大阪市平野区', 'オオサカシヒラノク', '加美正覚寺', 'カミショウカクジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市平野区長吉出戸', '27', '27126', '5470011', '大阪府', 'オオサカフ', '大阪市平野区', 'オオサカシヒラノク', '長吉出戸', 'ナガヨシデト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市平野区長吉六反', '27', '27126', '5470012', '大阪府', 'オオサカフ', '大阪市平野区', 'オオサカシヒラノク', '長吉六反', 'ナガヨシロクタン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市平野区長吉長原東', '27', '27126', '5470013', '大阪府', 'オオサカフ', '大阪市平野区', 'オオサカシヒラノク', '長吉長原東', 'ナガヨシナガハラヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市平野区長吉川辺', '27', '27126', '5470014', '大阪府', 'オオサカフ', '大阪市平野区', 'オオサカシヒラノク', '長吉川辺', 'ナガヨシカワナベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市平野区長吉長原西', '27', '27126', '5470015', '大阪府', 'オオサカフ', '大阪市平野区', 'オオサカシヒラノク', '長吉長原西', 'ナガヨシナガハラニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市平野区長吉長原', '27', '27126', '5470016', '大阪府', 'オオサカフ', '大阪市平野区', 'オオサカシヒラノク', '長吉長原', 'ナガヨシナガハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市平野区喜連東', '27', '27126', '5470021', '大阪府', 'オオサカフ', '大阪市平野区', 'オオサカシヒラノク', '喜連東', 'キレヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市平野区瓜破東', '27', '27126', '5470022', '大阪府', 'オオサカフ', '大阪市平野区', 'オオサカシヒラノク', '瓜破東', 'ウリワリヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市平野区瓜破南', '27', '27126', '5470023', '大阪府', 'オオサカフ', '大阪市平野区', 'オオサカシヒラノク', '瓜破南', 'ウリワリミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市平野区瓜破', '27', '27126', '5470024', '大阪府', 'オオサカフ', '大阪市平野区', 'オオサカシヒラノク', '瓜破', 'ウリワリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市平野区瓜破西', '27', '27126', '5470025', '大阪府', 'オオサカフ', '大阪市平野区', 'オオサカシヒラノク', '瓜破西', 'ウリワリニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市平野区喜連西', '27', '27126', '5470026', '大阪府', 'オオサカフ', '大阪市平野区', 'オオサカシヒラノク', '喜連西', 'キレニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市平野区喜連', '27', '27126', '5470027', '大阪府', 'オオサカフ', '大阪市平野区', 'オオサカシヒラノク', '喜連', 'キレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市平野区平野南', '27', '27126', '5470031', '大阪府', 'オオサカフ', '大阪市平野区', 'オオサカシヒラノク', '平野南', 'ヒラノミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市平野区流町', '27', '27126', '5470032', '大阪府', 'オオサカフ', '大阪市平野区', 'オオサカシヒラノク', '流町', 'ナガレマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市平野区平野西', '27', '27126', '5470033', '大阪府', 'オオサカフ', '大阪市平野区', 'オオサカシヒラノク', '平野西', 'ヒラノニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市平野区背戸口', '27', '27126', '5470034', '大阪府', 'オオサカフ', '大阪市平野区', 'オオサカシヒラノク', '背戸口', 'セトグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市平野区西脇', '27', '27126', '5470035', '大阪府', 'オオサカフ', '大阪市平野区', 'オオサカシヒラノク', '西脇', 'ニシワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市平野区平野北', '27', '27126', '5470041', '大阪府', 'オオサカフ', '大阪市平野区', 'オオサカシヒラノク', '平野北', 'ヒラノキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市平野区平野市町', '27', '27126', '5470042', '大阪府', 'オオサカフ', '大阪市平野区', 'オオサカシヒラノク', '平野市町', 'ヒラノイチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市平野区平野東', '27', '27126', '5470043', '大阪府', 'オオサカフ', '大阪市平野区', 'オオサカシヒラノク', '平野東', 'ヒラノヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市平野区平野本町', '27', '27126', '5470044', '大阪府', 'オオサカフ', '大阪市平野区', 'オオサカシヒラノク', '平野本町', 'ヒラノホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市平野区平野上町', '27', '27126', '5470045', '大阪府', 'オオサカフ', '大阪市平野区', 'オオサカシヒラノク', '平野上町', 'ヒラノウエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市平野区平野宮町', '27', '27126', '5470046', '大阪府', 'オオサカフ', '大阪市平野区', 'オオサカシヒラノク', '平野宮町', 'ヒラノミヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市平野区平野元町', '27', '27126', '5470047', '大阪府', 'オオサカフ', '大阪市平野区', 'オオサカシヒラノク', '平野元町', 'ヒラノモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市平野区平野馬場', '27', '27126', '5470048', '大阪府', 'オオサカフ', '大阪市平野区', 'オオサカシヒラノク', '平野馬場', 'ヒラノババ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉佐野市泉州空港北', '27', '27213', '5490001', '大阪府', 'オオサカフ', '泉佐野市', 'イズミサノシ', '泉州空港北', 'センシュウクウコウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉南郡田尻町泉州空港中', '27', '27362', '5490011', '大阪府', 'オオサカフ', '泉南郡田尻町', 'センナングンタジリチョウ', '泉州空港中', 'センシュウクウコウナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉南市泉州空港南', '27', '27228', '5490021', '大阪府', 'オオサカフ', '泉南市', 'センナンシ', '泉州空港南', 'センシュウクウコウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道沙流郡日高町', '01', '01601', '0550000', '北海道', 'ホッカイドウ', '沙流郡日高町', 'サルグンヒダカチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('60609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市西区', '27', '27106', '5500000', '大阪府', 'オオサカフ', '大阪市西区', 'オオサカシニシク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('60610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市西区土佐堀', '27', '27106', '5500001', '大阪府', 'オオサカフ', '大阪市西区', 'オオサカシニシク', '土佐堀', 'トサボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市西区江戸堀', '27', '27106', '5500002', '大阪府', 'オオサカフ', '大阪市西区', 'オオサカシニシク', '江戸堀', 'エドボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市西区京町堀', '27', '27106', '5500003', '大阪府', 'オオサカフ', '大阪市西区', 'オオサカシニシク', '京町堀', 'キョウマチボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市西区靱本町', '27', '27106', '5500004', '大阪府', 'オオサカフ', '大阪市西区', 'オオサカシニシク', '靱本町', 'ウツボホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市西区西本町', '27', '27106', '5500005', '大阪府', 'オオサカフ', '大阪市西区', 'オオサカシニシク', '西本町', 'ニシホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市西区江之子島', '27', '27106', '5500006', '大阪府', 'オオサカフ', '大阪市西区', 'オオサカシニシク', '江之子島', 'エノコジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道沙流郡日高町富川北', '01', '01601', '0550001', '北海道', 'ホッカイドウ', '沙流郡日高町', 'サルグンヒダカチョウ', '富川北', 'トミカワキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市西区阿波座', '27', '27106', '5500011', '大阪府', 'オオサカフ', '大阪市西区', 'オオサカシニシク', '阿波座', 'アワザ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市西区立売堀', '27', '27106', '5500012', '大阪府', 'オオサカフ', '大阪市西区', 'オオサカシニシク', '立売堀', 'イタチボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市西区新町', '27', '27106', '5500013', '大阪府', 'オオサカフ', '大阪市西区', 'オオサカシニシク', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市西区北堀江', '27', '27106', '5500014', '大阪府', 'オオサカフ', '大阪市西区', 'オオサカシニシク', '北堀江', 'キタホリエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市西区南堀江', '27', '27106', '5500015', '大阪府', 'オオサカフ', '大阪市西区', 'オオサカシニシク', '南堀江', 'ミナミホリエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道沙流郡日高町平賀', '01', '01601', '0550002', '北海道', 'ホッカイドウ', '沙流郡日高町', 'サルグンヒダカチョウ', '平賀', 'ビラガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市西区川口', '27', '27106', '5500021', '大阪府', 'オオサカフ', '大阪市西区', 'オオサカシニシク', '川口', 'カワグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市西区本田', '27', '27106', '5500022', '大阪府', 'オオサカフ', '大阪市西区', 'オオサカシニシク', '本田', 'ホンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市西区千代崎', '27', '27106', '5500023', '大阪府', 'オオサカフ', '大阪市西区', 'オオサカシニシク', '千代崎', 'チヨザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市西区境川', '27', '27106', '5500024', '大阪府', 'オオサカフ', '大阪市西区', 'オオサカシニシク', '境川', 'サカイガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市西区九条南', '27', '27106', '5500025', '大阪府', 'オオサカフ', '大阪市西区', 'オオサカシニシク', '九条南', 'クジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市西区安治川', '27', '27106', '5500026', '大阪府', 'オオサカフ', '大阪市西区', 'オオサカシニシク', '安治川', 'アジガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市西区九条', '27', '27106', '5500027', '大阪府', 'オオサカフ', '大阪市西区', 'オオサカシニシク', '九条', 'クジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道沙流郡日高町福満', '01', '01601', '0550003', '北海道', 'ホッカイドウ', '沙流郡日高町', 'サルグンヒダカチョウ', '福満', 'フクミツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道沙流郡日高町富川東', '01', '01601', '0550004', '北海道', 'ホッカイドウ', '沙流郡日高町', 'サルグンヒダカチョウ', '富川東', 'トミカワヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道沙流郡日高町富浜', '01', '01601', '0550005', '北海道', 'ホッカイドウ', '沙流郡日高町', 'サルグンヒダカチョウ', '富浜', 'トミハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道沙流郡日高町富川南', '01', '01601', '0550006', '北海道', 'ホッカイドウ', '沙流郡日高町', 'サルグンヒダカチョウ', '富川南', 'トミカワミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道沙流郡日高町富川西', '01', '01601', '0550007', '北海道', 'ホッカイドウ', '沙流郡日高町', 'サルグンヒダカチョウ', '富川西', 'トミカワニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道沙流郡日高町富川駒丘', '01', '01601', '0550008', '北海道', 'ホッカイドウ', '沙流郡日高町', 'サルグンヒダカチョウ', '富川駒丘', 'トミカワコマオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道沙流郡平取町', '01', '01602', '0550100', '北海道', 'ホッカイドウ', '沙流郡平取町', 'サルグンビラトリチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('60637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道沙流郡平取町二風谷', '01', '01602', '0550101', '北海道', 'ホッカイドウ', '沙流郡平取町', 'サルグンビラトリチョウ', '二風谷', 'ニブタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道沙流郡平取町小平', '01', '01602', '0550102', '北海道', 'ホッカイドウ', '沙流郡平取町', 'サルグンビラトリチョウ', '小平', 'コビラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道沙流郡平取町川向', '01', '01602', '0550103', '北海道', 'ホッカイドウ', '沙流郡平取町', 'サルグンビラトリチョウ', '川向', 'カワムカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道沙流郡平取町紫雲古津', '01', '01602', '0550104', '北海道', 'ホッカイドウ', '沙流郡平取町', 'サルグンビラトリチョウ', '紫雲古津', 'シウンコツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道沙流郡平取町去場', '01', '01602', '0550105', '北海道', 'ホッカイドウ', '沙流郡平取町', 'サルグンビラトリチョウ', '去場', 'サルバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道沙流郡平取町荷菜', '01', '01602', '0550106', '北海道', 'ホッカイドウ', '沙流郡平取町', 'サルグンビラトリチョウ', '荷菜', 'ニナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道沙流郡平取町本町', '01', '01602', '0550107', '北海道', 'ホッカイドウ', '沙流郡平取町', 'サルグンビラトリチョウ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道沙流郡平取町貫気別', '01', '01602', '0550321', '北海道', 'ホッカイドウ', '沙流郡平取町', 'サルグンビラトリチョウ', '貫気別', 'ヌキベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道沙流郡平取町旭', '01', '01602', '0550322', '北海道', 'ホッカイドウ', '沙流郡平取町', 'サルグンビラトリチョウ', '旭', 'アサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道沙流郡平取町芽生', '01', '01602', '0550323', '北海道', 'ホッカイドウ', '沙流郡平取町', 'サルグンビラトリチョウ', '芽生', 'メム', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道沙流郡平取町荷負', '01', '01602', '0550324', '北海道', 'ホッカイドウ', '沙流郡平取町', 'サルグンビラトリチョウ', '荷負', 'ニオイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道沙流郡平取町長知内', '01', '01602', '0550325', '北海道', 'ホッカイドウ', '沙流郡平取町', 'サルグンビラトリチョウ', '長知内', 'オサチナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道沙流郡平取町振内町', '01', '01602', '0550411', '北海道', 'ホッカイドウ', '沙流郡平取町', 'サルグンビラトリチョウ', '振内町', 'フレナイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道沙流郡平取町幌毛志', '01', '01602', '0550412', '北海道', 'ホッカイドウ', '沙流郡平取町', 'サルグンビラトリチョウ', '幌毛志', 'ホロケシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道沙流郡平取町仁世宇', '01', '01602', '0550413', '北海道', 'ホッカイドウ', '沙流郡平取町', 'サルグンビラトリチョウ', '仁世宇', 'ニセウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道沙流郡平取町岩知志', '01', '01602', '0550414', '北海道', 'ホッカイドウ', '沙流郡平取町', 'サルグンビラトリチョウ', '岩知志', 'イワチシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道沙流郡平取町豊糠', '01', '01602', '0550415', '北海道', 'ホッカイドウ', '沙流郡平取町', 'サルグンビラトリチョウ', '豊糠', 'トヨヌカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市大正区', '27', '27108', '5510000', '大阪府', 'オオサカフ', '大阪市大正区', 'オオサカシタイショウク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('60679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市大正区三軒家西', '27', '27108', '5510001', '大阪府', 'オオサカフ', '大阪市大正区', 'オオサカシタイショウク', '三軒家西', 'サンゲンヤニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市大正区三軒家東', '27', '27108', '5510002', '大阪府', 'オオサカフ', '大阪市大正区', 'オオサカシタイショウク', '三軒家東', 'サンゲンヤヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市大正区千島', '27', '27108', '5510003', '大阪府', 'オオサカフ', '大阪市大正区', 'オオサカシタイショウク', '千島', 'チシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市大正区小林東', '27', '27108', '5510011', '大阪府', 'オオサカフ', '大阪市大正区', 'オオサカシタイショウク', '小林東', 'コバヤシヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市大正区平尾', '27', '27108', '5510012', '大阪府', 'オオサカフ', '大阪市大正区', 'オオサカシタイショウク', '平尾', 'ヒラオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市大正区小林西', '27', '27108', '5510013', '大阪府', 'オオサカフ', '大阪市大正区', 'オオサカシタイショウク', '小林西', 'コバヤシニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市大正区南恩加島', '27', '27108', '5510021', '大阪府', 'オオサカフ', '大阪市大正区', 'オオサカシタイショウク', '南恩加島', 'ミナミオカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市大正区船町', '27', '27108', '5510022', '大阪府', 'オオサカフ', '大阪市大正区', 'オオサカシタイショウク', '船町', 'フナマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市大正区鶴町', '27', '27108', '5510023', '大阪府', 'オオサカフ', '大阪市大正区', 'オオサカシタイショウク', '鶴町', 'ツルマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市大正区泉尾', '27', '27108', '5510031', '大阪府', 'オオサカフ', '大阪市大正区', 'オオサカシタイショウク', '泉尾', 'イズオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市大正区北村', '27', '27108', '5510032', '大阪府', 'オオサカフ', '大阪市大正区', 'オオサカシタイショウク', '北村', 'キタムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市大正区北恩加島', '27', '27108', '5510033', '大阪府', 'オオサカフ', '大阪市大正区', 'オオサカシタイショウク', '北恩加島', 'キタオカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市港区', '27', '27107', '5520000', '大阪府', 'オオサカフ', '大阪市港区', 'オオサカシミナトク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('60694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市港区波除', '27', '27107', '5520001', '大阪府', 'オオサカフ', '大阪市港区', 'オオサカシミナトク', '波除', 'ナミヨケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市港区市岡元町', '27', '27107', '5520002', '大阪府', 'オオサカフ', '大阪市港区', 'オオサカシミナトク', '市岡元町', 'イチオカモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市港区磯路', '27', '27107', '5520003', '大阪府', 'オオサカフ', '大阪市港区', 'オオサカシミナトク', '磯路', 'イソジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市港区夕凪', '27', '27107', '5520004', '大阪府', 'オオサカフ', '大阪市港区', 'オオサカシミナトク', '夕凪', 'ユウナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市港区田中', '27', '27107', '5520005', '大阪府', 'オオサカフ', '大阪市港区', 'オオサカシミナトク', '田中', 'タナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市港区石田', '27', '27107', '5520006', '大阪府', 'オオサカフ', '大阪市港区', 'オオサカシミナトク', '石田', 'イシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市港区弁天', '27', '27107', '5520007', '大阪府', 'オオサカフ', '大阪市港区', 'オオサカシミナトク', '弁天', 'ベンテン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市港区南市岡', '27', '27107', '5520011', '大阪府', 'オオサカフ', '大阪市港区', 'オオサカシミナトク', '南市岡', 'ミナミイチオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市港区市岡', '27', '27107', '5520012', '大阪府', 'オオサカフ', '大阪市港区', 'オオサカシミナトク', '市岡', 'イチオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市港区福崎', '27', '27107', '5520013', '大阪府', 'オオサカフ', '大阪市港区', 'オオサカシミナトク', '福崎', 'フクザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市港区八幡屋', '27', '27107', '5520014', '大阪府', 'オオサカフ', '大阪市港区', 'オオサカシミナトク', '八幡屋', 'ヤハタヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市港区池島', '27', '27107', '5520015', '大阪府', 'オオサカフ', '大阪市港区', 'オオサカシミナトク', '池島', 'イケジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市港区三先', '27', '27107', '5520016', '大阪府', 'オオサカフ', '大阪市港区', 'オオサカシミナトク', '三先', 'ミサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市港区築港', '27', '27107', '5520021', '大阪府', 'オオサカフ', '大阪市港区', 'オオサカシミナトク', '築港', 'チッコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市港区海岸通', '27', '27107', '5520022', '大阪府', 'オオサカフ', '大阪市港区', 'オオサカシミナトク', '海岸通', 'カイガンドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市港区港晴', '27', '27107', '5520023', '大阪府', 'オオサカフ', '大阪市港区', 'オオサカシミナトク', '港晴', 'コウセイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道沙流郡日高町本町東', '01', '01601', '0552301', '北海道', 'ホッカイドウ', '沙流郡日高町', 'サルグンヒダカチョウ', '本町東', 'ホンチョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道沙流郡日高町本町西', '01', '01601', '0552302', '北海道', 'ホッカイドウ', '沙流郡日高町', 'サルグンヒダカチョウ', '本町西', 'ホンチョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道沙流郡日高町栄町東', '01', '01601', '0552303', '北海道', 'ホッカイドウ', '沙流郡日高町', 'サルグンヒダカチョウ', '栄町東', 'サカエマチヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道沙流郡日高町栄町西', '01', '01601', '0552304', '北海道', 'ホッカイドウ', '沙流郡日高町', 'サルグンヒダカチョウ', '栄町西', 'サカエマチニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道沙流郡日高町新町', '01', '01601', '0552305', '北海道', 'ホッカイドウ', '沙流郡日高町', 'サルグンヒダカチョウ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道沙流郡日高町宮下町', '01', '01601', '0552306', '北海道', 'ホッカイドウ', '沙流郡日高町', 'サルグンヒダカチョウ', '宮下町', 'ミヤシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道沙流郡日高町松風町', '01', '01601', '0552307', '北海道', 'ホッカイドウ', '沙流郡日高町', 'サルグンヒダカチョウ', '松風町', 'マツカゼチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道沙流郡日高町山手町', '01', '01601', '0552308', '北海道', 'ホッカイドウ', '沙流郡日高町', 'サルグンヒダカチョウ', '山手町', 'ヤマテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道沙流郡日高町若葉町', '01', '01601', '0552309', '北海道', 'ホッカイドウ', '沙流郡日高町', 'サルグンヒダカチョウ', '若葉町', 'ワカバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道沙流郡日高町日高1区', '01', '01601', '0552311', '北海道', 'ホッカイドウ', '沙流郡日高町', 'サルグンヒダカチョウ', '日高', 'ヒダカ', null, null, '1区', '01ク');
INSERT INTO `ms_addresses` VALUES ('60720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道沙流郡日高町日高2区', '01', '01601', '0552312', '北海道', 'ホッカイドウ', '沙流郡日高町', 'サルグンヒダカチョウ', '日高', 'ヒダカ', null, null, '2区', '02ク');
INSERT INTO `ms_addresses` VALUES ('60721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道沙流郡日高町日高3区', '01', '01601', '0552313', '北海道', 'ホッカイドウ', '沙流郡日高町', 'サルグンヒダカチョウ', '日高', 'ヒダカ', null, null, '3区', '03ク');
INSERT INTO `ms_addresses` VALUES ('60722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道沙流郡日高町千栄', '01', '01601', '0552314', '北海道', 'ホッカイドウ', '沙流郡日高町', 'サルグンヒダカチョウ', '千栄', 'チサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道沙流郡日高町富岡', '01', '01601', '0552315', '北海道', 'ホッカイドウ', '沙流郡日高町', 'サルグンヒダカチョウ', '富岡', 'トミオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道沙流郡日高町三岩', '01', '01601', '0552316', '北海道', 'ホッカイドウ', '沙流郡日高町', 'サルグンヒダカチョウ', '三岩', 'ミツイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市福島区', '27', '27103', '5530000', '大阪府', 'オオサカフ', '大阪市福島区', 'オオサカシフクシマク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('60728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市福島区海老江', '27', '27103', '5530001', '大阪府', 'オオサカフ', '大阪市福島区', 'オオサカシフクシマク', '海老江', 'エビエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市福島区鷺洲', '27', '27103', '5530002', '大阪府', 'オオサカフ', '大阪市福島区', 'オオサカシフクシマク', '鷺洲', 'サギス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市福島区福島', '27', '27103', '5530003', '大阪府', 'オオサカフ', '大阪市福島区', 'オオサカシフクシマク', '福島', 'フクシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市福島区玉川', '27', '27103', '5530004', '大阪府', 'オオサカフ', '大阪市福島区', 'オオサカシフクシマク', '玉川', 'タマガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市福島区野田', '27', '27103', '5530005', '大阪府', 'オオサカフ', '大阪市福島区', 'オオサカシフクシマク', '野田', 'ノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市福島区吉野', '27', '27103', '5530006', '大阪府', 'オオサカフ', '大阪市福島区', 'オオサカシフクシマク', '吉野', 'ヨシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市福島区大開', '27', '27103', '5530007', '大阪府', 'オオサカフ', '大阪市福島区', 'オオサカシフクシマク', '大開', 'オオヒラキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市此花区', '27', '27104', '5540000', '大阪府', 'オオサカフ', '大阪市此花区', 'オオサカシコノハナク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('60743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市此花区高見', '27', '27104', '5540001', '大阪府', 'オオサカフ', '大阪市此花区', 'オオサカシコノハナク', '高見', 'タカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市此花区伝法', '27', '27104', '5540002', '大阪府', 'オオサカフ', '大阪市此花区', 'オオサカシコノハナク', '伝法', 'デンポウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市此花区朝日', '27', '27104', '5540011', '大阪府', 'オオサカフ', '大阪市此花区', 'オオサカシコノハナク', '朝日', 'アサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市此花区西九条', '27', '27104', '5540012', '大阪府', 'オオサカフ', '大阪市此花区', 'オオサカシコノハナク', '西九条', 'ニシクジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市此花区梅香', '27', '27104', '5540013', '大阪府', 'オオサカフ', '大阪市此花区', 'オオサカシコノハナク', '梅香', 'バイカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市此花区四貫島', '27', '27104', '5540014', '大阪府', 'オオサカフ', '大阪市此花区', 'オオサカシコノハナク', '四貫島', 'シカンジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市此花区春日出北', '27', '27104', '5540021', '大阪府', 'オオサカフ', '大阪市此花区', 'オオサカシコノハナク', '春日出北', 'カスガデキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市此花区春日出中', '27', '27104', '5540022', '大阪府', 'オオサカフ', '大阪市此花区', 'オオサカシコノハナク', '春日出中', 'カスガデナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市此花区春日出南', '27', '27104', '5540023', '大阪府', 'オオサカフ', '大阪市此花区', 'オオサカシコノハナク', '春日出南', 'カスガデミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市此花区島屋', '27', '27104', '5540024', '大阪府', 'オオサカフ', '大阪市此花区', 'オオサカシコノハナク', '島屋', 'シマヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市此花区桜島', '27', '27104', '5540031', '大阪府', 'オオサカフ', '大阪市此花区', 'オオサカシコノハナク', '桜島', 'サクラジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市此花区梅町', '27', '27104', '5540032', '大阪府', 'オオサカフ', '大阪市此花区', 'オオサカシコノハナク', '梅町', 'ウメマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市此花区北港', '27', '27104', '5540033', '大阪府', 'オオサカフ', '大阪市此花区', 'オオサカシコノハナク', '北港', 'ホクコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市此花区北港白津', '27', '27104', '5540041', '大阪府', 'オオサカフ', '大阪市此花区', 'オオサカシコノハナク', '北港白津', 'ホクコウシラツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市此花区北港緑地', '27', '27104', '5540042', '大阪府', 'オオサカフ', '大阪市此花区', 'オオサカシコノハナク', '北港緑地', 'ホクコウリョクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市此花区夢洲東', '27', '27104', '5540043', '大阪府', 'オオサカフ', '大阪市此花区', 'オオサカシコノハナク', '夢洲東', 'ユメシマヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市此花区酉島', '27', '27104', '5540051', '大阪府', 'オオサカフ', '大阪市此花区', 'オオサカシコノハナク', '酉島', 'トリシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市此花区常吉', '27', '27104', '5540052', '大阪府', 'オオサカフ', '大阪市此花区', 'オオサカシコノハナク', '常吉', 'ツネヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市西淀川区', '27', '27113', '5550000', '大阪府', 'オオサカフ', '大阪市西淀川区', 'オオサカシニシヨドガワク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('60768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市西淀川区佃', '27', '27113', '5550001', '大阪府', 'オオサカフ', '大阪市西淀川区', 'オオサカシニシヨドガワク', '佃', 'ツクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市西淀川区竹島', '27', '27113', '5550011', '大阪府', 'オオサカフ', '大阪市西淀川区', 'オオサカシニシヨドガワク', '竹島', 'タケシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市西淀川区御幣島', '27', '27113', '5550012', '大阪府', 'オオサカフ', '大阪市西淀川区', 'オオサカシニシヨドガワク', '御幣島', 'ミテジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市西淀川区千舟', '27', '27113', '5550013', '大阪府', 'オオサカフ', '大阪市西淀川区', 'オオサカシニシヨドガワク', '千舟', 'チフネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市西淀川区歌島', '27', '27113', '5550021', '大阪府', 'オオサカフ', '大阪市西淀川区', 'オオサカシニシヨドガワク', '歌島', 'ウタジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市西淀川区柏里', '27', '27113', '5550022', '大阪府', 'オオサカフ', '大阪市西淀川区', 'オオサカシニシヨドガワク', '柏里', 'カシワザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市西淀川区花川', '27', '27113', '5550023', '大阪府', 'オオサカフ', '大阪市西淀川区', 'オオサカシニシヨドガワク', '花川', 'ハナカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市西淀川区野里', '27', '27113', '5550024', '大阪府', 'オオサカフ', '大阪市西淀川区', 'オオサカシニシヨドガワク', '野里', 'ノザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市西淀川区姫里', '27', '27113', '5550025', '大阪府', 'オオサカフ', '大阪市西淀川区', 'オオサカシニシヨドガワク', '姫里', 'ヒメサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市西淀川区出来島', '27', '27113', '5550031', '大阪府', 'オオサカフ', '大阪市西淀川区', 'オオサカシニシヨドガワク', '出来島', 'デキシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市西淀川区大和田', '27', '27113', '5550032', '大阪府', 'オオサカフ', '大阪市西淀川区', 'オオサカシニシヨドガワク', '大和田', 'オオワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市西淀川区姫島', '27', '27113', '5550033', '大阪府', 'オオサカフ', '大阪市西淀川区', 'オオサカシニシヨドガワク', '姫島', 'ヒメシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市西淀川区福町', '27', '27113', '5550034', '大阪府', 'オオサカフ', '大阪市西淀川区', 'オオサカシニシヨドガワク', '福町', 'フクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市西淀川区中島', '27', '27113', '5550041', '大阪府', 'オオサカフ', '大阪市西淀川区', 'オオサカシニシヨドガワク', '中島', 'ナカシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市西淀川区西島', '27', '27113', '5550042', '大阪府', 'オオサカフ', '大阪市西淀川区', 'オオサカシニシヨドガワク', '西島', 'ニシシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市西淀川区大野', '27', '27113', '5550043', '大阪府', 'オオサカフ', '大阪市西淀川区', 'オオサカシニシヨドガワク', '大野', 'オオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市西淀川区百島', '27', '27113', '5550044', '大阪府', 'オオサカフ', '大阪市西淀川区', 'オオサカシニシヨドガワク', '百島', 'ヒャクシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市浪速区', '27', '27111', '5560000', '大阪府', 'オオサカフ', '大阪市浪速区', 'オオサカシナニワク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('60789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市浪速区下寺', '27', '27111', '5560001', '大阪府', 'オオサカフ', '大阪市浪速区', 'オオサカシナニワク', '下寺', 'シモデラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市浪速区恵美須東', '27', '27111', '5560002', '大阪府', 'オオサカフ', '大阪市浪速区', 'オオサカシナニワク', '恵美須東', 'エビスヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市浪速区恵美須西', '27', '27111', '5560003', '大阪府', 'オオサカフ', '大阪市浪速区', 'オオサカシナニワク', '恵美須西', 'エビスニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市浪速区日本橋西', '27', '27111', '5560004', '大阪府', 'オオサカフ', '大阪市浪速区', 'オオサカシナニワク', '日本橋西', 'ニッポンバシニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市浪速区日本橋', '27', '27111', '5560005', '大阪府', 'オオサカフ', '大阪市浪速区', 'オオサカシナニワク', '日本橋', 'ニッポンバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市浪速区日本橋東', '27', '27111', '5560006', '大阪府', 'オオサカフ', '大阪市浪速区', 'オオサカシナニワク', '日本橋東', 'ニッポンバシヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市浪速区難波中', '27', '27111', '5560011', '大阪府', 'オオサカフ', '大阪市浪速区', 'オオサカシナニワク', '難波中', 'ナンバナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市浪速区敷津東', '27', '27111', '5560012', '大阪府', 'オオサカフ', '大阪市浪速区', 'オオサカシナニワク', '敷津東', 'シキツヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市浪速区戎本町', '27', '27111', '5560013', '大阪府', 'オオサカフ', '大阪市浪速区', 'オオサカシナニワク', '戎本町', 'エビスホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市浪速区大国', '27', '27111', '5560014', '大阪府', 'オオサカフ', '大阪市浪速区', 'オオサカシナニワク', '大国', 'ダイコク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市浪速区敷津西', '27', '27111', '5560015', '大阪府', 'オオサカフ', '大阪市浪速区', 'オオサカシナニワク', '敷津西', 'シキツニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市浪速区元町', '27', '27111', '5560016', '大阪府', 'オオサカフ', '大阪市浪速区', 'オオサカシナニワク', '元町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市浪速区湊町', '27', '27111', '5560017', '大阪府', 'オオサカフ', '大阪市浪速区', 'オオサカシナニワク', '湊町', 'ミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市浪速区立葉', '27', '27111', '5560020', '大阪府', 'オオサカフ', '大阪市浪速区', 'オオサカシナニワク', '立葉', 'タテバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市浪速区幸町', '27', '27111', '5560021', '大阪府', 'オオサカフ', '大阪市浪速区', 'オオサカシナニワク', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市浪速区桜川', '27', '27111', '5560022', '大阪府', 'オオサカフ', '大阪市浪速区', 'オオサカシナニワク', '桜川', 'サクラガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市浪速区稲荷', '27', '27111', '5560023', '大阪府', 'オオサカフ', '大阪市浪速区', 'オオサカシナニワク', '稲荷', 'イナリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市浪速区塩草', '27', '27111', '5560024', '大阪府', 'オオサカフ', '大阪市浪速区', 'オオサカシナニワク', '塩草', 'シオクサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市浪速区浪速東', '27', '27111', '5560025', '大阪府', 'オオサカフ', '大阪市浪速区', 'オオサカシナニワク', '浪速東', 'ナニワヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市浪速区浪速西', '27', '27111', '5560026', '大阪府', 'オオサカフ', '大阪市浪速区', 'オオサカシナニワク', '浪速西', 'ナニワニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市浪速区木津川', '27', '27111', '5560027', '大阪府', 'オオサカフ', '大阪市浪速区', 'オオサカシナニワク', '木津川', 'キヅガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市浪速区久保吉', '27', '27111', '5560028', '大阪府', 'オオサカフ', '大阪市浪速区', 'オオサカシナニワク', '久保吉', 'クボヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市浪速区芦原', '27', '27111', '5560029', '大阪府', 'オオサカフ', '大阪市浪速区', 'オオサカシナニワク', '芦原', 'アシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市西成区', '27', '27122', '5570000', '大阪府', 'オオサカフ', '大阪市西成区', 'オオサカシニシナリク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('60826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市西成区山王', '27', '27122', '5570001', '大阪府', 'オオサカフ', '大阪市西成区', 'オオサカシニシナリク', '山王', 'サンノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市西成区太子', '27', '27122', '5570002', '大阪府', 'オオサカフ', '大阪市西成区', 'オオサカシニシナリク', '太子', 'タイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市西成区天下茶屋北', '27', '27122', '5570003', '大阪府', 'オオサカフ', '大阪市西成区', 'オオサカシニシナリク', '天下茶屋北', 'テンガチャヤキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市西成区萩之茶屋', '27', '27122', '5570004', '大阪府', 'オオサカフ', '大阪市西成区', 'オオサカシニシナリク', '萩之茶屋', 'ハギノチャヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市西成区天下茶屋東', '27', '27122', '5570011', '大阪府', 'オオサカフ', '大阪市西成区', 'オオサカシニシナリク', '天下茶屋東', 'テンガチャヤヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市西成区聖天下', '27', '27122', '5570012', '大阪府', 'オオサカフ', '大阪市西成区', 'オオサカシニシナリク', '聖天下', 'ショウテンシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市西成区天神ノ森', '27', '27122', '5570013', '大阪府', 'オオサカフ', '大阪市西成区', 'オオサカシニシナリク', '天神ノ森', 'テンジンノモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市西成区天下茶屋', '27', '27122', '5570014', '大阪府', 'オオサカフ', '大阪市西成区', 'オオサカシニシナリク', '天下茶屋', 'テンガチャヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市西成区花園南', '27', '27122', '5570015', '大阪府', 'オオサカフ', '大阪市西成区', 'オオサカシニシナリク', '花園南', 'ハナゾノミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市西成区花園北', '27', '27122', '5570016', '大阪府', 'オオサカフ', '大阪市西成区', 'オオサカシニシナリク', '花園北', 'ハナゾノキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市西成区北開', '27', '27122', '5570021', '大阪府', 'オオサカフ', '大阪市西成区', 'オオサカシニシナリク', '北開', 'キタビラキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市西成区中開', '27', '27122', '5570022', '大阪府', 'オオサカフ', '大阪市西成区', 'オオサカシニシナリク', '中開', 'ナカビラキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市西成区南開', '27', '27122', '5570023', '大阪府', 'オオサカフ', '大阪市西成区', 'オオサカシニシナリク', '南開', 'ミナミビラキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市西成区出城', '27', '27122', '5570024', '大阪府', 'オオサカフ', '大阪市西成区', 'オオサカシニシナリク', '出城', 'デシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市西成区長橋', '27', '27122', '5570025', '大阪府', 'オオサカフ', '大阪市西成区', 'オオサカシニシナリク', '長橋', 'ナガハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市西成区鶴見橋', '27', '27122', '5570031', '大阪府', 'オオサカフ', '大阪市西成区', 'オオサカシニシナリク', '鶴見橋', 'ツルミバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市西成区旭', '27', '27122', '5570032', '大阪府', 'オオサカフ', '大阪市西成区', 'オオサカシニシナリク', '旭', 'アサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市西成区梅南', '27', '27122', '5570033', '大阪府', 'オオサカフ', '大阪市西成区', 'オオサカシニシナリク', '梅南', 'バイナン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市西成区松', '27', '27122', '5570034', '大阪府', 'オオサカフ', '大阪市西成区', 'オオサカシニシナリク', '松', 'マツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市西成区岸里', '27', '27122', '5570041', '大阪府', 'オオサカフ', '大阪市西成区', 'オオサカシニシナリク', '岸里', 'キシノサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市西成区岸里東', '27', '27122', '5570042', '大阪府', 'オオサカフ', '大阪市西成区', 'オオサカシニシナリク', '岸里東', 'キシノサトヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市西成区玉出東', '27', '27122', '5570043', '大阪府', 'オオサカフ', '大阪市西成区', 'オオサカシニシナリク', '玉出東', 'タマデヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市西成区玉出中', '27', '27122', '5570044', '大阪府', 'オオサカフ', '大阪市西成区', 'オオサカシニシナリク', '玉出中', 'タマデナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市西成区玉出西', '27', '27122', '5570045', '大阪府', 'オオサカフ', '大阪市西成区', 'オオサカシニシナリク', '玉出西', 'タマデニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市西成区橘', '27', '27122', '5570051', '大阪府', 'オオサカフ', '大阪市西成区', 'オオサカシニシナリク', '橘', 'タチバナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市西成区潮路', '27', '27122', '5570052', '大阪府', 'オオサカフ', '大阪市西成区', 'オオサカシニシナリク', '潮路', 'シオジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市西成区千本北', '27', '27122', '5570053', '大阪府', 'オオサカフ', '大阪市西成区', 'オオサカシニシナリク', '千本北', 'センボンキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市西成区千本中', '27', '27122', '5570054', '大阪府', 'オオサカフ', '大阪市西成区', 'オオサカシニシナリク', '千本中', 'センボンナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市西成区千本南', '27', '27122', '5570055', '大阪府', 'オオサカフ', '大阪市西成区', 'オオサカシニシナリク', '千本南', 'センボンミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市西成区北津守', '27', '27122', '5570061', '大阪府', 'オオサカフ', '大阪市西成区', 'オオサカシニシナリク', '北津守', 'キタツモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市西成区津守', '27', '27122', '5570062', '大阪府', 'オオサカフ', '大阪市西成区', 'オオサカシニシナリク', '津守', 'ツモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市西成区南津守', '27', '27122', '5570063', '大阪府', 'オオサカフ', '大阪市西成区', 'オオサカシニシナリク', '南津守', 'ミナミツモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市住吉区', '27', '27120', '5580000', '大阪府', 'オオサカフ', '大阪市住吉区', 'オオサカシスミヨシク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('60860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市住吉区大領', '27', '27120', '5580001', '大阪府', 'オオサカフ', '大阪市住吉区', 'オオサカシスミヨシク', '大領', 'ダイリョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市住吉区長居西', '27', '27120', '5580002', '大阪府', 'オオサカフ', '大阪市住吉区', 'オオサカシスミヨシク', '長居西', 'ナガイニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市住吉区長居', '27', '27120', '5580003', '大阪府', 'オオサカフ', '大阪市住吉区', 'オオサカシスミヨシク', '長居', 'ナガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市住吉区長居東', '27', '27120', '5580004', '大阪府', 'オオサカフ', '大阪市住吉区', 'オオサカシスミヨシク', '長居東', 'ナガイヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市住吉区苅田', '27', '27120', '5580011', '大阪府', 'オオサカフ', '大阪市住吉区', 'オオサカシスミヨシク', '苅田', 'カリタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市住吉区庭井', '27', '27120', '5580012', '大阪府', 'オオサカフ', '大阪市住吉区', 'オオサカシスミヨシク', '庭井', 'ニワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市住吉区我孫子東', '27', '27120', '5580013', '大阪府', 'オオサカフ', '大阪市住吉区', 'オオサカシスミヨシク', '我孫子東', 'アビコヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市住吉区我孫子', '27', '27120', '5580014', '大阪府', 'オオサカフ', '大阪市住吉区', 'オオサカシスミヨシク', '我孫子', 'アビコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市住吉区我孫子西', '27', '27120', '5580015', '大阪府', 'オオサカフ', '大阪市住吉区', 'オオサカシスミヨシク', '我孫子西', 'アビコニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市住吉区浅香', '27', '27120', '5580021', '大阪府', 'オオサカフ', '大阪市住吉区', 'オオサカシスミヨシク', '浅香', 'アサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市住吉区杉本', '27', '27120', '5580022', '大阪府', 'オオサカフ', '大阪市住吉区', 'オオサカシスミヨシク', '杉本', 'スギモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市住吉区山之内', '27', '27120', '5580023', '大阪府', 'オオサカフ', '大阪市住吉区', 'オオサカシスミヨシク', '山之内', 'ヤマノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市住吉区山之内元町', '27', '27120', '5580024', '大阪府', 'オオサカフ', '大阪市住吉区', 'オオサカシスミヨシク', '山之内元町', 'ヤマノウチモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市住吉区沢之町', '27', '27120', '5580031', '大阪府', 'オオサカフ', '大阪市住吉区', 'オオサカシスミヨシク', '沢之町', 'サワノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市住吉区遠里小野', '27', '27120', '5580032', '大阪府', 'オオサカフ', '大阪市住吉区', 'オオサカシスミヨシク', '遠里小野', 'オリオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市住吉区清水丘', '27', '27120', '5580033', '大阪府', 'オオサカフ', '大阪市住吉区', 'オオサカシスミヨシク', '清水丘', 'シミズガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市住吉区南住吉', '27', '27120', '5580041', '大阪府', 'オオサカフ', '大阪市住吉区', 'オオサカシスミヨシク', '南住吉', 'ミナミスミヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市住吉区殿辻', '27', '27120', '5580042', '大阪府', 'オオサカフ', '大阪市住吉区', 'オオサカシスミヨシク', '殿辻', 'トノツジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市住吉区墨江', '27', '27120', '5580043', '大阪府', 'オオサカフ', '大阪市住吉区', 'オオサカシスミヨシク', '墨江', 'スミエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市住吉区長峡町', '27', '27120', '5580044', '大阪府', 'オオサカフ', '大阪市住吉区', 'オオサカシスミヨシク', '長峡町', 'ナガオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市住吉区住吉', '27', '27120', '5580045', '大阪府', 'オオサカフ', '大阪市住吉区', 'オオサカシスミヨシク', '住吉', 'スミヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市住吉区上住吉', '27', '27120', '5580046', '大阪府', 'オオサカフ', '大阪市住吉区', 'オオサカシスミヨシク', '上住吉', 'ウエスミヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市住吉区千躰', '27', '27120', '5580047', '大阪府', 'オオサカフ', '大阪市住吉区', 'オオサカシスミヨシク', '千躰', 'センタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市住吉区東粉浜', '27', '27120', '5580051', '大阪府', 'オオサカフ', '大阪市住吉区', 'オオサカシスミヨシク', '東粉浜', 'ヒガシコハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市住吉区帝塚山西', '27', '27120', '5580052', '大阪府', 'オオサカフ', '大阪市住吉区', 'オオサカシスミヨシク', '帝塚山西', 'テヅカヤマニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市住吉区帝塚山中', '27', '27120', '5580053', '大阪府', 'オオサカフ', '大阪市住吉区', 'オオサカシスミヨシク', '帝塚山中', 'テヅカヤマナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市住吉区帝塚山東', '27', '27120', '5580054', '大阪府', 'オオサカフ', '大阪市住吉区', 'オオサカシスミヨシク', '帝塚山東', 'テヅカヤマヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市住吉区万代', '27', '27120', '5580055', '大阪府', 'オオサカフ', '大阪市住吉区', 'オオサカシスミヨシク', '万代', 'バンダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市住吉区万代東', '27', '27120', '5580056', '大阪府', 'オオサカフ', '大阪市住吉区', 'オオサカシスミヨシク', '万代東', 'バンダイヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市住之江区', '27', '27125', '5590000', '大阪府', 'オオサカフ', '大阪市住之江区', 'オオサカシスミノエク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('60894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市住之江区粉浜', '27', '27125', '5590001', '大阪府', 'オオサカフ', '大阪市住之江区', 'オオサカシスミノエク', '粉浜', 'コハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市住之江区浜口東', '27', '27125', '5590002', '大阪府', 'オオサカフ', '大阪市住之江区', 'オオサカシスミノエク', '浜口東', 'ハマグチヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市住之江区安立', '27', '27125', '5590003', '大阪府', 'オオサカフ', '大阪市住之江区', 'オオサカシスミノエク', '安立', 'アンリュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市住之江区住之江', '27', '27125', '5590004', '大阪府', 'オオサカフ', '大阪市住之江区', 'オオサカシスミノエク', '住之江', 'スミノエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市住之江区西住之江', '27', '27125', '5590005', '大阪府', 'オオサカフ', '大阪市住之江区', 'オオサカシスミノエク', '西住之江', 'ニシスミノエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市住之江区浜口西', '27', '27125', '5590006', '大阪府', 'オオサカフ', '大阪市住之江区', 'オオサカシスミノエク', '浜口西', 'ハマグチニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市住之江区粉浜西', '27', '27125', '5590007', '大阪府', 'オオサカフ', '大阪市住之江区', 'オオサカシスミノエク', '粉浜西', 'コハマニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市住之江区北加賀屋', '27', '27125', '5590011', '大阪府', 'オオサカフ', '大阪市住之江区', 'オオサカシスミノエク', '北加賀屋', 'キタカガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市住之江区東加賀屋', '27', '27125', '5590012', '大阪府', 'オオサカフ', '大阪市住之江区', 'オオサカシスミノエク', '東加賀屋', 'ヒガシカガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市住之江区御崎', '27', '27125', '5590013', '大阪府', 'オオサカフ', '大阪市住之江区', 'オオサカシスミノエク', '御崎', 'ミサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市住之江区北島', '27', '27125', '5590014', '大阪府', 'オオサカフ', '大阪市住之江区', 'オオサカシスミノエク', '北島', 'キタジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市住之江区南加賀屋', '27', '27125', '5590015', '大阪府', 'オオサカフ', '大阪市住之江区', 'オオサカシスミノエク', '南加賀屋', 'ミナミカガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市住之江区西加賀屋', '27', '27125', '5590016', '大阪府', 'オオサカフ', '大阪市住之江区', 'オオサカシスミノエク', '西加賀屋', 'ニシカガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市住之江区中加賀屋', '27', '27125', '5590017', '大阪府', 'オオサカフ', '大阪市住之江区', 'オオサカシスミノエク', '中加賀屋', 'ナカカガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市住之江区柴谷', '27', '27125', '5590021', '大阪府', 'オオサカフ', '大阪市住之江区', 'オオサカシスミノエク', '柴谷', 'シバタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市住之江区緑木', '27', '27125', '5590022', '大阪府', 'オオサカフ', '大阪市住之江区', 'オオサカシスミノエク', '緑木', 'ミドリギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市住之江区泉', '27', '27125', '5590023', '大阪府', 'オオサカフ', '大阪市住之江区', 'オオサカシスミノエク', '泉', 'イズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市住之江区新北島', '27', '27125', '5590024', '大阪府', 'オオサカフ', '大阪市住之江区', 'オオサカシスミノエク', '新北島', 'シンキタジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市住之江区平林南', '27', '27125', '5590025', '大阪府', 'オオサカフ', '大阪市住之江区', 'オオサカシスミノエク', '平林南', 'ヒラバヤシミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市住之江区平林北', '27', '27125', '5590026', '大阪府', 'オオサカフ', '大阪市住之江区', 'オオサカシスミノエク', '平林北', 'ヒラバヤシキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市住之江区南港東', '27', '27125', '5590031', '大阪府', 'オオサカフ', '大阪市住之江区', 'オオサカシスミノエク', '南港東', 'ナンコウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市住之江区南港南', '27', '27125', '5590032', '大阪府', 'オオサカフ', '大阪市住之江区', 'オオサカシスミノエク', '南港南', 'ナンコウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市住之江区南港中', '27', '27125', '5590033', '大阪府', 'オオサカフ', '大阪市住之江区', 'オオサカシスミノエク', '南港中', 'ナンコウナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪市住之江区南港北', '27', '27125', '5590034', '大阪府', 'オオサカフ', '大阪市住之江区', 'オオサカシスミノエク', '南港北', 'ナンコウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道日高郡新ひだか町', '01', '01610', '0560000', '北海道', 'ホッカイドウ', '日高郡新ひだか町', 'ヒダカグンシンヒダカチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('60936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市', '27', '27203', '5600000', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('60937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市北緑丘', '27', '27203', '5600001', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', '北緑丘', 'キタミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市緑丘', '27', '27203', '5600002', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', '緑丘', 'ミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市東豊中町', '27', '27203', '5600003', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', '東豊中町', 'ヒガシトヨナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市少路', '27', '27203', '5600004', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', '少路', 'ショウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市西緑丘', '27', '27203', '5600005', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', '西緑丘', 'ニシミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道日高郡新ひだか町静内目名', '01', '01610', '0560001', '北海道', 'ホッカイドウ', '日高郡新ひだか町', 'ヒダカグンシンヒダカチョウ', '静内目名', 'シズナイメナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市上野西', '27', '27203', '5600011', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', '上野西', 'ウエノニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市上野坂', '27', '27203', '5600012', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', '上野坂', 'ウエノサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市上野東', '27', '27203', '5600013', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', '上野東', 'ウエノヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市熊野町', '27', '27203', '5600014', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', '熊野町', 'クマノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市赤阪', '27', '27203', '5600015', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', '赤阪', 'アカサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市栗ケ丘町', '27', '27203', '5600016', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', '栗ケ丘町', 'クリガオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道日高郡新ひだか町静内神森', '01', '01610', '0560002', '北海道', 'ホッカイドウ', '日高郡新ひだか町', 'ヒダカグンシンヒダカチョウ', '静内神森', 'シズナイカミモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市本町', '27', '27203', '5600021', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市北桜塚', '27', '27203', '5600022', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', '北桜塚', 'キタサクラヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市岡上の町', '27', '27203', '5600023', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', '岡上の町', 'オカカミノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市末広町', '27', '27203', '5600024', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', '末広町', 'スエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市立花町', '27', '27203', '5600025', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', '立花町', 'タチバナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市玉井町', '27', '27203', '5600026', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', '玉井町', 'タマイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道日高郡新ひだか町静内旭町', '01', '01610', '0560003', '北海道', 'ホッカイドウ', '日高郡新ひだか町', 'ヒダカグンシンヒダカチョウ', '静内旭町', 'シズナイアサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市蛍池北町', '27', '27203', '5600031', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', '蛍池北町', 'ホタルガイケキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市蛍池東町', '27', '27203', '5600032', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', '蛍池東町', 'ホタルガイケヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市蛍池中町', '27', '27203', '5600033', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', '蛍池中町', 'ホタルガイケナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市蛍池南町', '27', '27203', '5600034', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', '蛍池南町', 'ホタルガイケミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市箕輪', '27', '27203', '5600035', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', '箕輪', 'ミノワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市蛍池西町', '27', '27203', '5600036', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', '蛍池西町', 'ホタルガイケニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道日高郡新ひだか町静内緑町', '01', '01610', '0560004', '北海道', 'ホッカイドウ', '日高郡新ひだか町', 'ヒダカグンシンヒダカチョウ', '静内緑町', 'シズナイミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市清風荘', '27', '27203', '5600041', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', '清風荘', 'セイフウソウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市石橋麻田町', '27', '27203', '5600042', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', '石橋麻田町', 'イシバシアサダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市待兼山町', '27', '27203', '5600043', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', '待兼山町', 'マチカネヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市刀根山元町', '27', '27203', '5600044', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', '刀根山元町', 'トネヤマモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市刀根山', '27', '27203', '5600045', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', '刀根山', 'トネヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市千里園', '27', '27203', '5600046', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', '千里園', 'センリエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道日高郡新ひだか町静内こうせい町', '01', '01610', '0560005', '北海道', 'ホッカイドウ', '日高郡新ひだか町', 'ヒダカグンシンヒダカチョウ', '静内こうせい町', 'シズナイコウセイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市永楽荘', '27', '27203', '5600051', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', '永楽荘', 'エイラクソウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市春日町', '27', '27203', '5600052', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', '春日町', 'カスガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市向丘', '27', '27203', '5600053', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', '向丘', 'ムカイガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市桜の町', '27', '27203', '5600054', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', '桜の町', 'サクラノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市柴原町', '27', '27203', '5600055', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', '柴原町', 'シバハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市宮山町', '27', '27203', '5600056', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', '宮山町', 'ミヤヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道日高郡新ひだか町静内中野町', '01', '01610', '0560006', '北海道', 'ホッカイドウ', '日高郡新ひだか町', 'ヒダカグンシンヒダカチョウ', '静内中野町', 'シズナイナカノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道日高郡新ひだか町静内清水丘', '01', '01610', '0560007', '北海道', 'ホッカイドウ', '日高郡新ひだか町', 'ヒダカグンシンヒダカチョウ', '静内清水丘', 'シズナイシミズオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市新千里北町', '27', '27203', '5600081', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', '新千里北町', 'シンセンリキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市新千里東町', '27', '27203', '5600082', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', '新千里東町', 'シンセンリヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市新千里西町', '27', '27203', '5600083', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', '新千里西町', 'シンセンリニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市新千里南町', '27', '27203', '5600084', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', '新千里南町', 'シンセンリミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市上新田', '27', '27203', '5600085', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', '上新田', 'カミシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道日高郡新ひだか町静内真歌', '01', '01610', '0560011', '北海道', 'ホッカイドウ', '日高郡新ひだか町', 'ヒダカグンシンヒダカチョウ', '静内真歌', 'シズナイマウタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道日高郡新ひだか町静内入船町', '01', '01610', '0560013', '北海道', 'ホッカイドウ', '日高郡新ひだか町', 'ヒダカグンシンヒダカチョウ', '静内入船町', 'シズナイイリフネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道日高郡新ひだか町静内古川町', '01', '01610', '0560014', '北海道', 'ホッカイドウ', '日高郡新ひだか町', 'ヒダカグンシンヒダカチョウ', '静内古川町', 'シズナイフルカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道日高郡新ひだか町静内海岸町', '01', '01610', '0560015', '北海道', 'ホッカイドウ', '日高郡新ひだか町', 'ヒダカグンシンヒダカチョウ', '静内海岸町', 'シズナイカイガンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道日高郡新ひだか町静内本町', '01', '01610', '0560016', '北海道', 'ホッカイドウ', '日高郡新ひだか町', 'ヒダカグンシンヒダカチョウ', '静内本町', 'シズナイホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道日高郡新ひだか町静内御幸町', '01', '01610', '0560017', '北海道', 'ホッカイドウ', '日高郡新ひだか町', 'ヒダカグンシンヒダカチョウ', '静内御幸町', 'シズナイミユキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道日高郡新ひだか町静内吉野町', '01', '01610', '0560018', '北海道', 'ホッカイドウ', '日高郡新ひだか町', 'ヒダカグンシンヒダカチョウ', '静内吉野町', 'シズナイヨシノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道日高郡新ひだか町静内青柳町', '01', '01610', '0560019', '北海道', 'ホッカイドウ', '日高郡新ひだか町', 'ヒダカグンシンヒダカチョウ', '静内青柳町', 'シズナイアオヤギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道日高郡新ひだか町静内花園', '01', '01610', '0560021', '北海道', 'ホッカイドウ', '日高郡新ひだか町', 'ヒダカグンシンヒダカチョウ', '静内花園', 'シズナイハナゾノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道日高郡新ひだか町静内高砂町', '01', '01610', '0560022', '北海道', 'ホッカイドウ', '日高郡新ひだか町', 'ヒダカグンシンヒダカチョウ', '静内高砂町', 'シズナイタカサゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道日高郡新ひだか町静内ときわ町', '01', '01610', '0560023', '北海道', 'ホッカイドウ', '日高郡新ひだか町', 'ヒダカグンシンヒダカチョウ', '静内ときわ町', 'シズナイトキワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道日高郡新ひだか町静内山手町', '01', '01610', '0560024', '北海道', 'ホッカイドウ', '日高郡新ひだか町', 'ヒダカグンシンヒダカチョウ', '静内山手町', 'シズナイヤマテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道日高郡新ひだか町静内木場町', '01', '01610', '0560025', '北海道', 'ホッカイドウ', '日高郡新ひだか町', 'ヒダカグンシンヒダカチョウ', '静内木場町', 'シズナイキバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道日高郡新ひだか町静内末広町', '01', '01610', '0560026', '北海道', 'ホッカイドウ', '日高郡新ひだか町', 'ヒダカグンシンヒダカチョウ', '静内末広町', 'シズナイスエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道日高郡新ひだか町静内駒場', '01', '01610', '0560027', '北海道', 'ホッカイドウ', '日高郡新ひだか町', 'ヒダカグンシンヒダカチョウ', '静内駒場', 'シズナイコマバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('60999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道日高郡新ひだか町静内柏台', '01', '01610', '0560028', '北海道', 'ホッカイドウ', '日高郡新ひだか町', 'ヒダカグンシンヒダカチョウ', '静内柏台', 'シズナイカシワダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道日高郡新ひだか町静内御園', '01', '01610', '0560141', '北海道', 'ホッカイドウ', '日高郡新ひだか町', 'ヒダカグンシンヒダカチョウ', '静内御園', 'シズナイミソノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道日高郡新ひだか町静内農屋', '01', '01610', '0560142', '北海道', 'ホッカイドウ', '日高郡新ひだか町', 'ヒダカグンシンヒダカチョウ', '静内農屋', 'シズナイノヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道日高郡新ひだか町静内豊畑', '01', '01610', '0560143', '北海道', 'ホッカイドウ', '日高郡新ひだか町', 'ヒダカグンシンヒダカチョウ', '静内豊畑', 'シズナイトヨハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道日高郡新ひだか町静内田原', '01', '01610', '0560144', '北海道', 'ホッカイドウ', '日高郡新ひだか町', 'ヒダカグンシンヒダカチョウ', '静内田原', 'シズナイタハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道日高郡新ひだか町静内目名', '01', '01610', '0560145', '北海道', 'ホッカイドウ', '日高郡新ひだか町', 'ヒダカグンシンヒダカチョウ', '静内目名', 'シズナイメナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道日高郡新ひだか町静内高見', '01', '01610', '0560146', '北海道', 'ホッカイドウ', '日高郡新ひだか町', 'ヒダカグンシンヒダカチョウ', '静内高見', 'シズナイタカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市曽根西町', '27', '27203', '5610801', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', '曽根西町', 'ソネニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市曽根東町', '27', '27203', '5610802', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', '曽根東町', 'ソネヒガシノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市城山町', '27', '27203', '5610803', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', '城山町', 'シロヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市曽根南町', '27', '27203', '5610804', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', '曽根南町', 'ソネミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市原田南', '27', '27203', '5610805', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', '原田南', 'ハラダミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市原田西町', '27', '27203', '5610806', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', '原田西町', 'ハラダニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市原田中', '27', '27203', '5610807', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', '原田中', 'ハラダナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市原田元町', '27', '27203', '5610808', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', '原田元町', 'ハラダモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市若竹町', '27', '27203', '5610811', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', '若竹町', 'ワカタケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市北条町', '27', '27203', '5610812', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', '北条町', 'キタジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市小曽根', '27', '27203', '5610813', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', '小曽根', 'オゾネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市豊南町東', '27', '27203', '5610814', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', '豊南町東', 'ホウナンチョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市豊南町南', '27', '27203', '5610815', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', '豊南町南', 'ホウナンチョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市豊南町西', '27', '27203', '5610816', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', '豊南町西', 'ホウナンチョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市浜', '27', '27203', '5610817', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', '浜', 'ハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市日出町', '27', '27203', '5610821', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', '日出町', 'ヒノデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市三国', '27', '27203', '5610822', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', '三国', 'ミクニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市神州町', '27', '27203', '5610823', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', '神州町', 'カミスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市大島町', '27', '27203', '5610824', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', '大島町', 'オオシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市二葉町', '27', '27203', '5610825', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', '二葉町', 'フタバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市島江町', '27', '27203', '5610826', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', '島江町', 'シマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市大黒町', '27', '27203', '5610827', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', '大黒町', 'ダイコクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市三和町', '27', '27203', '5610828', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', '三和町', 'サンワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市千成町', '27', '27203', '5610829', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', '千成町', 'センナリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市庄内東町', '27', '27203', '5610831', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', '庄内東町', 'ショウナイヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市庄内西町', '27', '27203', '5610832', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', '庄内西町', 'ショウナイニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市庄内幸町', '27', '27203', '5610833', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', '庄内幸町', 'ショウナイサイワイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市庄内栄町', '27', '27203', '5610834', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', '庄内栄町', 'ショウナイサカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市庄本町', '27', '27203', '5610835', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', '庄本町', 'ショウモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市庄内宝町', '27', '27203', '5610836', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', '庄内宝町', 'ショウナイタカラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市名神口', '27', '27203', '5610841', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', '名神口', 'メイシングチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市今在家町', '27', '27203', '5610842', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', '今在家町', 'イマザイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市上津島', '27', '27203', '5610843', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', '上津島', 'コウヅシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市利倉西', '27', '27203', '5610844', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', '利倉西', 'トクラニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市利倉', '27', '27203', '5610845', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', '利倉', 'トクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市利倉東', '27', '27203', '5610846', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', '利倉東', 'トクラヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市服部元町', '27', '27203', '5610851', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', '服部元町', 'ハットリモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市服部本町', '27', '27203', '5610852', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', '服部本町', 'ハットリホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市服部南町', '27', '27203', '5610853', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', '服部南町', 'ハットリミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市稲津町', '27', '27203', '5610854', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', '稲津町', 'イナヅチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市野田町', '27', '27203', '5610855', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', '野田町', 'ノダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市穂積', '27', '27203', '5610856', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', '穂積', 'ホヅミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市服部寿町', '27', '27203', '5610857', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', '服部寿町', 'ハットリコトブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市服部西町', '27', '27203', '5610858', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', '服部西町', 'ハットリニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市服部豊町', '27', '27203', '5610859', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', '服部豊町', 'ハットリユタカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市東泉丘', '27', '27203', '5610861', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', '東泉丘', 'ヒガシイズミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市西泉丘', '27', '27203', '5610862', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', '西泉丘', 'ニシイズミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市広田町', '27', '27203', '5610863', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', '広田町', 'ヒロタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市夕日丘', '27', '27203', '5610864', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', '夕日丘', 'ユウヒガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市旭丘', '27', '27203', '5610865', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', '旭丘', 'アサヒガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市東寺内町', '27', '27203', '5610871', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', '東寺内町', 'ヒガシテラウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市寺内', '27', '27203', '5610872', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', '寺内', 'テラウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市服部緑地', '27', '27203', '5610873', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', '服部緑地', 'ハットリリョクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市長興寺南', '27', '27203', '5610874', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', '長興寺南', 'チョウコウジミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市長興寺北', '27', '27203', '5610875', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', '長興寺北', 'チョウコウジキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市中桜塚', '27', '27203', '5610881', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', '中桜塚', 'ナカサクラヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市南桜塚', '27', '27203', '5610882', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', '南桜塚', 'ミナミサクラヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市岡町南', '27', '27203', '5610883', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', '岡町南', 'オカマチミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市岡町北', '27', '27203', '5610884', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', '岡町北', 'オカマチキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市岡町', '27', '27203', '5610885', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', '岡町', 'オカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市走井', '27', '27203', '5610891', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', '走井', 'ハシリイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市山ノ上町', '27', '27203', '5610892', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', '山ノ上町', 'ヤマノウエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市宝山町', '27', '27203', '5610893', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', '宝山町', 'ホウザンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊中市勝部', '27', '27203', '5610894', '大阪府', 'オオサカフ', '豊中市', 'トヨナカシ', '勝部', 'カツベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府箕面市', '27', '27220', '5620000', '大阪府', 'オオサカフ', '箕面市', 'ミノオシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('61091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府箕面市箕面', '27', '27220', '5620001', '大阪府', 'オオサカフ', '箕面市', 'ミノオシ', '箕面', 'ミノオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府箕面市箕面公園', '27', '27220', '5620002', '大阪府', 'オオサカフ', '箕面市', 'ミノオシ', '箕面公園', 'ミノオコウエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府箕面市西小路', '27', '27220', '5620003', '大阪府', 'オオサカフ', '箕面市', 'ミノオシ', '西小路', 'ニシショウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府箕面市牧落', '27', '27220', '5620004', '大阪府', 'オオサカフ', '箕面市', 'ミノオシ', '牧落', 'マキオチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府箕面市新稲', '27', '27220', '5620005', '大阪府', 'オオサカフ', '箕面市', 'ミノオシ', '新稲', 'ニイナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府箕面市温泉町', '27', '27220', '5620006', '大阪府', 'オオサカフ', '箕面市', 'ミノオシ', '温泉町', 'オンセンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府箕面市如意谷', '27', '27220', '5620011', '大阪府', 'オオサカフ', '箕面市', 'ミノオシ', '如意谷', 'ニョイダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府箕面市白島', '27', '27220', '5620012', '大阪府', 'オオサカフ', '箕面市', 'ミノオシ', '白島', 'ハクシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府箕面市坊島', '27', '27220', '5620013', '大阪府', 'オオサカフ', '箕面市', 'ミノオシ', '坊島', 'ボウシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府箕面市萱野', '27', '27220', '5620014', '大阪府', 'オオサカフ', '箕面市', 'ミノオシ', '萱野', 'カヤノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府箕面市稲', '27', '27220', '5620015', '大阪府', 'オオサカフ', '箕面市', 'ミノオシ', '稲', 'イナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府箕面市粟生間谷', '27', '27220', '5620021', '大阪府', 'オオサカフ', '箕面市', 'ミノオシ', '粟生間谷', 'アオマタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府箕面市粟生間谷東', '27', '27220', '5620022', '大阪府', 'オオサカフ', '箕面市', 'ミノオシ', '粟生間谷東', 'アオマタニヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府箕面市粟生間谷西', '27', '27220', '5620023', '大阪府', 'オオサカフ', '箕面市', 'ミノオシ', '粟生間谷西', 'アオマタニニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府箕面市粟生新家', '27', '27220', '5620024', '大阪府', 'オオサカフ', '箕面市', 'ミノオシ', '粟生新家', 'アオシンケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府箕面市粟生外院', '27', '27220', '5620025', '大阪府', 'オオサカフ', '箕面市', 'ミノオシ', '粟生外院', 'アオゲイン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府箕面市外院', '27', '27220', '5620026', '大阪府', 'オオサカフ', '箕面市', 'ミノオシ', '外院', 'ゲイン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府箕面市石丸', '27', '27220', '5620027', '大阪府', 'オオサカフ', '箕面市', 'ミノオシ', '石丸', 'イシマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府箕面市彩都粟生南', '27', '27220', '5620028', '大阪府', 'オオサカフ', '箕面市', 'ミノオシ', '彩都粟生南', 'サイトアオミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府箕面市彩都粟生北', '27', '27220', '5620029', '大阪府', 'オオサカフ', '箕面市', 'ミノオシ', '彩都粟生北', 'サイトアオキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府箕面市小野原東', '27', '27220', '5620031', '大阪府', 'オオサカフ', '箕面市', 'ミノオシ', '小野原東', 'オノハラヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府箕面市小野原西', '27', '27220', '5620032', '大阪府', 'オオサカフ', '箕面市', 'ミノオシ', '小野原西', 'オノハラニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府箕面市今宮', '27', '27220', '5620033', '大阪府', 'オオサカフ', '箕面市', 'ミノオシ', '今宮', 'イマミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府箕面市西宿', '27', '27220', '5620034', '大阪府', 'オオサカフ', '箕面市', 'ミノオシ', '西宿', 'ニシジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府箕面市船場東', '27', '27220', '5620035', '大阪府', 'オオサカフ', '箕面市', 'ミノオシ', '船場東', 'センバヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府箕面市船場西', '27', '27220', '5620036', '大阪府', 'オオサカフ', '箕面市', 'ミノオシ', '船場西', 'センバニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府箕面市桜', '27', '27220', '5620041', '大阪府', 'オオサカフ', '箕面市', 'ミノオシ', '桜', 'サクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府箕面市百楽荘', '27', '27220', '5620042', '大阪府', 'オオサカフ', '箕面市', 'ミノオシ', '百楽荘', 'ヒャクラクソウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府箕面市桜井', '27', '27220', '5620043', '大阪府', 'オオサカフ', '箕面市', 'ミノオシ', '桜井', 'サクライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府箕面市半町', '27', '27220', '5620044', '大阪府', 'オオサカフ', '箕面市', 'ミノオシ', '半町', 'ハンジョ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府箕面市瀬川', '27', '27220', '5620045', '大阪府', 'オオサカフ', '箕面市', 'ミノオシ', '瀬川', 'セガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府箕面市桜ケ丘', '27', '27220', '5620046', '大阪府', 'オオサカフ', '箕面市', 'ミノオシ', '桜ケ丘', 'サクラガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府池田市', '27', '27204', '5630000', '大阪府', 'オオサカフ', '池田市', 'イケダシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('61146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府池田市伏尾町', '27', '27204', '5630011', '大阪府', 'オオサカフ', '池田市', 'イケダシ', '伏尾町', 'フシオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府池田市東山町', '27', '27204', '5630012', '大阪府', 'オオサカフ', '池田市', 'イケダシ', '東山町', 'ヒガシヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府池田市中川原町', '27', '27204', '5630013', '大阪府', 'オオサカフ', '池田市', 'イケダシ', '中川原町', 'ナカガワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府池田市木部町', '27', '27204', '5630014', '大阪府', 'オオサカフ', '池田市', 'イケダシ', '木部町', 'キベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府池田市古江町', '27', '27204', '5630015', '大阪府', 'オオサカフ', '池田市', 'イケダシ', '古江町', 'フルエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府池田市吉田町', '27', '27204', '5630016', '大阪府', 'オオサカフ', '池田市', 'イケダシ', '吉田町', 'ヨシダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府池田市伏尾台', '27', '27204', '5630017', '大阪府', 'オオサカフ', '池田市', 'イケダシ', '伏尾台', 'フシオダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府池田市畑', '27', '27204', '5630021', '大阪府', 'オオサカフ', '池田市', 'イケダシ', '畑', 'ハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府池田市旭丘', '27', '27204', '5630022', '大阪府', 'オオサカフ', '池田市', 'イケダシ', '旭丘', 'アサヒガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府池田市井口堂', '27', '27204', '5630023', '大阪府', 'オオサカフ', '池田市', 'イケダシ', '井口堂', 'イグチドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府池田市鉢塚', '27', '27204', '5630024', '大阪府', 'オオサカフ', '池田市', 'イケダシ', '鉢塚', 'ハチヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府池田市城南', '27', '27204', '5630025', '大阪府', 'オオサカフ', '池田市', 'イケダシ', '城南', 'ジョウナン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府池田市緑丘', '27', '27204', '5630026', '大阪府', 'オオサカフ', '池田市', 'イケダシ', '緑丘', 'ミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府池田市上池田', '27', '27204', '5630027', '大阪府', 'オオサカフ', '池田市', 'イケダシ', '上池田', 'ウエイケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府池田市渋谷', '27', '27204', '5630028', '大阪府', 'オオサカフ', '池田市', 'イケダシ', '渋谷', 'シブタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府池田市五月丘', '27', '27204', '5630029', '大阪府', 'オオサカフ', '池田市', 'イケダシ', '五月丘', 'サツキガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府池田市天神', '27', '27204', '5630031', '大阪府', 'オオサカフ', '池田市', 'イケダシ', '天神', 'テンジン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府池田市石橋', '27', '27204', '5630032', '大阪府', 'オオサカフ', '池田市', 'イケダシ', '石橋', 'イシバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府池田市住吉', '27', '27204', '5630033', '大阪府', 'オオサカフ', '池田市', 'イケダシ', '住吉', 'スミヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府池田市空港', '27', '27204', '5630034', '大阪府', 'オオサカフ', '池田市', 'イケダシ', '空港', 'クウコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府池田市豊島南', '27', '27204', '5630035', '大阪府', 'オオサカフ', '池田市', 'イケダシ', '豊島南', 'トヨシマミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府池田市豊島北', '27', '27204', '5630036', '大阪府', 'オオサカフ', '池田市', 'イケダシ', '豊島北', 'トヨシマキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府池田市八王寺', '27', '27204', '5630037', '大阪府', 'オオサカフ', '池田市', 'イケダシ', '八王寺', 'ハチオウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府池田市荘園', '27', '27204', '5630038', '大阪府', 'オオサカフ', '池田市', 'イケダシ', '荘園', 'ソウエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府池田市満寿美町', '27', '27204', '5630041', '大阪府', 'オオサカフ', '池田市', 'イケダシ', '満寿美町', 'マスミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府池田市宇保町', '27', '27204', '5630042', '大阪府', 'オオサカフ', '池田市', 'イケダシ', '宇保町', 'ウホチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府池田市神田', '27', '27204', '5630043', '大阪府', 'オオサカフ', '池田市', 'イケダシ', '神田', 'コウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府池田市ダイハツ町', '27', '27204', '5630044', '大阪府', 'オオサカフ', '池田市', 'イケダシ', 'ダイハツ町', 'ダイハツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府池田市桃園', '27', '27204', '5630045', '大阪府', 'オオサカフ', '池田市', 'イケダシ', '桃園', 'モモゾノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府池田市姫室町', '27', '27204', '5630046', '大阪府', 'オオサカフ', '池田市', 'イケダシ', '姫室町', 'ヒメムロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府池田市室町', '27', '27204', '5630047', '大阪府', 'オオサカフ', '池田市', 'イケダシ', '室町', 'ムロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府池田市呉服町', '27', '27204', '5630048', '大阪府', 'オオサカフ', '池田市', 'イケダシ', '呉服町', 'クレハチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府池田市新町', '27', '27204', '5630050', '大阪府', 'オオサカフ', '池田市', 'イケダシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府池田市綾羽', '27', '27204', '5630051', '大阪府', 'オオサカフ', '池田市', 'イケダシ', '綾羽', 'アヤハ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府池田市城山町', '27', '27204', '5630052', '大阪府', 'オオサカフ', '池田市', 'イケダシ', '城山町', 'シロヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府池田市建石町', '27', '27204', '5630053', '大阪府', 'オオサカフ', '池田市', 'イケダシ', '建石町', 'タテイシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府池田市大和町', '27', '27204', '5630054', '大阪府', 'オオサカフ', '池田市', 'イケダシ', '大和町', 'ダイワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府池田市菅原町', '27', '27204', '5630055', '大阪府', 'オオサカフ', '池田市', 'イケダシ', '菅原町', 'スガハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府池田市栄町', '27', '27204', '5630056', '大阪府', 'オオサカフ', '池田市', 'イケダシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府池田市槻木町', '27', '27204', '5630057', '大阪府', 'オオサカフ', '池田市', 'イケダシ', '槻木町', 'ツキノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府池田市栄本町', '27', '27204', '5630058', '大阪府', 'オオサカフ', '池田市', 'イケダシ', '栄本町', 'サカエホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府池田市西本町', '27', '27204', '5630059', '大阪府', 'オオサカフ', '池田市', 'イケダシ', '西本町', 'ニシホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊能郡豊能町', '27', '27321', '5630100', '大阪府', 'オオサカフ', '豊能郡豊能町', 'トヨノグントヨノチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('61189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊能郡豊能町吉川', '27', '27321', '5630101', '大阪府', 'オオサカフ', '豊能郡豊能町', 'トヨノグントヨノチョウ', '吉川', 'ヨシカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊能郡豊能町ときわ台', '27', '27321', '5630102', '大阪府', 'オオサカフ', '豊能郡豊能町', 'トヨノグントヨノチョウ', 'ときわ台', 'トキワダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊能郡豊能町東ときわ台', '27', '27321', '5630103', '大阪府', 'オオサカフ', '豊能郡豊能町', 'トヨノグントヨノチョウ', '東ときわ台', 'ヒガシトキワダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊能郡豊能町光風台', '27', '27321', '5630104', '大阪府', 'オオサカフ', '豊能郡豊能町', 'トヨノグントヨノチョウ', '光風台', 'コウフウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊能郡豊能町新光風台', '27', '27321', '5630105', '大阪府', 'オオサカフ', '豊能郡豊能町', 'トヨノグントヨノチョウ', '新光風台', 'シンコウフウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊能郡能勢町吉野', '27', '27322', '5630111', '大阪府', 'オオサカフ', '豊能郡能勢町', 'トヨノグンノセチョウ', '吉野', 'ヨシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊能郡能勢町杉原', '27', '27322', '5630112', '大阪府', 'オオサカフ', '豊能郡能勢町', 'トヨノグンノセチョウ', '杉原', 'スギハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊能郡能勢町倉垣', '27', '27322', '5630113', '大阪府', 'オオサカフ', '豊能郡能勢町', 'トヨノグンノセチョウ', '倉垣', 'クラガキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊能郡能勢町山内', '27', '27322', '5630114', '大阪府', 'オオサカフ', '豊能郡能勢町', 'トヨノグンノセチョウ', '山内', 'ヤマウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊能郡能勢町地黄', '27', '27322', '5630121', '大阪府', 'オオサカフ', '豊能郡能勢町', 'トヨノグンノセチョウ', '地黄', 'ジオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊能郡能勢町上田尻', '27', '27322', '5630122', '大阪府', 'オオサカフ', '豊能郡能勢町', 'トヨノグンノセチョウ', '上田尻', 'カミタジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊能郡能勢町下田尻', '27', '27322', '5630123', '大阪府', 'オオサカフ', '豊能郡能勢町', 'トヨノグンノセチョウ', '下田尻', 'シモタジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊能郡能勢町野間大原', '27', '27322', '5630131', '大阪府', 'オオサカフ', '豊能郡能勢町', 'トヨノグンノセチョウ', '野間大原', 'ノマオオハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊能郡能勢町野間中', '27', '27322', '5630132', '大阪府', 'オオサカフ', '豊能郡能勢町', 'トヨノグンノセチョウ', '野間中', 'ノマナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊能郡能勢町野間稲地', '27', '27322', '5630133', '大阪府', 'オオサカフ', '豊能郡能勢町', 'トヨノグンノセチョウ', '野間稲地', 'ノマイナジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊能郡能勢町野間出野', '27', '27322', '5630134', '大阪府', 'オオサカフ', '豊能郡能勢町', 'トヨノグンノセチョウ', '野間出野', 'ノマシュツノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊能郡能勢町野間西山', '27', '27322', '5630135', '大阪府', 'オオサカフ', '豊能郡能勢町', 'トヨノグンノセチョウ', '野間西山', 'ノマニシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊能郡豊能町牧', '27', '27321', '5630211', '大阪府', 'オオサカフ', '豊能郡豊能町', 'トヨノグントヨノチョウ', '牧', 'マキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊能郡豊能町寺田', '27', '27321', '5630212', '大阪府', 'オオサカフ', '豊能郡豊能町', 'トヨノグントヨノチョウ', '寺田', 'テラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊能郡豊能町切畑', '27', '27321', '5630213', '大阪府', 'オオサカフ', '豊能郡豊能町', 'トヨノグントヨノチョウ', '切畑', 'キリハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊能郡豊能町希望ケ丘', '27', '27321', '5630214', '大阪府', 'オオサカフ', '豊能郡豊能町', 'トヨノグントヨノチョウ', '希望ケ丘', 'キボウガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊能郡豊能町木代', '27', '27321', '5630215', '大阪府', 'オオサカフ', '豊能郡豊能町', 'トヨノグントヨノチョウ', '木代', 'キシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊能郡豊能町高山', '27', '27321', '5630216', '大阪府', 'オオサカフ', '豊能郡豊能町', 'トヨノグントヨノチョウ', '高山', 'タカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊能郡豊能町川尻', '27', '27321', '5630217', '大阪府', 'オオサカフ', '豊能郡豊能町', 'トヨノグントヨノチョウ', '川尻', 'カワシリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊能郡豊能町野間口', '27', '27321', '5630218', '大阪府', 'オオサカフ', '豊能郡豊能町', 'トヨノグントヨノチョウ', '野間口', 'ノマグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊能郡豊能町余野', '27', '27321', '5630219', '大阪府', 'オオサカフ', '豊能郡豊能町', 'トヨノグントヨノチョウ', '余野', 'ヨノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府箕面市上止々呂美', '27', '27220', '5630251', '大阪府', 'オオサカフ', '箕面市', 'ミノオシ', '上止々呂美', 'カミトドロミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府箕面市下止々呂美', '27', '27220', '5630252', '大阪府', 'オオサカフ', '箕面市', 'ミノオシ', '下止々呂美', 'シモトドロミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府箕面市森町北', '27', '27220', '5630256', '大阪府', 'オオサカフ', '箕面市', 'ミノオシ', '森町北', 'シンマチキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府箕面市森町中', '27', '27220', '5630257', '大阪府', 'オオサカフ', '箕面市', 'ミノオシ', '森町中', 'シンマチナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊能郡能勢町', '27', '27322', '5630300', '大阪府', 'オオサカフ', '豊能郡能勢町', 'トヨノグンノセチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('61221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊能郡能勢町宿野', '27', '27322', '5630341', '大阪府', 'オオサカフ', '豊能郡能勢町', 'トヨノグンノセチョウ', '宿野', 'シュクノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊能郡能勢町栗栖', '27', '27322', '5630351', '大阪府', 'オオサカフ', '豊能郡能勢町', 'トヨノグンノセチョウ', '栗栖', 'クルス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊能郡能勢町大里', '27', '27322', '5630352', '大阪府', 'オオサカフ', '豊能郡能勢町', 'トヨノグンノセチョウ', '大里', 'オオザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊能郡能勢町柏原', '27', '27322', '5630353', '大阪府', 'オオサカフ', '豊能郡能勢町', 'トヨノグンノセチョウ', '柏原', 'カシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊能郡能勢町片山', '27', '27322', '5630354', '大阪府', 'オオサカフ', '豊能郡能勢町', 'トヨノグンノセチョウ', '片山', 'カタヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊能郡能勢町下田', '27', '27322', '5630355', '大阪府', 'オオサカフ', '豊能郡能勢町', 'トヨノグンノセチョウ', '下田', 'シモダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊能郡能勢町平通', '27', '27322', '5630356', '大阪府', 'オオサカフ', '豊能郡能勢町', 'トヨノグンノセチョウ', '平通', 'ヒラドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊能郡能勢町今西', '27', '27322', '5630361', '大阪府', 'オオサカフ', '豊能郡能勢町', 'トヨノグンノセチョウ', '今西', 'イマニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊能郡能勢町森上', '27', '27322', '5630362', '大阪府', 'オオサカフ', '豊能郡能勢町', 'トヨノグンノセチョウ', '森上', 'モリガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊能郡能勢町稲地', '27', '27322', '5630363', '大阪府', 'オオサカフ', '豊能郡能勢町', 'トヨノグンノセチョウ', '稲地', 'イナジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊能郡能勢町平野', '27', '27322', '5630364', '大阪府', 'オオサカフ', '豊能郡能勢町', 'トヨノグンノセチョウ', '平野', 'ヒラノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊能郡能勢町上杉', '27', '27322', '5630365', '大阪府', 'オオサカフ', '豊能郡能勢町', 'トヨノグンノセチョウ', '上杉', 'ウエスギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊能郡能勢町垂水', '27', '27322', '5630366', '大阪府', 'オオサカフ', '豊能郡能勢町', 'トヨノグンノセチョウ', '垂水', 'タルミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊能郡能勢町神山', '27', '27322', '5630367', '大阪府', 'オオサカフ', '豊能郡能勢町', 'トヨノグンノセチョウ', '神山', 'コヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊能郡能勢町長谷', '27', '27322', '5630368', '大阪府', 'オオサカフ', '豊能郡能勢町', 'トヨノグンノセチョウ', '長谷', 'ナガタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊能郡能勢町天王', '27', '27322', '5630371', '大阪府', 'オオサカフ', '豊能郡能勢町', 'トヨノグンノセチョウ', '天王', 'テンノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊能郡能勢町山辺', '27', '27322', '5630372', '大阪府', 'オオサカフ', '豊能郡能勢町', 'トヨノグンノセチョウ', '山辺', 'ヤマベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府豊能郡能勢町山田', '27', '27322', '5630373', '大阪府', 'オオサカフ', '豊能郡能勢町', 'トヨノグンノセチョウ', '山田', 'ヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県伊丹市小阪田食田', '28', '28207', '5630801', '兵庫県', 'ヒョウゴケン', '伊丹市', 'イタミシ', '小阪田', 'オサカデン', null, null, '食田', 'クイタ');
INSERT INTO `ms_addresses` VALUES ('61245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府吹田市', '27', '27205', '5640000', '大阪府', 'オオサカフ', '吹田市', 'スイタシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('61246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府吹田市岸部北', '27', '27205', '5640001', '大阪府', 'オオサカフ', '吹田市', 'スイタシ', '岸部北', 'キシベキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府吹田市岸部中', '27', '27205', '5640002', '大阪府', 'オオサカフ', '吹田市', 'スイタシ', '岸部中', 'キシベナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府吹田市天道町', '27', '27205', '5640003', '大阪府', 'オオサカフ', '吹田市', 'スイタシ', '天道町', 'テンドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府吹田市原町', '27', '27205', '5640004', '大阪府', 'オオサカフ', '吹田市', 'スイタシ', '原町', 'ハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府吹田市岸部南', '27', '27205', '5640011', '大阪府', 'オオサカフ', '吹田市', 'スイタシ', '岸部南', 'キシベミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府吹田市南正雀', '27', '27205', '5640012', '大阪府', 'オオサカフ', '吹田市', 'スイタシ', '南正雀', 'ミナミショウジャク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府吹田市川園町', '27', '27205', '5640013', '大阪府', 'オオサカフ', '吹田市', 'スイタシ', '川園町', 'カワゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府吹田市吹東町', '27', '27205', '5640014', '大阪府', 'オオサカフ', '吹田市', 'スイタシ', '吹東町', 'スイトウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府吹田市幸町', '27', '27205', '5640015', '大阪府', 'オオサカフ', '吹田市', 'スイタシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府吹田市平松町', '27', '27205', '5640016', '大阪府', 'オオサカフ', '吹田市', 'スイタシ', '平松町', 'ヒラマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府吹田市芝田町', '27', '27205', '5640017', '大阪府', 'オオサカフ', '吹田市', 'スイタシ', '芝田町', 'シバタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府吹田市目俵町', '27', '27205', '5640021', '大阪府', 'オオサカフ', '吹田市', 'スイタシ', '目俵町', 'メダワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府吹田市末広町', '27', '27205', '5640022', '大阪府', 'オオサカフ', '吹田市', 'スイタシ', '末広町', 'スエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府吹田市日の出町', '27', '27205', '5640023', '大阪府', 'オオサカフ', '吹田市', 'スイタシ', '日の出町', 'ヒノデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府吹田市高城町', '27', '27205', '5640024', '大阪府', 'オオサカフ', '吹田市', 'スイタシ', '高城町', 'タカシロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府吹田市南高浜町', '27', '27205', '5640025', '大阪府', 'オオサカフ', '吹田市', 'スイタシ', '南高浜町', 'ミナミタカハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府吹田市高浜町', '27', '27205', '5640026', '大阪府', 'オオサカフ', '吹田市', 'スイタシ', '高浜町', 'タカハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府吹田市朝日町', '27', '27205', '5640027', '大阪府', 'オオサカフ', '吹田市', 'スイタシ', '朝日町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府吹田市昭和町', '27', '27205', '5640028', '大阪府', 'オオサカフ', '吹田市', 'スイタシ', '昭和町', 'ショウワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府吹田市元町', '27', '27205', '5640031', '大阪府', 'オオサカフ', '吹田市', 'スイタシ', '元町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府吹田市内本町', '27', '27205', '5640032', '大阪府', 'オオサカフ', '吹田市', 'スイタシ', '内本町', 'ウチホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府吹田市東御旅町', '27', '27205', '5640033', '大阪府', 'オオサカフ', '吹田市', 'スイタシ', '東御旅町', 'ヒガシオタビチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府吹田市西御旅町', '27', '27205', '5640034', '大阪府', 'オオサカフ', '吹田市', 'スイタシ', '西御旅町', 'ニシオタビチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府吹田市中の島町', '27', '27205', '5640035', '大阪府', 'オオサカフ', '吹田市', 'スイタシ', '中の島町', 'ナカノシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府吹田市寿町', '27', '27205', '5640036', '大阪府', 'オオサカフ', '吹田市', 'スイタシ', '寿町', 'コトブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府吹田市川岸町', '27', '27205', '5640037', '大阪府', 'オオサカフ', '吹田市', 'スイタシ', '川岸町', 'カワギシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府吹田市南清和園町', '27', '27205', '5640038', '大阪府', 'オオサカフ', '吹田市', 'スイタシ', '南清和園町', 'ミナミセイワエンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府吹田市清和園町', '27', '27205', '5640039', '大阪府', 'オオサカフ', '吹田市', 'スイタシ', '清和園町', 'セイワエンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府吹田市泉町', '27', '27205', '5640041', '大阪府', 'オオサカフ', '吹田市', 'スイタシ', '泉町', 'イズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府吹田市穂波町', '27', '27205', '5640042', '大阪府', 'オオサカフ', '吹田市', 'スイタシ', '穂波町', 'ホナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府吹田市南吹田', '27', '27205', '5640043', '大阪府', 'オオサカフ', '吹田市', 'スイタシ', '南吹田', 'ミナミスイタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府吹田市南金田', '27', '27205', '5640044', '大阪府', 'オオサカフ', '吹田市', 'スイタシ', '南金田', 'ミナミカネデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府吹田市金田町', '27', '27205', '5640045', '大阪府', 'オオサカフ', '吹田市', 'スイタシ', '金田町', 'カネデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府吹田市豊津町', '27', '27205', '5640051', '大阪府', 'オオサカフ', '吹田市', 'スイタシ', '豊津町', 'トヨツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府吹田市広芝町', '27', '27205', '5640052', '大阪府', 'オオサカフ', '吹田市', 'スイタシ', '広芝町', 'ヒロシバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府吹田市江の木町', '27', '27205', '5640053', '大阪府', 'オオサカフ', '吹田市', 'スイタシ', '江の木町', 'エノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府吹田市芳野町', '27', '27205', '5640054', '大阪府', 'オオサカフ', '吹田市', 'スイタシ', '芳野町', 'ヨシノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府吹田市円山町', '27', '27205', '5640061', '大阪府', 'オオサカフ', '吹田市', 'スイタシ', '円山町', 'マルヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府吹田市垂水町', '27', '27205', '5640062', '大阪府', 'オオサカフ', '吹田市', 'スイタシ', '垂水町', 'タルミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府吹田市江坂町', '27', '27205', '5640063', '大阪府', 'オオサカフ', '吹田市', 'スイタシ', '江坂町', 'エサカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府吹田市西の庄町', '27', '27205', '5640071', '大阪府', 'オオサカフ', '吹田市', 'スイタシ', '西の庄町', 'ニシノショウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府吹田市出口町', '27', '27205', '5640072', '大阪府', 'オオサカフ', '吹田市', 'スイタシ', '出口町', 'デグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府吹田市山手町', '27', '27205', '5640073', '大阪府', 'オオサカフ', '吹田市', 'スイタシ', '山手町', 'ヤマテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府吹田市藤が丘町', '27', '27205', '5640081', '大阪府', 'オオサカフ', '吹田市', 'スイタシ', '藤が丘町', 'フジガオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府吹田市片山町', '27', '27205', '5640082', '大阪府', 'オオサカフ', '吹田市', 'スイタシ', '片山町', 'カタヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府吹田市朝日が丘町', '27', '27205', '5640083', '大阪府', 'オオサカフ', '吹田市', 'スイタシ', '朝日が丘町', 'アサヒガオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府吹田市青葉丘北', '27', '27205', '5650801', '大阪府', 'オオサカフ', '吹田市', 'スイタシ', '青葉丘北', 'アオバオカキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府吹田市青葉丘南', '27', '27205', '5650802', '大阪府', 'オオサカフ', '吹田市', 'スイタシ', '青葉丘南', 'アオバオカミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府吹田市新芦屋下', '27', '27205', '5650803', '大阪府', 'オオサカフ', '吹田市', 'スイタシ', '新芦屋下', 'シンアシヤシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府吹田市新芦屋上', '27', '27205', '5650804', '大阪府', 'オオサカフ', '吹田市', 'スイタシ', '新芦屋上', 'シンアシヤカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府吹田市清水', '27', '27205', '5650805', '大阪府', 'オオサカフ', '吹田市', 'スイタシ', '清水', 'シミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府吹田市樫切山', '27', '27205', '5650806', '大阪府', 'オオサカフ', '吹田市', 'スイタシ', '樫切山', 'カシキリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府吹田市千里丘上', '27', '27205', '5650811', '大阪府', 'オオサカフ', '吹田市', 'スイタシ', '千里丘上', 'センリオカカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府吹田市千里丘中', '27', '27205', '5650812', '大阪府', 'オオサカフ', '吹田市', 'スイタシ', '千里丘中', 'センリオカナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府吹田市千里丘下', '27', '27205', '5650813', '大阪府', 'オオサカフ', '吹田市', 'スイタシ', '千里丘下', 'センリオカシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府吹田市千里丘西', '27', '27205', '5650814', '大阪府', 'オオサカフ', '吹田市', 'スイタシ', '千里丘西', 'センリオカニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府吹田市千里丘北', '27', '27205', '5650815', '大阪府', 'オオサカフ', '吹田市', 'スイタシ', '千里丘北', 'センリオカキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府吹田市長野東', '27', '27205', '5650816', '大阪府', 'オオサカフ', '吹田市', 'スイタシ', '長野東', 'ナガノヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府吹田市長野西', '27', '27205', '5650817', '大阪府', 'オオサカフ', '吹田市', 'スイタシ', '長野西', 'ナガノニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府吹田市尺谷', '27', '27205', '5650818', '大阪府', 'オオサカフ', '吹田市', 'スイタシ', '尺谷', 'シャクタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府吹田市山田東', '27', '27205', '5650821', '大阪府', 'オオサカフ', '吹田市', 'スイタシ', '山田東', 'ヤマダヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府吹田市山田市場', '27', '27205', '5650822', '大阪府', 'オオサカフ', '吹田市', 'スイタシ', '山田市場', 'ヤマダイチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府吹田市山田南', '27', '27205', '5650823', '大阪府', 'オオサカフ', '吹田市', 'スイタシ', '山田南', 'ヤマダミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府吹田市山田西', '27', '27205', '5650824', '大阪府', 'オオサカフ', '吹田市', 'スイタシ', '山田西', 'ヤマダニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府吹田市山田北', '27', '27205', '5650825', '大阪府', 'オオサカフ', '吹田市', 'スイタシ', '山田北', 'ヤマダキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府吹田市千里万博公園', '27', '27205', '5650826', '大阪府', 'オオサカフ', '吹田市', 'スイタシ', '千里万博公園', 'センリバンパクコウエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府吹田市五月が丘東', '27', '27205', '5650831', '大阪府', 'オオサカフ', '吹田市', 'スイタシ', '五月が丘東', 'サツキガオカヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府吹田市五月が丘南', '27', '27205', '5650832', '大阪府', 'オオサカフ', '吹田市', 'スイタシ', '五月が丘南', 'サツキガオカミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府吹田市五月が丘西', '27', '27205', '5650833', '大阪府', 'オオサカフ', '吹田市', 'スイタシ', '五月が丘西', 'サツキガオカニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府吹田市五月が丘北', '27', '27205', '5650834', '大阪府', 'オオサカフ', '吹田市', 'スイタシ', '五月が丘北', 'サツキガオカキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府吹田市竹谷町', '27', '27205', '5650835', '大阪府', 'オオサカフ', '吹田市', 'スイタシ', '竹谷町', 'タケタニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府吹田市佐井寺', '27', '27205', '5650836', '大阪府', 'オオサカフ', '吹田市', 'スイタシ', '佐井寺', 'サイデラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府吹田市佐井寺南が丘', '27', '27205', '5650837', '大阪府', 'オオサカフ', '吹田市', 'スイタシ', '佐井寺南が丘', 'サイデラミナミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府吹田市上山手町', '27', '27205', '5650841', '大阪府', 'オオサカフ', '吹田市', 'スイタシ', '上山手町', 'カミヤマテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府吹田市千里山東', '27', '27205', '5650842', '大阪府', 'オオサカフ', '吹田市', 'スイタシ', '千里山東', 'センリヤマヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府吹田市千里山松が丘', '27', '27205', '5650843', '大阪府', 'オオサカフ', '吹田市', 'スイタシ', '千里山松が丘', 'センリヤママツガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府吹田市千里山霧が丘', '27', '27205', '5650844', '大阪府', 'オオサカフ', '吹田市', 'スイタシ', '千里山霧が丘', 'センリヤマキリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府吹田市千里山星が丘', '27', '27205', '5650845', '大阪府', 'オオサカフ', '吹田市', 'スイタシ', '千里山星が丘', 'センリヤマホシガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府吹田市千里山虹が丘', '27', '27205', '5650846', '大阪府', 'オオサカフ', '吹田市', 'スイタシ', '千里山虹が丘', 'センリヤマニジガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府吹田市千里山月が丘', '27', '27205', '5650847', '大阪府', 'オオサカフ', '吹田市', 'スイタシ', '千里山月が丘', 'センリヤマツキガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府吹田市千里山高塚', '27', '27205', '5650848', '大阪府', 'オオサカフ', '吹田市', 'スイタシ', '千里山高塚', 'センリヤマタカツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府吹田市千里山西', '27', '27205', '5650851', '大阪府', 'オオサカフ', '吹田市', 'スイタシ', '千里山西', 'センリヤマニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府吹田市千里山竹園', '27', '27205', '5650852', '大阪府', 'オオサカフ', '吹田市', 'スイタシ', '千里山竹園', 'センリヤマタケゾノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府吹田市春日', '27', '27205', '5650853', '大阪府', 'オオサカフ', '吹田市', 'スイタシ', '春日', 'カスガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府吹田市桃山台', '27', '27205', '5650854', '大阪府', 'オオサカフ', '吹田市', 'スイタシ', '桃山台', 'モモヤマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府吹田市佐竹台', '27', '27205', '5650855', '大阪府', 'オオサカフ', '吹田市', 'スイタシ', '佐竹台', 'サタケダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府吹田市高野台', '27', '27205', '5650861', '大阪府', 'オオサカフ', '吹田市', 'スイタシ', '高野台', 'タカノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府吹田市津雲台', '27', '27205', '5650862', '大阪府', 'オオサカフ', '吹田市', 'スイタシ', '津雲台', 'ツクモダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府吹田市竹見台', '27', '27205', '5650863', '大阪府', 'オオサカフ', '吹田市', 'スイタシ', '竹見台', 'タケミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府吹田市山田丘', '27', '27205', '5650871', '大阪府', 'オオサカフ', '吹田市', 'スイタシ', '山田丘', 'ヤマダオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府吹田市上山田', '27', '27205', '5650872', '大阪府', 'オオサカフ', '吹田市', 'スイタシ', '上山田', 'カミヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府吹田市藤白台', '27', '27205', '5650873', '大阪府', 'オオサカフ', '吹田市', 'スイタシ', '藤白台', 'フジシロダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府吹田市古江台', '27', '27205', '5650874', '大阪府', 'オオサカフ', '吹田市', 'スイタシ', '古江台', 'フルエダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府吹田市青山台', '27', '27205', '5650875', '大阪府', 'オオサカフ', '吹田市', 'スイタシ', '青山台', 'アオヤマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府摂津市', '27', '27224', '5660000', '大阪府', 'オオサカフ', '摂津市', 'セッツシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('61358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府摂津市千里丘', '27', '27224', '5660001', '大阪府', 'オオサカフ', '摂津市', 'セッツシ', '千里丘', 'センリオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府摂津市千里丘東', '27', '27224', '5660011', '大阪府', 'オオサカフ', '摂津市', 'セッツシ', '千里丘東', 'センリオカヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府摂津市庄屋', '27', '27224', '5660012', '大阪府', 'オオサカフ', '摂津市', 'セッツシ', '庄屋', 'ショウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府摂津市阪急正雀', '27', '27224', '5660013', '大阪府', 'オオサカフ', '摂津市', 'セッツシ', '阪急正雀', 'ハンキュウショウジャク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府摂津市南千里丘', '27', '27224', '5660021', '大阪府', 'オオサカフ', '摂津市', 'セッツシ', '南千里丘', 'ミナミセンリオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府摂津市三島', '27', '27224', '5660022', '大阪府', 'オオサカフ', '摂津市', 'セッツシ', '三島', 'ミシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府摂津市正雀', '27', '27224', '5660023', '大阪府', 'オオサカフ', '摂津市', 'セッツシ', '正雀', 'ショウジャク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府摂津市正雀本町', '27', '27224', '5660024', '大阪府', 'オオサカフ', '摂津市', 'セッツシ', '正雀本町', 'ショウジャクホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府摂津市東正雀', '27', '27224', '5660025', '大阪府', 'オオサカフ', '摂津市', 'セッツシ', '東正雀', 'ヒガシショウジャク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府摂津市昭和園', '27', '27224', '5660031', '大阪府', 'オオサカフ', '摂津市', 'セッツシ', '昭和園', 'ショウワエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府摂津市桜町', '27', '27224', '5660032', '大阪府', 'オオサカフ', '摂津市', 'セッツシ', '桜町', 'サクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府摂津市学園町', '27', '27224', '5660033', '大阪府', 'オオサカフ', '摂津市', 'セッツシ', '学園町', 'ガクエンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府摂津市香露園', '27', '27224', '5660034', '大阪府', 'オオサカフ', '摂津市', 'セッツシ', '香露園', 'コウロエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府摂津市鶴野', '27', '27224', '5660035', '大阪府', 'オオサカフ', '摂津市', 'セッツシ', '鶴野', 'ツルノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府摂津市北別府町', '27', '27224', '5660041', '大阪府', 'オオサカフ', '摂津市', 'セッツシ', '北別府町', 'キタベフチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府摂津市東別府', '27', '27224', '5660042', '大阪府', 'オオサカフ', '摂津市', 'セッツシ', '東別府', 'ヒガシベフ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府摂津市一津屋', '27', '27224', '5660043', '大阪府', 'オオサカフ', '摂津市', 'セッツシ', '一津屋', 'ヒトツヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府摂津市西一津屋', '27', '27224', '5660044', '大阪府', 'オオサカフ', '摂津市', 'セッツシ', '西一津屋', 'ニシヒトツヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府摂津市南別府町', '27', '27224', '5660045', '大阪府', 'オオサカフ', '摂津市', 'セッツシ', '南別府町', 'ミナミベフチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府摂津市別府', '27', '27224', '5660046', '大阪府', 'オオサカフ', '摂津市', 'セッツシ', '別府', 'ベフ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府摂津市浜町', '27', '27224', '5660047', '大阪府', 'オオサカフ', '摂津市', 'セッツシ', '浜町', 'ハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府摂津市安威川南町', '27', '27224', '5660051', '大阪府', 'オオサカフ', '摂津市', 'セッツシ', '安威川南町', 'アイガワミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府摂津市鳥飼本町', '27', '27224', '5660052', '大阪府', 'オオサカフ', '摂津市', 'セッツシ', '鳥飼本町', 'トリカイホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府摂津市鳥飼野々', '27', '27224', '5660053', '大阪府', 'オオサカフ', '摂津市', 'セッツシ', '鳥飼野々', 'トリカイノノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府摂津市鳥飼八防', '27', '27224', '5660054', '大阪府', 'オオサカフ', '摂津市', 'セッツシ', '鳥飼八防', 'トリカイハチボウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府摂津市新在家', '27', '27224', '5660055', '大阪府', 'オオサカフ', '摂津市', 'セッツシ', '新在家', 'シンザイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府摂津市鳥飼八町', '27', '27224', '5660061', '大阪府', 'オオサカフ', '摂津市', 'セッツシ', '鳥飼八町', 'トリカイハッチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府摂津市鳥飼上', '27', '27224', '5660062', '大阪府', 'オオサカフ', '摂津市', 'セッツシ', '鳥飼上', 'トリカイカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府摂津市鳥飼銘木町', '27', '27224', '5660063', '大阪府', 'オオサカフ', '摂津市', 'セッツシ', '鳥飼銘木町', 'トリカイメイモクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府摂津市鳥飼中', '27', '27224', '5660064', '大阪府', 'オオサカフ', '摂津市', 'セッツシ', '鳥飼中', 'トリカイナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府摂津市鳥飼新町', '27', '27224', '5660065', '大阪府', 'オオサカフ', '摂津市', 'セッツシ', '鳥飼新町', 'トリカイシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府摂津市鳥飼下', '27', '27224', '5660071', '大阪府', 'オオサカフ', '摂津市', 'セッツシ', '鳥飼下', 'トリカイシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府摂津市鳥飼西', '27', '27224', '5660072', '大阪府', 'オオサカフ', '摂津市', 'セッツシ', '鳥飼西', 'トリカイニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府摂津市鳥飼和道', '27', '27224', '5660073', '大阪府', 'オオサカフ', '摂津市', 'セッツシ', '鳥飼和道', 'トリカイワドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府摂津市東一津屋', '27', '27224', '5660074', '大阪府', 'オオサカフ', '摂津市', 'セッツシ', '東一津屋', 'ヒガシヒトツヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市', '27', '27211', '5670000', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('61400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市安威', '27', '27211', '5670001', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '安威', 'アイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市東安威', '27', '27211', '5670002', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '東安威', 'ヒガシアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市西河原北町', '27', '27211', '5670003', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '西河原北町', 'ニシガワラキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市南耳原', '27', '27211', '5670004', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '南耳原', 'ミナミミノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市五日市', '27', '27211', '5670005', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '五日市', 'イツカイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市耳原', '27', '27211', '5670006', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '耳原', 'ミノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市南安威', '27', '27211', '5670007', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '南安威', 'ミナミアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市西安威', '27', '27211', '5670008', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '西安威', 'ニシアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市山手台', '27', '27211', '5670009', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '山手台', 'ヤマテダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市高田町', '27', '27211', '5670011', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '高田町', 'タカダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市東太田', '27', '27211', '5670012', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '東太田', 'ヒガシオオダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市太田東芝町', '27', '27211', '5670013', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '太田東芝町', 'オオダトウシバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市城の前町', '27', '27211', '5670014', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '城の前町', 'シロノマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市西太田町', '27', '27211', '5670015', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '西太田町', 'ニシオオダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市十日市町', '27', '27211', '5670016', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '十日市町', 'トオカイチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市花園', '27', '27211', '5670017', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '花園', 'ハナゾノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市太田', '27', '27211', '5670018', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '太田', 'オオダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市三島丘', '27', '27211', '5670021', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '三島丘', 'ミシマオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市三島町', '27', '27211', '5670022', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '三島町', 'ミシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市西河原', '27', '27211', '5670023', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '西河原', 'ニシガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市三咲町', '27', '27211', '5670024', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '三咲町', 'ミサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市田中町', '27', '27211', '5670025', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '田中町', 'タナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市松下町', '27', '27211', '5670026', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '松下町', 'マツシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市西田中町', '27', '27211', '5670027', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '西田中町', 'ニシタナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市畑田町', '27', '27211', '5670028', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '畑田町', 'ハタケダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市五日市緑町', '27', '27211', '5670029', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '五日市緑町', 'イツカイチミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市春日', '27', '27211', '5670031', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '春日', 'カスガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市西駅前町', '27', '27211', '5670032', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '西駅前町', 'ニシエキマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市松ケ本町', '27', '27211', '5670033', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '松ケ本町', 'マツガモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市中穂積', '27', '27211', '5670034', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '中穂積', 'ナカホヅミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市見付山', '27', '27211', '5670035', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '見付山', 'ミツケヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市上穂積', '27', '27211', '5670036', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '上穂積', 'カミホヅミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市上穂東町', '27', '27211', '5670037', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '上穂東町', 'カミホヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市下穂積', '27', '27211', '5670041', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '下穂積', 'シモホヅミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市宇野辺', '27', '27211', '5670042', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '宇野辺', 'ウノベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市小坪井', '27', '27211', '5670043', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '小坪井', 'コツボイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市穂積台', '27', '27211', '5670044', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '穂積台', 'ホヅミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市紫明園', '27', '27211', '5670045', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '紫明園', 'シメイエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市南春日丘', '27', '27211', '5670046', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '南春日丘', 'ミナミカスガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市美穂ケ丘', '27', '27211', '5670047', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '美穂ケ丘', 'ミホガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市北春日丘', '27', '27211', '5670048', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '北春日丘', 'キタカスガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市宿久庄', '27', '27211', '5670051', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '宿久庄', 'シュクノショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市室山', '27', '27211', '5670052', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '室山', 'ムロヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市豊原町', '27', '27211', '5670053', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '豊原町', 'トヨハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市藤の里', '27', '27211', '5670054', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '藤の里', 'フジノサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市宿川原町', '27', '27211', '5670055', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '宿川原町', 'シュクガハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市南清水町', '27', '27211', '5670056', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '南清水町', 'ミナミシミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市豊川', '27', '27211', '5670057', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '豊川', 'トヨカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市西豊川町', '27', '27211', '5670058', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '西豊川町', 'ニシトヨカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市清水', '27', '27211', '5670059', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '清水', 'シミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市福井', '27', '27211', '5670061', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '福井', 'フクイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市東福井', '27', '27211', '5670062', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '東福井', 'ヒガシフクイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市中河原町', '27', '27211', '5670063', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '中河原町', 'ナカカハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市上野町', '27', '27211', '5670064', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '上野町', 'ウエノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市上郡', '27', '27211', '5670065', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '上郡', 'カミゴオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市下井町', '27', '27211', '5670066', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '下井町', 'シモイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市西福井', '27', '27211', '5670067', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '西福井', 'ニシフクイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市郡山', '27', '27211', '5670071', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '郡山', 'コオリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市郡', '27', '27211', '5670072', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '郡', 'コオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市西穂積町', '27', '27211', '5670073', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '西穂積町', 'ニシホヅミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市新郡山', '27', '27211', '5670074', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '新郡山', 'シンコオリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市道祖本', '27', '27211', '5670075', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '道祖本', 'サイノモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市井口台', '27', '27211', '5670076', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '井口台', 'イグチダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市彩都あさぎ', '27', '27211', '5670085', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '彩都あさぎ', 'サイトアサギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市彩都やまぶき', '27', '27211', '5670086', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '彩都やまぶき', 'サイトヤマブキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市総持寺', '27', '27211', '5670801', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '総持寺', 'ソウジジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市総持寺駅前町', '27', '27211', '5670802', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '総持寺駅前町', 'ソウジジエキマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市中総持寺町', '27', '27211', '5670803', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '中総持寺町', 'ナカソウジジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市総持寺台', '27', '27211', '5670804', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '総持寺台', 'ソウジジダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市橋の内', '27', '27211', '5670805', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '橋の内', 'ハシノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市庄', '27', '27211', '5670806', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '庄', 'ショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市宮元町', '27', '27211', '5670810', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '宮元町', 'ミヤモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市上泉町', '27', '27211', '5670811', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '上泉町', 'カミイズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市東宮町', '27', '27211', '5670812', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '東宮町', 'トウグウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市大住町', '27', '27211', '5670813', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '大住町', 'オオスミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市戸伏町', '27', '27211', '5670814', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '戸伏町', 'トブシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市竹橋町', '27', '27211', '5670815', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '竹橋町', 'タケハシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市永代町', '27', '27211', '5670816', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '永代町', 'エイダイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市別院町', '27', '27211', '5670817', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '別院町', 'ベツインチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市本町', '27', '27211', '5670818', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市片桐町', '27', '27211', '5670819', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '片桐町', 'カタギリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市末広町', '27', '27211', '5670821', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '末広町', 'スエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市中村町', '27', '27211', '5670822', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '中村町', 'ナカムラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市寺田町', '27', '27211', '5670823', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '寺田町', 'テラダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市中津町', '27', '27211', '5670824', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '中津町', 'ナカツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市園田町', '27', '27211', '5670825', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '園田町', 'ソノダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市大池', '27', '27211', '5670826', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '大池', 'オオイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市稲葉町', '27', '27211', '5670827', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '稲葉町', 'イナバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市舟木町', '27', '27211', '5670828', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '舟木町', 'フナキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市双葉町', '27', '27211', '5670829', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '双葉町', 'フタバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市鮎川', '27', '27211', '5670831', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '鮎川', 'アユカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市白川', '27', '27211', '5670832', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '白川', 'シラカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市学園町', '27', '27211', '5670833', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '学園町', 'ガクエンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市学園南町', '27', '27211', '5670834', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '学園南町', 'ガクエンミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市新堂', '27', '27211', '5670835', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '新堂', 'シンドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市目垣', '27', '27211', '5670836', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '目垣', 'メガキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市南目垣', '27', '27211', '5670837', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '南目垣', 'ミナミメガキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市東野々宮町', '27', '27211', '5670838', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '東野々宮町', 'ヒガシノノミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市桑田町', '27', '27211', '5670841', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '桑田町', 'クワタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市五十鈴町', '27', '27211', '5670842', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '五十鈴町', 'イスズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市星見町', '27', '27211', '5670843', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '星見町', 'ホシミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市大同町', '27', '27211', '5670844', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '大同町', 'ダイドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市平田', '27', '27211', '5670845', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '平田', 'ヒラタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市玉島', '27', '27211', '5670846', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '玉島', 'タマシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市野々宮', '27', '27211', '5670847', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '野々宮', 'ノノミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市玉島台', '27', '27211', '5670848', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '玉島台', 'タマシマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市平田台', '27', '27211', '5670849', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '平田台', 'ヒラタダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市真砂', '27', '27211', '5670851', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '真砂', 'マサゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市小柳町', '27', '27211', '5670852', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '小柳町', 'コヤナギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市宮島', '27', '27211', '5670853', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '宮島', 'ミヤジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市島', '27', '27211', '5670854', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '島', 'シマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市新和町', '27', '27211', '5670855', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '新和町', 'シンワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市東奈良', '27', '27211', '5670861', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '東奈良', 'ヒガシナラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市美沢町', '27', '27211', '5670862', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '美沢町', 'ミサワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市沢良宜東町', '27', '27211', '5670863', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '沢良宜東町', 'サワラギヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市沢良宜浜', '27', '27211', '5670864', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '沢良宜浜', 'サワラギハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市横江', '27', '27211', '5670865', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '横江', 'ヨコエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市高浜町', '27', '27211', '5670866', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '高浜町', 'タカハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市大正町', '27', '27211', '5670867', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '大正町', 'タイショウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市沢良宜西', '27', '27211', '5670868', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '沢良宜西', 'サワラギニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市岩倉町', '27', '27211', '5670871', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '岩倉町', 'イワクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市新中条町', '27', '27211', '5670872', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '新中条町', 'シンチュウジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市小川町', '27', '27211', '5670873', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '小川町', 'オガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市奈良町', '27', '27211', '5670874', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '奈良町', 'ナラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市若草町', '27', '27211', '5670875', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '若草町', 'ワカクサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市天王', '27', '27211', '5670876', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '天王', 'テンノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市丑寅', '27', '27211', '5670877', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '丑寅', 'ウシトラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市蔵垣内', '27', '27211', '5670878', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '蔵垣内', 'クラカキウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市東宇野辺町', '27', '27211', '5670879', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '東宇野辺町', 'ヒガシウノベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市上中条', '27', '27211', '5670881', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '上中条', 'カミチュウジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市元町', '27', '27211', '5670882', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '元町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市大手町', '27', '27211', '5670883', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '大手町', 'オオテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市新庄町', '27', '27211', '5670884', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '新庄町', 'シンジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市東中条町', '27', '27211', '5670885', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '東中条町', 'ヒガシチュウジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市下中条町', '27', '27211', '5670886', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '下中条町', 'シモチュウジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市西中条町', '27', '27211', '5670887', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '西中条町', 'ニシチュウジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市駅前', '27', '27211', '5670888', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '駅前', 'エキマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市水尾', '27', '27211', '5670891', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '水尾', 'ミズオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市並木町', '27', '27211', '5670892', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '並木町', 'ナミキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市玉瀬町', '27', '27211', '5670893', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '玉瀬町', 'タマセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市若園町', '27', '27211', '5670894', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '若園町', 'ワカソノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市玉櫛', '27', '27211', '5670895', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '玉櫛', 'タマクシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市玉水町', '27', '27211', '5670896', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '玉水町', 'タマミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市主原町', '27', '27211', '5670897', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '主原町', 'アルジハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市清阪', '27', '27211', '5680081', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '清阪', 'キヨサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市下音羽', '27', '27211', '5680082', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '下音羽', 'シモオトワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市車作', '27', '27211', '5680083', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '車作', 'クルマツクリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市安元', '27', '27211', '5680084', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '安元', 'ヤスモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市忍頂寺', '27', '27211', '5680085', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '忍頂寺', 'ニンチョウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市上音羽', '27', '27211', '5680086', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '上音羽', 'カミオトワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市銭原', '27', '27211', '5680087', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '銭原', 'ゼニハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市長谷', '27', '27211', '5680088', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '長谷', 'ナガタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市大岩', '27', '27211', '5680091', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '大岩', 'オオイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市生保', '27', '27211', '5680092', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '生保', 'ショウボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市大門寺', '27', '27211', '5680093', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '大門寺', 'ダイモンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市桑原', '27', '27211', '5680094', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '桑原', 'クワノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市佐保', '27', '27211', '5680095', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '佐保', 'サホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市粟生岩阪', '27', '27211', '5680096', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '粟生岩阪', 'アオイワサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市泉原', '27', '27211', '5680097', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '泉原', 'イズハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府茨木市千提寺', '27', '27211', '5680098', '大阪府', 'オオサカフ', '茨木市', 'イバラキシ', '千提寺', 'センダイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市', '27', '27207', '5690000', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('61580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市淀の原町', '27', '27207', '5690001', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '淀の原町', 'ヨドノハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市東上牧', '27', '27207', '5690002', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '東上牧', 'ヒガシカンマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市上牧町', '27', '27207', '5690003', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '上牧町', 'カンマキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市上牧南駅前町', '27', '27207', '5690004', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '上牧南駅前町', 'カンマキミナミエキマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市上牧北駅前町', '27', '27207', '5690005', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '上牧北駅前町', 'カンマキキタエキマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市上牧山手町', '27', '27207', '5690006', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '上牧山手町', 'カンマキヤマテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市神内', '27', '27207', '5690007', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '神内', 'コウナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市道鵜町', '27', '27207', '5690011', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '道鵜町', 'ドウウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市東天川', '27', '27207', '5690012', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '東天川', 'ヒガシアマガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市野田', '27', '27207', '5690013', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '野田', 'ノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市野田東', '27', '27207', '5690014', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '野田東', 'ノダヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市井尻', '27', '27207', '5690015', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '井尻', 'イジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市五領町', '27', '27207', '5690016', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '五領町', 'ゴリョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市前島', '27', '27207', '5690021', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '前島', 'マエシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市須賀町', '27', '27207', '5690022', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '須賀町', 'スガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市松川町', '27', '27207', '5690023', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '松川町', 'マツカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市日向町', '27', '27207', '5690024', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '日向町', 'ヒュウガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市藤の里町', '27', '27207', '5690025', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '藤の里町', 'フジノサトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市天川町', '27', '27207', '5690026', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '天川町', 'アマガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市天川新町', '27', '27207', '5690027', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '天川新町', 'アマガワシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市大冠町', '27', '27207', '5690031', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '大冠町', 'オオカンムリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市東和町', '27', '27207', '5690032', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '東和町', 'トウワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市深沢本町', '27', '27207', '5690033', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '深沢本町', 'フカザワホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市大塚町', '27', '27207', '5690034', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '大塚町', 'オオツカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市深沢町', '27', '27207', '5690035', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '深沢町', 'フカザワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市辻子', '27', '27207', '5690036', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '辻子', 'ズシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市北大樋町', '27', '27207', '5690041', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '北大樋町', 'キタオオヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市南大樋町', '27', '27207', '5690042', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '南大樋町', 'ミナミオオヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市竹の内町', '27', '27207', '5690043', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '竹の内町', 'タケノウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市番田', '27', '27207', '5690044', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '番田', 'バンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市西大樋町', '27', '27207', '5690045', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '西大樋町', 'ニシオオヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市登町', '27', '27207', '5690046', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '登町', 'ノボリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市堤町', '27', '27207', '5690047', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '堤町', 'ツツミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市八幡町', '27', '27207', '5690051', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '八幡町', 'ヤハタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市城東町', '27', '27207', '5690052', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '城東町', 'ジョウトウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市春日町', '27', '27207', '5690053', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '春日町', 'カスガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市若松町', '27', '27207', '5690054', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '若松町', 'ワカマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市西冠', '27', '27207', '5690055', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '西冠', 'ニシカンムリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市城南町', '27', '27207', '5690056', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '城南町', 'ジョウナンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市土橋町', '27', '27207', '5690057', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '土橋町', 'ドバシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市高西町', '27', '27207', '5690061', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '高西町', 'コウサイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市下田部町', '27', '27207', '5690062', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '下田部町', 'シモタナベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市南庄所町', '27', '27207', '5690063', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '南庄所町', 'ミナミショウドコロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市庄所町', '27', '27207', '5690064', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '庄所町', 'ショウドコロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市城西町', '27', '27207', '5690065', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '城西町', 'ジョウサイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市中川町', '27', '27207', '5690066', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '中川町', 'ナカガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市桃園町', '27', '27207', '5690067', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '桃園町', 'トウエンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市城北町', '27', '27207', '5690071', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '城北町', 'ジョウホクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市京口町', '27', '27207', '5690072', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '京口町', 'キョウグチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市上本町', '27', '27207', '5690073', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '上本町', 'カミホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市本町', '27', '27207', '5690074', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市城内町', '27', '27207', '5690075', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '城内町', 'ジョウナイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市出丸町', '27', '27207', '5690076', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '出丸町', 'デマルチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市野見町', '27', '27207', '5690077', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '野見町', 'ノミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市大手町', '27', '27207', '5690078', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '大手町', 'オオテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市宮野町', '27', '27207', '5690081', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '宮野町', 'ミヤノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市明野町', '27', '27207', '5690082', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '明野町', 'アケノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市永楽町', '27', '27207', '5690083', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '永楽町', 'エイラクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市沢良木町', '27', '27207', '5690084', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '沢良木町', 'サワラギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市南松原町', '27', '27207', '5690085', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '南松原町', 'ミナミマツバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市松原町', '27', '27207', '5690086', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '松原町', 'マツバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市千代田町', '27', '27207', '5690087', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '千代田町', 'チヨダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市天王町', '27', '27207', '5690088', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '天王町', 'テンノウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市梶原', '27', '27207', '5690091', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '梶原', 'カジハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市梶原中村町', '27', '27207', '5690092', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '梶原中村町', 'カジハラナカムラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市萩之庄', '27', '27207', '5690093', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '萩之庄', 'ハギノショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市緑町', '27', '27207', '5690094', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '緑町', 'ミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市八丁西町', '27', '27207', '5690095', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '八丁西町', 'ハッチョウニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市八丁畷町', '27', '27207', '5690096', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '八丁畷町', 'ハッチョウナワテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市高垣町', '27', '27207', '5690097', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '高垣町', 'タカガキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市大学町', '27', '27207', '5690801', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '大学町', 'ダイガクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市北園町', '27', '27207', '5690802', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '北園町', 'キタソノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市高槻町', '27', '27207', '5690803', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '高槻町', 'タカツキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市紺屋町', '27', '27207', '5690804', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '紺屋町', 'コンヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市上田辺町', '27', '27207', '5690805', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '上田辺町', 'カミタナベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市明田町', '27', '27207', '5690806', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '明田町', 'アケタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市桜町', '27', '27207', '5690807', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '桜町', 'サクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市東五百住町', '27', '27207', '5690811', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '東五百住町', 'ヒガシヨスミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市登美の里町', '27', '27207', '5690812', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '登美の里町', 'トミノサトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市西五百住町', '27', '27207', '5690813', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '西五百住町', 'ニシヨスミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市富田町', '27', '27207', '5690814', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '富田町', 'トンダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市昭和台町', '27', '27207', '5690815', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '昭和台町', 'ショウワダイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市北昭和台町', '27', '27207', '5690816', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '北昭和台町', 'キタショウワダイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市桜ケ丘北町', '27', '27207', '5690817', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '桜ケ丘北町', 'サクラガオカキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市桜ケ丘南町', '27', '27207', '5690818', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '桜ケ丘南町', 'サクラガオカミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市津之江北町', '27', '27207', '5690821', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '津之江北町', 'ツノエキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市津之江町', '27', '27207', '5690822', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '津之江町', 'ツノエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市芝生町', '27', '27207', '5690823', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '芝生町', 'シボウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市川添', '27', '27207', '5690824', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '川添', 'カワゾエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市栄町', '27', '27207', '5690825', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市寿町', '27', '27207', '5690826', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '寿町', 'コトブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市如是町', '27', '27207', '5690827', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '如是町', 'ニョゼチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市唐崎北', '27', '27207', '5690831', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '唐崎北', 'カラサキキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市唐崎中', '27', '27207', '5690832', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '唐崎中', 'カラサキナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市唐崎南', '27', '27207', '5690833', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '唐崎南', 'カラサキミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市唐崎', '27', '27207', '5690834', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '唐崎', 'カラサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市三島江', '27', '27207', '5690835', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '三島江', 'ミシマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市唐崎西', '27', '27207', '5690836', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '唐崎西', 'カラサキニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市西面北', '27', '27207', '5690841', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '西面北', 'サイメキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市西面中', '27', '27207', '5690842', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '西面中', 'サイメナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市三箇牧', '27', '27207', '5690843', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '三箇牧', 'サンガマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市柱本', '27', '27207', '5690844', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '柱本', 'ハシラモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市柱本南町', '27', '27207', '5690845', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '柱本南町', 'ハシラモトミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市柱本新町', '27', '27207', '5690846', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '柱本新町', 'ハシラモトシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市西面南', '27', '27207', '5690847', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '西面南', 'サイメミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市南総持寺町', '27', '27207', '5690851', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '南総持寺町', 'ミナミソウジジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市北柳川町', '27', '27207', '5690852', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '北柳川町', 'キタヤナガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市柳川町', '27', '27207', '5690853', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '柳川町', 'ヤナガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市西町', '27', '27207', '5690854', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '西町', 'ニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市牧田町', '27', '27207', '5690855', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '牧田町', 'マキタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市玉川新町', '27', '27207', '5690856', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '玉川新町', 'タマガワシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市玉川', '27', '27207', '5690857', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '玉川', 'タマガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市中畑', '27', '27207', '5691001', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '中畑', 'ナカハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市田能', '27', '27207', '5691002', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '田能', 'タノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市出灰', '27', '27207', '5691003', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '出灰', 'イズリハ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市二料', '27', '27207', '5691004', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '二料', 'ニリョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市杉生', '27', '27207', '5691005', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '杉生', 'スギオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市川久保', '27', '27207', '5691011', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '川久保', 'カワクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市成合', '27', '27207', '5691012', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '成合', 'ナリアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市成合南の町', '27', '27207', '5691013', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '成合南の町', 'ナリアイミナミノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市成合東の町', '27', '27207', '5691014', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '成合東の町', 'ナリアイヒガシノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市成合中の町', '27', '27207', '5691015', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '成合中の町', 'ナリアイナカノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市成合西の町', '27', '27207', '5691016', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '成合西の町', 'ナリアイニシノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市成合北の町', '27', '27207', '5691017', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '成合北の町', 'ナリアイキタノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市花林苑', '27', '27207', '5691018', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '花林苑', 'カリンエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市高見台', '27', '27207', '5691020', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '高見台', 'タカミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市弥生が丘町', '27', '27207', '5691021', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '弥生が丘町', 'ヤヨイガオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市日吉台', '27', '27207', '5691022', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '日吉台', 'ヒヨシダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市宮が谷町', '27', '27207', '5691023', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '宮が谷町', 'ミヤガダニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市寺谷町', '27', '27207', '5691024', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '寺谷町', 'テラタニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市芝谷町', '27', '27207', '5691025', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '芝谷町', 'シバタニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市緑が丘', '27', '27207', '5691026', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '緑が丘', 'ミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市浦堂', '27', '27207', '5691027', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '浦堂', 'ウラドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市浦堂本町', '27', '27207', '5691028', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '浦堂本町', 'ウラドウホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市安岡寺町', '27', '27207', '5691029', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '安岡寺町', 'アンコウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市松が丘', '27', '27207', '5691031', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '松が丘', 'マツガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市宮之川原', '27', '27207', '5691032', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '宮之川原', 'ミヤノカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市宮之川原元町', '27', '27207', '5691033', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '宮之川原元町', 'ミヤノカワラモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市大蔵司', '27', '27207', '5691034', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '大蔵司', 'ダイゾウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市西之川原', '27', '27207', '5691035', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '西之川原', 'ニシノカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市塚脇', '27', '27207', '5691036', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '塚脇', 'ツカワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市東城山町', '27', '27207', '5691037', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '東城山町', 'ヒガシシロヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市黄金の里', '27', '27207', '5691038', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '黄金の里', 'コガネノサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市清水台', '27', '27207', '5691039', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '清水台', 'シミズダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市奈佐原', '27', '27207', '5691041', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '奈佐原', 'ナサハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市南平台', '27', '27207', '5691042', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '南平台', 'ナンペイダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市奈佐原元町', '27', '27207', '5691043', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '奈佐原元町', 'ナサハラモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市上土室', '27', '27207', '5691044', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '上土室', 'カミハムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市阿武野', '27', '27207', '5691045', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '阿武野', 'アブノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市塚原', '27', '27207', '5691046', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '塚原', 'ツカハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市大和', '27', '27207', '5691047', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '大和', 'ダイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市原', '27', '27207', '5691051', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '原', 'ハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市霊仙寺町', '27', '27207', '5691052', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '霊仙寺町', 'リョウゼンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市萩谷月見台', '27', '27207', '5691053', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '萩谷月見台', 'ハギタニツキミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市萩谷', '27', '27207', '5691054', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '萩谷', 'ハギタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市安満御所の町', '27', '27207', '5691101', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '安満御所の町', 'アマゴショノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市安満磐手町', '27', '27207', '5691102', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '安満磐手町', 'アマイワテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市山手町', '27', '27207', '5691103', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '山手町', 'ヤマテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市安満東の町', '27', '27207', '5691104', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '安満東の町', 'アマヒガシノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市安満中の町', '27', '27207', '5691105', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '安満中の町', 'アマナカノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市安満新町', '27', '27207', '5691106', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '安満新町', 'アマシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市安満西の町', '27', '27207', '5691107', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '安満西の町', 'アマニシノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市安満北の町', '27', '27207', '5691108', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '安満北の町', 'アマキタノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市紅茸町', '27', '27207', '5691109', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '紅茸町', 'ベニタケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市美しが丘', '27', '27207', '5691111', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '美しが丘', 'ウツクシガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市別所本町', '27', '27207', '5691112', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '別所本町', 'ベッシヨホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市別所中の町', '27', '27207', '5691113', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '別所中の町', 'ベッシヨナカノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市別所新町', '27', '27207', '5691114', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '別所新町', 'ベッシヨシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市古曽部町', '27', '27207', '5691115', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '古曽部町', 'コソベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市白梅町', '27', '27207', '5691116', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '白梅町', 'ハクバイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市天神町', '27', '27207', '5691117', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '天神町', 'テンジンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市奥天神町', '27', '27207', '5691118', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '奥天神町', 'オクテンジンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市真上町', '27', '27207', '5691121', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '真上町', 'マカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市月見町', '27', '27207', '5691122', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '月見町', 'ツキミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市芥川町', '27', '27207', '5691123', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '芥川町', 'アクタガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市南芥川町', '27', '27207', '5691124', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '南芥川町', 'ミナミアクタガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市紫町', '27', '27207', '5691125', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '紫町', 'ムラサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市殿町', '27', '27207', '5691126', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '殿町', 'トノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市西真上', '27', '27207', '5691127', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '西真上', 'ニシマカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市名神町', '27', '27207', '5691128', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '名神町', 'メイシンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市郡家本町', '27', '27207', '5691131', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '郡家本町', 'グンゲホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市清福寺町', '27', '27207', '5691132', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '清福寺町', 'セイフクジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市川西町', '27', '27207', '5691133', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '川西町', 'カワニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市朝日町', '27', '27207', '5691134', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '朝日町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市今城町', '27', '27207', '5691135', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '今城町', 'イマシロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市郡家新町', '27', '27207', '5691136', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '郡家新町', 'グンゲシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市岡本町', '27', '27207', '5691137', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '岡本町', 'オカモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市氷室町', '27', '27207', '5691141', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '氷室町', 'ヒムロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市宮田町', '27', '27207', '5691142', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '宮田町', 'ミヤダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市幸町', '27', '27207', '5691143', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市大畑町', '27', '27207', '5691144', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '大畑町', 'オオハタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市富田丘町', '27', '27207', '5691145', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '富田丘町', 'トンダオカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市赤大路町', '27', '27207', '5691146', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '赤大路町', 'アカオオジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高槻市土室町', '27', '27207', '5691147', '大阪府', 'オオサカフ', '高槻市', 'タカツキシ', '土室町', 'ハムロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道浦河郡浦河町', '01', '01607', '0570000', '北海道', 'ホッカイドウ', '浦河郡浦河町', 'ウラカワグンウラカワチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('61805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府守口市', '27', '27209', '5700000', '大阪府', 'オオサカフ', '守口市', 'モリグチシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('61806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府守口市佐太西町', '27', '27209', '5700001', '大阪府', 'オオサカフ', '守口市', 'モリグチシ', '佐太西町', 'サタニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府守口市佐太中町', '27', '27209', '5700002', '大阪府', 'オオサカフ', '守口市', 'モリグチシ', '佐太中町', 'サタナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府守口市大日町', '27', '27209', '5700003', '大阪府', 'オオサカフ', '守口市', 'モリグチシ', '大日町', 'ダイニチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府守口市淀江町', '27', '27209', '5700004', '大阪府', 'オオサカフ', '守口市', 'モリグチシ', '淀江町', 'ヨドエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府守口市八雲中町', '27', '27209', '5700005', '大阪府', 'オオサカフ', '守口市', 'モリグチシ', '八雲中町', 'ヤグモナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府守口市八雲西町', '27', '27209', '5700006', '大阪府', 'オオサカフ', '守口市', 'モリグチシ', '八雲西町', 'ヤグモニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府守口市下島町', '27', '27209', '5700007', '大阪府', 'オオサカフ', '守口市', 'モリグチシ', '下島町', 'シモジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府守口市八雲北町', '27', '27209', '5700008', '大阪府', 'オオサカフ', '守口市', 'モリグチシ', '八雲北町', 'ヤグモキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府守口市大庭町', '27', '27209', '5700009', '大阪府', 'オオサカフ', '守口市', 'モリグチシ', '大庭町', 'オオバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道浦河郡浦河町東幌別', '01', '01607', '0570001', '北海道', 'ホッカイドウ', '浦河郡浦河町', 'ウラカワグンウラカワチョウ', '東幌別', 'ヒガシホロベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府守口市金田町', '27', '27209', '5700011', '大阪府', 'オオサカフ', '守口市', 'モリグチシ', '金田町', 'キンダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府守口市大久保町', '27', '27209', '5700012', '大阪府', 'オオサカフ', '守口市', 'モリグチシ', '大久保町', 'オオクボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府守口市東町', '27', '27209', '5700013', '大阪府', 'オオサカフ', '守口市', 'モリグチシ', '東町', 'ヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府守口市藤田町', '27', '27209', '5700014', '大阪府', 'オオサカフ', '守口市', 'モリグチシ', '藤田町', 'トウダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府守口市梶町', '27', '27209', '5700015', '大阪府', 'オオサカフ', '守口市', 'モリグチシ', '梶町', 'カジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府守口市大日東町', '27', '27209', '5700016', '大阪府', 'オオサカフ', '守口市', 'モリグチシ', '大日東町', 'ダイニチヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府守口市佐太東町', '27', '27209', '5700017', '大阪府', 'オオサカフ', '守口市', 'モリグチシ', '佐太東町', 'サタヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道浦河郡浦河町西幌別', '01', '01607', '0570002', '北海道', 'ホッカイドウ', '浦河郡浦河町', 'ウラカワグンウラカワチョウ', '西幌別', 'ニシホロベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府守口市八雲東町', '27', '27209', '5700021', '大阪府', 'オオサカフ', '守口市', 'モリグチシ', '八雲東町', 'ヤグモヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府守口市暁町', '27', '27209', '5700022', '大阪府', 'オオサカフ', '守口市', 'モリグチシ', '暁町', 'アカツキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府守口市日向町', '27', '27209', '5700023', '大阪府', 'オオサカフ', '守口市', 'モリグチシ', '日向町', 'ヒュウガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府守口市神木町', '27', '27209', '5700024', '大阪府', 'オオサカフ', '守口市', 'モリグチシ', '神木町', 'カミキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府守口市竜田通', '27', '27209', '5700025', '大阪府', 'オオサカフ', '守口市', 'モリグチシ', '竜田通', 'タツタドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府守口市松月町', '27', '27209', '5700026', '大阪府', 'オオサカフ', '守口市', 'モリグチシ', '松月町', 'ショウゲツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府守口市桜町', '27', '27209', '5700027', '大阪府', 'オオサカフ', '守口市', 'モリグチシ', '桜町', 'サクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府守口市本町', '27', '27209', '5700028', '大阪府', 'オオサカフ', '守口市', 'モリグチシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府守口市来迎町', '27', '27209', '5700029', '大阪府', 'オオサカフ', '守口市', 'モリグチシ', '来迎町', 'ライコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道浦河郡浦河町白泉', '01', '01607', '0570003', '北海道', 'ホッカイドウ', '浦河郡浦河町', 'ウラカワグンウラカワチョウ', '白泉', 'シロイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府守口市橋波東之町', '27', '27209', '5700031', '大阪府', 'オオサカフ', '守口市', 'モリグチシ', '橋波東之町', 'ハシバヒガシノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府守口市菊水通', '27', '27209', '5700032', '大阪府', 'オオサカフ', '守口市', 'モリグチシ', '菊水通', 'キクスイドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府守口市大宮通', '27', '27209', '5700033', '大阪府', 'オオサカフ', '守口市', 'モリグチシ', '大宮通', 'オオミヤドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府守口市西郷通', '27', '27209', '5700034', '大阪府', 'オオサカフ', '守口市', 'モリグチシ', '西郷通', 'サイゴウドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府守口市東光町', '27', '27209', '5700035', '大阪府', 'オオサカフ', '守口市', 'モリグチシ', '東光町', 'トウコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府守口市大枝東町', '27', '27209', '5700036', '大阪府', 'オオサカフ', '守口市', 'モリグチシ', '大枝東町', 'オオエダヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府守口市大枝北町', '27', '27209', '5700037', '大阪府', 'オオサカフ', '守口市', 'モリグチシ', '大枝北町', 'オオエダキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府守口市河原町', '27', '27209', '5700038', '大阪府', 'オオサカフ', '守口市', 'モリグチシ', '河原町', 'カワハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府守口市橋波西之町', '27', '27209', '5700039', '大阪府', 'オオサカフ', '守口市', 'モリグチシ', '橋波西之町', 'ハシバニシノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道浦河郡浦河町月寒', '01', '01607', '0570004', '北海道', 'ホッカイドウ', '浦河郡浦河町', 'ウラカワグンウラカワチョウ', '月寒', 'ツキサップ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府守口市東郷通', '27', '27209', '5700041', '大阪府', 'オオサカフ', '守口市', 'モリグチシ', '東郷通', 'トウゴウドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府守口市寺方錦通', '27', '27209', '5700042', '大阪府', 'オオサカフ', '守口市', 'モリグチシ', '寺方錦通', 'テラカタニシキドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府守口市高瀬旧大枝', '27', '27209', '5700043', '大阪府', 'オオサカフ', '守口市', 'モリグチシ', '高瀬旧大枝', 'タカセキュウオオエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府守口市高瀬旧世木', '27', '27209', '5700043', '大阪府', 'オオサカフ', '守口市', 'モリグチシ', '高瀬旧世木', 'タカセキュウセギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府守口市高瀬旧馬場', '27', '27209', '5700043', '大阪府', 'オオサカフ', '守口市', 'モリグチシ', '高瀬旧馬場', 'タカセキュウババ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府守口市南寺方東通', '27', '27209', '5700043', '大阪府', 'オオサカフ', '守口市', 'モリグチシ', '南寺方東通', 'ミナミテラカタヒガシドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府守口市南寺方南通', '27', '27209', '5700044', '大阪府', 'オオサカフ', '守口市', 'モリグチシ', '南寺方南通', 'ミナミテラカタミナミドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府守口市南寺方中通', '27', '27209', '5700045', '大阪府', 'オオサカフ', '守口市', 'モリグチシ', '南寺方中通', 'ミナミテラカタナカドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府守口市南寺方北通', '27', '27209', '5700046', '大阪府', 'オオサカフ', '守口市', 'モリグチシ', '南寺方北通', 'ミナミテラカタキタドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府守口市寺方元町', '27', '27209', '5700047', '大阪府', 'オオサカフ', '守口市', 'モリグチシ', '寺方元町', 'テラカタモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府守口市寺方本通', '27', '27209', '5700048', '大阪府', 'オオサカフ', '守口市', 'モリグチシ', '寺方本通', 'テラカタホンドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道浦河郡浦河町東町うしお', '01', '01607', '0570005', '北海道', 'ホッカイドウ', '浦河郡浦河町', 'ウラカワグンウラカワチョウ', '東町うしお', 'ヒガシチョウウシオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府守口市大枝南町', '27', '27209', '5700051', '大阪府', 'オオサカフ', '守口市', 'モリグチシ', '大枝南町', 'オオエダミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府守口市松下町', '27', '27209', '5700052', '大阪府', 'オオサカフ', '守口市', 'モリグチシ', '松下町', 'マツシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府守口市高瀬町', '27', '27209', '5700053', '大阪府', 'オオサカフ', '守口市', 'モリグチシ', '高瀬町', 'タカセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府守口市大枝西町', '27', '27209', '5700054', '大阪府', 'オオサカフ', '守口市', 'モリグチシ', '大枝西町', 'オオエダニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府守口市春日町', '27', '27209', '5700055', '大阪府', 'オオサカフ', '守口市', 'モリグチシ', '春日町', 'カスガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府守口市寺内町', '27', '27209', '5700056', '大阪府', 'オオサカフ', '守口市', 'モリグチシ', '寺内町', 'ジナイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道浦河郡浦河町東町かしわ', '01', '01607', '0570006', '北海道', 'ホッカイドウ', '浦河郡浦河町', 'ウラカワグンウラカワチョウ', '東町かしわ', 'ヒガシチョウカシワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府守口市小春町', '27', '27209', '5700061', '大阪府', 'オオサカフ', '守口市', 'モリグチシ', '小春町', 'コハルチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府守口市馬場町', '27', '27209', '5700062', '大阪府', 'オオサカフ', '守口市', 'モリグチシ', '馬場町', 'ババチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府守口市大門町', '27', '27209', '5700063', '大阪府', 'オオサカフ', '守口市', 'モリグチシ', '大門町', 'ダイモンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府守口市長池町', '27', '27209', '5700064', '大阪府', 'オオサカフ', '守口市', 'モリグチシ', '長池町', 'ナガイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府守口市滝井元町', '27', '27209', '5700065', '大阪府', 'オオサカフ', '守口市', 'モリグチシ', '滝井元町', 'タキイモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府守口市梅園町', '27', '27209', '5700066', '大阪府', 'オオサカフ', '守口市', 'モリグチシ', '梅園町', 'ウメゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道浦河郡浦河町東町ちのみ', '01', '01607', '0570007', '北海道', 'ホッカイドウ', '浦河郡浦河町', 'ウラカワグンウラカワチョウ', '東町ちのみ', 'ヒガシチョウチノミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府守口市祝町', '27', '27209', '5700071', '大阪府', 'オオサカフ', '守口市', 'モリグチシ', '祝町', 'イワイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府守口市早苗町', '27', '27209', '5700072', '大阪府', 'オオサカフ', '守口市', 'モリグチシ', '早苗町', 'サナエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府守口市土居町', '27', '27209', '5700073', '大阪府', 'オオサカフ', '守口市', 'モリグチシ', '土居町', 'ドイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府守口市文園町', '27', '27209', '5700074', '大阪府', 'オオサカフ', '守口市', 'モリグチシ', '文園町', 'フミゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府守口市紅屋町', '27', '27209', '5700075', '大阪府', 'オオサカフ', '守口市', 'モリグチシ', '紅屋町', 'ベニヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府守口市滝井西町', '27', '27209', '5700076', '大阪府', 'オオサカフ', '守口市', 'モリグチシ', '滝井西町', 'タキイニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府守口市寿町', '27', '27209', '5700077', '大阪府', 'オオサカフ', '守口市', 'モリグチシ', '寿町', 'コトブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府守口市平代町', '27', '27209', '5700078', '大阪府', 'オオサカフ', '守口市', 'モリグチシ', '平代町', 'ヒラダイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府守口市金下町', '27', '27209', '5700079', '大阪府', 'オオサカフ', '守口市', 'モリグチシ', '金下町', 'カネシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府守口市日吉町', '27', '27209', '5700081', '大阪府', 'オオサカフ', '守口市', 'モリグチシ', '日吉町', 'ヒヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府守口市豊秀町', '27', '27209', '5700082', '大阪府', 'オオサカフ', '守口市', 'モリグチシ', '豊秀町', 'トヨヒデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府守口市京阪本通', '27', '27209', '5700083', '大阪府', 'オオサカフ', '守口市', 'モリグチシ', '京阪本通', 'ケイハンホンドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府守口市緑町', '27', '27209', '5700084', '大阪府', 'オオサカフ', '守口市', 'モリグチシ', '緑町', 'ミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府守口市松町', '27', '27209', '5700085', '大阪府', 'オオサカフ', '守口市', 'モリグチシ', '松町', 'マツマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府守口市竹町', '27', '27209', '5700086', '大阪府', 'オオサカフ', '守口市', 'モリグチシ', '竹町', 'タケマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府守口市梅町', '27', '27209', '5700087', '大阪府', 'オオサカフ', '守口市', 'モリグチシ', '梅町', 'ウメマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府守口市北斗町', '27', '27209', '5700091', '大阪府', 'オオサカフ', '守口市', 'モリグチシ', '北斗町', 'ホクトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府守口市日光町', '27', '27209', '5700092', '大阪府', 'オオサカフ', '守口市', 'モリグチシ', '日光町', 'ニッコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府守口市浜町', '27', '27209', '5700093', '大阪府', 'オオサカフ', '守口市', 'モリグチシ', '浜町', 'ハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府守口市京阪北本通', '27', '27209', '5700094', '大阪府', 'オオサカフ', '守口市', 'モリグチシ', '京阪北本通', 'ケイハンキタホンドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府守口市八島町', '27', '27209', '5700095', '大阪府', 'オオサカフ', '守口市', 'モリグチシ', '八島町', 'ヤシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府守口市外島町', '27', '27209', '5700096', '大阪府', 'オオサカフ', '守口市', 'モリグチシ', '外島町', 'ソトジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府守口市桃町', '27', '27209', '5700097', '大阪府', 'オオサカフ', '守口市', 'モリグチシ', '桃町', 'モモマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府守口市新橋寺町', '27', '27209', '5700098', '大阪府', 'オオサカフ', '守口市', 'モリグチシ', '新橋寺町', 'シンハシデラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道浦河郡浦河町旭町', '01', '01607', '0570011', '北海道', 'ホッカイドウ', '浦河郡浦河町', 'ウラカワグンウラカワチョウ', '旭町', 'アサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道浦河郡浦河町常盤町', '01', '01607', '0570012', '北海道', 'ホッカイドウ', '浦河郡浦河町', 'ウラカワグンウラカワチョウ', '常盤町', 'トキワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道浦河郡浦河町大通', '01', '01607', '0570013', '北海道', 'ホッカイドウ', '浦河郡浦河町', 'ウラカワグンウラカワチョウ', '大通', 'オオドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道浦河郡浦河町入船町', '01', '01607', '0570014', '北海道', 'ホッカイドウ', '浦河郡浦河町', 'ウラカワグンウラカワチョウ', '入船町', 'イリフネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道浦河郡浦河町浜町', '01', '01607', '0570015', '北海道', 'ホッカイドウ', '浦河郡浦河町', 'ウラカワグンウラカワチョウ', '浜町', 'ハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道浦河郡浦河町潮見町', '01', '01607', '0570021', '北海道', 'ホッカイドウ', '浦河郡浦河町', 'ウラカワグンウラカワチョウ', '潮見町', 'シオミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道浦河郡浦河町昌平町', '01', '01607', '0570022', '北海道', 'ホッカイドウ', '浦河郡浦河町', 'ウラカワグンウラカワチョウ', '昌平町', 'ショウヘイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道浦河郡浦河町栄丘', '01', '01607', '0570023', '北海道', 'ホッカイドウ', '浦河郡浦河町', 'ウラカワグンウラカワチョウ', '栄丘', 'サカエオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道浦河郡浦河町築地', '01', '01607', '0570024', '北海道', 'ホッカイドウ', '浦河郡浦河町', 'ウラカワグンウラカワチョウ', '築地', 'ツキジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道浦河郡浦河町緑町', '01', '01607', '0570025', '北海道', 'ホッカイドウ', '浦河郡浦河町', 'ウラカワグンウラカワチョウ', '緑町', 'ミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道浦河郡浦河町向別', '01', '01607', '0570026', '北海道', 'ホッカイドウ', '浦河郡浦河町', 'ウラカワグンウラカワチョウ', '向別', 'ムコウベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道浦河郡浦河町上向別', '01', '01607', '0570027', '北海道', 'ホッカイドウ', '浦河郡浦河町', 'ウラカワグンウラカワチョウ', '上向別', 'カミムコウベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道浦河郡浦河町向が丘東', '01', '01607', '0570031', '北海道', 'ホッカイドウ', '浦河郡浦河町', 'ウラカワグンウラカワチョウ', '向が丘東', 'ムコウガオカヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道浦河郡浦河町向が丘西', '01', '01607', '0570032', '北海道', 'ホッカイドウ', '浦河郡浦河町', 'ウラカワグンウラカワチョウ', '向が丘西', 'ムコウガオカニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道浦河郡浦河町堺町東', '01', '01607', '0570033', '北海道', 'ホッカイドウ', '浦河郡浦河町', 'ウラカワグンウラカワチョウ', '堺町東', 'サカイマチヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道浦河郡浦河町堺町西', '01', '01607', '0570034', '北海道', 'ホッカイドウ', '浦河郡浦河町', 'ウラカワグンウラカワチョウ', '堺町西', 'サカイマチニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道浦河郡浦河町井寒台', '01', '01607', '0570035', '北海道', 'ホッカイドウ', '浦河郡浦河町', 'ウラカワグンウラカワチョウ', '井寒台', 'イカンタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道浦河郡浦河町絵笛', '01', '01607', '0570036', '北海道', 'ホッカイドウ', '浦河郡浦河町', 'ウラカワグンウラカワチョウ', '絵笛', 'エブエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道浦河郡浦河町西舎', '01', '01607', '0570171', '北海道', 'ホッカイドウ', '浦河郡浦河町', 'ウラカワグンウラカワチョウ', '西舎', 'ニシチャ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道浦河郡浦河町杵臼', '01', '01607', '0570172', '北海道', 'ホッカイドウ', '浦河郡浦河町', 'ウラカワグンウラカワチョウ', '杵臼', 'キネウス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道浦河郡浦河町上杵臼', '01', '01607', '0570173', '北海道', 'ホッカイドウ', '浦河郡浦河町', 'ウラカワグンウラカワチョウ', '上杵臼', 'カミキネウス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道浦河郡浦河町上西舎', '01', '01607', '0570174', '北海道', 'ホッカイドウ', '浦河郡浦河町', 'ウラカワグンウラカワチョウ', '上西舎', 'カミニシチャ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府門真市', '27', '27223', '5710000', '大阪府', 'オオサカフ', '門真市', 'カドマシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('61935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府門真市巣本', '27', '27223', '5710001', '大阪府', 'オオサカフ', '門真市', 'カドマシ', '巣本', 'スモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府門真市巣本町', '27', '27223', '5710001', '大阪府', 'オオサカフ', '門真市', 'カドマシ', '巣本町', 'スモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府門真市岸和田', '27', '27223', '5710002', '大阪府', 'オオサカフ', '門真市', 'カドマシ', '岸和田', 'キシワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府門真市下馬伏', '27', '27223', '5710003', '大阪府', 'オオサカフ', '門真市', 'カドマシ', '下馬伏', 'シモマブシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府門真市上島頭', '27', '27223', '5710004', '大阪府', 'オオサカフ', '門真市', 'カドマシ', '上島頭', 'カミシマガシラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府門真市下島頭', '27', '27223', '5710004', '大阪府', 'オオサカフ', '門真市', 'カドマシ', '下島頭', 'シモシマガシラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府門真市南野口町', '27', '27223', '5710005', '大阪府', 'オオサカフ', '門真市', 'カドマシ', '南野口町', 'ミナミノグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府門真市上馬伏', '27', '27223', '5710006', '大阪府', 'オオサカフ', '門真市', 'カドマシ', '上馬伏', 'カミマブシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府門真市北岸和田', '27', '27223', '5710007', '大阪府', 'オオサカフ', '門真市', 'カドマシ', '北岸和田', 'キタキシワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府門真市東江端町', '27', '27223', '5710008', '大阪府', 'オオサカフ', '門真市', 'カドマシ', '東江端町', 'ヒガシエバタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府門真市下馬伏町', '27', '27223', '5710009', '大阪府', 'オオサカフ', '門真市', 'カドマシ', '下馬伏町', 'シモマブシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府門真市脇田町', '27', '27223', '5710011', '大阪府', 'オオサカフ', '門真市', 'カドマシ', '脇田町', 'ワキタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府門真市江端町', '27', '27223', '5710012', '大阪府', 'オオサカフ', '門真市', 'カドマシ', '江端町', 'エバタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府門真市千石東町', '27', '27223', '5710013', '大阪府', 'オオサカフ', '門真市', 'カドマシ', '千石東町', 'センゴクヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府門真市千石西町', '27', '27223', '5710014', '大阪府', 'オオサカフ', '門真市', 'カドマシ', '千石西町', 'センゴクニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府門真市三ツ島', '27', '27223', '5710015', '大阪府', 'オオサカフ', '門真市', 'カドマシ', '三ツ島', 'ミツジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府門真市島頭', '27', '27223', '5710016', '大阪府', 'オオサカフ', '門真市', 'カドマシ', '島頭', 'シマガシラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府門真市舟田町', '27', '27223', '5710021', '大阪府', 'オオサカフ', '門真市', 'カドマシ', '舟田町', 'フナダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府門真市沖町', '27', '27223', '5710022', '大阪府', 'オオサカフ', '門真市', 'カドマシ', '沖町', 'オキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府門真市横地', '27', '27223', '5710023', '大阪府', 'オオサカフ', '門真市', 'カドマシ', '横地', 'ヨコチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府門真市野口', '27', '27223', '5710024', '大阪府', 'オオサカフ', '門真市', 'カドマシ', '野口', 'ノグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府門真市北島', '27', '27223', '5710025', '大阪府', 'オオサカフ', '門真市', 'カドマシ', '北島', 'キタジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府門真市北島町', '27', '27223', '5710026', '大阪府', 'オオサカフ', '門真市', 'カドマシ', '北島町', 'キタジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府門真市五月田町', '27', '27223', '5710027', '大阪府', 'オオサカフ', '門真市', 'カドマシ', '五月田町', 'サツキダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府門真市打越', '27', '27223', '5710028', '大阪府', 'オオサカフ', '門真市', 'カドマシ', '打越', 'ウチコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府門真市打越町', '27', '27223', '5710029', '大阪府', 'オオサカフ', '門真市', 'カドマシ', '打越町', 'ウチコシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府門真市末広町', '27', '27223', '5710030', '大阪府', 'オオサカフ', '門真市', 'カドマシ', '末広町', 'スエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府門真市古川町', '27', '27223', '5710031', '大阪府', 'オオサカフ', '門真市', 'カドマシ', '古川町', 'フルカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府門真市寿町', '27', '27223', '5710032', '大阪府', 'オオサカフ', '門真市', 'カドマシ', '寿町', 'コトブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府門真市一番町', '27', '27223', '5710033', '大阪府', 'オオサカフ', '門真市', 'カドマシ', '一番町', 'イチバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府門真市東田町', '27', '27223', '5710034', '大阪府', 'オオサカフ', '門真市', 'カドマシ', '東田町', 'ヒガシダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府門真市桑才', '27', '27223', '5710035', '大阪府', 'オオサカフ', '門真市', 'カドマシ', '桑才', 'クワザイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府門真市三番', '27', '27223', '5710036', '大阪府', 'オオサカフ', '門真市', 'カドマシ', '三番', 'サンバン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府門真市ひえ島', '27', '27223', '5710037', '大阪府', 'オオサカフ', '門真市', 'カドマシ', 'ひえ島', 'ヒエジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府門真市柳田町', '27', '27223', '5710038', '大阪府', 'オオサカフ', '門真市', 'カドマシ', '柳田町', 'ヤナギダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府門真市速見町', '27', '27223', '5710039', '大阪府', 'オオサカフ', '門真市', 'カドマシ', '速見町', 'ハヤミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府門真市柳町', '27', '27223', '5710041', '大阪府', 'オオサカフ', '門真市', 'カドマシ', '柳町', 'ヤナギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府門真市深田町', '27', '27223', '5710042', '大阪府', 'オオサカフ', '門真市', 'カドマシ', '深田町', 'フカダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府門真市桑才新町', '27', '27223', '5710043', '大阪府', 'オオサカフ', '門真市', 'カドマシ', '桑才新町', 'クワザイシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府門真市松生町', '27', '27223', '5710044', '大阪府', 'オオサカフ', '門真市', 'カドマシ', '松生町', 'マツオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府門真市殿島町', '27', '27223', '5710045', '大阪府', 'オオサカフ', '門真市', 'カドマシ', '殿島町', 'トノシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府門真市本町', '27', '27223', '5710046', '大阪府', 'オオサカフ', '門真市', 'カドマシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府門真市栄町', '27', '27223', '5710047', '大阪府', 'オオサカフ', '門真市', 'カドマシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府門真市新橋町', '27', '27223', '5710048', '大阪府', 'オオサカフ', '門真市', 'カドマシ', '新橋町', 'シンバシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府門真市門真', '27', '27223', '5710050', '大阪府', 'オオサカフ', '門真市', 'カドマシ', '門真', 'カドマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府門真市向島町', '27', '27223', '5710051', '大阪府', 'オオサカフ', '門真市', 'カドマシ', '向島町', 'ムコウジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府門真市月出町', '27', '27223', '5710052', '大阪府', 'オオサカフ', '門真市', 'カドマシ', '月出町', 'ツキデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府門真市泉町', '27', '27223', '5710053', '大阪府', 'オオサカフ', '門真市', 'カドマシ', '泉町', 'イズミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府門真市浜町', '27', '27223', '5710054', '大阪府', 'オオサカフ', '門真市', 'カドマシ', '浜町', 'ハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府門真市中町', '27', '27223', '5710055', '大阪府', 'オオサカフ', '門真市', 'カドマシ', '中町', 'ナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府門真市松葉町', '27', '27223', '5710056', '大阪府', 'オオサカフ', '門真市', 'カドマシ', '松葉町', 'マツバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府門真市元町', '27', '27223', '5710057', '大阪府', 'オオサカフ', '門真市', 'カドマシ', '元町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府門真市小路町', '27', '27223', '5710058', '大阪府', 'オオサカフ', '門真市', 'カドマシ', '小路町', 'ショウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府門真市堂山町', '27', '27223', '5710059', '大阪府', 'オオサカフ', '門真市', 'カドマシ', '堂山町', 'ドウヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府門真市朝日町', '27', '27223', '5710061', '大阪府', 'オオサカフ', '門真市', 'カドマシ', '朝日町', 'アサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府門真市宮野町', '27', '27223', '5710062', '大阪府', 'オオサカフ', '門真市', 'カドマシ', '宮野町', 'ミヤノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府門真市常称寺町', '27', '27223', '5710063', '大阪府', 'オオサカフ', '門真市', 'カドマシ', '常称寺町', 'ジョウショウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府門真市御堂町', '27', '27223', '5710064', '大阪府', 'オオサカフ', '門真市', 'カドマシ', '御堂町', 'ミドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府門真市垣内町', '27', '27223', '5710065', '大阪府', 'オオサカフ', '門真市', 'カドマシ', '垣内町', 'カキウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府門真市幸福町', '27', '27223', '5710066', '大阪府', 'オオサカフ', '門真市', 'カドマシ', '幸福町', 'コウフクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府門真市石原町', '27', '27223', '5710067', '大阪府', 'オオサカフ', '門真市', 'カドマシ', '石原町', 'イシハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府門真市大倉町', '27', '27223', '5710068', '大阪府', 'オオサカフ', '門真市', 'カドマシ', '大倉町', 'オオクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府門真市上野口町', '27', '27223', '5710070', '大阪府', 'オオサカフ', '門真市', 'カドマシ', '上野口町', 'カミノグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府門真市上島町', '27', '27223', '5710071', '大阪府', 'オオサカフ', '門真市', 'カドマシ', '上島町', 'カミシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('61999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府門真市城垣町', '27', '27223', '5710072', '大阪府', 'オオサカフ', '門真市', 'カドマシ', '城垣町', 'シロガキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府門真市北巣本町', '27', '27223', '5710073', '大阪府', 'オオサカフ', '門真市', 'カドマシ', '北巣本町', 'キタスモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府門真市宮前町', '27', '27223', '5710074', '大阪府', 'オオサカフ', '門真市', 'カドマシ', '宮前町', 'ミヤマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府門真市下島町', '27', '27223', '5710075', '大阪府', 'オオサカフ', '門真市', 'カドマシ', '下島町', 'シモシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府門真市大池町', '27', '27223', '5710076', '大阪府', 'オオサカフ', '門真市', 'カドマシ', '大池町', 'オオイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府門真市大橋町', '27', '27223', '5710077', '大阪府', 'オオサカフ', '門真市', 'カドマシ', '大橋町', 'オオハシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府門真市常盤町', '27', '27223', '5710078', '大阪府', 'オオサカフ', '門真市', 'カドマシ', '常盤町', 'トキワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府門真市野里町', '27', '27223', '5710079', '大阪府', 'オオサカフ', '門真市', 'カドマシ', '野里町', 'ノザトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市', '27', '27215', '5720000', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('62019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市成田東町', '27', '27215', '5720001', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '成田東町', 'ナリタヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市成田東が丘', '27', '27215', '5720002', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '成田東が丘', 'ナリタヒガシガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市成田南町', '27', '27215', '5720003', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '成田南町', 'ナリタミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市成田町', '27', '27215', '5720004', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '成田町', 'ナリタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市成田西町', '27', '27215', '5720005', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '成田西町', 'ナリタニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市美井元町', '27', '27215', '5720006', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '美井元町', 'ミイモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市美井町', '27', '27215', '5720007', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '美井町', 'ミイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市菅相塚町', '27', '27215', '5720008', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '菅相塚町', 'カンソウヅカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市末広町', '27', '27215', '5720009', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '末広町', 'スエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市明徳', '27', '27215', '5720011', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '明徳', 'メイトク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市池の瀬町', '27', '27215', '5720012', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '池の瀬町', 'イケノセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市三井が丘', '27', '27215', '5720013', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '三井が丘', 'ミイガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市八幡台', '27', '27215', '5720014', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '八幡台', 'ハチマンダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市川勝町', '27', '27215', '5720015', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '川勝町', 'カワカツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市国松町', '27', '27215', '5720016', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '国松町', 'クニマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市幸町', '27', '27215', '5720017', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市境橋町', '27', '27215', '5720018', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '境橋町', 'サカイバシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市三井南町', '27', '27215', '5720019', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '三井南町', 'ミイミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市田井西町', '27', '27215', '5720020', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '田井西町', 'タイニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市田井町', '27', '27215', '5720021', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '田井町', 'タイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市緑町', '27', '27215', '5720022', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '緑町', 'ミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市音羽町', '27', '27215', '5720023', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '音羽町', 'オトワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市石津南町', '27', '27215', '5720024', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '石津南町', 'イシヅミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市石津元町', '27', '27215', '5720025', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '石津元町', 'イシヅモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市石津中町', '27', '27215', '5720026', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '石津中町', 'イシヅナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市石津東町', '27', '27215', '5720027', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '石津東町', 'イシヅヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市日新町', '27', '27215', '5720028', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '日新町', 'ニッシンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市寿町', '27', '27215', '5720029', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '寿町', 'コトブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市池田本町', '27', '27215', '5720030', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '池田本町', 'イケダホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市若葉町', '27', '27215', '5720031', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '若葉町', 'ワカバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市北大利町', '27', '27215', '5720032', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '北大利町', 'キタオオトシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市池田東町', '27', '27215', '5720033', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '池田東町', 'イケダヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市池田南町', '27', '27215', '5720034', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '池田南町', 'イケダミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市池田旭町', '27', '27215', '5720035', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '池田旭町', 'イケダアサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市池田西町', '27', '27215', '5720036', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '池田西町', 'イケダニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市葛原新町', '27', '27215', '5720037', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '葛原新町', 'クズハラシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市池田新町', '27', '27215', '5720038', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '池田新町', 'イケダシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市池田', '27', '27215', '5720039', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '池田', 'イケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市桜木町', '27', '27215', '5720041', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '桜木町', 'サクラギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市東大利町', '27', '27215', '5720042', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '東大利町', 'ヒガシオオトシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市錦町', '27', '27215', '5720043', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '錦町', 'ニシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市清水町', '27', '27215', '5720044', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '清水町', 'シミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市東神田町', '27', '27215', '5720045', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '東神田町', 'ヒガシカミダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市成美町', '27', '27215', '5720046', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '成美町', 'セイビチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市大利元町', '27', '27215', '5720047', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '大利元町', 'オオトシモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市大利町', '27', '27215', '5720048', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '大利町', 'オオトシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市黒原城内町', '27', '27215', '5720050', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '黒原城内町', 'クロハラジョウナイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市高柳', '27', '27215', '5720051', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '高柳', 'タカヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市上神田', '27', '27215', '5720052', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '上神田', 'カミカミダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市中神田町', '27', '27215', '5720053', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '中神田町', 'ナカカミダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市下神田町', '27', '27215', '5720054', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '下神田町', 'シモカミダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市御幸東町', '27', '27215', '5720055', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '御幸東町', 'ミユキヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市御幸西町', '27', '27215', '5720056', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '御幸西町', 'ミユキニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市黒原旭町', '27', '27215', '5720057', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '黒原旭町', 'クロハラアサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市黒原橘町', '27', '27215', '5720058', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '黒原橘町', 'クロハラタチバナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市黒原新町', '27', '27215', '5720059', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '黒原新町', 'クロハラシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市長栄寺町', '27', '27215', '5720061', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '長栄寺町', 'チョウエイジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市高柳栄町', '27', '27215', '5720062', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '高柳栄町', 'タカヤナギサカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市春日町', '27', '27215', '5720063', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '春日町', 'カスガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市対馬江東町', '27', '27215', '5720064', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '対馬江東町', 'ツシマエヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市対馬江西町', '27', '27215', '5720065', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '対馬江西町', 'ツシマエニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市仁和寺町', '27', '27215', '5720066', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '仁和寺町', 'ニワジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市宝町', '27', '27215', '5720067', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '宝町', 'タカラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市豊里町', '27', '27215', '5720071', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '豊里町', 'トヨザトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市太間東町', '27', '27215', '5720072', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '太間東町', 'タイマヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市池田北町', '27', '27215', '5720073', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '池田北町', 'イケダキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市池田中町', '27', '27215', '5720074', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '池田中町', 'イケダナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市葛原', '27', '27215', '5720075', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '葛原', 'クズハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市仁和寺本町', '27', '27215', '5720076', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '仁和寺本町', 'ニワジホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市点野', '27', '27215', '5720077', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '点野', 'シメノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市太間町', '27', '27215', '5720078', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '太間町', 'タイマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市香里北之町', '27', '27215', '5720080', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '香里北之町', 'コオリキタノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市東香里園町', '27', '27215', '5720081', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '東香里園町', 'ヒガシコオリエンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市香里本通町', '27', '27215', '5720082', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '香里本通町', 'コオリホンドオリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市郡元町', '27', '27215', '5720083', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '郡元町', 'コオリモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市香里南之町', '27', '27215', '5720084', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '香里南之町', 'コオリミナミノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市香里新町', '27', '27215', '5720085', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '香里新町', 'コオリシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市松屋町', '27', '27215', '5720086', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '松屋町', 'マツヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市木屋町', '27', '27215', '5720087', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '木屋町', 'コヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市木屋元町', '27', '27215', '5720088', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '木屋元町', 'コヤモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市香里西之町', '27', '27215', '5720089', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '香里西之町', 'コオリニシノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市寝屋', '27', '27215', '5720801', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '寝屋', 'ネヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市梅が丘', '27', '27215', '5720803', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '梅が丘', 'ウメガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市高宮', '27', '27215', '5720806', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '高宮', 'タカミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市堀溝北町', '27', '27215', '5720810', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '堀溝北町', 'ホリミゾキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市楠根南町', '27', '27215', '5720811', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '楠根南町', 'クスネミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市新家', '27', '27215', '5720812', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '新家', 'シンケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市讃良東町', '27', '27215', '5720813', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '讃良東町', 'サンラヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市堀溝', '27', '27215', '5720814', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '堀溝', 'ホリミゾ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市河北東町', '27', '27215', '5720815', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '河北東町', 'カワキタヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市河北中町', '27', '27215', '5720816', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '河北中町', 'カワキタナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市河北西町', '27', '27215', '5720817', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '河北西町', 'カワキタニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市讃良西町', '27', '27215', '5720818', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '讃良西町', 'サンラニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市大成町', '27', '27215', '5720819', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '大成町', 'タイセイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市中木田町', '27', '27215', '5720820', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '中木田町', 'ナカキダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市出雲町', '27', '27215', '5720821', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '出雲町', 'イズモチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市木田元宮', '27', '27215', '5720822', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '木田元宮', 'キダモトミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市下木田町', '27', '27215', '5720823', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '下木田町', 'シモキダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市萱島東', '27', '27215', '5720824', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '萱島東', 'カヤシマヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市萱島南町', '27', '27215', '5720825', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '萱島南町', 'カヤシマミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市南水苑町', '27', '27215', '5720826', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '南水苑町', 'ナンスイエンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市萱島本町', '27', '27215', '5720827', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '萱島本町', 'カヤシマホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市萱島桜園町', '27', '27215', '5720828', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '萱島桜園町', 'カヤシマサクラエンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市萱島信和町', '27', '27215', '5720829', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '萱島信和町', 'カヤシマシンワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市豊野町', '27', '27215', '5720831', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '豊野町', 'トヨノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市本町', '27', '27215', '5720832', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市初町', '27', '27215', '5720833', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '初町', 'ハッチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市昭栄町', '27', '27215', '5720834', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '昭栄町', 'ショウエイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市日之出町', '27', '27215', '5720835', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '日之出町', 'ヒノデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市木田町', '27', '27215', '5720836', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '木田町', 'キダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市早子町', '27', '27215', '5720837', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '早子町', 'ハヤコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市八坂町', '27', '27215', '5720838', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '八坂町', 'ヤサカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市平池町', '27', '27215', '5720839', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '平池町', 'ヒライケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市太秦桜が丘', '27', '27215', '5720840', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '太秦桜が丘', 'ウズマササクラガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市太秦東が丘', '27', '27215', '5720841', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '太秦東が丘', 'ウズマサヒガシガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市太秦高塚町', '27', '27215', '5720842', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '太秦高塚町', 'ウズマサタカツカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市太秦中町', '27', '27215', '5720843', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '太秦中町', 'ウズマサナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市太秦緑が丘', '27', '27215', '5720844', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '太秦緑が丘', 'ウズマサミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市楠根北町', '27', '27215', '5720845', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '楠根北町', 'クスネキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市高宮栄町', '27', '27215', '5720846', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '高宮栄町', 'タカミヤサカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市高宮新町', '27', '27215', '5720847', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '高宮新町', 'タカミヤシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市秦町', '27', '27215', '5720848', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '秦町', 'ハダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市太秦元町', '27', '27215', '5720849', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '太秦元町', 'ウズマサモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市打上高塚町', '27', '27215', '5720850', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '打上高塚町', 'ウチアゲタカツカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市寝屋北町', '27', '27215', '5720851', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '寝屋北町', 'ネヤキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市寝屋新町', '27', '27215', '5720852', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '寝屋新町', 'ネヤシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市大谷町', '27', '27215', '5720853', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '大谷町', 'オオタニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市寝屋川公園', '27', '27215', '5720854', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '寝屋川公園', 'ネヤガワコウエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市寝屋南', '27', '27215', '5720855', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '寝屋南', 'ネヤミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市宇谷町', '27', '27215', '5720856', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '宇谷町', 'ウタニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市打上中町', '27', '27215', '5720857', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '打上中町', 'ウチアゲナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市打上元町', '27', '27215', '5720858', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '打上元町', 'ウチアゲモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市打上新町', '27', '27215', '5720859', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '打上新町', 'ウチアゲシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市打上南町', '27', '27215', '5720861', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '打上南町', 'ウチアゲミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市打上宮前町', '27', '27215', '5720862', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '打上宮前町', 'ウチアゲミヤマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市明和', '27', '27215', '5720863', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '明和', 'メイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市高倉', '27', '27215', '5720864', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '高倉', 'タカクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市小路北町', '27', '27215', '5720865', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '小路北町', 'ショウジキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市小路南町', '27', '27215', '5720866', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '小路南町', 'ショウジミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府寝屋川市高宮あさひ丘', '27', '27215', '5720867', '大阪府', 'オオサカフ', '寝屋川市', 'ネヤガワシ', '高宮あさひ丘', 'タカミヤアサヒオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市', '27', '27210', '5730000', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('62184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市田口山', '27', '27210', '5730001', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '田口山', 'タグチヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市出屋敷元町', '27', '27210', '5730002', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '出屋敷元町', 'デヤシキモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市出屋敷西町', '27', '27210', '5730003', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '出屋敷西町', 'デヤシキニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市中宮大池', '27', '27210', '5730004', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '中宮大池', 'ナカミヤオオイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市池之宮', '27', '27210', '5730005', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '池之宮', 'イケノミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市堂山東町', '27', '27210', '5730006', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '堂山東町', 'ドウヤマヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市堂山', '27', '27210', '5730007', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '堂山', 'ドウヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市中宮山戸町', '27', '27210', '5730011', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '中宮山戸町', 'ナカミヤヤマトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市松丘町', '27', '27210', '5730012', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '松丘町', 'マツガオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市星丘', '27', '27210', '5730013', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '星丘', 'ホシガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市村野高見台', '27', '27210', '5730014', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '村野高見台', 'ムラノタカミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市村野東町', '27', '27210', '5730015', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '村野東町', 'ムラノヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市村野本町', '27', '27210', '5730016', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '村野本町', 'ムラノホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市印田町', '27', '27210', '5730017', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '印田町', 'インダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市桜丘町', '27', '27210', '5730018', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '桜丘町', 'サクラガオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市中宮西之町', '27', '27210', '5730021', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '中宮西之町', 'ナカミヤニシノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市宮之阪', '27', '27210', '5730022', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '宮之阪', 'ミヤノサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市東田宮', '27', '27210', '5730023', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '東田宮', 'ヒガシタミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市田宮本町', '27', '27210', '5730024', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '田宮本町', 'タミヤホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市西田宮町', '27', '27210', '5730025', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '西田宮町', 'ニシタミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市朝日丘町', '27', '27210', '5730026', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '朝日丘町', 'アサヒガオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市大垣内町', '27', '27210', '5730027', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '大垣内町', 'オオガイトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市川原町', '27', '27210', '5730028', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '川原町', 'カワハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市岡本町', '27', '27210', '5730031', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '岡本町', 'オカホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市岡東町', '27', '27210', '5730032', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '岡東町', 'オカヒガシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市岡南町', '27', '27210', '5730033', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '岡南町', 'オカミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市岡山手町', '27', '27210', '5730034', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '岡山手町', 'オカヤマテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市高塚町', '27', '27210', '5730035', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '高塚町', 'タカツカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市伊加賀北町', '27', '27210', '5730036', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '伊加賀北町', 'イカガキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市枚方上之町', '27', '27210', '5730037', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '枚方上之町', 'ヒラカタカミノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市山之上東町', '27', '27210', '5730041', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '山之上東町', 'ヤマノウエヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市村野西町', '27', '27210', '5730042', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '村野西町', 'ムラノニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市村野南町', '27', '27210', '5730043', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '村野南町', 'ムラノミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市東藤田町', '27', '27210', '5730044', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '東藤田町', 'ヒガシトウダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市藤田町', '27', '27210', '5730045', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '藤田町', 'トウダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市宮之下町', '27', '27210', '5730046', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '宮之下町', 'ミヤノシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市山之上', '27', '27210', '5730047', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '山之上', 'ヤマノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市山之上西町', '27', '27210', '5730048', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '山之上西町', 'ヤマノウエニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市山之上北町', '27', '27210', '5730049', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '山之上北町', 'ヤマノウエキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市三矢町', '27', '27210', '5730051', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '三矢町', 'ミツヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市枚方元町', '27', '27210', '5730052', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '枚方元町', 'ヒラカタモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市伊加賀南町', '27', '27210', '5730053', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '伊加賀南町', 'イカガミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市枚方公園町', '27', '27210', '5730054', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '枚方公園町', 'ヒラカタコウエンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市伊加賀本町', '27', '27210', '5730055', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '伊加賀本町', 'イカガホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市桜町', '27', '27210', '5730056', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '桜町', 'サクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市堤町', '27', '27210', '5730057', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '堤町', 'ツツミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市伊加賀東町', '27', '27210', '5730058', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '伊加賀東町', 'イカガヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市伊加賀寿町', '27', '27210', '5730061', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '伊加賀寿町', 'イカガコトブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市伊加賀栄町', '27', '27210', '5730062', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '伊加賀栄町', 'イカガサカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市走谷', '27', '27210', '5730063', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '走谷', 'ハシリダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市北中振', '27', '27210', '5730064', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '北中振', 'キタナカブリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市出口', '27', '27210', '5730065', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '出口', 'デグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市伊加賀西町', '27', '27210', '5730066', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '伊加賀西町', 'イカガニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市伊加賀緑町', '27', '27210', '5730067', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '伊加賀緑町', 'イカガミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市茄子作', '27', '27210', '5730071', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '茄子作', 'ナスヅクリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市茄子作南町', '27', '27210', '5730072', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '茄子作南町', 'ナスヅクリミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市高田', '27', '27210', '5730073', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '高田', 'コウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市東香里南町', '27', '27210', '5730074', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '東香里南町', 'ヒガシコウリミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市東香里', '27', '27210', '5730075', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '東香里', 'ヒガシコウリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市東香里元町', '27', '27210', '5730076', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '東香里元町', 'ヒガシコウリモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市東香里新町', '27', '27210', '5730077', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '東香里新町', 'ヒガシコウリシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市釈尊寺町', '27', '27210', '5730081', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '釈尊寺町', 'シャクソンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市茄子作東町', '27', '27210', '5730082', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '茄子作東町', 'ナスヅクリヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市茄子作北町', '27', '27210', '5730083', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '茄子作北町', 'ナスヅクリキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市香里ケ丘', '27', '27210', '5730084', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '香里ケ丘', 'コウリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市香里園東之町', '27', '27210', '5730085', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '香里園東之町', 'コウリエンヒガシノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市香里園町', '27', '27210', '5730086', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '香里園町', 'コウリエンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市香里園山之手町', '27', '27210', '5730087', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '香里園山之手町', 'コウリエンヤマノテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市香里園桜木町', '27', '27210', '5730088', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '香里園桜木町', 'コウリエンサクラギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市菊丘町', '27', '27210', '5730091', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '菊丘町', 'キクガオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市菊丘南町', '27', '27210', '5730092', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '菊丘南町', 'キクガオカミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市東中振', '27', '27210', '5730093', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '東中振', 'ヒガシナカブリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市南中振', '27', '27210', '5730094', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '南中振', 'ミナミナカブリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市翠香園町', '27', '27210', '5730095', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '翠香園町', 'スイコウエンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市長尾峠町', '27', '27210', '5730101', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '長尾峠町', 'ナガオトウゲチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市長尾家具町', '27', '27210', '5730102', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '長尾家具町', 'ナガオカグマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市長尾荒阪', '27', '27210', '5730103', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '長尾荒阪', 'ナガオアラサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市長尾播磨谷', '27', '27210', '5730104', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '長尾播磨谷', 'ナガオハリマダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市長尾東町', '27', '27210', '5730105', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '長尾東町', 'ナガオヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市長尾台', '27', '27210', '5730106', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '長尾台', 'ナガオダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市長尾宮前', '27', '27210', '5730107', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '長尾宮前', 'ナガオミヤマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市杉北町', '27', '27210', '5730111', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '杉北町', 'スギキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市尊延寺', '27', '27210', '5730112', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '尊延寺', 'ソンエンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市宗谷', '27', '27210', '5730113', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '宗谷', 'ソウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市穂谷', '27', '27210', '5730114', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '穂谷', 'ホタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市氷室台', '27', '27210', '5730115', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '氷室台', 'ヒムロダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市杉責谷', '27', '27210', '5730116', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '杉責谷', 'スギセメダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市杉', '27', '27210', '5730117', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '杉', 'スギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市杉山手', '27', '27210', '5730118', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '杉山手', 'スギヤマテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市津田北町', '27', '27210', '5730121', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '津田北町', 'ツダキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市津田東町', '27', '27210', '5730122', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '津田東町', 'ツダヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市津田', '27', '27210', '5730123', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '津田', 'ツダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市津田南町', '27', '27210', '5730124', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '津田南町', 'ツダミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市津田駅前', '27', '27210', '5730125', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '津田駅前', 'ツダエキマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市津田西町', '27', '27210', '5730126', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '津田西町', 'ツダニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市津田元町', '27', '27210', '5730127', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '津田元町', 'ツダモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市津田山手', '27', '27210', '5730128', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '津田山手', 'ツダヤマテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市春日野', '27', '27210', '5730131', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '春日野', 'カスガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市野村元町', '27', '27210', '5730132', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '野村元町', 'ノムラモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市野村南町', '27', '27210', '5730133', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '野村南町', 'ノムラミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市春日東町', '27', '27210', '5730134', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '春日東町', 'カスガヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市春日元町', '27', '27210', '5730135', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '春日元町', 'カスガモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市春日西町', '27', '27210', '5730136', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '春日西町', 'カスガニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市春日北町', '27', '27210', '5730137', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '春日北町', 'カスガキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市大峰北町', '27', '27210', '5730141', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '大峰北町', 'オオミネキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市大峰東町', '27', '27210', '5730142', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '大峰東町', 'オオミネヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市野村北町', '27', '27210', '5730143', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '野村北町', 'ノムラキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市野村中町', '27', '27210', '5730144', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '野村中町', 'ノムラナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市大峰南町', '27', '27210', '5730145', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '大峰南町', 'オオミネミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市大峰元町', '27', '27210', '5730146', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '大峰元町', 'オオミネモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市藤阪北町', '27', '27210', '5730151', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '藤阪北町', 'フジサカキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市藤阪中町', '27', '27210', '5730152', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '藤阪中町', 'フジサカナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市藤阪東町', '27', '27210', '5730153', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '藤阪東町', 'フジサカヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市王仁公園', '27', '27210', '5730154', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '王仁公園', 'ワニコウエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市藤阪天神町', '27', '27210', '5730155', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '藤阪天神町', 'フジサカテンジンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市藤阪南町', '27', '27210', '5730156', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '藤阪南町', 'フジサカミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市藤阪元町', '27', '27210', '5730157', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '藤阪元町', 'フジサカモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市藤阪西町', '27', '27210', '5730158', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '藤阪西町', 'フジサカニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市長尾北町', '27', '27210', '5730161', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '長尾北町', 'ナガオキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市長尾西町', '27', '27210', '5730162', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '長尾西町', 'ナガオニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市長尾元町', '27', '27210', '5730163', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '長尾元町', 'ナガオモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市長尾谷町', '27', '27210', '5730164', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '長尾谷町', 'ナガオタニマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市山田池東町', '27', '27210', '5730165', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '山田池東町', 'ヤマダイケヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市山田池北町', '27', '27210', '5730166', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '山田池北町', 'ヤマダイケキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市山田池公園', '27', '27210', '5730167', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '山田池公園', 'ヤマダイケコウエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市山田池南町', '27', '27210', '5730168', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '山田池南町', 'ヤマダイケミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市北山', '27', '27210', '5730171', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '北山', 'キタヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市楠葉中之芝', '27', '27210', '5731101', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '楠葉中之芝', 'クズハナカノシバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市北楠葉町', '27', '27210', '5731102', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '北楠葉町', 'キタクズハチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市楠葉野田', '27', '27210', '5731103', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '楠葉野田', 'クズハノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市楠葉丘', '27', '27210', '5731104', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '楠葉丘', 'クズハオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市南楠葉', '27', '27210', '5731105', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '南楠葉', 'ミナミクズハ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市町楠葉', '27', '27210', '5731106', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '町楠葉', 'マチクズハ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市楠葉中町', '27', '27210', '5731107', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '楠葉中町', 'クズハナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市楠葉朝日', '27', '27210', '5731111', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '楠葉朝日', 'クズハアサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市楠葉美咲', '27', '27210', '5731112', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '楠葉美咲', 'クズハミサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市楠葉面取町', '27', '27210', '5731113', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '楠葉面取町', 'クズハメンドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市東山', '27', '27210', '5731114', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '東山', 'ヒガシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市東船橋', '27', '27210', '5731115', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '東船橋', 'ヒガシフナハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市船橋本町', '27', '27210', '5731116', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '船橋本町', 'フナハシホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市北船橋町', '27', '27210', '5731117', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '北船橋町', 'キタフナハシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市楠葉並木', '27', '27210', '5731118', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '楠葉並木', 'クズハナミキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市楠葉花園町', '27', '27210', '5731121', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '楠葉花園町', 'クズハハナゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市西船橋', '27', '27210', '5731122', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '西船橋', 'ニシフナハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市南船橋', '27', '27210', '5731123', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '南船橋', 'ミナミフナハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市養父東町', '27', '27210', '5731124', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '養父東町', 'ヤブヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市養父元町', '27', '27210', '5731125', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '養父元町', 'ヤブモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市上島東町', '27', '27210', '5731126', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '上島東町', 'カミジマヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市上島町', '27', '27210', '5731127', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '上島町', 'カミジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市樋之上町', '27', '27210', '5731128', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '樋之上町', 'ヒノウエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市高野道', '27', '27210', '5731131', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '高野道', 'コウヤミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市招提田近', '27', '27210', '5731132', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '招提田近', 'ショウダイタヂカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市招提元町', '27', '27210', '5731133', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '招提元町', 'ショウダイモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市養父丘', '27', '27210', '5731134', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '養父丘', 'ヤブガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市招提平野町', '27', '27210', '5731135', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '招提平野町', 'ショウダイヒラノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市宇山東町', '27', '27210', '5731136', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '宇山東町', 'ウヤマヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市西招提町', '27', '27210', '5731137', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '西招提町', 'ニシショウダイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市招提北町', '27', '27210', '5731138', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '招提北町', 'ショウダイキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市養父西町', '27', '27210', '5731141', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '養父西町', 'ヤブニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市牧野下島町', '27', '27210', '5731142', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '牧野下島町', 'マキノシモジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市宇山町', '27', '27210', '5731143', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '宇山町', 'ウヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市牧野本町', '27', '27210', '5731144', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '牧野本町', 'マキノホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市黄金野', '27', '27210', '5731145', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '黄金野', 'コガネノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市牧野阪', '27', '27210', '5731146', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '牧野阪', 'マキノサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市渚内野', '27', '27210', '5731147', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '渚内野', 'ナギサウチノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市西牧野', '27', '27210', '5731148', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '西牧野', 'ニシマキノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市牧野北町', '27', '27210', '5731149', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '牧野北町', 'マキノキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市東牧野町', '27', '27210', '5731151', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '東牧野町', 'ヒガシマキノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市招提中町', '27', '27210', '5731152', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '招提中町', 'ショウダイナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市招提大谷', '27', '27210', '5731153', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '招提大谷', 'ショウダイオオタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市招提東町', '27', '27210', '5731154', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '招提東町', 'ショウダイヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市招提南町', '27', '27210', '5731155', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '招提南町', 'ショウダイミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市片鉾東町', '27', '27210', '5731156', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '片鉾東町', 'カタホコヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市片鉾本町', '27', '27210', '5731157', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '片鉾本町', 'カタホコホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市北片鉾町', '27', '27210', '5731158', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '北片鉾町', 'キタカタホコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市車塚', '27', '27210', '5731159', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '車塚', 'クルマヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市交北', '27', '27210', '5731161', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '交北', 'コウホク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市田口', '27', '27210', '5731162', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '田口', 'タグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市甲斐田新町', '27', '27210', '5731163', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '甲斐田新町', 'カイダシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市須山町', '27', '27210', '5731164', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '須山町', 'スヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市都丘町', '27', '27210', '5731165', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '都丘町', 'ミヤコガオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市新之栄町', '27', '27210', '5731166', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '新之栄町', 'シンノエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市甲斐田町', '27', '27210', '5731167', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '甲斐田町', 'カイダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市甲斐田東町', '27', '27210', '5731168', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '甲斐田東町', 'カイダヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市三栗', '27', '27210', '5731171', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '三栗', 'メグリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市渚栄町', '27', '27210', '5731172', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '渚栄町', 'ナギササカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市小倉町', '27', '27210', '5731173', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '小倉町', 'オグラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市小倉東町', '27', '27210', '5731174', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '小倉東町', 'オグラヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市上野', '27', '27210', '5731175', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '上野', 'ウエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市渚東町', '27', '27210', '5731176', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '渚東町', 'ナギサヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市渚元町', '27', '27210', '5731177', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '渚元町', 'ナギサモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市渚西', '27', '27210', '5731178', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '渚西', 'ナギサニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市渚本町', '27', '27210', '5731181', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '渚本町', 'ナギサホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市御殿山町', '27', '27210', '5731182', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '御殿山町', 'ゴテンヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市渚南町', '27', '27210', '5731183', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '渚南町', 'ナギサミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市磯島茶屋町', '27', '27210', '5731184', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '磯島茶屋町', 'イソシマチャヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市天之川町', '27', '27210', '5731185', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '天之川町', 'アマノガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市磯島南町', '27', '27210', '5731186', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '磯島南町', 'イソシマミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市磯島元町', '27', '27210', '5731187', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '磯島元町', 'イソシマモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市磯島北町', '27', '27210', '5731188', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '磯島北町', 'イソシマキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市新町', '27', '27210', '5731191', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市西禁野', '27', '27210', '5731192', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '西禁野', 'ニシキンヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市御殿山南町', '27', '27210', '5731193', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '御殿山南町', 'ゴテンヤマミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市中宮北町', '27', '27210', '5731194', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '中宮北町', 'ナカミヤキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市中宮東之町', '27', '27210', '5731195', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '中宮東之町', 'ナカミヤヒガシノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市中宮本町', '27', '27210', '5731196', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '中宮本町', 'ナカミヤホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府枚方市禁野本町', '27', '27210', '5731197', '大阪府', 'オオサカフ', '枚方市', 'ヒラカタシ', '禁野本町', 'キンヤホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大東市', '27', '27218', '5740000', '大阪府', 'オオサカフ', '大東市', 'ダイトウシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('62397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大東市学園町', '27', '27218', '5740001', '大阪府', 'オオサカフ', '大東市', 'ダイトウシ', '学園町', 'ガクエンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大東市錦町', '27', '27218', '5740002', '大阪府', 'オオサカフ', '大東市', 'ダイトウシ', '錦町', 'ニシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大東市明美の里町', '27', '27218', '5740003', '大阪府', 'オオサカフ', '大東市', 'ダイトウシ', '明美の里町', 'アケミノサトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大東市南楠の里町', '27', '27218', '5740004', '大阪府', 'オオサカフ', '大東市', 'ダイトウシ', '南楠の里町', 'ミナミクスノサトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大東市西楠の里町', '27', '27218', '5740005', '大阪府', 'オオサカフ', '大東市', 'ダイトウシ', '西楠の里町', 'ニシクスノサトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大東市中楠の里町', '27', '27218', '5740006', '大阪府', 'オオサカフ', '大東市', 'ダイトウシ', '中楠の里町', 'ナカクスノサトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大東市北楠の里町', '27', '27218', '5740007', '大阪府', 'オオサカフ', '大東市', 'ダイトウシ', '北楠の里町', 'キタクスノサトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大東市北新町', '27', '27218', '5740008', '大阪府', 'オオサカフ', '大東市', 'ダイトウシ', '北新町', 'キタシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大東市北条', '27', '27218', '5740011', '大阪府', 'オオサカフ', '大東市', 'ダイトウシ', '北条', 'ホウジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大東市龍間', '27', '27218', '5740012', '大阪府', 'オオサカフ', '大東市', 'ダイトウシ', '龍間', 'タツマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大東市中垣内', '27', '27218', '5740013', '大阪府', 'オオサカフ', '大東市', 'ダイトウシ', '中垣内', 'ナカガイト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大東市寺川', '27', '27218', '5740014', '大阪府', 'オオサカフ', '大東市', 'ダイトウシ', '寺川', 'テラガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大東市野崎', '27', '27218', '5740015', '大阪府', 'オオサカフ', '大東市', 'ダイトウシ', '野崎', 'ノザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大東市南津の辺町', '27', '27218', '5740016', '大阪府', 'オオサカフ', '大東市', 'ダイトウシ', '南津の辺町', 'ミナミツノベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大東市津の辺町', '27', '27218', '5740017', '大阪府', 'オオサカフ', '大東市', 'ダイトウシ', '津の辺町', 'ツノベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大東市平野屋新町', '27', '27218', '5740021', '大阪府', 'オオサカフ', '大東市', 'ダイトウシ', '平野屋新町', 'ヒラノヤシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大東市平野屋', '27', '27218', '5740022', '大阪府', 'オオサカフ', '大東市', 'ダイトウシ', '平野屋', 'ヒラノヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大東市南新田', '27', '27218', '5740023', '大阪府', 'オオサカフ', '大東市', 'ダイトウシ', '南新田', 'ミナミシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大東市泉町', '27', '27218', '5740024', '大阪府', 'オオサカフ', '大東市', 'ダイトウシ', '泉町', 'イズミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大東市御供田', '27', '27218', '5740025', '大阪府', 'オオサカフ', '大東市', 'ダイトウシ', '御供田', 'ゴクデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大東市住道', '27', '27218', '5740026', '大阪府', 'オオサカフ', '大東市', 'ダイトウシ', '住道', 'スミノドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大東市三住町', '27', '27218', '5740027', '大阪府', 'オオサカフ', '大東市', 'ダイトウシ', '三住町', 'ミスミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大東市幸町', '27', '27218', '5740028', '大阪府', 'オオサカフ', '大東市', 'ダイトウシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大東市川中新町', '27', '27218', '5740031', '大阪府', 'オオサカフ', '大東市', 'ダイトウシ', '川中新町', 'カワナカシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大東市栄和町', '27', '27218', '5740032', '大阪府', 'オオサカフ', '大東市', 'ダイトウシ', '栄和町', 'エイワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大東市扇町', '27', '27218', '5740033', '大阪府', 'オオサカフ', '大東市', 'ダイトウシ', '扇町', 'オウギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大東市朋来', '27', '27218', '5740034', '大阪府', 'オオサカフ', '大東市', 'ダイトウシ', '朋来', 'ホウライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大東市三洋町', '27', '27218', '5740035', '大阪府', 'オオサカフ', '大東市', 'ダイトウシ', '三洋町', 'サンヨウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大東市末広町', '27', '27218', '5740036', '大阪府', 'オオサカフ', '大東市', 'ダイトウシ', '末広町', 'スエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大東市新町', '27', '27218', '5740037', '大阪府', 'オオサカフ', '大東市', 'ダイトウシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大東市浜町', '27', '27218', '5740041', '大阪府', 'オオサカフ', '大東市', 'ダイトウシ', '浜町', 'ハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大東市大野', '27', '27218', '5740042', '大阪府', 'オオサカフ', '大東市', 'ダイトウシ', '大野', 'オオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大東市灰塚', '27', '27218', '5740043', '大阪府', 'オオサカフ', '大東市', 'ダイトウシ', '灰塚', 'ハイヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大東市諸福', '27', '27218', '5740044', '大阪府', 'オオサカフ', '大東市', 'ダイトウシ', '諸福', 'モロフク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大東市太子田', '27', '27218', '5740045', '大阪府', 'オオサカフ', '大東市', 'ダイトウシ', '太子田', 'タシデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大東市赤井', '27', '27218', '5740046', '大阪府', 'オオサカフ', '大東市', 'ダイトウシ', '赤井', 'アカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大東市新田境町', '27', '27218', '5740051', '大阪府', 'オオサカフ', '大東市', 'ダイトウシ', '新田境町', 'シンデンサカイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大東市新田北町', '27', '27218', '5740052', '大阪府', 'オオサカフ', '大東市', 'ダイトウシ', '新田北町', 'シンデンキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大東市新田旭町', '27', '27218', '5740053', '大阪府', 'オオサカフ', '大東市', 'ダイトウシ', '新田旭町', 'シンデンアサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大東市新田東本町', '27', '27218', '5740054', '大阪府', 'オオサカフ', '大東市', 'ダイトウシ', '新田東本町', 'シンデンヒガシホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大東市新田本町', '27', '27218', '5740055', '大阪府', 'オオサカフ', '大東市', 'ダイトウシ', '新田本町', 'シンデンホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大東市新田中町', '27', '27218', '5740056', '大阪府', 'オオサカフ', '大東市', 'ダイトウシ', '新田中町', 'シンデンナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大東市新田西町', '27', '27218', '5740057', '大阪府', 'オオサカフ', '大東市', 'ダイトウシ', '新田西町', 'シンデンニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大東市大東町', '27', '27218', '5740061', '大阪府', 'オオサカフ', '大東市', 'ダイトウシ', '大東町', 'ダイトウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大東市氷野', '27', '27218', '5740062', '大阪府', 'オオサカフ', '大東市', 'ダイトウシ', '氷野', 'ヒノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大東市南郷町', '27', '27218', '5740063', '大阪府', 'オオサカフ', '大東市', 'ダイトウシ', '南郷町', 'ナンゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大東市御領', '27', '27218', '5740064', '大阪府', 'オオサカフ', '大東市', 'ダイトウシ', '御領', 'ゴリョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大東市深野北', '27', '27218', '5740071', '大阪府', 'オオサカフ', '大東市', 'ダイトウシ', '深野北', 'フコノキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大東市深野', '27', '27218', '5740072', '大阪府', 'オオサカフ', '大東市', 'ダイトウシ', '深野', 'フコノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大東市緑が丘', '27', '27218', '5740073', '大阪府', 'オオサカフ', '大東市', 'ダイトウシ', '緑が丘', 'ミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大東市谷川', '27', '27218', '5740074', '大阪府', 'オオサカフ', '大東市', 'ダイトウシ', '谷川', 'タニガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大東市深野南町', '27', '27218', '5740075', '大阪府', 'オオサカフ', '大東市', 'ダイトウシ', '深野南町', 'フコノミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大東市曙町', '27', '27218', '5740076', '大阪府', 'オオサカフ', '大東市', 'ダイトウシ', '曙町', 'アケボノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大東市三箇', '27', '27218', '5740077', '大阪府', 'オオサカフ', '大東市', 'ダイトウシ', '三箇', 'サンガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府四條畷市', '27', '27229', '5750000', '大阪府', 'オオサカフ', '四條畷市', 'シジョウナワテシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('62456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府四條畷市砂', '27', '27229', '5750001', '大阪府', 'オオサカフ', '四條畷市', 'シジョウナワテシ', '砂', 'スナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府四條畷市岡山', '27', '27229', '5750002', '大阪府', 'オオサカフ', '四條畷市', 'シジョウナワテシ', '岡山', 'オカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府四條畷市岡山東', '27', '27229', '5750003', '大阪府', 'オオサカフ', '四條畷市', 'シジョウナワテシ', '岡山東', 'オカヤマヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府四條畷市岡山', '27', '27229', '5750004', '大阪府', 'オオサカフ', '四條畷市', 'シジョウナワテシ', '岡山', 'オカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府四條畷市逢阪', '27', '27229', '5750011', '大阪府', 'オオサカフ', '四條畷市', 'シジョウナワテシ', '逢阪', 'オウサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府四條畷市下田原', '27', '27229', '5750012', '大阪府', 'オオサカフ', '四條畷市', 'シジョウナワテシ', '下田原', 'シモタワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府四條畷市田原台', '27', '27229', '5750013', '大阪府', 'オオサカフ', '四條畷市', 'シジョウナワテシ', '田原台', 'タワラダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府四條畷市上田原', '27', '27229', '5750014', '大阪府', 'オオサカフ', '四條畷市', 'シジョウナワテシ', '上田原', 'カミタワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府四條畷市さつきケ丘', '27', '27229', '5750015', '大阪府', 'オオサカフ', '四條畷市', 'シジョウナワテシ', 'さつきケ丘', 'サツキガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府四條畷市緑風台', '27', '27229', '5750016', '大阪府', 'オオサカフ', '四條畷市', 'シジョウナワテシ', '緑風台', 'リョクフウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府四條畷市南野', '27', '27229', '5750021', '大阪府', 'オオサカフ', '四條畷市', 'シジョウナワテシ', '南野', 'ミナミノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府四條畷市南野', '27', '27229', '5750022', '大阪府', 'オオサカフ', '四條畷市', 'シジョウナワテシ', '南野', 'ミナミノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府四條畷市楠公', '27', '27229', '5750023', '大阪府', 'オオサカフ', '四條畷市', 'シジョウナワテシ', '楠公', 'ナンコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府四條畷市塚脇町', '27', '27229', '5750024', '大阪府', 'オオサカフ', '四條畷市', 'シジョウナワテシ', '塚脇町', 'ツカワキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府四條畷市蔀屋', '27', '27229', '5750031', '大阪府', 'オオサカフ', '四條畷市', 'シジョウナワテシ', '蔀屋', 'シトミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府四條畷市米崎町', '27', '27229', '5750032', '大阪府', 'オオサカフ', '四條畷市', 'シジョウナワテシ', '米崎町', 'コメザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府四條畷市美田町', '27', '27229', '5750033', '大阪府', 'オオサカフ', '四條畷市', 'シジョウナワテシ', '美田町', 'ミタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府四條畷市江瀬美町', '27', '27229', '5750034', '大阪府', 'オオサカフ', '四條畷市', 'シジョウナワテシ', '江瀬美町', 'エセビチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府四條畷市雁屋北町', '27', '27229', '5750035', '大阪府', 'オオサカフ', '四條畷市', 'シジョウナワテシ', '雁屋北町', 'カリヤキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府四條畷市雁屋南町', '27', '27229', '5750036', '大阪府', 'オオサカフ', '四條畷市', 'シジョウナワテシ', '雁屋南町', 'カリヤミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府四條畷市蔀屋新町', '27', '27229', '5750041', '大阪府', 'オオサカフ', '四條畷市', 'シジョウナワテシ', '蔀屋新町', 'シトミヤシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府四條畷市蔀屋本町', '27', '27229', '5750042', '大阪府', 'オオサカフ', '四條畷市', 'シジョウナワテシ', '蔀屋本町', 'シトミヤホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府四條畷市北出町', '27', '27229', '5750043', '大阪府', 'オオサカフ', '四條畷市', 'シジョウナワテシ', '北出町', 'キタデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府四條畷市二丁通町', '27', '27229', '5750044', '大阪府', 'オオサカフ', '四條畷市', 'シジョウナワテシ', '二丁通町', 'ニチョウドオリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府四條畷市雁屋西町', '27', '27229', '5750045', '大阪府', 'オオサカフ', '四條畷市', 'シジョウナワテシ', '雁屋西町', 'カリヤニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府四條畷市中野本町', '27', '27229', '5750051', '大阪府', 'オオサカフ', '四條畷市', 'シジョウナワテシ', '中野本町', 'ナカノホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府四條畷市中野', '27', '27229', '5750052', '大阪府', 'オオサカフ', '四條畷市', 'シジョウナワテシ', '中野', 'ナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府四條畷市中野', '27', '27229', '5750053', '大阪府', 'オオサカフ', '四條畷市', 'シジョウナワテシ', '中野', 'ナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府四條畷市中野新町', '27', '27229', '5750054', '大阪府', 'オオサカフ', '四條畷市', 'シジョウナワテシ', '中野新町', 'ナカノシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府四條畷市清滝中町', '27', '27229', '5750061', '大阪府', 'オオサカフ', '四條畷市', 'シジョウナワテシ', '清滝中町', 'キヨタキナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府四條畷市清滝新町', '27', '27229', '5750062', '大阪府', 'オオサカフ', '四條畷市', 'シジョウナワテシ', '清滝新町', 'キヨタキシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府四條畷市清瀧', '27', '27229', '5750063', '大阪府', 'オオサカフ', '四條畷市', 'シジョウナワテシ', '清瀧', 'キヨタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府交野市', '27', '27230', '5760000', '大阪府', 'オオサカフ', '交野市', 'カタノシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('62495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府交野市倉治', '27', '27230', '5760001', '大阪府', 'オオサカフ', '交野市', 'カタノシ', '倉治', 'クラジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府交野市私部', '27', '27230', '5760002', '大阪府', 'オオサカフ', '交野市', 'カタノシ', '私部', 'キサベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府交野市傍示', '27', '27230', '5760003', '大阪府', 'オオサカフ', '交野市', 'カタノシ', '傍示', 'ホウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府交野市私市', '27', '27230', '5760004', '大阪府', 'オオサカフ', '交野市', 'カタノシ', '私市', 'キサイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府交野市森', '27', '27230', '5760005', '大阪府', 'オオサカフ', '交野市', 'カタノシ', '森', 'モリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府交野市寺', '27', '27230', '5760006', '大阪府', 'オオサカフ', '交野市', 'カタノシ', '寺', 'テラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府交野市星田', '27', '27230', '5760011', '大阪府', 'オオサカフ', '交野市', 'カタノシ', '星田', 'ホシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府交野市妙見東', '27', '27230', '5760012', '大阪府', 'オオサカフ', '交野市', 'カタノシ', '妙見東', 'ミョウケンヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府交野市南星台', '27', '27230', '5760013', '大阪府', 'オオサカフ', '交野市', 'カタノシ', '南星台', 'ナンセイダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府交野市星田山手', '27', '27230', '5760014', '大阪府', 'オオサカフ', '交野市', 'カタノシ', '星田山手', 'ホシダヤマテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府交野市星田西', '27', '27230', '5760015', '大阪府', 'オオサカフ', '交野市', 'カタノシ', '星田西', 'ホシダニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府交野市星田', '27', '27230', '5760016', '大阪府', 'オオサカフ', '交野市', 'カタノシ', '星田', 'ホシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府交野市星田北', '27', '27230', '5760017', '大阪府', 'オオサカフ', '交野市', 'カタノシ', '星田北', 'ホシダキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府交野市妙見坂', '27', '27230', '5760021', '大阪府', 'オオサカフ', '交野市', 'カタノシ', '妙見坂', 'ミョウケンザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府交野市藤が尾', '27', '27230', '5760022', '大阪府', 'オオサカフ', '交野市', 'カタノシ', '藤が尾', 'フジガオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府交野市森南', '27', '27230', '5760031', '大阪府', 'オオサカフ', '交野市', 'カタノシ', '森南', 'モリミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府交野市私市山手', '27', '27230', '5760032', '大阪府', 'オオサカフ', '交野市', 'カタノシ', '私市山手', 'キサイチヤマテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府交野市私市', '27', '27230', '5760033', '大阪府', 'オオサカフ', '交野市', 'カタノシ', '私市', 'キサイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府交野市天野が原町', '27', '27230', '5760034', '大阪府', 'オオサカフ', '交野市', 'カタノシ', '天野が原町', 'アマノガハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府交野市私部南', '27', '27230', '5760035', '大阪府', 'オオサカフ', '交野市', 'カタノシ', '私部南', 'キサベミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府交野市森北', '27', '27230', '5760036', '大阪府', 'オオサカフ', '交野市', 'カタノシ', '森北', 'モリキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府交野市私部西', '27', '27230', '5760041', '大阪府', 'オオサカフ', '交野市', 'カタノシ', '私部西', 'キサベニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府交野市梅が枝', '27', '27230', '5760042', '大阪府', 'オオサカフ', '交野市', 'カタノシ', '梅が枝', 'ウメガエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府交野市松塚', '27', '27230', '5760043', '大阪府', 'オオサカフ', '交野市', 'カタノシ', '松塚', 'マツヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府交野市倉治', '27', '27230', '5760051', '大阪府', 'オオサカフ', '交野市', 'カタノシ', '倉治', 'クラジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府交野市私部', '27', '27230', '5760052', '大阪府', 'オオサカフ', '交野市', 'カタノシ', '私部', 'キサベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府交野市郡津', '27', '27230', '5760053', '大阪府', 'オオサカフ', '交野市', 'カタノシ', '郡津', 'コウヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府交野市幾野', '27', '27230', '5760054', '大阪府', 'オオサカフ', '交野市', 'カタノシ', '幾野', 'イクノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府交野市東倉治', '27', '27230', '5760061', '大阪府', 'オオサカフ', '交野市', 'カタノシ', '東倉治', 'ヒガシクラジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府交野市神宮寺', '27', '27230', '5760062', '大阪府', 'オオサカフ', '交野市', 'カタノシ', '神宮寺', 'ジングウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府交野市寺', '27', '27230', '5760063', '大阪府', 'オオサカフ', '交野市', 'カタノシ', '寺', 'テラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府交野市寺南野', '27', '27230', '5760064', '大阪府', 'オオサカフ', '交野市', 'カタノシ', '寺南野', 'テラミナミノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府交野市向井田', '27', '27230', '5760065', '大阪府', 'オオサカフ', '交野市', 'カタノシ', '向井田', 'ムカイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府交野市青山', '27', '27230', '5760066', '大阪府', 'オオサカフ', '交野市', 'カタノシ', '青山', 'アオヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市', '27', '27227', '5770000', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('62531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市徳庵本町', '27', '27227', '5770001', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '徳庵本町', 'トクアンホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市稲田上町', '27', '27227', '5770002', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '稲田上町', 'イナダウエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市稲田三島町', '27', '27227', '5770003', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '稲田三島町', 'イナダミシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市稲田新町', '27', '27227', '5770004', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '稲田新町', 'イナダシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市七軒家', '27', '27227', '5770005', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '七軒家', 'シチケンヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市楠根', '27', '27227', '5770006', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '楠根', 'クスネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市稲田本町', '27', '27227', '5770007', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '稲田本町', 'イナダホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市荒本北', '27', '27227', '5770011', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '荒本北', 'アラモトキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市長田東', '27', '27227', '5770012', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '長田東', 'ナガタヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市長田中', '27', '27227', '5770013', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '長田中', 'ナガタナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市長田内介', '27', '27227', '5770014', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '長田内介', 'ナガタナイスケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市長田', '27', '27227', '5770015', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '長田', 'ナガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市長田西', '27', '27227', '5770016', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '長田西', 'ナガタニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市藤戸新田', '27', '27227', '5770017', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '藤戸新田', 'フジトシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市荒本新町', '27', '27227', '5770022', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '荒本新町', 'アラモトシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市荒本', '27', '27227', '5770023', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '荒本', 'アラモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市荒本西', '27', '27227', '5770024', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '荒本西', 'アラモトニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市新家', '27', '27227', '5770025', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '新家', 'シンケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市新家東町', '27', '27227', '5770026', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '新家東町', 'シンケヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市新家中町', '27', '27227', '5770027', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '新家中町', 'シンケナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市新家西町', '27', '27227', '5770028', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '新家西町', 'シンケニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市御厨', '27', '27227', '5770032', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '御厨', 'ミクリヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市御厨東', '27', '27227', '5770033', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '御厨東', 'ミクリヤヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市御厨南', '27', '27227', '5770034', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '御厨南', 'ミクリヤミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市御厨中', '27', '27227', '5770035', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '御厨中', 'ミクリヤナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市御厨栄町', '27', '27227', '5770036', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '御厨栄町', 'ミクリヤサカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市御厨西ノ町', '27', '27227', '5770037', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '御厨西ノ町', 'ミクリヤニシノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市西堤', '27', '27227', '5770042', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '西堤', 'ニシヅツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市西堤学園町', '27', '27227', '5770044', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '西堤学園町', 'ニシヅツミガクエンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市西堤本通東', '27', '27227', '5770045', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '西堤本通東', 'ニシヅツミホンドオリヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市西堤本通西', '27', '27227', '5770046', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '西堤本通西', 'ニシヅツミホンドオリニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市西堤楠町', '27', '27227', '5770047', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '西堤楠町', 'ニシヅツミクスノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市西堤西', '27', '27227', '5770048', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '西堤西', 'ニシツツミニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市新喜多', '27', '27227', '5770052', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '新喜多', 'シギタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市高井田', '27', '27227', '5770053', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '高井田', 'タカイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市高井田元町', '27', '27227', '5770054', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '高井田元町', 'タカイダモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市長栄寺', '27', '27227', '5770055', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '長栄寺', 'チョウエイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市長堂', '27', '27227', '5770056', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '長堂', 'チョウドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市足代新町', '27', '27227', '5770057', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '足代新町', 'アジロシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市足代北', '27', '27227', '5770058', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '足代北', 'アジロキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市森河内西', '27', '27227', '5770061', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '森河内西', 'モリカワチニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市森河内東', '27', '27227', '5770062', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '森河内東', 'モリカワチヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市川俣', '27', '27227', '5770063', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '川俣', 'カワマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市川俣本町', '27', '27227', '5770064', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '川俣本町', 'カワマタホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市高井田中', '27', '27227', '5770065', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '高井田中', 'タカイダナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市高井田本通', '27', '27227', '5770066', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '高井田本通', 'タカイダホンドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市高井田西', '27', '27227', '5770067', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '高井田西', 'タカイダニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市小阪', '27', '27227', '5770801', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '小阪', 'コサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市小阪本町', '27', '27227', '5770802', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '小阪本町', 'コサカホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市下小阪', '27', '27227', '5770803', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '下小阪', 'シモコサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市中小阪', '27', '27227', '5770804', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '中小阪', 'ナカコサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市宝持', '27', '27227', '5770805', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '宝持', 'ホウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市上小阪', '27', '27227', '5770806', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '上小阪', 'カミコサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市菱屋西', '27', '27227', '5770807', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '菱屋西', 'ヒシヤニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市横沼町', '27', '27227', '5770808', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '横沼町', 'ヨコヌマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市永和', '27', '27227', '5770809', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '永和', 'エイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市西上小阪', '27', '27227', '5770811', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '西上小阪', 'ニシカミコサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市東上小阪', '27', '27227', '5770812', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '東上小阪', 'ヒガシカミコサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市新上小阪', '27', '27227', '5770813', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '新上小阪', 'シンカミコサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市南上小阪', '27', '27227', '5770814', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '南上小阪', 'ミナミカミコサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市金物町', '27', '27227', '5770815', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '金物町', 'カナモノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市友井', '27', '27227', '5770816', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '友井', 'トモイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市近江堂', '27', '27227', '5770817', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '近江堂', 'オウミドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市小若江', '27', '27227', '5770818', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '小若江', 'コワカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市吉松', '27', '27227', '5770821', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '吉松', 'ヨシマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市源氏ケ丘', '27', '27227', '5770822', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '源氏ケ丘', 'ゲンジガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市金岡', '27', '27227', '5770823', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '金岡', 'カナオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市大蓮東', '27', '27227', '5770824', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '大蓮東', 'オオハスヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市大蓮南', '27', '27227', '5770825', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '大蓮南', 'オオハスミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市大蓮北', '27', '27227', '5770826', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '大蓮北', 'オオハスキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市衣摺', '27', '27227', '5770827', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '衣摺', 'キズリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市俊徳町', '27', '27227', '5770831', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '俊徳町', 'シュントクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市長瀬町', '27', '27227', '5770832', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '長瀬町', 'ナガセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市柏田東町', '27', '27227', '5770833', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '柏田東町', 'カシタヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市柏田本町', '27', '27227', '5770834', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '柏田本町', 'カシタホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市柏田西', '27', '27227', '5770835', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '柏田西', 'カシタニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市渋川町', '27', '27227', '5770836', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '渋川町', 'シブカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市寿町', '27', '27227', '5770837', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '寿町', 'コトブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市足代', '27', '27227', '5770841', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '足代', 'アジロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市足代南', '27', '27227', '5770842', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '足代南', 'アジロミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市荒川', '27', '27227', '5770843', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '荒川', 'アラカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市太平寺', '27', '27227', '5770844', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '太平寺', 'タイヘイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市寺前町', '27', '27227', '5770845', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '寺前町', 'テラマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市岸田堂北町', '27', '27227', '5770846', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '岸田堂北町', 'キシダドウキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市岸田堂南町', '27', '27227', '5770847', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '岸田堂南町', 'キシダドウミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市岸田堂西', '27', '27227', '5770848', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '岸田堂西', 'キシダドウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市三ノ瀬', '27', '27227', '5770849', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '三ノ瀬', 'サンノセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市加納', '27', '27227', '5780901', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '加納', 'カノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市川中', '27', '27227', '5780902', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '川中', 'カワナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市今米', '27', '27227', '5780903', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '今米', 'イマゴメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市吉原', '27', '27227', '5780904', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '吉原', 'ヨシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市川田', '27', '27227', '5780905', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '川田', 'カワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市中新開', '27', '27227', '5780911', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '中新開', 'ナカシンカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市角田', '27', '27227', '5780912', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '角田', 'スミダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市中野', '27', '27227', '5780913', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '中野', 'ナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市箕輪', '27', '27227', '5780914', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '箕輪', 'ミノワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市古箕輪', '27', '27227', '5780915', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '古箕輪', 'コミノワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市水走', '27', '27227', '5780921', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '水走', 'ミズハイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市松原', '27', '27227', '5780922', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '松原', 'マツバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市松原南', '27', '27227', '5780923', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '松原南', 'マツバラミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市吉田', '27', '27227', '5780924', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '吉田', 'ヨシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市稲葉', '27', '27227', '5780925', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '稲葉', 'イナバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市花園東町', '27', '27227', '5780931', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '花園東町', 'ハナゾノヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市玉串町東', '27', '27227', '5780932', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '玉串町東', 'タマクシチョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市玉串元町', '27', '27227', '5780933', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '玉串元町', 'タマクシモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市玉串町西', '27', '27227', '5780934', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '玉串町西', 'タマクシチョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市若江東町', '27', '27227', '5780935', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '若江東町', 'ワカエヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市花園西町', '27', '27227', '5780936', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '花園西町', 'ハナゾノニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市花園本町', '27', '27227', '5780937', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '花園本町', 'ハナゾノホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市岩田町', '27', '27227', '5780941', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '岩田町', 'イワタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市若江本町', '27', '27227', '5780942', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '若江本町', 'ワカエホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市若江南町', '27', '27227', '5780943', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '若江南町', 'ワカエミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市若江西新町', '27', '27227', '5780944', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '若江西新町', 'ワカエニシシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市若江北町', '27', '27227', '5780945', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '若江北町', 'ワカエキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市瓜生堂', '27', '27227', '5780946', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '瓜生堂', 'ウリュウドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市西岩田', '27', '27227', '5780947', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '西岩田', 'ニシイワタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市菱屋東', '27', '27227', '5780948', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '菱屋東', 'ヒシヤヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市新庄東', '27', '27227', '5780951', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '新庄東', 'シンジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市本庄東', '27', '27227', '5780952', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '本庄東', 'ホンジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市本庄', '27', '27227', '5780953', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '本庄', 'ホンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市横枕', '27', '27227', '5780954', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '横枕', 'ヨコマクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市横枕南', '27', '27227', '5780955', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '横枕南', 'ヨコマクラミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市横枕西', '27', '27227', '5780956', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '横枕西', 'ヨコマクラニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市本庄中', '27', '27227', '5780957', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '本庄中', 'ホンジョウナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市新庄南', '27', '27227', '5780958', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '新庄南', 'シンジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市南鴻池町', '27', '27227', '5780961', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '南鴻池町', 'ミナミコウノイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市新庄', '27', '27227', '5780963', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '新庄', 'シンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市新庄西', '27', '27227', '5780964', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '新庄西', 'シンジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市本庄西', '27', '27227', '5780965', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '本庄西', 'ホンジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市三島', '27', '27227', '5780966', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '三島', 'ミシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市新鴻池町', '27', '27227', '5780967', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '新鴻池町', 'シンコウノイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市鴻池本町', '27', '27227', '5780971', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '鴻池本町', 'コウノイケホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市鴻池町', '27', '27227', '5780972', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '鴻池町', 'コウノイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市東鴻池町', '27', '27227', '5780973', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '東鴻池町', 'ヒガシコウノイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市鴻池元町', '27', '27227', '5780974', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '鴻池元町', 'コウノイケモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市中鴻池町', '27', '27227', '5780975', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '中鴻池町', 'ナカコウノイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市西鴻池町', '27', '27227', '5780976', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '西鴻池町', 'ニシコウノイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市鴻池徳庵町', '27', '27227', '5780977', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '鴻池徳庵町', 'コウノイケトクアンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市北鴻池町', '27', '27227', '5780978', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '北鴻池町', 'キタコウノイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市島之内', '27', '27227', '5780981', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '島之内', 'シマノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市吉田本町', '27', '27227', '5780982', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '吉田本町', 'ヨシタホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市吉田下島', '27', '27227', '5780983', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '吉田下島', 'ヨシタシモジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市菱江', '27', '27227', '5780984', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '菱江', 'ヒシエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市中野南', '27', '27227', '5780985', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '中野南', 'ナカノミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市善根寺町', '27', '27227', '5798001', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '善根寺町', 'ゼンコンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市池之端町', '27', '27227', '5798002', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '池之端町', 'イケノハタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市日下町', '27', '27227', '5798003', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '日下町', 'クサカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市布市町', '27', '27227', '5798004', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '布市町', 'ヌノイチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市元町', '27', '27227', '5798005', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '元町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市東石切町', '27', '27227', '5798011', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '東石切町', 'ヒガシイシキリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市上石切町', '27', '27227', '5798012', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '上石切町', 'カミイシキリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市西石切町', '27', '27227', '5798013', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '西石切町', 'ニシイシキリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市中石切町', '27', '27227', '5798014', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '中石切町', 'ナカイシキリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市北石切町', '27', '27227', '5798015', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '北石切町', 'キタイシキリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市額田町', '27', '27227', '5798021', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '額田町', 'ヌカタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市山手町', '27', '27227', '5798022', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '山手町', 'ヤマテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市立花町', '27', '27227', '5798023', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '立花町', 'タチバナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市南荘町', '27', '27227', '5798024', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '南荘町', 'ナンソウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市宝町', '27', '27227', '5798025', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '宝町', 'タカラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市弥生町', '27', '27227', '5798026', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '弥生町', 'ヤヨイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市東山町', '27', '27227', '5798027', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '東山町', 'ヒガシヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市豊浦町', '27', '27227', '5798031', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '豊浦町', 'トヨウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市東豊浦町', '27', '27227', '5798032', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '東豊浦町', 'ヒガシトヨウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市出雲井町', '27', '27227', '5798033', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '出雲井町', 'イズモイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市出雲井本町', '27', '27227', '5798034', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '出雲井本町', 'イズモイホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市鳥居町', '27', '27227', '5798035', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '鳥居町', 'トリイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市鷹殿町', '27', '27227', '5798036', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '鷹殿町', 'タカドノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市新町', '27', '27227', '5798037', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市箱殿町', '27', '27227', '5798038', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '箱殿町', 'ハコドノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市喜里川町', '27', '27227', '5798041', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '喜里川町', 'キリカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市五条町', '27', '27227', '5798042', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '五条町', 'ゴジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市客坊町', '27', '27227', '5798043', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '客坊町', 'キャクボウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市河内町', '27', '27227', '5798044', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '河内町', 'カワチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市本町', '27', '27227', '5798045', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市昭和町', '27', '27227', '5798046', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '昭和町', 'ショウワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市桜町', '27', '27227', '5798047', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '桜町', 'サクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市旭町', '27', '27227', '5798048', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '旭町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市瓢箪山町', '27', '27227', '5798051', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '瓢箪山町', 'ヒョウタンヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市上四条町', '27', '27227', '5798052', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '上四条町', 'カミシジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市四条町', '27', '27227', '5798053', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '四条町', 'シジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市南四条町', '27', '27227', '5798054', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '南四条町', 'ミナミシジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市末広町', '27', '27227', '5798055', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '末広町', 'スエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市若草町', '27', '27227', '5798056', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '若草町', 'ワカクサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市御幸町', '27', '27227', '5798057', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '御幸町', 'ミユキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市神田町', '27', '27227', '5798058', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '神田町', 'カンダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市六万寺町', '27', '27227', '5798061', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '六万寺町', 'ロクマンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市上六万寺町', '27', '27227', '5798062', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '上六万寺町', 'カミロクマンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市横小路町', '27', '27227', '5798063', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '横小路町', 'ヨコショウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市池島町', '27', '27227', '5798064', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '池島町', 'イケシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市新池島町', '27', '27227', '5798065', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '新池島町', 'シンイケシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市下六万寺町', '27', '27227', '5798066', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '下六万寺町', 'シモロクマンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道様似郡様似町', '01', '01608', '0580000', '北海道', 'ホッカイドウ', '様似郡様似町', 'サマニグンサマニチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('62764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府松原市', '27', '27217', '5800000', '大阪府', 'オオサカフ', '松原市', 'マツバラシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('62765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府松原市若林', '27', '27217', '5800001', '大阪府', 'オオサカフ', '松原市', 'マツバラシ', '若林', 'ワカバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府松原市小川', '27', '27217', '5800002', '大阪府', 'オオサカフ', '松原市', 'マツバラシ', '小川', 'オガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府松原市一津屋', '27', '27217', '5800003', '大阪府', 'オオサカフ', '松原市', 'マツバラシ', '一津屋', 'ヒトツヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府松原市西野々', '27', '27217', '5800004', '大阪府', 'オオサカフ', '松原市', 'マツバラシ', '西野々', 'ニシノノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府松原市別所', '27', '27217', '5800005', '大阪府', 'オオサカフ', '松原市', 'マツバラシ', '別所', 'ベッショ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府松原市大堀', '27', '27217', '5800006', '大阪府', 'オオサカフ', '松原市', 'マツバラシ', '大堀', 'オオボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道様似郡様似町旭', '01', '01608', '0580001', '北海道', 'ホッカイドウ', '様似郡様似町', 'サマニグンサマニチョウ', '旭', 'アサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府松原市西大塚', '27', '27217', '5800011', '大阪府', 'オオサカフ', '松原市', 'マツバラシ', '西大塚', 'ニシオオツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府松原市立部', '27', '27217', '5800012', '大阪府', 'オオサカフ', '松原市', 'マツバラシ', '立部', 'タツベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府松原市丹南', '27', '27217', '5800013', '大阪府', 'オオサカフ', '松原市', 'マツバラシ', '丹南', 'タンナン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府松原市岡', '27', '27217', '5800014', '大阪府', 'オオサカフ', '松原市', 'マツバラシ', '岡', 'オカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府松原市新堂', '27', '27217', '5800015', '大阪府', 'オオサカフ', '松原市', 'マツバラシ', '新堂', 'シンドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府松原市上田', '27', '27217', '5800016', '大阪府', 'オオサカフ', '松原市', 'マツバラシ', '上田', 'ウエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府松原市柴垣', '27', '27217', '5800017', '大阪府', 'オオサカフ', '松原市', 'マツバラシ', '柴垣', 'シバガキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道様似郡様似町幌満', '01', '01608', '0580002', '北海道', 'ホッカイドウ', '様似郡様似町', 'サマニグンサマニチョウ', '幌満', 'ホロマン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府松原市高見の里', '27', '27217', '5800021', '大阪府', 'オオサカフ', '松原市', 'マツバラシ', '高見の里', 'タカミノサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府松原市河合', '27', '27217', '5800022', '大阪府', 'オオサカフ', '松原市', 'マツバラシ', '河合', 'カワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府松原市南新町', '27', '27217', '5800023', '大阪府', 'オオサカフ', '松原市', 'マツバラシ', '南新町', 'ミナミシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府松原市東新町', '27', '27217', '5800024', '大阪府', 'オオサカフ', '松原市', 'マツバラシ', '東新町', 'ヒガシシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府松原市北新町', '27', '27217', '5800025', '大阪府', 'オオサカフ', '松原市', 'マツバラシ', '北新町', 'キタシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府松原市天美我堂', '27', '27217', '5800026', '大阪府', 'オオサカフ', '松原市', 'マツバラシ', '天美我堂', 'アマミガドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道様似郡様似町冬島', '01', '01608', '0580003', '北海道', 'ホッカイドウ', '様似郡様似町', 'サマニグンサマニチョウ', '冬島', 'フユシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府松原市天美北', '27', '27217', '5800031', '大阪府', 'オオサカフ', '松原市', 'マツバラシ', '天美北', 'アマミキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府松原市天美東', '27', '27217', '5800032', '大阪府', 'オオサカフ', '松原市', 'マツバラシ', '天美東', 'アマミヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府松原市天美南', '27', '27217', '5800033', '大阪府', 'オオサカフ', '松原市', 'マツバラシ', '天美南', 'アマミミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府松原市天美西', '27', '27217', '5800034', '大阪府', 'オオサカフ', '松原市', 'マツバラシ', '天美西', 'アマミニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道様似郡様似町平宇', '01', '01608', '0580004', '北海道', 'ホッカイドウ', '様似郡様似町', 'サマニグンサマニチョウ', '平宇', 'ヒラウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府松原市三宅東', '27', '27217', '5800041', '大阪府', 'オオサカフ', '松原市', 'マツバラシ', '三宅東', 'ミヤケヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府松原市松ケ丘', '27', '27217', '5800042', '大阪府', 'オオサカフ', '松原市', 'マツバラシ', '松ケ丘', 'マツガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府松原市阿保', '27', '27217', '5800043', '大阪府', 'オオサカフ', '松原市', 'マツバラシ', '阿保', 'アオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府松原市田井城', '27', '27217', '5800044', '大阪府', 'オオサカフ', '松原市', 'マツバラシ', '田井城', 'タイジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府松原市三宅西', '27', '27217', '5800045', '大阪府', 'オオサカフ', '松原市', 'マツバラシ', '三宅西', 'ミヤケニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府松原市三宅中', '27', '27217', '5800046', '大阪府', 'オオサカフ', '松原市', 'マツバラシ', '三宅中', 'ミヤケナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道様似郡様似町田代', '01', '01608', '0580011', '北海道', 'ホッカイドウ', '様似郡様似町', 'サマニグンサマニチョウ', '田代', 'タシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道様似郡様似町朝日丘', '01', '01608', '0580012', '北海道', 'ホッカイドウ', '様似郡様似町', 'サマニグンサマニチョウ', '朝日丘', 'アサヒオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道様似郡様似町緑町', '01', '01608', '0580013', '北海道', 'ホッカイドウ', '様似郡様似町', 'サマニグンサマニチョウ', '緑町', 'ミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道様似郡様似町大通', '01', '01608', '0580014', '北海道', 'ホッカイドウ', '様似郡様似町', 'サマニグンサマニチョウ', '大通', 'オオドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道様似郡様似町錦町', '01', '01608', '0580015', '北海道', 'ホッカイドウ', '様似郡様似町', 'サマニグンサマニチョウ', '錦町', 'ニシキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道様似郡様似町新富', '01', '01608', '0580021', '北海道', 'ホッカイドウ', '様似郡様似町', 'サマニグンサマニチョウ', '新富', 'シントミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道様似郡様似町岡田', '01', '01608', '0580022', '北海道', 'ホッカイドウ', '様似郡様似町', 'サマニグンサマニチョウ', '岡田', 'オカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道様似郡様似町栄町', '01', '01608', '0580023', '北海道', 'ホッカイドウ', '様似郡様似町', 'サマニグンサマニチョウ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道様似郡様似町会所町', '01', '01608', '0580024', '北海道', 'ホッカイドウ', '様似郡様似町', 'サマニグンサマニチョウ', '会所町', 'カイショマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道様似郡様似町港町', '01', '01608', '0580025', '北海道', 'ホッカイドウ', '様似郡様似町', 'サマニグンサマニチョウ', '港町', 'ミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道様似郡様似町本町', '01', '01608', '0580026', '北海道', 'ホッカイドウ', '様似郡様似町', 'サマニグンサマニチョウ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道様似郡様似町潮見台', '01', '01608', '0580027', '北海道', 'ホッカイドウ', '様似郡様似町', 'サマニグンサマニチョウ', '潮見台', 'シオミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道様似郡様似町西様似', '01', '01608', '0580031', '北海道', 'ホッカイドウ', '様似郡様似町', 'サマニグンサマニチョウ', '西様似', 'ニシサマニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道様似郡様似町西町', '01', '01608', '0580032', '北海道', 'ホッカイドウ', '様似郡様似町', 'サマニグンサマニチョウ', '西町', 'ニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道様似郡様似町鵜苫', '01', '01608', '0580033', '北海道', 'ホッカイドウ', '様似郡様似町', 'サマニグンサマニチョウ', '鵜苫', 'ウトマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道浦河郡浦河町東幌別', '01', '01607', '0580041', '北海道', 'ホッカイドウ', '浦河郡浦河町', 'ウラカワグンウラカワチョウ', '東幌別', 'ヒガシホロベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道幌泉郡えりも町', '01', '01609', '0580200', '北海道', 'ホッカイドウ', '幌泉郡えりも町', 'ホロイズミグンエリモチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('62815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道幌泉郡えりも町東洋歌露', '01', '01609', '0580201', '北海道', 'ホッカイドウ', '幌泉郡えりも町', 'ホロイズミグンエリモチョウ', '東洋', 'トウヨウ', null, null, '歌露', 'ウタロ');
INSERT INTO `ms_addresses` VALUES ('62816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道幌泉郡えりも町東洋エンドマカゲ', '01', '01609', '0580201', '北海道', 'ホッカイドウ', '幌泉郡えりも町', 'ホロイズミグンエリモチョウ', '東洋', 'トウヨウ', null, null, 'エンドマカゲ', 'エンドマカゲ');
INSERT INTO `ms_addresses` VALUES ('62817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道幌泉郡えりも町東洋エンドモ', '01', '01609', '0580201', '北海道', 'ホッカイドウ', '幌泉郡えりも町', 'ホロイズミグンエリモチョウ', '東洋', 'トウヨウ', null, null, 'エンドモ', 'エンドモ');
INSERT INTO `ms_addresses` VALUES ('62818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道幌泉郡えりも町東洋坂岸', '01', '01609', '0580201', '北海道', 'ホッカイドウ', '幌泉郡えりも町', 'ホロイズミグンエリモチョウ', '東洋', 'トウヨウ', null, null, '坂岸', 'サカギシ');
INSERT INTO `ms_addresses` VALUES ('62819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道幌泉郡えりも町歌別', '01', '01609', '0580202', '北海道', 'ホッカイドウ', '幌泉郡えりも町', 'ホロイズミグンエリモチョウ', '歌別', 'ウタベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道幌泉郡えりも町新浜', '01', '01609', '0580203', '北海道', 'ホッカイドウ', '幌泉郡えりも町', 'ホロイズミグンエリモチョウ', '新浜', 'シンハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道幌泉郡えりも町本町', '01', '01609', '0580204', '北海道', 'ホッカイドウ', '幌泉郡えりも町', 'ホロイズミグンエリモチョウ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道幌泉郡えりも町大和', '01', '01609', '0580205', '北海道', 'ホッカイドウ', '幌泉郡えりも町', 'ホロイズミグンエリモチョウ', '大和', 'ヤマト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道幌泉郡えりも町笛舞', '01', '01609', '0580206', '北海道', 'ホッカイドウ', '幌泉郡えりも町', 'ホロイズミグンエリモチョウ', '笛舞', 'フエマイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道幌泉郡えりも町近浦', '01', '01609', '0580207', '北海道', 'ホッカイドウ', '幌泉郡えりも町', 'ホロイズミグンエリモチョウ', '近浦', 'チカウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道幌泉郡えりも町苫別', '01', '01609', '0580341', '北海道', 'ホッカイドウ', '幌泉郡えりも町', 'ホロイズミグンエリモチョウ', '苫別', 'トマベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道幌泉郡えりも町えりも岬', '01', '01609', '0580342', '北海道', 'ホッカイドウ', '幌泉郡えりも町', 'ホロイズミグンエリモチョウ', 'えりも岬', 'エリモミサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道幌泉郡えりも町東洋', '01', '01609', '0580343', '北海道', 'ホッカイドウ', '幌泉郡えりも町', 'ホロイズミグンエリモチョウ', '東洋', 'トウヨウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道幌泉郡えりも町東洋油駒', '01', '01609', '0580343', '北海道', 'ホッカイドウ', '幌泉郡えりも町', 'ホロイズミグンエリモチョウ', '東洋', 'トウヨウ', null, null, '油駒', 'アブラコマ');
INSERT INTO `ms_addresses` VALUES ('62830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道幌泉郡えりも町東洋南東洋', '01', '01609', '0580343', '北海道', 'ホッカイドウ', '幌泉郡えりも町', 'ホロイズミグンエリモチョウ', '東洋', 'トウヨウ', null, null, '南東洋', 'ミナミトウヨウ');
INSERT INTO `ms_addresses` VALUES ('62831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道幌泉郡えりも町庶野', '01', '01609', '0580421', '北海道', 'ホッカイドウ', '幌泉郡えりも町', 'ホロイズミグンエリモチョウ', '庶野', 'ショヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道幌泉郡えりも町目黒', '01', '01609', '0580422', '北海道', 'ホッカイドウ', '幌泉郡えりも町', 'ホロイズミグンエリモチョウ', '目黒', 'メグロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市', '27', '27212', '5810000', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('62840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市末広町', '27', '27212', '5810001', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '末広町', 'スエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市東久宝寺', '27', '27212', '5810002', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '東久宝寺', 'ヒガシキュウホウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市本町', '27', '27212', '5810003', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市東本町', '27', '27212', '5810004', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '東本町', 'ヒガシホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市荘内町', '27', '27212', '5810005', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '荘内町', 'ソウナイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市清水町', '27', '27212', '5810006', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '清水町', 'シミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市光南町', '27', '27212', '5810007', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '光南町', 'コウナンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市若草町', '27', '27212', '5810011', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '若草町', 'ワカクサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市小阪合町', '27', '27212', '5810012', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '小阪合町', 'コザカアイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市山本町南', '27', '27212', '5810013', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '山本町南', 'ヤマモトチョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市中田', '27', '27212', '5810014', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '中田', 'ナカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市刑部', '27', '27212', '5810015', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '刑部', 'オサカベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市八尾木北', '27', '27212', '5810016', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '八尾木北', 'ヤオギキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市高美町', '27', '27212', '5810017', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '高美町', 'タカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市青山町', '27', '27212', '5810018', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '青山町', 'アオヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市南小阪合町', '27', '27212', '5810019', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '南小阪合町', 'ミナミコザカアイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市曙川東', '27', '27212', '5810020', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '曙川東', 'アケガワヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市山本高安町', '27', '27212', '5810021', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '山本高安町', 'ヤマモトタカヤスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市柏村町', '27', '27212', '5810022', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '柏村町', 'カシムラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市都塚', '27', '27212', '5810023', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '都塚', 'ミヤコヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市二俣', '27', '27212', '5810024', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '二俣', 'フタマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市天王寺屋', '27', '27212', '5810025', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '天王寺屋', 'テンノウジヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市曙町', '27', '27212', '5810026', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '曙町', 'アケボノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市八尾木', '27', '27212', '5810027', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '八尾木', 'ヤオギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市八尾木東', '27', '27212', '5810028', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '八尾木東', 'ヤオギヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市東弓削', '27', '27212', '5810029', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '東弓削', 'ヒガシユゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市志紀町', '27', '27212', '5810031', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '志紀町', 'シキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市弓削町', '27', '27212', '5810032', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '弓削町', 'ユウゲチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市志紀町南', '27', '27212', '5810033', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '志紀町南', 'シキチョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市弓削町南', '27', '27212', '5810034', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '弓削町南', 'ユウゲチョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市西弓削', '27', '27212', '5810035', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '西弓削', 'ニシユウゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市沼', '27', '27212', '5810036', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '沼', 'ヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市太田', '27', '27212', '5810037', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '太田', 'オオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市若林町', '27', '27212', '5810038', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '若林町', 'ワカバヤシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市太田新町', '27', '27212', '5810039', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '太田新町', 'オオタシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市北木の本', '27', '27212', '5810041', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '北木の本', 'キタキノモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市南木の本', '27', '27212', '5810042', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '南木の本', 'ミナミキノモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市空港', '27', '27212', '5810043', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '空港', 'クウコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市木の本', '27', '27212', '5810044', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '木の本', 'キノモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市西木の本', '27', '27212', '5810045', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '西木の本', 'ニシキノモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市竹渕西', '27', '27212', '5810051', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '竹渕西', 'タケフチニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市竹渕', '27', '27212', '5810052', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '竹渕', 'タケフチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市竹渕東', '27', '27212', '5810053', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '竹渕東', 'タケフチヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市南亀井町', '27', '27212', '5810054', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '南亀井町', 'ミナミカメイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市跡部南の町', '27', '27212', '5810055', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '跡部南の町', 'アトベミナミノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市南太子堂', '27', '27212', '5810056', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '南太子堂', 'ミナミタイシドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市春日町', '27', '27212', '5810061', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '春日町', 'カスガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市東太子', '27', '27212', '5810062', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '東太子', 'ヒガシタイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市太子堂', '27', '27212', '5810063', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '太子堂', 'タイシドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市跡部本町', '27', '27212', '5810064', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '跡部本町', 'アトベホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市亀井町', '27', '27212', '5810065', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '亀井町', 'カメイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市北亀井町', '27', '27212', '5810066', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '北亀井町', 'キタカメイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市神武町', '27', '27212', '5810067', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '神武町', 'ジンムチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市跡部北の町', '27', '27212', '5810068', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '跡部北の町', 'アトベキタノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市龍華町', '27', '27212', '5810069', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '龍華町', 'リュウゲチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市北久宝寺', '27', '27212', '5810071', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '北久宝寺', 'キタキュウホウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市久宝寺', '27', '27212', '5810072', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '久宝寺', 'キュウホウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市高町', '27', '27212', '5810073', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '高町', 'タカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市栄町', '27', '27212', '5810074', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市渋川町', '27', '27212', '5810075', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '渋川町', 'シブカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市南久宝寺', '27', '27212', '5810076', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '南久宝寺', 'ミナミキュウホウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市西久宝寺', '27', '27212', '5810077', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '西久宝寺', 'ニシキュウホウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市南本町', '27', '27212', '5810081', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '南本町', 'ミナミホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市相生町', '27', '27212', '5810082', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '相生町', 'アイオイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市永畑町', '27', '27212', '5810083', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '永畑町', 'ナガハタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市植松町', '27', '27212', '5810084', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '植松町', 'ウエマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市安中町', '27', '27212', '5810085', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '安中町', 'ヤスナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市陽光園', '27', '27212', '5810086', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '陽光園', 'ヨウコウエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市明美町', '27', '27212', '5810087', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '明美町', 'アケミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市松山町', '27', '27212', '5810088', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '松山町', 'マツヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市南植松町', '27', '27212', '5810091', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '南植松町', 'ミナミウエマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市老原', '27', '27212', '5810092', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '老原', 'オイハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市東老原', '27', '27212', '5810093', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '東老原', 'ヒガシオイハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市志紀町西', '27', '27212', '5810094', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '志紀町西', 'シキチョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市田井中', '27', '27212', '5810095', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '田井中', 'タイナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市山城町', '27', '27212', '5810801', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '山城町', 'ヤマシロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市北本町', '27', '27212', '5810802', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '北本町', 'キタホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市光町', '27', '27212', '5810803', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '光町', 'ヒカリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市新家町', '27', '27212', '5810811', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '新家町', 'シンケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市山賀町', '27', '27212', '5810812', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '山賀町', 'ヤマガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市泉町', '27', '27212', '5810813', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '泉町', 'イズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市楠根町', '27', '27212', '5810814', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '楠根町', 'クスネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市宮町', '27', '27212', '5810815', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '宮町', 'ミヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市佐堂町', '27', '27212', '5810816', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '佐堂町', 'サドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市久宝園', '27', '27212', '5810817', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '久宝園', 'キュウホウエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市美園町', '27', '27212', '5810818', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '美園町', 'ミソノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市幸町', '27', '27212', '5810821', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市高砂町', '27', '27212', '5810822', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '高砂町', 'タカサゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市桂町', '27', '27212', '5810823', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '桂町', 'カツラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市山本町北', '27', '27212', '5810831', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '山本町北', 'ヤマモトチョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市堤町', '27', '27212', '5810832', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '堤町', 'ツツミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市旭ケ丘', '27', '27212', '5810833', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '旭ケ丘', 'アサヒガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市萱振町', '27', '27212', '5810834', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '萱振町', 'カヤフリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市小畑町', '27', '27212', '5810835', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '小畑町', 'コハタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市長池町', '27', '27212', '5810836', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '長池町', 'ナガイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市緑ケ丘', '27', '27212', '5810837', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '緑ケ丘', 'ミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市福万寺町北', '27', '27212', '5810841', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '福万寺町北', 'フクマンジチョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市福万寺町', '27', '27212', '5810842', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '福万寺町', 'フクマンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市福万寺町南', '27', '27212', '5810843', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '福万寺町南', 'フクマンジチョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市福栄町', '27', '27212', '5810844', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '福栄町', 'フクエイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市上之島町北', '27', '27212', '5810845', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '上之島町北', 'カミノシマチョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市上之島町南', '27', '27212', '5810846', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '上之島町南', 'カミノシマチョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市東山本町', '27', '27212', '5810847', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '東山本町', 'ヒガシヤマモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市上尾町', '27', '27212', '5810851', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '上尾町', 'カミオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市西高安町', '27', '27212', '5810852', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '西高安町', 'ニシタカヤスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市楽音寺', '27', '27212', '5810853', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '楽音寺', 'ガクオンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市大竹', '27', '27212', '5810854', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '大竹', 'オオタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市神立', '27', '27212', '5810855', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '神立', 'コウダチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市水越', '27', '27212', '5810856', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '水越', 'ミズコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市東町', '27', '27212', '5810861', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '東町', 'ヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市千塚', '27', '27212', '5810862', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '千塚', 'チヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市大窪', '27', '27212', '5810863', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '大窪', 'オオクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市山畑', '27', '27212', '5810864', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '山畑', 'ヤマタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市服部川', '27', '27212', '5810865', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '服部川', 'ハットリガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市東山本新町', '27', '27212', '5810866', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '東山本新町', 'ヒガシヤマモトシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市山本町', '27', '27212', '5810867', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '山本町', 'ヤマモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市西山本町', '27', '27212', '5810868', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '西山本町', 'ニシヤマモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市桜ケ丘', '27', '27212', '5810869', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '桜ケ丘', 'サクラガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市高安町北', '27', '27212', '5810871', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '高安町北', 'タカヤスチョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市郡川', '27', '27212', '5810872', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '郡川', 'コオリガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市黒谷', '27', '27212', '5810873', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '黒谷', 'クロダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市教興寺', '27', '27212', '5810874', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '教興寺', 'キョウコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市高安町南', '27', '27212', '5810875', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '高安町南', 'タカヤスチョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市垣内', '27', '27212', '5810881', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '垣内', 'カイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市恩智北町', '27', '27212', '5810882', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '恩智北町', 'オンヂキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市恩智中町', '27', '27212', '5810883', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '恩智中町', 'オンヂナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市恩智南町', '27', '27212', '5810884', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '恩智南町', 'オンヂミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府八尾市神宮寺', '27', '27212', '5810885', '大阪府', 'オオサカフ', '八尾市', 'ヤオシ', '神宮寺', 'ジングウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府柏原市', '27', '27221', '5820000', '大阪府', 'オオサカフ', '柏原市', 'カシワラシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('62973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府柏原市本郷', '27', '27221', '5820001', '大阪府', 'オオサカフ', '柏原市', 'カシワラシ', '本郷', 'ホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府柏原市今町', '27', '27221', '5820002', '大阪府', 'オオサカフ', '柏原市', 'カシワラシ', '今町', 'イママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府柏原市堂島町', '27', '27221', '5820003', '大阪府', 'オオサカフ', '柏原市', 'カシワラシ', '堂島町', 'ドウジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府柏原市河原町', '27', '27221', '5820004', '大阪府', 'オオサカフ', '柏原市', 'カシワラシ', '河原町', 'カワハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府柏原市法善寺', '27', '27221', '5820005', '大阪府', 'オオサカフ', '柏原市', 'カシワラシ', '法善寺', 'ホウゼンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府柏原市清州', '27', '27221', '5820006', '大阪府', 'オオサカフ', '柏原市', 'カシワラシ', '清州', 'キヨス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府柏原市上市', '27', '27221', '5820007', '大阪府', 'オオサカフ', '柏原市', 'カシワラシ', '上市', 'カミイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府柏原市古町', '27', '27221', '5820008', '大阪府', 'オオサカフ', '柏原市', 'カシワラシ', '古町', 'フルマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府柏原市大正', '27', '27221', '5820009', '大阪府', 'オオサカフ', '柏原市', 'カシワラシ', '大正', 'タイショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府柏原市山ノ井町', '27', '27221', '5820010', '大阪府', 'オオサカフ', '柏原市', 'カシワラシ', '山ノ井町', 'ヤマノイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府柏原市本堂', '27', '27221', '5820011', '大阪府', 'オオサカフ', '柏原市', 'カシワラシ', '本堂', 'ホンドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府柏原市雁多尾畑', '27', '27221', '5820012', '大阪府', 'オオサカフ', '柏原市', 'カシワラシ', '雁多尾畑', 'カリンドオバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府柏原市峠', '27', '27221', '5820013', '大阪府', 'オオサカフ', '柏原市', 'カシワラシ', '峠', 'トウゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府柏原市青谷', '27', '27221', '5820014', '大阪府', 'オオサカフ', '柏原市', 'カシワラシ', '青谷', 'アオタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府柏原市高井田', '27', '27221', '5820015', '大阪府', 'オオサカフ', '柏原市', 'カシワラシ', '高井田', 'タカイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府柏原市安堂町', '27', '27221', '5820016', '大阪府', 'オオサカフ', '柏原市', 'カシワラシ', '安堂町', 'アンドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府柏原市太平寺', '27', '27221', '5820017', '大阪府', 'オオサカフ', '柏原市', 'カシワラシ', '太平寺', 'タイヘイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府柏原市大県', '27', '27221', '5820018', '大阪府', 'オオサカフ', '柏原市', 'カシワラシ', '大県', 'オオガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府柏原市平野', '27', '27221', '5820019', '大阪府', 'オオサカフ', '柏原市', 'カシワラシ', '平野', 'ヒラノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府柏原市片山町', '27', '27221', '5820020', '大阪府', 'オオサカフ', '柏原市', 'カシワラシ', '片山町', 'カタヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府柏原市国分本町', '27', '27221', '5820021', '大阪府', 'オオサカフ', '柏原市', 'カシワラシ', '国分本町', 'コクブホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府柏原市国分市場', '27', '27221', '5820022', '大阪府', 'オオサカフ', '柏原市', 'カシワラシ', '国分市場', 'コクブイチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府柏原市国分東条町', '27', '27221', '5820023', '大阪府', 'オオサカフ', '柏原市', 'カシワラシ', '国分東条町', 'コクブヒガンジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府柏原市田辺', '27', '27221', '5820024', '大阪府', 'オオサカフ', '柏原市', 'カシワラシ', '田辺', 'タナベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府柏原市国分西', '27', '27221', '5820025', '大阪府', 'オオサカフ', '柏原市', 'カシワラシ', '国分西', 'コクブニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府柏原市旭ケ丘', '27', '27221', '5820026', '大阪府', 'オオサカフ', '柏原市', 'カシワラシ', '旭ケ丘', 'アサヒガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('62999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府柏原市円明町', '27', '27221', '5820027', '大阪府', 'オオサカフ', '柏原市', 'カシワラシ', '円明町', 'エンミョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府柏原市玉手町', '27', '27221', '5820028', '大阪府', 'オオサカフ', '柏原市', 'カシワラシ', '玉手町', 'タマテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府柏原市石川町', '27', '27221', '5820029', '大阪府', 'オオサカフ', '柏原市', 'カシワラシ', '石川町', 'イシカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府羽曳野市', '27', '27222', '5830000', '大阪府', 'オオサカフ', '羽曳野市', 'ハビキノシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('63007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府藤井寺市', '27', '27226', '5830000', '大阪府', 'オオサカフ', '藤井寺市', 'フジイデラシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('63008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府南河内郡太子町', '27', '27381', '5830000', '大阪府', 'オオサカフ', '南河内郡太子町', 'ミナミカワチグンタイシチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('63009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府藤井寺市川北', '27', '27226', '5830001', '大阪府', 'オオサカフ', '藤井寺市', 'フジイデラシ', '川北', 'カワキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府藤井寺市北條町', '27', '27226', '5830002', '大阪府', 'オオサカフ', '藤井寺市', 'フジイデラシ', '北條町', 'ホウジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府藤井寺市船橋町', '27', '27226', '5830003', '大阪府', 'オオサカフ', '藤井寺市', 'フジイデラシ', '船橋町', 'フナハシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府藤井寺市梅が園町', '27', '27226', '5830004', '大阪府', 'オオサカフ', '藤井寺市', 'フジイデラシ', '梅が園町', 'ウメガエンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府藤井寺市惣社', '27', '27226', '5830005', '大阪府', 'オオサカフ', '藤井寺市', 'フジイデラシ', '惣社', 'ソウシャ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府藤井寺市国府', '27', '27226', '5830006', '大阪府', 'オオサカフ', '藤井寺市', 'フジイデラシ', '国府', 'コウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府藤井寺市林', '27', '27226', '5830007', '大阪府', 'オオサカフ', '藤井寺市', 'フジイデラシ', '林', 'ハヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府藤井寺市大井', '27', '27226', '5830008', '大阪府', 'オオサカフ', '藤井寺市', 'フジイデラシ', '大井', 'オオイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府藤井寺市西大井', '27', '27226', '5830009', '大阪府', 'オオサカフ', '藤井寺市', 'フジイデラシ', '西大井', 'ニシオオイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府藤井寺市沢田', '27', '27226', '5830011', '大阪府', 'オオサカフ', '藤井寺市', 'フジイデラシ', '沢田', 'サワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府藤井寺市道明寺', '27', '27226', '5830012', '大阪府', 'オオサカフ', '藤井寺市', 'フジイデラシ', '道明寺', 'ドウミョウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府藤井寺市古室', '27', '27226', '5830013', '大阪府', 'オオサカフ', '藤井寺市', 'フジイデラシ', '古室', 'コムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府藤井寺市野中', '27', '27226', '5830014', '大阪府', 'オオサカフ', '藤井寺市', 'フジイデラシ', '野中', 'ノナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府藤井寺市青山', '27', '27226', '5830015', '大阪府', 'オオサカフ', '藤井寺市', 'フジイデラシ', '青山', 'アオヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府藤井寺市陵南町', '27', '27226', '5830016', '大阪府', 'オオサカフ', '藤井寺市', 'フジイデラシ', '陵南町', 'リョウナンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府藤井寺市藤ケ丘', '27', '27226', '5830017', '大阪府', 'オオサカフ', '藤井寺市', 'フジイデラシ', '藤ケ丘', 'フジガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府藤井寺市西古室', '27', '27226', '5830018', '大阪府', 'オオサカフ', '藤井寺市', 'フジイデラシ', '西古室', 'ニシコムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府藤井寺市御舟町', '27', '27226', '5830021', '大阪府', 'オオサカフ', '藤井寺市', 'フジイデラシ', '御舟町', 'ミフネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府藤井寺市東藤井寺町', '27', '27226', '5830022', '大阪府', 'オオサカフ', '藤井寺市', 'フジイデラシ', '東藤井寺町', 'ヒガシフジイデラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府藤井寺市さくら町', '27', '27226', '5830023', '大阪府', 'オオサカフ', '藤井寺市', 'フジイデラシ', 'さくら町', 'サクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府藤井寺市藤井寺', '27', '27226', '5830024', '大阪府', 'オオサカフ', '藤井寺市', 'フジイデラシ', '藤井寺', 'フジイデラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府藤井寺市春日丘新町', '27', '27226', '5830025', '大阪府', 'オオサカフ', '藤井寺市', 'フジイデラシ', '春日丘新町', 'カスガオカシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府藤井寺市春日丘', '27', '27226', '5830026', '大阪府', 'オオサカフ', '藤井寺市', 'フジイデラシ', '春日丘', 'カスガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府藤井寺市岡', '27', '27226', '5830027', '大阪府', 'オオサカフ', '藤井寺市', 'フジイデラシ', '岡', 'オカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府藤井寺市小山新町', '27', '27226', '5830031', '大阪府', 'オオサカフ', '藤井寺市', 'フジイデラシ', '小山新町', 'コヤマシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府藤井寺市小山藤美町', '27', '27226', '5830032', '大阪府', 'オオサカフ', '藤井寺市', 'フジイデラシ', '小山藤美町', 'コヤマフジミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府藤井寺市小山', '27', '27226', '5830033', '大阪府', 'オオサカフ', '藤井寺市', 'フジイデラシ', '小山', 'コヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府藤井寺市小山藤の里町', '27', '27226', '5830034', '大阪府', 'オオサカフ', '藤井寺市', 'フジイデラシ', '小山藤の里町', 'コヤマフジノサトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府藤井寺市北岡', '27', '27226', '5830035', '大阪府', 'オオサカフ', '藤井寺市', 'フジイデラシ', '北岡', 'キタオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府藤井寺市恵美坂', '27', '27226', '5830036', '大阪府', 'オオサカフ', '藤井寺市', 'フジイデラシ', '恵美坂', 'エミサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府藤井寺市津堂', '27', '27226', '5830037', '大阪府', 'オオサカフ', '藤井寺市', 'フジイデラシ', '津堂', 'ツドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府羽曳野市駒ケ谷', '27', '27222', '5830841', '大阪府', 'オオサカフ', '羽曳野市', 'ハビキノシ', '駒ケ谷', 'コマガタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府羽曳野市飛鳥', '27', '27222', '5830842', '大阪府', 'オオサカフ', '羽曳野市', 'ハビキノシ', '飛鳥', 'アスカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府羽曳野市通法寺', '27', '27222', '5830843', '大阪府', 'オオサカフ', '羽曳野市', 'ハビキノシ', '通法寺', 'ツウホウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府羽曳野市壺井', '27', '27222', '5830844', '大阪府', 'オオサカフ', '羽曳野市', 'ハビキノシ', '壺井', 'ツボイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府羽曳野市広瀬', '27', '27222', '5830845', '大阪府', 'オオサカフ', '羽曳野市', 'ハビキノシ', '広瀬', 'ヒロセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府羽曳野市東阪田', '27', '27222', '5830846', '大阪府', 'オオサカフ', '羽曳野市', 'ハビキノシ', '東阪田', 'ヒガシサカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府羽曳野市大黒', '27', '27222', '5830847', '大阪府', 'オオサカフ', '羽曳野市', 'ハビキノシ', '大黒', 'オグロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府羽曳野市川向', '27', '27222', '5830848', '大阪府', 'オオサカフ', '羽曳野市', 'ハビキノシ', '川向', 'カワムカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府羽曳野市碓井', '27', '27222', '5830851', '大阪府', 'オオサカフ', '羽曳野市', 'ハビキノシ', '碓井', 'ウスイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府羽曳野市古市', '27', '27222', '5830852', '大阪府', 'オオサカフ', '羽曳野市', 'ハビキノシ', '古市', 'フルイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府羽曳野市栄町', '27', '27222', '5830853', '大阪府', 'オオサカフ', '羽曳野市', 'ハビキノシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府羽曳野市軽里', '27', '27222', '5830854', '大阪府', 'オオサカフ', '羽曳野市', 'ハビキノシ', '軽里', 'カルサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府羽曳野市翠鳥園', '27', '27222', '5830855', '大阪府', 'オオサカフ', '羽曳野市', 'ハビキノシ', '翠鳥園', 'スイチョウエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府羽曳野市白鳥', '27', '27222', '5830856', '大阪府', 'オオサカフ', '羽曳野市', 'ハビキノシ', '白鳥', 'ハクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府羽曳野市誉田', '27', '27222', '5830857', '大阪府', 'オオサカフ', '羽曳野市', 'ハビキノシ', '誉田', 'コンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府羽曳野市南古市', '27', '27222', '5830858', '大阪府', 'オオサカフ', '羽曳野市', 'ハビキノシ', '南古市', 'ミナミフルイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府羽曳野市西浦', '27', '27222', '5830861', '大阪府', 'オオサカフ', '羽曳野市', 'ハビキノシ', '西浦', 'ニシウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府羽曳野市尺度', '27', '27222', '5830862', '大阪府', 'オオサカフ', '羽曳野市', 'ハビキノシ', '尺度', 'シャクド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府羽曳野市蔵之内', '27', '27222', '5830863', '大阪府', 'オオサカフ', '羽曳野市', 'ハビキノシ', '蔵之内', 'クラノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府羽曳野市羽曳が丘', '27', '27222', '5830864', '大阪府', 'オオサカフ', '羽曳野市', 'ハビキノシ', '羽曳が丘', 'ハビキガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府羽曳野市羽曳が丘西', '27', '27222', '5830865', '大阪府', 'オオサカフ', '羽曳野市', 'ハビキノシ', '羽曳が丘西', 'ハビキガオカニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府羽曳野市埴生野', '27', '27222', '5830866', '大阪府', 'オオサカフ', '羽曳野市', 'ハビキノシ', '埴生野', 'ハニュウノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府羽曳野市河原城', '27', '27222', '5830867', '大阪府', 'オオサカフ', '羽曳野市', 'ハビキノシ', '河原城', 'カワハラジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府羽曳野市学園前', '27', '27222', '5830868', '大阪府', 'オオサカフ', '羽曳野市', 'ハビキノシ', '学園前', 'ガクエンマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府羽曳野市野々上', '27', '27222', '5830871', '大阪府', 'オオサカフ', '羽曳野市', 'ハビキノシ', '野々上', 'ノノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府羽曳野市はびきの', '27', '27222', '5830872', '大阪府', 'オオサカフ', '羽曳野市', 'ハビキノシ', 'はびきの', 'ハビキノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府羽曳野市桃山台', '27', '27222', '5830873', '大阪府', 'オオサカフ', '羽曳野市', 'ハビキノシ', '桃山台', 'モモヤマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府羽曳野市郡戸', '27', '27222', '5830874', '大阪府', 'オオサカフ', '羽曳野市', 'ハビキノシ', '郡戸', 'コオズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府羽曳野市樫山', '27', '27222', '5830875', '大阪府', 'オオサカフ', '羽曳野市', 'ハビキノシ', '樫山', 'カシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府羽曳野市伊賀', '27', '27222', '5830876', '大阪府', 'オオサカフ', '羽曳野市', 'ハビキノシ', '伊賀', 'イガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府羽曳野市島泉', '27', '27222', '5830881', '大阪府', 'オオサカフ', '羽曳野市', 'ハビキノシ', '島泉', 'シマイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府羽曳野市高鷲', '27', '27222', '5830882', '大阪府', 'オオサカフ', '羽曳野市', 'ハビキノシ', '高鷲', 'タカワシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府羽曳野市向野', '27', '27222', '5830883', '大阪府', 'オオサカフ', '羽曳野市', 'ハビキノシ', '向野', 'ムカイノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府羽曳野市野', '27', '27222', '5830884', '大阪府', 'オオサカフ', '羽曳野市', 'ハビキノシ', '野', 'ノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府羽曳野市南恵我之荘', '27', '27222', '5830885', '大阪府', 'オオサカフ', '羽曳野市', 'ハビキノシ', '南恵我之荘', 'ミナミエガノショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府羽曳野市恵我之荘', '27', '27222', '5830886', '大阪府', 'オオサカフ', '羽曳野市', 'ハビキノシ', '恵我之荘', 'エガノショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府南河内郡太子町春日', '27', '27381', '5830991', '大阪府', 'オオサカフ', '南河内郡太子町', 'ミナミカワチグンタイシチョウ', '春日', 'カスガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府南河内郡太子町山田', '27', '27381', '5830992', '大阪府', 'オオサカフ', '南河内郡太子町', 'ミナミカワチグンタイシチョウ', '山田', 'ヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府南河内郡太子町畑', '27', '27381', '5830993', '大阪府', 'オオサカフ', '南河内郡太子町', 'ミナミカワチグンタイシチョウ', '畑', 'ハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府南河内郡太子町葉室', '27', '27381', '5830994', '大阪府', 'オオサカフ', '南河内郡太子町', 'ミナミカワチグンタイシチョウ', '葉室', 'ハムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府南河内郡太子町太子', '27', '27381', '5830995', '大阪府', 'オオサカフ', '南河内郡太子町', 'ミナミカワチグンタイシチョウ', '太子', 'タイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府南河内郡太子町聖和台', '27', '27381', '5830996', '大阪府', 'オオサカフ', '南河内郡太子町', 'ミナミカワチグンタイシチョウ', '聖和台', 'セイワダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府富田林市', '27', '27214', '5840000', '大阪府', 'オオサカフ', '富田林市', 'トンダバヤシシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('63093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府富田林市梅の里', '27', '27214', '5840001', '大阪府', 'オオサカフ', '富田林市', 'トンダバヤシシ', '梅の里', 'ウメノサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府富田林市平町', '27', '27214', '5840002', '大阪府', 'オオサカフ', '富田林市', 'トンダバヤシシ', '平町', 'ヒラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府富田林市喜志新家町', '27', '27214', '5840003', '大阪府', 'オオサカフ', '富田林市', 'トンダバヤシシ', '喜志新家町', 'キシシンケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府富田林市木戸山町', '27', '27214', '5840004', '大阪府', 'オオサカフ', '富田林市', 'トンダバヤシシ', '木戸山町', 'キドヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府富田林市喜志町', '27', '27214', '5840005', '大阪府', 'オオサカフ', '富田林市', 'トンダバヤシシ', '喜志町', 'キシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府富田林市旭ケ丘町', '27', '27214', '5840006', '大阪府', 'オオサカフ', '富田林市', 'トンダバヤシシ', '旭ケ丘町', 'アサヒガオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府富田林市南旭ケ丘町', '27', '27214', '5840007', '大阪府', 'オオサカフ', '富田林市', 'トンダバヤシシ', '南旭ケ丘町', 'ミナミアサヒガオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府富田林市喜志', '27', '27214', '5840008', '大阪府', 'オオサカフ', '富田林市', 'トンダバヤシシ', '喜志', 'キシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府富田林市宮町', '27', '27214', '5840011', '大阪府', 'オオサカフ', '富田林市', 'トンダバヤシシ', '宮町', 'ミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府富田林市粟ケ池町', '27', '27214', '5840012', '大阪府', 'オオサカフ', '富田林市', 'トンダバヤシシ', '粟ケ池町', 'アワガイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府富田林市桜井町', '27', '27214', '5840013', '大阪府', 'オオサカフ', '富田林市', 'トンダバヤシシ', '桜井町', 'サクライチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府富田林市川面町', '27', '27214', '5840014', '大阪府', 'オオサカフ', '富田林市', 'トンダバヤシシ', '川面町', 'カワヅラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府富田林市西条町', '27', '27214', '5840015', '大阪府', 'オオサカフ', '富田林市', 'トンダバヤシシ', '西条町', 'サイジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府富田林市通法寺町', '27', '27214', '5840016', '大阪府', 'オオサカフ', '富田林市', 'トンダバヤシシ', '通法寺町', 'ツウホウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府富田林市中野町', '27', '27214', '5840021', '大阪府', 'オオサカフ', '富田林市', 'トンダバヤシシ', '中野町', 'ナカノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府富田林市中野町東', '27', '27214', '5840022', '大阪府', 'オオサカフ', '富田林市', 'トンダバヤシシ', '中野町東', 'ナカノチョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府富田林市若松町東', '27', '27214', '5840023', '大阪府', 'オオサカフ', '富田林市', 'トンダバヤシシ', '若松町東', 'ワカマツチョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府富田林市若松町', '27', '27214', '5840024', '大阪府', 'オオサカフ', '富田林市', 'トンダバヤシシ', '若松町', 'ワカマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府富田林市若松町西', '27', '27214', '5840025', '大阪府', 'オオサカフ', '富田林市', 'トンダバヤシシ', '若松町西', 'ワカマツチョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府富田林市緑ケ丘町', '27', '27214', '5840026', '大阪府', 'オオサカフ', '富田林市', 'トンダバヤシシ', '緑ケ丘町', 'ミドリガオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府富田林市中野', '27', '27214', '5840027', '大阪府', 'オオサカフ', '富田林市', 'トンダバヤシシ', '中野', 'ナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府富田林市中野町西', '27', '27214', '5840028', '大阪府', 'オオサカフ', '富田林市', 'トンダバヤシシ', '中野町西', 'ナカノチョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府富田林市寿町', '27', '27214', '5840031', '大阪府', 'オオサカフ', '富田林市', 'トンダバヤシシ', '寿町', 'コトブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府富田林市常盤町', '27', '27214', '5840032', '大阪府', 'オオサカフ', '富田林市', 'トンダバヤシシ', '常盤町', 'トキワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府富田林市富田林町', '27', '27214', '5840033', '大阪府', 'オオサカフ', '富田林市', 'トンダバヤシシ', '富田林町', 'トンダバヤシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府富田林市清水町', '27', '27214', '5840034', '大阪府', 'オオサカフ', '富田林市', 'トンダバヤシシ', '清水町', 'シミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府富田林市谷川町', '27', '27214', '5840035', '大阪府', 'オオサカフ', '富田林市', 'トンダバヤシシ', '谷川町', 'タニガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府富田林市甲田', '27', '27214', '5840036', '大阪府', 'オオサカフ', '富田林市', 'トンダバヤシシ', '甲田', 'コウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府富田林市宮甲田町', '27', '27214', '5840037', '大阪府', 'オオサカフ', '富田林市', 'トンダバヤシシ', '宮甲田町', 'ミヤコウダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府富田林市錦ケ丘町', '27', '27214', '5840038', '大阪府', 'オオサカフ', '富田林市', 'トンダバヤシシ', '錦ケ丘町', 'ニシキガオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府富田林市美山台', '27', '27214', '5840039', '大阪府', 'オオサカフ', '富田林市', 'トンダバヤシシ', '美山台', 'ミヤマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府富田林市かがり台', '27', '27214', '5840040', '大阪府', 'オオサカフ', '富田林市', 'トンダバヤシシ', 'かがり台', 'カガリダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府富田林市楠町', '27', '27214', '5840041', '大阪府', 'オオサカフ', '富田林市', 'トンダバヤシシ', '楠町', 'クスノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府富田林市北大伴町', '27', '27214', '5840042', '大阪府', 'オオサカフ', '富田林市', 'トンダバヤシシ', '北大伴町', 'キタオオトモチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府富田林市南大伴町', '27', '27214', '5840043', '大阪府', 'オオサカフ', '富田林市', 'トンダバヤシシ', '南大伴町', 'ミナミオオトモチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府富田林市別井', '27', '27214', '5840044', '大阪府', 'オオサカフ', '富田林市', 'トンダバヤシシ', '別井', 'ベツイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府富田林市山中田町', '27', '27214', '5840045', '大阪府', 'オオサカフ', '富田林市', 'トンダバヤシシ', '山中田町', 'ヤマチュウダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府富田林市東板持町', '27', '27214', '5840046', '大阪府', 'オオサカフ', '富田林市', 'トンダバヤシシ', '東板持町', 'ヒガシイタモチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府富田林市山手町', '27', '27214', '5840047', '大阪府', 'オオサカフ', '富田林市', 'トンダバヤシシ', '山手町', 'ヤマテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府富田林市西板持町', '27', '27214', '5840048', '大阪府', 'オオサカフ', '富田林市', 'トンダバヤシシ', '西板持町', 'ニシイタモチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府富田林市川向町', '27', '27214', '5840049', '大阪府', 'オオサカフ', '富田林市', 'トンダバヤシシ', '川向町', 'カワムカイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府富田林市楠風台', '27', '27214', '5840051', '大阪府', 'オオサカフ', '富田林市', 'トンダバヤシシ', '楠風台', 'ナンプウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府富田林市佐備', '27', '27214', '5840052', '大阪府', 'オオサカフ', '富田林市', 'トンダバヤシシ', '佐備', 'サビ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府富田林市龍泉', '27', '27214', '5840053', '大阪府', 'オオサカフ', '富田林市', 'トンダバヤシシ', '龍泉', 'リュウセン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府富田林市甘南備', '27', '27214', '5840054', '大阪府', 'オオサカフ', '富田林市', 'トンダバヤシシ', '甘南備', 'カンナビ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府富田林市伏見堂', '27', '27214', '5840055', '大阪府', 'オオサカフ', '富田林市', 'トンダバヤシシ', '伏見堂', 'フシミドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府富田林市嬉', '27', '27214', '5840056', '大阪府', 'オオサカフ', '富田林市', 'トンダバヤシシ', '嬉', 'ウレシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府富田林市横山', '27', '27214', '5840057', '大阪府', 'オオサカフ', '富田林市', 'トンダバヤシシ', '横山', 'ヨコヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府富田林市彼方', '27', '27214', '5840058', '大阪府', 'オオサカフ', '富田林市', 'トンダバヤシシ', '彼方', 'オチカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府富田林市伏山', '27', '27214', '5840061', '大阪府', 'オオサカフ', '富田林市', 'トンダバヤシシ', '伏山', 'フシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府富田林市須賀', '27', '27214', '5840062', '大阪府', 'オオサカフ', '富田林市', 'トンダバヤシシ', '須賀', 'スガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府富田林市錦織', '27', '27214', '5840063', '大阪府', 'オオサカフ', '富田林市', 'トンダバヤシシ', '錦織', 'ニシキオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府富田林市不動ケ丘町', '27', '27214', '5840064', '大阪府', 'オオサカフ', '富田林市', 'トンダバヤシシ', '不動ケ丘町', 'フドウガオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府富田林市金剛伏山台', '27', '27214', '5840065', '大阪府', 'オオサカフ', '富田林市', 'トンダバヤシシ', '金剛伏山台', 'コンゴウフシヤマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府富田林市錦織北', '27', '27214', '5840066', '大阪府', 'オオサカフ', '富田林市', 'トンダバヤシシ', '錦織北', 'ニシキオリキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府富田林市錦織南', '27', '27214', '5840067', '大阪府', 'オオサカフ', '富田林市', 'トンダバヤシシ', '錦織南', 'ニシキオリミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府富田林市錦織中', '27', '27214', '5840068', '大阪府', 'オオサカフ', '富田林市', 'トンダバヤシシ', '錦織中', 'ニシキオリナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府富田林市錦織東', '27', '27214', '5840069', '大阪府', 'オオサカフ', '富田林市', 'トンダバヤシシ', '錦織東', 'ニシキオリヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府富田林市藤沢台', '27', '27214', '5840071', '大阪府', 'オオサカフ', '富田林市', 'トンダバヤシシ', '藤沢台', 'フジサワダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府富田林市高辺台', '27', '27214', '5840072', '大阪府', 'オオサカフ', '富田林市', 'トンダバヤシシ', '高辺台', 'タカベダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府富田林市寺池台', '27', '27214', '5840073', '大阪府', 'オオサカフ', '富田林市', 'トンダバヤシシ', '寺池台', 'テライケダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府富田林市久野喜台', '27', '27214', '5840074', '大阪府', 'オオサカフ', '富田林市', 'トンダバヤシシ', '久野喜台', 'クノキダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府富田林市青葉丘', '27', '27214', '5840076', '大阪府', 'オオサカフ', '富田林市', 'トンダバヤシシ', '青葉丘', 'アオバオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府富田林市新青葉丘町', '27', '27214', '5840077', '大阪府', 'オオサカフ', '富田林市', 'トンダバヤシシ', '新青葉丘町', 'シンアオバオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府富田林市加太', '27', '27214', '5840078', '大阪府', 'オオサカフ', '富田林市', 'トンダバヤシシ', '加太', 'カダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府富田林市五軒家', '27', '27214', '5840079', '大阪府', 'オオサカフ', '富田林市', 'トンダバヤシシ', '五軒家', 'ゴケンヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府富田林市廿山', '27', '27214', '5840081', '大阪府', 'オオサカフ', '富田林市', 'トンダバヤシシ', '廿山', 'ツヅヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府富田林市向陽台', '27', '27214', '5840082', '大阪府', 'オオサカフ', '富田林市', 'トンダバヤシシ', '向陽台', 'コウヨウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府富田林市小金台', '27', '27214', '5840083', '大阪府', 'オオサカフ', '富田林市', 'トンダバヤシシ', '小金台', 'コガネダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府富田林市桜ケ丘町', '27', '27214', '5840084', '大阪府', 'オオサカフ', '富田林市', 'トンダバヤシシ', '桜ケ丘町', 'サクラガオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府富田林市新家', '27', '27214', '5840085', '大阪府', 'オオサカフ', '富田林市', 'トンダバヤシシ', '新家', 'シンケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府富田林市津々山台', '27', '27214', '5840086', '大阪府', 'オオサカフ', '富田林市', 'トンダバヤシシ', '津々山台', 'ツヅヤマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府富田林市新堂', '27', '27214', '5840091', '大阪府', 'オオサカフ', '富田林市', 'トンダバヤシシ', '新堂', 'シンドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府富田林市昭和町', '27', '27214', '5840092', '大阪府', 'オオサカフ', '富田林市', 'トンダバヤシシ', '昭和町', 'ショウワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府富田林市本町', '27', '27214', '5840093', '大阪府', 'オオサカフ', '富田林市', 'トンダバヤシシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府富田林市富美ケ丘町', '27', '27214', '5840094', '大阪府', 'オオサカフ', '富田林市', 'トンダバヤシシ', '富美ケ丘町', 'フミガオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府富田林市毛人谷', '27', '27214', '5840095', '大阪府', 'オオサカフ', '富田林市', 'トンダバヤシシ', '毛人谷', 'エビタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府南河内郡河南町', '27', '27382', '5850000', '大阪府', 'オオサカフ', '南河内郡河南町', 'ミナミカワチグンカナンチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('63177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府南河内郡千早赤阪村', '27', '27383', '5850000', '大阪府', 'オオサカフ', '南河内郡千早赤阪村', 'ミナミカワチグンチハヤアカサカムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('63178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府南河内郡河南町東山', '27', '27382', '5850001', '大阪府', 'オオサカフ', '南河内郡河南町', 'ミナミカワチグンカナンチョウ', '東山', 'ヒガシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府南河内郡河南町一須賀', '27', '27382', '5850002', '大阪府', 'オオサカフ', '南河内郡河南町', 'ミナミカワチグンカナンチョウ', '一須賀', 'イチスカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府南河内郡河南町大ケ塚', '27', '27382', '5850003', '大阪府', 'オオサカフ', '南河内郡河南町', 'ミナミカワチグンカナンチョウ', '大ケ塚', 'ダイガツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府南河内郡河南町山城', '27', '27382', '5850004', '大阪府', 'オオサカフ', '南河内郡河南町', 'ミナミカワチグンカナンチョウ', '山城', 'ヤマシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府南河内郡河南町大宝', '27', '27382', '5850005', '大阪府', 'オオサカフ', '南河内郡河南町', 'ミナミカワチグンカナンチョウ', '大宝', 'タイホウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府南河内郡河南町葉室', '27', '27382', '5850006', '大阪府', 'オオサカフ', '南河内郡河南町', 'ミナミカワチグンカナンチョウ', '葉室', 'ハムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府南河内郡河南町寺田', '27', '27382', '5850011', '大阪府', 'オオサカフ', '南河内郡河南町', 'ミナミカワチグンカナンチョウ', '寺田', 'テラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府南河内郡河南町加納', '27', '27382', '5850012', '大阪府', 'オオサカフ', '南河内郡河南町', 'ミナミカワチグンカナンチョウ', '加納', 'カノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府南河内郡河南町平石', '27', '27382', '5850013', '大阪府', 'オオサカフ', '南河内郡河南町', 'ミナミカワチグンカナンチョウ', '平石', 'ヒライシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府南河内郡河南町白木', '27', '27382', '5850014', '大阪府', 'オオサカフ', '南河内郡河南町', 'ミナミカワチグンカナンチョウ', '白木', 'シラキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府南河内郡河南町持尾', '27', '27382', '5850021', '大阪府', 'オオサカフ', '南河内郡河南町', 'ミナミカワチグンカナンチョウ', '持尾', 'モチオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府南河内郡河南町弘川', '27', '27382', '5850022', '大阪府', 'オオサカフ', '南河内郡河南町', 'ミナミカワチグンカナンチョウ', '弘川', 'ヒロカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府南河内郡河南町下河内', '27', '27382', '5850023', '大阪府', 'オオサカフ', '南河内郡河南町', 'ミナミカワチグンカナンチョウ', '下河内', 'シモカワチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府南河内郡河南町上河内', '27', '27382', '5850024', '大阪府', 'オオサカフ', '南河内郡河南町', 'ミナミカワチグンカナンチョウ', '上河内', 'カミカワチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府南河内郡河南町さくら坂', '27', '27382', '5850025', '大阪府', 'オオサカフ', '南河内郡河南町', 'ミナミカワチグンカナンチョウ', 'さくら坂', 'サクラザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府南河内郡河南町鈴美台', '27', '27382', '5850026', '大阪府', 'オオサカフ', '南河内郡河南町', 'ミナミカワチグンカナンチョウ', '鈴美台', 'スズミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府南河内郡河南町さくら坂南', '27', '27382', '5850027', '大阪府', 'オオサカフ', '南河内郡河南町', 'ミナミカワチグンカナンチョウ', 'さくら坂南', 'サクラザカミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府南河内郡河南町中', '27', '27382', '5850031', '大阪府', 'オオサカフ', '南河内郡河南町', 'ミナミカワチグンカナンチョウ', '中', 'ナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府南河内郡河南町馬谷', '27', '27382', '5850032', '大阪府', 'オオサカフ', '南河内郡河南町', 'ミナミカワチグンカナンチョウ', '馬谷', 'マダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府南河内郡河南町芹生谷', '27', '27382', '5850033', '大阪府', 'オオサカフ', '南河内郡河南町', 'ミナミカワチグンカナンチョウ', '芹生谷', 'セリウダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府南河内郡河南町神山', '27', '27382', '5850034', '大阪府', 'オオサカフ', '南河内郡河南町', 'ミナミカワチグンカナンチョウ', '神山', 'コウヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府南河内郡河南町寛弘寺', '27', '27382', '5850035', '大阪府', 'オオサカフ', '南河内郡河南町', 'ミナミカワチグンカナンチョウ', '寛弘寺', 'カンコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府南河内郡千早赤阪村水分', '27', '27383', '5850041', '大阪府', 'オオサカフ', '南河内郡千早赤阪村', 'ミナミカワチグンチハヤアカサカムラ', '水分', 'スイブン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府南河内郡千早赤阪村二河原辺', '27', '27383', '5850042', '大阪府', 'オオサカフ', '南河内郡千早赤阪村', 'ミナミカワチグンチハヤアカサカムラ', '二河原辺', 'ニガラベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府南河内郡千早赤阪村桐山', '27', '27383', '5850043', '大阪府', 'オオサカフ', '南河内郡千早赤阪村', 'ミナミカワチグンチハヤアカサカムラ', '桐山', 'キリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府南河内郡千早赤阪村森屋', '27', '27383', '5850044', '大阪府', 'オオサカフ', '南河内郡千早赤阪村', 'ミナミカワチグンチハヤアカサカムラ', '森屋', 'モリヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府南河内郡千早赤阪村川野辺', '27', '27383', '5850045', '大阪府', 'オオサカフ', '南河内郡千早赤阪村', 'ミナミカワチグンチハヤアカサカムラ', '川野辺', 'カワノベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府南河内郡千早赤阪村千早', '27', '27383', '5850051', '大阪府', 'オオサカフ', '南河内郡千早赤阪村', 'ミナミカワチグンチハヤアカサカムラ', '千早', 'チハヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府南河内郡千早赤阪村中津原', '27', '27383', '5850052', '大阪府', 'オオサカフ', '南河内郡千早赤阪村', 'ミナミカワチグンチハヤアカサカムラ', '中津原', 'ナカツハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府南河内郡千早赤阪村小吹', '27', '27383', '5850053', '大阪府', 'オオサカフ', '南河内郡千早赤阪村', 'ミナミカワチグンチハヤアカサカムラ', '小吹', 'コブキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府南河内郡千早赤阪村吉年', '27', '27383', '5850054', '大阪府', 'オオサカフ', '南河内郡千早赤阪村', 'ミナミカワチグンチハヤアカサカムラ', '吉年', 'ヨドシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府南河内郡千早赤阪村東阪', '27', '27383', '5850055', '大阪府', 'オオサカフ', '南河内郡千早赤阪村', 'ミナミカワチグンチハヤアカサカムラ', '東阪', 'アズマザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府河内長野市', '27', '27216', '5860000', '大阪府', 'オオサカフ', '河内長野市', 'カワチナガノシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('63219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府河内長野市木戸', '27', '27216', '5860001', '大阪府', 'オオサカフ', '河内長野市', 'カワチナガノシ', '木戸', 'キド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府河内長野市木戸町', '27', '27216', '5860001', '大阪府', 'オオサカフ', '河内長野市', 'カワチナガノシ', '木戸町', 'キドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府河内長野市市町', '27', '27216', '5860002', '大阪府', 'オオサカフ', '河内長野市', 'カワチナガノシ', '市町', 'イチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府河内長野市楠町東', '27', '27216', '5860003', '大阪府', 'オオサカフ', '河内長野市', 'カワチナガノシ', '楠町東', 'クスノキチョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府河内長野市楠町西', '27', '27216', '5860004', '大阪府', 'オオサカフ', '河内長野市', 'カワチナガノシ', '楠町西', 'クスノキチョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府河内長野市松ケ丘西町', '27', '27216', '5860005', '大阪府', 'オオサカフ', '河内長野市', 'カワチナガノシ', '松ケ丘西町', 'マツガオカニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府河内長野市松ケ丘中町', '27', '27216', '5860006', '大阪府', 'オオサカフ', '河内長野市', 'カワチナガノシ', '松ケ丘中町', 'マツガオカナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府河内長野市松ケ丘東町', '27', '27216', '5860007', '大阪府', 'オオサカフ', '河内長野市', 'カワチナガノシ', '松ケ丘東町', 'マツガオカヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府河内長野市木戸東町', '27', '27216', '5860008', '大阪府', 'オオサカフ', '河内長野市', 'カワチナガノシ', '木戸東町', 'キドヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府河内長野市木戸西町', '27', '27216', '5860009', '大阪府', 'オオサカフ', '河内長野市', 'カワチナガノシ', '木戸西町', 'キドニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府河内長野市汐の宮町', '27', '27216', '5860011', '大阪府', 'オオサカフ', '河内長野市', 'カワチナガノシ', '汐の宮町', 'シオノミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府河内長野市菊水町', '27', '27216', '5860012', '大阪府', 'オオサカフ', '河内長野市', 'カワチナガノシ', '菊水町', 'キクスイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府河内長野市向野町', '27', '27216', '5860013', '大阪府', 'オオサカフ', '河内長野市', 'カワチナガノシ', '向野町', 'ムカイノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府河内長野市長野町', '27', '27216', '5860014', '大阪府', 'オオサカフ', '河内長野市', 'カワチナガノシ', '長野町', 'ナガノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府河内長野市本町', '27', '27216', '5860015', '大阪府', 'オオサカフ', '河内長野市', 'カワチナガノシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府河内長野市西代町', '27', '27216', '5860016', '大阪府', 'オオサカフ', '河内長野市', 'カワチナガノシ', '西代町', 'ニシダイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府河内長野市古野町', '27', '27216', '5860017', '大阪府', 'オオサカフ', '河内長野市', 'カワチナガノシ', '古野町', 'フルノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府河内長野市千代田南町', '27', '27216', '5860018', '大阪府', 'オオサカフ', '河内長野市', 'カワチナガノシ', '千代田南町', 'チヨダミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府河内長野市原町', '27', '27216', '5860021', '大阪府', 'オオサカフ', '河内長野市', 'カワチナガノシ', '原町', 'ハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府河内長野市本多町', '27', '27216', '5860022', '大阪府', 'オオサカフ', '河内長野市', 'カワチナガノシ', '本多町', 'ホンダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府河内長野市野作町', '27', '27216', '5860023', '大阪府', 'オオサカフ', '河内長野市', 'カワチナガノシ', '野作町', 'ノサクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府河内長野市西之山町', '27', '27216', '5860024', '大阪府', 'オオサカフ', '河内長野市', 'カワチナガノシ', '西之山町', 'ニシノヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府河内長野市昭栄町', '27', '27216', '5860025', '大阪府', 'オオサカフ', '河内長野市', 'カワチナガノシ', '昭栄町', 'ショウエイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府河内長野市寿町', '27', '27216', '5860026', '大阪府', 'オオサカフ', '河内長野市', 'カワチナガノシ', '寿町', 'コトブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府河内長野市千代田台町', '27', '27216', '5860027', '大阪府', 'オオサカフ', '河内長野市', 'カワチナガノシ', '千代田台町', 'チヨダダイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府河内長野市錦町', '27', '27216', '5860031', '大阪府', 'オオサカフ', '河内長野市', 'カワチナガノシ', '錦町', 'ニシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府河内長野市栄町', '27', '27216', '5860032', '大阪府', 'オオサカフ', '河内長野市', 'カワチナガノシ', '栄町', 'サカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府河内長野市喜多町', '27', '27216', '5860033', '大阪府', 'オオサカフ', '河内長野市', 'カワチナガノシ', '喜多町', 'キタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府河内長野市上田町', '27', '27216', '5860034', '大阪府', 'オオサカフ', '河内長野市', 'カワチナガノシ', '上田町', 'ウエダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府河内長野市小塩町', '27', '27216', '5860035', '大阪府', 'オオサカフ', '河内長野市', 'カワチナガノシ', '小塩町', 'オシオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府河内長野市高向', '27', '27216', '5860036', '大阪府', 'オオサカフ', '河内長野市', 'カワチナガノシ', '高向', 'タコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府河内長野市上原町', '27', '27216', '5860037', '大阪府', 'オオサカフ', '河内長野市', 'カワチナガノシ', '上原町', 'ウワハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府河内長野市上原西町', '27', '27216', '5860038', '大阪府', 'オオサカフ', '河内長野市', 'カワチナガノシ', '上原西町', 'ウワハラニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府河内長野市楠ケ丘', '27', '27216', '5860039', '大阪府', 'オオサカフ', '河内長野市', 'カワチナガノシ', '楠ケ丘', 'クスガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府河内長野市大師町', '27', '27216', '5860041', '大阪府', 'オオサカフ', '河内長野市', 'カワチナガノシ', '大師町', 'ダイシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府河内長野市日東町', '27', '27216', '5860042', '大阪府', 'オオサカフ', '河内長野市', 'カワチナガノシ', '日東町', 'ニットウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府河内長野市清見台', '27', '27216', '5860043', '大阪府', 'オオサカフ', '河内長野市', 'カワチナガノシ', '清見台', 'キヨミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府河内長野市美加の台', '27', '27216', '5860044', '大阪府', 'オオサカフ', '河内長野市', 'カワチナガノシ', '美加の台', 'ミカノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府河内長野市東片添町', '27', '27216', '5860045', '大阪府', 'オオサカフ', '河内長野市', 'カワチナガノシ', '東片添町', 'ヒガシカタソエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府河内長野市中片添町', '27', '27216', '5860046', '大阪府', 'オオサカフ', '河内長野市', 'カワチナガノシ', '中片添町', 'ナカカタソエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府河内長野市西片添町', '27', '27216', '5860047', '大阪府', 'オオサカフ', '河内長野市', 'カワチナガノシ', '西片添町', 'ニシカタソエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府河内長野市三日市町', '27', '27216', '5860048', '大阪府', 'オオサカフ', '河内長野市', 'カワチナガノシ', '三日市町', 'ミッカイチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府河内長野市末広町', '27', '27216', '5860051', '大阪府', 'オオサカフ', '河内長野市', 'カワチナガノシ', '末広町', 'スエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府河内長野市河合寺', '27', '27216', '5860052', '大阪府', 'オオサカフ', '河内長野市', 'カワチナガノシ', '河合寺', 'カワイデラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府河内長野市寺元', '27', '27216', '5860053', '大阪府', 'オオサカフ', '河内長野市', 'カワチナガノシ', '寺元', 'テラモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府河内長野市神ガ丘', '27', '27216', '5860054', '大阪府', 'オオサカフ', '河内長野市', 'カワチナガノシ', '神ガ丘', 'カミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府河内長野市鳩原', '27', '27216', '5860055', '大阪府', 'オオサカフ', '河内長野市', 'カワチナガノシ', '鳩原', 'ハトハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府河内長野市太井', '27', '27216', '5860056', '大阪府', 'オオサカフ', '河内長野市', 'カワチナガノシ', '太井', 'オオイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府河内長野市小深', '27', '27216', '5860057', '大阪府', 'オオサカフ', '河内長野市', 'カワチナガノシ', '小深', 'コブカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府河内長野市石見川', '27', '27216', '5860058', '大阪府', 'オオサカフ', '河内長野市', 'カワチナガノシ', '石見川', 'イシミガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府河内長野市岩瀬', '27', '27216', '5860061', '大阪府', 'オオサカフ', '河内長野市', 'カワチナガノシ', '岩瀬', 'イワゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府河内長野市天見', '27', '27216', '5860062', '大阪府', 'オオサカフ', '河内長野市', 'カワチナガノシ', '天見', 'アマミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府河内長野市流谷', '27', '27216', '5860063', '大阪府', 'オオサカフ', '河内長野市', 'カワチナガノシ', '流谷', 'ナガレタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府河内長野市唐久谷', '27', '27216', '5860064', '大阪府', 'オオサカフ', '河内長野市', 'カワチナガノシ', '唐久谷', 'カラクダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府河内長野市南ケ丘', '27', '27216', '5860065', '大阪府', 'オオサカフ', '河内長野市', 'カワチナガノシ', '南ケ丘', 'ミナミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府河内長野市清水', '27', '27216', '5860066', '大阪府', 'オオサカフ', '河内長野市', 'カワチナガノシ', '清水', 'シミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府河内長野市南青葉台', '27', '27216', '5860067', '大阪府', 'オオサカフ', '河内長野市', 'カワチナガノシ', '南青葉台', 'ミナミアオバダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府河内長野市北青葉台', '27', '27216', '5860068', '大阪府', 'オオサカフ', '河内長野市', 'カワチナガノシ', '北青葉台', 'キタアオバダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府河内長野市石仏', '27', '27216', '5860069', '大阪府', 'オオサカフ', '河内長野市', 'カワチナガノシ', '石仏', 'イシボトケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府河内長野市加賀田', '27', '27216', '5860071', '大阪府', 'オオサカフ', '河内長野市', 'カワチナガノシ', '加賀田', 'カガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府河内長野市滝畑', '27', '27216', '5860072', '大阪府', 'オオサカフ', '河内長野市', 'カワチナガノシ', '滝畑', 'タキハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府河内長野市大矢船西町', '27', '27216', '5860073', '大阪府', 'オオサカフ', '河内長野市', 'カワチナガノシ', '大矢船西町', 'オオヤブネニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府河内長野市大矢船南町', '27', '27216', '5860074', '大阪府', 'オオサカフ', '河内長野市', 'カワチナガノシ', '大矢船南町', 'オオヤブネミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府河内長野市大矢船中町', '27', '27216', '5860075', '大阪府', 'オオサカフ', '河内長野市', 'カワチナガノシ', '大矢船中町', 'オオヤブネナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府河内長野市大矢船北町', '27', '27216', '5860076', '大阪府', 'オオサカフ', '河内長野市', 'カワチナガノシ', '大矢船北町', 'オオヤブネキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府河内長野市南花台', '27', '27216', '5860077', '大阪府', 'オオサカフ', '河内長野市', 'カワチナガノシ', '南花台', 'ナンカダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府河内長野市緑ケ丘北町', '27', '27216', '5860081', '大阪府', 'オオサカフ', '河内長野市', 'カワチナガノシ', '緑ケ丘北町', 'ミドリガオカキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府河内長野市緑ケ丘中町', '27', '27216', '5860082', '大阪府', 'オオサカフ', '河内長野市', 'カワチナガノシ', '緑ケ丘中町', 'ミドリガオカナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府河内長野市緑ケ丘南町', '27', '27216', '5860083', '大阪府', 'オオサカフ', '河内長野市', 'カワチナガノシ', '緑ケ丘南町', 'ミドリガオカミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府河内長野市旭ケ丘', '27', '27216', '5860084', '大阪府', 'オオサカフ', '河内長野市', 'カワチナガノシ', '旭ケ丘', 'アサヒガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府河内長野市日野', '27', '27216', '5860085', '大阪府', 'オオサカフ', '河内長野市', 'カワチナガノシ', '日野', 'ヒノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府河内長野市天野町', '27', '27216', '5860086', '大阪府', 'オオサカフ', '河内長野市', 'カワチナガノシ', '天野町', 'アマノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府河内長野市下里町', '27', '27216', '5860087', '大阪府', 'オオサカフ', '河内長野市', 'カワチナガノシ', '下里町', 'シモザトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府河内長野市北貴望ケ丘', '27', '27216', '5860091', '大阪府', 'オオサカフ', '河内長野市', 'カワチナガノシ', '北貴望ケ丘', 'キタキボウガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府河内長野市南貴望ケ丘', '27', '27216', '5860092', '大阪府', 'オオサカフ', '河内長野市', 'カワチナガノシ', '南貴望ケ丘', 'ミナミキボウガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府河内長野市荘園町', '27', '27216', '5860093', '大阪府', 'オオサカフ', '河内長野市', 'カワチナガノシ', '荘園町', 'ソウエンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府河内長野市小山田町', '27', '27216', '5860094', '大阪府', 'オオサカフ', '河内長野市', 'カワチナガノシ', '小山田町', 'オヤマダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府河内長野市あかしあ台', '27', '27216', '5860095', '大阪府', 'オオサカフ', '河内長野市', 'カワチナガノシ', 'あかしあ台', 'アカシアダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府河内長野市自由ケ丘', '27', '27216', '5860096', '大阪府', 'オオサカフ', '河内長野市', 'カワチナガノシ', '自由ケ丘', 'ジュウガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府河内長野市桐ケ丘', '27', '27216', '5860097', '大阪府', 'オオサカフ', '河内長野市', 'カワチナガノシ', '桐ケ丘', 'キリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市美原区', '27', '27147', '5870000', '大阪府', 'オオサカフ', '堺市美原区', 'サカイシミハラク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('63311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市美原区大保', '27', '27147', '5870001', '大阪府', 'オオサカフ', '堺市美原区', 'サカイシミハラク', '大保', 'ダイホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市美原区黒山', '27', '27147', '5870002', '大阪府', 'オオサカフ', '堺市美原区', 'サカイシミハラク', '黒山', 'クロヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市美原区阿弥', '27', '27147', '5870003', '大阪府', 'オオサカフ', '堺市美原区', 'サカイシミハラク', '阿弥', 'アミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市美原区丹上', '27', '27147', '5870011', '大阪府', 'オオサカフ', '堺市美原区', 'サカイシミハラク', '丹上', 'タンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市美原区多治井', '27', '27147', '5870012', '大阪府', 'オオサカフ', '堺市美原区', 'サカイシミハラク', '多治井', 'タジイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市美原区真福寺', '27', '27147', '5870013', '大阪府', 'オオサカフ', '堺市美原区', 'サカイシミハラク', '真福寺', 'シンプクジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市美原区丹南', '27', '27147', '5870014', '大阪府', 'オオサカフ', '堺市美原区', 'サカイシミハラク', '丹南', 'タンナン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市美原区小平尾', '27', '27147', '5870021', '大阪府', 'オオサカフ', '堺市美原区', 'サカイシミハラク', '小平尾', 'コビラオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市美原区平尾', '27', '27147', '5870022', '大阪府', 'オオサカフ', '堺市美原区', 'サカイシミハラク', '平尾', 'ヒラオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市美原区さつき野西', '27', '27147', '5870031', '大阪府', 'オオサカフ', '堺市美原区', 'サカイシミハラク', 'さつき野西', 'サツキノニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市美原区さつき野東', '27', '27147', '5870032', '大阪府', 'オオサカフ', '堺市美原区', 'サカイシミハラク', 'さつき野東', 'サツキノヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市美原区菅生', '27', '27147', '5870041', '大阪府', 'オオサカフ', '堺市美原区', 'サカイシミハラク', '菅生', 'スゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市美原区木材通', '27', '27147', '5870042', '大阪府', 'オオサカフ', '堺市美原区', 'サカイシミハラク', '木材通', 'モクザイドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市美原区青南台', '27', '27147', '5870043', '大阪府', 'オオサカフ', '堺市美原区', 'サカイシミハラク', '青南台', 'セイナンダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市美原区北余部', '27', '27147', '5870051', '大阪府', 'オオサカフ', '堺市美原区', 'サカイシミハラク', '北余部', 'キタアマベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市美原区南余部', '27', '27147', '5870052', '大阪府', 'オオサカフ', '堺市美原区', 'サカイシミハラク', '南余部', 'ミナミアマベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市美原区北余部西', '27', '27147', '5870053', '大阪府', 'オオサカフ', '堺市美原区', 'サカイシミハラク', '北余部西', 'キタアマベニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市美原区南余部西', '27', '27147', '5870054', '大阪府', 'オオサカフ', '堺市美原区', 'サカイシミハラク', '南余部西', 'ミナミアマベニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市美原区今井', '27', '27147', '5870061', '大阪府', 'オオサカフ', '堺市美原区', 'サカイシミハラク', '今井', 'イマイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市美原区太井', '27', '27147', '5870062', '大阪府', 'オオサカフ', '堺市美原区', 'サカイシミハラク', '太井', 'タイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市美原区大饗', '27', '27147', '5870063', '大阪府', 'オオサカフ', '堺市美原区', 'サカイシミハラク', '大饗', 'オワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市美原区菩提', '27', '27147', '5870064', '大阪府', 'オオサカフ', '堺市美原区', 'サカイシミハラク', '菩提', 'ボダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市美原区小寺', '27', '27147', '5870065', '大阪府', 'オオサカフ', '堺市美原区', 'サカイシミハラク', '小寺', 'コデラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市美原区石原', '27', '27147', '5870066', '大阪府', 'オオサカフ', '堺市美原区', 'サカイシミハラク', '石原', 'イシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪狭山市', '27', '27231', '5890000', '大阪府', 'オオサカフ', '大阪狭山市', 'オオサカサヤマシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('63340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪狭山市東野西', '27', '27231', '5890001', '大阪府', 'オオサカフ', '大阪狭山市', 'オオサカサヤマシ', '東野西', 'ヒガシノニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪狭山市東野中', '27', '27231', '5890002', '大阪府', 'オオサカフ', '大阪狭山市', 'オオサカサヤマシ', '東野中', 'ヒガシノナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪狭山市東野東', '27', '27231', '5890003', '大阪府', 'オオサカフ', '大阪狭山市', 'オオサカサヤマシ', '東野東', 'ヒガシノヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪狭山市東池尻', '27', '27231', '5890004', '大阪府', 'オオサカフ', '大阪狭山市', 'オオサカサヤマシ', '東池尻', 'ヒガシイケジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪狭山市狭山', '27', '27231', '5890005', '大阪府', 'オオサカフ', '大阪狭山市', 'オオサカサヤマシ', '狭山', 'サヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪狭山市金剛', '27', '27231', '5890006', '大阪府', 'オオサカフ', '大阪狭山市', 'オオサカサヤマシ', '金剛', 'コンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪狭山市池尻中', '27', '27231', '5890007', '大阪府', 'オオサカフ', '大阪狭山市', 'オオサカサヤマシ', '池尻中', 'イケジリナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪狭山市池尻自由丘', '27', '27231', '5890008', '大阪府', 'オオサカフ', '大阪狭山市', 'オオサカサヤマシ', '池尻自由丘', 'イケジリジュウガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪狭山市池尻北', '27', '27231', '5890009', '大阪府', 'オオサカフ', '大阪狭山市', 'オオサカサヤマシ', '池尻北', 'イケジリキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪狭山市半田', '27', '27231', '5890011', '大阪府', 'オオサカフ', '大阪狭山市', 'オオサカサヤマシ', '半田', 'ハンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪狭山市東茱萸木', '27', '27231', '5890012', '大阪府', 'オオサカフ', '大阪狭山市', 'オオサカサヤマシ', '東茱萸木', 'ヒガシクミノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪狭山市茱萸木', '27', '27231', '5890013', '大阪府', 'オオサカフ', '大阪狭山市', 'オオサカサヤマシ', '茱萸木', 'クミノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪狭山市大野東', '27', '27231', '5890014', '大阪府', 'オオサカフ', '大阪狭山市', 'オオサカサヤマシ', '大野東', 'オオノヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪狭山市大野中', '27', '27231', '5890015', '大阪府', 'オオサカフ', '大阪狭山市', 'オオサカサヤマシ', '大野中', 'オオノナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪狭山市大野西', '27', '27231', '5890016', '大阪府', 'オオサカフ', '大阪狭山市', 'オオサカサヤマシ', '大野西', 'オオノニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪狭山市今熊', '27', '27231', '5890021', '大阪府', 'オオサカフ', '大阪狭山市', 'オオサカサヤマシ', '今熊', 'イマクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪狭山市西山台', '27', '27231', '5890022', '大阪府', 'オオサカフ', '大阪狭山市', 'オオサカサヤマシ', '西山台', 'ニシヤマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪狭山市大野台', '27', '27231', '5890023', '大阪府', 'オオサカフ', '大阪狭山市', 'オオサカサヤマシ', '大野台', 'オオノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪狭山市池之原', '27', '27231', '5890031', '大阪府', 'オオサカフ', '大阪狭山市', 'オオサカサヤマシ', '池之原', 'イケノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪狭山市岩室', '27', '27231', '5890032', '大阪府', 'オオサカフ', '大阪狭山市', 'オオサカサヤマシ', '岩室', 'イワムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪狭山市山本南', '27', '27231', '5890033', '大阪府', 'オオサカフ', '大阪狭山市', 'オオサカサヤマシ', '山本南', 'ヤマモトミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪狭山市山本中', '27', '27231', '5890034', '大阪府', 'オオサカフ', '大阪狭山市', 'オオサカサヤマシ', '山本中', 'ヤマモトナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪狭山市山本北', '27', '27231', '5890035', '大阪府', 'オオサカフ', '大阪狭山市', 'オオサカサヤマシ', '山本北', 'ヤマモトキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府大阪狭山市山本東', '27', '27231', '5890036', '大阪府', 'オオサカフ', '大阪狭山市', 'オオサカサヤマシ', '山本東', 'ヤマモトヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道登別市', '01', '01230', '0590000', '北海道', 'ホッカイドウ', '登別市', 'ノボリベツシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('63369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区', '27', '27141', '5900000', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('63370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区遠里小野町', '27', '27141', '5900001', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '遠里小野町', 'オリオノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区砂道町', '27', '27141', '5900002', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '砂道町', 'スナミチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区高須町', '27', '27141', '5900003', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '高須町', 'タカスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区北清水町', '27', '27141', '5900004', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '北清水町', 'キタシミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区南清水町', '27', '27141', '5900005', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '南清水町', 'ミナミシミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区錦綾町', '27', '27141', '5900006', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '錦綾町', 'キンリョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区北庄町', '27', '27141', '5900007', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '北庄町', 'キタショウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区南庄町', '27', '27141', '5900008', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '南庄町', 'ミナミショウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道登別市新栄町', '01', '01230', '0590001', '北海道', 'ホッカイドウ', '登別市', 'ノボリベツシ', '新栄町', 'シンエイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区香ケ丘町', '27', '27141', '5900011', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '香ケ丘町', 'カオリガオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区浅香山町', '27', '27141', '5900012', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '浅香山町', 'アサカヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区東雲西町', '27', '27141', '5900013', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '東雲西町', 'シノノメニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区田出井町', '27', '27141', '5900014', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '田出井町', 'タデイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区南田出井町', '27', '27141', '5900015', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '南田出井町', 'ミナミタデイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区中田出井町', '27', '27141', '5900016', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '中田出井町', 'ナカタデイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区北田出井町', '27', '27141', '5900017', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '北田出井町', 'キタタデイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区今池町', '27', '27141', '5900018', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '今池町', 'イマイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道登別市幸町', '01', '01230', '0590002', '北海道', 'ホッカイドウ', '登別市', 'ノボリベツシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区北三国ケ丘町', '27', '27141', '5900021', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '北三国ケ丘町', 'キタミクニガオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区中三国ケ丘町', '27', '27141', '5900022', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '中三国ケ丘町', 'ナカミクニガオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区南三国ケ丘町', '27', '27141', '5900023', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '南三国ケ丘町', 'ミナミミクニガオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区向陵中町', '27', '27141', '5900024', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '向陵中町', 'コウリョウナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区向陵東町', '27', '27141', '5900025', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '向陵東町', 'コウリョウヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区向陵西町', '27', '27141', '5900026', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '向陵西町', 'コウリョウニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区榎元町', '27', '27141', '5900027', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '榎元町', 'エノキモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区三国ケ丘御幸通', '27', '27141', '5900028', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '三国ケ丘御幸通', 'ミクニガオカミユキドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道登別市千歳町', '01', '01230', '0590003', '北海道', 'ホッカイドウ', '登別市', 'ノボリベツシ', '千歳町', 'チトセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区五月町', '27', '27141', '5900031', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '五月町', 'サツキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区西永山園', '27', '27141', '5900032', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '西永山園', 'ニシナガヤマエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区中永山園', '27', '27141', '5900033', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '中永山園', 'ナカナガヤマエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区東永山園', '27', '27141', '5900034', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '東永山園', 'ヒガシナガヤマエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区大仙町', '27', '27141', '5900035', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '大仙町', 'ダイセンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区南丸保園', '27', '27141', '5900036', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '南丸保園', 'ミナミマルホエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区北丸保園', '27', '27141', '5900037', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '北丸保園', 'キタマルホエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道登別市来馬町', '01', '01230', '0590004', '北海道', 'ホッカイドウ', '登別市', 'ノボリベツシ', '来馬町', 'ライバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区陵西通', '27', '27141', '5900041', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '陵西通', 'リョウサイドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区七条通', '27', '27141', '5900042', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '七条通', 'シチジョウドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区六条通', '27', '27141', '5900043', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '六条通', 'ロクジョウドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区五条通', '27', '27141', '5900044', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '五条通', 'ゴジョウドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区四条通', '27', '27141', '5900045', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '四条通', 'シジョウドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区三条通', '27', '27141', '5900046', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '三条通', 'サンジョウドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区二条通', '27', '27141', '5900047', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '二条通', 'ニジョウドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区一条通', '27', '27141', '5900048', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '一条通', 'イチジョウドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道登別市札内町', '01', '01230', '0590005', '北海道', 'ホッカイドウ', '登別市', 'ノボリベツシ', '札内町', 'サツナイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区幸通', '27', '27141', '5900051', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '幸通', 'サイワイドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区八千代通', '27', '27141', '5900052', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '八千代通', 'ヤチヨドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区文珠橋通', '27', '27141', '5900053', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '文珠橋通', 'モンジュバシドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区京町通', '27', '27141', '5900054', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '京町通', 'キョウマチドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区旭通', '27', '27141', '5900055', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '旭通', 'アサヒドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区神保通', '27', '27141', '5900056', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '神保通', 'シンポドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区御陵通', '27', '27141', '5900057', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '御陵通', 'ゴリョウドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区翁橋町', '27', '27141', '5900061', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '翁橋町', 'オキナバシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区北安井町', '27', '27141', '5900062', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '北安井町', 'キタヤスイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区中安井町', '27', '27141', '5900063', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '中安井町', 'ナカヤスイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区南安井町', '27', '27141', '5900064', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '南安井町', 'ミナミヤスイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区永代町', '27', '27141', '5900065', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '永代町', 'エイタイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区賑町', '27', '27141', '5900066', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '賑町', 'ニギワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区北向陽町', '27', '27141', '5900071', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '北向陽町', 'キタコウヨウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区中向陽町', '27', '27141', '5900072', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '中向陽町', 'ナカコウヨウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区南向陽町', '27', '27141', '5900073', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '南向陽町', 'ミナミコウヨウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区北花田口町', '27', '27141', '5900074', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '北花田口町', 'キタハナダグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区南花田口町', '27', '27141', '5900075', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '南花田口町', 'ミナミハナダグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区北瓦町', '27', '27141', '5900076', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '北瓦町', 'キタカワラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区中瓦町', '27', '27141', '5900077', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '中瓦町', 'ナカカワラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区南瓦町', '27', '27141', '5900078', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '南瓦町', 'ミナミカワラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区新町', '27', '27141', '5900079', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市南区', '27', '27145', '5900100', '大阪府', 'オオサカフ', '堺市南区', 'サカイシミナミク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('63437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市南区宮山台', '27', '27145', '5900101', '大阪府', 'オオサカフ', '堺市南区', 'サカイシミナミク', '宮山台', 'ミヤヤマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市南区和田東', '27', '27145', '5900102', '大阪府', 'オオサカフ', '堺市南区', 'サカイシミナミク', '和田東', 'ワダヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市南区深阪南', '27', '27145', '5900103', '大阪府', 'オオサカフ', '堺市南区', 'サカイシミナミク', '深阪南', 'フカサカミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市南区土佐屋台', '27', '27145', '5900104', '大阪府', 'オオサカフ', '堺市南区', 'サカイシミナミク', '土佐屋台', 'トサヤダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市中区竹城台', '27', '27142', '5900105', '大阪府', 'オオサカフ', '堺市中区', 'サカイシナカク', '竹城台', 'タケシロダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市南区竹城台', '27', '27145', '5900105', '大阪府', 'オオサカフ', '堺市南区', 'サカイシミナミク', '竹城台', 'タケシロダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市南区豊田', '27', '27145', '5900106', '大阪府', 'オオサカフ', '堺市南区', 'サカイシミナミク', '豊田', 'トヨダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道登別市常盤町', '01', '01230', '0590011', '北海道', 'ホッカイドウ', '登別市', 'ノボリベツシ', '常盤町', 'トキワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市中区三原台', '27', '27142', '5900111', '大阪府', 'オオサカフ', '堺市中区', 'サカイシナカク', '三原台', 'ミハラダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市南区三原台', '27', '27145', '5900111', '大阪府', 'オオサカフ', '堺市南区', 'サカイシミナミク', '三原台', 'ミハラダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市南区岩室', '27', '27145', '5900112', '大阪府', 'オオサカフ', '堺市南区', 'サカイシミナミク', '岩室', 'イワムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市南区晴美台', '27', '27145', '5900113', '大阪府', 'オオサカフ', '堺市南区', 'サカイシミナミク', '晴美台', 'ハルミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市南区槇塚台', '27', '27145', '5900114', '大阪府', 'オオサカフ', '堺市南区', 'サカイシミナミク', '槇塚台', 'マキヅカダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市南区茶山台', '27', '27145', '5900115', '大阪府', 'オオサカフ', '堺市南区', 'サカイシミナミク', '茶山台', 'チャヤマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市南区若松台', '27', '27145', '5900116', '大阪府', 'オオサカフ', '堺市南区', 'サカイシミナミク', '若松台', 'ワカマツダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市南区高倉台', '27', '27145', '5900117', '大阪府', 'オオサカフ', '堺市南区', 'サカイシミナミク', '高倉台', 'タカクラダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道登別市中央町', '01', '01230', '0590012', '北海道', 'ホッカイドウ', '登別市', 'ノボリベツシ', '中央町', 'チュウオウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市南区片蔵', '27', '27145', '5900121', '大阪府', 'オオサカフ', '堺市南区', 'サカイシミナミク', '片蔵', 'カタクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市南区釜室', '27', '27145', '5900122', '大阪府', 'オオサカフ', '堺市南区', 'サカイシミナミク', '釜室', 'カマムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市南区逆瀬川', '27', '27145', '5900123', '大阪府', 'オオサカフ', '堺市南区', 'サカイシミナミク', '逆瀬川', 'サカセガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市南区畑', '27', '27145', '5900124', '大阪府', 'オオサカフ', '堺市南区', 'サカイシミナミク', '畑', 'ハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市南区鉢ケ峯寺', '27', '27145', '5900125', '大阪府', 'オオサカフ', '堺市南区', 'サカイシミナミク', '鉢ケ峯寺', 'ハチガミネジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市南区泉田中', '27', '27145', '5900126', '大阪府', 'オオサカフ', '堺市南区', 'サカイシミナミク', '泉田中', 'イズミタナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市南区富蔵', '27', '27145', '5900127', '大阪府', 'オオサカフ', '堺市南区', 'サカイシミナミク', '富蔵', 'トミクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道登別市幌別町', '01', '01230', '0590013', '北海道', 'ホッカイドウ', '登別市', 'ノボリベツシ', '幌別町', 'ホロベツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市南区栂', '27', '27145', '5900131', '大阪府', 'オオサカフ', '堺市南区', 'サカイシミナミク', '栂', 'トガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市南区原山台', '27', '27145', '5900132', '大阪府', 'オオサカフ', '堺市南区', 'サカイシミナミク', '原山台', 'ハラヤマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市南区庭代台', '27', '27145', '5900133', '大阪府', 'オオサカフ', '堺市南区', 'サカイシミナミク', '庭代台', 'ニワシロダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市南区御池台', '27', '27145', '5900134', '大阪府', 'オオサカフ', '堺市南区', 'サカイシミナミク', '御池台', 'ミイケダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市南区別所', '27', '27145', '5900135', '大阪府', 'オオサカフ', '堺市南区', 'サカイシミナミク', '別所', 'ベッシヨ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市南区美木多上', '27', '27145', '5900136', '大阪府', 'オオサカフ', '堺市南区', 'サカイシミナミク', '美木多上', 'ミキタカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市南区城山台', '27', '27145', '5900137', '大阪府', 'オオサカフ', '堺市南区', 'サカイシミナミク', '城山台', 'シロヤマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市南区鴨谷台', '27', '27145', '5900138', '大阪府', 'オオサカフ', '堺市南区', 'サカイシミナミク', '鴨谷台', 'カモタニダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道登別市富士町', '01', '01230', '0590014', '北海道', 'ホッカイドウ', '登別市', 'ノボリベツシ', '富士町', 'フジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市南区桃山台', '27', '27145', '5900141', '大阪府', 'オオサカフ', '堺市南区', 'サカイシミナミク', '桃山台', 'モモヤマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市南区檜尾', '27', '27145', '5900142', '大阪府', 'オオサカフ', '堺市南区', 'サカイシミナミク', '檜尾', 'ヒノオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市南区新檜尾台', '27', '27145', '5900143', '大阪府', 'オオサカフ', '堺市南区', 'サカイシミナミク', '新檜尾台', 'シンヒノオダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市南区赤坂台', '27', '27145', '5900144', '大阪府', 'オオサカフ', '堺市南区', 'サカイシミナミク', '赤坂台', 'アカサカダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市南区大森', '27', '27145', '5900145', '大阪府', 'オオサカフ', '堺市南区', 'サカイシミナミク', '大森', 'オオモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道登別市新川町', '01', '01230', '0590015', '北海道', 'ホッカイドウ', '登別市', 'ノボリベツシ', '新川町', 'シンカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市南区小代', '27', '27145', '5900151', '大阪府', 'オオサカフ', '堺市南区', 'サカイシミナミク', '小代', 'コダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市南区和田', '27', '27145', '5900152', '大阪府', 'オオサカフ', '堺市南区', 'サカイシミナミク', '和田', 'ワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市南区大庭寺', '27', '27145', '5900153', '大阪府', 'オオサカフ', '堺市南区', 'サカイシミナミク', '大庭寺', 'オオバデラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市南区三木閉', '27', '27145', '5900154', '大阪府', 'オオサカフ', '堺市南区', 'サカイシミナミク', '三木閉', 'ミキトジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市南区野々井', '27', '27145', '5900155', '大阪府', 'オオサカフ', '堺市南区', 'サカイシミナミク', '野々井', 'ノノイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市南区稲葉', '27', '27145', '5900156', '大阪府', 'オオサカフ', '堺市南区', 'サカイシミナミク', '稲葉', 'イナバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市南区高尾', '27', '27145', '5900157', '大阪府', 'オオサカフ', '堺市南区', 'サカイシミナミク', '高尾', 'タカオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市南区太平寺', '27', '27145', '5900158', '大阪府', 'オオサカフ', '堺市南区', 'サカイシミナミク', '太平寺', 'タイヘイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道登別市片倉町', '01', '01230', '0590016', '北海道', 'ホッカイドウ', '登別市', 'ノボリベツシ', '片倉町', 'カタクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道登別市柏木町', '01', '01230', '0590017', '北海道', 'ホッカイドウ', '登別市', 'ノボリベツシ', '柏木町', 'カシワギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道登別市鉱山町', '01', '01230', '0590021', '北海道', 'ホッカイドウ', '登別市', 'ノボリベツシ', '鉱山町', 'コウザンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道登別市川上町', '01', '01230', '0590022', '北海道', 'ホッカイドウ', '登別市', 'ノボリベツシ', '川上町', 'カワカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道登別市桜木町', '01', '01230', '0590023', '北海道', 'ホッカイドウ', '登別市', 'ノボリベツシ', '桜木町', 'サクラギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道登別市緑町', '01', '01230', '0590024', '北海道', 'ホッカイドウ', '登別市', 'ノボリベツシ', '緑町', 'ミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道登別市大和町', '01', '01230', '0590025', '北海道', 'ホッカイドウ', '登別市', 'ノボリベツシ', '大和町', 'ヤマトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道登別市若山町', '01', '01230', '0590026', '北海道', 'ホッカイドウ', '登別市', 'ノボリベツシ', '若山町', 'ワカヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道登別市青葉町', '01', '01230', '0590027', '北海道', 'ホッカイドウ', '登別市', 'ノボリベツシ', '青葉町', 'アオバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道登別市富岸町', '01', '01230', '0590028', '北海道', 'ホッカイドウ', '登別市', 'ノボリベツシ', '富岸町', 'トンケシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道登別市上鷲別町', '01', '01230', '0590031', '北海道', 'ホッカイドウ', '登別市', 'ノボリベツシ', '上鷲別町', 'カミワシベツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道登別市新生町', '01', '01230', '0590032', '北海道', 'ホッカイドウ', '登別市', 'ノボリベツシ', '新生町', 'シンセイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道登別市栄町', '01', '01230', '0590033', '北海道', 'ホッカイドウ', '登別市', 'ノボリベツシ', '栄町', 'サカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道登別市鷲別町', '01', '01230', '0590034', '北海道', 'ホッカイドウ', '登別市', 'ノボリベツシ', '鷲別町', 'ワシベツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道登別市若草町', '01', '01230', '0590035', '北海道', 'ホッカイドウ', '登別市', 'ノボリベツシ', '若草町', 'ワカクサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道登別市美園町', '01', '01230', '0590036', '北海道', 'ホッカイドウ', '登別市', 'ノボリベツシ', '美園町', 'ミソノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉南郡熊取町', '27', '27361', '5900400', '大阪府', 'オオサカフ', '泉南郡熊取町', 'センナングンクマトリチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('63502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉南郡熊取町大久保', '27', '27361', '5900401', '大阪府', 'オオサカフ', '泉南郡熊取町', 'センナングンクマトリチョウ', '大久保', 'オオクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉南郡熊取町大久保北', '27', '27361', '5900402', '大阪府', 'オオサカフ', '泉南郡熊取町', 'センナングンクマトリチョウ', '大久保北', 'オオクボキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉南郡熊取町大久保中', '27', '27361', '5900403', '大阪府', 'オオサカフ', '泉南郡熊取町', 'センナングンクマトリチョウ', '大久保中', 'オオクボナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉南郡熊取町大久保西', '27', '27361', '5900404', '大阪府', 'オオサカフ', '泉南郡熊取町', 'センナングンクマトリチョウ', '大久保西', 'オオクボニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉南郡熊取町大久保南', '27', '27361', '5900405', '大阪府', 'オオサカフ', '泉南郡熊取町', 'センナングンクマトリチョウ', '大久保南', 'オオクボミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉南郡熊取町大久保東', '27', '27361', '5900406', '大阪府', 'オオサカフ', '泉南郡熊取町', 'センナングンクマトリチョウ', '大久保東', 'オオクボヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉南郡熊取町青葉台', '27', '27361', '5900407', '大阪府', 'オオサカフ', '泉南郡熊取町', 'センナングンクマトリチョウ', '青葉台', 'アオバダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉南郡熊取町五門', '27', '27361', '5900411', '大阪府', 'オオサカフ', '泉南郡熊取町', 'センナングンクマトリチョウ', '五門', 'ゴモン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉南郡熊取町紺屋', '27', '27361', '5900412', '大阪府', 'オオサカフ', '泉南郡熊取町', 'センナングンクマトリチョウ', '紺屋', 'コンヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉南郡熊取町桜が丘', '27', '27361', '5900413', '大阪府', 'オオサカフ', '泉南郡熊取町', 'センナングンクマトリチョウ', '桜が丘', 'サクラガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉南郡熊取町五門東', '27', '27361', '5900414', '大阪府', 'オオサカフ', '泉南郡熊取町', 'センナングンクマトリチョウ', '五門東', 'ゴモンヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉南郡熊取町五門西', '27', '27361', '5900415', '大阪府', 'オオサカフ', '泉南郡熊取町', 'センナングンクマトリチョウ', '五門西', 'ゴモンニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉南郡熊取町東和苑', '27', '27361', '5900416', '大阪府', 'オオサカフ', '泉南郡熊取町', 'センナングンクマトリチョウ', '東和苑', 'トウワエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉南郡熊取町和田', '27', '27361', '5900417', '大阪府', 'オオサカフ', '泉南郡熊取町', 'センナングンクマトリチョウ', '和田', 'ワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉南郡熊取町七山', '27', '27361', '5900421', '大阪府', 'オオサカフ', '泉南郡熊取町', 'センナングンクマトリチョウ', '七山', 'シチヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉南郡熊取町希望が丘', '27', '27361', '5900422', '大阪府', 'オオサカフ', '泉南郡熊取町', 'センナングンクマトリチョウ', '希望が丘', 'キボウガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉南郡熊取町自由が丘', '27', '27361', '5900423', '大阪府', 'オオサカフ', '泉南郡熊取町', 'センナングンクマトリチョウ', '自由が丘', 'ジュウガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉南郡熊取町七山北', '27', '27361', '5900424', '大阪府', 'オオサカフ', '泉南郡熊取町', 'センナングンクマトリチョウ', '七山北', 'シチヤマキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉南郡熊取町七山東', '27', '27361', '5900425', '大阪府', 'オオサカフ', '泉南郡熊取町', 'センナングンクマトリチョウ', '七山東', 'シチヤマヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉南郡熊取町七山南', '27', '27361', '5900426', '大阪府', 'オオサカフ', '泉南郡熊取町', 'センナングンクマトリチョウ', '七山南', 'シチヤマミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉南郡熊取町七山西', '27', '27361', '5900427', '大阪府', 'オオサカフ', '泉南郡熊取町', 'センナングンクマトリチョウ', '七山西', 'シチヤマニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉南郡熊取町小谷', '27', '27361', '5900431', '大阪府', 'オオサカフ', '泉南郡熊取町', 'センナングンクマトリチョウ', '小谷', 'オダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉南郡熊取町小垣内', '27', '27361', '5900432', '大阪府', 'オオサカフ', '泉南郡熊取町', 'センナングンクマトリチョウ', '小垣内', 'オガイト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉南郡熊取町若葉', '27', '27361', '5900433', '大阪府', 'オオサカフ', '泉南郡熊取町', 'センナングンクマトリチョウ', '若葉', 'ワカバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉南郡熊取町小谷北', '27', '27361', '5900434', '大阪府', 'オオサカフ', '泉南郡熊取町', 'センナングンクマトリチョウ', '小谷北', 'オダニキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉南郡熊取町小谷南', '27', '27361', '5900435', '大阪府', 'オオサカフ', '泉南郡熊取町', 'センナングンクマトリチョウ', '小谷南', 'オダニミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉南郡熊取町高田', '27', '27361', '5900436', '大阪府', 'オオサカフ', '泉南郡熊取町', 'センナングンクマトリチョウ', '高田', 'コウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉南郡熊取町久保', '27', '27361', '5900441', '大阪府', 'オオサカフ', '泉南郡熊取町', 'センナングンクマトリチョウ', '久保', 'クボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉南郡熊取町つばさが丘東', '27', '27361', '5900442', '大阪府', 'オオサカフ', '泉南郡熊取町', 'センナングンクマトリチョウ', 'つばさが丘東', 'ツバサガオカヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉南郡熊取町つばさが丘西', '27', '27361', '5900443', '大阪府', 'オオサカフ', '泉南郡熊取町', 'センナングンクマトリチョウ', 'つばさが丘西', 'ツバサガオカニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉南郡熊取町つばさが丘北', '27', '27361', '5900444', '大阪府', 'オオサカフ', '泉南郡熊取町', 'センナングンクマトリチョウ', 'つばさが丘北', 'ツバサガオカキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉南郡熊取町五月ケ丘', '27', '27361', '5900445', '大阪府', 'オオサカフ', '泉南郡熊取町', 'センナングンクマトリチョウ', '五月ケ丘', 'サツキガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉南郡熊取町成合北', '27', '27361', '5900446', '大阪府', 'オオサカフ', '泉南郡熊取町', 'センナングンクマトリチョウ', '成合北', 'ナリアイキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉南郡熊取町成合東', '27', '27361', '5900447', '大阪府', 'オオサカフ', '泉南郡熊取町', 'センナングンクマトリチョウ', '成合東', 'ナリアイヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉南郡熊取町成合南', '27', '27361', '5900448', '大阪府', 'オオサカフ', '泉南郡熊取町', 'センナングンクマトリチョウ', '成合南', 'ナリアイミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉南郡熊取町成合西', '27', '27361', '5900449', '大阪府', 'オオサカフ', '泉南郡熊取町', 'センナングンクマトリチョウ', '成合西', 'ナリアイニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉南郡熊取町大宮', '27', '27361', '5900450', '大阪府', 'オオサカフ', '泉南郡熊取町', 'センナングンクマトリチョウ', '大宮', 'オオミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉南郡熊取町野田', '27', '27361', '5900451', '大阪府', 'オオサカフ', '泉南郡熊取町', 'センナングンクマトリチョウ', '野田', 'ノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉南郡熊取町山の手台', '27', '27361', '5900452', '大阪府', 'オオサカフ', '泉南郡熊取町', 'センナングンクマトリチョウ', '山の手台', 'ヤマノテダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉南郡熊取町南山の手台', '27', '27361', '5900453', '大阪府', 'オオサカフ', '泉南郡熊取町', 'センナングンクマトリチョウ', '南山の手台', 'ミナミヤマノテダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉南郡熊取町新野田', '27', '27361', '5900454', '大阪府', 'オオサカフ', '泉南郡熊取町', 'センナングンクマトリチョウ', '新野田', 'シンノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉南郡熊取町長池', '27', '27361', '5900455', '大阪府', 'オオサカフ', '泉南郡熊取町', 'センナングンクマトリチョウ', '長池', 'ナガイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉南郡熊取町美熊台', '27', '27361', '5900456', '大阪府', 'オオサカフ', '泉南郡熊取町', 'センナングンクマトリチョウ', '美熊台', 'ミクマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉南郡熊取町朝代東', '27', '27361', '5900457', '大阪府', 'オオサカフ', '泉南郡熊取町', 'センナングンクマトリチョウ', '朝代東', 'アサシロヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉南郡熊取町朝代西', '27', '27361', '5900458', '大阪府', 'オオサカフ', '泉南郡熊取町', 'センナングンクマトリチョウ', '朝代西', 'アサシロニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉南郡熊取町朝代台', '27', '27361', '5900459', '大阪府', 'オオサカフ', '泉南郡熊取町', 'センナングンクマトリチョウ', '朝代台', 'アサシロダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府貝塚市三ツ松', '27', '27208', '5900461', '大阪府', 'オオサカフ', '貝塚市', 'カイヅカシ', '三ツ松', 'ミツマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉南市', '27', '27228', '5900500', '大阪府', 'オオサカフ', '泉南市', 'センナンシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('63556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉南市兎田', '27', '27228', '5900501', '大阪府', 'オオサカフ', '泉南市', 'センナンシ', '兎田', 'ウサイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉南市別所', '27', '27228', '5900502', '大阪府', 'オオサカフ', '泉南市', 'センナンシ', '別所', 'ベッシヨ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉南市新家', '27', '27228', '5900503', '大阪府', 'オオサカフ', '泉南市', 'センナンシ', '新家', 'シンゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉南市信達市場', '27', '27228', '5900504', '大阪府', 'オオサカフ', '泉南市', 'センナンシ', '信達市場', 'シンダチイチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉南市信達大苗代', '27', '27228', '5900505', '大阪府', 'オオサカフ', '泉南市', 'センナンシ', '信達大苗代', 'シンダチオノシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉南市信達葛畑', '27', '27228', '5900511', '大阪府', 'オオサカフ', '泉南市', 'センナンシ', '信達葛畑', 'シンダチツズラバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉南市信達童子畑', '27', '27228', '5900512', '大阪府', 'オオサカフ', '泉南市', 'センナンシ', '信達童子畑', 'シンダチワラヅハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉南市信達楠畑', '27', '27228', '5900513', '大阪府', 'オオサカフ', '泉南市', 'センナンシ', '信達楠畑', 'シンダチクスバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉南市信達金熊寺', '27', '27228', '5900514', '大阪府', 'オオサカフ', '泉南市', 'センナンシ', '信達金熊寺', 'シンダチキンユウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉南市信達六尾', '27', '27228', '5900515', '大阪府', 'オオサカフ', '泉南市', 'センナンシ', '信達六尾', 'シンダチムツオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉南市樽井', '27', '27228', '5900521', '大阪府', 'オオサカフ', '泉南市', 'センナンシ', '樽井', 'タルイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉南市信達牧野', '27', '27228', '5900522', '大阪府', 'オオサカフ', '泉南市', 'センナンシ', '信達牧野', 'シンダチマキノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉南市信達岡中', '27', '27228', '5900523', '大阪府', 'オオサカフ', '泉南市', 'センナンシ', '信達岡中', 'シンダチオカナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉南市幡代', '27', '27228', '5900524', '大阪府', 'オオサカフ', '泉南市', 'センナンシ', '幡代', 'ハタシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉南市馬場', '27', '27228', '5900525', '大阪府', 'オオサカフ', '泉南市', 'センナンシ', '馬場', 'ババ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉南市男里', '27', '27228', '5900526', '大阪府', 'オオサカフ', '泉南市', 'センナンシ', '男里', 'オノサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉南市岡田', '27', '27228', '5900531', '大阪府', 'オオサカフ', '泉南市', 'センナンシ', '岡田', 'オカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉南市北野', '27', '27228', '5900532', '大阪府', 'オオサカフ', '泉南市', 'センナンシ', '北野', 'キタノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉南市中小路', '27', '27228', '5900533', '大阪府', 'オオサカフ', '泉南市', 'センナンシ', '中小路', 'ナコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉南市鳴滝', '27', '27228', '5900534', '大阪府', 'オオサカフ', '泉南市', 'センナンシ', '鳴滝', 'ナルタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉南市りんくう南浜', '27', '27228', '5900535', '大阪府', 'オオサカフ', '泉南市', 'センナンシ', 'りんくう南浜', 'リンクウミナミハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区大仙中町', '27', '27141', '5900801', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '大仙中町', 'ダイセンナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区百舌鳥夕雲町', '27', '27141', '5900802', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '百舌鳥夕雲町', 'モズセキウンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区東上野芝町1丁', '27', '27141', '5900803', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '東上野芝町', 'ヒガシウエノシバチョウ', null, null, '1丁', '01チョウ');
INSERT INTO `ms_addresses` VALUES ('63581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区緑ヶ丘南町', '27', '27141', '5900804', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '緑ヶ丘南町', 'ミドリガオカミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区緑ヶ丘中町', '27', '27141', '5900805', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '緑ヶ丘中町', 'ミドリガオカナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区緑ヶ丘北町', '27', '27141', '5900806', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '緑ヶ丘北町', 'ミドリガオカキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区旭ケ丘南町', '27', '27141', '5900807', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '旭ケ丘南町', 'アサヒガオカミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区旭ケ丘中町', '27', '27141', '5900808', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '旭ケ丘中町', 'アサヒガオカナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区旭ケ丘北町', '27', '27141', '5900809', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '旭ケ丘北町', 'アサヒガオカキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区南陵町', '27', '27141', '5900811', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '南陵町', 'ナンリョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区霞ケ丘町', '27', '27141', '5900812', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '霞ケ丘町', 'カスミガオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区神石市之町', '27', '27141', '5900813', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '神石市之町', 'カミイシイチノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区石津町', '27', '27141', '5900814', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '石津町', 'イシヅチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区高砂町', '27', '27141', '5900820', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '高砂町', 'タカサゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区大仙西町', '27', '27141', '5900821', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '大仙西町', 'ダイセンニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区協和町', '27', '27141', '5900822', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '協和町', 'キョウワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区石津北町', '27', '27141', '5900823', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '石津北町', 'イシヅキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区老松町', '27', '27141', '5900824', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '老松町', 'オイマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区昭和通', '27', '27141', '5900825', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '昭和通', 'ショウワドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区菅原通', '27', '27141', '5900826', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '菅原通', 'スガハラドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区春日通', '27', '27141', '5900827', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '春日通', 'カスガドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区八幡通', '27', '27141', '5900828', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '八幡通', 'ヤハタドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区東湊町', '27', '27141', '5900829', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '東湊町', 'ヒガシミナトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区出島西町', '27', '27141', '5900831', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '出島西町', 'デジマニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区出島浜通', '27', '27141', '5900832', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '出島浜通', 'デジマハマドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区出島海岸通', '27', '27141', '5900833', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '出島海岸通', 'デジマカイガンドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区出島町', '27', '27141', '5900834', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '出島町', 'デジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区西湊町', '27', '27141', '5900835', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '西湊町', 'ニシミナトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区楠町', '27', '27141', '5900836', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '楠町', 'クスノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区柏木町', '27', '27141', '5900837', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '柏木町', 'カシワギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区築港八幡町', '27', '27141', '5900901', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '築港八幡町', 'チッコウヤワタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区松屋大和川通', '27', '27141', '5900902', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '松屋大和川通', 'マツヤヤマトガワドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区松屋町', '27', '27141', '5900903', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '松屋町', 'マツヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区南島町', '27', '27141', '5900904', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '南島町', 'ミナミジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区鉄砲町', '27', '27141', '5900905', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '鉄砲町', 'テッポウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区三宝町', '27', '27141', '5900906', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '三宝町', 'サンボウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区緑町', '27', '27141', '5900907', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '緑町', 'ミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区匠町', '27', '27141', '5900908', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '匠町', 'タクミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区七道西町', '27', '27141', '5900911', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '七道西町', 'シチドウニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区並松町', '27', '27141', '5900912', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '並松町', 'ナミマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区七道東町', '27', '27141', '5900913', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '七道東町', 'シチドウヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区北半町西', '27', '27141', '5900921', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '北半町西', 'キタハンチョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区北半町東', '27', '27141', '5900922', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '北半町東', 'キタハンチョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区北旅籠町東', '27', '27141', '5900923', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '北旅籠町東', 'キタハタゴチョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区桜之町東', '27', '27141', '5900924', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '桜之町東', 'サクラノチョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区綾之町東', '27', '27141', '5900925', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '綾之町東', 'アヤノチョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区綾之町西', '27', '27141', '5900926', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '綾之町西', 'アヤノチョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区桜之町西', '27', '27141', '5900927', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '桜之町西', 'サクラノチョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区北旅籠町西', '27', '27141', '5900928', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '北旅籠町西', 'キタハタゴチョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区柳之町西', '27', '27141', '5900930', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '柳之町西', 'ヤナギノチョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区錦之町西', '27', '27141', '5900931', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '錦之町西', 'ニシキノチョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区錦之町東', '27', '27141', '5900932', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '錦之町東', 'ニシキノチョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区柳之町東', '27', '27141', '5900933', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '柳之町東', 'ヤナギノチョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区九間町東', '27', '27141', '5900934', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '九間町東', 'クケンチョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区神明町東', '27', '27141', '5900935', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '神明町東', 'シンメイチョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区宿屋町東', '27', '27141', '5900936', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '宿屋町東', 'シュクヤチョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区宿屋町西', '27', '27141', '5900937', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '宿屋町西', 'シュクヤチョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区神明町西', '27', '27141', '5900938', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '神明町西', 'シンメイチョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区九間町西', '27', '27141', '5900939', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '九間町西', 'クケンチョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区車之町西', '27', '27141', '5900940', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '車之町西', 'クルマノチョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区材木町西', '27', '27141', '5900941', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '材木町西', 'ザイモクチョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区材木町東', '27', '27141', '5900942', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '材木町東', 'ザイモクチョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区車之町東', '27', '27141', '5900943', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '車之町東', 'クルマノチョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区櫛屋町東', '27', '27141', '5900944', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '櫛屋町東', 'クシヤチョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区戎之町東', '27', '27141', '5900945', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '戎之町東', 'エビスノチョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区熊野町東', '27', '27141', '5900946', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '熊野町東', 'クマノチョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区熊野町西', '27', '27141', '5900947', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '熊野町西', 'クマノチョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区戎之町西', '27', '27141', '5900948', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '戎之町西', 'エビスノチョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区櫛屋町西', '27', '27141', '5900949', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '櫛屋町西', 'クシヤチョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区甲斐町西', '27', '27141', '5900950', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '甲斐町西', 'カイノチョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区市之町西', '27', '27141', '5900951', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '市之町西', 'イチノチョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区市之町東', '27', '27141', '5900952', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '市之町東', 'イチノチョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区甲斐町東', '27', '27141', '5900953', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '甲斐町東', 'カイノチョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区大町東', '27', '27141', '5900954', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '大町東', 'オオチョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区宿院町東', '27', '27141', '5900955', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '宿院町東', 'シュクインチョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区中之町東', '27', '27141', '5900956', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '中之町東', 'ナカノチョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区中之町西', '27', '27141', '5900957', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '中之町西', 'ナカノチョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区宿院町西', '27', '27141', '5900958', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '宿院町西', 'シュクインチョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区大町西', '27', '27141', '5900959', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '大町西', 'オオチョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区少林寺町西', '27', '27141', '5900960', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '少林寺町西', 'ショウリンジチョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区寺地町西', '27', '27141', '5900961', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '寺地町西', 'テラジチョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区寺地町東', '27', '27141', '5900962', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '寺地町東', 'テラジチョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区少林寺町東', '27', '27141', '5900963', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '少林寺町東', 'ショウリンジチョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区新在家町東', '27', '27141', '5900964', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '新在家町東', 'シンザイケチョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区南旅篭町東', '27', '27141', '5900965', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '南旅篭町東', 'ミナミハタゴチョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区南半町東', '27', '27141', '5900966', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '南半町東', 'ミナミハンチョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区南半町西', '27', '27141', '5900967', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '南半町西', 'ミナミハンチョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区南旅篭町西', '27', '27141', '5900968', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '南旅篭町西', 'ミナミハタゴチョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区新在家町西', '27', '27141', '5900969', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '新在家町西', 'シンザイケチョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区栄橋町', '27', '27141', '5900971', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '栄橋町', 'サカエバシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区竜神橋町', '27', '27141', '5900972', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '竜神橋町', 'リュウジンバシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区住吉橋町', '27', '27141', '5900973', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '住吉橋町', 'スミヨシバシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区大浜北町', '27', '27141', '5900974', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '大浜北町', 'オオハマキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区大浜中町', '27', '27141', '5900975', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '大浜中町', 'オオハマナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区大浜南町', '27', '27141', '5900976', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '大浜南町', 'オオハマミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区大浜西町', '27', '27141', '5900977', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '大浜西町', 'オオハマニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区塩浜町', '27', '27141', '5900981', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '塩浜町', 'シオハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区海山町', '27', '27141', '5900982', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '海山町', 'カイサンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区山本町', '27', '27141', '5900983', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '山本町', 'ヤマモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区神南辺町', '27', '27141', '5900984', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '神南辺町', 'カンナベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区戎島町', '27', '27141', '5900985', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '戎島町', 'エビスジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区北波止町', '27', '27141', '5900986', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '北波止町', 'キタハトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市堺区築港南町', '27', '27141', '5900987', '大阪府', 'オオサカフ', '堺市堺区', 'サカイシサカイク', '築港南町', 'チッコウミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道伊達市有珠町', '01', '01233', '0590151', '北海道', 'ホッカイドウ', '伊達市', 'ダテシ', '有珠町', 'ウスチョウ', null, null, null, null), ('63682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道伊達市北有珠町', '01', '01233', '0590152', '北海道', 'ホッカイドウ', '伊達市', 'ダテシ', '北有珠町', 'キタウスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道伊達市大平町', '01', '01233', '0590153', '北海道', 'ホッカイドウ', '伊達市', 'ダテシ', '大平町', 'オオダイラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道伊達市東有珠町', '01', '01233', '0590154', '北海道', 'ホッカイドウ', '伊達市', 'ダテシ', '東有珠町', 'ヒガシウスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道伊達市若生町', '01', '01233', '0590155', '北海道', 'ホッカイドウ', '伊達市', 'ダテシ', '若生町', 'ワッカオイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道伊達市南有珠町', '01', '01233', '0590156', '北海道', 'ホッカイドウ', '伊達市', 'ダテシ', '南有珠町', 'ミナミウスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道伊達市向有珠町', '01', '01233', '0590157', '北海道', 'ホッカイドウ', '伊達市', 'ダテシ', '向有珠町', 'ムカイウスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道伊達市南黄金町', '01', '01233', '0590271', '北海道', 'ホッカイドウ', '伊達市', 'ダテシ', '南黄金町', 'ミナミコガネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道伊達市北黄金町', '01', '01233', '0590272', '北海道', 'ホッカイドウ', '伊達市', 'ダテシ', '北黄金町', 'キタコガネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道伊達市南稀府町', '01', '01233', '0590273', '北海道', 'ホッカイドウ', '伊達市', 'ダテシ', '南稀府町', 'ミナミマレフチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道伊達市中稀府町', '01', '01233', '0590274', '北海道', 'ホッカイドウ', '伊達市', 'ダテシ', '中稀府町', 'ナカマレフチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道伊達市北稀府町', '01', '01233', '0590275', '北海道', 'ホッカイドウ', '伊達市', 'ダテシ', '北稀府町', 'キタマレフチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道登別市札内町', '01', '01230', '0590461', '北海道', 'ホッカイドウ', '登別市', 'ノボリベツシ', '札内町', 'サツナイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道登別市富浦町', '01', '01230', '0590462', '北海道', 'ホッカイドウ', '登別市', 'ノボリベツシ', '富浦町', 'トミウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道登別市中登別町', '01', '01230', '0590463', '北海道', 'ホッカイドウ', '登別市', 'ノボリベツシ', '中登別町', 'ナカノボリベツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道登別市登別東町', '01', '01230', '0590464', '北海道', 'ホッカイドウ', '登別市', 'ノボリベツシ', '登別東町', 'ノボリベツヒガシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道登別市登別本町', '01', '01230', '0590465', '北海道', 'ホッカイドウ', '登別市', 'ノボリベツシ', '登別本町', 'ノボリベツホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道登別市登別港町', '01', '01230', '0590466', '北海道', 'ホッカイドウ', '登別市', 'ノボリベツシ', '登別港町', 'ノボリベツミナトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道登別市登別温泉町', '01', '01230', '0590551', '北海道', 'ホッカイドウ', '登別市', 'ノボリベツシ', '登別温泉町', 'ノボリベツオンセンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道登別市上登別町', '01', '01230', '0590552', '北海道', 'ホッカイドウ', '登別市', 'ノボリベツシ', '上登別町', 'カミノボリベツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道登別市カルルス町', '01', '01230', '0590553', '北海道', 'ホッカイドウ', '登別市', 'ノボリベツシ', 'カルルス町', 'カルルスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道白老郡白老町虎杖浜', '01', '01578', '0590641', '北海道', 'ホッカイドウ', '白老郡白老町', 'シラオイグンシラオイチョウ', '虎杖浜', 'コジョウハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道白老郡白老町竹浦', '01', '01578', '0590642', '北海道', 'ホッカイドウ', '白老郡白老町', 'シラオイグンシラオイチョウ', '竹浦', 'タケウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道白老郡白老町', '01', '01578', '0590900', '北海道', 'ホッカイドウ', '白老郡白老町', 'シラオイグンシラオイチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('63730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道白老郡白老町社台', '01', '01578', '0590901', '北海道', 'ホッカイドウ', '白老郡白老町', 'シラオイグンシラオイチョウ', '社台', 'シャダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道白老郡白老町若草町', '01', '01578', '0590902', '北海道', 'ホッカイドウ', '白老郡白老町', 'シラオイグンシラオイチョウ', '若草町', 'ワカクサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道白老郡白老町日の出町', '01', '01578', '0590903', '北海道', 'ホッカイドウ', '白老郡白老町', 'シラオイグンシラオイチョウ', '日の出町', 'ヒノデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道白老郡白老町東町', '01', '01578', '0590904', '北海道', 'ホッカイドウ', '白老郡白老町', 'シラオイグンシラオイチョウ', '東町', 'ヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道白老郡白老町大町', '01', '01578', '0590905', '北海道', 'ホッカイドウ', '白老郡白老町', 'シラオイグンシラオイチョウ', '大町', 'オオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道白老郡白老町本町', '01', '01578', '0590906', '北海道', 'ホッカイドウ', '白老郡白老町', 'シラオイグンシラオイチョウ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道白老郡白老町末広町', '01', '01578', '0590907', '北海道', 'ホッカイドウ', '白老郡白老町', 'シラオイグンシラオイチョウ', '末広町', 'スエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道白老郡白老町緑丘', '01', '01578', '0590908', '北海道', 'ホッカイドウ', '白老郡白老町', 'シラオイグンシラオイチョウ', '緑丘', 'ミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道白老郡白老町森野', '01', '01578', '0590911', '北海道', 'ホッカイドウ', '白老郡白老町', 'シラオイグンシラオイチョウ', '森野', 'モリノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道白老郡白老町陣屋町', '01', '01578', '0590912', '北海道', 'ホッカイドウ', '白老郡白老町', 'シラオイグンシラオイチョウ', '陣屋町', 'ジンヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道白老郡白老町緑町', '01', '01578', '0590913', '北海道', 'ホッカイドウ', '白老郡白老町', 'シラオイグンシラオイチョウ', '緑町', 'ミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道白老郡白老町栄町', '01', '01578', '0590914', '北海道', 'ホッカイドウ', '白老郡白老町', 'シラオイグンシラオイチョウ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道白老郡白老町川沿', '01', '01578', '0590915', '北海道', 'ホッカイドウ', '白老郡白老町', 'シラオイグンシラオイチョウ', '川沿', 'カワゾエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道白老郡白老町高砂町', '01', '01578', '0590916', '北海道', 'ホッカイドウ', '白老郡白老町', 'シラオイグンシラオイチョウ', '高砂町', 'タカサゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道白老郡白老町石山', '01', '01578', '0590921', '北海道', 'ホッカイドウ', '白老郡白老町', 'シラオイグンシラオイチョウ', '石山', 'イシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道白老郡白老町萩野', '01', '01578', '0590922', '北海道', 'ホッカイドウ', '白老郡白老町', 'シラオイグンシラオイチョウ', '萩野', 'ハギノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道白老郡白老町北吉原', '01', '01578', '0590923', '北海道', 'ホッカイドウ', '白老郡白老町', 'シラオイグンシラオイチョウ', '北吉原', 'キタヨシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市北区', '27', '27146', '5910000', '大阪府', 'オオサカフ', '堺市北区', 'サカイシキタク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('63752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫小牧市ときわ町', '01', '01213', '0591261', '北海道', 'ホッカイドウ', '苫小牧市', 'トマコマイシ', 'ときわ町', 'トキワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫小牧市美原町', '01', '01213', '0591262', '北海道', 'ホッカイドウ', '苫小牧市', 'トマコマイシ', '美原町', 'ミハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫小牧市青雲町', '01', '01213', '0591263', '北海道', 'ホッカイドウ', '苫小牧市', 'トマコマイシ', '青雲町', 'セイウンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫小牧市宮前町', '01', '01213', '0591264', '北海道', 'ホッカイドウ', '苫小牧市', 'トマコマイシ', '宮前町', 'ミヤマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫小牧市樽前', '01', '01213', '0591265', '北海道', 'ホッカイドウ', '苫小牧市', 'トマコマイシ', '樽前', 'タルマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫小牧市澄川町', '01', '01213', '0591271', '北海道', 'ホッカイドウ', '苫小牧市', 'トマコマイシ', '澄川町', 'スミカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫小牧市のぞみ町', '01', '01213', '0591272', '北海道', 'ホッカイドウ', '苫小牧市', 'トマコマイシ', 'のぞみ町', 'ノゾミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫小牧市明徳町', '01', '01213', '0591273', '北海道', 'ホッカイドウ', '苫小牧市', 'トマコマイシ', '明徳町', 'メイトクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫小牧市もえぎ町', '01', '01213', '0591274', '北海道', 'ホッカイドウ', '苫小牧市', 'トマコマイシ', 'もえぎ町', 'モエギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫小牧市錦岡', '01', '01213', '0591275', '北海道', 'ホッカイドウ', '苫小牧市', 'トマコマイシ', '錦岡', 'ニシキオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫小牧市はまなす町2丁目', '01', '01213', '0591276', '北海道', 'ホッカイドウ', '苫小牧市', 'トマコマイシ', 'はまなす町', 'ハマナスチョウ', null, null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('63764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫小牧市東開町', '01', '01213', '0591301', '北海道', 'ホッカイドウ', '苫小牧市', 'トマコマイシ', '東開町', 'トウカイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫小牧市拓勇西町', '01', '01213', '0591302', '北海道', 'ホッカイドウ', '苫小牧市', 'トマコマイシ', '拓勇西町', 'タクユウニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫小牧市拓勇東町', '01', '01213', '0591303', '北海道', 'ホッカイドウ', '苫小牧市', 'トマコマイシ', '拓勇東町', 'タクユウヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫小牧市北栄町', '01', '01213', '0591304', '北海道', 'ホッカイドウ', '苫小牧市', 'トマコマイシ', '北栄町', 'ホクエイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫小牧市美沢', '01', '01213', '0591361', '北海道', 'ホッカイドウ', '苫小牧市', 'トマコマイシ', '美沢', 'ミサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫小牧市柏原', '01', '01213', '0591362', '北海道', 'ホッカイドウ', '苫小牧市', 'トマコマイシ', '柏原', 'カシワバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫小牧市静川', '01', '01213', '0591363', '北海道', 'ホッカイドウ', '苫小牧市', 'トマコマイシ', '静川', 'シズカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫小牧市沼ノ端', '01', '01213', '0591364', '北海道', 'ホッカイドウ', '苫小牧市', 'トマコマイシ', '沼ノ端', 'ヌマノハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫小牧市植苗', '01', '01213', '0591365', '北海道', 'ホッカイドウ', '苫小牧市', 'トマコマイシ', '植苗', 'ウエナエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫小牧市あけぼの町1丁目', '01', '01213', '0591366', '北海道', 'ホッカイドウ', '苫小牧市', 'トマコマイシ', 'あけぼの町', 'アケボノチョウ', null, null, '1丁目', '01チョウメ');
INSERT INTO `ms_addresses` VALUES ('63774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫小牧市あけぼの町2丁目', '01', '01213', '0591366', '北海道', 'ホッカイドウ', '苫小牧市', 'トマコマイシ', 'あけぼの町', 'アケボノチョウ', null, null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('63775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫小牧市弁天', '01', '01213', '0591371', '北海道', 'ホッカイドウ', '苫小牧市', 'トマコマイシ', '弁天', 'ベンテン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫小牧市勇払', '01', '01213', '0591372', '北海道', 'ホッカイドウ', '苫小牧市', 'トマコマイシ', '勇払', 'ユウフツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫小牧市真砂町', '01', '01213', '0591373', '北海道', 'ホッカイドウ', '苫小牧市', 'トマコマイシ', '真砂町', 'マサゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫小牧市晴海町', '01', '01213', '0591374', '北海道', 'ホッカイドウ', '苫小牧市', 'トマコマイシ', '晴海町', 'ハルミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫小牧市一本松町', '01', '01213', '0591375', '北海道', 'ホッカイドウ', '苫小牧市', 'トマコマイシ', '一本松町', 'イッポンマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡安平町早来新栄', '01', '01585', '0591431', '北海道', 'ホッカイドウ', '勇払郡安平町', 'ユウフツグンアビラチョウ', '早来新栄', 'ハヤキタシンエイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡安平町早来源武', '01', '01585', '0591432', '北海道', 'ホッカイドウ', '勇払郡安平町', 'ユウフツグンアビラチョウ', '早来源武', 'ハヤキタゲンブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡安平町遠浅', '01', '01585', '0591433', '北海道', 'ホッカイドウ', '勇払郡安平町', 'ユウフツグンアビラチョウ', '遠浅', 'トアサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡安平町早来富岡', '01', '01585', '0591434', '北海道', 'ホッカイドウ', '勇払郡安平町', 'ユウフツグンアビラチョウ', '早来富岡', 'ハヤキタトミオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡安平町', '01', '01585', '0591500', '北海道', 'ホッカイドウ', '勇払郡安平町', 'ユウフツグンアビラチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('63790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡安平町早来大町', '01', '01585', '0591501', '北海道', 'ホッカイドウ', '勇払郡安平町', 'ユウフツグンアビラチョウ', '早来大町', 'ハヤキタオオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡安平町早来北進', '01', '01585', '0591502', '北海道', 'ホッカイドウ', '勇払郡安平町', 'ユウフツグンアビラチョウ', '早来北進', 'ハヤキタホクシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡安平町東早来', '01', '01585', '0591503', '北海道', 'ホッカイドウ', '勇払郡安平町', 'ユウフツグンアビラチョウ', '東早来', 'ヒガシハヤキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡安平町早来守田', '01', '01585', '0591504', '北海道', 'ホッカイドウ', '勇払郡安平町', 'ユウフツグンアビラチョウ', '早来守田', 'ハヤキタモリタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡安平町早来栄町', '01', '01585', '0591505', '北海道', 'ホッカイドウ', '勇払郡安平町', 'ユウフツグンアビラチョウ', '早来栄町', 'ハヤキタサカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡安平町早来北町', '01', '01585', '0591506', '北海道', 'ホッカイドウ', '勇払郡安平町', 'ユウフツグンアビラチョウ', '早来北町', 'ハヤキタキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡安平町安平', '01', '01585', '0591511', '北海道', 'ホッカイドウ', '勇払郡安平町', 'ユウフツグンアビラチョウ', '安平', 'アビラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡安平町早来瑞穂', '01', '01585', '0591512', '北海道', 'ホッカイドウ', '勇払郡安平町', 'ユウフツグンアビラチョウ', '早来瑞穂', 'ハヤキタミズホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡安平町早来緑丘', '01', '01585', '0591513', '北海道', 'ホッカイドウ', '勇払郡安平町', 'ユウフツグンアビラチョウ', '早来緑丘', 'ハヤキタミドリオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡厚真町', '01', '01581', '0591600', '北海道', 'ホッカイドウ', '勇払郡厚真町', 'ユウフツグンアツマチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('63805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡厚真町京町', '01', '01581', '0591601', '北海道', 'ホッカイドウ', '勇払郡厚真町', 'ユウフツグンアツマチョウ', '京町', 'キョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡厚真町表町', '01', '01581', '0591602', '北海道', 'ホッカイドウ', '勇払郡厚真町', 'ユウフツグンアツマチョウ', '表町', 'オモテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡厚真町本町', '01', '01581', '0591603', '北海道', 'ホッカイドウ', '勇払郡厚真町', 'ユウフツグンアツマチョウ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡厚真町錦町', '01', '01581', '0591604', '北海道', 'ホッカイドウ', '勇払郡厚真町', 'ユウフツグンアツマチョウ', '錦町', 'ニシキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡厚真町本郷', '01', '01581', '0591605', '北海道', 'ホッカイドウ', '勇払郡厚真町', 'ユウフツグンアツマチョウ', '本郷', 'ホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡厚真町朝日', '01', '01581', '0591606', '北海道', 'ホッカイドウ', '勇払郡厚真町', 'ユウフツグンアツマチョウ', '朝日', 'アサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡厚真町幌里', '01', '01581', '0591611', '北海道', 'ホッカイドウ', '勇払郡厚真町', 'ユウフツグンアツマチョウ', '幌里', 'ホロサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡厚真町桜丘', '01', '01581', '0591612', '北海道', 'ホッカイドウ', '勇払郡厚真町', 'ユウフツグンアツマチョウ', '桜丘', 'サクラオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡厚真町吉野', '01', '01581', '0591613', '北海道', 'ホッカイドウ', '勇払郡厚真町', 'ユウフツグンアツマチョウ', '吉野', 'ヨシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡厚真町富里', '01', '01581', '0591614', '北海道', 'ホッカイドウ', '勇払郡厚真町', 'ユウフツグンアツマチョウ', '富里', 'トミサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡厚真町高丘', '01', '01581', '0591615', '北海道', 'ホッカイドウ', '勇払郡厚真町', 'ユウフツグンアツマチョウ', '高丘', 'タカオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡厚真町幌内', '01', '01581', '0591616', '北海道', 'ホッカイドウ', '勇払郡厚真町', 'ユウフツグンアツマチョウ', '幌内', 'ホロナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡厚真町東和', '01', '01581', '0591621', '北海道', 'ホッカイドウ', '勇払郡厚真町', 'ユウフツグンアツマチョウ', '東和', 'トウワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡厚真町宇隆', '01', '01581', '0591622', '北海道', 'ホッカイドウ', '勇払郡厚真町', 'ユウフツグンアツマチョウ', '宇隆', 'ウリュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡厚真町新町', '01', '01581', '0591623', '北海道', 'ホッカイドウ', '勇払郡厚真町', 'ユウフツグンアツマチョウ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡厚真町豊沢', '01', '01581', '0591624', '北海道', 'ホッカイドウ', '勇払郡厚真町', 'ユウフツグンアツマチョウ', '豊沢', 'トヨサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡厚真町美里', '01', '01581', '0591625', '北海道', 'ホッカイドウ', '勇払郡厚真町', 'ユウフツグンアツマチョウ', '美里', 'ミサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡厚真町上厚真', '01', '01581', '0591741', '北海道', 'ホッカイドウ', '勇払郡厚真町', 'ユウフツグンアツマチョウ', '上厚真', 'カミアツマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡厚真町浜厚真', '01', '01581', '0591742', '北海道', 'ホッカイドウ', '勇払郡厚真町', 'ユウフツグンアツマチョウ', '浜厚真', 'ハマアツマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡厚真町共和', '01', '01581', '0591743', '北海道', 'ホッカイドウ', '勇払郡厚真町', 'ユウフツグンアツマチョウ', '共和', 'キョウワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡厚真町共栄', '01', '01581', '0591744', '北海道', 'ホッカイドウ', '勇払郡厚真町', 'ユウフツグンアツマチョウ', '共栄', 'キョウエイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡厚真町豊川', '01', '01581', '0591745', '北海道', 'ホッカイドウ', '勇払郡厚真町', 'ユウフツグンアツマチョウ', '豊川', 'トヨカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡厚真町上野', '01', '01581', '0591746', '北海道', 'ホッカイドウ', '勇払郡厚真町', 'ユウフツグンアツマチョウ', '上野', 'ウエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡厚真町富野', '01', '01581', '0591747', '北海道', 'ホッカイドウ', '勇払郡厚真町', 'ユウフツグンアツマチョウ', '富野', 'トミノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡厚真町厚和', '01', '01581', '0591748', '北海道', 'ホッカイドウ', '勇払郡厚真町', 'ユウフツグンアツマチョウ', '厚和', 'コウワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡厚真町清住', '01', '01581', '0591749', '北海道', 'ホッカイドウ', '勇払郡厚真町', 'ユウフツグンアツマチョウ', '清住', 'キヨズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡厚真町鯉沼', '01', '01581', '0591751', '北海道', 'ホッカイドウ', '勇払郡厚真町', 'ユウフツグンアツマチョウ', '鯉沼', 'コイヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡厚真町軽舞', '01', '01581', '0591752', '北海道', 'ホッカイドウ', '勇払郡厚真町', 'ユウフツグンアツマチョウ', '軽舞', 'カルマイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡厚真町豊丘', '01', '01581', '0591753', '北海道', 'ホッカイドウ', '勇払郡厚真町', 'ユウフツグンアツマチョウ', '豊丘', 'トヨオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡厚真町鹿沼', '01', '01581', '0591754', '北海道', 'ホッカイドウ', '勇払郡厚真町', 'ユウフツグンアツマチョウ', '鹿沼', 'シカヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市北区常磐町', '27', '27146', '5918001', '大阪府', 'オオサカフ', '堺市北区', 'サカイシキタク', '常磐町', 'トキワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市北区北花田町', '27', '27146', '5918002', '大阪府', 'オオサカフ', '堺市北区', 'サカイシキタク', '北花田町', 'キタハナダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市北区船堂町', '27', '27146', '5918003', '大阪府', 'オオサカフ', '堺市北区', 'サカイシキタク', '船堂町', 'センドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市北区蔵前町', '27', '27146', '5918004', '大阪府', 'オオサカフ', '堺市北区', 'サカイシキタク', '蔵前町', 'クラマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市北区新堀町', '27', '27146', '5918005', '大阪府', 'オオサカフ', '堺市北区', 'サカイシキタク', '新堀町', 'シンボリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市北区宮本町', '27', '27146', '5918006', '大阪府', 'オオサカフ', '堺市北区', 'サカイシキタク', '宮本町', 'ミヤモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市北区奥本町', '27', '27146', '5918007', '大阪府', 'オオサカフ', '堺市北区', 'サカイシキタク', '奥本町', 'オクモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市北区東浅香山町', '27', '27146', '5918008', '大阪府', 'オオサカフ', '堺市北区', 'サカイシキタク', '東浅香山町', 'ヒガシアサカヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市北区南花田町', '27', '27146', '5918011', '大阪府', 'オオサカフ', '堺市北区', 'サカイシキタク', '南花田町', 'ミナミハナダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市北区中村町', '27', '27146', '5918012', '大阪府', 'オオサカフ', '堺市北区', 'サカイシキタク', '中村町', 'ナカムラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市北区野遠町', '27', '27146', '5918013', '大阪府', 'オオサカフ', '堺市北区', 'サカイシキタク', '野遠町', 'ノトウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市北区八下北', '27', '27146', '5918014', '大阪府', 'オオサカフ', '堺市北区', 'サカイシキタク', '八下北', 'ヤシモキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市北区新金岡町', '27', '27146', '5918021', '大阪府', 'オオサカフ', '堺市北区', 'サカイシキタク', '新金岡町', 'シンカナオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市北区金岡町', '27', '27146', '5918022', '大阪府', 'オオサカフ', '堺市北区', 'サカイシキタク', '金岡町', 'カナオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市北区中百舌鳥町', '27', '27146', '5918023', '大阪府', 'オオサカフ', '堺市北区', 'サカイシキタク', '中百舌鳥町', 'ナカモズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市北区黒土町', '27', '27146', '5918024', '大阪府', 'オオサカフ', '堺市北区', 'サカイシキタク', '黒土町', 'クロツチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市北区長曾根町', '27', '27146', '5918025', '大阪府', 'オオサカフ', '堺市北区', 'サカイシキタク', '長曾根町', 'ナガソネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市北区百舌鳥梅北町', '27', '27146', '5918031', '大阪府', 'オオサカフ', '堺市北区', 'サカイシキタク', '百舌鳥梅北町', 'モズウメキタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市北区百舌鳥梅町', '27', '27146', '5918032', '大阪府', 'オオサカフ', '堺市北区', 'サカイシキタク', '百舌鳥梅町', 'モズウメマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市北区百舌鳥西之町', '27', '27146', '5918033', '大阪府', 'オオサカフ', '堺市北区', 'サカイシキタク', '百舌鳥西之町', 'モズニシノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市北区百舌鳥陵南町', '27', '27146', '5918034', '大阪府', 'オオサカフ', '堺市北区', 'サカイシキタク', '百舌鳥陵南町', 'モズリョウナンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市北区東上野芝町2丁', '27', '27146', '5918035', '大阪府', 'オオサカフ', '堺市北区', 'サカイシキタク', '東上野芝町', 'ヒガシウエノシバチョウ', null, null, '2丁', '02チョウ');
INSERT INTO `ms_addresses` VALUES ('63859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市北区百舌鳥本町', '27', '27146', '5918036', '大阪府', 'オオサカフ', '堺市北区', 'サカイシキタク', '百舌鳥本町', 'モズホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市北区百舌鳥赤畑町', '27', '27146', '5918037', '大阪府', 'オオサカフ', '堺市北区', 'サカイシキタク', '百舌鳥赤畑町', 'モズアカハタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市北区東雲東町', '27', '27146', '5918041', '大阪府', 'オオサカフ', '堺市北区', 'サカイシキタク', '東雲東町', 'シノノメヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市北区大豆塚町', '27', '27146', '5918042', '大阪府', 'オオサカフ', '堺市北区', 'サカイシキタク', '大豆塚町', 'マメヅカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市北区北長尾町', '27', '27146', '5918043', '大阪府', 'オオサカフ', '堺市北区', 'サカイシキタク', '北長尾町', 'キタナガオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市北区中長尾町', '27', '27146', '5918044', '大阪府', 'オオサカフ', '堺市北区', 'サカイシキタク', '中長尾町', 'ナカナガオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市北区南長尾町', '27', '27146', '5918045', '大阪府', 'オオサカフ', '堺市北区', 'サカイシキタク', '南長尾町', 'ミナミナガオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市北区東三国ケ丘町', '27', '27146', '5918046', '大阪府', 'オオサカフ', '堺市北区', 'サカイシキタク', '東三国ケ丘町', 'ヒガシミクニガオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡安平町追分本町', '01', '01585', '0591911', '北海道', 'ホッカイドウ', '勇払郡安平町', 'ユウフツグンアビラチョウ', '追分本町', 'オイワケホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡安平町追分柏が丘', '01', '01585', '0591921', '北海道', 'ホッカイドウ', '勇払郡安平町', 'ユウフツグンアビラチョウ', '追分柏が丘', 'オイワケカシワガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡安平町追分中央', '01', '01585', '0591931', '北海道', 'ホッカイドウ', '勇払郡安平町', 'ユウフツグンアビラチョウ', '追分中央', 'オイワケチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡安平町追分青葉', '01', '01585', '0591941', '北海道', 'ホッカイドウ', '勇払郡安平町', 'ユウフツグンアビラチョウ', '追分青葉', 'オイワケアオバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡安平町追分白樺', '01', '01585', '0591942', '北海道', 'ホッカイドウ', '勇払郡安平町', 'ユウフツグンアビラチョウ', '追分白樺', 'オイワケシラカバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡安平町追分若草', '01', '01585', '0591951', '北海道', 'ホッカイドウ', '勇払郡安平町', 'ユウフツグンアビラチョウ', '追分若草', 'オイワケワカクサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡安平町追分花園', '01', '01585', '0591961', '北海道', 'ホッカイドウ', '勇払郡安平町', 'ユウフツグンアビラチョウ', '追分花園', 'オイワケハナゾノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡安平町追分緑が丘', '01', '01585', '0591971', '北海道', 'ホッカイドウ', '勇払郡安平町', 'ユウフツグンアビラチョウ', '追分緑が丘', 'オイワケミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡安平町追分美園', '01', '01585', '0591982', '北海道', 'ホッカイドウ', '勇払郡安平町', 'ユウフツグンアビラチョウ', '追分美園', 'オイワケミソノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡安平町追分旭', '01', '01585', '0591983', '北海道', 'ホッカイドウ', '勇払郡安平町', 'ユウフツグンアビラチョウ', '追分旭', 'オイワケアサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡安平町追分向陽', '01', '01585', '0591984', '北海道', 'ホッカイドウ', '勇払郡安平町', 'ユウフツグンアビラチョウ', '追分向陽', 'オイワケコウヨウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡安平町追分春日', '01', '01585', '0591985', '北海道', 'ホッカイドウ', '勇払郡安平町', 'ユウフツグンアビラチョウ', '追分春日', 'オイワケカスガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡安平町追分弥生', '01', '01585', '0591986', '北海道', 'ホッカイドウ', '勇払郡安平町', 'ユウフツグンアビラチョウ', '追分弥生', 'オイワケヤヨイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡安平町追分豊栄', '01', '01585', '0591987', '北海道', 'ホッカイドウ', '勇払郡安平町', 'ユウフツグンアビラチョウ', '追分豊栄', 'オイワケホウエイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高石市', '27', '27225', '5920000', '大阪府', 'オオサカフ', '高石市', 'タカイシシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('63887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高石市高砂', '27', '27225', '5920001', '大阪府', 'オオサカフ', '高石市', 'タカイシシ', '高砂', 'タカサゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高石市羽衣', '27', '27225', '5920002', '大阪府', 'オオサカフ', '高石市', 'タカイシシ', '羽衣', 'ハゴロモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高石市羽衣公園丁', '27', '27225', '5920002', '大阪府', 'オオサカフ', '高石市', 'タカイシシ', '羽衣公園丁', 'ハゴロモコウエンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高石市東羽衣', '27', '27225', '5920003', '大阪府', 'オオサカフ', '高石市', 'タカイシシ', '東羽衣', 'ヒガシハゴロモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高石市高師浜', '27', '27225', '5920004', '大阪府', 'オオサカフ', '高石市', 'タカイシシ', '高師浜', 'タカシノハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高石市千代田', '27', '27225', '5920005', '大阪府', 'オオサカフ', '高石市', 'タカイシシ', '千代田', 'チヨダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高石市高師浜丁', '27', '27225', '5920006', '大阪府', 'オオサカフ', '高石市', 'タカイシシ', '高師浜丁', 'タカシノハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高石市加茂', '27', '27225', '5920011', '大阪府', 'オオサカフ', '高石市', 'タカイシシ', '加茂', 'カモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高石市西取石', '27', '27225', '5920012', '大阪府', 'オオサカフ', '高石市', 'タカイシシ', '西取石', 'ニシトリイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高石市取石', '27', '27225', '5920013', '大阪府', 'オオサカフ', '高石市', 'タカイシシ', '取石', 'トリイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高石市綾園', '27', '27225', '5920014', '大阪府', 'オオサカフ', '高石市', 'タカイシシ', '綾園', 'アヤゾノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道沙流郡日高町門別本町', '01', '01601', '0592121', '北海道', 'ホッカイドウ', '沙流郡日高町', 'サルグンヒダカチョウ', '門別本町', 'モンベツホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道沙流郡日高町緑町', '01', '01601', '0592122', '北海道', 'ホッカイドウ', '沙流郡日高町', 'サルグンヒダカチョウ', '緑町', 'ミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道沙流郡日高町幾千世', '01', '01601', '0592123', '北海道', 'ホッカイドウ', '沙流郡日高町', 'サルグンヒダカチョウ', '幾千世', 'イクチセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道沙流郡日高町庫富', '01', '01601', '0592124', '北海道', 'ホッカイドウ', '沙流郡日高町', 'サルグンヒダカチョウ', '庫富', 'クラトミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道沙流郡日高町広富', '01', '01601', '0592125', '北海道', 'ホッカイドウ', '沙流郡日高町', 'サルグンヒダカチョウ', '広富', 'ヒロトミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道沙流郡日高町豊郷', '01', '01601', '0592126', '北海道', 'ホッカイドウ', '沙流郡日高町', 'サルグンヒダカチョウ', '豊郷', 'トヨサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道沙流郡日高町旭町', '01', '01601', '0592127', '北海道', 'ホッカイドウ', '沙流郡日高町', 'サルグンヒダカチョウ', '旭町', 'アサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道沙流郡日高町豊田', '01', '01601', '0592241', '北海道', 'ホッカイドウ', '沙流郡日高町', 'サルグンヒダカチョウ', '豊田', 'トヨタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道沙流郡日高町美原', '01', '01601', '0592242', '北海道', 'ホッカイドウ', '沙流郡日高町', 'サルグンヒダカチョウ', '美原', 'ミハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道沙流郡日高町厚賀町', '01', '01601', '0592243', '北海道', 'ホッカイドウ', '沙流郡日高町', 'サルグンヒダカチョウ', '厚賀町', 'アツガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道沙流郡日高町賀張', '01', '01601', '0592244', '北海道', 'ホッカイドウ', '沙流郡日高町', 'サルグンヒダカチョウ', '賀張', 'カバリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道沙流郡日高町清畠', '01', '01601', '0592245', '北海道', 'ホッカイドウ', '沙流郡日高町', 'サルグンヒダカチョウ', '清畠', 'キヨハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道新冠郡新冠町共栄', '01', '01604', '0592251', '北海道', 'ホッカイドウ', '新冠郡新冠町', 'ニイカップグンニイカップチョウ', '共栄', 'キョウエイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道新冠郡新冠町東川', '01', '01604', '0592252', '北海道', 'ホッカイドウ', '新冠郡新冠町', 'ニイカップグンニイカップチョウ', '東川', 'ヒガシカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道新冠郡新冠町大狩部', '01', '01604', '0592253', '北海道', 'ホッカイドウ', '新冠郡新冠町', 'ニイカップグンニイカップチョウ', '大狩部', 'オオカリベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道沙流郡日高町正和', '01', '01601', '0592331', '北海道', 'ホッカイドウ', '沙流郡日高町', 'サルグンヒダカチョウ', '正和', 'ショウワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道沙流郡日高町三和', '01', '01601', '0592332', '北海道', 'ホッカイドウ', '沙流郡日高町', 'サルグンヒダカチョウ', '三和', 'ミワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道新冠郡新冠町新和', '01', '01604', '0592341', '北海道', 'ホッカイドウ', '新冠郡新冠町', 'ニイカップグンニイカップチョウ', '新和', 'シンワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道新冠郡新冠町里平', '01', '01604', '0592342', '北海道', 'ホッカイドウ', '新冠郡新冠町', 'ニイカップグンニイカップチョウ', '里平', 'リビラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道新冠郡新冠町太陽', '01', '01604', '0592343', '北海道', 'ホッカイドウ', '新冠郡新冠町', 'ニイカップグンニイカップチョウ', '太陽', 'タイヨウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道新冠郡新冠町美宇', '01', '01604', '0592344', '北海道', 'ホッカイドウ', '新冠郡新冠町', 'ニイカップグンニイカップチョウ', '美宇', 'ビウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道新冠郡新冠町', '01', '01604', '0592400', '北海道', 'ホッカイドウ', '新冠郡新冠町', 'ニイカップグンニイカップチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('63921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道新冠郡新冠町本町', '01', '01604', '0592401', '北海道', 'ホッカイドウ', '新冠郡新冠町', 'ニイカップグンニイカップチョウ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道新冠郡新冠町中央町', '01', '01604', '0592402', '北海道', 'ホッカイドウ', '新冠郡新冠町', 'ニイカップグンニイカップチョウ', '中央町', 'チュウオウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道新冠郡新冠町北星町', '01', '01604', '0592403', '北海道', 'ホッカイドウ', '新冠郡新冠町', 'ニイカップグンニイカップチョウ', '北星町', 'ホクセイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道新冠郡新冠町東町', '01', '01604', '0592404', '北海道', 'ホッカイドウ', '新冠郡新冠町', 'ニイカップグンニイカップチョウ', '東町', 'アズマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道新冠郡新冠町大狩部', '01', '01604', '0592411', '北海道', 'ホッカイドウ', '新冠郡新冠町', 'ニイカップグンニイカップチョウ', '大狩部', 'オオカリベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道新冠郡新冠町節婦町', '01', '01604', '0592412', '北海道', 'ホッカイドウ', '新冠郡新冠町', 'ニイカップグンニイカップチョウ', '節婦町', 'セップチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道新冠郡新冠町高江', '01', '01604', '0592413', '北海道', 'ホッカイドウ', '新冠郡新冠町', 'ニイカップグンニイカップチョウ', '高江', 'タカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道新冠郡新冠町朝日', '01', '01604', '0592414', '北海道', 'ホッカイドウ', '新冠郡新冠町', 'ニイカップグンニイカップチョウ', '朝日', 'アサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道新冠郡新冠町緑丘', '01', '01604', '0592415', '北海道', 'ホッカイドウ', '新冠郡新冠町', 'ニイカップグンニイカップチョウ', '緑丘', 'ミドリオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道新冠郡新冠町古岸', '01', '01604', '0592416', '北海道', 'ホッカイドウ', '新冠郡新冠町', 'ニイカップグンニイカップチョウ', '古岸', 'フルギシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道新冠郡新冠町東泊津', '01', '01604', '0592417', '北海道', 'ホッカイドウ', '新冠郡新冠町', 'ニイカップグンニイカップチョウ', '東泊津', 'ヒガシハクツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道新冠郡新冠町西泊津', '01', '01604', '0592418', '北海道', 'ホッカイドウ', '新冠郡新冠町', 'ニイカップグンニイカップチョウ', '西泊津', 'ニシハクツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道新冠郡新冠町若園', '01', '01604', '0592421', '北海道', 'ホッカイドウ', '新冠郡新冠町', 'ニイカップグンニイカップチョウ', '若園', 'ワカゾノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道新冠郡新冠町岩清水', '01', '01604', '0592422', '北海道', 'ホッカイドウ', '新冠郡新冠町', 'ニイカップグンニイカップチョウ', '岩清水', 'イワシミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道新冠郡新冠町泉', '01', '01604', '0592423', '北海道', 'ホッカイドウ', '新冠郡新冠町', 'ニイカップグンニイカップチョウ', '泉', 'イズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道新冠郡新冠町新栄', '01', '01604', '0592424', '北海道', 'ホッカイドウ', '新冠郡新冠町', 'ニイカップグンニイカップチョウ', '新栄', 'シンエイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道新冠郡新冠町明和', '01', '01604', '0592425', '北海道', 'ホッカイドウ', '新冠郡新冠町', 'ニイカップグンニイカップチョウ', '明和', 'メイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道新冠郡新冠町万世', '01', '01604', '0592426', '北海道', 'ホッカイドウ', '新冠郡新冠町', 'ニイカップグンニイカップチョウ', '万世', 'バンセイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道新冠郡新冠町大富', '01', '01604', '0592427', '北海道', 'ホッカイドウ', '新冠郡新冠町', 'ニイカップグンニイカップチョウ', '大富', 'オオトミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道日高郡新ひだか町東静内', '01', '01610', '0592561', '北海道', 'ホッカイドウ', '日高郡新ひだか町', 'ヒダカグンシンヒダカチョウ', '東静内', 'ヒガシシズナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道日高郡新ひだか町静内浦和', '01', '01610', '0592562', '北海道', 'ホッカイドウ', '日高郡新ひだか町', 'ヒダカグンシンヒダカチョウ', '静内浦和', 'シズナイウラワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道日高郡新ひだか町静内川合', '01', '01610', '0592563', '北海道', 'ホッカイドウ', '日高郡新ひだか町', 'ヒダカグンシンヒダカチョウ', '静内川合', 'シズナイカワアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道日高郡新ひだか町静内西川', '01', '01610', '0592564', '北海道', 'ホッカイドウ', '日高郡新ひだか町', 'ヒダカグンシンヒダカチョウ', '静内西川', 'シズナイニシカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道日高郡新ひだか町静内春立', '01', '01610', '0592565', '北海道', 'ホッカイドウ', '日高郡新ひだか町', 'ヒダカグンシンヒダカチョウ', '静内春立', 'シズナイハルタチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道日高郡新ひだか町静内東別', '01', '01610', '0592566', '北海道', 'ホッカイドウ', '日高郡新ひだか町', 'ヒダカグンシンヒダカチョウ', '静内東別', 'シズナイトウベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道日高郡新ひだか町三石西端', '01', '01610', '0592571', '北海道', 'ホッカイドウ', '日高郡新ひだか町', 'ヒダカグンシンヒダカチョウ', '三石西端', 'ミツイシニシハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市西区築港新町', '27', '27144', '5928331', '大阪府', 'オオサカフ', '堺市西区', 'サカイシニシク', '築港新町', 'チッコウシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市西区石津西町', '27', '27144', '5928332', '大阪府', 'オオサカフ', '堺市西区', 'サカイシニシク', '石津西町', 'イシヅニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市西区浜寺石津町西', '27', '27144', '5928333', '大阪府', 'オオサカフ', '堺市西区', 'サカイシニシク', '浜寺石津町西', 'ハマデライシヅチョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市西区浜寺石津町中', '27', '27144', '5928334', '大阪府', 'オオサカフ', '堺市西区', 'サカイシニシク', '浜寺石津町中', 'ハマデライシヅチョウナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市西区浜寺石津町東', '27', '27144', '5928335', '大阪府', 'オオサカフ', '堺市西区', 'サカイシニシク', '浜寺石津町東', 'ハマデライシヅチョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市西区浜寺船尾町東', '27', '27144', '5928341', '大阪府', 'オオサカフ', '堺市西区', 'サカイシニシク', '浜寺船尾町東', 'ハマデラフナオチョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市西区浜寺船尾町西', '27', '27144', '5928342', '大阪府', 'オオサカフ', '堺市西区', 'サカイシニシク', '浜寺船尾町西', 'ハマデラフナオチョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市西区浜寺元町', '27', '27144', '5928343', '大阪府', 'オオサカフ', '堺市西区', 'サカイシニシク', '浜寺元町', 'ハマデラモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市西区浜寺南町', '27', '27144', '5928344', '大阪府', 'オオサカフ', '堺市西区', 'サカイシニシク', '浜寺南町', 'ハマデラミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市西区浜寺昭和町', '27', '27144', '5928345', '大阪府', 'オオサカフ', '堺市西区', 'サカイシニシク', '浜寺昭和町', 'ハマデラショウワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市西区浜寺公園町', '27', '27144', '5928346', '大阪府', 'オオサカフ', '堺市西区', 'サカイシニシク', '浜寺公園町', 'ハマデラコウエンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市西区浜寺諏訪森町西', '27', '27144', '5928347', '大阪府', 'オオサカフ', '堺市西区', 'サカイシニシク', '浜寺諏訪森町西', 'ハマデラスワノモリチョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市西区浜寺諏訪森町中', '27', '27144', '5928348', '大阪府', 'オオサカフ', '堺市西区', 'サカイシニシク', '浜寺諏訪森町中', 'ハマデラスワノモリチョウナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市西区浜寺諏訪森町東', '27', '27144', '5928349', '大阪府', 'オオサカフ', '堺市西区', 'サカイシニシク', '浜寺諏訪森町東', 'ハマデラスワノモリチョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市西区築港浜寺町', '27', '27144', '5928351', '大阪府', 'オオサカフ', '堺市西区', 'サカイシニシク', '築港浜寺町', 'チッコウハマデラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市西区築港浜寺西町', '27', '27144', '5928352', '大阪府', 'オオサカフ', '堺市西区', 'サカイシニシク', '築港浜寺西町', 'チッコウハマデラニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市西区', '27', '27144', '5930000', '大阪府', 'オオサカフ', '堺市西区', 'サカイシニシク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('63967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道日高郡新ひだか町三石富沢', '01', '01610', '0593101', '北海道', 'ホッカイドウ', '日高郡新ひだか町', 'ヒダカグンシンヒダカチョウ', '三石富沢', 'ミツイシトミサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道日高郡新ひだか町三石福畑', '01', '01610', '0593102', '北海道', 'ホッカイドウ', '日高郡新ひだか町', 'ヒダカグンシンヒダカチョウ', '三石福畑', 'ミツイシフクハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道日高郡新ひだか町三石豊岡', '01', '01610', '0593103', '北海道', 'ホッカイドウ', '日高郡新ひだか町', 'ヒダカグンシンヒダカチョウ', '三石豊岡', 'ミツイシトヨオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道日高郡新ひだか町三石蓬栄', '01', '01610', '0593104', '北海道', 'ホッカイドウ', '日高郡新ひだか町', 'ヒダカグンシンヒダカチョウ', '三石蓬栄', 'ミツイシホウエイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道日高郡新ひだか町三石東蓬莱', '01', '01610', '0593105', '北海道', 'ホッカイドウ', '日高郡新ひだか町', 'ヒダカグンシンヒダカチョウ', '三石東蓬莱', 'ミツイシヒガシホウライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道日高郡新ひだか町三石西蓬莱', '01', '01610', '0593106', '北海道', 'ホッカイドウ', '日高郡新ひだか町', 'ヒダカグンシンヒダカチョウ', '三石西蓬莱', 'ミツイシニシホウライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道日高郡新ひだか町三石旭町', '01', '01610', '0593107', '北海道', 'ホッカイドウ', '日高郡新ひだか町', 'ヒダカグンシンヒダカチョウ', '三石旭町', 'ミツイシアサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道日高郡新ひだか町三石本町', '01', '01610', '0593108', '北海道', 'ホッカイドウ', '日高郡新ひだか町', 'ヒダカグンシンヒダカチョウ', '三石本町', 'ミツイシホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道日高郡新ひだか町三石越海町', '01', '01610', '0593111', '北海道', 'ホッカイドウ', '日高郡新ひだか町', 'ヒダカグンシンヒダカチョウ', '三石越海町', 'ミツイシコシウミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道日高郡新ひだか町三石港町', '01', '01610', '0593112', '北海道', 'ホッカイドウ', '日高郡新ひだか町', 'ヒダカグンシンヒダカチョウ', '三石港町', 'ミツイシミナトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道日高郡新ひだか町三石本桐', '01', '01610', '0593231', '北海道', 'ホッカイドウ', '日高郡新ひだか町', 'ヒダカグンシンヒダカチョウ', '三石本桐', 'ミツイシホンキリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道日高郡新ひだか町三石美野和', '01', '01610', '0593232', '北海道', 'ホッカイドウ', '日高郡新ひだか町', 'ヒダカグンシンヒダカチョウ', '三石美野和', 'ミツイシミノワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道日高郡新ひだか町三石鳧舞', '01', '01610', '0593233', '北海道', 'ホッカイドウ', '日高郡新ひだか町', 'ヒダカグンシンヒダカチョウ', '三石鳧舞', 'ミツイシケリマイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道日高郡新ひだか町三石歌笛', '01', '01610', '0593351', '北海道', 'ホッカイドウ', '日高郡新ひだか町', 'ヒダカグンシンヒダカチョウ', '三石歌笛', 'ミツイシウタフエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道日高郡新ひだか町三石稲見', '01', '01610', '0593352', '北海道', 'ホッカイドウ', '日高郡新ひだか町', 'ヒダカグンシンヒダカチョウ', '三石稲見', 'ミツイシイナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道日高郡新ひだか町三石清瀬', '01', '01610', '0593353', '北海道', 'ホッカイドウ', '日高郡新ひだか町', 'ヒダカグンシンヒダカチョウ', '三石清瀬', 'ミツイシキヨセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道日高郡新ひだか町三石川上', '01', '01610', '0593354', '北海道', 'ホッカイドウ', '日高郡新ひだか町', 'ヒダカグンシンヒダカチョウ', '三石川上', 'ミツイシカワカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道日高郡新ひだか町三石美河', '01', '01610', '0593355', '北海道', 'ホッカイドウ', '日高郡新ひだか町', 'ヒダカグンシンヒダカチョウ', '三石美河', 'ミツイシミカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道浦河郡浦河町荻伏町', '01', '01607', '0593451', '北海道', 'ホッカイドウ', '浦河郡浦河町', 'ウラカワグンウラカワチョウ', '荻伏町', 'オギフシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道浦河郡浦河町瑞穂', '01', '01607', '0593453', '北海道', 'ホッカイドウ', '浦河郡浦河町', 'ウラカワグンウラカワチョウ', '瑞穂', 'ミズホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道浦河郡浦河町野深', '01', '01607', '0593454', '北海道', 'ホッカイドウ', '浦河郡浦河町', 'ウラカワグンウラカワチョウ', '野深', 'ノブカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道浦河郡浦河町東栄', '01', '01607', '0593461', '北海道', 'ホッカイドウ', '浦河郡浦河町', 'ウラカワグンウラカワチョウ', '東栄', 'トウエイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道浦河郡浦河町富里', '01', '01607', '0593462', '北海道', 'ホッカイドウ', '浦河郡浦河町', 'ウラカワグンウラカワチョウ', '富里', 'トミサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道浦河郡浦河町姉茶', '01', '01607', '0593463', '北海道', 'ホッカイドウ', '浦河郡浦河町', 'ウラカワグンウラカワチョウ', '姉茶', 'アネチャ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市西区上野芝町', '27', '27144', '5938301', '大阪府', 'オオサカフ', '堺市西区', 'サカイシニシク', '上野芝町', 'ウエノシバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市西区北条町', '27', '27144', '5938302', '大阪府', 'オオサカフ', '堺市西区', 'サカイシニシク', '北条町', 'ホウジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市西区上野芝向ケ丘町', '27', '27144', '5938303', '大阪府', 'オオサカフ', '堺市西区', 'サカイシニシク', '上野芝向ケ丘町', 'ウエノシバムコウガオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市西区家原寺町', '27', '27144', '5938304', '大阪府', 'オオサカフ', '堺市西区', 'サカイシニシク', '家原寺町', 'エバラジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市西区堀上緑町', '27', '27144', '5938305', '大阪府', 'オオサカフ', '堺市西区', 'サカイシニシク', '堀上緑町', 'ホリアゲミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市西区八田寺町', '27', '27144', '5938306', '大阪府', 'オオサカフ', '堺市西区', 'サカイシニシク', '八田寺町', 'ハンダイジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市西区平岡町', '27', '27144', '5938307', '大阪府', 'オオサカフ', '堺市西区', 'サカイシニシク', '平岡町', 'ヒラオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('63999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市西区神野町', '27', '27144', '5938308', '大阪府', 'オオサカフ', '堺市西区', 'サカイシニシク', '神野町', 'コウノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市西区上', '27', '27144', '5938311', '大阪府', 'オオサカフ', '堺市西区', 'サカイシニシク', '上', 'カミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市西区草部', '27', '27144', '5938312', '大阪府', 'オオサカフ', '堺市西区', 'サカイシニシク', '草部', 'クサベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市西区小代', '27', '27144', '5938313', '大阪府', 'オオサカフ', '堺市西区', 'サカイシニシク', '小代', 'コダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市西区太平寺', '27', '27144', '5938314', '大阪府', 'オオサカフ', '堺市西区', 'サカイシニシク', '太平寺', 'タイヘイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市西区菱木', '27', '27144', '5938315', '大阪府', 'オオサカフ', '堺市西区', 'サカイシニシク', '菱木', 'ヒシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市西区山田', '27', '27144', '5938316', '大阪府', 'オオサカフ', '堺市西区', 'サカイシニシク', '山田', 'ヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市西区原田', '27', '27144', '5938317', '大阪府', 'オオサカフ', '堺市西区', 'サカイシニシク', '原田', 'ハラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市西区宮下町', '27', '27144', '5938321', '大阪府', 'オオサカフ', '堺市西区', 'サカイシニシク', '宮下町', 'ミヤシモチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市西区津久野町', '27', '27144', '5938322', '大阪府', 'オオサカフ', '堺市西区', 'サカイシニシク', '津久野町', 'ツクノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市西区鶴田町', '27', '27144', '5938323', '大阪府', 'オオサカフ', '堺市西区', 'サカイシニシク', '鶴田町', 'ツルタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市西区鳳東町', '27', '27144', '5938324', '大阪府', 'オオサカフ', '堺市西区', 'サカイシニシク', '鳳東町', 'オオトリヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市西区鳳南町', '27', '27144', '5938325', '大阪府', 'オオサカフ', '堺市西区', 'サカイシニシク', '鳳南町', 'オオトリミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市西区鳳西町', '27', '27144', '5938326', '大阪府', 'オオサカフ', '堺市西区', 'サカイシニシク', '鳳西町', 'オオトリニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市西区鳳中町', '27', '27144', '5938327', '大阪府', 'オオサカフ', '堺市西区', 'サカイシニシク', '鳳中町', 'オオトリナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市西区鳳北町', '27', '27144', '5938328', '大阪府', 'オオサカフ', '堺市西区', 'サカイシニシク', '鳳北町', 'オオトリキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市西区下田町', '27', '27144', '5938329', '大阪府', 'オオサカフ', '堺市西区', 'サカイシニシク', '下田町', 'シモダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府和泉市', '27', '27219', '5940000', '大阪府', 'オオサカフ', '和泉市', 'イズミシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('64017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府和泉市舞町', '27', '27219', '5940001', '大阪府', 'オオサカフ', '和泉市', 'イズミシ', '舞町', 'マイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府和泉市上町', '27', '27219', '5940002', '大阪府', 'オオサカフ', '和泉市', 'イズミシ', '上町', 'カミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府和泉市太町', '27', '27219', '5940003', '大阪府', 'オオサカフ', '和泉市', 'イズミシ', '太町', 'タイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府和泉市王子町', '27', '27219', '5940004', '大阪府', 'オオサカフ', '和泉市', 'イズミシ', '王子町', 'オウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府和泉市幸', '27', '27219', '5940005', '大阪府', 'オオサカフ', '和泉市', 'イズミシ', '幸', 'サイワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府和泉市尾井町', '27', '27219', '5940006', '大阪府', 'オオサカフ', '和泉市', 'イズミシ', '尾井町', 'オノイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府和泉市上代町', '27', '27219', '5940011', '大阪府', 'オオサカフ', '和泉市', 'イズミシ', '上代町', 'ウエダイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府和泉市小野町', '27', '27219', '5940012', '大阪府', 'オオサカフ', '和泉市', 'イズミシ', '小野町', 'オノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府和泉市鶴山台', '27', '27219', '5940013', '大阪府', 'オオサカフ', '和泉市', 'イズミシ', '鶴山台', 'ツルヤマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府和泉市山荘町', '27', '27219', '5940021', '大阪府', 'オオサカフ', '和泉市', 'イズミシ', '山荘町', 'サンソウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府和泉市黒鳥町', '27', '27219', '5940022', '大阪府', 'オオサカフ', '和泉市', 'イズミシ', '黒鳥町', 'クロドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府和泉市伯太町', '27', '27219', '5940023', '大阪府', 'オオサカフ', '和泉市', 'イズミシ', '伯太町', 'ハカタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府和泉市伏屋町', '27', '27219', '5940031', '大阪府', 'オオサカフ', '和泉市', 'イズミシ', '伏屋町', 'フセヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府和泉市池田下町', '27', '27219', '5940032', '大阪府', 'オオサカフ', '和泉市', 'イズミシ', '池田下町', 'イケダシモチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府和泉市いぶき野', '27', '27219', '5940041', '大阪府', 'オオサカフ', '和泉市', 'イズミシ', 'いぶき野', 'イブキノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府和泉市箕形町', '27', '27219', '5940042', '大阪府', 'オオサカフ', '和泉市', 'イズミシ', '箕形町', 'ミガタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府和泉市東阪本町', '27', '27219', '5940051', '大阪府', 'オオサカフ', '和泉市', 'イズミシ', '東阪本町', 'ヒガシサカモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府和泉市阪本町', '27', '27219', '5940052', '大阪府', 'オオサカフ', '和泉市', 'イズミシ', '阪本町', 'サカモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府和泉市芦部町', '27', '27219', '5940053', '大阪府', 'オオサカフ', '和泉市', 'イズミシ', '芦部町', 'アシベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府和泉市一条院町', '27', '27219', '5940054', '大阪府', 'オオサカフ', '和泉市', 'イズミシ', '一条院町', 'イチジョウインチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府和泉市弥生町', '27', '27219', '5940061', '大阪府', 'オオサカフ', '和泉市', 'イズミシ', '弥生町', 'ヤヨイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府和泉市寺田町', '27', '27219', '5940062', '大阪府', 'オオサカフ', '和泉市', 'イズミシ', '寺田町', 'テラダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府和泉市今福町', '27', '27219', '5940063', '大阪府', 'オオサカフ', '和泉市', 'イズミシ', '今福町', 'イマフクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府和泉市寺門町', '27', '27219', '5940064', '大阪府', 'オオサカフ', '和泉市', 'イズミシ', '寺門町', 'テラカドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府和泉市観音寺町', '27', '27219', '5940065', '大阪府', 'オオサカフ', '和泉市', 'イズミシ', '観音寺町', 'カンノンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府和泉市桑原町', '27', '27219', '5940066', '大阪府', 'オオサカフ', '和泉市', 'イズミシ', '桑原町', 'クワバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府和泉市府中町', '27', '27219', '5940071', '大阪府', 'オオサカフ', '和泉市', 'イズミシ', '府中町', 'フチュウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府和泉市井ノ口町', '27', '27219', '5940072', '大阪府', 'オオサカフ', '和泉市', 'イズミシ', '井ノ口町', 'イノクチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府和泉市和気町', '27', '27219', '5940073', '大阪府', 'オオサカフ', '和泉市', 'イズミシ', '和気町', 'ワケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府和泉市小田町', '27', '27219', '5940074', '大阪府', 'オオサカフ', '和泉市', 'イズミシ', '小田町', 'オダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府和泉市繁和町', '27', '27219', '5940075', '大阪府', 'オオサカフ', '和泉市', 'イズミシ', '繁和町', 'ハンワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府和泉市肥子町', '27', '27219', '5940076', '大阪府', 'オオサカフ', '和泉市', 'イズミシ', '肥子町', 'ヒコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府和泉市葛の葉町', '27', '27219', '5940081', '大阪府', 'オオサカフ', '和泉市', 'イズミシ', '葛の葉町', 'クズノハチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府和泉市富秋町', '27', '27219', '5940082', '大阪府', 'オオサカフ', '和泉市', 'イズミシ', '富秋町', 'トミアキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府和泉市池上町', '27', '27219', '5940083', '大阪府', 'オオサカフ', '和泉市', 'イズミシ', '池上町', 'イケガミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府和泉市室堂町', '27', '27219', '5941101', '大阪府', 'オオサカフ', '和泉市', 'イズミシ', '室堂町', 'ムロドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府和泉市和田町', '27', '27219', '5941102', '大阪府', 'オオサカフ', '和泉市', 'イズミシ', '和田町', 'ワダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府和泉市浦田町', '27', '27219', '5941103', '大阪府', 'オオサカフ', '和泉市', 'イズミシ', '浦田町', 'ウラダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府和泉市万町', '27', '27219', '5941104', '大阪府', 'オオサカフ', '和泉市', 'イズミシ', '万町', 'マンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府和泉市のぞみ野', '27', '27219', '5941105', '大阪府', 'オオサカフ', '和泉市', 'イズミシ', 'のぞみ野', 'ノゾミノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府和泉市はつが野', '27', '27219', '5941106', '大阪府', 'オオサカフ', '和泉市', 'イズミシ', 'はつが野', 'ハツガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府和泉市光明台', '27', '27219', '5941111', '大阪府', 'オオサカフ', '和泉市', 'イズミシ', '光明台', 'コウミョウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府和泉市三林町', '27', '27219', '5941112', '大阪府', 'オオサカフ', '和泉市', 'イズミシ', '三林町', 'ミバヤシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府和泉市黒石町', '27', '27219', '5941113', '大阪府', 'オオサカフ', '和泉市', 'イズミシ', '黒石町', 'クロイシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府和泉市国分町', '27', '27219', '5941114', '大阪府', 'オオサカフ', '和泉市', 'イズミシ', '国分町', 'コクブチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府和泉市平井町', '27', '27219', '5941115', '大阪府', 'オオサカフ', '和泉市', 'イズミシ', '平井町', 'ヒライチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府和泉市納花町', '27', '27219', '5941116', '大阪府', 'オオサカフ', '和泉市', 'イズミシ', '納花町', 'ノウケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府和泉市鍛治屋町', '27', '27219', '5941117', '大阪府', 'オオサカフ', '和泉市', 'イズミシ', '鍛治屋町', 'カジヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府和泉市みずき台', '27', '27219', '5941118', '大阪府', 'オオサカフ', '和泉市', 'イズミシ', 'みずき台', 'ミズキダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府和泉市下宮町', '27', '27219', '5941121', '大阪府', 'オオサカフ', '和泉市', 'イズミシ', '下宮町', 'シモノミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府和泉市北田中町', '27', '27219', '5941122', '大阪府', 'オオサカフ', '和泉市', 'イズミシ', '北田中町', 'キタダナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府和泉市福瀬町', '27', '27219', '5941123', '大阪府', 'オオサカフ', '和泉市', 'イズミシ', '福瀬町', 'フクゼチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府和泉市南面利町', '27', '27219', '5941124', '大阪府', 'オオサカフ', '和泉市', 'イズミシ', '南面利町', 'ナメリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府和泉市善正町', '27', '27219', '5941125', '大阪府', 'オオサカフ', '和泉市', 'イズミシ', '善正町', 'ゼンショウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府和泉市九鬼町', '27', '27219', '5941126', '大阪府', 'オオサカフ', '和泉市', 'イズミシ', '九鬼町', 'クキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府和泉市小野田町', '27', '27219', '5941127', '大阪府', 'オオサカフ', '和泉市', 'イズミシ', '小野田町', 'オノダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府和泉市岡町', '27', '27219', '5941128', '大阪府', 'オオサカフ', '和泉市', 'イズミシ', '岡町', 'オカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府和泉市槇尾山町', '27', '27219', '5941131', '大阪府', 'オオサカフ', '和泉市', 'イズミシ', '槇尾山町', 'マキオサンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府和泉市父鬼町', '27', '27219', '5941132', '大阪府', 'オオサカフ', '和泉市', 'イズミシ', '父鬼町', 'チチオニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府和泉市春木川町', '27', '27219', '5941133', '大阪府', 'オオサカフ', '和泉市', 'イズミシ', '春木川町', 'ハルキガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府和泉市大野町', '27', '27219', '5941134', '大阪府', 'オオサカフ', '和泉市', 'イズミシ', '大野町', 'オオノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府和泉市坪井町', '27', '27219', '5941135', '大阪府', 'オオサカフ', '和泉市', 'イズミシ', '坪井町', 'ツボイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府和泉市仏並町', '27', '27219', '5941136', '大阪府', 'オオサカフ', '和泉市', 'イズミシ', '仏並町', 'ブツナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府和泉市春木町', '27', '27219', '5941141', '大阪府', 'オオサカフ', '和泉市', 'イズミシ', '春木町', 'ハルキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府和泉市久井町', '27', '27219', '5941142', '大阪府', 'オオサカフ', '和泉市', 'イズミシ', '久井町', 'ヒサイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府和泉市若樫町', '27', '27219', '5941143', '大阪府', 'オオサカフ', '和泉市', 'イズミシ', '若樫町', 'ワカカシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府和泉市テクノステージ', '27', '27219', '5941144', '大阪府', 'オオサカフ', '和泉市', 'イズミシ', 'テクノステージ', 'テクノステージ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府和泉市唐国町', '27', '27219', '5941151', '大阪府', 'オオサカフ', '和泉市', 'イズミシ', '唐国町', 'カラクニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府和泉市まなび野', '27', '27219', '5941152', '大阪府', 'オオサカフ', '和泉市', 'イズミシ', 'まなび野', 'マナビノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府和泉市青葉台', '27', '27219', '5941153', '大阪府', 'オオサカフ', '和泉市', 'イズミシ', '青葉台', 'アオバダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府和泉市松尾寺町', '27', '27219', '5941154', '大阪府', 'オオサカフ', '和泉市', 'イズミシ', '松尾寺町', 'マツオジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府和泉市緑ケ丘', '27', '27219', '5941155', '大阪府', 'オオサカフ', '和泉市', 'イズミシ', '緑ケ丘', 'ミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府和泉市内田町', '27', '27219', '5941156', '大阪府', 'オオサカフ', '和泉市', 'イズミシ', '内田町', 'ウチダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府和泉市あゆみ野', '27', '27219', '5941157', '大阪府', 'オオサカフ', '和泉市', 'イズミシ', 'あゆみ野', 'アユミノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉大津市', '27', '27206', '5950000', '大阪府', 'オオサカフ', '泉大津市', 'イズミオオツシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('64094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉北郡忠岡町', '27', '27341', '5950000', '大阪府', 'オオサカフ', '泉北郡忠岡町', 'センボクグンタダオカチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('64095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉大津市綾井', '27', '27206', '5950001', '大阪府', 'オオサカフ', '泉大津市', 'イズミオオツシ', '綾井', 'アヤイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉大津市末広町', '27', '27206', '5950002', '大阪府', 'オオサカフ', '泉大津市', 'イズミオオツシ', '末広町', 'スエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉大津市尾井千原町', '27', '27206', '5950003', '大阪府', 'オオサカフ', '泉大津市', 'イズミオオツシ', '尾井千原町', 'オイチハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉大津市千原町', '27', '27206', '5950004', '大阪府', 'オオサカフ', '泉大津市', 'イズミオオツシ', '千原町', 'チハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉大津市森町', '27', '27206', '5950005', '大阪府', 'オオサカフ', '泉大津市', 'イズミオオツシ', '森町', 'モリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉大津市東助松町', '27', '27206', '5950006', '大阪府', 'オオサカフ', '泉大津市', 'イズミオオツシ', '東助松町', 'ヒガシスケマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉大津市助松団地', '27', '27206', '5950007', '大阪府', 'オオサカフ', '泉大津市', 'イズミオオツシ', '助松団地', 'スケマツダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉大津市曽根町', '27', '27206', '5950011', '大阪府', 'オオサカフ', '泉大津市', 'イズミオオツシ', '曽根町', 'ソネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉大津市南曾根', '27', '27206', '5950011', '大阪府', 'オオサカフ', '泉大津市', 'イズミオオツシ', '南曾根', 'ミナミソネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉大津市北豊中町', '27', '27206', '5950012', '大阪府', 'オオサカフ', '泉大津市', 'イズミオオツシ', '北豊中町', 'キタトヨナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉大津市宮町', '27', '27206', '5950013', '大阪府', 'オオサカフ', '泉大津市', 'イズミオオツシ', '宮町', 'ミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉大津市寿町', '27', '27206', '5950014', '大阪府', 'オオサカフ', '泉大津市', 'イズミオオツシ', '寿町', 'コトブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉大津市二田町', '27', '27206', '5950015', '大阪府', 'オオサカフ', '泉大津市', 'イズミオオツシ', '二田町', 'フツタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉大津市条南町', '27', '27206', '5950016', '大阪府', 'オオサカフ', '泉大津市', 'イズミオオツシ', '条南町', 'ジョウナンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉大津市池園町', '27', '27206', '5950017', '大阪府', 'オオサカフ', '泉大津市', 'イズミオオツシ', '池園町', 'イケゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉大津市東豊中町', '27', '27206', '5950021', '大阪府', 'オオサカフ', '泉大津市', 'イズミオオツシ', '東豊中町', 'ヒガシトヨナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉大津市池浦', '27', '27206', '5950022', '大阪府', 'オオサカフ', '泉大津市', 'イズミオオツシ', '池浦', 'イケウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉大津市豊中町', '27', '27206', '5950023', '大阪府', 'オオサカフ', '泉大津市', 'イズミオオツシ', '豊中町', 'トヨナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉大津市池浦町', '27', '27206', '5950024', '大阪府', 'オオサカフ', '泉大津市', 'イズミオオツシ', '池浦町', 'イケウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉大津市旭町', '27', '27206', '5950025', '大阪府', 'オオサカフ', '泉大津市', 'イズミオオツシ', '旭町', 'アサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉大津市東雲町', '27', '27206', '5950026', '大阪府', 'オオサカフ', '泉大津市', 'イズミオオツシ', '東雲町', 'シノノメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉大津市下条町', '27', '27206', '5950027', '大阪府', 'オオサカフ', '泉大津市', 'イズミオオツシ', '下条町', 'ゲジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉大津市要池住宅', '27', '27206', '5950028', '大阪府', 'オオサカフ', '泉大津市', 'イズミオオツシ', '要池住宅', 'カナメイケジュウタク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉大津市我孫子', '27', '27206', '5950031', '大阪府', 'オオサカフ', '泉大津市', 'イズミオオツシ', '我孫子', 'アビコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉大津市穴田', '27', '27206', '5950032', '大阪府', 'オオサカフ', '泉大津市', 'イズミオオツシ', '穴田', 'アナダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉大津市板原', '27', '27206', '5950033', '大阪府', 'オオサカフ', '泉大津市', 'イズミオオツシ', '板原', 'イタハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉大津市板原町', '27', '27206', '5950033', '大阪府', 'オオサカフ', '泉大津市', 'イズミオオツシ', '板原町', 'イタハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉大津市宇多', '27', '27206', '5950034', '大阪府', 'オオサカフ', '泉大津市', 'イズミオオツシ', '宇多', 'ウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉大津市式内町', '27', '27206', '5950035', '大阪府', 'オオサカフ', '泉大津市', 'イズミオオツシ', '式内町', 'シキナイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉大津市昭和町', '27', '27206', '5950036', '大阪府', 'オオサカフ', '泉大津市', 'イズミオオツシ', '昭和町', 'ショウワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉大津市虫取', '27', '27206', '5950037', '大阪府', 'オオサカフ', '泉大津市', 'イズミオオツシ', '虫取', 'ムシトリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉大津市虫取町', '27', '27206', '5950037', '大阪府', 'オオサカフ', '泉大津市', 'イズミオオツシ', '虫取町', 'ムシトリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉大津市楠町西', '27', '27206', '5950038', '大阪府', 'オオサカフ', '泉大津市', 'イズミオオツシ', '楠町西', 'クスノキチョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉大津市楠町東', '27', '27206', '5950039', '大阪府', 'オオサカフ', '泉大津市', 'イズミオオツシ', '楠町東', 'クスノキチョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉大津市戎町', '27', '27206', '5950041', '大阪府', 'オオサカフ', '泉大津市', 'イズミオオツシ', '戎町', 'エビスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉大津市高津町', '27', '27206', '5950042', '大阪府', 'オオサカフ', '泉大津市', 'イズミオオツシ', '高津町', 'タカツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉大津市清水町', '27', '27206', '5950043', '大阪府', 'オオサカフ', '泉大津市', 'イズミオオツシ', '清水町', 'シミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉大津市河原町', '27', '27206', '5950044', '大阪府', 'オオサカフ', '泉大津市', 'イズミオオツシ', '河原町', 'カワハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉大津市下之町', '27', '27206', '5950045', '大阪府', 'オオサカフ', '泉大津市', 'イズミオオツシ', '下之町', 'シタノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉大津市上之町', '27', '27206', '5950046', '大阪府', 'オオサカフ', '泉大津市', 'イズミオオツシ', '上之町', 'ウエノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉大津市東港町', '27', '27206', '5950051', '大阪府', 'オオサカフ', '泉大津市', 'イズミオオツシ', '東港町', 'ヒガシミナトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉大津市西港町', '27', '27206', '5950052', '大阪府', 'オオサカフ', '泉大津市', 'イズミオオツシ', '西港町', 'ニシミナトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉大津市青葉町', '27', '27206', '5950053', '大阪府', 'オオサカフ', '泉大津市', 'イズミオオツシ', '青葉町', 'アオバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉大津市汐見町', '27', '27206', '5950054', '大阪府', 'オオサカフ', '泉大津市', 'イズミオオツシ', '汐見町', 'シオミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉大津市なぎさ町', '27', '27206', '5950055', '大阪府', 'オオサカフ', '泉大津市', 'イズミオオツシ', 'なぎさ町', 'ナギサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉大津市夕凪町', '27', '27206', '5950056', '大阪府', 'オオサカフ', '泉大津市', 'イズミオオツシ', '夕凪町', 'ユウナギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉大津市春日町', '27', '27206', '5950061', '大阪府', 'オオサカフ', '泉大津市', 'イズミオオツシ', '春日町', 'カスガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉大津市田中町', '27', '27206', '5950062', '大阪府', 'オオサカフ', '泉大津市', 'イズミオオツシ', '田中町', 'タナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉大津市本町', '27', '27206', '5950063', '大阪府', 'オオサカフ', '泉大津市', 'イズミオオツシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉大津市神明町', '27', '27206', '5950064', '大阪府', 'オオサカフ', '泉大津市', 'イズミオオツシ', '神明町', 'シンメイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉大津市若宮町', '27', '27206', '5950065', '大阪府', 'オオサカフ', '泉大津市', 'イズミオオツシ', '若宮町', 'ワカミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉大津市菅原町', '27', '27206', '5950066', '大阪府', 'オオサカフ', '泉大津市', 'イズミオオツシ', '菅原町', 'スガハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉大津市小松町', '27', '27206', '5950067', '大阪府', 'オオサカフ', '泉大津市', 'イズミオオツシ', '小松町', 'コマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉大津市助松町', '27', '27206', '5950071', '大阪府', 'オオサカフ', '泉大津市', 'イズミオオツシ', '助松町', 'スケマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉大津市松之浜町', '27', '27206', '5950072', '大阪府', 'オオサカフ', '泉大津市', 'イズミオオツシ', '松之浜町', 'マツノハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉大津市新港町', '27', '27206', '5950073', '大阪府', 'オオサカフ', '泉大津市', 'イズミオオツシ', '新港町', 'シンミナトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉大津市小津島町', '27', '27206', '5950074', '大阪府', 'オオサカフ', '泉大津市', 'イズミオオツシ', '小津島町', 'オヅシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉大津市臨海町', '27', '27206', '5950075', '大阪府', 'オオサカフ', '泉大津市', 'イズミオオツシ', '臨海町', 'リンカイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府高石市南高砂', '27', '27225', '5950081', '大阪府', 'オオサカフ', '高石市', 'タカイシシ', '南高砂', 'ミナミタカサゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉北郡忠岡町高月北', '27', '27341', '5950801', '大阪府', 'オオサカフ', '泉北郡忠岡町', 'センボクグンタダオカチョウ', '高月北', 'タカツキキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉北郡忠岡町高月南', '27', '27341', '5950802', '大阪府', 'オオサカフ', '泉北郡忠岡町', 'センボクグンタダオカチョウ', '高月南', 'タカツキミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉北郡忠岡町北出', '27', '27341', '5950803', '大阪府', 'オオサカフ', '泉北郡忠岡町', 'センボクグンタダオカチョウ', '北出', 'キタイデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉北郡忠岡町馬瀬', '27', '27341', '5950804', '大阪府', 'オオサカフ', '泉北郡忠岡町', 'センボクグンタダオカチョウ', '馬瀬', 'マゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉北郡忠岡町忠岡東', '27', '27341', '5950805', '大阪府', 'オオサカフ', '泉北郡忠岡町', 'センボクグンタダオカチョウ', '忠岡東', 'タダオカヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉北郡忠岡町忠岡北', '27', '27341', '5950811', '大阪府', 'オオサカフ', '泉北郡忠岡町', 'センボクグンタダオカチョウ', '忠岡北', 'タダオカキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉北郡忠岡町忠岡中', '27', '27341', '5950812', '大阪府', 'オオサカフ', '泉北郡忠岡町', 'センボクグンタダオカチョウ', '忠岡中', 'タダオカナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉北郡忠岡町忠岡南', '27', '27341', '5950813', '大阪府', 'オオサカフ', '泉北郡忠岡町', 'センボクグンタダオカチョウ', '忠岡南', 'タダオカミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉北郡忠岡町新浜', '27', '27341', '5950814', '大阪府', 'オオサカフ', '泉北郡忠岡町', 'センボクグンタダオカチョウ', '新浜', 'ニイハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府岸和田市', '27', '27202', '5960000', '大阪府', 'オオサカフ', '岸和田市', 'キシワダシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('64169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府岸和田市磯上町', '27', '27202', '5960001', '大阪府', 'オオサカフ', '岸和田市', 'キシワダシ', '磯上町', 'イソノカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府岸和田市吉井町', '27', '27202', '5960002', '大阪府', 'オオサカフ', '岸和田市', 'キシワダシ', '吉井町', 'ヨシイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府岸和田市中井町', '27', '27202', '5960003', '大阪府', 'オオサカフ', '岸和田市', 'キシワダシ', '中井町', 'ナカイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府岸和田市荒木町', '27', '27202', '5960004', '大阪府', 'オオサカフ', '岸和田市', 'キシワダシ', '荒木町', 'アラキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府岸和田市春木旭町', '27', '27202', '5960005', '大阪府', 'オオサカフ', '岸和田市', 'キシワダシ', '春木旭町', 'ハルキアサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府岸和田市春木若松町', '27', '27202', '5960006', '大阪府', 'オオサカフ', '岸和田市', 'キシワダシ', '春木若松町', 'ハルキワカマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府岸和田市木材町', '27', '27202', '5960011', '大阪府', 'オオサカフ', '岸和田市', 'キシワダシ', '木材町', 'モクザイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府岸和田市新港町', '27', '27202', '5960012', '大阪府', 'オオサカフ', '岸和田市', 'キシワダシ', '新港町', 'シンミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府岸和田市臨海町', '27', '27202', '5960013', '大阪府', 'オオサカフ', '岸和田市', 'キシワダシ', '臨海町', 'リンカイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府岸和田市港緑町', '27', '27202', '5960014', '大阪府', 'オオサカフ', '岸和田市', 'キシワダシ', '港緑町', 'ミナトミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府岸和田市地蔵浜町', '27', '27202', '5960015', '大阪府', 'オオサカフ', '岸和田市', 'キシワダシ', '地蔵浜町', 'ジゾウハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府岸和田市岸之浦町', '27', '27202', '5960016', '大阪府', 'オオサカフ', '岸和田市', 'キシワダシ', '岸之浦町', 'キシノウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府岸和田市松風町', '27', '27202', '5960021', '大阪府', 'オオサカフ', '岸和田市', 'キシワダシ', '松風町', 'マツカゼチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府岸和田市戎町', '27', '27202', '5960022', '大阪府', 'オオサカフ', '岸和田市', 'キシワダシ', '戎町', 'エビスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府岸和田市八幡町', '27', '27202', '5960023', '大阪府', 'オオサカフ', '岸和田市', 'キシワダシ', '八幡町', 'ハチマンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府岸和田市春木宮川町', '27', '27202', '5960024', '大阪府', 'オオサカフ', '岸和田市', 'キシワダシ', '春木宮川町', 'ハルキミヤガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府岸和田市春木宮本町', '27', '27202', '5960025', '大阪府', 'オオサカフ', '岸和田市', 'キシワダシ', '春木宮本町', 'ハルキミヤモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府岸和田市春木大国町', '27', '27202', '5960026', '大阪府', 'オオサカフ', '岸和田市', 'キシワダシ', '春木大国町', 'ハルキダイコクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府岸和田市春木大小路町', '27', '27202', '5960031', '大阪府', 'オオサカフ', '岸和田市', 'キシワダシ', '春木大小路町', 'ハルキオオショウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府岸和田市春木元町', '27', '27202', '5960032', '大阪府', 'オオサカフ', '岸和田市', 'キシワダシ', '春木元町', 'ハルキモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府岸和田市春木中町', '27', '27202', '5960033', '大阪府', 'オオサカフ', '岸和田市', 'キシワダシ', '春木中町', 'ハルキナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府岸和田市春木本町', '27', '27202', '5960034', '大阪府', 'オオサカフ', '岸和田市', 'キシワダシ', '春木本町', 'ハルキホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府岸和田市春木泉町', '27', '27202', '5960035', '大阪府', 'オオサカフ', '岸和田市', 'キシワダシ', '春木泉町', 'ハルキイズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府岸和田市春木南浜町', '27', '27202', '5960036', '大阪府', 'オオサカフ', '岸和田市', 'キシワダシ', '春木南浜町', 'ハルキミナミハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府岸和田市春木北浜町', '27', '27202', '5960037', '大阪府', 'オオサカフ', '岸和田市', 'キシワダシ', '春木北浜町', 'ハルキキタハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府岸和田市下野町', '27', '27202', '5960041', '大阪府', 'オオサカフ', '岸和田市', 'キシワダシ', '下野町', 'シモノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府岸和田市加守町', '27', '27202', '5960042', '大阪府', 'オオサカフ', '岸和田市', 'キシワダシ', '加守町', 'カモリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府岸和田市宮前町', '27', '27202', '5960043', '大阪府', 'オオサカフ', '岸和田市', 'キシワダシ', '宮前町', 'ミヤマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府岸和田市西之内町', '27', '27202', '5960044', '大阪府', 'オオサカフ', '岸和田市', 'キシワダシ', '西之内町', 'ニシノウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府岸和田市別所町', '27', '27202', '5960045', '大阪府', 'オオサカフ', '岸和田市', 'キシワダシ', '別所町', 'ベッシヨチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府岸和田市藤井町', '27', '27202', '5960046', '大阪府', 'オオサカフ', '岸和田市', 'キシワダシ', '藤井町', 'フジイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府岸和田市上野町東', '27', '27202', '5960047', '大阪府', 'オオサカフ', '岸和田市', 'キシワダシ', '上野町東', 'カミノチョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府岸和田市上野町西', '27', '27202', '5960048', '大阪府', 'オオサカフ', '岸和田市', 'キシワダシ', '上野町西', 'カミノチョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府岸和田市八阪町', '27', '27202', '5960049', '大阪府', 'オオサカフ', '岸和田市', 'キシワダシ', '八阪町', 'ヤサカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府岸和田市岸野町', '27', '27202', '5960051', '大阪府', 'オオサカフ', '岸和田市', 'キシワダシ', '岸野町', 'キシノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府岸和田市並松町', '27', '27202', '5960052', '大阪府', 'オオサカフ', '岸和田市', 'キシワダシ', '並松町', 'ナンマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府岸和田市沼町', '27', '27202', '5960053', '大阪府', 'オオサカフ', '岸和田市', 'キシワダシ', '沼町', 'ヌマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府岸和田市宮本町', '27', '27202', '5960054', '大阪府', 'オオサカフ', '岸和田市', 'キシワダシ', '宮本町', 'ミヤモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府岸和田市五軒屋町', '27', '27202', '5960055', '大阪府', 'オオサカフ', '岸和田市', 'キシワダシ', '五軒屋町', 'ゴケンヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府岸和田市北町', '27', '27202', '5960056', '大阪府', 'オオサカフ', '岸和田市', 'キシワダシ', '北町', 'キタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府岸和田市筋海町', '27', '27202', '5960057', '大阪府', 'オオサカフ', '岸和田市', 'キシワダシ', '筋海町', 'スジカイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府岸和田市大北町', '27', '27202', '5960061', '大阪府', 'オオサカフ', '岸和田市', 'キシワダシ', '大北町', 'オオキタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府岸和田市中北町', '27', '27202', '5960062', '大阪府', 'オオサカフ', '岸和田市', 'キシワダシ', '中北町', 'ナカキタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府岸和田市大手町', '27', '27202', '5960063', '大阪府', 'オオサカフ', '岸和田市', 'キシワダシ', '大手町', 'オオテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府岸和田市紙屋町', '27', '27202', '5960064', '大阪府', 'オオサカフ', '岸和田市', 'キシワダシ', '紙屋町', 'カミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府岸和田市中之浜町', '27', '27202', '5960065', '大阪府', 'オオサカフ', '岸和田市', 'キシワダシ', '中之浜町', 'ナカノハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府岸和田市大工町', '27', '27202', '5960066', '大阪府', 'オオサカフ', '岸和田市', 'キシワダシ', '大工町', 'ダイクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府岸和田市南町', '27', '27202', '5960067', '大阪府', 'オオサカフ', '岸和田市', 'キシワダシ', '南町', 'ミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府岸和田市魚屋町', '27', '27202', '5960071', '大阪府', 'オオサカフ', '岸和田市', 'キシワダシ', '魚屋町', 'ウオヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府岸和田市堺町', '27', '27202', '5960072', '大阪府', 'オオサカフ', '岸和田市', 'キシワダシ', '堺町', 'サカイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府岸和田市岸城町', '27', '27202', '5960073', '大阪府', 'オオサカフ', '岸和田市', 'キシワダシ', '岸城町', 'キシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府岸和田市本町', '27', '27202', '5960074', '大阪府', 'オオサカフ', '岸和田市', 'キシワダシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府岸和田市中町', '27', '27202', '5960075', '大阪府', 'オオサカフ', '岸和田市', 'キシワダシ', '中町', 'ナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府岸和田市野田町', '27', '27202', '5960076', '大阪府', 'オオサカフ', '岸和田市', 'キシワダシ', '野田町', 'ノダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府岸和田市上町', '27', '27202', '5960077', '大阪府', 'オオサカフ', '岸和田市', 'キシワダシ', '上町', 'ウエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府岸和田市南上町', '27', '27202', '5960078', '大阪府', 'オオサカフ', '岸和田市', 'キシワダシ', '南上町', 'ミナミウエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府岸和田市包近町', '27', '27202', '5960101', '大阪府', 'オオサカフ', '岸和田市', 'キシワダシ', '包近町', 'カネチカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府岸和田市山直中町', '27', '27202', '5960102', '大阪府', 'オオサカフ', '岸和田市', 'キシワダシ', '山直中町', 'ヤマダイナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府岸和田市稲葉町', '27', '27202', '5960103', '大阪府', 'オオサカフ', '岸和田市', 'キシワダシ', '稲葉町', 'イナバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府岸和田市積川町', '27', '27202', '5960104', '大阪府', 'オオサカフ', '岸和田市', 'キシワダシ', '積川町', 'ツガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府岸和田市内畑町', '27', '27202', '5960105', '大阪府', 'オオサカフ', '岸和田市', 'キシワダシ', '内畑町', 'ウチハタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府岸和田市上白原町', '27', '27202', '5960111', '大阪府', 'オオサカフ', '岸和田市', 'キシワダシ', '上白原町', 'カミシラハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府岸和田市神於町', '27', '27202', '5960112', '大阪府', 'オオサカフ', '岸和田市', 'キシワダシ', '神於町', 'コウノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府岸和田市河合町', '27', '27202', '5960113', '大阪府', 'オオサカフ', '岸和田市', 'キシワダシ', '河合町', 'カアイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府岸和田市大沢町', '27', '27202', '5960114', '大阪府', 'オオサカフ', '岸和田市', 'キシワダシ', '大沢町', 'オオサワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府岸和田市相川町', '27', '27202', '5960115', '大阪府', 'オオサカフ', '岸和田市', 'キシワダシ', '相川町', 'ソウガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府岸和田市塔原町', '27', '27202', '5960116', '大阪府', 'オオサカフ', '岸和田市', 'キシワダシ', '塔原町', 'トノハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府岸和田市箕土路町', '27', '27202', '5960801', '大阪府', 'オオサカフ', '岸和田市', 'キシワダシ', '箕土路町', 'ミドロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府岸和田市西大路町', '27', '27202', '5960802', '大阪府', 'オオサカフ', '岸和田市', 'キシワダシ', '西大路町', 'ニシオオジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府岸和田市東大路町', '27', '27202', '5960803', '大阪府', 'オオサカフ', '岸和田市', 'キシワダシ', '東大路町', 'ヒガシオオジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府岸和田市今木町', '27', '27202', '5960804', '大阪府', 'オオサカフ', '岸和田市', 'キシワダシ', '今木町', 'イマキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府岸和田市田治米町', '27', '27202', '5960805', '大阪府', 'オオサカフ', '岸和田市', 'キシワダシ', '田治米町', 'タジメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府岸和田市摩湯町', '27', '27202', '5960806', '大阪府', 'オオサカフ', '岸和田市', 'キシワダシ', '摩湯町', 'マユチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府岸和田市東ケ丘町', '27', '27202', '5960807', '大阪府', 'オオサカフ', '岸和田市', 'キシワダシ', '東ケ丘町', 'ヒガシガオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府岸和田市三田町', '27', '27202', '5960808', '大阪府', 'オオサカフ', '岸和田市', 'キシワダシ', '三田町', 'ミタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府岸和田市下池田町', '27', '27202', '5960811', '大阪府', 'オオサカフ', '岸和田市', 'キシワダシ', '下池田町', 'シモイケダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府岸和田市大町', '27', '27202', '5960812', '大阪府', 'オオサカフ', '岸和田市', 'キシワダシ', '大町', 'オオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府岸和田市池尻町', '27', '27202', '5960813', '大阪府', 'オオサカフ', '岸和田市', 'キシワダシ', '池尻町', 'イケジリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府岸和田市岡山町', '27', '27202', '5960814', '大阪府', 'オオサカフ', '岸和田市', 'キシワダシ', '岡山町', 'オカヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府岸和田市三ケ山町', '27', '27202', '5960815', '大阪府', 'オオサカフ', '岸和田市', 'キシワダシ', '三ケ山町', 'サンガヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府岸和田市尾生町', '27', '27202', '5960816', '大阪府', 'オオサカフ', '岸和田市', 'キシワダシ', '尾生町', 'オブチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府岸和田市小松里町', '27', '27202', '5960821', '大阪府', 'オオサカフ', '岸和田市', 'キシワダシ', '小松里町', 'コマツリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府岸和田市額原町', '27', '27202', '5960822', '大阪府', 'オオサカフ', '岸和田市', 'キシワダシ', '額原町', 'ガクハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府岸和田市下松町', '27', '27202', '5960823', '大阪府', 'オオサカフ', '岸和田市', 'キシワダシ', '下松町', 'シモマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府岸和田市葛城町', '27', '27202', '5960824', '大阪府', 'オオサカフ', '岸和田市', 'キシワダシ', '葛城町', 'カツラギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府岸和田市土生町', '27', '27202', '5960825', '大阪府', 'オオサカフ', '岸和田市', 'キシワダシ', '土生町', 'ハブチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府岸和田市作才町', '27', '27202', '5960826', '大阪府', 'オオサカフ', '岸和田市', 'キシワダシ', '作才町', 'ザクザイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府岸和田市上松町', '27', '27202', '5960827', '大阪府', 'オオサカフ', '岸和田市', 'キシワダシ', '上松町', 'カミマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府岸和田市門前町', '27', '27202', '5960828', '大阪府', 'オオサカフ', '岸和田市', 'キシワダシ', '門前町', 'モンゼンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府岸和田市畑町', '27', '27202', '5960831', '大阪府', 'オオサカフ', '岸和田市', 'キシワダシ', '畑町', 'ハタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府岸和田市極楽寺町', '27', '27202', '5960832', '大阪府', 'オオサカフ', '岸和田市', 'キシワダシ', '極楽寺町', 'ゴクラクジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府岸和田市神須屋町', '27', '27202', '5960833', '大阪府', 'オオサカフ', '岸和田市', 'キシワダシ', '神須屋町', 'コウズヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府岸和田市天神山町', '27', '27202', '5960834', '大阪府', 'オオサカフ', '岸和田市', 'キシワダシ', '天神山町', 'テンジンヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府岸和田市流木町', '27', '27202', '5960835', '大阪府', 'オオサカフ', '岸和田市', 'キシワダシ', '流木町', 'ナガレギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府岸和田市行遇町', '27', '27202', '5960836', '大阪府', 'オオサカフ', '岸和田市', 'キシワダシ', '行遇町', 'ユキアイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府岸和田市八田町', '27', '27202', '5960841', '大阪府', 'オオサカフ', '岸和田市', 'キシワダシ', '八田町', 'ハツタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府岸和田市真上町', '27', '27202', '5960842', '大阪府', 'オオサカフ', '岸和田市', 'キシワダシ', '真上町', 'マガミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府岸和田市北阪町', '27', '27202', '5960843', '大阪府', 'オオサカフ', '岸和田市', 'キシワダシ', '北阪町', 'キタサカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府岸和田市土生滝町', '27', '27202', '5960844', '大阪府', 'オオサカフ', '岸和田市', 'キシワダシ', '土生滝町', 'ハブタキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府岸和田市阿間河滝町', '27', '27202', '5960845', '大阪府', 'オオサカフ', '岸和田市', 'キシワダシ', '阿間河滝町', 'アマカダキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府貝塚市清児新町', '27', '27208', '5960901', '大阪府', 'オオサカフ', '貝塚市', 'カイヅカシ', '清児新町', 'セチゴシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府貝塚市', '27', '27208', '5970000', '大阪府', 'オオサカフ', '貝塚市', 'カイヅカシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('64275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府貝塚市近木', '27', '27208', '5970001', '大阪府', 'オオサカフ', '貝塚市', 'カイヅカシ', '近木', 'コギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府貝塚市新町', '27', '27208', '5970002', '大阪府', 'オオサカフ', '貝塚市', 'カイヅカシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府貝塚市中', '27', '27208', '5970003', '大阪府', 'オオサカフ', '貝塚市', 'カイヅカシ', '中', 'ナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府貝塚市西町', '27', '27208', '5970004', '大阪府', 'オオサカフ', '貝塚市', 'カイヅカシ', '西町', 'ニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府貝塚市南町', '27', '27208', '5970005', '大阪府', 'オオサカフ', '貝塚市', 'カイヅカシ', '南町', 'ミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府貝塚市北町', '27', '27208', '5970011', '大阪府', 'オオサカフ', '貝塚市', 'カイヅカシ', '北町', 'キタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府貝塚市津田', '27', '27208', '5970012', '大阪府', 'オオサカフ', '貝塚市', 'カイヅカシ', '津田', 'ツダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府貝塚市津田北町', '27', '27208', '5970013', '大阪府', 'オオサカフ', '貝塚市', 'カイヅカシ', '津田北町', 'ツダキタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府貝塚市津田南町', '27', '27208', '5970014', '大阪府', 'オオサカフ', '貝塚市', 'カイヅカシ', '津田南町', 'ツダミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府貝塚市堀', '27', '27208', '5970015', '大阪府', 'オオサカフ', '貝塚市', 'カイヅカシ', '堀', 'ホリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府貝塚市小瀬', '27', '27208', '5970021', '大阪府', 'オオサカフ', '貝塚市', 'カイヅカシ', '小瀬', 'コセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府貝塚市新井', '27', '27208', '5970022', '大阪府', 'オオサカフ', '貝塚市', 'カイヅカシ', '新井', 'ニイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府貝塚市福田', '27', '27208', '5970023', '大阪府', 'オオサカフ', '貝塚市', 'カイヅカシ', '福田', 'フクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府貝塚市久保', '27', '27208', '5970031', '大阪府', 'オオサカフ', '貝塚市', 'カイヅカシ', '久保', 'クボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府貝塚市永吉', '27', '27208', '5970032', '大阪府', 'オオサカフ', '貝塚市', 'カイヅカシ', '永吉', 'ナガヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府貝塚市半田', '27', '27208', '5970033', '大阪府', 'オオサカフ', '貝塚市', 'カイヅカシ', '半田', 'ハンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府貝塚市清児', '27', '27208', '5970041', '大阪府', 'オオサカフ', '貝塚市', 'カイヅカシ', '清児', 'セチゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府貝塚市名越', '27', '27208', '5970042', '大阪府', 'オオサカフ', '貝塚市', 'カイヅカシ', '名越', 'ナゴセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府貝塚市橋本', '27', '27208', '5970043', '大阪府', 'オオサカフ', '貝塚市', 'カイヅカシ', '橋本', 'ハシモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府貝塚市森', '27', '27208', '5970044', '大阪府', 'オオサカフ', '貝塚市', 'カイヅカシ', '森', 'モリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府貝塚市三ツ松', '27', '27208', '5970045', '大阪府', 'オオサカフ', '貝塚市', 'カイヅカシ', '三ツ松', 'ミツマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府貝塚市東山', '27', '27208', '5970046', '大阪府', 'オオサカフ', '貝塚市', 'カイヅカシ', '東山', 'ヒガシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府貝塚市王子', '27', '27208', '5970051', '大阪府', 'オオサカフ', '貝塚市', 'カイヅカシ', '王子', 'オウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府貝塚市窪田', '27', '27208', '5970052', '大阪府', 'オオサカフ', '貝塚市', 'カイヅカシ', '窪田', 'クボタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府貝塚市地蔵堂', '27', '27208', '5970053', '大阪府', 'オオサカフ', '貝塚市', 'カイヅカシ', '地蔵堂', 'ジゾウドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府貝塚市堤', '27', '27208', '5970054', '大阪府', 'オオサカフ', '貝塚市', 'カイヅカシ', '堤', 'ツツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府貝塚市浦田', '27', '27208', '5970061', '大阪府', 'オオサカフ', '貝塚市', 'カイヅカシ', '浦田', 'ウラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府貝塚市澤', '27', '27208', '5970062', '大阪府', 'オオサカフ', '貝塚市', 'カイヅカシ', '澤', 'サワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府貝塚市二色港町', '27', '27208', '5970063', '大阪府', 'オオサカフ', '貝塚市', 'カイヅカシ', '二色港町', 'ニシキミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府貝塚市加神', '27', '27208', '5970071', '大阪府', 'オオサカフ', '貝塚市', 'カイヅカシ', '加神', 'カシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府貝塚市畠中', '27', '27208', '5970072', '大阪府', 'オオサカフ', '貝塚市', 'カイヅカシ', '畠中', 'ハタケナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府貝塚市脇浜', '27', '27208', '5970073', '大阪府', 'オオサカフ', '貝塚市', 'カイヅカシ', '脇浜', 'ワキハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府貝塚市加治', '27', '27208', '5970074', '大阪府', 'オオサカフ', '貝塚市', 'カイヅカシ', '加治', 'カジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府貝塚市神前', '27', '27208', '5970075', '大阪府', 'オオサカフ', '貝塚市', 'カイヅカシ', '神前', 'コウザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府貝塚市麻生中', '27', '27208', '5970081', '大阪府', 'オオサカフ', '貝塚市', 'カイヅカシ', '麻生中', 'アソナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府貝塚市石才', '27', '27208', '5970082', '大阪府', 'オオサカフ', '貝塚市', 'カイヅカシ', '石才', 'イシザイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府貝塚市海塚', '27', '27208', '5970083', '大阪府', 'オオサカフ', '貝塚市', 'カイヅカシ', '海塚', 'ウミヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府貝塚市鳥羽', '27', '27208', '5970084', '大阪府', 'オオサカフ', '貝塚市', 'カイヅカシ', '鳥羽', 'トバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府貝塚市東', '27', '27208', '5970085', '大阪府', 'オオサカフ', '貝塚市', 'カイヅカシ', '東', 'ヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府貝塚市二色', '27', '27208', '5970091', '大阪府', 'オオサカフ', '貝塚市', 'カイヅカシ', '二色', 'ニシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府貝塚市二色北町', '27', '27208', '5970092', '大阪府', 'オオサカフ', '貝塚市', 'カイヅカシ', '二色北町', 'ニシキキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府貝塚市二色中町', '27', '27208', '5970093', '大阪府', 'オオサカフ', '貝塚市', 'カイヅカシ', '二色中町', 'ニシキナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府貝塚市二色南町', '27', '27208', '5970094', '大阪府', 'オオサカフ', '貝塚市', 'カイヅカシ', '二色南町', 'ニシキミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府貝塚市港', '27', '27208', '5970095', '大阪府', 'オオサカフ', '貝塚市', 'カイヅカシ', '港', 'ミナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府貝塚市三ケ山', '27', '27208', '5970101', '大阪府', 'オオサカフ', '貝塚市', 'カイヅカシ', '三ケ山', 'ミケヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府貝塚市木積', '27', '27208', '5970102', '大阪府', 'オオサカフ', '貝塚市', 'カイヅカシ', '木積', 'コツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府貝塚市馬場', '27', '27208', '5970103', '大阪府', 'オオサカフ', '貝塚市', 'カイヅカシ', '馬場', 'ババ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府貝塚市水間', '27', '27208', '5970104', '大阪府', 'オオサカフ', '貝塚市', 'カイヅカシ', '水間', 'ミズマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府貝塚市三ツ松', '27', '27208', '5970105', '大阪府', 'オオサカフ', '貝塚市', 'カイヅカシ', '三ツ松', 'ミツマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府貝塚市畠中', '27', '27208', '5970106', '大阪府', 'オオサカフ', '貝塚市', 'カイヅカシ', '畠中', 'ハタケナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府貝塚市地蔵堂', '27', '27208', '5970107', '大阪府', 'オオサカフ', '貝塚市', 'カイヅカシ', '地蔵堂', 'ジゾウドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府貝塚市蕎原', '27', '27208', '5970111', '大阪府', 'オオサカフ', '貝塚市', 'カイヅカシ', '蕎原', 'ソブラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府貝塚市大川', '27', '27208', '5970112', '大阪府', 'オオサカフ', '貝塚市', 'カイヅカシ', '大川', 'オオカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府貝塚市秬谷', '27', '27208', '5970113', '大阪府', 'オオサカフ', '貝塚市', 'カイヅカシ', '秬谷', 'キビタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉佐野市', '27', '27213', '5980000', '大阪府', 'オオサカフ', '泉佐野市', 'イズミサノシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('64340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉南郡田尻町', '27', '27362', '5980000', '大阪府', 'オオサカフ', '泉南郡田尻町', 'センナングンタジリチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('64341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉佐野市上瓦屋', '27', '27213', '5980001', '大阪府', 'オオサカフ', '泉佐野市', 'イズミサノシ', '上瓦屋', 'カミカワラヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉佐野市中庄', '27', '27213', '5980002', '大阪府', 'オオサカフ', '泉佐野市', 'イズミサノシ', '中庄', 'ナカショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉佐野市俵屋', '27', '27213', '5980003', '大阪府', 'オオサカフ', '泉佐野市', 'イズミサノシ', '俵屋', 'タワラヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉佐野市市場南', '27', '27213', '5980004', '大阪府', 'オオサカフ', '泉佐野市', 'イズミサノシ', '市場南', 'イチバミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉佐野市市場東', '27', '27213', '5980005', '大阪府', 'オオサカフ', '泉佐野市', 'イズミサノシ', '市場東', 'イチバヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉佐野市市場西', '27', '27213', '5980006', '大阪府', 'オオサカフ', '泉佐野市', 'イズミサノシ', '市場西', 'イチバニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉佐野市上町', '27', '27213', '5980007', '大阪府', 'オオサカフ', '泉佐野市', 'イズミサノシ', '上町', 'ウエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉佐野市松風台', '27', '27213', '5980008', '大阪府', 'オオサカフ', '泉佐野市', 'イズミサノシ', '松風台', 'ショウフウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉佐野市高松北', '27', '27213', '5980011', '大阪府', 'オオサカフ', '泉佐野市', 'イズミサノシ', '高松北', 'タカマツキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉佐野市高松東', '27', '27213', '5980012', '大阪府', 'オオサカフ', '泉佐野市', 'イズミサノシ', '高松東', 'タカマツヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉佐野市中町', '27', '27213', '5980013', '大阪府', 'オオサカフ', '泉佐野市', 'イズミサノシ', '中町', 'ナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉佐野市葵町', '27', '27213', '5980014', '大阪府', 'オオサカフ', '泉佐野市', 'イズミサノシ', '葵町', 'アオイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉佐野市高松南', '27', '27213', '5980015', '大阪府', 'オオサカフ', '泉佐野市', 'イズミサノシ', '高松南', 'タカマツミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉佐野市高松西', '27', '27213', '5980016', '大阪府', 'オオサカフ', '泉佐野市', 'イズミサノシ', '高松西', 'タカマツニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉佐野市日根野', '27', '27213', '5980021', '大阪府', 'オオサカフ', '泉佐野市', 'イズミサノシ', '日根野', 'ヒネノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉佐野市土丸', '27', '27213', '5980022', '大阪府', 'オオサカフ', '泉佐野市', 'イズミサノシ', '土丸', 'ツチマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉佐野市大木', '27', '27213', '5980023', '大阪府', 'オオサカフ', '泉佐野市', 'イズミサノシ', '大木', 'オオギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉佐野市上之郷', '27', '27213', '5980024', '大阪府', 'オオサカフ', '泉佐野市', 'イズミサノシ', '上之郷', 'カミノゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉佐野市東羽倉崎町', '27', '27213', '5980031', '大阪府', 'オオサカフ', '泉佐野市', 'イズミサノシ', '東羽倉崎町', 'ヒガシハグラザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉佐野市新安松', '27', '27213', '5980032', '大阪府', 'オオサカフ', '泉佐野市', 'イズミサノシ', '新安松', 'シンヤスマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉佐野市南中安松', '27', '27213', '5980033', '大阪府', 'オオサカフ', '泉佐野市', 'イズミサノシ', '南中安松', 'ミナミナカヤスマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉佐野市長滝', '27', '27213', '5980034', '大阪府', 'オオサカフ', '泉佐野市', 'イズミサノシ', '長滝', 'ナガタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉佐野市南中樫井', '27', '27213', '5980035', '大阪府', 'オオサカフ', '泉佐野市', 'イズミサノシ', '南中樫井', 'ミナミナカカシイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉佐野市南中岡本', '27', '27213', '5980036', '大阪府', 'オオサカフ', '泉佐野市', 'イズミサノシ', '南中岡本', 'ミナミナカオカモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉佐野市羽倉崎上町', '27', '27213', '5980037', '大阪府', 'オオサカフ', '泉佐野市', 'イズミサノシ', '羽倉崎上町', 'ハグラザキウエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉佐野市野出町', '27', '27213', '5980041', '大阪府', 'オオサカフ', '泉佐野市', 'イズミサノシ', '野出町', 'ノデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉佐野市西本町', '27', '27213', '5980042', '大阪府', 'オオサカフ', '泉佐野市', 'イズミサノシ', '西本町', 'ニシホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉佐野市大西', '27', '27213', '5980043', '大阪府', 'オオサカフ', '泉佐野市', 'イズミサノシ', '大西', 'オオニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉佐野市笠松', '27', '27213', '5980044', '大阪府', 'オオサカフ', '泉佐野市', 'イズミサノシ', '笠松', 'カサマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉佐野市松原', '27', '27213', '5980045', '大阪府', 'オオサカフ', '泉佐野市', 'イズミサノシ', '松原', 'マツバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉佐野市羽倉崎', '27', '27213', '5980046', '大阪府', 'オオサカフ', '泉佐野市', 'イズミサノシ', '羽倉崎', 'ハグラザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉佐野市りんくう往来南', '27', '27213', '5980047', '大阪府', 'オオサカフ', '泉佐野市', 'イズミサノシ', 'りんくう往来南', 'リンクウオウライミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉佐野市りんくう往来北', '27', '27213', '5980048', '大阪府', 'オオサカフ', '泉佐野市', 'イズミサノシ', 'りんくう往来北', 'リンクウオウライキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉佐野市新町', '27', '27213', '5980051', '大阪府', 'オオサカフ', '泉佐野市', 'イズミサノシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉佐野市旭町', '27', '27213', '5980052', '大阪府', 'オオサカフ', '泉佐野市', 'イズミサノシ', '旭町', 'アサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉佐野市大宮町', '27', '27213', '5980053', '大阪府', 'オオサカフ', '泉佐野市', 'イズミサノシ', '大宮町', 'オオミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉佐野市栄町', '27', '27213', '5980054', '大阪府', 'オオサカフ', '泉佐野市', 'イズミサノシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉佐野市若宮町', '27', '27213', '5980055', '大阪府', 'オオサカフ', '泉佐野市', 'イズミサノシ', '若宮町', 'ワカミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉佐野市元町', '27', '27213', '5980056', '大阪府', 'オオサカフ', '泉佐野市', 'イズミサノシ', '元町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉佐野市本町', '27', '27213', '5980057', '大阪府', 'オオサカフ', '泉佐野市', 'イズミサノシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉佐野市春日町', '27', '27213', '5980058', '大阪府', 'オオサカフ', '泉佐野市', 'イズミサノシ', '春日町', 'カスガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉佐野市住吉町', '27', '27213', '5980061', '大阪府', 'オオサカフ', '泉佐野市', 'イズミサノシ', '住吉町', 'スミヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉佐野市下瓦屋', '27', '27213', '5980062', '大阪府', 'オオサカフ', '泉佐野市', 'イズミサノシ', '下瓦屋', 'シモカワラヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉佐野市湊', '27', '27213', '5980063', '大阪府', 'オオサカフ', '泉佐野市', 'イズミサノシ', '湊', 'ミナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉佐野市新浜町', '27', '27213', '5980064', '大阪府', 'オオサカフ', '泉佐野市', 'イズミサノシ', '新浜町', 'ニイハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉佐野市鶴原', '27', '27213', '5980071', '大阪府', 'オオサカフ', '泉佐野市', 'イズミサノシ', '鶴原', 'ツルハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉佐野市泉ケ丘', '27', '27213', '5980072', '大阪府', 'オオサカフ', '泉佐野市', 'イズミサノシ', '泉ケ丘', 'イズミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉佐野市南泉ケ丘', '27', '27213', '5980073', '大阪府', 'オオサカフ', '泉佐野市', 'イズミサノシ', '南泉ケ丘', 'ミナミイズミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉佐野市東佐野台', '27', '27213', '5980074', '大阪府', 'オオサカフ', '泉佐野市', 'イズミサノシ', '東佐野台', 'ヒガシサノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉佐野市佐野台', '27', '27213', '5980075', '大阪府', 'オオサカフ', '泉佐野市', 'イズミサノシ', '佐野台', 'サノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉南郡田尻町嘉祥寺', '27', '27362', '5980091', '大阪府', 'オオサカフ', '泉南郡田尻町', 'センナングンタジリチョウ', '嘉祥寺', 'カショウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉南郡田尻町吉見', '27', '27362', '5980092', '大阪府', 'オオサカフ', '泉南郡田尻町', 'センナングンタジリチョウ', '吉見', 'ヨシミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉南郡田尻町りんくうポート北', '27', '27362', '5980093', '大阪府', 'オオサカフ', '泉南郡田尻町', 'センナングンタジリチョウ', 'りんくうポート北', 'リンクウポートキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉南郡田尻町りんくうポート南', '27', '27362', '5980094', '大阪府', 'オオサカフ', '泉南郡田尻町', 'センナングンタジリチョウ', 'りんくうポート南', 'リンクウポートミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市中区', '27', '27142', '5990000', '大阪府', 'オオサカフ', '堺市中区', 'サカイシナカク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('64408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市東区', '27', '27143', '5990000', '大阪府', 'オオサカフ', '堺市東区', 'サカイシヒガシク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('64409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府阪南市', '27', '27232', '5990200', '大阪府', 'オオサカフ', '阪南市', 'ハンナンシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('64410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府阪南市尾崎町', '27', '27232', '5990201', '大阪府', 'オオサカフ', '阪南市', 'ハンナンシ', '尾崎町', 'オザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府阪南市下出', '27', '27232', '5990202', '大阪府', 'オオサカフ', '阪南市', 'ハンナンシ', '下出', 'シモイデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府阪南市黒田', '27', '27232', '5990203', '大阪府', 'オオサカフ', '阪南市', 'ハンナンシ', '黒田', 'クロダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府阪南市鳥取', '27', '27232', '5990204', '大阪府', 'オオサカフ', '阪南市', 'ハンナンシ', '鳥取', 'トットリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府阪南市新町', '27', '27232', '5990205', '大阪府', 'オオサカフ', '阪南市', 'ハンナンシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府阪南市鳥取中', '27', '27232', '5990211', '大阪府', 'オオサカフ', '阪南市', 'ハンナンシ', '鳥取中', 'トットリナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府阪南市自然田', '27', '27232', '5990212', '大阪府', 'オオサカフ', '阪南市', 'ハンナンシ', '自然田', 'ジネンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府阪南市和泉鳥取', '27', '27232', '5990213', '大阪府', 'オオサカフ', '阪南市', 'ハンナンシ', '和泉鳥取', 'イズミトットリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府阪南市山中渓', '27', '27232', '5990214', '大阪府', 'オオサカフ', '阪南市', 'ハンナンシ', '山中渓', 'ヤマナカダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府阪南市さつき台', '27', '27232', '5990215', '大阪府', 'オオサカフ', '阪南市', 'ハンナンシ', 'さつき台', 'サツキダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府阪南市緑ケ丘', '27', '27232', '5990216', '大阪府', 'オオサカフ', '阪南市', 'ハンナンシ', '緑ケ丘', 'ミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府阪南市石田', '27', '27232', '5990221', '大阪府', 'オオサカフ', '阪南市', 'ハンナンシ', '石田', 'イシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府阪南市桑畑', '27', '27232', '5990222', '大阪府', 'オオサカフ', '阪南市', 'ハンナンシ', '桑畑', 'クワバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府阪南市光陽台', '27', '27232', '5990223', '大阪府', 'オオサカフ', '阪南市', 'ハンナンシ', '光陽台', 'コウヨウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府阪南市舞', '27', '27232', '5990224', '大阪府', 'オオサカフ', '阪南市', 'ハンナンシ', '舞', 'マイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府阪南市鳥取三井', '27', '27232', '5990225', '大阪府', 'オオサカフ', '阪南市', 'ハンナンシ', '鳥取三井', 'トットリミツイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府阪南市貝掛', '27', '27232', '5990231', '大阪府', 'オオサカフ', '阪南市', 'ハンナンシ', '貝掛', 'カイカケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府阪南市箱作', '27', '27232', '5990232', '大阪府', 'オオサカフ', '阪南市', 'ハンナンシ', '箱作', 'ハコツクリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府阪南市南山中', '27', '27232', '5990233', '大阪府', 'オオサカフ', '阪南市', 'ハンナンシ', '南山中', 'ミナミヤマナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府阪南市淡輪', '27', '27232', '5990234', '大阪府', 'オオサカフ', '阪南市', 'ハンナンシ', '淡輪', 'タンノワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府阪南市箱の浦', '27', '27232', '5990235', '大阪府', 'オオサカフ', '阪南市', 'ハンナンシ', '箱の浦', 'ハコノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府阪南市桃の木台', '27', '27232', '5990236', '大阪府', 'オオサカフ', '阪南市', 'ハンナンシ', '桃の木台', 'モモノキダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉南郡岬町', '27', '27366', '5990300', '大阪府', 'オオサカフ', '泉南郡岬町', 'センナングンミサキチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('64434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉南郡岬町淡輪', '27', '27366', '5990301', '大阪府', 'オオサカフ', '泉南郡岬町', 'センナングンミサキチョウ', '淡輪', 'タンノワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉南郡岬町孝子', '27', '27366', '5990302', '大阪府', 'オオサカフ', '泉南郡岬町', 'センナングンミサキチョウ', '孝子', 'キョウシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉南郡岬町深日', '27', '27366', '5990303', '大阪府', 'オオサカフ', '泉南郡岬町', 'センナングンミサキチョウ', '深日', 'フケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉南郡岬町望海坂', '27', '27366', '5990304', '大阪府', 'オオサカフ', '泉南郡岬町', 'センナングンミサキチョウ', '望海坂', 'ノゾミザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉南郡岬町多奈川谷川', '27', '27366', '5990311', '大阪府', 'オオサカフ', '泉南郡岬町', 'センナングンミサキチョウ', '多奈川谷川', 'タナガワタニガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉南郡岬町多奈川東畑', '27', '27366', '5990312', '大阪府', 'オオサカフ', '泉南郡岬町', 'センナングンミサキチョウ', '多奈川東畑', 'タナガワヒガシバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉南郡岬町多奈川西畑', '27', '27366', '5990313', '大阪府', 'オオサカフ', '泉南郡岬町', 'センナングンミサキチョウ', '多奈川西畑', 'タナガワニシバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府泉南郡岬町多奈川小島', '27', '27366', '5990314', '大阪府', 'オオサカフ', '泉南郡岬町', 'センナングンミサキチョウ', '多奈川小島', 'タナガワコシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市東区八下町', '27', '27143', '5998101', '大阪府', 'オオサカフ', '堺市東区', 'サカイシヒガシク', '八下町', 'ヤシモチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市東区石原町', '27', '27143', '5998102', '大阪府', 'オオサカフ', '堺市東区', 'サカイシヒガシク', '石原町', 'イシハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市東区菩提町', '27', '27143', '5998103', '大阪府', 'オオサカフ', '堺市東区', 'サカイシヒガシク', '菩提町', 'ボダイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市東区引野町', '27', '27143', '5998104', '大阪府', 'オオサカフ', '堺市東区', 'サカイシヒガシク', '引野町', 'ヒキノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市東区白鷺町', '27', '27143', '5998107', '大阪府', 'オオサカフ', '堺市東区', 'サカイシヒガシク', '白鷺町', 'シラサギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市東区日置荘北町', '27', '27143', '5998111', '大阪府', 'オオサカフ', '堺市東区', 'サカイシヒガシク', '日置荘北町', 'ヒキショウキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市東区日置荘原寺町', '27', '27143', '5998112', '大阪府', 'オオサカフ', '堺市東区', 'サカイシヒガシク', '日置荘原寺町', 'ヒキショウハラデラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市東区日置荘田中町', '27', '27143', '5998113', '大阪府', 'オオサカフ', '堺市東区', 'サカイシヒガシク', '日置荘田中町', 'ヒキショウタナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市東区日置荘西町', '27', '27143', '5998114', '大阪府', 'オオサカフ', '堺市東区', 'サカイシヒガシク', '日置荘西町', 'ヒキショウニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市東区関茶屋', '27', '27143', '5998115', '大阪府', 'オオサカフ', '堺市東区', 'サカイシヒガシク', '関茶屋', 'セキチャヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市東区野尻町', '27', '27143', '5998116', '大阪府', 'オオサカフ', '堺市東区', 'サカイシヒガシク', '野尻町', 'ノジリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市東区高松', '27', '27143', '5998121', '大阪府', 'オオサカフ', '堺市東区', 'サカイシヒガシク', '高松', 'タカマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市東区丈六', '27', '27143', '5998122', '大阪府', 'オオサカフ', '堺市東区', 'サカイシヒガシク', '丈六', 'ジョウロク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市東区北野田', '27', '27143', '5998123', '大阪府', 'オオサカフ', '堺市東区', 'サカイシヒガシク', '北野田', 'キタノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市東区南野田', '27', '27143', '5998124', '大阪府', 'オオサカフ', '堺市東区', 'サカイシヒガシク', '南野田', 'ミナミノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市東区西野', '27', '27143', '5998125', '大阪府', 'オオサカフ', '堺市東区', 'サカイシヒガシク', '西野', 'ニシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市東区大美野', '27', '27143', '5998126', '大阪府', 'オオサカフ', '堺市東区', 'サカイシヒガシク', '大美野', 'オオミノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市東区草尾', '27', '27143', '5998127', '大阪府', 'オオサカフ', '堺市東区', 'サカイシヒガシク', '草尾', 'クサオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市東区中茶屋', '27', '27143', '5998128', '大阪府', 'オオサカフ', '堺市東区', 'サカイシヒガシク', '中茶屋', 'ナカチャヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市中区学園町', '27', '27142', '5998231', '大阪府', 'オオサカフ', '堺市中区', 'サカイシナカク', '学園町', 'ガクエンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市中区新家町', '27', '27142', '5998232', '大阪府', 'オオサカフ', '堺市中区', 'サカイシナカク', '新家町', 'シンケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市中区大野芝町', '27', '27142', '5998233', '大阪府', 'オオサカフ', '堺市中区', 'サカイシナカク', '大野芝町', 'オオノシバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市中区土塔町', '27', '27142', '5998234', '大阪府', 'オオサカフ', '堺市中区', 'サカイシナカク', '土塔町', 'ドトウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市中区深井東町', '27', '27142', '5998235', '大阪府', 'オオサカフ', '堺市中区', 'サカイシナカク', '深井東町', 'フカイヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市中区深井沢町', '27', '27142', '5998236', '大阪府', 'オオサカフ', '堺市中区', 'サカイシナカク', '深井沢町', 'フカイサワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市中区深井水池町', '27', '27142', '5998237', '大阪府', 'オオサカフ', '堺市中区', 'サカイシナカク', '深井水池町', 'フカイミズガイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市中区土師町', '27', '27142', '5998238', '大阪府', 'オオサカフ', '堺市中区', 'サカイシナカク', '土師町', 'ハゼチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市中区福田', '27', '27142', '5998241', '大阪府', 'オオサカフ', '堺市中区', 'サカイシナカク', '福田', 'フクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市中区陶器北', '27', '27142', '5998242', '大阪府', 'オオサカフ', '堺市中区', 'サカイシナカク', '陶器北', 'トウキキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市中区見野山', '27', '27142', '5998243', '大阪府', 'オオサカフ', '堺市中区', 'サカイシナカク', '見野山', 'ミノヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市中区上之', '27', '27142', '5998244', '大阪府', 'オオサカフ', '堺市中区', 'サカイシナカク', '上之', 'ウエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市中区辻之', '27', '27142', '5998245', '大阪府', 'オオサカフ', '堺市中区', 'サカイシナカク', '辻之', 'ツジノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市中区田園', '27', '27142', '5998246', '大阪府', 'オオサカフ', '堺市中区', 'サカイシナカク', '田園', 'タゾノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市中区東山', '27', '27142', '5998247', '大阪府', 'オオサカフ', '堺市中区', 'サカイシナカク', '東山', 'ヒガシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市中区深井畑山町', '27', '27142', '5998248', '大阪府', 'オオサカフ', '堺市中区', 'サカイシナカク', '深井畑山町', 'フカイハタヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市中区平井', '27', '27142', '5998251', '大阪府', 'オオサカフ', '堺市中区', 'サカイシナカク', '平井', 'ヒライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市中区楢葉', '27', '27142', '5998252', '大阪府', 'オオサカフ', '堺市中区', 'サカイシナカク', '楢葉', 'ナラバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市中区深阪', '27', '27142', '5998253', '大阪府', 'オオサカフ', '堺市中区', 'サカイシナカク', '深阪', 'フカサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市中区伏尾', '27', '27142', '5998254', '大阪府', 'オオサカフ', '堺市中区', 'サカイシナカク', '伏尾', 'フセオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市中区堀上町', '27', '27142', '5998261', '大阪府', 'オオサカフ', '堺市中区', 'サカイシナカク', '堀上町', 'ホリアゲチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市中区八田北町', '27', '27142', '5998262', '大阪府', 'オオサカフ', '堺市中区', 'サカイシナカク', '八田北町', 'ハンダキタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市中区八田南之町', '27', '27142', '5998263', '大阪府', 'オオサカフ', '堺市中区', 'サカイシナカク', '八田南之町', 'ハンダミナミノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市中区小阪西町', '27', '27142', '5998264', '大阪府', 'オオサカフ', '堺市中区', 'サカイシナカク', '小阪西町', 'コサカニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市中区八田西町', '27', '27142', '5998265', '大阪府', 'オオサカフ', '堺市中区', 'サカイシナカク', '八田西町', 'ハンダニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市中区毛穴町', '27', '27142', '5998266', '大阪府', 'オオサカフ', '堺市中区', 'サカイシナカク', '毛穴町', 'ケナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市中区八田寺町', '27', '27142', '5998267', '大阪府', 'オオサカフ', '堺市中区', 'サカイシナカク', '八田寺町', 'ハンダイジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市中区深井北町', '27', '27142', '5998271', '大阪府', 'オオサカフ', '堺市中区', 'サカイシナカク', '深井北町', 'フカイキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市中区深井中町', '27', '27142', '5998272', '大阪府', 'オオサカフ', '堺市中区', 'サカイシナカク', '深井中町', 'フカイナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市中区深井清水町', '27', '27142', '5998273', '大阪府', 'オオサカフ', '堺市中区', 'サカイシナカク', '深井清水町', 'フカイシミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市中区宮園町', '27', '27142', '5998274', '大阪府', 'オオサカフ', '堺市中区', 'サカイシナカク', '宮園町', 'ミヤゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市中区東八田', '27', '27142', '5998275', '大阪府', 'オオサカフ', '堺市中区', 'サカイシナカク', '東八田', 'ヒガシハンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府堺市中区小阪', '27', '27142', '5998276', '大阪府', 'オオサカフ', '堺市中区', 'サカイシナカク', '小阪', 'コサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市手稲区', '01', '01109', '0060000', '北海道', 'ホッカイドウ', '札幌市手稲区', 'サッポロシテイネク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('64497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区', '01', '01101', '0600000', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('64498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区', '26', '26106', '6000000', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('64499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北1条西1丁目', '01', '01101', '0600001', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北1条西', 'キタ01ジョウニシ', null, null, '1丁目', '01チョウメ');
INSERT INTO `ms_addresses` VALUES ('64500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北1条西2丁目', '01', '01101', '0600001', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北1条西', 'キタ01ジョウニシ', null, null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('64501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北1条西3丁目', '01', '01101', '0600001', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北1条西', 'キタ01ジョウニシ', null, null, '3丁目', '03チョウメ');
INSERT INTO `ms_addresses` VALUES ('64502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北1条西4丁目', '01', '01101', '0600001', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北1条西', 'キタ01ジョウニシ', null, null, '4丁目', '04チョウメ');
INSERT INTO `ms_addresses` VALUES ('64503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北1条西5丁目', '01', '01101', '0600001', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北1条西', 'キタ01ジョウニシ', null, null, '5丁目', '05チョウメ');
INSERT INTO `ms_addresses` VALUES ('64504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北1条西6丁目', '01', '01101', '0600001', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北1条西', 'キタ01ジョウニシ', null, null, '6丁目', '06チョウメ');
INSERT INTO `ms_addresses` VALUES ('64505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北1条西7丁目', '01', '01101', '0600001', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北1条西', 'キタ01ジョウニシ', null, null, '7丁目', '07チョウメ');
INSERT INTO `ms_addresses` VALUES ('64506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北1条西8丁目', '01', '01101', '0600001', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北1条西', 'キタ01ジョウニシ', null, null, '8丁目', '08チョウメ');
INSERT INTO `ms_addresses` VALUES ('64507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北1条西9丁目', '01', '01101', '0600001', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北1条西', 'キタ01ジョウニシ', null, null, '9丁目', '09チョウメ');
INSERT INTO `ms_addresses` VALUES ('64508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北1条西10丁目', '01', '01101', '0600001', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北1条西', 'キタ01ジョウニシ', null, null, '10丁目', '10チョウメ');
INSERT INTO `ms_addresses` VALUES ('64509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北1条西11丁目', '01', '01101', '0600001', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北1条西', 'キタ01ジョウニシ', null, null, '11丁目', '11チョウメ');
INSERT INTO `ms_addresses` VALUES ('64510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北1条西12丁目', '01', '01101', '0600001', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北1条西', 'キタ01ジョウニシ', null, null, '12丁目', '12チョウメ');
INSERT INTO `ms_addresses` VALUES ('64511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北1条西13丁目', '01', '01101', '0600001', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北1条西', 'キタ01ジョウニシ', null, null, '13丁目', '13チョウメ');
INSERT INTO `ms_addresses` VALUES ('64512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北1条西14丁目', '01', '01101', '0600001', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北1条西', 'キタ01ジョウニシ', null, null, '14丁目', '14チョウメ');
INSERT INTO `ms_addresses` VALUES ('64513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北1条西15丁目', '01', '01101', '0600001', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北1条西', 'キタ01ジョウニシ', null, null, '15丁目', '15チョウメ');
INSERT INTO `ms_addresses` VALUES ('64514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北1条西16丁目', '01', '01101', '0600001', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北1条西', 'キタ01ジョウニシ', null, null, '16丁目', '16チョウメ');
INSERT INTO `ms_addresses` VALUES ('64515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北1条西17丁目', '01', '01101', '0600001', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北1条西', 'キタ01ジョウニシ', null, null, '17丁目', '17チョウメ');
INSERT INTO `ms_addresses` VALUES ('64516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北1条西18丁目', '01', '01101', '0600001', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北1条西', 'キタ01ジョウニシ', null, null, '18丁目', '18チョウメ');
INSERT INTO `ms_addresses` VALUES ('64517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北1条西19丁目', '01', '01101', '0600001', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北1条西', 'キタ01ジョウニシ', null, null, '19丁目', '19チョウメ');
INSERT INTO `ms_addresses` VALUES ('64518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北2条西1丁目', '01', '01101', '0600002', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北2条西', 'キタ02ジョウニシ', null, null, '1丁目', '01チョウメ');
INSERT INTO `ms_addresses` VALUES ('64519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北2条西2丁目', '01', '01101', '0600002', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北2条西', 'キタ02ジョウニシ', null, null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('64520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北2条西3丁目', '01', '01101', '0600002', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北2条西', 'キタ02ジョウニシ', null, null, '3丁目', '03チョウメ');
INSERT INTO `ms_addresses` VALUES ('64521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北2条西4丁目', '01', '01101', '0600002', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北2条西', 'キタ02ジョウニシ', null, null, '4丁目', '04チョウメ');
INSERT INTO `ms_addresses` VALUES ('64522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北2条西5丁目', '01', '01101', '0600002', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北2条西', 'キタ02ジョウニシ', null, null, '5丁目', '05チョウメ');
INSERT INTO `ms_addresses` VALUES ('64523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北2条西6丁目', '01', '01101', '0600002', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北2条西', 'キタ02ジョウニシ', null, null, '6丁目', '06チョウメ');
INSERT INTO `ms_addresses` VALUES ('64524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北2条西7丁目', '01', '01101', '0600002', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北2条西', 'キタ02ジョウニシ', null, null, '7丁目', '07チョウメ');
INSERT INTO `ms_addresses` VALUES ('64525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北2条西8丁目', '01', '01101', '0600002', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北2条西', 'キタ02ジョウニシ', null, null, '8丁目', '08チョウメ');
INSERT INTO `ms_addresses` VALUES ('64526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北2条西9丁目', '01', '01101', '0600002', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北2条西', 'キタ02ジョウニシ', null, null, '9丁目', '09チョウメ');
INSERT INTO `ms_addresses` VALUES ('64527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北2条西10丁目', '01', '01101', '0600002', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北2条西', 'キタ02ジョウニシ', null, null, '10丁目', '10チョウメ');
INSERT INTO `ms_addresses` VALUES ('64528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北2条西11丁目', '01', '01101', '0600002', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北2条西', 'キタ02ジョウニシ', null, null, '11丁目', '11チョウメ');
INSERT INTO `ms_addresses` VALUES ('64529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北2条西12丁目', '01', '01101', '0600002', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北2条西', 'キタ02ジョウニシ', null, null, '12丁目', '12チョウメ');
INSERT INTO `ms_addresses` VALUES ('64530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北2条西13丁目', '01', '01101', '0600002', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北2条西', 'キタ02ジョウニシ', null, null, '13丁目', '13チョウメ');
INSERT INTO `ms_addresses` VALUES ('64531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北2条西14丁目', '01', '01101', '0600002', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北2条西', 'キタ02ジョウニシ', null, null, '14丁目', '14チョウメ');
INSERT INTO `ms_addresses` VALUES ('64532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北2条西15丁目', '01', '01101', '0600002', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北2条西', 'キタ02ジョウニシ', null, null, '15丁目', '15チョウメ');
INSERT INTO `ms_addresses` VALUES ('64533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北2条西16丁目', '01', '01101', '0600002', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北2条西', 'キタ02ジョウニシ', null, null, '16丁目', '16チョウメ');
INSERT INTO `ms_addresses` VALUES ('64534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北2条西17丁目', '01', '01101', '0600002', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北2条西', 'キタ02ジョウニシ', null, null, '17丁目', '17チョウメ');
INSERT INTO `ms_addresses` VALUES ('64535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北2条西18丁目', '01', '01101', '0600002', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北2条西', 'キタ02ジョウニシ', null, null, '18丁目', '18チョウメ');
INSERT INTO `ms_addresses` VALUES ('64536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北2条西19丁目', '01', '01101', '0600002', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北2条西', 'キタ02ジョウニシ', null, null, '19丁目', '19チョウメ');
INSERT INTO `ms_addresses` VALUES ('64537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北3条西1丁目', '01', '01101', '0600003', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北3条西', 'キタ03ジョウニシ', null, null, '1丁目', '01チョウメ');
INSERT INTO `ms_addresses` VALUES ('64538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北3条西2丁目', '01', '01101', '0600003', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北3条西', 'キタ03ジョウニシ', null, null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('64539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北3条西3丁目', '01', '01101', '0600003', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北3条西', 'キタ03ジョウニシ', null, null, '3丁目', '03チョウメ');
INSERT INTO `ms_addresses` VALUES ('64540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北3条西4丁目', '01', '01101', '0600003', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北3条西', 'キタ03ジョウニシ', null, null, '4丁目', '04チョウメ');
INSERT INTO `ms_addresses` VALUES ('64541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北3条西5丁目', '01', '01101', '0600003', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北3条西', 'キタ03ジョウニシ', null, null, '5丁目', '05チョウメ');
INSERT INTO `ms_addresses` VALUES ('64542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北3条西6丁目', '01', '01101', '0600003', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北3条西', 'キタ03ジョウニシ', null, null, '6丁目', '06チョウメ');
INSERT INTO `ms_addresses` VALUES ('64543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北3条西7丁目', '01', '01101', '0600003', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北3条西', 'キタ03ジョウニシ', null, null, '7丁目', '07チョウメ');
INSERT INTO `ms_addresses` VALUES ('64544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北3条西8丁目', '01', '01101', '0600003', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北3条西', 'キタ03ジョウニシ', null, null, '8丁目', '08チョウメ');
INSERT INTO `ms_addresses` VALUES ('64545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北3条西9丁目', '01', '01101', '0600003', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北3条西', 'キタ03ジョウニシ', null, null, '9丁目', '09チョウメ');
INSERT INTO `ms_addresses` VALUES ('64546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北3条西10丁目', '01', '01101', '0600003', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北3条西', 'キタ03ジョウニシ', null, null, '10丁目', '10チョウメ');
INSERT INTO `ms_addresses` VALUES ('64547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北3条西11丁目', '01', '01101', '0600003', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北3条西', 'キタ03ジョウニシ', null, null, '11丁目', '11チョウメ');
INSERT INTO `ms_addresses` VALUES ('64548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北3条西12丁目', '01', '01101', '0600003', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北3条西', 'キタ03ジョウニシ', null, null, '12丁目', '12チョウメ');
INSERT INTO `ms_addresses` VALUES ('64549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北3条西13丁目', '01', '01101', '0600003', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北3条西', 'キタ03ジョウニシ', null, null, '13丁目', '13チョウメ');
INSERT INTO `ms_addresses` VALUES ('64550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北3条西14丁目', '01', '01101', '0600003', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北3条西', 'キタ03ジョウニシ', null, null, '14丁目', '14チョウメ');
INSERT INTO `ms_addresses` VALUES ('64551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北3条西15丁目', '01', '01101', '0600003', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北3条西', 'キタ03ジョウニシ', null, null, '15丁目', '15チョウメ');
INSERT INTO `ms_addresses` VALUES ('64552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北3条西16丁目', '01', '01101', '0600003', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北3条西', 'キタ03ジョウニシ', null, null, '16丁目', '16チョウメ');
INSERT INTO `ms_addresses` VALUES ('64553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北3条西17丁目', '01', '01101', '0600003', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北3条西', 'キタ03ジョウニシ', null, null, '17丁目', '17チョウメ');
INSERT INTO `ms_addresses` VALUES ('64554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北3条西18丁目', '01', '01101', '0600003', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北3条西', 'キタ03ジョウニシ', null, null, '18丁目', '18チョウメ');
INSERT INTO `ms_addresses` VALUES ('64555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北3条西19丁目', '01', '01101', '0600003', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北3条西', 'キタ03ジョウニシ', null, null, '19丁目', '19チョウメ');
INSERT INTO `ms_addresses` VALUES ('64556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北4条西1丁目', '01', '01101', '0600004', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北4条西', 'キタ04ジョウニシ', null, null, '1丁目', '01チョウメ');
INSERT INTO `ms_addresses` VALUES ('64557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北4条西2丁目', '01', '01101', '0600004', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北4条西', 'キタ04ジョウニシ', null, null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('64558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北4条西3丁目', '01', '01101', '0600004', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北4条西', 'キタ04ジョウニシ', null, null, '3丁目', '03チョウメ');
INSERT INTO `ms_addresses` VALUES ('64559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北4条西4丁目', '01', '01101', '0600004', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北4条西', 'キタ04ジョウニシ', null, null, '4丁目', '04チョウメ');
INSERT INTO `ms_addresses` VALUES ('64560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北4条西5丁目', '01', '01101', '0600004', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北4条西', 'キタ04ジョウニシ', null, null, '5丁目', '05チョウメ');
INSERT INTO `ms_addresses` VALUES ('64561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北4条西6丁目', '01', '01101', '0600004', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北4条西', 'キタ04ジョウニシ', null, null, '6丁目', '06チョウメ');
INSERT INTO `ms_addresses` VALUES ('64562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北4条西7丁目', '01', '01101', '0600004', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北4条西', 'キタ04ジョウニシ', null, null, '7丁目', '07チョウメ');
INSERT INTO `ms_addresses` VALUES ('64563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北4条西8丁目', '01', '01101', '0600004', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北4条西', 'キタ04ジョウニシ', null, null, '8丁目', '08チョウメ');
INSERT INTO `ms_addresses` VALUES ('64564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北4条西9丁目', '01', '01101', '0600004', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北4条西', 'キタ04ジョウニシ', null, null, '9丁目', '09チョウメ');
INSERT INTO `ms_addresses` VALUES ('64565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北4条西10丁目', '01', '01101', '0600004', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北4条西', 'キタ04ジョウニシ', null, null, '10丁目', '10チョウメ');
INSERT INTO `ms_addresses` VALUES ('64566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北4条西11丁目', '01', '01101', '0600004', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北4条西', 'キタ04ジョウニシ', null, null, '11丁目', '11チョウメ');
INSERT INTO `ms_addresses` VALUES ('64567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北4条西12丁目', '01', '01101', '0600004', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北4条西', 'キタ04ジョウニシ', null, null, '12丁目', '12チョウメ');
INSERT INTO `ms_addresses` VALUES ('64568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北4条西13丁目', '01', '01101', '0600004', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北4条西', 'キタ04ジョウニシ', null, null, '13丁目', '13チョウメ');
INSERT INTO `ms_addresses` VALUES ('64569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北4条西14丁目', '01', '01101', '0600004', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北4条西', 'キタ04ジョウニシ', null, null, '14丁目', '14チョウメ');
INSERT INTO `ms_addresses` VALUES ('64570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北4条西15丁目', '01', '01101', '0600004', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北4条西', 'キタ04ジョウニシ', null, null, '15丁目', '15チョウメ');
INSERT INTO `ms_addresses` VALUES ('64571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北4条西16丁目', '01', '01101', '0600004', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北4条西', 'キタ04ジョウニシ', null, null, '16丁目', '16チョウメ');
INSERT INTO `ms_addresses` VALUES ('64572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北4条西17丁目', '01', '01101', '0600004', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北4条西', 'キタ04ジョウニシ', null, null, '17丁目', '17チョウメ');
INSERT INTO `ms_addresses` VALUES ('64573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北4条西18丁目', '01', '01101', '0600004', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北4条西', 'キタ04ジョウニシ', null, null, '18丁目', '18チョウメ');
INSERT INTO `ms_addresses` VALUES ('64574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北4条西19丁目', '01', '01101', '0600004', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北4条西', 'キタ04ジョウニシ', null, null, '19丁目', '19チョウメ');
INSERT INTO `ms_addresses` VALUES ('64575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北5条西1丁目', '01', '01101', '0600005', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北5条西', 'キタ05ジョウニシ', null, null, '1丁目', '01チョウメ');
INSERT INTO `ms_addresses` VALUES ('64576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北5条西2丁目', '01', '01101', '0600005', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北5条西', 'キタ05ジョウニシ', null, null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('64577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北5条西3丁目', '01', '01101', '0600005', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北5条西', 'キタ05ジョウニシ', null, null, '3丁目', '03チョウメ');
INSERT INTO `ms_addresses` VALUES ('64578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北5条西4丁目', '01', '01101', '0600005', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北5条西', 'キタ05ジョウニシ', null, null, '4丁目', '04チョウメ');
INSERT INTO `ms_addresses` VALUES ('64579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北5条西5丁目', '01', '01101', '0600005', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北5条西', 'キタ05ジョウニシ', null, null, '5丁目', '05チョウメ');
INSERT INTO `ms_addresses` VALUES ('64580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北5条西6丁目', '01', '01101', '0600005', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北5条西', 'キタ05ジョウニシ', null, null, '6丁目', '06チョウメ');
INSERT INTO `ms_addresses` VALUES ('64581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北5条西7丁目', '01', '01101', '0600005', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北5条西', 'キタ05ジョウニシ', null, null, '7丁目', '07チョウメ');
INSERT INTO `ms_addresses` VALUES ('64582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北5条西8丁目', '01', '01101', '0600005', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北5条西', 'キタ05ジョウニシ', null, null, '8丁目', '08チョウメ');
INSERT INTO `ms_addresses` VALUES ('64583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北5条西9丁目', '01', '01101', '0600005', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北5条西', 'キタ05ジョウニシ', null, null, '9丁目', '09チョウメ');
INSERT INTO `ms_addresses` VALUES ('64584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北5条西10丁目', '01', '01101', '0600005', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北5条西', 'キタ05ジョウニシ', null, null, '10丁目', '10チョウメ');
INSERT INTO `ms_addresses` VALUES ('64585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北5条西11丁目', '01', '01101', '0600005', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北5条西', 'キタ05ジョウニシ', null, null, '11丁目', '11チョウメ');
INSERT INTO `ms_addresses` VALUES ('64586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北5条西12丁目', '01', '01101', '0600005', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北5条西', 'キタ05ジョウニシ', null, null, '12丁目', '12チョウメ');
INSERT INTO `ms_addresses` VALUES ('64587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北5条西13丁目', '01', '01101', '0600005', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北5条西', 'キタ05ジョウニシ', null, null, '13丁目', '13チョウメ');
INSERT INTO `ms_addresses` VALUES ('64588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北5条西14丁目', '01', '01101', '0600005', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北5条西', 'キタ05ジョウニシ', null, null, '14丁目', '14チョウメ');
INSERT INTO `ms_addresses` VALUES ('64589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北5条西15丁目', '01', '01101', '0600005', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北5条西', 'キタ05ジョウニシ', null, null, '15丁目', '15チョウメ');
INSERT INTO `ms_addresses` VALUES ('64590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北5条西16丁目', '01', '01101', '0600005', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北5条西', 'キタ05ジョウニシ', null, null, '16丁目', '16チョウメ');
INSERT INTO `ms_addresses` VALUES ('64591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北5条西17丁目', '01', '01101', '0600005', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北5条西', 'キタ05ジョウニシ', null, null, '17丁目', '17チョウメ');
INSERT INTO `ms_addresses` VALUES ('64592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北5条西18丁目', '01', '01101', '0600005', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北5条西', 'キタ05ジョウニシ', null, null, '18丁目', '18チョウメ');
INSERT INTO `ms_addresses` VALUES ('64593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北5条西19丁目', '01', '01101', '0600005', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北5条西', 'キタ05ジョウニシ', null, null, '19丁目', '19チョウメ');
INSERT INTO `ms_addresses` VALUES ('64594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北5条西20丁目', '01', '01101', '0600005', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北5条西', 'キタ05ジョウニシ', null, null, '20丁目', '20チョウメ');
INSERT INTO `ms_addresses` VALUES ('64595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北5条西21丁目', '01', '01101', '0600005', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北5条西', 'キタ05ジョウニシ', null, null, '21丁目', '21チョウメ');
INSERT INTO `ms_addresses` VALUES ('64596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北5条西22丁目', '01', '01101', '0600005', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北5条西', 'キタ05ジョウニシ', null, null, '22丁目', '22チョウメ');
INSERT INTO `ms_addresses` VALUES ('64597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北5条西23丁目', '01', '01101', '0600005', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北5条西', 'キタ05ジョウニシ', null, null, '23丁目', '23チョウメ');
INSERT INTO `ms_addresses` VALUES ('64598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北5条西24丁目', '01', '01101', '0600005', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北5条西', 'キタ05ジョウニシ', null, null, '24丁目', '24チョウメ');
INSERT INTO `ms_addresses` VALUES ('64599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北6条西10丁目', '01', '01101', '0600006', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北6条西', 'キタ06ジョウニシ', null, null, '10丁目', '10チョウメ');
INSERT INTO `ms_addresses` VALUES ('64600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北6条西11丁目', '01', '01101', '0600006', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北6条西', 'キタ06ジョウニシ', null, null, '11丁目', '11チョウメ');
INSERT INTO `ms_addresses` VALUES ('64601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北6条西12丁目', '01', '01101', '0600006', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北6条西', 'キタ06ジョウニシ', null, null, '12丁目', '12チョウメ');
INSERT INTO `ms_addresses` VALUES ('64602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北6条西13丁目', '01', '01101', '0600006', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北6条西', 'キタ06ジョウニシ', null, null, '13丁目', '13チョウメ');
INSERT INTO `ms_addresses` VALUES ('64603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北6条西14丁目', '01', '01101', '0600006', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北6条西', 'キタ06ジョウニシ', null, null, '14丁目', '14チョウメ');
INSERT INTO `ms_addresses` VALUES ('64604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北6条西15丁目', '01', '01101', '0600006', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北6条西', 'キタ06ジョウニシ', null, null, '15丁目', '15チョウメ');
INSERT INTO `ms_addresses` VALUES ('64605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北6条西16丁目', '01', '01101', '0600006', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北6条西', 'キタ06ジョウニシ', null, null, '16丁目', '16チョウメ');
INSERT INTO `ms_addresses` VALUES ('64606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北6条西17丁目', '01', '01101', '0600006', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北6条西', 'キタ06ジョウニシ', null, null, '17丁目', '17チョウメ');
INSERT INTO `ms_addresses` VALUES ('64607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北6条西18丁目', '01', '01101', '0600006', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北6条西', 'キタ06ジョウニシ', null, null, '18丁目', '18チョウメ');
INSERT INTO `ms_addresses` VALUES ('64608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北6条西19丁目', '01', '01101', '0600006', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北6条西', 'キタ06ジョウニシ', null, null, '19丁目', '19チョウメ');
INSERT INTO `ms_addresses` VALUES ('64609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北6条西20丁目', '01', '01101', '0600006', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北6条西', 'キタ06ジョウニシ', null, null, '20丁目', '20チョウメ');
INSERT INTO `ms_addresses` VALUES ('64610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北6条西21丁目', '01', '01101', '0600006', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北6条西', 'キタ06ジョウニシ', null, null, '21丁目', '21チョウメ');
INSERT INTO `ms_addresses` VALUES ('64611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北6条西22丁目', '01', '01101', '0600006', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北6条西', 'キタ06ジョウニシ', null, null, '22丁目', '22チョウメ');
INSERT INTO `ms_addresses` VALUES ('64612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北6条西23丁目', '01', '01101', '0600006', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北6条西', 'キタ06ジョウニシ', null, null, '23丁目', '23チョウメ');
INSERT INTO `ms_addresses` VALUES ('64613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北6条西24丁目', '01', '01101', '0600006', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北6条西', 'キタ06ジョウニシ', null, null, '24丁目', '24チョウメ');
INSERT INTO `ms_addresses` VALUES ('64614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北6条西25丁目', '01', '01101', '0600006', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北6条西', 'キタ06ジョウニシ', null, null, '25丁目', '25チョウメ');
INSERT INTO `ms_addresses` VALUES ('64615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北7条西', '01', '01101', '0600007', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北7条西', 'キタ07ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北8条西', '01', '01101', '0600008', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北8条西', 'キタ08ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北9条西', '01', '01101', '0600009', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北9条西', 'キタ09ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市手稲区西宮の沢1条', '01', '01109', '0060001', '北海道', 'ホッカイドウ', '札幌市手稲区', 'サッポロシテイネク', '西宮の沢1条', 'ニシミヤノサワ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北10条西', '01', '01101', '0600010', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北10条西', 'キタ10ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北11条西', '01', '01101', '0600011', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北11条西', 'キタ11ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北12条西', '01', '01101', '0600012', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北12条西', 'キタ12ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北13条西', '01', '01101', '0600013', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北13条西', 'キタ13ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北14条西', '01', '01101', '0600014', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北14条西', 'キタ14ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北15条西', '01', '01101', '0600015', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北15条西', 'キタ15ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北16条西', '01', '01101', '0600016', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北16条西', 'キタ16ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北17条西', '01', '01101', '0600017', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北17条西', 'キタ17ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北18条西', '01', '01101', '0600018', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北18条西', 'キタ18ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市手稲区西宮の沢2条', '01', '01109', '0060002', '北海道', 'ホッカイドウ', '札幌市手稲区', 'サッポロシテイネク', '西宮の沢2条', 'ニシミヤノサワ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北20条西', '01', '01101', '0600020', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北20条西', 'キタ20ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北21条西', '01', '01101', '0600021', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北21条西', 'キタ21ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北22条西', '01', '01101', '0600022', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北22条西', 'キタ22ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市手稲区西宮の沢3条', '01', '01109', '0060003', '北海道', 'ホッカイドウ', '札幌市手稲区', 'サッポロシテイネク', '西宮の沢3条', 'ニシミヤノサワ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北1条東', '01', '01101', '0600031', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北1条東', 'キタ01ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北2条東', '01', '01101', '0600032', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北2条東', 'キタ02ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北3条東', '01', '01101', '0600033', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北3条東', 'キタ03ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北4条東1丁目', '01', '01101', '0600034', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北4条東', 'キタ04ジョウヒガシ', null, null, '1丁目', '01チョウメ');
INSERT INTO `ms_addresses` VALUES ('64637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北4条東2丁目', '01', '01101', '0600034', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北4条東', 'キタ04ジョウヒガシ', null, null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('64638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北4条東3丁目', '01', '01101', '0600034', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北4条東', 'キタ04ジョウヒガシ', null, null, '3丁目', '03チョウメ');
INSERT INTO `ms_addresses` VALUES ('64639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北4条東4丁目', '01', '01101', '0600034', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北4条東', 'キタ04ジョウヒガシ', null, null, '4丁目', '04チョウメ');
INSERT INTO `ms_addresses` VALUES ('64640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北4条東5丁目', '01', '01101', '0600034', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北4条東', 'キタ04ジョウヒガシ', null, null, '5丁目', '05チョウメ');
INSERT INTO `ms_addresses` VALUES ('64641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北4条東6丁目', '01', '01101', '0600034', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北4条東', 'キタ04ジョウヒガシ', null, null, '6丁目', '06チョウメ');
INSERT INTO `ms_addresses` VALUES ('64642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北4条東7丁目', '01', '01101', '0600034', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北4条東', 'キタ04ジョウヒガシ', null, null, '7丁目', '07チョウメ');
INSERT INTO `ms_addresses` VALUES ('64643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北4条東8丁目', '01', '01101', '0600034', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北4条東', 'キタ04ジョウヒガシ', null, null, '8丁目', '08チョウメ');
INSERT INTO `ms_addresses` VALUES ('64644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北5条東', '01', '01101', '0600035', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北5条東', 'キタ05ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市手稲区西宮の沢4条', '01', '01109', '0060004', '北海道', 'ホッカイドウ', '札幌市手稲区', 'サッポロシテイネク', '西宮の沢4条', 'ニシミヤノサワ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区大通東', '01', '01101', '0600041', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '大通東', 'オオドオリヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区大通西1丁目', '01', '01101', '0600042', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '大通西', 'オオドオリニシ', null, null, '1丁目', '01チョウメ');
INSERT INTO `ms_addresses` VALUES ('64648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区大通西2丁目', '01', '01101', '0600042', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '大通西', 'オオドオリニシ', null, null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('64649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区大通西3丁目', '01', '01101', '0600042', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '大通西', 'オオドオリニシ', null, null, '3丁目', '03チョウメ');
INSERT INTO `ms_addresses` VALUES ('64650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区大通西4丁目', '01', '01101', '0600042', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '大通西', 'オオドオリニシ', null, null, '4丁目', '04チョウメ');
INSERT INTO `ms_addresses` VALUES ('64651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区大通西5丁目', '01', '01101', '0600042', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '大通西', 'オオドオリニシ', null, null, '5丁目', '05チョウメ');
INSERT INTO `ms_addresses` VALUES ('64652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区大通西6丁目', '01', '01101', '0600042', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '大通西', 'オオドオリニシ', null, null, '6丁目', '06チョウメ');
INSERT INTO `ms_addresses` VALUES ('64653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区大通西7丁目', '01', '01101', '0600042', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '大通西', 'オオドオリニシ', null, null, '7丁目', '07チョウメ');
INSERT INTO `ms_addresses` VALUES ('64654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区大通西8丁目', '01', '01101', '0600042', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '大通西', 'オオドオリニシ', null, null, '8丁目', '08チョウメ');
INSERT INTO `ms_addresses` VALUES ('64655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区大通西9丁目', '01', '01101', '0600042', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '大通西', 'オオドオリニシ', null, null, '9丁目', '09チョウメ');
INSERT INTO `ms_addresses` VALUES ('64656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区大通西10丁目', '01', '01101', '0600042', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '大通西', 'オオドオリニシ', null, null, '10丁目', '10チョウメ');
INSERT INTO `ms_addresses` VALUES ('64657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区大通西11丁目', '01', '01101', '0600042', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '大通西', 'オオドオリニシ', null, null, '11丁目', '11チョウメ');
INSERT INTO `ms_addresses` VALUES ('64658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区大通西12丁目', '01', '01101', '0600042', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '大通西', 'オオドオリニシ', null, null, '12丁目', '12チョウメ');
INSERT INTO `ms_addresses` VALUES ('64659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区大通西13丁目', '01', '01101', '0600042', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '大通西', 'オオドオリニシ', null, null, '13丁目', '13チョウメ');
INSERT INTO `ms_addresses` VALUES ('64660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区大通西14丁目', '01', '01101', '0600042', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '大通西', 'オオドオリニシ', null, null, '14丁目', '14チョウメ');
INSERT INTO `ms_addresses` VALUES ('64661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区大通西15丁目', '01', '01101', '0600042', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '大通西', 'オオドオリニシ', null, null, '15丁目', '15チョウメ');
INSERT INTO `ms_addresses` VALUES ('64662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区大通西16丁目', '01', '01101', '0600042', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '大通西', 'オオドオリニシ', null, null, '16丁目', '16チョウメ');
INSERT INTO `ms_addresses` VALUES ('64663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区大通西17丁目', '01', '01101', '0600042', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '大通西', 'オオドオリニシ', null, null, '17丁目', '17チョウメ');
INSERT INTO `ms_addresses` VALUES ('64664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区大通西18丁目', '01', '01101', '0600042', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '大通西', 'オオドオリニシ', null, null, '18丁目', '18チョウメ');
INSERT INTO `ms_addresses` VALUES ('64665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区大通西19丁目', '01', '01101', '0600042', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '大通西', 'オオドオリニシ', null, null, '19丁目', '19チョウメ');
INSERT INTO `ms_addresses` VALUES ('64666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市手稲区西宮の沢5条', '01', '01109', '0060005', '北海道', 'ホッカイドウ', '札幌市手稲区', 'サッポロシテイネク', '西宮の沢5条', 'ニシミヤノサワ05ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南1条東', '01', '01101', '0600051', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南1条東', 'ミナミ01ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南2条東', '01', '01101', '0600052', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南2条東', 'ミナミ02ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南3条東', '01', '01101', '0600053', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南3条東', 'ミナミ03ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南4条東', '01', '01101', '0600054', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南4条東', 'ミナミ04ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南5条東', '01', '01101', '0600055', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南5条東', 'ミナミ05ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南6条東', '01', '01101', '0600056', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南6条東', 'ミナミ06ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南7条東', '01', '01101', '0600057', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南7条東', 'ミナミ07ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市手稲区西宮の沢6条', '01', '01109', '0060006', '北海道', 'ホッカイドウ', '札幌市手稲区', 'サッポロシテイネク', '西宮の沢6条', 'ニシミヤノサワ06ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南1条西1丁目', '01', '01101', '0600061', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南1条西', 'ミナミ01ジョウニシ', null, null, '1丁目', '01チョウメ');
INSERT INTO `ms_addresses` VALUES ('64676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南1条西2丁目', '01', '01101', '0600061', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南1条西', 'ミナミ01ジョウニシ', null, null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('64677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南1条西3丁目', '01', '01101', '0600061', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南1条西', 'ミナミ01ジョウニシ', null, null, '3丁目', '03チョウメ');
INSERT INTO `ms_addresses` VALUES ('64678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南1条西4丁目', '01', '01101', '0600061', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南1条西', 'ミナミ01ジョウニシ', null, null, '4丁目', '04チョウメ');
INSERT INTO `ms_addresses` VALUES ('64679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南1条西5丁目', '01', '01101', '0600061', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南1条西', 'ミナミ01ジョウニシ', null, null, '5丁目', '05チョウメ');
INSERT INTO `ms_addresses` VALUES ('64680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南1条西6丁目', '01', '01101', '0600061', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南1条西', 'ミナミ01ジョウニシ', null, null, '6丁目', '06チョウメ');
INSERT INTO `ms_addresses` VALUES ('64681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南1条西7丁目', '01', '01101', '0600061', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南1条西', 'ミナミ01ジョウニシ', null, null, '7丁目', '07チョウメ');
INSERT INTO `ms_addresses` VALUES ('64682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南1条西8丁目', '01', '01101', '0600061', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南1条西', 'ミナミ01ジョウニシ', null, null, '8丁目', '08チョウメ');
INSERT INTO `ms_addresses` VALUES ('64683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南1条西9丁目', '01', '01101', '0600061', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南1条西', 'ミナミ01ジョウニシ', null, null, '9丁目', '09チョウメ');
INSERT INTO `ms_addresses` VALUES ('64684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南1条西10丁目', '01', '01101', '0600061', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南1条西', 'ミナミ01ジョウニシ', null, null, '10丁目', '10チョウメ');
INSERT INTO `ms_addresses` VALUES ('64685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南1条西11丁目', '01', '01101', '0600061', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南1条西', 'ミナミ01ジョウニシ', null, null, '11丁目', '11チョウメ');
INSERT INTO `ms_addresses` VALUES ('64686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南1条西12丁目', '01', '01101', '0600061', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南1条西', 'ミナミ01ジョウニシ', null, null, '12丁目', '12チョウメ');
INSERT INTO `ms_addresses` VALUES ('64687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南1条西13丁目', '01', '01101', '0600061', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南1条西', 'ミナミ01ジョウニシ', null, null, '13丁目', '13チョウメ');
INSERT INTO `ms_addresses` VALUES ('64688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南1条西14丁目', '01', '01101', '0600061', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南1条西', 'ミナミ01ジョウニシ', null, null, '14丁目', '14チョウメ');
INSERT INTO `ms_addresses` VALUES ('64689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南1条西15丁目', '01', '01101', '0600061', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南1条西', 'ミナミ01ジョウニシ', null, null, '15丁目', '15チョウメ');
INSERT INTO `ms_addresses` VALUES ('64690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南1条西16丁目', '01', '01101', '0600061', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南1条西', 'ミナミ01ジョウニシ', null, null, '16丁目', '16チョウメ');
INSERT INTO `ms_addresses` VALUES ('64691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南1条西17丁目', '01', '01101', '0600061', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南1条西', 'ミナミ01ジョウニシ', null, null, '17丁目', '17チョウメ');
INSERT INTO `ms_addresses` VALUES ('64692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南1条西18丁目', '01', '01101', '0600061', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南1条西', 'ミナミ01ジョウニシ', null, null, '18丁目', '18チョウメ');
INSERT INTO `ms_addresses` VALUES ('64693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南1条西19丁目', '01', '01101', '0600061', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南1条西', 'ミナミ01ジョウニシ', null, null, '19丁目', '19チョウメ');
INSERT INTO `ms_addresses` VALUES ('64694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南2条西1丁目', '01', '01101', '0600062', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南2条西', 'ミナミ02ジョウニシ', null, null, '1丁目', '01チョウメ');
INSERT INTO `ms_addresses` VALUES ('64695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南2条西2丁目', '01', '01101', '0600062', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南2条西', 'ミナミ02ジョウニシ', null, null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('64696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南2条西3丁目', '01', '01101', '0600062', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南2条西', 'ミナミ02ジョウニシ', null, null, '3丁目', '03チョウメ');
INSERT INTO `ms_addresses` VALUES ('64697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南2条西4丁目', '01', '01101', '0600062', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南2条西', 'ミナミ02ジョウニシ', null, null, '4丁目', '04チョウメ');
INSERT INTO `ms_addresses` VALUES ('64698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南2条西5丁目', '01', '01101', '0600062', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南2条西', 'ミナミ02ジョウニシ', null, null, '5丁目', '05チョウメ');
INSERT INTO `ms_addresses` VALUES ('64699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南2条西6丁目', '01', '01101', '0600062', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南2条西', 'ミナミ02ジョウニシ', null, null, '6丁目', '06チョウメ');
INSERT INTO `ms_addresses` VALUES ('64700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南2条西7丁目', '01', '01101', '0600062', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南2条西', 'ミナミ02ジョウニシ', null, null, '7丁目', '07チョウメ');
INSERT INTO `ms_addresses` VALUES ('64701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南2条西8丁目', '01', '01101', '0600062', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南2条西', 'ミナミ02ジョウニシ', null, null, '8丁目', '08チョウメ');
INSERT INTO `ms_addresses` VALUES ('64702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南2条西9丁目', '01', '01101', '0600062', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南2条西', 'ミナミ02ジョウニシ', null, null, '9丁目', '09チョウメ');
INSERT INTO `ms_addresses` VALUES ('64703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南2条西10丁目', '01', '01101', '0600062', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南2条西', 'ミナミ02ジョウニシ', null, null, '10丁目', '10チョウメ');
INSERT INTO `ms_addresses` VALUES ('64704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南2条西11丁目', '01', '01101', '0600062', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南2条西', 'ミナミ02ジョウニシ', null, null, '11丁目', '11チョウメ');
INSERT INTO `ms_addresses` VALUES ('64705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南2条西12丁目', '01', '01101', '0600062', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南2条西', 'ミナミ02ジョウニシ', null, null, '12丁目', '12チョウメ');
INSERT INTO `ms_addresses` VALUES ('64706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南2条西13丁目', '01', '01101', '0600062', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南2条西', 'ミナミ02ジョウニシ', null, null, '13丁目', '13チョウメ');
INSERT INTO `ms_addresses` VALUES ('64707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南2条西14丁目', '01', '01101', '0600062', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南2条西', 'ミナミ02ジョウニシ', null, null, '14丁目', '14チョウメ');
INSERT INTO `ms_addresses` VALUES ('64708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南2条西15丁目', '01', '01101', '0600062', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南2条西', 'ミナミ02ジョウニシ', null, null, '15丁目', '15チョウメ');
INSERT INTO `ms_addresses` VALUES ('64709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南2条西16丁目', '01', '01101', '0600062', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南2条西', 'ミナミ02ジョウニシ', null, null, '16丁目', '16チョウメ');
INSERT INTO `ms_addresses` VALUES ('64710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南2条西17丁目', '01', '01101', '0600062', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南2条西', 'ミナミ02ジョウニシ', null, null, '17丁目', '17チョウメ');
INSERT INTO `ms_addresses` VALUES ('64711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南2条西18丁目', '01', '01101', '0600062', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南2条西', 'ミナミ02ジョウニシ', null, null, '18丁目', '18チョウメ');
INSERT INTO `ms_addresses` VALUES ('64712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南2条西19丁目', '01', '01101', '0600062', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南2条西', 'ミナミ02ジョウニシ', null, null, '19丁目', '19チョウメ');
INSERT INTO `ms_addresses` VALUES ('64713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南3条西1丁目', '01', '01101', '0600063', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南3条西', 'ミナミ03ジョウニシ', null, null, '1丁目', '01チョウメ');
INSERT INTO `ms_addresses` VALUES ('64714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南3条西2丁目', '01', '01101', '0600063', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南3条西', 'ミナミ03ジョウニシ', null, null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('64715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南3条西3丁目', '01', '01101', '0600063', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南3条西', 'ミナミ03ジョウニシ', null, null, '3丁目', '03チョウメ');
INSERT INTO `ms_addresses` VALUES ('64716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南3条西4丁目', '01', '01101', '0600063', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南3条西', 'ミナミ03ジョウニシ', null, null, '4丁目', '04チョウメ');
INSERT INTO `ms_addresses` VALUES ('64717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南3条西5丁目', '01', '01101', '0600063', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南3条西', 'ミナミ03ジョウニシ', null, null, '5丁目', '05チョウメ');
INSERT INTO `ms_addresses` VALUES ('64718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南3条西6丁目', '01', '01101', '0600063', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南3条西', 'ミナミ03ジョウニシ', null, null, '6丁目', '06チョウメ');
INSERT INTO `ms_addresses` VALUES ('64719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南3条西7丁目', '01', '01101', '0600063', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南3条西', 'ミナミ03ジョウニシ', null, null, '7丁目', '07チョウメ');
INSERT INTO `ms_addresses` VALUES ('64720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南3条西8丁目', '01', '01101', '0600063', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南3条西', 'ミナミ03ジョウニシ', null, null, '8丁目', '08チョウメ');
INSERT INTO `ms_addresses` VALUES ('64721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南3条西9丁目', '01', '01101', '0600063', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南3条西', 'ミナミ03ジョウニシ', null, null, '9丁目', '09チョウメ');
INSERT INTO `ms_addresses` VALUES ('64722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南3条西10丁目', '01', '01101', '0600063', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南3条西', 'ミナミ03ジョウニシ', null, null, '10丁目', '10チョウメ');
INSERT INTO `ms_addresses` VALUES ('64723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南3条西11丁目', '01', '01101', '0600063', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南3条西', 'ミナミ03ジョウニシ', null, null, '11丁目', '11チョウメ');
INSERT INTO `ms_addresses` VALUES ('64724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南3条西12丁目', '01', '01101', '0600063', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南3条西', 'ミナミ03ジョウニシ', null, null, '12丁目', '12チョウメ');
INSERT INTO `ms_addresses` VALUES ('64725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南3条西13丁目', '01', '01101', '0600063', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南3条西', 'ミナミ03ジョウニシ', null, null, '13丁目', '13チョウメ');
INSERT INTO `ms_addresses` VALUES ('64726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南3条西14丁目', '01', '01101', '0600063', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南3条西', 'ミナミ03ジョウニシ', null, null, '14丁目', '14チョウメ');
INSERT INTO `ms_addresses` VALUES ('64727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南3条西15丁目', '01', '01101', '0600063', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南3条西', 'ミナミ03ジョウニシ', null, null, '15丁目', '15チョウメ');
INSERT INTO `ms_addresses` VALUES ('64728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南3条西16丁目', '01', '01101', '0600063', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南3条西', 'ミナミ03ジョウニシ', null, null, '16丁目', '16チョウメ');
INSERT INTO `ms_addresses` VALUES ('64729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南3条西17丁目', '01', '01101', '0600063', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南3条西', 'ミナミ03ジョウニシ', null, null, '17丁目', '17チョウメ');
INSERT INTO `ms_addresses` VALUES ('64730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南3条西18丁目', '01', '01101', '0600063', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南3条西', 'ミナミ03ジョウニシ', null, null, '18丁目', '18チョウメ');
INSERT INTO `ms_addresses` VALUES ('64731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市手稲区西宮の沢', '01', '01109', '0060009', '北海道', 'ホッカイドウ', '札幌市手稲区', 'サッポロシテイネク', '西宮の沢', 'ニシミヤノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市手稲区富丘1条', '01', '01109', '0060011', '北海道', 'ホッカイドウ', '札幌市手稲区', 'サッポロシテイネク', '富丘1条', 'トミオカ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市手稲区富丘2条', '01', '01109', '0060012', '北海道', 'ホッカイドウ', '札幌市手稲区', 'サッポロシテイネク', '富丘2条', 'トミオカ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市手稲区富丘3条', '01', '01109', '0060013', '北海道', 'ホッカイドウ', '札幌市手稲区', 'サッポロシテイネク', '富丘3条', 'トミオカ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市手稲区富丘4条', '01', '01109', '0060014', '北海道', 'ホッカイドウ', '札幌市手稲区', 'サッポロシテイネク', '富丘4条', 'トミオカ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市手稲区富丘5条', '01', '01109', '0060015', '北海道', 'ホッカイドウ', '札幌市手稲区', 'サッポロシテイネク', '富丘5条', 'トミオカ05ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市手稲区富丘6条', '01', '01109', '0060016', '北海道', 'ホッカイドウ', '札幌市手稲区', 'サッポロシテイネク', '富丘6条', 'トミオカ06ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市手稲区手稲富丘', '01', '01109', '0060019', '北海道', 'ホッカイドウ', '札幌市手稲区', 'サッポロシテイネク', '手稲富丘', 'テイネトミオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市手稲区手稲本町1条', '01', '01109', '0060021', '北海道', 'ホッカイドウ', '札幌市手稲区', 'サッポロシテイネク', '手稲本町1条', 'テイネホンチョウ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市手稲区手稲本町2条', '01', '01109', '0060022', '北海道', 'ホッカイドウ', '札幌市手稲区', 'サッポロシテイネク', '手稲本町2条', 'テイネホンチョウ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市手稲区手稲本町3条', '01', '01109', '0060023', '北海道', 'ホッカイドウ', '札幌市手稲区', 'サッポロシテイネク', '手稲本町3条', 'テイネホンチョウ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市手稲区手稲本町4条', '01', '01109', '0060024', '北海道', 'ホッカイドウ', '札幌市手稲区', 'サッポロシテイネク', '手稲本町4条', 'テイネホンチョウ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市手稲区手稲本町5条', '01', '01109', '0060025', '北海道', 'ホッカイドウ', '札幌市手稲区', 'サッポロシテイネク', '手稲本町5条', 'テイネホンチョウ05ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市手稲区手稲本町6条', '01', '01109', '0060026', '北海道', 'ホッカイドウ', '札幌市手稲区', 'サッポロシテイネク', '手稲本町6条', 'テイネホンチョウ06ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市手稲区手稲本町', '01', '01109', '0060029', '北海道', 'ホッカイドウ', '札幌市手稲区', 'サッポロシテイネク', '手稲本町', 'テイネホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市手稲区稲穂1条', '01', '01109', '0060031', '北海道', 'ホッカイドウ', '札幌市手稲区', 'サッポロシテイネク', '稲穂1条', 'イナホ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市手稲区稲穂2条', '01', '01109', '0060032', '北海道', 'ホッカイドウ', '札幌市手稲区', 'サッポロシテイネク', '稲穂2条', 'イナホ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市手稲区稲穂3条', '01', '01109', '0060033', '北海道', 'ホッカイドウ', '札幌市手稲区', 'サッポロシテイネク', '稲穂3条', 'イナホ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市手稲区稲穂4条', '01', '01109', '0060034', '北海道', 'ホッカイドウ', '札幌市手稲区', 'サッポロシテイネク', '稲穂4条', 'イナホ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市手稲区稲穂5条', '01', '01109', '0060035', '北海道', 'ホッカイドウ', '札幌市手稲区', 'サッポロシテイネク', '稲穂5条', 'イナホ05ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市手稲区手稲稲穂', '01', '01109', '0060039', '北海道', 'ホッカイドウ', '札幌市手稲区', 'サッポロシテイネク', '手稲稲穂', 'テイネイナホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市手稲区金山1条', '01', '01109', '0060041', '北海道', 'ホッカイドウ', '札幌市手稲区', 'サッポロシテイネク', '金山1条', 'カナヤマ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市手稲区金山2条', '01', '01109', '0060042', '北海道', 'ホッカイドウ', '札幌市手稲区', 'サッポロシテイネク', '金山2条', 'カナヤマ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市手稲区金山3条', '01', '01109', '0060043', '北海道', 'ホッカイドウ', '札幌市手稲区', 'サッポロシテイネク', '金山3条', 'カナヤマ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市手稲区手稲金山', '01', '01109', '0060049', '北海道', 'ホッカイドウ', '札幌市手稲区', 'サッポロシテイネク', '手稲金山', 'テイネカナヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市手稲区星置南', '01', '01109', '0060050', '北海道', 'ホッカイドウ', '札幌市手稲区', 'サッポロシテイネク', '星置南', 'ホシオキミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区真町', '26', '26106', '6008001', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '真町', 'シンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区御旅町', '26', '26106', '6008002', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '御旅町', 'オタビチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区御旅宮本町', '26', '26106', '6008003', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '御旅宮本町', 'オタビミヤモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区奈良物町', '26', '26106', '6008004', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '奈良物町', 'ナラモノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区立売東町', '26', '26106', '6008005', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '立売東町', 'タチウリヒガシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区立売中之町', '26', '26106', '6008006', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '立売中之町', 'タチウリナカノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区立売西町', '26', '26106', '6008007', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '立売西町', 'タチウリニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区長刀鉾町', '26', '26106', '6008008', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '長刀鉾町', 'ナギナタボコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区函谷鉾町', '26', '26106', '6008009', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '函谷鉾町', 'カンコボコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区橋本町', '26', '26106', '6008011', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '橋本町', 'ハシモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区斎藤町', '26', '26106', '6008012', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '斎藤町', 'サイトウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区天王町', '26', '26106', '6008013', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '天王町', 'テンノウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区和泉屋町', '26', '26106', '6008014', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '和泉屋町', 'イズミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区美濃屋町', '26', '26106', '6008015', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '美濃屋町', 'ミノヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区材木町木屋町通松原下る', '26', '26106', '6008016', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '材木町', 'ザイモクチョウ', null, '木屋町通松原下る', null, null);
INSERT INTO `ms_addresses` VALUES ('64772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区材木町松原通木屋町東入', '26', '26106', '6008016', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '材木町', 'ザイモクチョウ', null, '松原通木屋町東入', null, null);
INSERT INTO `ms_addresses` VALUES ('64773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区材木町松原通高瀬川筋東入', '26', '26106', '6008016', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '材木町', 'ザイモクチョウ', null, '松原通高瀬川筋東入', null, null);
INSERT INTO `ms_addresses` VALUES ('64774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区下材木町', '26', '26106', '6008017', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '下材木町', 'シモザイモクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区市之町', '26', '26106', '6008018', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '市之町', 'イチノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区船頭町', '26', '26106', '6008019', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '船頭町', 'センドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区御影堂前町', '26', '26106', '6008020', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '御影堂前町', 'ミカゲドウマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区順風町', '26', '26106', '6008021', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '順風町', 'ジュンプウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区稲荷町河原町通四条下る', '26', '26106', '6008022', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '稲荷町', 'イナリチョウ', null, '河原町通四条下る', null, null);
INSERT INTO `ms_addresses` VALUES ('64780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区稲荷町河原町通四条下る2丁目', '26', '26106', '6008022', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '稲荷町', 'イナリチョウ', null, '河原町通四条下る2丁目', null, null);
INSERT INTO `ms_addresses` VALUES ('64781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区富永町河原町通四条下る2丁目', '26', '26106', '6008023', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '富永町', 'トミナガチョウ', null, '河原町通四条下る2丁目', null, null);
INSERT INTO `ms_addresses` VALUES ('64782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区富永町河原町通高辻上る', '26', '26106', '6008023', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '富永町', 'トミナガチョウ', null, '河原町通高辻上る', null, null);
INSERT INTO `ms_addresses` VALUES ('64783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区富永町河原町通仏光寺下る', '26', '26106', '6008023', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '富永町', 'トミナガチョウ', null, '河原町通仏光寺下る', null, null);
INSERT INTO `ms_addresses` VALUES ('64784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区富永町河原町通松原上る', '26', '26106', '6008023', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '富永町', 'トミナガチョウ', null, '河原町通松原上る', null, null);
INSERT INTO `ms_addresses` VALUES ('64785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区富永町河原町通松原上る2丁目', '26', '26106', '6008023', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '富永町', 'トミナガチョウ', null, '河原町通松原上る2丁目', null, null);
INSERT INTO `ms_addresses` VALUES ('64786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区富永町高辻通河原町西入', '26', '26106', '6008023', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '富永町', 'トミナガチョウ', null, '高辻通河原町西入', null, null);
INSERT INTO `ms_addresses` VALUES ('64787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区富永町仏光寺通河原町西入', '26', '26106', '6008023', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '富永町', 'トミナガチョウ', null, '仏光寺通河原町西入', null, null);
INSERT INTO `ms_addresses` VALUES ('64788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区天満町', '26', '26106', '6008024', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '天満町', 'テンマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区清水町河原町通高辻下る', '26', '26106', '6008025', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '清水町', 'シミズチョウ', null, '河原町通高辻下る', null, null);
INSERT INTO `ms_addresses` VALUES ('64790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区清水町河原町通松原上る', '26', '26106', '6008025', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '清水町', 'シミズチョウ', null, '河原町通松原上る', null, null);
INSERT INTO `ms_addresses` VALUES ('64791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区清水町西木屋町通高辻下る', '26', '26106', '6008025', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '清水町', 'シミズチョウ', null, '西木屋町通高辻下る', null, null);
INSERT INTO `ms_addresses` VALUES ('64792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区清水町西木屋町通松原上る', '26', '26106', '6008025', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '清水町', 'シミズチョウ', null, '西木屋町通松原上る', null, null);
INSERT INTO `ms_addresses` VALUES ('64793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区松川町', '26', '26106', '6008026', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '松川町', 'マツカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区難波町', '26', '26106', '6008027', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '難波町', 'ナンバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区植松町河原町通松原下る', '26', '26106', '6008028', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '植松町', 'ウエマツチョウ', null, '河原町通松原下る', null, null);
INSERT INTO `ms_addresses` VALUES ('64796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区植松町河原町通万寿寺上る', '26', '26106', '6008028', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '植松町', 'ウエマツチョウ', null, '河原町通万寿寺上る', null, null);
INSERT INTO `ms_addresses` VALUES ('64797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区植松町寺町通松原下る', '26', '26106', '6008028', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '植松町', 'ウエマツチョウ', null, '寺町通松原下る', null, null);
INSERT INTO `ms_addresses` VALUES ('64798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区植松町寺町通万寿寺上る', '26', '26106', '6008028', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '植松町', 'ウエマツチョウ', null, '寺町通万寿寺上る', null, null);
INSERT INTO `ms_addresses` VALUES ('64799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区植松町松原通寺町西入', '26', '26106', '6008028', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '植松町', 'ウエマツチョウ', null, '松原通寺町西入', null, null);
INSERT INTO `ms_addresses` VALUES ('64800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区植松町松原通寺町東入', '26', '26106', '6008028', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '植松町', 'ウエマツチョウ', null, '松原通寺町東入', null, null);
INSERT INTO `ms_addresses` VALUES ('64801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区植松町万寿寺通河原町西入', '26', '26106', '6008028', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '植松町', 'ウエマツチョウ', null, '万寿寺通河原町西入', null, null);
INSERT INTO `ms_addresses` VALUES ('64802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区植松町万寿寺通寺町西入', '26', '26106', '6008028', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '植松町', 'ウエマツチョウ', null, '万寿寺通寺町西入', null, null);
INSERT INTO `ms_addresses` VALUES ('64803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区西橋詰町', '26', '26106', '6008029', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '西橋詰町', 'ニシハシヅメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区貞安前之町', '26', '26106', '6008031', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '貞安前之町', 'テイアンマエノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区中之町寺町通綾小路下る', '26', '26106', '6008032', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '中之町', 'ナカノチョウ', null, '寺町通綾小路下る', null, null);
INSERT INTO `ms_addresses` VALUES ('64806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区中之町寺町通仏光寺上る', '26', '26106', '6008032', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '中之町', 'ナカノチョウ', null, '寺町通仏光寺上る', null, null);
INSERT INTO `ms_addresses` VALUES ('64807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区中之町仏光寺通寺町西入', '26', '26106', '6008032', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '中之町', 'ナカノチョウ', null, '仏光寺通寺町西入', null, null);
INSERT INTO `ms_addresses` VALUES ('64808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区中之町仏光寺通寺町東入', '26', '26106', '6008032', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '中之町', 'ナカノチョウ', null, '仏光寺通寺町東入', null, null);
INSERT INTO `ms_addresses` VALUES ('64809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区恵美須之町', '26', '26106', '6008033', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '恵美須之町', 'エビスノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区幸竹町', '26', '26106', '6008034', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '幸竹町', 'コウタケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区京極町', '26', '26106', '6008035', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '京極町', 'キョウゴクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区茶磨屋町高辻通御幸町東入', '26', '26106', '6008036', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '茶磨屋町', 'チャマヤチョウ', null, '高辻通御幸町東入', null, null);
INSERT INTO `ms_addresses` VALUES ('64813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区茶磨屋町高辻通寺町西入', '26', '26106', '6008036', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '茶磨屋町', 'チャマヤチョウ', null, '高辻通寺町西入', null, null);
INSERT INTO `ms_addresses` VALUES ('64814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区丸屋町御幸町通綾小路下る', '26', '26106', '6008037', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '丸屋町', 'マルヤチョウ', null, '御幸町通綾小路下る', null, null);
INSERT INTO `ms_addresses` VALUES ('64815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区丸屋町御幸町通仏光寺上る', '26', '26106', '6008037', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '丸屋町', 'マルヤチョウ', null, '御幸町通仏光寺上る', null, null);
INSERT INTO `ms_addresses` VALUES ('64816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区足袋屋町', '26', '26106', '6008038', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '足袋屋町', 'タビヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区大寿町', '26', '26106', '6008039', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '大寿町', 'ダイズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区安土町', '26', '26106', '6008040', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '安土町', 'アヅチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区八文字町', '26', '26106', '6008041', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '八文字町', 'ハチモンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区俵屋町麩屋町通綾小路下る', '26', '26106', '6008042', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '俵屋町', 'タワラヤチョウ', null, '麩屋町通綾小路下る', null, null);
INSERT INTO `ms_addresses` VALUES ('64821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区俵屋町麩屋町通仏光寺上る', '26', '26106', '6008042', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '俵屋町', 'タワラヤチョウ', null, '麩屋町通仏光寺上る', null, null);
INSERT INTO `ms_addresses` VALUES ('64822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区大黒町仏光寺通御幸町西入', '26', '26106', '6008043', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '大黒町', 'ダイコクチョウ', null, '仏光寺通御幸町西入', null, null);
INSERT INTO `ms_addresses` VALUES ('64823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区大黒町仏光寺通御幸町東入', '26', '26106', '6008043', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '大黒町', 'ダイコクチョウ', null, '仏光寺通御幸町東入', null, null);
INSERT INTO `ms_addresses` VALUES ('64824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区大黒町仏光寺通寺町西入', '26', '26106', '6008043', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '大黒町', 'ダイコクチョウ', null, '仏光寺通寺町西入', null, null);
INSERT INTO `ms_addresses` VALUES ('64825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区大黒町仏光寺通麩屋町東入', '26', '26106', '6008043', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '大黒町', 'ダイコクチョウ', null, '仏光寺通麩屋町東入', null, null);
INSERT INTO `ms_addresses` VALUES ('64826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区橘町御幸町通高辻上る', '26', '26106', '6008044', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '橘町', 'タチバナチョウ', null, '御幸町通高辻上る', null, null);
INSERT INTO `ms_addresses` VALUES ('64827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区橘町御幸町通仏光寺下る', '26', '26106', '6008044', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '橘町', 'タチバナチョウ', null, '御幸町通仏光寺下る', null, null);
INSERT INTO `ms_addresses` VALUES ('64828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区橘町高辻通御幸町西入', '26', '26106', '6008044', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '橘町', 'タチバナチョウ', null, '高辻通御幸町西入', null, null);
INSERT INTO `ms_addresses` VALUES ('64829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区橘町高辻通御幸町東入', '26', '26106', '6008044', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '橘町', 'タチバナチョウ', null, '高辻通御幸町東入', null, null);
INSERT INTO `ms_addresses` VALUES ('64830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区茶磨屋町高辻通御幸町西入', '26', '26106', '6008045', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '茶磨屋町', 'チャマヤチョウ', null, '高辻通御幸町西入', null, null);
INSERT INTO `ms_addresses` VALUES ('64831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区茶磨屋町高辻通麩屋町東入', '26', '26106', '6008045', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '茶磨屋町', 'チャマヤチョウ', null, '高辻通麩屋町東入', null, null);
INSERT INTO `ms_addresses` VALUES ('64832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区桝屋町', '26', '26106', '6008046', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '桝屋町', 'マスヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区石不動之町', '26', '26106', '6008047', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '石不動之町', 'イシフドウノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区須浜町', '26', '26106', '6008048', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '須浜町', 'スバマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区堅田町万寿寺通御幸町西入', '26', '26106', '6008049', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '堅田町', 'カタダチョウ', null, '万寿寺通御幸町西入', null, null);
INSERT INTO `ms_addresses` VALUES ('64836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区堅田町万寿寺通富小路東入', '26', '26106', '6008050', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '堅田町', 'カタダチョウ', null, '万寿寺通富小路東入', null, null);
INSERT INTO `ms_addresses` VALUES ('64837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区堅田町万寿寺通麩屋町西入', '26', '26106', '6008050', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '堅田町', 'カタダチョウ', null, '万寿寺通麩屋町西入', null, null);
INSERT INTO `ms_addresses` VALUES ('64838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区徳正寺町', '26', '26106', '6008051', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '徳正寺町', 'トクショウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区塩屋町綾小路通富小路西入', '26', '26106', '6008052', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '塩屋町', 'シオヤチョウ', null, '綾小路通富小路西入', null, null);
INSERT INTO `ms_addresses` VALUES ('64840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区塩屋町綾小路通富小路東入', '26', '26106', '6008052', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '塩屋町', 'シオヤチョウ', null, '綾小路通富小路東入', null, null);
INSERT INTO `ms_addresses` VALUES ('64841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区塩屋町綾小路通麩屋町西入', '26', '26106', '6008052', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '塩屋町', 'シオヤチョウ', null, '綾小路通麩屋町西入', null, null);
INSERT INTO `ms_addresses` VALUES ('64842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区塩屋町綾小路通柳馬場東入', '26', '26106', '6008052', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '塩屋町', 'シオヤチョウ', null, '綾小路通柳馬場東入', null, null);
INSERT INTO `ms_addresses` VALUES ('64843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区塩屋町富小路通綾小路上る', '26', '26106', '6008052', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '塩屋町', 'シオヤチョウ', null, '富小路通綾小路上る', null, null);
INSERT INTO `ms_addresses` VALUES ('64844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区塩屋町富小路通綾小路下る', '26', '26106', '6008052', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '塩屋町', 'シオヤチョウ', null, '富小路通綾小路下る', null, null);
INSERT INTO `ms_addresses` VALUES ('64845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区塩屋町麩屋町通綾小路下る', '26', '26106', '6008052', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '塩屋町', 'シオヤチョウ', null, '麩屋町通綾小路下る', null, null);
INSERT INTO `ms_addresses` VALUES ('64846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区塗師屋町富小路通綾小路下る', '26', '26106', '6008053', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '塗師屋町', 'ヌシヤチョウ', null, '富小路通綾小路下る', null, null);
INSERT INTO `ms_addresses` VALUES ('64847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区塗師屋町富小路通仏光寺上る', '26', '26106', '6008053', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '塗師屋町', 'ヌシヤチョウ', null, '富小路通仏光寺上る', null, null);
INSERT INTO `ms_addresses` VALUES ('64848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区仏光寺東町', '26', '26106', '6008054', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '仏光寺東町', 'ブッコウジヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区鍋屋町', '26', '26106', '6008055', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '鍋屋町', 'ナベヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区雁金町高辻通富小路東入', '26', '26106', '6008056', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '雁金町', 'カリガネチョウ', null, '高辻通富小路東入', null, null);
INSERT INTO `ms_addresses` VALUES ('64851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区雁金町高辻通麩屋町西入', '26', '26106', '6008056', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '雁金町', 'カリガネチョウ', null, '高辻通麩屋町西入', null, null);
INSERT INTO `ms_addresses` VALUES ('64852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区鍵屋町高辻通麩屋町西入', '26', '26106', '6008057', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '鍵屋町', 'カギヤチョウ', null, '高辻通麩屋町西入', null, null);
INSERT INTO `ms_addresses` VALUES ('64853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区鍵屋町高辻通麩屋町東入', '26', '26106', '6008057', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '鍵屋町', 'カギヤチョウ', null, '高辻通麩屋町東入', null, null);
INSERT INTO `ms_addresses` VALUES ('64854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区鍵屋町麩屋町通高辻下る', '26', '26106', '6008057', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '鍵屋町', 'カギヤチョウ', null, '麩屋町通高辻下る', null, null);
INSERT INTO `ms_addresses` VALUES ('64855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区鍵屋町麩屋町通松原上る', '26', '26106', '6008057', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '鍵屋町', 'カギヤチョウ', null, '麩屋町通松原上る', null, null);
INSERT INTO `ms_addresses` VALUES ('64856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区上鱗形町', '26', '26106', '6008058', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '上鱗形町', 'カミウロコガタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区下鱗形町', '26', '26106', '6008059', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '下鱗形町', 'シモウロコガタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北6条西', '01', '01102', '0600806', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北6条西', 'キタ06ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区雁金町高辻通富小路西入', '26', '26106', '6008060', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '雁金町', 'カリガネチョウ', null, '高辻通富小路西入', null, null);
INSERT INTO `ms_addresses` VALUES ('64860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区雁金町高辻通柳馬場東入', '26', '26106', '6008060', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '雁金町', 'カリガネチョウ', null, '高辻通柳馬場東入', null, null);
INSERT INTO `ms_addresses` VALUES ('64861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区筋屋町', '26', '26106', '6008061', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '筋屋町', 'スジヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区恵美須屋町', '26', '26106', '6008062', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '恵美須屋町', 'エビスヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区松原中之町', '26', '26106', '6008063', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '松原中之町', 'マツバラナカノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区本上神明町', '26', '26106', '6008064', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '本上神明町', 'モトカミシンメイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区本神明町', '26', '26106', '6008065', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '本神明町', 'モトシンメイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区柏屋町万寿寺通柳馬場西入', '26', '26106', '6008066', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '柏屋町', 'カシワヤチョウ', null, '万寿寺通柳馬場西入', null, null);
INSERT INTO `ms_addresses` VALUES ('64867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区柏屋町柳馬場通五条上る', '26', '26106', '6008066', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '柏屋町', 'カシワヤチョウ', null, '柳馬場通五条上る', null, null);
INSERT INTO `ms_addresses` VALUES ('64868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区柏屋町柳馬場通万寿寺下る', '26', '26106', '6008066', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '柏屋町', 'カシワヤチョウ', null, '柳馬場通万寿寺下る', null, null);
INSERT INTO `ms_addresses` VALUES ('64869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区堅田町万寿寺通堺町東入', '26', '26106', '6008067', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '堅田町', 'カタダチョウ', null, '万寿寺通堺町東入', null, null);
INSERT INTO `ms_addresses` VALUES ('64870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区堅田町万寿寺通富小路西入', '26', '26106', '6008067', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '堅田町', 'カタダチョウ', null, '万寿寺通富小路西入', null, null);
INSERT INTO `ms_addresses` VALUES ('64871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区堅田町万寿寺通柳馬場西入', '26', '26106', '6008067', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '堅田町', 'カタダチョウ', null, '万寿寺通柳馬場西入', null, null);
INSERT INTO `ms_addresses` VALUES ('64872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区堅田町万寿寺通柳馬場東入', '26', '26106', '6008067', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '堅田町', 'カタダチョウ', null, '万寿寺通柳馬場東入', null, null);
INSERT INTO `ms_addresses` VALUES ('64873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区堅田町柳馬場通万寿寺上る', '26', '26106', '6008067', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '堅田町', 'カタダチョウ', null, '柳馬場通万寿寺上る', null, null);
INSERT INTO `ms_addresses` VALUES ('64874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区忠庵町', '26', '26106', '6008068', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '忠庵町', 'チュウアンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区吉文字町高辻通柳馬場西入', '26', '26106', '6008069', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '吉文字町', 'キチモンジチョウ', null, '高辻通柳馬場西入', null, null);
INSERT INTO `ms_addresses` VALUES ('64876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区吉文字町高辻通柳馬場東入', '26', '26106', '6008069', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '吉文字町', 'キチモンジチョウ', null, '高辻通柳馬場東入', null, null);
INSERT INTO `ms_addresses` VALUES ('64877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区吉文字町柳馬場通高辻下る', '26', '26106', '6008069', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '吉文字町', 'キチモンジチョウ', null, '柳馬場通高辻下る', null, null);
INSERT INTO `ms_addresses` VALUES ('64878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区吉文字町柳馬場通松原上る', '26', '26106', '6008069', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '吉文字町', 'キチモンジチョウ', null, '柳馬場通松原上る', null, null);
INSERT INTO `ms_addresses` VALUES ('64879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北7条西', '01', '01102', '0600807', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北7条西', 'キタ07ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区俵屋町堺町通万寿寺下る', '26', '26106', '6008070', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '俵屋町', 'タワラヤチョウ', null, '堺町通万寿寺下る', null, null);
INSERT INTO `ms_addresses` VALUES ('64881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区俵屋町万寿寺通堺町西入', '26', '26106', '6008070', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '俵屋町', 'タワラヤチョウ', null, '万寿寺通堺町西入', null, null);
INSERT INTO `ms_addresses` VALUES ('64882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区俵屋町万寿寺通堺町東入', '26', '26106', '6008070', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '俵屋町', 'タワラヤチョウ', null, '万寿寺通堺町東入', null, null);
INSERT INTO `ms_addresses` VALUES ('64883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区俵屋町五条通堺町上る', '26', '26106', '6008070', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '俵屋町', 'タワラヤチョウ', null, '五条通堺町上る', null, null);
INSERT INTO `ms_addresses` VALUES ('64884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区相之町', '26', '26106', '6008071', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '相之町', 'アイノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区綾材木町', '26', '26106', '6008072', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '綾材木町', 'アヤザイモクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区永原町', '26', '26106', '6008073', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '永原町', 'ナガハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区東前町', '26', '26106', '6008074', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '東前町', 'ヒガシマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区万里小路町', '26', '26106', '6008075', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '万里小路町', 'マリコウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区泉正寺町', '26', '26106', '6008076', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '泉正寺町', 'センショウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区夕顔町', '26', '26106', '6008077', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '夕顔町', 'ユウガオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区杉屋町', '26', '26106', '6008078', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '杉屋町', 'スギヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区鍛冶屋町堺町通松原下る', '26', '26106', '6008079', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '鍛冶屋町', 'カジヤチョウ', null, '堺町通松原下る', null, null);
INSERT INTO `ms_addresses` VALUES ('64893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区鍛冶屋町堺町通万寿寺上る', '26', '26106', '6008079', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '鍛冶屋町', 'カジヤチョウ', null, '堺町通万寿寺上る', null, null);
INSERT INTO `ms_addresses` VALUES ('64894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区鍛冶屋町万寿寺通堺町東入', '26', '26106', '6008079', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '鍛冶屋町', 'カジヤチョウ', null, '万寿寺通堺町東入', null, null);
INSERT INTO `ms_addresses` VALUES ('64895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北8条西', '01', '01102', '0600808', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北8条西', 'キタ08ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区小石町', '26', '26106', '6008081', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '小石町', 'コイシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区高材木町', '26', '26106', '6008082', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '高材木町', 'タカザイモクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区西前町', '26', '26106', '6008083', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '西前町', 'ニシマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区新開町', '26', '26106', '6008084', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '新開町', 'シンカイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区葛籠屋町', '26', '26106', '6008085', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '葛籠屋町', 'ツヅラヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区本燈籠町', '26', '26106', '6008086', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '本燈籠町', 'ホントウロウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区樋之下町', '26', '26106', '6008087', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '樋之下町', 'ヒノシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区官社殿町', '26', '26106', '6008088', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '官社殿町', 'カンシャデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区堅田町万寿寺通堺町西入', '26', '26106', '6008089', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '堅田町', 'カタダチョウ', null, '万寿寺通堺町西入', null, null);
INSERT INTO `ms_addresses` VALUES ('64905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北9条西', '01', '01102', '0600809', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北9条西', 'キタ09ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区竹屋之町', '26', '26106', '6008090', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '竹屋之町', 'タケヤノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区元悪王子町', '26', '26106', '6008091', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '元悪王子町', 'モトアクオウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区神明町', '26', '26106', '6008092', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '神明町', 'シンメイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区竹屋町高倉通綾小路下る', '26', '26106', '6008093', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '竹屋町', 'タケヤチョウ', null, '高倉通綾小路下る', null, null);
INSERT INTO `ms_addresses` VALUES ('64910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区竹屋町高倉通仏光寺上る', '26', '26106', '6008093', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '竹屋町', 'タケヤチョウ', null, '高倉通仏光寺上る', null, null);
INSERT INTO `ms_addresses` VALUES ('64911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区竹屋町堺町通綾小路下る西入', '26', '26106', '6008093', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '竹屋町', 'タケヤチョウ', null, '堺町通綾小路下る西入', null, null);
INSERT INTO `ms_addresses` VALUES ('64912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区仏光寺西町', '26', '26106', '6008094', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '仏光寺西町', 'ブッコウジニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区扇酒屋町', '26', '26106', '6008095', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '扇酒屋町', 'オウギサカヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区高橋町', '26', '26106', '6008096', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '高橋町', 'タカハシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区三軒町', '26', '26106', '6008097', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '三軒町', 'サンゲンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区稲荷町間之町通高辻下る', '26', '26106', '6008098', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '稲荷町', 'イナリチョウ', null, '間之町通高辻下る', null, null);
INSERT INTO `ms_addresses` VALUES ('64917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区稲荷町間之町通松原上る', '26', '26106', '6008098', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '稲荷町', 'イナリチョウ', null, '間之町通松原上る', null, null);
INSERT INTO `ms_addresses` VALUES ('64918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区稲荷町高辻通間之町西入', '26', '26106', '6008098', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '稲荷町', 'イナリチョウ', null, '高辻通間之町西入', null, null);
INSERT INTO `ms_addresses` VALUES ('64919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区稲荷町高辻通間之町東入', '26', '26106', '6008098', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '稲荷町', 'イナリチョウ', null, '高辻通間之町東入', null, null);
INSERT INTO `ms_addresses` VALUES ('64920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区稲荷町高辻通東洞院東入', '26', '26106', '6008098', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '稲荷町', 'イナリチョウ', null, '高辻通東洞院東入', null, null);
INSERT INTO `ms_addresses` VALUES ('64921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区上柳町仏光寺通烏丸東入', '26', '26106', '6008099', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '上柳町', 'カミヤナギチョウ', null, '仏光寺通烏丸東入', null, null);
INSERT INTO `ms_addresses` VALUES ('64922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区上柳町仏光寺通烏丸東入上る', '26', '26106', '6008099', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '上柳町', 'カミヤナギチョウ', null, '仏光寺通烏丸東入上る', null, null);
INSERT INTO `ms_addresses` VALUES ('64923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区上柳町仏光寺通烏丸東入下る', '26', '26106', '6008099', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '上柳町', 'カミヤナギチョウ', null, '仏光寺通烏丸東入下る', null, null);
INSERT INTO `ms_addresses` VALUES ('64924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区上柳町仏光寺通東洞院西入', '26', '26106', '6008099', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '上柳町', 'カミヤナギチョウ', null, '仏光寺通東洞院西入', null, null);
INSERT INTO `ms_addresses` VALUES ('64925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北10条西5丁目', '01', '01102', '0600810', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北10条西', 'キタ10ジョウニシ', null, null, '5丁目', '05チョウメ');
INSERT INTO `ms_addresses` VALUES ('64926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北10条西6丁目', '01', '01102', '0600810', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北10条西', 'キタ10ジョウニシ', null, null, '6丁目', '06チョウメ');
INSERT INTO `ms_addresses` VALUES ('64927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北10条西7丁目', '01', '01102', '0600810', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北10条西', 'キタ10ジョウニシ', null, null, '7丁目', '07チョウメ');
INSERT INTO `ms_addresses` VALUES ('64928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北10条西8丁目', '01', '01102', '0600810', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北10条西', 'キタ10ジョウニシ', null, null, '8丁目', '08チョウメ');
INSERT INTO `ms_addresses` VALUES ('64929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北10条西9丁目', '01', '01102', '0600810', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北10条西', 'キタ10ジョウニシ', null, null, '9丁目', '09チョウメ');
INSERT INTO `ms_addresses` VALUES ('64930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北10条西10丁目', '01', '01102', '0600810', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北10条西', 'キタ10ジョウニシ', null, null, '10丁目', '10チョウメ');
INSERT INTO `ms_addresses` VALUES ('64931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北10条西11丁目', '01', '01102', '0600810', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北10条西', 'キタ10ジョウニシ', null, null, '11丁目', '11チョウメ');
INSERT INTO `ms_addresses` VALUES ('64932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区御影堂町', '26', '26106', '6008101', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '御影堂町', 'ミエイドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区本覚寺前町', '26', '26106', '6008102', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '本覚寺前町', 'ホンガクジマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区塩竈町', '26', '26106', '6008103', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '塩竈町', 'シオガマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区万寿寺町', '26', '26106', '6008104', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '万寿寺町', 'マンジュウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区松屋町', '26', '26106', '6008105', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '松屋町', 'マツヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区醍醐町', '26', '26106', '6008106', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '醍醐町', 'ダイゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区東錺屋町', '26', '26106', '6008107', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '東錺屋町', 'ヒガシカザリヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区西錺屋町', '26', '26106', '6008108', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '西錺屋町', 'ニシカザリヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区平屋町', '26', '26106', '6008109', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '平屋町', 'ヒラヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北11条西5丁目', '01', '01102', '0600811', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北11条西', 'キタ11ジョウニシ', null, null, '5丁目', '05チョウメ');
INSERT INTO `ms_addresses` VALUES ('64942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区南橋詰町', '26', '26106', '6008110', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '南橋詰町', 'ミナミハシヅメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北11条西6丁目', '01', '01102', '0600811', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北11条西', 'キタ11ジョウニシ', null, null, '6丁目', '06チョウメ');
INSERT INTO `ms_addresses` VALUES ('64944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北11条西7丁目', '01', '01102', '0600811', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北11条西', 'キタ11ジョウニシ', null, null, '7丁目', '07チョウメ');
INSERT INTO `ms_addresses` VALUES ('64945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北11条西8丁目', '01', '01102', '0600811', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北11条西', 'キタ11ジョウニシ', null, null, '8丁目', '08チョウメ');
INSERT INTO `ms_addresses` VALUES ('64946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北11条西9丁目', '01', '01102', '0600811', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北11条西', 'キタ11ジョウニシ', null, null, '9丁目', '09チョウメ');
INSERT INTO `ms_addresses` VALUES ('64947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北11条西10丁目', '01', '01102', '0600811', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北11条西', 'キタ11ジョウニシ', null, null, '10丁目', '10チョウメ');
INSERT INTO `ms_addresses` VALUES ('64948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北11条西11丁目', '01', '01102', '0600811', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北11条西', 'キタ11ジョウニシ', null, null, '11丁目', '11チョウメ');
INSERT INTO `ms_addresses` VALUES ('64949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区都市町', '26', '26106', '6008111', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '都市町', 'トイチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区八ツ柳町', '26', '26106', '6008112', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '八ツ柳町', 'ヤツヤナギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区波止土濃町', '26', '26106', '6008113', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '波止土濃町', 'ハシドノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区早尾町', '26', '26106', '6008114', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '早尾町', 'ハヤオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区岩滝町', '26', '26106', '6008115', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '岩滝町', 'イワタキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区聖真子町', '26', '26106', '6008116', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '聖真子町', 'ショウシンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区南京極町', '26', '26106', '6008117', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '南京極町', 'ミナミキョウゴクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区平居町', '26', '26106', '6008118', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '平居町', 'ヒライチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区本塩竈町', '26', '26106', '6008119', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '本塩竈町', 'モトシオガマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北12条西5丁目', '01', '01102', '0600812', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北12条西', 'キタ12ジョウニシ', null, null, '5丁目', '05チョウメ');
INSERT INTO `ms_addresses` VALUES ('64959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区若宮町上ノ口通河原町西入', '26', '26106', '6008120', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '若宮町', 'ワカミヤチョウ', null, '上ノ口通河原町西入', null, null);
INSERT INTO `ms_addresses` VALUES ('64960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区若宮町上ノ口通河原町西入下る', '26', '26106', '6008120', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '若宮町', 'ワカミヤチョウ', null, '上ノ口通河原町西入下る', null, null);
INSERT INTO `ms_addresses` VALUES ('64961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区若宮町河原町通上枳殻馬場上る', '26', '26106', '6008120', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '若宮町', 'ワカミヤチョウ', null, '河原町通上枳殻馬場上る', null, null);
INSERT INTO `ms_addresses` VALUES ('64962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区若宮町河原町通上ノ口下る', '26', '26106', '6008120', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '若宮町', 'ワカミヤチョウ', null, '河原町通上ノ口下る', null, null);
INSERT INTO `ms_addresses` VALUES ('64963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区若宮町河原町通正面上る', '26', '26106', '6008120', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '若宮町', 'ワカミヤチョウ', null, '河原町通正面上る', null, null);
INSERT INTO `ms_addresses` VALUES ('64964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北12条西6丁目', '01', '01102', '0600812', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北12条西', 'キタ12ジョウニシ', null, null, '6丁目', '06チョウメ');
INSERT INTO `ms_addresses` VALUES ('64965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北12条西7丁目', '01', '01102', '0600812', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北12条西', 'キタ12ジョウニシ', null, null, '7丁目', '07チョウメ');
INSERT INTO `ms_addresses` VALUES ('64966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北12条西8丁目', '01', '01102', '0600812', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北12条西', 'キタ12ジョウニシ', null, null, '8丁目', '08チョウメ');
INSERT INTO `ms_addresses` VALUES ('64967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北12条西9丁目', '01', '01102', '0600812', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北12条西', 'キタ12ジョウニシ', null, null, '9丁目', '09チョウメ');
INSERT INTO `ms_addresses` VALUES ('64968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北12条西10丁目', '01', '01102', '0600812', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北12条西', 'キタ12ジョウニシ', null, null, '10丁目', '10チョウメ');
INSERT INTO `ms_addresses` VALUES ('64969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北12条西11丁目', '01', '01102', '0600812', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北12条西', 'キタ12ジョウニシ', null, null, '11丁目', '11チョウメ');
INSERT INTO `ms_addresses` VALUES ('64970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北12条西12丁目', '01', '01102', '0600812', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北12条西', 'キタ12ジョウニシ', null, null, '12丁目', '12チョウメ');
INSERT INTO `ms_addresses` VALUES ('64971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区菊屋町上ノ口通加茂川筋西入', '26', '26106', '6008121', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '菊屋町', 'キクヤチョウ', null, '上ノ口通加茂川筋西入', null, null);
INSERT INTO `ms_addresses` VALUES ('64972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区菊屋町上ノ口通加茂川筋西入上る', '26', '26106', '6008121', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '菊屋町', 'キクヤチョウ', null, '上ノ口通加茂川筋西入上る', null, null);
INSERT INTO `ms_addresses` VALUES ('64973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区菊屋町加茂川筋上ノ口下る', '26', '26106', '6008121', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '菊屋町', 'キクヤチョウ', null, '加茂川筋上ノ口下る', null, null);
INSERT INTO `ms_addresses` VALUES ('64974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区菊屋町上ノ口通二ノ宮西入', '26', '26106', '6008121', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '菊屋町', 'キクヤチョウ', null, '上ノ口通二ノ宮西入', null, null);
INSERT INTO `ms_addresses` VALUES ('64975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区菊屋町二ノ宮通上ノ口下る', '26', '26106', '6008121', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '菊屋町', 'キクヤチョウ', null, '二ノ宮通上ノ口下る', null, null);
INSERT INTO `ms_addresses` VALUES ('64976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区平岡町', '26', '26106', '6008122', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '平岡町', 'ヒラオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区高宮町', '26', '26106', '6008123', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '高宮町', 'タカミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区富松町', '26', '26106', '6008124', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '富松町', 'トミマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区富浜町', '26', '26106', '6008125', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '富浜町', 'トミハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区鍵屋町正面通木屋町東入', '26', '26106', '6008126', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '鍵屋町', 'カギヤチョウ', null, '正面通木屋町東入', null, null);
INSERT INTO `ms_addresses` VALUES ('64981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区鍵屋町加茂川筋正面上る', '26', '26106', '6008126', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '鍵屋町', 'カギヤチョウ', null, '加茂川筋正面上る', null, null);
INSERT INTO `ms_addresses` VALUES ('64982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区鍵屋町正面通二ノ宮西入', '26', '26106', '6008126', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '鍵屋町', 'カギヤチョウ', null, '正面通二ノ宮西入', null, null);
INSERT INTO `ms_addresses` VALUES ('64983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区鍵屋町木屋町通正面上る', '26', '26106', '6008126', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '鍵屋町', 'カギヤチョウ', null, '木屋町通正面上る', null, null);
INSERT INTO `ms_addresses` VALUES ('64984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区鍵屋町正面通二ノ宮東入', '26', '26106', '6008126', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '鍵屋町', 'カギヤチョウ', null, '正面通二ノ宮東入', null, null);
INSERT INTO `ms_addresses` VALUES ('64985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区鍵屋町正面通加茂川筋西入', '26', '26106', '6008126', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '鍵屋町', 'カギヤチョウ', null, '正面通加茂川筋西入', null, null);
INSERT INTO `ms_addresses` VALUES ('64986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区鍵屋町二ノ宮通正面上る', '26', '26106', '6008126', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '鍵屋町', 'カギヤチョウ', null, '二ノ宮通正面上る', null, null);
INSERT INTO `ms_addresses` VALUES ('64987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区梅湊町', '26', '26106', '6008127', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '梅湊町', 'ウメミナトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区大工町上ノ口通河原町東入', '26', '26106', '6008128', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '大工町', 'ダイクチョウ', null, '上ノ口通河原町東入', null, null);
INSERT INTO `ms_addresses` VALUES ('64989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区大工町上ノ口通土手町西入', '26', '26106', '6008128', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '大工町', 'ダイクチョウ', null, '上ノ口通土手町西入', null, null);
INSERT INTO `ms_addresses` VALUES ('64990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区大工町上ノ口通土手町東入', '26', '26106', '6008128', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '大工町', 'ダイクチョウ', null, '上ノ口通土手町東入', null, null);
INSERT INTO `ms_addresses` VALUES ('64991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区大工町上ノ口通西木屋町西入', '26', '26106', '6008128', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '大工町', 'ダイクチョウ', null, '上ノ口通西木屋町西入', null, null);
INSERT INTO `ms_addresses` VALUES ('64992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区大工町河原町通上ノ口上る', '26', '26106', '6008128', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '大工町', 'ダイクチョウ', null, '河原町通上ノ口上る', null, null);
INSERT INTO `ms_addresses` VALUES ('64993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区大工町河原町通上ノ口下る', '26', '26106', '6008128', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '大工町', 'ダイクチョウ', null, '河原町通上ノ口下る', null, null);
INSERT INTO `ms_addresses` VALUES ('64994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区大工町河原町通六条下る', '26', '26106', '6008128', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '大工町', 'ダイクチョウ', null, '河原町通六条下る', null, null);
INSERT INTO `ms_addresses` VALUES ('64995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区大工町土手町通上ノ口下る', '26', '26106', '6008128', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '大工町', 'ダイクチョウ', null, '土手町通上ノ口下る', null, null);
INSERT INTO `ms_addresses` VALUES ('64996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区大工町土手町通正面上る', '26', '26106', '6008128', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '大工町', 'ダイクチョウ', null, '土手町通正面上る', null, null);
INSERT INTO `ms_addresses` VALUES ('64997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区大工町上枳殻馬場通河原町東入', '26', '26106', '6008128', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '大工町', 'ダイクチョウ', null, '上枳殻馬場通河原町東入', null, null);
INSERT INTO `ms_addresses` VALUES ('64998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区溜池町', '26', '26106', '6008129', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '溜池町', 'タメイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('64999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北13条西5丁目', '01', '01102', '0600813', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北13条西', 'キタ13ジョウニシ', null, null, '5丁目', '05チョウメ');
INSERT INTO `ms_addresses` VALUES ('65000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区紺屋町', '26', '26106', '6008130', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '紺屋町', 'コンヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北13条西6丁目', '01', '01102', '0600813', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北13条西', 'キタ13ジョウニシ', null, null, '6丁目', '06チョウメ');
INSERT INTO `ms_addresses` VALUES ('65002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北13条西7丁目', '01', '01102', '0600813', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北13条西', 'キタ13ジョウニシ', null, null, '7丁目', '07チョウメ');
INSERT INTO `ms_addresses` VALUES ('65003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北13条西8丁目', '01', '01102', '0600813', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北13条西', 'キタ13ジョウニシ', null, null, '8丁目', '08チョウメ');
INSERT INTO `ms_addresses` VALUES ('65004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北13条西9丁目', '01', '01102', '0600813', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北13条西', 'キタ13ジョウニシ', null, null, '9丁目', '09チョウメ');
INSERT INTO `ms_addresses` VALUES ('65005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北13条西10丁目', '01', '01102', '0600813', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北13条西', 'キタ13ジョウニシ', null, null, '10丁目', '10チョウメ');
INSERT INTO `ms_addresses` VALUES ('65006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北13条西11丁目', '01', '01102', '0600813', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北13条西', 'キタ13ジョウニシ', null, null, '11丁目', '11チョウメ');
INSERT INTO `ms_addresses` VALUES ('65007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北13条西12丁目', '01', '01102', '0600813', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北13条西', 'キタ13ジョウニシ', null, null, '12丁目', '12チョウメ');
INSERT INTO `ms_addresses` VALUES ('65008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区上二之宮町', '26', '26106', '6008131', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '上二之宮町', 'カミニノミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区下二之宮町', '26', '26106', '6008132', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '下二之宮町', 'シモニノミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区稲荷町七条通加茂川筋西入', '26', '26106', '6008133', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '稲荷町', 'イナリチョウ', null, '七条通加茂川筋西入', null, null);
INSERT INTO `ms_addresses` VALUES ('65011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区稲荷町七条通木屋町東入', '26', '26106', '6008133', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '稲荷町', 'イナリチョウ', null, '七条通木屋町東入', null, null);
INSERT INTO `ms_addresses` VALUES ('65012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区山王町正面通木屋町西入', '26', '26106', '6008134', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '山王町', 'サンノウチョウ', null, '正面通木屋町西入', null, null);
INSERT INTO `ms_addresses` VALUES ('65013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区山王町正面通木屋町東入', '26', '26106', '6008134', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '山王町', 'サンノウチョウ', null, '正面通木屋町東入', null, null);
INSERT INTO `ms_addresses` VALUES ('65014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区山王町正面通三ノ宮西入', '26', '26106', '6008134', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '山王町', 'サンノウチョウ', null, '正面通三ノ宮西入', null, null);
INSERT INTO `ms_addresses` VALUES ('65015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区山王町正面通三ノ宮東入', '26', '26106', '6008134', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '山王町', 'サンノウチョウ', null, '正面通三ノ宮東入', null, null);
INSERT INTO `ms_addresses` VALUES ('65016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区山王町正面通二ノ宮西入', '26', '26106', '6008134', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '山王町', 'サンノウチョウ', null, '正面通二ノ宮西入', null, null);
INSERT INTO `ms_addresses` VALUES ('65017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区上三之宮町', '26', '26106', '6008135', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '上三之宮町', 'カミサンノミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区下三之宮町', '26', '26106', '6008136', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '下三之宮町', 'シモサンノミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区十禅師町', '26', '26106', '6008137', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '十禅師町', 'ジュウゼンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区大宮町', '26', '26106', '6008138', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '大宮町', 'オオミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区八王子町', '26', '26106', '6008139', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '八王子町', 'ハチオウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北14条西5丁目', '01', '01102', '0600814', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北14条西', 'キタ14ジョウニシ', null, null, '5丁目', '05チョウメ');
INSERT INTO `ms_addresses` VALUES ('65023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北14条西6丁目', '01', '01102', '0600814', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北14条西', 'キタ14ジョウニシ', null, null, '6丁目', '06チョウメ');
INSERT INTO `ms_addresses` VALUES ('65024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北14条西7丁目', '01', '01102', '0600814', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北14条西', 'キタ14ジョウニシ', null, null, '7丁目', '07チョウメ');
INSERT INTO `ms_addresses` VALUES ('65025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北14条西8丁目', '01', '01102', '0600814', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北14条西', 'キタ14ジョウニシ', null, null, '8丁目', '08チョウメ');
INSERT INTO `ms_addresses` VALUES ('65026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北14条西9丁目', '01', '01102', '0600814', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北14条西', 'キタ14ジョウニシ', null, null, '9丁目', '09チョウメ');
INSERT INTO `ms_addresses` VALUES ('65027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北14条西10丁目', '01', '01102', '0600814', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北14条西', 'キタ14ジョウニシ', null, null, '10丁目', '10チョウメ');
INSERT INTO `ms_addresses` VALUES ('65028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北14条西11丁目', '01', '01102', '0600814', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北14条西', 'キタ14ジョウニシ', null, null, '11丁目', '11チョウメ');
INSERT INTO `ms_addresses` VALUES ('65029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北14条西12丁目', '01', '01102', '0600814', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北14条西', 'キタ14ジョウニシ', null, null, '12丁目', '12チョウメ');
INSERT INTO `ms_addresses` VALUES ('65030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北14条西13丁目', '01', '01102', '0600814', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北14条西', 'キタ14ジョウニシ', null, null, '13丁目', '13チョウメ');
INSERT INTO `ms_addresses` VALUES ('65031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区新日吉町', '26', '26106', '6008141', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '新日吉町', 'シンヒヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区納屋町', '26', '26106', '6008142', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '納屋町', 'ナヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区住吉町河原町通七条上る', '26', '26106', '6008143', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '住吉町', 'スミヨシチョウ', null, '河原町通七条上る', null, null);
INSERT INTO `ms_addresses` VALUES ('65034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区住吉町河原町通下枳殻馬場下る', '26', '26106', '6008143', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '住吉町', 'スミヨシチョウ', null, '河原町通下枳殻馬場下る', null, null);
INSERT INTO `ms_addresses` VALUES ('65035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区住吉町下枳殻馬場通河原町西入', '26', '26106', '6008143', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '住吉町', 'スミヨシチョウ', null, '下枳殻馬場通河原町西入', null, null);
INSERT INTO `ms_addresses` VALUES ('65036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区住吉町下珠数屋町通高倉東入', '26', '26106', '6008143', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '住吉町', 'スミヨシチョウ', null, '下珠数屋町通高倉東入', null, null);
INSERT INTO `ms_addresses` VALUES ('65037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区塩屋町河原町通七条上る西入', '26', '26106', '6008144', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '塩屋町', 'シオヤチョウ', null, '河原町通七条上る西入', null, null);
INSERT INTO `ms_addresses` VALUES ('65038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区塩屋町七条通河原町西入上る', '26', '26106', '6008144', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '塩屋町', 'シオヤチョウ', null, '七条通河原町西入上る', null, null);
INSERT INTO `ms_addresses` VALUES ('65039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区塩屋町下枳殻馬場通河原町西入下る', '26', '26106', '6008144', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '塩屋町', 'シオヤチョウ', null, '下枳殻馬場通河原町西入下る', null, null);
INSERT INTO `ms_addresses` VALUES ('65040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区皆山町', '26', '26106', '6008145', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '皆山町', 'カイザンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区材木町間之町通七条下る', '26', '26106', '6008146', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '材木町', 'ザイモクチョウ', null, '間之町通七条下る', null, null);
INSERT INTO `ms_addresses` VALUES ('65042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区材木町間之町通七条上る', '26', '26106', '6008146', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '材木町', 'ザイモクチョウ', null, '間之町通七条上る', null, null);
INSERT INTO `ms_addresses` VALUES ('65043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区材木町河原町通七条上る', '26', '26106', '6008146', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '材木町', 'ザイモクチョウ', null, '河原町通七条上る', null, null);
INSERT INTO `ms_addresses` VALUES ('65044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区材木町河原町通七条下る', '26', '26106', '6008146', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '材木町', 'ザイモクチョウ', null, '河原町通七条下る', null, null);
INSERT INTO `ms_addresses` VALUES ('65045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区材木町七条通間之町西入', '26', '26106', '6008146', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '材木町', 'ザイモクチョウ', null, '七条通間之町西入', null, null);
INSERT INTO `ms_addresses` VALUES ('65046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区材木町七条通間之町東入', '26', '26106', '6008146', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '材木町', 'ザイモクチョウ', null, '七条通間之町東入', null, null);
INSERT INTO `ms_addresses` VALUES ('65047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区材木町七条通河原町西入', '26', '26106', '6008146', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '材木町', 'ザイモクチョウ', null, '七条通河原町西入', null, null);
INSERT INTO `ms_addresses` VALUES ('65048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区材木町七条通河原町東入', '26', '26106', '6008146', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '材木町', 'ザイモクチョウ', null, '七条通河原町東入', null, null);
INSERT INTO `ms_addresses` VALUES ('65049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区材木町七条通高倉西入', '26', '26106', '6008146', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '材木町', 'ザイモクチョウ', null, '七条通高倉西入', null, null);
INSERT INTO `ms_addresses` VALUES ('65050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区材木町七条通高倉東入', '26', '26106', '6008146', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '材木町', 'ザイモクチョウ', null, '七条通高倉東入', null, null);
INSERT INTO `ms_addresses` VALUES ('65051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区材木町七条通土手町西入', '26', '26106', '6008146', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '材木町', 'ザイモクチョウ', null, '七条通土手町西入', null, null);
INSERT INTO `ms_addresses` VALUES ('65052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区材木町七条通東洞院東入', '26', '26106', '6008146', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '材木町', 'ザイモクチョウ', null, '七条通東洞院東入', null, null);
INSERT INTO `ms_addresses` VALUES ('65053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区材木町高倉通七条上る', '26', '26106', '6008146', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '材木町', 'ザイモクチョウ', null, '高倉通七条上る', null, null);
INSERT INTO `ms_addresses` VALUES ('65054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区材木町高倉通七条下る', '26', '26106', '6008146', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '材木町', 'ザイモクチョウ', null, '高倉通七条下る', null, null);
INSERT INTO `ms_addresses` VALUES ('65055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区材木町土手町通七条上る', '26', '26106', '6008146', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '材木町', 'ザイモクチョウ', null, '土手町通七条上る', null, null);
INSERT INTO `ms_addresses` VALUES ('65056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区材木町東洞院通七条下る', '26', '26106', '6008146', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '材木町', 'ザイモクチョウ', null, '東洞院通七条下る', null, null);
INSERT INTO `ms_addresses` VALUES ('65057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区材木町柳馬場通七条上る', '26', '26106', '6008146', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '材木町', 'ザイモクチョウ', null, '柳馬場通七条上る', null, null);
INSERT INTO `ms_addresses` VALUES ('65058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区堀詰町', '26', '26106', '6008147', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '堀詰町', 'ホリヅメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区飴屋町', '26', '26106', '6008148', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '飴屋町', 'アメヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区粉川町', '26', '26106', '6008149', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '粉川町', 'コガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北15条西6丁目', '01', '01102', '0600815', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北15条西', 'キタ15ジョウニシ', null, null, '6丁目', '06チョウメ');
INSERT INTO `ms_addresses` VALUES ('65062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区上珠数屋町', '26', '26106', '6008150', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '上珠数屋町', 'カミジュズヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北15条西7丁目', '01', '01102', '0600815', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北15条西', 'キタ15ジョウニシ', null, null, '7丁目', '07チョウメ');
INSERT INTO `ms_addresses` VALUES ('65064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北15条西8丁目', '01', '01102', '0600815', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北15条西', 'キタ15ジョウニシ', null, null, '8丁目', '08チョウメ');
INSERT INTO `ms_addresses` VALUES ('65065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北15条西9丁目', '01', '01102', '0600815', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北15条西', 'キタ15ジョウニシ', null, null, '9丁目', '09チョウメ');
INSERT INTO `ms_addresses` VALUES ('65066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北15条西10丁目', '01', '01102', '0600815', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北15条西', 'キタ15ジョウニシ', null, null, '10丁目', '10チョウメ');
INSERT INTO `ms_addresses` VALUES ('65067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北15条西11丁目', '01', '01102', '0600815', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北15条西', 'キタ15ジョウニシ', null, null, '11丁目', '11チョウメ');
INSERT INTO `ms_addresses` VALUES ('65068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北15条西12丁目', '01', '01102', '0600815', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北15条西', 'キタ15ジョウニシ', null, null, '12丁目', '12チョウメ');
INSERT INTO `ms_addresses` VALUES ('65069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北15条西13丁目', '01', '01102', '0600815', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北15条西', 'キタ15ジョウニシ', null, null, '13丁目', '13チョウメ');
INSERT INTO `ms_addresses` VALUES ('65070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区打越町', '26', '26106', '6008151', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '打越町', 'ウチコシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区筒金町', '26', '26106', '6008152', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '筒金町', 'ツツガネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区廿人講町', '26', '26106', '6008153', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '廿人講町', 'ニジュウニンコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区榎木町', '26', '26106', '6008154', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '榎木町', 'エノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区西玉水町', '26', '26106', '6008155', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '西玉水町', 'ニシタマミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区笹屋町', '26', '26106', '6008156', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '笹屋町', 'ササヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区橘町下珠数屋町通不明門東入', '26', '26106', '6008157', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '橘町', 'タチバナチョウ', null, '下珠数屋町通不明門東入', null, null);
INSERT INTO `ms_addresses` VALUES ('65077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区橘町下珠数屋町通烏丸東入', '26', '26106', '6008157', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '橘町', 'タチバナチョウ', null, '下珠数屋町通烏丸東入', null, null);
INSERT INTO `ms_addresses` VALUES ('65078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区橘町下珠数屋町通東洞院西入', '26', '26106', '6008157', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '橘町', 'タチバナチョウ', null, '下珠数屋町通東洞院西入', null, null);
INSERT INTO `ms_addresses` VALUES ('65079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区卓屋町', '26', '26106', '6008158', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '卓屋町', 'ショクヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区亀町', '26', '26106', '6008159', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '亀町', 'カメマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北16条西7丁目', '01', '01102', '0600816', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北16条西', 'キタ16ジョウニシ', null, null, '7丁目', '07チョウメ');
INSERT INTO `ms_addresses` VALUES ('65082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区西魚屋町', '26', '26106', '6008160', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '西魚屋町', 'ニシウオヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北16条西8丁目', '01', '01102', '0600816', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北16条西', 'キタ16ジョウニシ', null, null, '8丁目', '08チョウメ');
INSERT INTO `ms_addresses` VALUES ('65084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北16条西9丁目', '01', '01102', '0600816', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北16条西', 'キタ16ジョウニシ', null, null, '9丁目', '09チョウメ');
INSERT INTO `ms_addresses` VALUES ('65085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北16条西10丁目', '01', '01102', '0600816', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北16条西', 'キタ16ジョウニシ', null, null, '10丁目', '10チョウメ');
INSERT INTO `ms_addresses` VALUES ('65086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北16条西11丁目', '01', '01102', '0600816', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北16条西', 'キタ16ジョウニシ', null, null, '11丁目', '11チョウメ');
INSERT INTO `ms_addresses` VALUES ('65087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北16条西12丁目', '01', '01102', '0600816', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北16条西', 'キタ16ジョウニシ', null, null, '12丁目', '12チョウメ');
INSERT INTO `ms_addresses` VALUES ('65088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北16条西13丁目', '01', '01102', '0600816', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北16条西', 'キタ16ジョウニシ', null, null, '13丁目', '13チョウメ');
INSERT INTO `ms_addresses` VALUES ('65089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区大黒町鍵屋町通室町西入', '26', '26106', '6008161', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '大黒町', 'ダイコクチョウ', null, '鍵屋町通室町西入', null, null);
INSERT INTO `ms_addresses` VALUES ('65090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区大黒町鍵屋町通室町東入', '26', '26106', '6008161', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '大黒町', 'ダイコクチョウ', null, '鍵屋町通室町東入', null, null);
INSERT INTO `ms_addresses` VALUES ('65091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区大黒町五条通室町東入', '26', '26106', '6008161', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '大黒町', 'ダイコクチョウ', null, '五条通室町東入', null, null);
INSERT INTO `ms_addresses` VALUES ('65092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区大黒町室町通鍵屋町上る', '26', '26106', '6008161', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '大黒町', 'ダイコクチョウ', null, '室町通鍵屋町上る', null, null);
INSERT INTO `ms_addresses` VALUES ('65093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区大黒町室町通楊梅上る', '26', '26106', '6008161', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '大黒町', 'ダイコクチョウ', null, '室町通楊梅上る', null, null);
INSERT INTO `ms_addresses` VALUES ('65094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区大黒町室町通楊梅下る', '26', '26106', '6008161', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '大黒町', 'ダイコクチョウ', null, '室町通楊梅下る', null, null);
INSERT INTO `ms_addresses` VALUES ('65095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区堺町鍵屋町通室町西入', '26', '26106', '6008162', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '堺町', 'サカイチョウ', '（－チョウ）', '鍵屋町通室町西入', null, null);
INSERT INTO `ms_addresses` VALUES ('65096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区堺町鍵屋町通室町東入', '26', '26106', '6008162', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '堺町', 'サカイチョウ', '（－チョウ）', '鍵屋町通室町東入', null, null);
INSERT INTO `ms_addresses` VALUES ('65097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区堺町室町通鍵屋町下る', '26', '26106', '6008162', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '堺町', 'サカイチョウ', '（－チョウ）', '室町通鍵屋町下る', null, null);
INSERT INTO `ms_addresses` VALUES ('65098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区堺町的場通室町西入', '26', '26106', '6008162', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '堺町', 'サカイチョウ', '（－チョウ）', '的場通室町西入', null, null);
INSERT INTO `ms_addresses` VALUES ('65099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区堺町的場通室町東入', '26', '26106', '6008162', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '堺町', 'サカイチョウ', '（－チョウ）', '的場通室町東入', null, null);
INSERT INTO `ms_addresses` VALUES ('65100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区堺町室町通五条下る2丁目', '26', '26106', '6008162', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '堺町', 'サカイチョウ', '（－チョウ）', '室町通五条下る2丁目', null, null);
INSERT INTO `ms_addresses` VALUES ('65101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区堺町室町通六条上る', '26', '26106', '6008162', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '堺町', 'サカイチョウ', '（－チョウ）', '室町通六条上る', null, null);
INSERT INTO `ms_addresses` VALUES ('65102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区堺町室町通的場上る', '26', '26106', '6008162', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '堺町', 'サカイチョウ', '（－チョウ）', '室町通的場上る', null, null);
INSERT INTO `ms_addresses` VALUES ('65103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区下諏訪町', '26', '26106', '6008163', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '下諏訪町', 'シモスワンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区上柳町諏訪町通花屋町上る', '26', '26106', '6008164', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '上柳町', 'カミヤナギチョウ', null, '諏訪町通花屋町上る', null, null);
INSERT INTO `ms_addresses` VALUES ('65105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区上柳町諏訪町通六条上る', '26', '26106', '6008164', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '上柳町', 'カミヤナギチョウ', null, '諏訪町通六条上る', null, null);
INSERT INTO `ms_addresses` VALUES ('65106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区上柳町諏訪町通六条下る', '26', '26106', '6008164', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '上柳町', 'カミヤナギチョウ', null, '諏訪町通六条下る', null, null);
INSERT INTO `ms_addresses` VALUES ('65107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区上柳町六条通烏丸西入', '26', '26106', '6008164', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '上柳町', 'カミヤナギチョウ', null, '六条通烏丸西入', null, null);
INSERT INTO `ms_addresses` VALUES ('65108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区上柳町六条通諏訪町西入', '26', '26106', '6008164', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '上柳町', 'カミヤナギチョウ', null, '六条通諏訪町西入', null, null);
INSERT INTO `ms_addresses` VALUES ('65109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区上柳町六条通諏訪町東入', '26', '26106', '6008164', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '上柳町', 'カミヤナギチョウ', null, '六条通諏訪町東入', null, null);
INSERT INTO `ms_addresses` VALUES ('65110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区上柳町六条通室町東入', '26', '26106', '6008164', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '上柳町', 'カミヤナギチョウ', null, '六条通室町東入', null, null);
INSERT INTO `ms_addresses` VALUES ('65111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区下柳町', '26', '26106', '6008165', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '下柳町', 'シモヤナギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区乾町', '26', '26106', '6008166', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '乾町', 'イヌイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区常葉町', '26', '26106', '6008167', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '常葉町', 'トキワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区八百屋町室町新町ノ間六条下る', '26', '26106', '6008168', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '八百屋町', 'ヤオヤチョウ', null, '室町新町ノ間六条下る', null, null);
INSERT INTO `ms_addresses` VALUES ('65115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区八百屋町室町通花屋町上る', '26', '26106', '6008168', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '八百屋町', 'ヤオヤチョウ', null, '室町通花屋町上る', null, null);
INSERT INTO `ms_addresses` VALUES ('65116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区八百屋町室町通六条下る', '26', '26106', '6008168', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '八百屋町', 'ヤオヤチョウ', null, '室町通六条下る', null, null);
INSERT INTO `ms_addresses` VALUES ('65117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区八百屋町六条通新町東入下る', '26', '26106', '6008168', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '八百屋町', 'ヤオヤチョウ', null, '六条通新町東入下る', null, null);
INSERT INTO `ms_addresses` VALUES ('65118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区八百屋町六条通室町西入', '26', '26106', '6008168', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '八百屋町', 'ヤオヤチョウ', null, '六条通室町西入', null, null);
INSERT INTO `ms_addresses` VALUES ('65119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区八百屋町六条通室町西入下る', '26', '26106', '6008168', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '八百屋町', 'ヤオヤチョウ', null, '六条通室町西入下る', null, null);
INSERT INTO `ms_addresses` VALUES ('65120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区東魚屋町', '26', '26106', '6008169', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '東魚屋町', 'ヒガシウオヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北17条西7丁目', '01', '01102', '0600817', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北17条西', 'キタ17ジョウニシ', null, null, '7丁目', '07チョウメ');
INSERT INTO `ms_addresses` VALUES ('65122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区上諏訪町', '26', '26106', '6008170', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '上諏訪町', 'カミスワンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北17条西8丁目', '01', '01102', '0600817', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北17条西', 'キタ17ジョウニシ', null, null, '8丁目', '08チョウメ');
INSERT INTO `ms_addresses` VALUES ('65124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北17条西9丁目', '01', '01102', '0600817', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北17条西', 'キタ17ジョウニシ', null, null, '9丁目', '09チョウメ');
INSERT INTO `ms_addresses` VALUES ('65125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北17条西10丁目', '01', '01102', '0600817', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北17条西', 'キタ17ジョウニシ', null, null, '10丁目', '10チョウメ');
INSERT INTO `ms_addresses` VALUES ('65126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北17条西11丁目', '01', '01102', '0600817', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北17条西', 'キタ17ジョウニシ', null, null, '11丁目', '11チョウメ');
INSERT INTO `ms_addresses` VALUES ('65127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北17条西12丁目', '01', '01102', '0600817', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北17条西', 'キタ17ジョウニシ', null, null, '12丁目', '12チョウメ');
INSERT INTO `ms_addresses` VALUES ('65128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北17条西13丁目', '01', '01102', '0600817', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北17条西', 'キタ17ジョウニシ', null, null, '13丁目', '13チョウメ');
INSERT INTO `ms_addresses` VALUES ('65129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区上平野町', '26', '26106', '6008171', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '上平野町', 'カミヒラノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区下平野町', '26', '26106', '6008172', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '下平野町', 'シモヒラノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区仏具屋町不明門通五条下る2丁目', '26', '26106', '6008173', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '仏具屋町', 'ブツグヤチョウ', null, '不明門通五条下る2丁目', null, null);
INSERT INTO `ms_addresses` VALUES ('65132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区仏具屋町不明門通花屋町上る', '26', '26106', '6008173', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '仏具屋町', 'ブツグヤチョウ', null, '不明門通花屋町上る', null, null);
INSERT INTO `ms_addresses` VALUES ('65133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区仏具屋町不明門通六条上る', '26', '26106', '6008173', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '仏具屋町', 'ブツグヤチョウ', null, '不明門通六条上る', null, null);
INSERT INTO `ms_addresses` VALUES ('65134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区仏具屋町不明門通六条下る', '26', '26106', '6008173', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '仏具屋町', 'ブツグヤチョウ', null, '不明門通六条下る', null, null);
INSERT INTO `ms_addresses` VALUES ('65135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区仏具屋町花屋町通烏丸東入', '26', '26106', '6008173', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '仏具屋町', 'ブツグヤチョウ', null, '花屋町通烏丸東入', null, null);
INSERT INTO `ms_addresses` VALUES ('65136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区仏具屋町花屋町通不明門西入', '26', '26106', '6008173', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '仏具屋町', 'ブツグヤチョウ', null, '花屋町通不明門西入', null, null);
INSERT INTO `ms_addresses` VALUES ('65137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区仏具屋町花屋町通不明門東入', '26', '26106', '6008173', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '仏具屋町', 'ブツグヤチョウ', null, '花屋町通不明門東入', null, null);
INSERT INTO `ms_addresses` VALUES ('65138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区仏具屋町六条通不明門西入', '26', '26106', '6008173', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '仏具屋町', 'ブツグヤチョウ', null, '六条通不明門西入', null, null);
INSERT INTO `ms_addresses` VALUES ('65139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区仏具屋町六条通不明門東入', '26', '26106', '6008173', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '仏具屋町', 'ブツグヤチョウ', null, '六条通不明門東入', null, null);
INSERT INTO `ms_addresses` VALUES ('65140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区仏具屋町六条通烏丸東入', '26', '26106', '6008173', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '仏具屋町', 'ブツグヤチョウ', null, '六条通烏丸東入', null, null);
INSERT INTO `ms_addresses` VALUES ('65141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区仏具屋町六条通東洞院西入', '26', '26106', '6008173', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '仏具屋町', 'ブツグヤチョウ', null, '六条通東洞院西入', null, null);
INSERT INTO `ms_addresses` VALUES ('65142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区高槻町', '26', '26106', '6008174', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '高槻町', 'タカツキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区烏丸2丁目', '26', '26106', '6008175', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '烏丸', 'カラスマ', null, null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('65144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区北町', '26', '26106', '6008176', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '北町', 'キタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区大坂町', '26', '26106', '6008177', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '大坂町', 'オオサカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区鍵屋町鍵屋町通烏丸西入', '26', '26106', '6008178', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '鍵屋町', 'カギヤチョウ', null, '鍵屋町通烏丸西入', null, null);
INSERT INTO `ms_addresses` VALUES ('65147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区鍵屋町鍵屋町通諏訪町西入', '26', '26106', '6008178', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '鍵屋町', 'カギヤチョウ', null, '鍵屋町通諏訪町西入', null, null);
INSERT INTO `ms_addresses` VALUES ('65148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区鍵屋町鍵屋町通室町東入', '26', '26106', '6008178', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '鍵屋町', 'カギヤチョウ', null, '鍵屋町通室町東入', null, null);
INSERT INTO `ms_addresses` VALUES ('65149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区鍵屋町諏訪町通鍵屋町上る', '26', '26106', '6008178', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '鍵屋町', 'カギヤチョウ', null, '諏訪町通鍵屋町上る', null, null);
INSERT INTO `ms_addresses` VALUES ('65150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区鍵屋町諏訪町通鍵屋町下る', '26', '26106', '6008178', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '鍵屋町', 'カギヤチョウ', null, '諏訪町通鍵屋町下る', null, null);
INSERT INTO `ms_addresses` VALUES ('65151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区横諏訪町', '26', '26106', '6008179', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '横諏訪町', 'ヨコスワンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北18条西8丁目', '01', '01102', '0600818', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北18条西', 'キタ18ジョウニシ', null, null, '8丁目', '08チョウメ');
INSERT INTO `ms_addresses` VALUES ('65153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区下万寿寺町', '26', '26106', '6008180', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '下万寿寺町', 'シモマンジュウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北18条西9丁目', '01', '01102', '0600818', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北18条西', 'キタ18ジョウニシ', null, null, '9丁目', '09チョウメ');
INSERT INTO `ms_addresses` VALUES ('65155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北18条西10丁目', '01', '01102', '0600818', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北18条西', 'キタ18ジョウニシ', null, null, '10丁目', '10チョウメ');
INSERT INTO `ms_addresses` VALUES ('65156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北18条西11丁目', '01', '01102', '0600818', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北18条西', 'キタ18ジョウニシ', null, null, '11丁目', '11チョウメ');
INSERT INTO `ms_addresses` VALUES ('65157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北18条西12丁目', '01', '01102', '0600818', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北18条西', 'キタ18ジョウニシ', null, null, '12丁目', '12チョウメ');
INSERT INTO `ms_addresses` VALUES ('65158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北18条西13丁目', '01', '01102', '0600818', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北18条西', 'キタ18ジョウニシ', null, null, '13丁目', '13チョウメ');
INSERT INTO `ms_addresses` VALUES ('65159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区大津町', '26', '26106', '6008181', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '大津町', 'オオツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区塗師屋町間之町通五条下る', '26', '26106', '6008182', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '塗師屋町', 'ヌシヤチョウ', null, '間之町通五条下る', null, null);
INSERT INTO `ms_addresses` VALUES ('65161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区塗師屋町間之町通五条下る2丁目', '26', '26106', '6008182', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '塗師屋町', 'ヌシヤチョウ', null, '間之町通五条下る2丁目', null, null);
INSERT INTO `ms_addresses` VALUES ('65162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区塗師屋町間之町六条上る', '26', '26106', '6008182', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '塗師屋町', 'ヌシヤチョウ', null, '間之町六条上る', null, null);
INSERT INTO `ms_addresses` VALUES ('65163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区塗師屋町下坂通間之町西入', '26', '26106', '6008182', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '塗師屋町', 'ヌシヤチョウ', null, '下坂通間之町西入', null, null);
INSERT INTO `ms_addresses` VALUES ('65164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区塗師屋町下坂通間之町東入', '26', '26106', '6008182', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '塗師屋町', 'ヌシヤチョウ', null, '下坂通間之町東入', null, null);
INSERT INTO `ms_addresses` VALUES ('65165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区塗師屋町六条通間之町西入', '26', '26106', '6008182', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '塗師屋町', 'ヌシヤチョウ', null, '六条通間之町西入', null, null);
INSERT INTO `ms_addresses` VALUES ('65166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区塗師屋町六条通間之町東入', '26', '26106', '6008182', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '塗師屋町', 'ヌシヤチョウ', null, '六条通間之町東入', null, null);
INSERT INTO `ms_addresses` VALUES ('65167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区塗師屋町六条通高倉西入', '26', '26106', '6008182', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '塗師屋町', 'ヌシヤチョウ', null, '六条通高倉西入', null, null);
INSERT INTO `ms_addresses` VALUES ('65168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区塗師屋町六条通東洞院東入', '26', '26106', '6008182', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '塗師屋町', 'ヌシヤチョウ', null, '六条通東洞院東入', null, null);
INSERT INTO `ms_addresses` VALUES ('65169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区夷之町間之町通五条下る3丁目', '26', '26106', '6008183', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '夷之町', 'エビスノチョウ', null, '間之町通五条下る3丁目', null, null);
INSERT INTO `ms_addresses` VALUES ('65170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区夷之町間之町通花屋町上る', '26', '26106', '6008183', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '夷之町', 'エビスノチョウ', null, '間之町通花屋町上る', null, null);
INSERT INTO `ms_addresses` VALUES ('65171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区夷之町間之町通六条下る', '26', '26106', '6008183', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '夷之町', 'エビスノチョウ', null, '間之町通六条下る', null, null);
INSERT INTO `ms_addresses` VALUES ('65172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区夷之町花屋町通間之町西入', '26', '26106', '6008183', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '夷之町', 'エビスノチョウ', null, '花屋町通間之町西入', null, null);
INSERT INTO `ms_addresses` VALUES ('65173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区夷之町花屋町通間之町東入', '26', '26106', '6008183', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '夷之町', 'エビスノチョウ', null, '花屋町通間之町東入', null, null);
INSERT INTO `ms_addresses` VALUES ('65174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区夷之町花屋町通東洞院東入', '26', '26106', '6008183', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '夷之町', 'エビスノチョウ', null, '花屋町通東洞院東入', null, null);
INSERT INTO `ms_addresses` VALUES ('65175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区夷之町六条通間之町西入', '26', '26106', '6008183', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '夷之町', 'エビスノチョウ', null, '六条通間之町西入', null, null);
INSERT INTO `ms_addresses` VALUES ('65176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区夷之町六条通間之町東入', '26', '26106', '6008183', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '夷之町', 'エビスノチョウ', null, '六条通間之町東入', null, null);
INSERT INTO `ms_addresses` VALUES ('65177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区夷之町六条通東洞院東入', '26', '26106', '6008183', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '夷之町', 'エビスノチョウ', null, '六条通東洞院東入', null, null);
INSERT INTO `ms_addresses` VALUES ('65178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区天神町', '26', '26106', '6008184', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '天神町', 'テンジンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区花屋町上枳殻馬場通間之町西入', '26', '26106', '6008185', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '花屋町', 'ハナヤチョウ', null, '上枳殻馬場通間之町西入', null, null);
INSERT INTO `ms_addresses` VALUES ('65180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区花屋町上珠数屋町通間之町西入', '26', '26106', '6008185', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '花屋町', 'ハナヤチョウ', null, '上珠数屋町通間之町西入', null, null);
INSERT INTO `ms_addresses` VALUES ('65181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区花屋町上珠数屋町通東洞院東入', '26', '26106', '6008185', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '花屋町', 'ハナヤチョウ', null, '上珠数屋町通東洞院東入', null, null);
INSERT INTO `ms_addresses` VALUES ('65182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区花屋町東洞院通上枳殻馬場下る', '26', '26106', '6008185', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '花屋町', 'ハナヤチョウ', null, '東洞院通上枳殻馬場下る', null, null);
INSERT INTO `ms_addresses` VALUES ('65183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区花屋町間之町通上珠数屋町下る', '26', '26106', '6008185', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '花屋町', 'ハナヤチョウ', null, '間之町通上珠数屋町下る', null, null);
INSERT INTO `ms_addresses` VALUES ('65184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区富田町', '26', '26106', '6008186', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '富田町', 'トミタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区橋詰町', '26', '26106', '6008187', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '橋詰町', 'ハシヅメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区和泉町', '26', '26106', '6008188', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '和泉町', 'イズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区福島町', '26', '26106', '6008189', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '福島町', 'フクシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北19条西8丁目', '01', '01102', '0600819', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北19条西', 'キタ19ジョウニシ', null, null, '8丁目', '08チョウメ');
INSERT INTO `ms_addresses` VALUES ('65189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区東玉水町', '26', '26106', '6008190', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '東玉水町', 'ヒガシタマミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北19条西9丁目', '01', '01102', '0600819', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北19条西', 'キタ19ジョウニシ', null, null, '9丁目', '09チョウメ');
INSERT INTO `ms_addresses` VALUES ('65191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北19条西10丁目', '01', '01102', '0600819', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北19条西', 'キタ19ジョウニシ', null, null, '10丁目', '10チョウメ');
INSERT INTO `ms_addresses` VALUES ('65192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北19条西11丁目', '01', '01102', '0600819', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北19条西', 'キタ19ジョウニシ', null, null, '11丁目', '11チョウメ');
INSERT INTO `ms_addresses` VALUES ('65193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北19条西12丁目', '01', '01102', '0600819', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北19条西', 'キタ19ジョウニシ', null, null, '12丁目', '12チョウメ');
INSERT INTO `ms_addresses` VALUES ('65194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北19条西13丁目', '01', '01102', '0600819', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北19条西', 'キタ19ジョウニシ', null, null, '13丁目', '13チョウメ');
INSERT INTO `ms_addresses` VALUES ('65195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区堺町五条通高倉西入', '26', '26106', '6008191', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '堺町', 'サカイマチ', '（－マチ）', '五条通高倉西入', null, null);
INSERT INTO `ms_addresses` VALUES ('65196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区堺町五条通高倉東入', '26', '26106', '6008191', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '堺町', 'サカイマチ', '（－マチ）', '五条通高倉東入', null, null);
INSERT INTO `ms_addresses` VALUES ('65197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区堺町高倉通五条下る', '26', '26106', '6008191', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '堺町', 'サカイマチ', '（－マチ）', '高倉通五条下る', null, null);
INSERT INTO `ms_addresses` VALUES ('65198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区富屋町', '26', '26106', '6008192', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '富屋町', 'トミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区骨屋町六条通高倉東入', '26', '26106', '6008193', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '骨屋町', 'ホネヤチョウ', null, '六条通高倉東入', null, null);
INSERT INTO `ms_addresses` VALUES ('65200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区骨屋町六条通柳馬場西入', '26', '26106', '6008193', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '骨屋町', 'ホネヤチョウ', null, '六条通柳馬場西入', null, null);
INSERT INTO `ms_addresses` VALUES ('65201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区栄町', '26', '26106', '6008194', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '栄町', 'サカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区升屋町', '26', '26106', '6008195', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '升屋町', 'マスヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区八軒町', '26', '26106', '6008196', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '八軒町', 'ハチケンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区唐物町', '26', '26106', '6008197', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '唐物町', 'カラモノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区若松町', '26', '26106', '6008198', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '若松町', 'ワカマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区万屋町', '26', '26106', '6008199', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '万屋町', 'ヨロズヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北20条西11丁目', '01', '01102', '0600820', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北20条西', 'キタ20ジョウニシ', null, null, '11丁目', '11チョウメ');
INSERT INTO `ms_addresses` VALUES ('65208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北20条西12丁目', '01', '01102', '0600820', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北20条西', 'キタ20ジョウニシ', null, null, '12丁目', '12チョウメ');
INSERT INTO `ms_addresses` VALUES ('65209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市北区北20条西13丁目', '01', '01102', '0600820', '北海道', 'ホッカイドウ', '札幌市北区', 'サッポロシキタク', '北20条西', 'キタ20ジョウニシ', null, null, '13丁目', '13チョウメ');
INSERT INTO `ms_addresses` VALUES ('65210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区若宮町加茂川筋七条下る', '26', '26106', '6008201', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '若宮町', 'ワカミヤチョウ', null, '加茂川筋七条下る', null, null);
INSERT INTO `ms_addresses` VALUES ('65211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区若宮町木屋町通七条下る', '26', '26106', '6008201', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '若宮町', 'ワカミヤチョウ', null, '木屋町通七条下る', null, null);
INSERT INTO `ms_addresses` VALUES ('65212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区若宮町木屋町通七条下る東入', '26', '26106', '6008201', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '若宮町', 'ワカミヤチョウ', null, '木屋町通七条下る東入', null, null);
INSERT INTO `ms_addresses` VALUES ('65213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区若宮町三ノ宮通七条下る', '26', '26106', '6008201', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '若宮町', 'ワカミヤチョウ', null, '三ノ宮通七条下る', null, null);
INSERT INTO `ms_addresses` VALUES ('65214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区若宮町須原通七条下る', '26', '26106', '6008201', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '若宮町', 'ワカミヤチョウ', null, '須原通七条下る', null, null);
INSERT INTO `ms_addresses` VALUES ('65215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区若宮町七条大橋西入', '26', '26106', '6008201', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '若宮町', 'ワカミヤチョウ', null, '七条大橋西入', null, null);
INSERT INTO `ms_addresses` VALUES ('65216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区若宮町七条通加茂川筋西入', '26', '26106', '6008201', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '若宮町', 'ワカミヤチョウ', null, '七条通加茂川筋西入', null, null);
INSERT INTO `ms_addresses` VALUES ('65217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区若宮町七条通加茂川筋西入下る', '26', '26106', '6008201', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '若宮町', 'ワカミヤチョウ', null, '七条通加茂川筋西入下る', null, null);
INSERT INTO `ms_addresses` VALUES ('65218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区川端町', '26', '26106', '6008202', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '川端町', 'カワバタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区屋形町', '26', '26106', '6008203', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '屋形町', 'ヤカタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区東之町', '26', '26106', '6008204', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '東之町', 'ヒガシノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区西之町', '26', '26106', '6008205', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '西之町', 'ニシノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区下之町', '26', '26106', '6008206', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '下之町', 'シモノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区上之町', '26', '26106', '6008207', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '上之町', 'カミノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区小稲荷町', '26', '26106', '6008208', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '小稲荷町', 'コイナリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区郷之町', '26', '26106', '6008209', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '郷之町', 'ゴウノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区桜木町', '26', '26106', '6008210', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '桜木町', 'サクラギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区真苧屋町', '26', '26106', '6008211', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '真苧屋町', 'マオヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区塩小路町', '26', '26106', '6008212', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '塩小路町', 'シオコウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区東塩小路向畑町', '26', '26106', '6008213', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '東塩小路向畑町', 'ヒガシシオコウジムカイハタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区東塩小路高倉町', '26', '26106', '6008214', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '東塩小路高倉町', 'ヒガシシオコウジタカクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区東塩小路釜殿町', '26', '26106', '6008215', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '東塩小路釜殿町', 'ヒガシシオコウジカマドノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区東塩小路町', '26', '26106', '6008216', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '東塩小路町', 'ヒガシシオコウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区東境町', '26', '26106', '6008217', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '東境町', 'ヒガシサカイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区西境町', '26', '26106', '6008218', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '西境町', 'ニシサカイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区中居町', '26', '26106', '6008219', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '中居町', 'ナカイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区高雄町', '26', '26106', '6008221', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '高雄町', 'タカオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区文覚町', '26', '26106', '6008222', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '文覚町', 'モンガクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区大黒町油小路通七条下る', '26', '26106', '6008223', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '大黒町', 'ダイコクチョウ', null, '油小路通七条下る', null, null);
INSERT INTO `ms_addresses` VALUES ('65239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区大黒町七条通油小路東入', '26', '26106', '6008223', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '大黒町', 'ダイコクチョウ', null, '七条通油小路東入', null, null);
INSERT INTO `ms_addresses` VALUES ('65240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区大黒町七条通西洞院西入', '26', '26106', '6008223', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '大黒町', 'ダイコクチョウ', null, '七条通西洞院西入', null, null);
INSERT INTO `ms_addresses` VALUES ('65241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区大黒町下魚棚通油小路東入', '26', '26106', '6008223', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '大黒町', 'ダイコクチョウ', null, '下魚棚通油小路東入', null, null);
INSERT INTO `ms_addresses` VALUES ('65242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区大黒町下魚棚通西洞院西入', '26', '26106', '6008223', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '大黒町', 'ダイコクチョウ', null, '下魚棚通西洞院西入', null, null);
INSERT INTO `ms_addresses` VALUES ('65243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区大黒町西洞院通七条下る', '26', '26106', '6008223', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '大黒町', 'ダイコクチョウ', null, '西洞院通七条下る', null, null);
INSERT INTO `ms_addresses` VALUES ('65244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区大黒町東中筋通七条下る', '26', '26106', '6008223', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '大黒町', 'ダイコクチョウ', null, '東中筋通七条下る', null, null);
INSERT INTO `ms_addresses` VALUES ('65245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区大黒町東中筋通下魚棚下る', '26', '26106', '6008223', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '大黒町', 'ダイコクチョウ', null, '東中筋通下魚棚下る', null, null);
INSERT INTO `ms_addresses` VALUES ('65246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区東町', '26', '26106', '6008224', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '東町', 'ヒガシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区東大工町', '26', '26106', '6008225', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '東大工町', 'ヒガシダイクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区土橋町', '26', '26106', '6008226', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '土橋町', 'ツチハシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区菱屋町', '26', '26106', '6008227', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '菱屋町', 'ヒシヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区北小路町', '26', '26106', '6008228', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '北小路町', 'キタコウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区米屋町', '26', '26106', '6008229', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '米屋町', 'コメヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区油小路町', '26', '26106', '6008231', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '油小路町', 'アブラノコウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区南町', '26', '26106', '6008232', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '南町', 'ミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区北不動堂町', '26', '26106', '6008233', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '北不動堂町', 'キタフドンドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区南不動堂町', '26', '26106', '6008234', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '南不動堂町', 'ミナミフドンドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区東油小路町', '26', '26106', '6008235', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '東油小路町', 'ヒガシアブラノコウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区西油小路町', '26', '26106', '6008236', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '西油小路町', 'ニシアブラノコウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区松明町', '26', '26106', '6008237', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '松明町', 'タイマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区御方紺屋町', '26', '26106', '6008238', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '御方紺屋町', 'ミカタコンヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区鎌屋町', '26', '26106', '6008239', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '鎌屋町', 'カマヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区志水町', '26', '26106', '6008241', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '志水町', 'シミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区上夷町', '26', '26106', '6008242', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '上夷町', 'カミエビスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区南夷町', '26', '26106', '6008243', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '南夷町', 'ミナミエビスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区坊門中之町', '26', '26106', '6008244', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '坊門中之町', 'ボウモンナカノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区古御旅町', '26', '26106', '6008245', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '古御旅町', 'フルオタビチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区垣ケ内町', '26', '26106', '6008246', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '垣ケ内町', 'カキガウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区八条坊門町塩小路通黒門西入', '26', '26106', '6008247', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '八条坊門町', 'ハチジョウボウモンチョウ', null, '塩小路通黒門西入', null, null);
INSERT INTO `ms_addresses` VALUES ('65268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区上中之町', '26', '26106', '6008248', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '上中之町', 'カミナカノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区下糀屋町', '26', '26106', '6008249', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '下糀屋町', 'シモコウジヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区南八百屋町', '26', '26106', '6008251', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '南八百屋町', 'ミナミヤオヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区川端町木津屋橋通堀川西入', '26', '26106', '6008252', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '川端町', 'カワバタチョウ', null, '木津屋橋通堀川西入', null, null);
INSERT INTO `ms_addresses` VALUES ('65272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区川端町堀川通木津屋橋上る', '26', '26106', '6008252', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '川端町', 'カワバタチョウ', null, '堀川通木津屋橋上る', null, null);
INSERT INTO `ms_addresses` VALUES ('65273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区木津屋町', '26', '26106', '6008253', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '木津屋町', 'キヅヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区伊勢松町', '26', '26106', '6008254', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '伊勢松町', 'イセマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区清水町堀川通木津屋橋下る', '26', '26106', '6008255', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '清水町', 'シミズチョウ', null, '堀川通木津屋橋下る', null, null);
INSERT INTO `ms_addresses` VALUES ('65276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区清水町堀川通塩小路上る', '26', '26106', '6008255', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '清水町', 'シミズチョウ', null, '堀川通塩小路上る', null, null);
INSERT INTO `ms_addresses` VALUES ('65277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区清水町西堀川通木津屋橋下る', '26', '26106', '6008255', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '清水町', 'シミズチョウ', null, '西堀川通木津屋橋下る', null, null);
INSERT INTO `ms_addresses` VALUES ('65278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区清水町堀川通塩小路西入', '26', '26106', '6008255', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '清水町', 'シミズチョウ', null, '堀川通塩小路西入', null, null);
INSERT INTO `ms_addresses` VALUES ('65279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区松本町岩上通木津屋橋下る', '26', '26106', '6008256', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '松本町', 'マツモトチョウ', null, '岩上通木津屋橋下る', null, null);
INSERT INTO `ms_addresses` VALUES ('65280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区松本町岩上通塩小路上る', '26', '26106', '6008256', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '松本町', 'マツモトチョウ', null, '岩上通塩小路上る', null, null);
INSERT INTO `ms_addresses` VALUES ('65281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区三軒替地町', '26', '26106', '6008257', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '三軒替地町', 'サンゲンガエチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区金換町', '26', '26106', '6008258', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '金換町', 'カネガエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区上糀屋町', '26', '26106', '6008259', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '上糀屋町', 'カミコウジヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区花園町', '26', '26106', '6008261', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '花園町', 'ハナゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区八百屋町七条通猪熊通東入', '26', '26106', '6008262', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '八百屋町', 'ヤオヤチョウ', null, '七条通猪熊通東入', null, null);
INSERT INTO `ms_addresses` VALUES ('65286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区八百屋町七条通東堀川西入', '26', '26106', '6008262', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '八百屋町', 'ヤオヤチョウ', null, '七条通東堀川西入', null, null);
INSERT INTO `ms_addresses` VALUES ('65287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区八百屋町七条通堀川西入', '26', '26106', '6008262', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '八百屋町', 'ヤオヤチョウ', null, '七条通堀川西入', null, null);
INSERT INTO `ms_addresses` VALUES ('65288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区八百屋町七条通堀川西入下る', '26', '26106', '6008262', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '八百屋町', 'ヤオヤチョウ', null, '七条通堀川西入下る', null, null);
INSERT INTO `ms_addresses` VALUES ('65289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区八百屋町東堀川通七条下る西入', '26', '26106', '6008262', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '八百屋町', 'ヤオヤチョウ', null, '東堀川通七条下る西入', null, null);
INSERT INTO `ms_addresses` VALUES ('65290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区八百屋町下魚棚通堀川西入', '26', '26106', '6008262', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '八百屋町', 'ヤオヤチョウ', null, '下魚棚通堀川西入', null, null);
INSERT INTO `ms_addresses` VALUES ('65291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区下魚棚4丁目', '26', '26106', '6008263', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '下魚棚', 'シモウオノタナ', null, null, '4丁目', '04チョウメ');
INSERT INTO `ms_addresses` VALUES ('65292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区樽屋町', '26', '26106', '6008264', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '樽屋町', 'タルヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区徹宝町', '26', '26106', '6008265', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '徹宝町', 'テッポウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区上之町大宮通木津屋橋上る', '26', '26106', '6008266', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '上之町', 'カミノチョウ', null, '大宮通木津屋橋上る', null, null);
INSERT INTO `ms_addresses` VALUES ('65295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区上之町大宮通七条下る', '26', '26106', '6008266', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '上之町', 'カミノチョウ', null, '大宮通七条下る', null, null);
INSERT INTO `ms_addresses` VALUES ('65296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区上之町大宮通下魚棚下る', '26', '26106', '6008266', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '上之町', 'カミノチョウ', null, '大宮通下魚棚下る', null, null);
INSERT INTO `ms_addresses` VALUES ('65297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区上之町木津屋橋通大宮東入', '26', '26106', '6008266', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '上之町', 'カミノチョウ', null, '木津屋橋通大宮東入', null, null);
INSERT INTO `ms_addresses` VALUES ('65298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区上之町下魚棚通大宮東入', '26', '26106', '6008266', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '上之町', 'カミノチョウ', null, '下魚棚通大宮東入', null, null);
INSERT INTO `ms_addresses` VALUES ('65299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区御器屋町', '26', '26106', '6008267', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '御器屋町', 'ゴキヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区大工町猪熊通七条上る', '26', '26106', '6008268', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '大工町', 'ダイクチョウ', null, '猪熊通七条上る', null, null);
INSERT INTO `ms_addresses` VALUES ('65301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区大工町猪熊通七条下る', '26', '26106', '6008268', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '大工町', 'ダイクチョウ', null, '猪熊通七条下る', null, null);
INSERT INTO `ms_addresses` VALUES ('65302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区大工町猪熊通下魚棚上る', '26', '26106', '6008268', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '大工町', 'ダイクチョウ', null, '猪熊通下魚棚上る', null, null);
INSERT INTO `ms_addresses` VALUES ('65303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区大工町七条通猪熊西入', '26', '26106', '6008268', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '大工町', 'ダイクチョウ', null, '七条通猪熊西入', null, null);
INSERT INTO `ms_addresses` VALUES ('65304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区大工町七条通大宮東入', '26', '26106', '6008268', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '大工町', 'ダイクチョウ', null, '七条通大宮東入', null, null);
INSERT INTO `ms_addresses` VALUES ('65305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区大工町下魚棚通猪熊西入', '26', '26106', '6008268', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '大工町', 'ダイクチョウ', null, '下魚棚通猪熊西入', null, null);
INSERT INTO `ms_addresses` VALUES ('65306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区大工町下魚棚通大宮東入', '26', '26106', '6008268', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '大工町', 'ダイクチョウ', null, '下魚棚通大宮東入', null, null);
INSERT INTO `ms_addresses` VALUES ('65307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区大工町下魚棚通大宮東入下る', '26', '26106', '6008268', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '大工町', 'ダイクチョウ', null, '下魚棚通大宮東入下る', null, null);
INSERT INTO `ms_addresses` VALUES ('65308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区大工町下魚棚通黒門東入', '26', '26106', '6008268', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '大工町', 'ダイクチョウ', null, '下魚棚通黒門東入', null, null);
INSERT INTO `ms_addresses` VALUES ('65309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区西八百屋町', '26', '26106', '6008269', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '西八百屋町', 'ニシヤオヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区上柳町楊梅通新町東入', '26', '26106', '6008301', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '上柳町', 'カミヤナギチョウ', null, '楊梅通新町東入', null, null);
INSERT INTO `ms_addresses` VALUES ('65311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区上柳町室町新町之間五条下る', '26', '26106', '6008301', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '上柳町', 'カミヤナギチョウ', null, '室町新町之間五条下る', null, null);
INSERT INTO `ms_addresses` VALUES ('65312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区上柳町楊梅通新町東入上る', '26', '26106', '6008301', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '上柳町', 'カミヤナギチョウ', null, '楊梅通新町東入上る', null, null);
INSERT INTO `ms_addresses` VALUES ('65313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区上柳町楊梅通室町西入', '26', '26106', '6008301', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '上柳町', 'カミヤナギチョウ', null, '楊梅通室町西入', null, null);
INSERT INTO `ms_addresses` VALUES ('65314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区蛭子町', '26', '26106', '6008302', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '蛭子町', 'エビスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区銭屋町', '26', '26106', '6008303', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '銭屋町', 'ゼニヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区艮町', '26', '26106', '6008304', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '艮町', 'ウシトラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区東若松町', '26', '26106', '6008305', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '東若松町', 'ヒガシワカマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区平野町', '26', '26106', '6008306', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '平野町', 'ヒラノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区辰巳町', '26', '26106', '6008307', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '辰巳町', 'タツミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区新シ町', '26', '26106', '6008308', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '新シ町', 'アタラシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区夷之町七条通新町西入', '26', '26106', '6008310', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '夷之町', 'エビスノチョウ', null, '七条通新町西入', null, null);
INSERT INTO `ms_addresses` VALUES ('65322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区夷之町七条通新町東入', '26', '26106', '6008310', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '夷之町', 'エビスノチョウ', null, '七条通新町東入', null, null);
INSERT INTO `ms_addresses` VALUES ('65323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区夷之町七条通新町上る東入', '26', '26106', '6008310', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '夷之町', 'エビスノチョウ', null, '七条通新町上る東入', null, null);
INSERT INTO `ms_addresses` VALUES ('65324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区夷之町七条通西洞院東入', '26', '26106', '6008310', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '夷之町', 'エビスノチョウ', null, '七条通西洞院東入', null, null);
INSERT INTO `ms_addresses` VALUES ('65325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区夷之町新町通七条上る', '26', '26106', '6008310', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '夷之町', 'エビスノチョウ', null, '新町通七条上る', null, null);
INSERT INTO `ms_addresses` VALUES ('65326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区夷之町新町通七条下る', '26', '26106', '6008310', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '夷之町', 'エビスノチョウ', null, '新町通七条下る', null, null);
INSERT INTO `ms_addresses` VALUES ('65327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区夷之町新町通七条下る東入', '26', '26106', '6008310', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '夷之町', 'エビスノチョウ', null, '新町通七条下る東入', null, null);
INSERT INTO `ms_addresses` VALUES ('65328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区夷之町西洞院通七条上る', '26', '26106', '6008310', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '夷之町', 'エビスノチョウ', null, '西洞院通七条上る', null, null);
INSERT INTO `ms_addresses` VALUES ('65329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区毘沙門町', '26', '26106', '6008311', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '毘沙門町', 'ビシャモンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区上錫屋町', '26', '26106', '6008312', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '上錫屋町', 'カミスズヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区上若宮町', '26', '26106', '6008313', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '上若宮町', 'カミワカミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区若宮町新花屋町通若宮西入', '26', '26106', '6008314', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '若宮町', 'ワカミヤチョウ', null, '新花屋町通若宮西入', null, null);
INSERT INTO `ms_addresses` VALUES ('65333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区若宮町新花屋町通若宮東入', '26', '26106', '6008314', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '若宮町', 'ワカミヤチョウ', null, '新花屋町通若宮東入', null, null);
INSERT INTO `ms_addresses` VALUES ('65334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区若宮町六条通新町西入', '26', '26106', '6008314', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '若宮町', 'ワカミヤチョウ', null, '六条通新町西入', null, null);
INSERT INTO `ms_addresses` VALUES ('65335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区若宮町六条通西洞院東入', '26', '26106', '6008314', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '若宮町', 'ワカミヤチョウ', null, '六条通西洞院東入', null, null);
INSERT INTO `ms_addresses` VALUES ('65336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区若宮町六条通若宮西入', '26', '26106', '6008314', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '若宮町', 'ワカミヤチョウ', null, '六条通若宮西入', null, null);
INSERT INTO `ms_addresses` VALUES ('65337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区若宮町六条通若宮東入', '26', '26106', '6008314', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '若宮町', 'ワカミヤチョウ', null, '六条通若宮東入', null, null);
INSERT INTO `ms_addresses` VALUES ('65338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区若宮町若宮通新花屋町上る', '26', '26106', '6008314', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '若宮町', 'ワカミヤチョウ', null, '若宮通新花屋町上る', null, null);
INSERT INTO `ms_addresses` VALUES ('65339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区若宮町若宮通新花屋町下る', '26', '26106', '6008314', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '若宮町', 'ワカミヤチョウ', null, '若宮通新花屋町下る', null, null);
INSERT INTO `ms_addresses` VALUES ('65340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区若宮町若宮通花屋町上る', '26', '26106', '6008314', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '若宮町', 'ワカミヤチョウ', null, '若宮通花屋町上る', null, null);
INSERT INTO `ms_addresses` VALUES ('65341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区若宮町若宮通花屋町下る', '26', '26106', '6008314', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '若宮町', 'ワカミヤチョウ', null, '若宮通花屋町下る', null, null);
INSERT INTO `ms_addresses` VALUES ('65342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区若宮町若宮通六条下る', '26', '26106', '6008314', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '若宮町', 'ワカミヤチョウ', null, '若宮通六条下る', null, null);
INSERT INTO `ms_addresses` VALUES ('65343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区東松屋町', '26', '26106', '6008315', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '東松屋町', 'ヒガシマツヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区四本松町', '26', '26106', '6008316', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '四本松町', 'シホンマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区鍵屋町北小路通西洞院東入', '26', '26106', '6008317', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '鍵屋町', 'カギヤチョウ', null, '北小路通西洞院東入', null, null);
INSERT INTO `ms_addresses` VALUES ('65346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区鍵屋町北小路通若宮西入', '26', '26106', '6008317', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '鍵屋町', 'カギヤチョウ', null, '北小路通若宮西入', null, null);
INSERT INTO `ms_addresses` VALUES ('65347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区鍵屋町正面通新町西入', '26', '26106', '6008317', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '鍵屋町', 'カギヤチョウ', null, '正面通新町西入', null, null);
INSERT INTO `ms_addresses` VALUES ('65348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区鍵屋町若宮通正面下る', '26', '26106', '6008317', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '鍵屋町', 'カギヤチョウ', null, '若宮通正面下る', null, null);
INSERT INTO `ms_addresses` VALUES ('65349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区鍵屋町若宮通北小路上る', '26', '26106', '6008317', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '鍵屋町', 'カギヤチョウ', null, '若宮通北小路上る', null, null);
INSERT INTO `ms_addresses` VALUES ('65350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区鍵屋町正面通若宮東入', '26', '26106', '6008317', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '鍵屋町', 'カギヤチョウ', null, '正面通若宮東入', null, null);
INSERT INTO `ms_addresses` VALUES ('65351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区井筒町', '26', '26106', '6008318', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '井筒町', 'イヅツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区竹屋町若宮通北小路下る', '26', '26106', '6008319', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '竹屋町', 'タケヤチョウ', null, '若宮通北小路下る', null, null);
INSERT INTO `ms_addresses` VALUES ('65353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区竹屋町若宮通七条上る', '26', '26106', '6008319', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '竹屋町', 'タケヤチョウ', null, '若宮通七条上る', null, null);
INSERT INTO `ms_addresses` VALUES ('65354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区福本町', '26', '26106', '6008320', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '福本町', 'フクモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区八百屋町西洞院通楊梅上る', '26', '26106', '6008321', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '八百屋町', 'ヤオヤチョウ', null, '西洞院通楊梅上る', null, null);
INSERT INTO `ms_addresses` VALUES ('65356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区八百屋町西洞院通楊梅下る', '26', '26106', '6008321', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '八百屋町', 'ヤオヤチョウ', null, '西洞院通楊梅下る', null, null);
INSERT INTO `ms_addresses` VALUES ('65357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区八百屋町楊梅通西洞院東入', '26', '26106', '6008321', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '八百屋町', 'ヤオヤチョウ', null, '楊梅通西洞院東入', null, null);
INSERT INTO `ms_addresses` VALUES ('65358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区八百屋町楊梅通若宮西入', '26', '26106', '6008321', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '八百屋町', 'ヤオヤチョウ', null, '楊梅通若宮西入', null, null);
INSERT INTO `ms_addresses` VALUES ('65359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区小柳町', '26', '26106', '6008322', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '小柳町', 'コヤナギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区金屋町', '26', '26106', '6008323', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '金屋町', 'カナヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区東側町', '26', '26106', '6008324', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '東側町', 'ヒガシガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区西側町', '26', '26106', '6008325', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '西側町', 'ニシガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区西松屋町', '26', '26106', '6008326', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '西松屋町', 'ニシマツヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区西洞院町', '26', '26106', '6008327', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '西洞院町', 'ニシノトウインチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区蛭子水町', '26', '26106', '6008328', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '蛭子水町', 'エビスミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区鍛冶屋町北小路通西洞院西入', '26', '26106', '6008329', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '鍛冶屋町', 'カジヤチョウ', null, '北小路通西洞院西入', null, null);
INSERT INTO `ms_addresses` VALUES ('65367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区鍛冶屋町北小路通西洞院東入', '26', '26106', '6008329', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '鍛冶屋町', 'カジヤチョウ', null, '北小路通西洞院東入', null, null);
INSERT INTO `ms_addresses` VALUES ('65368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区鍛冶屋町西洞院通北小路上る', '26', '26106', '6008329', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '鍛冶屋町', 'カジヤチョウ', null, '西洞院通北小路上る', null, null);
INSERT INTO `ms_addresses` VALUES ('65369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区鍛冶屋町西洞院通正面下る', '26', '26106', '6008329', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '鍛冶屋町', 'カジヤチョウ', null, '西洞院通正面下る', null, null);
INSERT INTO `ms_addresses` VALUES ('65370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区金東横町', '26', '26106', '6008331', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '金東横町', 'キントウヨコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区中金仏町', '26', '26106', '6008332', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '中金仏町', 'ナカカナブツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区卜味金仏町', '26', '26106', '6008333', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '卜味金仏町', 'ボクミカナブツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区西若松町', '26', '26106', '6008334', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '西若松町', 'ニシワカマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区住吉町醒ケ井通高辻下る', '26', '26106', '6008335', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '住吉町', 'スミヨシチョウ', null, '醒ケ井通高辻下る', null, null);
INSERT INTO `ms_addresses` VALUES ('65375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区住吉町醒ケ井通松原上る', '26', '26106', '6008335', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '住吉町', 'スミヨシチョウ', null, '醒ケ井通松原上る', null, null);
INSERT INTO `ms_addresses` VALUES ('65376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区元日町', '26', '26106', '6008336', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '元日町', 'ガンジツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区佐女牛井町', '26', '26106', '6008337', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '佐女牛井町', 'サメガイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区泉水町', '26', '26106', '6008338', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '泉水町', 'センスイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区花屋町花屋町通油小路西入', '26', '26106', '6008340', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '花屋町', 'ハナヤチョウ', null, '花屋町通油小路西入', null, null);
INSERT INTO `ms_addresses` VALUES ('65380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区学林町', '26', '26106', '6008341', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '学林町', 'ガクリンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区山川町', '26', '26106', '6008342', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '山川町', 'ヤマカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区植松町正面通西洞院西入', '26', '26106', '6008343', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '植松町', 'ウエマツチョウ', null, '正面通西洞院西入', null, null);
INSERT INTO `ms_addresses` VALUES ('65383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区植松町西洞院通正面下る', '26', '26106', '6008343', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '植松町', 'ウエマツチョウ', null, '西洞院通正面下る', null, null);
INSERT INTO `ms_addresses` VALUES ('65384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区柳町', '26', '26106', '6008344', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '柳町', 'ヤナギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区紅葉町', '26', '26106', '6008345', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '紅葉町', 'モミジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区玉本町', '26', '26106', '6008346', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '玉本町', 'タマモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区仏具屋町油小路通正面上る', '26', '26106', '6008347', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '仏具屋町', 'ブツグヤチョウ', null, '油小路通正面上る', null, null);
INSERT INTO `ms_addresses` VALUES ('65388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区仏具屋町油小路通花屋町下る', '26', '26106', '6008347', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '仏具屋町', 'ブツグヤチョウ', null, '油小路通花屋町下る', null, null);
INSERT INTO `ms_addresses` VALUES ('65389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区仏具屋町正面通油小路東入', '26', '26106', '6008347', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '仏具屋町', 'ブツグヤチョウ', null, '正面通油小路東入', null, null);
INSERT INTO `ms_addresses` VALUES ('65390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区仏具屋町花屋町通油小路東入', '26', '26106', '6008347', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '仏具屋町', 'ブツグヤチョウ', null, '花屋町通油小路東入', null, null);
INSERT INTO `ms_addresses` VALUES ('65391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区珠数屋町', '26', '26106', '6008348', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '珠数屋町', 'ジュズヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区堺町堀川通旧花屋町東入', '26', '26106', '6008349', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '堺町', 'サカイチョウ', '（－チョウ）', '堀川通旧花屋町東入', null, null);
INSERT INTO `ms_addresses` VALUES ('65393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区堺町堀川通旧花屋町東入下る', '26', '26106', '6008349', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '堺町', 'サカイチョウ', '（－チョウ）', '堀川通旧花屋町東入下る', null, null);
INSERT INTO `ms_addresses` VALUES ('65394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区堺町堀川通正面上る', '26', '26106', '6008349', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '堺町', 'サカイチョウ', '（－チョウ）', '堀川通正面上る', null, null);
INSERT INTO `ms_addresses` VALUES ('65395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区富永町岩上通高辻上る', '26', '26106', '6008351', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '富永町', 'トミナガチョウ', null, '岩上通高辻上る', null, null);
INSERT INTO `ms_addresses` VALUES ('65396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区富永町岩上通高辻下る', '26', '26106', '6008351', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '富永町', 'トミナガチョウ', null, '岩上通高辻下る', null, null);
INSERT INTO `ms_addresses` VALUES ('65397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区富永町高辻通猪熊東入', '26', '26106', '6008351', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '富永町', 'トミナガチョウ', null, '高辻通猪熊東入', null, null);
INSERT INTO `ms_addresses` VALUES ('65398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区富永町高辻通岩上西入', '26', '26106', '6008351', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '富永町', 'トミナガチョウ', null, '高辻通岩上西入', null, null);
INSERT INTO `ms_addresses` VALUES ('65399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区富永町高辻通岩上東入', '26', '26106', '6008351', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '富永町', 'トミナガチョウ', null, '高辻通岩上東入', null, null);
INSERT INTO `ms_addresses` VALUES ('65400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区富永町高辻通西堀川西入', '26', '26106', '6008351', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '富永町', 'トミナガチョウ', null, '高辻通西堀川西入', null, null);
INSERT INTO `ms_addresses` VALUES ('65401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区富永町高辻通堀川西入', '26', '26106', '6008351', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '富永町', 'トミナガチョウ', null, '高辻通堀川西入', null, null);
INSERT INTO `ms_addresses` VALUES ('65402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区吉文字町岩上通松原上る', '26', '26106', '6008352', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '吉文字町', 'キチモンジチョウ', null, '岩上通松原上る', null, null);
INSERT INTO `ms_addresses` VALUES ('65403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区吉文字町岩上通高辻下る', '26', '26106', '6008352', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '吉文字町', 'キチモンジチョウ', null, '岩上通高辻下る', null, null);
INSERT INTO `ms_addresses` VALUES ('65404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区高辻猪熊町', '26', '26106', '6008353', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '高辻猪熊町', 'タカツジイノクマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区十文字町', '26', '26106', '6008354', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '十文字町', 'ジュウモンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区来迎堂町', '26', '26106', '6008355', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '来迎堂町', 'ライコウドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区北門前町', '26', '26106', '6008356', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '北門前町', 'キタモンゼンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区柿本町', '26', '26106', '6008357', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '柿本町', 'カキモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区門前町', '26', '26106', '6008358', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '門前町', 'モンゼンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区丸屋町綾小路通猪熊西入', '26', '26106', '6008359', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '丸屋町', 'マルヤチョウ', null, '綾小路通猪熊西入', null, null);
INSERT INTO `ms_addresses` VALUES ('65411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区丸屋町綾小路通大宮東入', '26', '26106', '6008359', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '丸屋町', 'マルヤチョウ', null, '綾小路通大宮東入', null, null);
INSERT INTO `ms_addresses` VALUES ('65412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区丸屋町綾小路通黒門西入', '26', '26106', '6008359', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '丸屋町', 'マルヤチョウ', null, '綾小路通黒門西入', null, null);
INSERT INTO `ms_addresses` VALUES ('65413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区丸屋町綾小路通黒門東入', '26', '26106', '6008359', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '丸屋町', 'マルヤチョウ', null, '綾小路通黒門東入', null, null);
INSERT INTO `ms_addresses` VALUES ('65414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区丸屋町猪熊通綾小路上る', '26', '26106', '6008359', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '丸屋町', 'マルヤチョウ', null, '猪熊通綾小路上る', null, null);
INSERT INTO `ms_addresses` VALUES ('65415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区丸屋町黒門通綾小路上る', '26', '26106', '6008359', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '丸屋町', 'マルヤチョウ', null, '黒門通綾小路上る', null, null);
INSERT INTO `ms_addresses` VALUES ('65416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区丸屋町黒門通綾小路下る', '26', '26106', '6008359', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '丸屋町', 'マルヤチョウ', null, '黒門通綾小路下る', null, null);
INSERT INTO `ms_addresses` VALUES ('65417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区堀之上町', '26', '26106', '6008361', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '堀之上町', 'ホリノガミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区中堂寺前町', '26', '26106', '6008362', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '中堂寺前町', 'チュウドウジマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区大宮1丁目', '26', '26106', '6008363', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '大宮', 'オオミヤ', null, null, '1丁目', '01チョウメ');
INSERT INTO `ms_addresses` VALUES ('65420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区大宮2丁目', '26', '26106', '6008363', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '大宮', 'オオミヤ', null, null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('65421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区大宮3丁目', '26', '26106', '6008363', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '大宮', 'オオミヤ', null, null, '3丁目', '03チョウメ');
INSERT INTO `ms_addresses` VALUES ('65422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区突抜', '26', '26106', '6008364', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '突抜', 'ツキヌケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区丹波街道町', '26', '26106', '6008365', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '丹波街道町', 'タンバカイドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区西門前町', '26', '26106', '6008371', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '西門前町', 'ニシモンゼンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区南門前町', '26', '26106', '6008372', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '南門前町', 'ミナミモンゼンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区下五条町', '26', '26106', '6008373', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '下五条町', 'シモゴジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区藪之内町', '26', '26106', '6008374', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '藪之内町', 'ヤブノウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区下長福寺町', '26', '26106', '6008375', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '下長福寺町', 'シモチョウフクジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区上長福寺町', '26', '26106', '6008376', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '上長福寺町', 'カミチョウフクジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区上五条町', '26', '26106', '6008377', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '上五条町', 'カミゴジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区下り松町', '26', '26106', '6008381', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '下り松町', 'サガリマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区塩屋町黒門通綾小路下る', '26', '26106', '6008382', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '塩屋町', 'シオヤチョウ', null, '黒門通綾小路下る', null, null);
INSERT INTO `ms_addresses` VALUES ('65433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区塩屋町黒門通仏光寺上る', '26', '26106', '6008382', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '塩屋町', 'シオヤチョウ', null, '黒門通仏光寺上る', null, null);
INSERT INTO `ms_addresses` VALUES ('65434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区綾大宮町', '26', '26106', '6008383', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '綾大宮町', 'アヤオオミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区今大黒町', '26', '26106', '6008384', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '今大黒町', 'イマダイコクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区五坊大宮町', '26', '26106', '6008385', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '五坊大宮町', 'ゴボウオオミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区杉蛭子町', '26', '26106', '6008386', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '杉蛭子町', 'スギエビスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区高辻大宮町', '26', '26106', '6008387', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '高辻大宮町', 'タカツジオオミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区坊門町', '26', '26106', '6008388', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '坊門町', 'ボウモンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区四条大宮町', '26', '26106', '6008389', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '四条大宮町', 'シジョウオオミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区松本町綾小路通猪熊東入', '26', '26106', '6008390', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '松本町', 'マツモトチョウ', null, '綾小路通猪熊東入', null, null);
INSERT INTO `ms_addresses` VALUES ('65442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区松本町猪熊通綾小路上る', '26', '26106', '6008390', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '松本町', 'マツモトチョウ', null, '猪熊通綾小路上る', null, null);
INSERT INTO `ms_addresses` VALUES ('65443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区松本町猪熊通四条下る', '26', '26106', '6008390', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '松本町', 'マツモトチョウ', null, '猪熊通四条下る', null, null);
INSERT INTO `ms_addresses` VALUES ('65444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区佐竹町', '26', '26106', '6008391', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '佐竹町', 'サタケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区妙満寺町', '26', '26106', '6008392', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '妙満寺町', 'ミョウマンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区雁金町岩上通綾小路下る', '26', '26106', '6008393', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '雁金町', 'カリガネチョウ', null, '岩上通綾小路下る', null, null);
INSERT INTO `ms_addresses` VALUES ('65447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区雁金町岩上通仏光寺上る', '26', '26106', '6008393', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '雁金町', 'カリガネチョウ', null, '岩上通仏光寺上る', null, null);
INSERT INTO `ms_addresses` VALUES ('65448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区晒屋町', '26', '26106', '6008394', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '晒屋町', 'サラシヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区徳屋町', '26', '26106', '6008395', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '徳屋町', 'トクヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区槌屋町', '26', '26106', '6008396', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '槌屋町', 'ツチヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区西田町', '26', '26106', '6008397', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '西田町', 'ニシダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区瀬戸屋町', '26', '26106', '6008398', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '瀬戸屋町', 'セトヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区丸屋町北小路通西中筋東入', '26', '26106', '6008399', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '丸屋町', 'マルヤチョウ', null, '北小路通西中筋東入', null, null);
INSERT INTO `ms_addresses` VALUES ('65454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区丸屋町西中筋通北小路上る', '26', '26106', '6008399', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '丸屋町', 'マルヤチョウ', null, '西中筋通北小路上る', null, null);
INSERT INTO `ms_addresses` VALUES ('65455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区丸屋町西中筋通正面下る', '26', '26106', '6008399', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '丸屋町', 'マルヤチョウ', null, '西中筋通正面下る', null, null);
INSERT INTO `ms_addresses` VALUES ('65456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区丸屋町北小路通堀川東入', '26', '26106', '6008399', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '丸屋町', 'マルヤチョウ', null, '北小路通堀川東入', null, null);
INSERT INTO `ms_addresses` VALUES ('65457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区丸屋町堀川通北小路上る', '26', '26106', '6008399', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '丸屋町', 'マルヤチョウ', null, '堀川通北小路上る', null, null);
INSERT INTO `ms_addresses` VALUES ('65458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区丸屋町堀川通正面下る', '26', '26106', '6008399', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '丸屋町', 'マルヤチョウ', null, '堀川通正面下る', null, null);
INSERT INTO `ms_addresses` VALUES ('65459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区燈籠町', '26', '26106', '6008401', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '燈籠町', 'トウロウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区大江町', '26', '26106', '6008402', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '大江町', 'オオエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区吉水町不明門通松原下る', '26', '26106', '6008403', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '吉水町', 'ヨシミズチョウ', null, '不明門通松原下る', null, null);
INSERT INTO `ms_addresses` VALUES ('65462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区吉水町不明門通万寿寺上る', '26', '26106', '6008403', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '吉水町', 'ヨシミズチョウ', null, '不明門通万寿寺上る', null, null);
INSERT INTO `ms_addresses` VALUES ('65463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区福田寺町', '26', '26106', '6008404', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '福田寺町', 'フクデンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区万寿寺中之町', '26', '26106', '6008405', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '万寿寺中之町', 'マンジュウジナカノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区亀屋町高倉通五条上る', '26', '26106', '6008406', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '亀屋町', 'カメヤチョウ', null, '高倉通五条上る', null, null);
INSERT INTO `ms_addresses` VALUES ('65466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区亀屋町高倉通万寿寺下る', '26', '26106', '6008406', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '亀屋町', 'カメヤチョウ', null, '高倉通万寿寺下る', null, null);
INSERT INTO `ms_addresses` VALUES ('65467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区朝妻町', '26', '26106', '6008407', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '朝妻町', 'アサヅマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区深草町', '26', '26106', '6008408', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '深草町', 'フカクサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区玉屋町', '26', '26106', '6008409', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '玉屋町', 'タマヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区悪王子町', '26', '26106', '6008410', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '悪王子町', 'アクオウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区水銀屋町', '26', '26106', '6008411', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '水銀屋町', 'スイギンヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区二帖半敷町', '26', '26106', '6008412', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '二帖半敷町', 'ニジョウハンジキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区大政所町', '26', '26106', '6008413', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '大政所町', 'オオマンドコロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区匂天神町', '26', '26106', '6008414', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '匂天神町', 'ニオイテンジンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区因幡堂町', '26', '26106', '6008415', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '因幡堂町', 'イナバドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区薬師前町', '26', '26106', '6008416', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '薬師前町', 'ヤクシマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区俊成町', '26', '26106', '6008417', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '俊成町', 'シュンゼイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区五条烏丸町', '26', '26106', '6008418', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '五条烏丸町', 'ゴジョウカラスマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区大堀町', '26', '26106', '6008419', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '大堀町', 'オオボリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区高砂町', '26', '26106', '6008420', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '高砂町', 'タカサゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区童侍者町', '26', '26106', '6008421', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '童侍者町', 'ドウジシャチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区白楽天町', '26', '26106', '6008422', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '白楽天町', 'ハクラクテンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区釘隠町', '26', '26106', '6008423', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '釘隠町', 'クギカクシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区山王町室町通高辻上る', '26', '26106', '6008424', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '山王町', 'サンノウチョウ', null, '室町通高辻上る', null, null);
INSERT INTO `ms_addresses` VALUES ('65485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区山王町室町通仏光寺下る', '26', '26106', '6008424', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '山王町', 'サンノウチョウ', null, '室町通仏光寺下る', null, null);
INSERT INTO `ms_addresses` VALUES ('65486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区骨屋町諏訪町通高辻上る', '26', '26106', '6008425', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '骨屋町', 'ホネヤチョウ', null, '諏訪町通高辻上る', null, null);
INSERT INTO `ms_addresses` VALUES ('65487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区骨屋町諏訪町通高辻下る', '26', '26106', '6008425', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '骨屋町', 'ホネヤチョウ', null, '諏訪町通高辻下る', null, null);
INSERT INTO `ms_addresses` VALUES ('65488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区骨屋町高辻通烏丸西入', '26', '26106', '6008425', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '骨屋町', 'ホネヤチョウ', null, '高辻通烏丸西入', null, null);
INSERT INTO `ms_addresses` VALUES ('65489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区骨屋町高辻通室町東入', '26', '26106', '6008425', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '骨屋町', 'ホネヤチョウ', null, '高辻通室町東入', null, null);
INSERT INTO `ms_addresses` VALUES ('65490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区小島町', '26', '26106', '6008426', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '小島町', 'コジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区玉津島町', '26', '26106', '6008427', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '玉津島町', 'タマツシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区弁財天町', '26', '26106', '6008428', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '弁財天町', 'ベンザイテンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区御供石町', '26', '26106', '6008429', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '御供石町', 'ゴクイシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区小田原町', '26', '26106', '6008430', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '小田原町', 'オダワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区善長寺町', '26', '26106', '6008431', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '善長寺町', 'ゼンチョウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区糸屋町', '26', '26106', '6008432', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '糸屋町', 'イトヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区繁昌町', '26', '26106', '6008433', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '繁昌町', 'ハンジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区高辻町', '26', '26106', '6008434', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '高辻町', 'タカツジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区中野之町', '26', '26106', '6008435', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '中野之町', 'ナカノノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区元両替町', '26', '26106', '6008436', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '元両替町', 'モトリョウガエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区徳万町', '26', '26106', '6008437', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '徳万町', 'トクマンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区長刀切町', '26', '26106', '6008438', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '長刀切町', 'ナギナタギリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区坂東屋町', '26', '26106', '6008439', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '坂東屋町', 'バントウヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区材木町新町通五条上る', '26', '26106', '6008440', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '材木町', 'ザイモクチョウ', null, '新町通五条上る', null, null);
INSERT INTO `ms_addresses` VALUES ('65505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区材木町新町通万寿寺下る', '26', '26106', '6008440', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '材木町', 'ザイモクチョウ', null, '新町通万寿寺下る', null, null);
INSERT INTO `ms_addresses` VALUES ('65506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区材木町万寿寺通新町西入', '26', '26106', '6008440', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '材木町', 'ザイモクチョウ', null, '万寿寺通新町西入', null, null);
INSERT INTO `ms_addresses` VALUES ('65507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区材木町万寿寺通新町東入', '26', '26106', '6008440', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '材木町', 'ザイモクチョウ', null, '万寿寺通新町東入', null, null);
INSERT INTO `ms_addresses` VALUES ('65508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区四条町', '26', '26106', '6008441', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '四条町', 'シジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区矢田町', '26', '26106', '6008442', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '矢田町', 'ヤダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区船鉾町', '26', '26106', '6008443', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '船鉾町', 'フナボコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区菅大臣町', '26', '26106', '6008444', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '菅大臣町', 'カンダイジンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区岩戸山町', '26', '26106', '6008445', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '岩戸山町', 'イワトヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区堀之内町', '26', '26106', '6008446', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '堀之内町', 'ホリノウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区御影町', '26', '26106', '6008447', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '御影町', 'ミカゲチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区藪下町', '26', '26106', '6008448', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '藪下町', 'ヤブシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区富永町新町通松原下る', '26', '26106', '6008449', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '富永町', 'トミナガチョウ', null, '新町通松原下る', null, null);
INSERT INTO `ms_addresses` VALUES ('65517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区富永町新町通万寿寺上る', '26', '26106', '6008449', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '富永町', 'トミナガチョウ', null, '新町通万寿寺上る', null, null);
INSERT INTO `ms_addresses` VALUES ('65518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区富永町万寿寺通新町西入', '26', '26106', '6008449', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '富永町', 'トミナガチョウ', null, '万寿寺通新町西入', null, null);
INSERT INTO `ms_addresses` VALUES ('65519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区富永町万寿寺通新町東入', '26', '26106', '6008449', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '富永町', 'トミナガチョウ', null, '万寿寺通新町東入', null, null);
INSERT INTO `ms_addresses` VALUES ('65520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区亀屋町若宮通松原下る', '26', '26106', '6008451', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '亀屋町', 'カメヤチョウ', null, '若宮通松原下る', null, null);
INSERT INTO `ms_addresses` VALUES ('65521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区亀屋町若宮通万寿寺上る', '26', '26106', '6008451', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '亀屋町', 'カメヤチョウ', null, '若宮通万寿寺上る', null, null);
INSERT INTO `ms_addresses` VALUES ('65522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区永倉町', '26', '26106', '6008452', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '永倉町', 'ナガクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区月見町', '26', '26106', '6008453', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '月見町', 'ツキミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区布屋町', '26', '26106', '6008454', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '布屋町', 'ヌノヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区八幡町', '26', '26106', '6008455', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '八幡町', 'ヤワタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区天使突抜', '26', '26106', '6008456', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '天使突抜', 'テンシツキヌケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区上金仏町', '26', '26106', '6008457', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '上金仏町', 'カミカナブツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区樋口町', '26', '26106', '6008458', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '樋口町', 'ヒグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区天神前町', '26', '26106', '6008459', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '天神前町', 'テンジンマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区荒神町', '26', '26106', '6008460', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '荒神町', 'コウジンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区木賊山町', '26', '26106', '6008461', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '木賊山町', 'トクサヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区本柳水町', '26', '26106', '6008462', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '本柳水町', 'ホンリュウスイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区永養寺町', '26', '26106', '6008463', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '永養寺町', 'エイヨウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区菊屋町高辻通新町西入下る', '26', '26106', '6008464', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '菊屋町', 'キクヤチョウ', null, '高辻通新町西入下る', null, null);
INSERT INTO `ms_addresses` VALUES ('65535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区菊屋町高辻通西洞院東入下る', '26', '26106', '6008464', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '菊屋町', 'キクヤチョウ', null, '高辻通西洞院東入下る', null, null);
INSERT INTO `ms_addresses` VALUES ('65536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区菊屋町若宮通高辻下る', '26', '26106', '6008464', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '菊屋町', 'キクヤチョウ', null, '若宮通高辻下る', null, null);
INSERT INTO `ms_addresses` VALUES ('65537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区菊屋町若宮通松原上る', '26', '26106', '6008464', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '菊屋町', 'キクヤチョウ', null, '若宮通松原上る', null, null);
INSERT INTO `ms_addresses` VALUES ('65538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区高辻西洞院町', '26', '26106', '6008465', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '高辻西洞院町', 'タカツジニシノトウインチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区舟屋町', '26', '26106', '6008466', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '舟屋町', 'フナヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区麓町', '26', '26106', '6008467', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '麓町', 'フモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区住吉町新花屋町通西中筋東入', '26', '26106', '6008468', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '住吉町', 'スミヨシチョウ', null, '新花屋町通西中筋東入', null, null);
INSERT INTO `ms_addresses` VALUES ('65542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区住吉町西中筋通新花屋町上る', '26', '26106', '6008468', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '住吉町', 'スミヨシチョウ', null, '西中筋通新花屋町上る', null, null);
INSERT INTO `ms_addresses` VALUES ('65543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区住吉町西中筋通新花屋町下る', '26', '26106', '6008468', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '住吉町', 'スミヨシチョウ', null, '西中筋通新花屋町下る', null, null);
INSERT INTO `ms_addresses` VALUES ('65544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区住吉町西中筋通花屋町上る', '26', '26106', '6008468', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '住吉町', 'スミヨシチョウ', null, '西中筋通花屋町上る', null, null);
INSERT INTO `ms_addresses` VALUES ('65545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区住吉町西中筋通六条下る', '26', '26106', '6008468', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '住吉町', 'スミヨシチョウ', null, '西中筋通六条下る', null, null);
INSERT INTO `ms_addresses` VALUES ('65546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区住吉町新花屋町通堀川東入', '26', '26106', '6008468', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '住吉町', 'スミヨシチョウ', null, '新花屋町通堀川東入', null, null);
INSERT INTO `ms_addresses` VALUES ('65547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区住吉町堀川通新花屋町上る', '26', '26106', '6008468', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '住吉町', 'スミヨシチョウ', null, '堀川通新花屋町上る', null, null);
INSERT INTO `ms_addresses` VALUES ('65548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区住吉町堀川通新花屋町下る', '26', '26106', '6008468', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '住吉町', 'スミヨシチョウ', null, '堀川通新花屋町下る', null, null);
INSERT INTO `ms_addresses` VALUES ('65549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区住吉町堀川通花屋町上る', '26', '26106', '6008468', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '住吉町', 'スミヨシチョウ', null, '堀川通花屋町上る', null, null);
INSERT INTO `ms_addresses` VALUES ('65550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区住吉町堀川通六条下る', '26', '26106', '6008468', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '住吉町', 'スミヨシチョウ', null, '堀川通六条下る', null, null);
INSERT INTO `ms_addresses` VALUES ('65551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区太子山町', '26', '26106', '6008469', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '太子山町', 'タイシヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区新釜座町', '26', '26106', '6008471', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '新釜座町', 'シンカマンザチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区妙伝寺町', '26', '26106', '6008472', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '妙伝寺町', 'ミョウデンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区芦刈山町', '26', '26106', '6008473', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '芦刈山町', 'アシカリヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区綾西洞院町', '26', '26106', '6008474', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '綾西洞院町', 'アヤニシノトウインチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区風早町', '26', '26106', '6008475', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '風早町', 'カザハヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区喜吉町', '26', '26106', '6008476', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '喜吉町', 'キヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区要法寺町', '26', '26106', '6008477', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '要法寺町', 'ヨウホウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区西綾小路西半町', '26', '26106', '6008478', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '西綾小路西半町', 'ニシアヤノコウジニシハンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区西綾小路東半町', '26', '26106', '6008479', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '西綾小路東半町', 'ニシアヤノコウジヒガシハンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区小泉町', '26', '26106', '6008480', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '小泉町', 'コイズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区四条堀川町', '26', '26106', '6008481', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '四条堀川町', 'シジョウホリカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区綾堀川町', '26', '26106', '6008482', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '綾堀川町', 'アヤホリカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区吉水町西堀川通高辻上る', '26', '26106', '6008483', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '吉水町', 'ヨシミズチョウ', null, '西堀川通高辻上る', null, null);
INSERT INTO `ms_addresses` VALUES ('65565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区吉水町西堀川通仏光寺下る', '26', '26106', '6008483', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '吉水町', 'ヨシミズチョウ', null, '西堀川通仏光寺下る', null, null);
INSERT INTO `ms_addresses` VALUES ('65566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区吉水町東堀川通高辻上る', '26', '26106', '6008483', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '吉水町', 'ヨシミズチョウ', null, '東堀川通高辻上る', null, null);
INSERT INTO `ms_addresses` VALUES ('65567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区吉水町東堀川通仏光寺下る', '26', '26106', '6008483', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '吉水町', 'ヨシミズチョウ', null, '東堀川通仏光寺下る', null, null);
INSERT INTO `ms_addresses` VALUES ('65568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区吉水町仏光寺通東堀川東入', '26', '26106', '6008483', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '吉水町', 'ヨシミズチョウ', null, '仏光寺通東堀川東入', null, null);
INSERT INTO `ms_addresses` VALUES ('65569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区吉水町堀川通仏光寺下る', '26', '26106', '6008483', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '吉水町', 'ヨシミズチョウ', null, '堀川通仏光寺下る', null, null);
INSERT INTO `ms_addresses` VALUES ('65570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区西高辻町', '26', '26106', '6008484', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '西高辻町', 'ニシタカツジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区五軒町', '26', '26106', '6008485', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '五軒町', 'ゴケンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区高辻堀川町', '26', '26106', '6008486', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '高辻堀川町', 'タカツジホリカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区橘町醒ケ井通松原上る', '26', '26106', '6008487', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '橘町', 'タチバナチョウ', null, '醒ケ井通松原上る', null, null);
INSERT INTO `ms_addresses` VALUES ('65574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区橘町醒ケ井通松原下る', '26', '26106', '6008487', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '橘町', 'タチバナチョウ', null, '醒ケ井通松原下る', null, null);
INSERT INTO `ms_addresses` VALUES ('65575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区橘町松原通油小路西入', '26', '26106', '6008487', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '橘町', 'タチバナチョウ', null, '松原通油小路西入', null, null);
INSERT INTO `ms_addresses` VALUES ('65576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区橘町松原通醒ケ井西入', '26', '26106', '6008487', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '橘町', 'タチバナチョウ', null, '松原通醒ケ井西入', null, null);
INSERT INTO `ms_addresses` VALUES ('65577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区橘町松原通醒ケ井東入', '26', '26106', '6008487', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '橘町', 'タチバナチョウ', null, '松原通醒ケ井東入', null, null);
INSERT INTO `ms_addresses` VALUES ('65578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区橘町松原通東堀川東入', '26', '26106', '6008487', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '橘町', 'タチバナチョウ', null, '松原通東堀川東入', null, null);
INSERT INTO `ms_addresses` VALUES ('65579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区橘町松原通堀川東入', '26', '26106', '6008487', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '橘町', 'タチバナチョウ', null, '松原通堀川東入', null, null);
INSERT INTO `ms_addresses` VALUES ('65580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区篠屋町', '26', '26106', '6008488', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '篠屋町', 'ササヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区橋橘町', '26', '26106', '6008489', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '橋橘町', 'ハシタチバナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区立中町', '26', '26106', '6008490', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '立中町', 'タツナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区鶏鉾町', '26', '26106', '6008491', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '鶏鉾町', 'ニワトリボコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区月鉾町', '26', '26106', '6008492', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '月鉾町', 'ツキホコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区郭巨山町', '26', '26106', '6008493', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '郭巨山町', 'カクキョヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区傘鉾町', '26', '26106', '6008494', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '傘鉾町', 'カサボコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区藤本寄町', '26', '26106', '6008495', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '藤本寄町', 'フジモトヨリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区石井筒町', '26', '26106', '6008496', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '石井筒町', 'イシイヅツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区高野堂町', '26', '26106', '6008497', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '高野堂町', 'コウヤドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区柏屋町四条通油小路西入', '26', '26106', '6008498', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '柏屋町', 'カシワヤチョウ', null, '四条通油小路西入', null, null);
INSERT INTO `ms_addresses` VALUES ('65591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区柏屋町四条通醒ケ井西入', '26', '26106', '6008498', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '柏屋町', 'カシワヤチョウ', null, '四条通醒ケ井西入', null, null);
INSERT INTO `ms_addresses` VALUES ('65592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区柏屋町四条通醒ケ井東入', '26', '26106', '6008498', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '柏屋町', 'カシワヤチョウ', null, '四条通醒ケ井東入', null, null);
INSERT INTO `ms_addresses` VALUES ('65593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区柏屋町四条通東堀川東入', '26', '26106', '6008498', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '柏屋町', 'カシワヤチョウ', null, '四条通東堀川東入', null, null);
INSERT INTO `ms_addresses` VALUES ('65594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区柏屋町四条通堀川東入', '26', '26106', '6008498', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '柏屋町', 'カシワヤチョウ', null, '四条通堀川東入', null, null);
INSERT INTO `ms_addresses` VALUES ('65595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区唐津屋町', '26', '26106', '6008499', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '唐津屋町', 'カラツヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区中堂寺西寺町', '26', '26106', '6008801', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '中堂寺西寺町', 'チュウドウジニシデラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区中堂寺櫛笥町', '26', '26106', '6008802', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '中堂寺櫛笥町', 'チュウドウジクシゲチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区中堂寺薮ノ内町', '26', '26106', '6008803', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '中堂寺薮ノ内町', 'チュウドウジヤブノウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区中堂寺前田町', '26', '26106', '6008804', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '中堂寺前田町', 'チュウドウジマエダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区中堂寺鍵田町', '26', '26106', '6008805', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '中堂寺鍵田町', 'チュウドウジカギタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区中堂寺壬生川町', '26', '26106', '6008806', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '中堂寺壬生川町', 'チュウドウジミブガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区中堂寺命婦町', '26', '26106', '6008807', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '中堂寺命婦町', 'チュウドウジミョウブチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区中堂寺坊城町', '26', '26106', '6008811', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '中堂寺坊城町', 'チュウドウジボウジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区中堂寺北町', '26', '26106', '6008812', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '中堂寺北町', 'チュウドウジキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区中堂寺南町', '26', '26106', '6008813', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '中堂寺南町', 'チュウドウジミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区中堂寺庄ノ内町', '26', '26106', '6008814', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '中堂寺庄ノ内町', 'チュウドウジショウノウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区中堂寺粟田町', '26', '26106', '6008815', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '中堂寺粟田町', 'チュウドウジアワタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区西新屋敷中堂寺町', '26', '26106', '6008816', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '西新屋敷中堂寺町', 'ニシシンヤシキチュウドウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区小坂町', '26', '26106', '6008821', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '小坂町', 'コサカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区裏片町', '26', '26106', '6008822', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '裏片町', 'ウラカタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区薬園町', '26', '26106', '6008823', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '薬園町', 'ヤクエンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区二人司町', '26', '26106', '6008824', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '二人司町', 'ニニンツカサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区西新屋敷中之町', '26', '26106', '6008825', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '西新屋敷中之町', 'ニシシンヤシキナカノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区西新屋敷上之町', '26', '26106', '6008826', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '西新屋敷上之町', 'ニシシンヤシキカミノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区西新屋敷太夫町', '26', '26106', '6008827', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '西新屋敷太夫町', 'ニシシンヤシキタユウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区西新屋敷揚屋町', '26', '26106', '6008828', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '西新屋敷揚屋町', 'ニシシンヤシキアゲヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区西新屋敷下之町', '26', '26106', '6008829', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '西新屋敷下之町', 'ニシシンヤシキシモノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区花畑町', '26', '26106', '6008831', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '花畑町', 'ハナバタケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区諏訪開町', '26', '26106', '6008832', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '諏訪開町', 'スワビラキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区西酢屋町', '26', '26106', '6008833', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '西酢屋町', 'ニシスヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区和気町', '26', '26106', '6008834', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '和気町', 'ワキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区観喜寺町', '26', '26106', '6008835', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '観喜寺町', 'カンキジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区八条坊門町八条通大宮西入', '26', '26106', '6008836', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '八条坊門町', 'ハチジョウボウモンチョウ', null, '八条通大宮西入', null, null);
INSERT INTO `ms_addresses` VALUES ('65649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区夷馬場町', '26', '26106', '6008837', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '夷馬場町', 'エビスノバンバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区朱雀正会町', '26', '26106', '6008841', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '朱雀正会町', 'スジャクショウカイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区朱雀堂ノ口町', '26', '26106', '6008842', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '朱雀堂ノ口町', 'スジャクドウノクチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区朱雀内畑町', '26', '26106', '6008843', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '朱雀内畑町', 'スジャクウチハタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区朱雀裏畑町', '26', '26106', '6008844', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '朱雀裏畑町', 'スジャクウラハタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区朱雀北ノ口町', '26', '26106', '6008845', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '朱雀北ノ口町', 'スジャクキタノクチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区朱雀宝蔵町', '26', '26106', '6008846', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '朱雀宝蔵町', 'スジャクホウゾウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区朱雀分木町', '26', '26106', '6008847', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '朱雀分木町', 'スジャクブンキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区梅小路頭町', '26', '26106', '6008851', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '梅小路頭町', 'ウメコウジカシラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区梅小路東中町', '26', '26106', '6008852', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '梅小路東中町', 'ウメコウジヒガシナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区梅小路高畑町', '26', '26106', '6008853', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '梅小路高畑町', 'ウメコウジタカハタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区梅小路西中町', '26', '26106', '6008854', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '梅小路西中町', 'ウメコウジニシナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区梅小路石橋町', '26', '26106', '6008855', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '梅小路石橋町', 'ウメコウジイシバシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区梅小路本町', '26', '26106', '6008856', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '梅小路本町', 'ウメコウジホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区梅小路東町', '26', '26106', '6008857', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '梅小路東町', 'ウメコウジヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区七条御所ノ内北町', '26', '26106', '6008861', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '七条御所ノ内北町', 'シチジョウゴショノウチキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区七条御所ノ内中町', '26', '26106', '6008862', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '七条御所ノ内中町', 'シチジョウゴショノウチナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区七条御所ノ内本町', '26', '26106', '6008863', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '七条御所ノ内本町', 'シチジョウゴショノウチホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区七条御所ノ内南町', '26', '26106', '6008864', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '七条御所ノ内南町', 'シチジョウゴショノウチミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区七条御所ノ内西町', '26', '26106', '6008865', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '七条御所ノ内西町', 'シチジョウゴショノウチニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区西七条北東野町', '26', '26106', '6008871', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '西七条北東野町', 'ニシシチジョウキタヒガシノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区西七条南東野町', '26', '26106', '6008872', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '西七条南東野町', 'ニシシチジョウミナミヒガシノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区西七条東久保町', '26', '26106', '6008873', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '西七条東久保町', 'ニシシチジョウヒガシクボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区西七条西久保町', '26', '26106', '6008874', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '西七条西久保町', 'ニシシチジョウニシクボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区西七条石井町', '26', '26106', '6008875', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '西七条石井町', 'ニシシチジョウイシイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区西七条南中野町', '26', '26106', '6008876', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '西七条南中野町', 'ニシシチジョウミナミナカノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区西七条南西野町', '26', '26106', '6008877', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '西七条南西野町', 'ニシシチジョウミナミニシノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区西七条北西野町', '26', '26106', '6008878', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '西七条北西野町', 'ニシシチジョウキタニシノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区西七条中野町', '26', '26106', '6008879', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '西七条中野町', 'ニシシチジョウナカノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区西七条掛越町', '26', '26106', '6008881', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '西七条掛越町', 'ニシシチジョウカケゴシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区西七条比輪田町', '26', '26106', '6008882', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '西七条比輪田町', 'ニシシチジョウヒワダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区西七条北衣田町', '26', '26106', '6008883', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '西七条北衣田町', 'ニシシチジョウキタキヌタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区西七条南衣田町', '26', '26106', '6008884', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '西七条南衣田町', 'ニシシチジョウミナミキヌタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区西七条南月読町', '26', '26106', '6008885', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '西七条南月読町', 'ニシシチジョウミナミツキヨミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区西七条北月読町', '26', '26106', '6008886', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '西七条北月読町', 'ニシシチジョウキタツキヨミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区西七条名倉町', '26', '26106', '6008887', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '西七条名倉町', 'ニシシチジョウナクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区西七条八幡町', '26', '26106', '6008888', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '西七条八幡町', 'ニシシチジョウヤワタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区西七条東八反田町', '26', '26106', '6008891', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '西七条東八反田町', 'ニシシチジョウヒガシハッタンダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区西七条西八反田町', '26', '26106', '6008892', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '西七条西八反田町', 'ニシシチジョウニシハッタンダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区西七条御領町', '26', '26106', '6008893', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '西七条御領町', 'ニシシチジョウゴリョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区西七条市部町', '26', '26106', '6008894', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '西七条市部町', 'ニシシチジョウイチベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区西七条東石ケ坪町', '26', '26106', '6008895', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '西七条東石ケ坪町', 'ニシシチジョウヒガシイシガツボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区西七条西石ケ坪町', '26', '26106', '6008896', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '西七条西石ケ坪町', 'ニシシチジョウニシイシガツボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区西七条御前田町', '26', '26106', '6008897', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '西七条御前田町', 'ニシシチジョウオンマエダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区西七条東御前田町', '26', '26106', '6008898', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '西七条東御前田町', 'ニシシチジョウヒガシオンマエダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市下京区西七条赤社町', '26', '26106', '6008899', '京都府', 'キョウトフ', '京都市下京区', 'キョウトシシモギョウク', '西七条赤社町', 'ニシシチジョウアカヤシロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北5条東4丁目', '01', '01103', '0600905', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北5条東', 'キタ05ジョウヒガシ', null, null, '4丁目', '04チョウメ');
INSERT INTO `ms_addresses` VALUES ('65696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北5条東5丁目', '01', '01103', '0600905', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北5条東', 'キタ05ジョウヒガシ', null, null, '5丁目', '05チョウメ');
INSERT INTO `ms_addresses` VALUES ('65697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北5条東6丁目', '01', '01103', '0600905', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北5条東', 'キタ05ジョウヒガシ', null, null, '6丁目', '06チョウメ');
INSERT INTO `ms_addresses` VALUES ('65698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北5条東7丁目', '01', '01103', '0600905', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北5条東', 'キタ05ジョウヒガシ', null, null, '7丁目', '07チョウメ');
INSERT INTO `ms_addresses` VALUES ('65699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北6条東1丁目', '01', '01103', '0600906', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北6条東', 'キタ06ジョウヒガシ', null, null, '1丁目', '01チョウメ');
INSERT INTO `ms_addresses` VALUES ('65700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北6条東2丁目', '01', '01103', '0600906', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北6条東', 'キタ06ジョウヒガシ', null, null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('65701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北6条東3丁目', '01', '01103', '0600906', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北6条東', 'キタ06ジョウヒガシ', null, null, '3丁目', '03チョウメ');
INSERT INTO `ms_addresses` VALUES ('65702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北6条東4丁目', '01', '01103', '0600906', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北6条東', 'キタ06ジョウヒガシ', null, null, '4丁目', '04チョウメ');
INSERT INTO `ms_addresses` VALUES ('65703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北6条東5丁目', '01', '01103', '0600906', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北6条東', 'キタ06ジョウヒガシ', null, null, '5丁目', '05チョウメ');
INSERT INTO `ms_addresses` VALUES ('65704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北6条東6丁目', '01', '01103', '0600906', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北6条東', 'キタ06ジョウヒガシ', null, null, '6丁目', '06チョウメ');
INSERT INTO `ms_addresses` VALUES ('65705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北6条東7丁目', '01', '01103', '0600906', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北6条東', 'キタ06ジョウヒガシ', null, null, '7丁目', '07チョウメ');
INSERT INTO `ms_addresses` VALUES ('65706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北7条東1丁目', '01', '01103', '0600907', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北7条東', 'キタ07ジョウヒガシ', null, null, '1丁目', '01チョウメ');
INSERT INTO `ms_addresses` VALUES ('65707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北7条東2丁目', '01', '01103', '0600907', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北7条東', 'キタ07ジョウヒガシ', null, null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('65708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北7条東3丁目', '01', '01103', '0600907', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北7条東', 'キタ07ジョウヒガシ', null, null, '3丁目', '03チョウメ');
INSERT INTO `ms_addresses` VALUES ('65709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北7条東4丁目', '01', '01103', '0600907', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北7条東', 'キタ07ジョウヒガシ', null, null, '4丁目', '04チョウメ');
INSERT INTO `ms_addresses` VALUES ('65710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北7条東5丁目', '01', '01103', '0600907', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北7条東', 'キタ07ジョウヒガシ', null, null, '5丁目', '05チョウメ');
INSERT INTO `ms_addresses` VALUES ('65711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北7条東6丁目', '01', '01103', '0600907', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北7条東', 'キタ07ジョウヒガシ', null, null, '6丁目', '06チョウメ');
INSERT INTO `ms_addresses` VALUES ('65712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北7条東7丁目', '01', '01103', '0600907', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北7条東', 'キタ07ジョウヒガシ', null, null, '7丁目', '07チョウメ');
INSERT INTO `ms_addresses` VALUES ('65713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北8条東1丁目', '01', '01103', '0600908', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北8条東', 'キタ08ジョウヒガシ', null, null, '1丁目', '01チョウメ');
INSERT INTO `ms_addresses` VALUES ('65714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北8条東2丁目', '01', '01103', '0600908', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北8条東', 'キタ08ジョウヒガシ', null, null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('65715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北8条東3丁目', '01', '01103', '0600908', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北8条東', 'キタ08ジョウヒガシ', null, null, '3丁目', '03チョウメ');
INSERT INTO `ms_addresses` VALUES ('65716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北8条東4丁目', '01', '01103', '0600908', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北8条東', 'キタ08ジョウヒガシ', null, null, '4丁目', '04チョウメ');
INSERT INTO `ms_addresses` VALUES ('65717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北8条東5丁目', '01', '01103', '0600908', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北8条東', 'キタ08ジョウヒガシ', null, null, '5丁目', '05チョウメ');
INSERT INTO `ms_addresses` VALUES ('65718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北8条東6丁目', '01', '01103', '0600908', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北8条東', 'キタ08ジョウヒガシ', null, null, '6丁目', '06チョウメ');
INSERT INTO `ms_addresses` VALUES ('65719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北8条東7丁目', '01', '01103', '0600908', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北8条東', 'キタ08ジョウヒガシ', null, null, '7丁目', '07チョウメ');
INSERT INTO `ms_addresses` VALUES ('65720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北9条東1丁目', '01', '01103', '0600909', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北9条東', 'キタ09ジョウヒガシ', null, null, '1丁目', '01チョウメ');
INSERT INTO `ms_addresses` VALUES ('65721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北9条東2丁目', '01', '01103', '0600909', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北9条東', 'キタ09ジョウヒガシ', null, null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('65722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北9条東3丁目', '01', '01103', '0600909', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北9条東', 'キタ09ジョウヒガシ', null, null, '3丁目', '03チョウメ');
INSERT INTO `ms_addresses` VALUES ('65723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北9条東4丁目', '01', '01103', '0600909', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北9条東', 'キタ09ジョウヒガシ', null, null, '4丁目', '04チョウメ');
INSERT INTO `ms_addresses` VALUES ('65724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北9条東5丁目', '01', '01103', '0600909', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北9条東', 'キタ09ジョウヒガシ', null, null, '5丁目', '05チョウメ');
INSERT INTO `ms_addresses` VALUES ('65725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北9条東6丁目', '01', '01103', '0600909', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北9条東', 'キタ09ジョウヒガシ', null, null, '6丁目', '06チョウメ');
INSERT INTO `ms_addresses` VALUES ('65726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北9条東7丁目', '01', '01103', '0600909', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北9条東', 'キタ09ジョウヒガシ', null, null, '7丁目', '07チョウメ');
INSERT INTO `ms_addresses` VALUES ('65727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区', '26', '26107', '6010000', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('65728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区真弓八幡町', '26', '26101', '6010101', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '真弓八幡町', 'マユミハチマンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区真弓善福', '26', '26101', '6010102', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '真弓善福', 'マユミゼンプク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区杉阪北尾', '26', '26101', '6010111', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '杉阪北尾', 'スギサカキタオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区杉阪都町', '26', '26101', '6010112', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '杉阪都町', 'スギサカミヤコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区杉阪道風町', '26', '26101', '6010113', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '杉阪道風町', 'スギサカトウフウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区中川東山', '26', '26101', '6010121', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '中川東山', 'ナカガワヒガシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区中川北山町', '26', '26101', '6010122', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '中川北山町', 'ナカガワキタヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区中川西山', '26', '26101', '6010123', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '中川西山', 'ナカガワニシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区中川中山', '26', '26101', '6010124', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '中川中山', 'ナカガワナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区中川川登', '26', '26101', '6010125', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '中川川登', 'ナカガワカワノボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区小野下ノ町', '26', '26101', '6010131', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '小野下ノ町', 'オノシモノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区小野中ノ町', '26', '26101', '6010132', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '小野中ノ町', 'オノナカノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区小野上ノ町', '26', '26101', '6010133', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '小野上ノ町', 'オノカミノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区小野岩戸', '26', '26101', '6010134', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '小野岩戸', 'オノイワト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区小野宮ノ上町', '26', '26101', '6010135', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '小野宮ノ上町', 'オノミヤノカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区大森稲荷', '26', '26101', '6010141', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '大森稲荷', 'オオモリイナリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区大森芦堂町', '26', '26101', '6010142', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '大森芦堂町', 'オオモリアシドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区大森中町', '26', '26101', '6010143', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '大森中町', 'オオモリナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区大森西町', '26', '26101', '6010144', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '大森西町', 'オオモリニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区大森東町', '26', '26101', '6010145', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '大森東町', 'オオモリヒガシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区京北周山町', '26', '26108', '6010251', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '京北周山町', 'ケイホクシュウザンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区京北五本松町', '26', '26108', '6010252', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '京北五本松町', 'ケイホクゴホンマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区京北柏原町', '26', '26108', '6010261', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '京北柏原町', 'ケイホクカシワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区京北細野町', '26', '26108', '6010262', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '京北細野町', 'ケイホクホソノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区京北弓槻町', '26', '26108', '6010263', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '京北弓槻町', 'ケイホクユヅキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区京北栃本町', '26', '26108', '6010264', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '京北栃本町', 'ケイホクトチモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区京北中地町', '26', '26108', '6010265', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '京北中地町', 'ケイホクチュウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区京北下宇津町', '26', '26108', '6010266', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '京北下宇津町', 'ケイホクシモウツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区京北熊田町', '26', '26108', '6010271', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '京北熊田町', 'ケイホククマタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区京北下熊田町', '26', '26108', '6010272', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '京北下熊田町', 'ケイホクシモクマタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区京北明石町', '26', '26108', '6010273', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '京北明石町', 'ケイホクアケシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区京北浅江町', '26', '26108', '6010274', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '京北浅江町', 'ケイホクアザエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区京北宇野町', '26', '26108', '6010275', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '京北宇野町', 'ケイホクウノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区京北西町', '26', '26108', '6010276', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '京北西町', 'ケイホクニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区京北漆谷町', '26', '26108', '6010277', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '京北漆谷町', 'ケイホクウルシタニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区京北矢代中町', '26', '26108', '6010278', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '京北矢代中町', 'ケイホクヤシロナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区京北小塩町', '26', '26108', '6010311', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '京北小塩町', 'ケイホクオシオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区京北初川町', '26', '26108', '6010312', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '京北初川町', 'ケイホクハツカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区京北井戸町', '26', '26108', '6010313', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '京北井戸町', 'ケイホクイドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区京北大野町', '26', '26108', '6010314', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '京北大野町', 'ケイホクオオノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区京北中江町', '26', '26108', '6010315', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '京北中江町', 'ケイホクナカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区京北比賀江町', '26', '26108', '6010316', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '京北比賀江町', 'ケイホクヒガエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区京北塔町', '26', '26108', '6010321', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '京北塔町', 'ケイホクトウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区京北辻町', '26', '26108', '6010322', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '京北辻町', 'ケイホクツジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区京北鳥居町', '26', '26108', '6010323', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '京北鳥居町', 'ケイホクトリイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区京北下町', '26', '26108', '6010324', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '京北下町', 'ケイホクシモチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区京北片波町', '26', '26108', '6010401', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '京北片波町', 'ケイホクカタナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区京北上黒田町', '26', '26108', '6010402', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '京北上黒田町', 'ケイホクカミクロダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区京北灰屋町', '26', '26108', '6010403', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '京北灰屋町', 'ケイホクハイヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区京北芹生町', '26', '26108', '6010404', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '京北芹生町', 'ケイホクセリョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区京北下黒田町', '26', '26108', '6010405', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '京北下黒田町', 'ケイホクシモクロダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区京北宮町', '26', '26108', '6010406', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '京北宮町', 'ケイホクミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区京北上弓削町', '26', '26108', '6010531', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '京北上弓削町', 'ケイホクカミユゲチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区京北上中町', '26', '26108', '6010532', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '京北上中町', 'ケイホクカミナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区京北下中町', '26', '26108', '6010533', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '京北下中町', 'ケイホクシモナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区京北下弓削町', '26', '26108', '6010534', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '京北下弓削町', 'ケイホクシモユゲチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区京北井崎町', '26', '26108', '6010535', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '京北井崎町', 'ケイホクイザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区京北塩田町', '26', '26108', '6010536', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '京北塩田町', 'ケイホクシオタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区京北赤石町', '26', '26108', '6010541', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '京北赤石町', 'ケイホクアカイシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区京北田貫町', '26', '26108', '6010542', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '京北田貫町', 'ケイホクタヌキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区京北室谷町', '26', '26108', '6010543', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '京北室谷町', 'ケイホクシツタンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市美山町江和', '26', '26213', '6010701', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '美山町江和', 'ミヤマチョウエワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市美山町田歌', '26', '26213', '6010702', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '美山町田歌', 'ミヤマチョウタウタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市美山町芦生', '26', '26213', '6010703', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '美山町芦生', 'ミヤマチョウアシウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市美山町白石', '26', '26213', '6010704', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '美山町白石', 'ミヤマチョウシライシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市美山町佐々里', '26', '26213', '6010705', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '美山町佐々里', 'ミヤマチョウササリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市美山町南', '26', '26213', '6010711', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '美山町南', 'ミヤマチョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市美山町北', '26', '26213', '6010712', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '美山町北', 'ミヤマチョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市美山町中', '26', '26213', '6010713', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '美山町中', 'ミヤマチョウナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市美山町河内谷', '26', '26213', '6010714', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '美山町河内谷', 'ミヤマチョウカワウチダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市美山町下', '26', '26213', '6010715', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '美山町下', 'ミヤマチョウシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市美山町知見', '26', '26213', '6010716', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '美山町知見', 'ミヤマチョウチミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市美山町上平屋', '26', '26213', '6010721', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '美山町上平屋', 'ミヤマチョウカミヒラヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市美山町安掛', '26', '26213', '6010722', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '美山町安掛', 'ミヤマチョウアガケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市美山町荒倉', '26', '26213', '6010723', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '美山町荒倉', 'ミヤマチョウアラクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市美山町内久保', '26', '26213', '6010724', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '美山町内久保', 'ミヤマチョウウチクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市美山町又林', '26', '26213', '6010731', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '美山町又林', 'ミヤマチョウマタバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市美山町下平屋', '26', '26213', '6010732', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '美山町下平屋', 'ミヤマチョウシモヒラヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市美山町野添', '26', '26213', '6010733', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '美山町野添', 'ミヤマチョウノゾエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市美山町長尾', '26', '26213', '6010734', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '美山町長尾', 'ミヤマチョウナガオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市美山町深見', '26', '26213', '6010735', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '美山町深見', 'ミヤマチョウフカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市美山町原', '26', '26213', '6010741', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '美山町原', 'ミヤマチョウハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市美山町板橋', '26', '26213', '6010742', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '美山町板橋', 'ミヤマチョウイタハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市美山町宮脇', '26', '26213', '6010743', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '美山町宮脇', 'ミヤマチョウミヤノワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市美山町下吉田', '26', '26213', '6010744', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '美山町下吉田', 'ミヤマチョウシモヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市美山町島', '26', '26213', '6010751', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '美山町島', 'ミヤマチョウシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市美山町長谷', '26', '26213', '6010752', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '美山町長谷', 'ミヤマチョウナガタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市美山町上司', '26', '26213', '6010753', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '美山町上司', 'ミヤマチョウジョウシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市美山町和泉', '26', '26213', '6010754', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '美山町和泉', 'ミヤマチョウイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市美山町静原', '26', '26213', '6010755', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '美山町静原', 'ミヤマチョウシズハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市美山町高野', '26', '26213', '6010761', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '美山町高野', 'ミヤマチョウタカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市美山町鶴ケ岡', '26', '26213', '6010762', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '美山町鶴ケ岡', 'ミヤマチョウツルガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市美山町豊郷', '26', '26213', '6010763', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '美山町豊郷', 'ミヤマチョウトヨサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市美山町盛郷', '26', '26213', '6010764', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '美山町盛郷', 'ミヤマチョウモリサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市美山町福居', '26', '26213', '6010765', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '美山町福居', 'ミヤマチョウフクイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市美山町萱野', '26', '26213', '6010771', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '美山町萱野', 'ミヤマチョウカヤノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市美山町大野', '26', '26213', '6010772', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '美山町大野', 'ミヤマチョウオオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市美山町三埜', '26', '26213', '6010773', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '美山町三埜', 'ミヤマチョウミツノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市美山町肱谷', '26', '26213', '6010774', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '美山町肱谷', 'ミヤマチョウヒジタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市美山町小渕', '26', '26213', '6010775', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '美山町小渕', 'ミヤマチョウオブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市美山町向山', '26', '26213', '6010776', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '美山町向山', 'ミヤマチョウムカイヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市美山町樫原', '26', '26213', '6010777', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '美山町樫原', 'ミヤマチョウカシワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市美山町音海', '26', '26213', '6010778', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '美山町音海', 'ミヤマチョウオトミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区広河原', '26', '26103', '6011101', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '広河原', 'ヒロガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区花脊原地町', '26', '26103', '6011102', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '花脊原地町', 'ハナセハラチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区花脊八桝町', '26', '26103', '6011103', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '花脊八桝町', 'ハナセヤマスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区花脊大布施町', '26', '26103', '6011104', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '花脊大布施町', 'ハナセオオフセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区花脊別所町', '26', '26103', '6011105', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '花脊別所町', 'ハナセベッショチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区鞍馬本町', '26', '26103', '6011111', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '鞍馬本町', 'クラマホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区鞍馬貴船町', '26', '26103', '6011112', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '鞍馬貴船町', 'クラマキブネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区鞍馬二ノ瀬町', '26', '26103', '6011113', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '鞍馬二ノ瀬町', 'クラマニノセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区静市静原町', '26', '26103', '6011121', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '静市静原町', 'シズイチシズハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区静市野中町', '26', '26103', '6011122', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '静市野中町', 'シズイチノナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区静市市原町', '26', '26103', '6011123', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '静市市原町', 'シズイチイチハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区岩倉上蔵町', '26', '26103', '6011124', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '岩倉上蔵町', 'イワクラアグラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区岩倉木野町', '26', '26103', '6011125', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '岩倉木野町', 'イワクラキノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区大原尾越町', '26', '26103', '6011231', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '大原尾越町', 'オオハラオゴセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区大原大見町', '26', '26103', '6011232', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '大原大見町', 'オオハラオオミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区大原百井町', '26', '26103', '6011233', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '大原百井町', 'オオハラモモイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区大原小出石町', '26', '26103', '6011234', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '大原小出石町', 'オオハラコデイシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区大原古知平町', '26', '26103', '6011235', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '大原古知平町', 'オオハラコチヒラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区大原勝林院町', '26', '26103', '6011241', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '大原勝林院町', 'オオハラショウリンインチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区大原来迎院町', '26', '26103', '6011242', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '大原来迎院町', 'オオハラライコウインチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区大原大長瀬町', '26', '26103', '6011243', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '大原大長瀬町', 'オオハラオオナガセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区大原上野町', '26', '26103', '6011244', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '大原上野町', 'オオハラウエノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区大原戸寺町', '26', '26103', '6011245', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '大原戸寺町', 'オオハラトデラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区大原井出町', '26', '26103', '6011246', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '大原井出町', 'オオハライデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区大原野村町', '26', '26103', '6011247', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '大原野村町', 'オオハラノムラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区大原草生町', '26', '26103', '6011248', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '大原草生町', 'オオハラクサオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区八瀬花尻町', '26', '26103', '6011251', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '八瀬花尻町', 'ヤセハナジリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区八瀬秋元町', '26', '26103', '6011252', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '八瀬秋元町', 'ヤセアキモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区八瀬近衛町', '26', '26103', '6011253', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '八瀬近衛町', 'ヤセコノエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区八瀬野瀬町', '26', '26103', '6011254', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '八瀬野瀬町', 'ヤセノセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区上高野東山', '26', '26103', '6011255', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '上高野東山', 'カミタカノヒガシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区醍醐上山田', '26', '26109', '6011301', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '醍醐上山田', 'ダイゴカミヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区醍醐内ケ井戸', '26', '26109', '6011302', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '醍醐内ケ井戸', 'ダイゴウチガイド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区醍醐大畑町', '26', '26109', '6011303', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '醍醐大畑町', 'ダイゴオオハタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区醍醐山ケ鼻', '26', '26109', '6011304', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '醍醐山ケ鼻', 'ダイゴヤマガハナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区醍醐柿原', '26', '26109', '6011305', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '醍醐柿原', 'ダイゴカキハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区醍醐連蔵', '26', '26109', '6011306', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '醍醐連蔵', 'ダイゴレンゾウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区醍醐狭間', '26', '26109', '6011307', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '醍醐狭間', 'ダイゴハザマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区醍醐御所ノ内', '26', '26109', '6011308', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '醍醐御所ノ内', 'ダイゴゴショノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区醍醐大高町', '26', '26109', '6011311', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '醍醐大高町', 'ダイゴオオタカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区醍醐片山町', '26', '26109', '6011312', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '醍醐片山町', 'ダイゴカタヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区醍醐御陵東裏町', '26', '26109', '6011313', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '醍醐御陵東裏町', 'ダイゴゴリョウヒガシウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区醍醐御陵西裏町', '26', '26109', '6011314', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '醍醐御陵西裏町', 'ダイゴゴリョウニシウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区醍醐烏橋町', '26', '26109', '6011315', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '醍醐烏橋町', 'ダイゴカラスバシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区醍醐古道町', '26', '26109', '6011316', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '醍醐古道町', 'ダイゴフルミチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区醍醐京道町', '26', '26109', '6011317', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '醍醐京道町', 'ダイゴキョウミチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区醍醐廻り戸町', '26', '26109', '6011318', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '醍醐廻り戸町', 'ダイゴマワリドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区醍醐北端山', '26', '26109', '6011321', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '醍醐北端山', 'ダイゴキタハヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区醍醐北伽藍町', '26', '26109', '6011322', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '醍醐北伽藍町', 'ダイゴキタガランチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区醍醐赤間南裏町', '26', '26109', '6011323', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '醍醐赤間南裏町', 'ダイゴアカマミナミウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区醍醐伽藍町', '26', '26109', '6011324', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '醍醐伽藍町', 'ダイゴガランチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区醍醐東大路町', '26', '26109', '6011325', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '醍醐東大路町', 'ダイゴヒガシオオジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区醍醐新町裏町', '26', '26109', '6011326', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '醍醐新町裏町', 'ダイゴシンマチウラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区醍醐切レ戸町', '26', '26109', '6011327', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '醍醐切レ戸町', 'ダイゴキレドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区醍醐南端山', '26', '26109', '6011331', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '醍醐南端山', 'ダイゴミナミハヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区醍醐下端山町', '26', '26109', '6011332', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '醍醐下端山町', 'ダイゴシモハヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区醍醐上端山町', '26', '26109', '6011333', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '醍醐上端山町', 'ダイゴカミハヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区醍醐勝口町', '26', '26109', '6011334', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '醍醐勝口町', 'ダイゴショウクチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区醍醐一言寺裏町', '26', '26109', '6011335', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '醍醐一言寺裏町', 'ダイゴイチゴンジウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区醍醐柏森町', '26', '26109', '6011336', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '醍醐柏森町', 'ダイゴカシワモリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区醍醐槇ノ内町', '26', '26109', '6011337', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '醍醐槇ノ内町', 'ダイゴマキノウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区醍醐落保町', '26', '26109', '6011338', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '醍醐落保町', 'ダイゴオチボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区醍醐岸ノ上町', '26', '26109', '6011341', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '醍醐岸ノ上町', 'ダイゴキシノウエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区醍醐上山口町', '26', '26109', '6011342', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '醍醐上山口町', 'ダイゴカミヤマグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区醍醐下山口町', '26', '26109', '6011343', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '醍醐下山口町', 'ダイゴシモヤマグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区醍醐辰巳町', '26', '26109', '6011344', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '醍醐辰巳町', 'ダイゴタツミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区醍醐外山街道町', '26', '26109', '6011345', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '醍醐外山街道町', 'ダイゴソトヤマカイドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区醍醐東合場町', '26', '26109', '6011346', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '醍醐東合場町', 'ダイゴヒガシアイバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区醍醐合場町', '26', '26109', '6011347', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '醍醐合場町', 'ダイゴアイバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区醍醐和泉町', '26', '26109', '6011351', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '醍醐和泉町', 'ダイゴイズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区醍醐南里町', '26', '26109', '6011352', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '醍醐南里町', 'ダイゴミナミサトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区醍醐御園尾町', '26', '26109', '6011353', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '醍醐御園尾町', 'ダイゴミソノオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区醍醐構口町', '26', '26109', '6011354', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '醍醐構口町', 'ダイゴカマエグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区醍醐多近田町', '26', '26109', '6011355', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '醍醐多近田町', 'ダイゴタコンダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区醍醐南西裏町', '26', '26109', '6011356', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '醍醐南西裏町', 'ダイゴミナミニシウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区醍醐僧尊坊町', '26', '26109', '6011357', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '醍醐僧尊坊町', 'ダイゴドドンボウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区醍醐御霊ケ下町', '26', '26109', '6011361', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '醍醐御霊ケ下町', 'ダイゴゴリョウガシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区醍醐池田町', '26', '26109', '6011362', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '醍醐池田町', 'ダイゴイケダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区醍醐鍵尾町', '26', '26109', '6011363', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '醍醐鍵尾町', 'ダイゴカギオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区醍醐江奈志町', '26', '26109', '6011364', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '醍醐江奈志町', 'ダイゴエナシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区醍醐新開', '26', '26109', '6011365', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '醍醐新開', 'ダイゴシンカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区醍醐大構町', '26', '26109', '6011366', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '醍醐大構町', 'ダイゴオオカマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区醍醐上ノ山町', '26', '26109', '6011371', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '醍醐上ノ山町', 'ダイゴウエノヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区醍醐平松町', '26', '26109', '6011372', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '醍醐平松町', 'ダイゴヒラマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区醍醐中山町', '26', '26109', '6011373', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '醍醐中山町', 'ダイゴナカヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区醍醐西大路町', '26', '26109', '6011374', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '醍醐西大路町', 'ダイゴニシオオジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区醍醐高畑町', '26', '26109', '6011375', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '醍醐高畑町', 'ダイゴタカハタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区醍醐折戸町', '26', '26109', '6011376', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '醍醐折戸町', 'ダイゴオリドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区醍醐北西裏町', '26', '26109', '6011377', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '醍醐北西裏町', 'ダイゴキタニシウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区醍醐川久保町', '26', '26109', '6011378', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '醍醐川久保町', 'ダイゴカワクボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区醍醐北谷', '26', '26109', '6011381', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '醍醐北谷', 'ダイゴキタダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区醍醐南谷', '26', '26109', '6011382', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '醍醐南谷', 'ダイゴミナミダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区醍醐醍醐山', '26', '26109', '6011383', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '醍醐醍醐山', 'ダイゴダイゴヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区醍醐高田', '26', '26109', '6011384', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '醍醐高田', 'ダイゴタカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区醍醐宮ノ下町', '26', '26109', '6011385', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '醍醐宮ノ下町', 'ダイゴミヤノシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区醍醐陀羅谷', '26', '26109', '6011386', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '醍醐陀羅谷', 'ダイゴダラタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区醍醐一ノ切町', '26', '26109', '6011387', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '醍醐一ノ切町', 'ダイゴイチノキリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区醍醐三ノ切', '26', '26109', '6011387', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '醍醐三ノ切', 'ダイゴサンノキリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区醍醐二ノ切町', '26', '26109', '6011387', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '醍醐二ノ切町', 'ダイゴニノキリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宇治市東笠取', '26', '26204', '6011391', '京都府', 'キョウトフ', '宇治市', 'ウジシ', '東笠取', 'ヒガシカサトリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宇治市西笠取', '26', '26204', '6011392', '京都府', 'キョウトフ', '宇治市', 'ウジシ', '西笠取', 'ニシカサトリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宇治市二尾', '26', '26204', '6011393', '京都府', 'キョウトフ', '宇治市', 'ウジシ', '二尾', 'ニノオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宇治市池尾', '26', '26204', '6011394', '京都府', 'キョウトフ', '宇治市', 'ウジシ', '池尾', 'イケノオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宇治市炭山', '26', '26204', '6011395', '京都府', 'キョウトフ', '宇治市', 'ウジシ', '炭山', 'スミヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宇治市菟道東垣内', '26', '26204', '6011396', '京都府', 'キョウトフ', '宇治市', 'ウジシ', '菟道東垣内', 'トドウヒガシガイト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区日野北山', '26', '26109', '6011401', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '日野北山', 'ヒノキタヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区日野南山', '26', '26109', '6011402', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '日野南山', 'ヒノミナミヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区日野船尾', '26', '26109', '6011403', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '日野船尾', 'ヒノフナオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区日野北川頬', '26', '26109', '6011404', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '日野北川頬', 'ヒノキタカワヅラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区日野林', '26', '26109', '6011405', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '日野林', 'ヒノハヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区日野谷寺町', '26', '26109', '6011406', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '日野谷寺町', 'ヒノタニデラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区日野慈悲町', '26', '26109', '6011411', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '日野慈悲町', 'ヒノジヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区日野畑出町', '26', '26109', '6011412', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '日野畑出町', 'ヒノハタデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区日野谷田町', '26', '26109', '6011413', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '日野谷田町', 'ヒノタニダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区日野奥出', '26', '26109', '6011414', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '日野奥出', 'ヒノオクデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区日野野色町', '26', '26109', '6011415', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '日野野色町', 'ヒノノイロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区日野岡西町', '26', '26109', '6011416', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '日野岡西町', 'ヒノオカニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区日野西大道町', '26', '26109', '6011417', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '日野西大道町', 'ヒノニシダイドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区日野馬場出町', '26', '26109', '6011421', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '日野馬場出町', 'ヒノバンバテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区日野不動講町', '26', '26109', '6011422', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '日野不動講町', 'ヒノフドウコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区日野西風呂町', '26', '26109', '6011423', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '日野西風呂町', 'ヒノニシフロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区日野田頬町', '26', '26109', '6011424', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '日野田頬町', 'ヒノタヅラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区日野田中町', '26', '26109', '6011425', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '日野田中町', 'ヒノタナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区日野西川頬', '26', '26109', '6011426', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '日野西川頬', 'ヒノニシカワヅラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区石田大受町', '26', '26109', '6011431', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '石田大受町', 'イシダオオウケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区石田内里町', '26', '26109', '6011432', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '石田内里町', 'イシダウチサトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区石田大山町', '26', '26109', '6011433', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '石田大山町', 'イシダオオヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区石田森南町', '26', '26109', '6011434', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '石田森南町', 'イシダモリミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区石田桜木', '26', '26109', '6011435', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '石田桜木', 'イシダサクラギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区石田西ノ坪', '26', '26109', '6011436', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '石田西ノ坪', 'イシダニシノツボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区石田森西', '26', '26109', '6011437', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '石田森西', 'イシダモリニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区石田川向', '26', '26109', '6011438', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '石田川向', 'イシダカワムカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区石田森東町', '26', '26109', '6011439', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '石田森東町', 'イシダモリヒガシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区小栗栖北谷町', '26', '26109', '6011441', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '小栗栖北谷町', 'オグリスキタダニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区小栗栖丸山', '26', '26109', '6011442', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '小栗栖丸山', 'オグリスマルヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区小栗栖岩ケ渕町', '26', '26109', '6011443', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '小栗栖岩ケ渕町', 'オグリスイワガフチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区小栗栖牛ケ渕町', '26', '26109', '6011444', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '小栗栖牛ケ渕町', 'オグリスウシガフチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区小栗栖森ケ渕町', '26', '26109', '6011445', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '小栗栖森ケ渕町', 'オグリスモリガフチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区小栗栖北後藤町', '26', '26109', '6011446', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '小栗栖北後藤町', 'オグリスキタゴトウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区小栗栖鉢伏', '26', '26109', '6011451', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '小栗栖鉢伏', 'オグリスハチフセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区小栗栖西ノ峯', '26', '26109', '6011452', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '小栗栖西ノ峯', 'オグリスニシノミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区小栗栖西谷町', '26', '26109', '6011453', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '小栗栖西谷町', 'オグリスニシダニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区小栗栖山口町', '26', '26109', '6011454', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '小栗栖山口町', 'オグリスヤマグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区小栗栖小阪町', '26', '26109', '6011455', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '小栗栖小阪町', 'オグリスコサカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区小栗栖南後藤町', '26', '26109', '6011456', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '小栗栖南後藤町', 'オグリスミナミゴトウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区小栗栖宮山', '26', '26109', '6011461', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '小栗栖宮山', 'オグリスミヤヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区小栗栖森本町', '26', '26109', '6011462', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '小栗栖森本町', 'オグリスモリモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区小栗栖中山田町', '26', '26109', '6011463', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '小栗栖中山田町', 'オグリスナカヤマダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区小栗栖石川町', '26', '26109', '6011464', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '小栗栖石川町', 'オグリスイシカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区東九条室町', '26', '26107', '6018001', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '東九条室町', 'ヒガシクジョウムロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区東九条上殿田町', '26', '26107', '6018002', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '東九条上殿田町', 'ヒガシクジョウカミトノダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区東九条西山王町', '26', '26107', '6018003', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '東九条西山王町', 'ヒガシクジョウニシサンノウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区東九条東山王町', '26', '26107', '6018004', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '東九条東山王町', 'ヒガシクジョウヒガシサンノウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区東九条西岩本町', '26', '26107', '6018005', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '東九条西岩本町', 'ヒガシクジョウニシイワモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区東九条東岩本町', '26', '26107', '6018006', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '東九条東岩本町', 'ヒガシクジョウヒガシイワモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区東九条北河原町', '26', '26107', '6018007', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '東九条北河原町', 'ヒガシクジョウキタカワラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区東九条南山王町', '26', '26107', '6018011', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '東九条南山王町', 'ヒガシクジョウミナミサンノウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区東九条南岩本町', '26', '26107', '6018012', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '東九条南岩本町', 'ヒガシクジョウミナミイワモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区東九条南河原町', '26', '26107', '6018013', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '東九条南河原町', 'ヒガシクジョウミナミカワラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区東九条河西町', '26', '26107', '6018014', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '東九条河西町', 'ヒガシクジョウカワニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区東九条上御霊町', '26', '26107', '6018015', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '東九条上御霊町', 'ヒガシクジョウカミゴリョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区東九条烏丸町', '26', '26107', '6018016', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '東九条烏丸町', 'ヒガシクジョウカラスマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区東九条北烏丸町', '26', '26107', '6018017', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '東九条北烏丸町', 'ヒガシクジョウキタカラスマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区東九条宇賀辺町', '26', '26107', '6018021', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '東九条宇賀辺町', 'ヒガシクジョウウカベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('65999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区東九条北松ノ木町', '26', '26107', '6018022', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '東九条北松ノ木町', 'ヒガシクジョウキタマツノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区東九条南松ノ木町', '26', '26107', '6018023', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '東九条南松ノ木町', 'ヒガシクジョウミナミマツノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区東九条東札辻町', '26', '26107', '6018024', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '東九条東札辻町', 'ヒガシクジョウヒガシフダノツジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区東九条柳下町', '26', '26107', '6018025', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '東九条柳下町', 'ヒガシクジョウヤナギノシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区東九条中札辻町', '26', '26107', '6018026', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '東九条中札辻町', 'ヒガシクジョウナカフダノツジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区東九条中御霊町', '26', '26107', '6018027', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '東九条中御霊町', 'ヒガシクジョウナカゴリョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区東九条東御霊町', '26', '26107', '6018028', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '東九条東御霊町', 'ヒガシクジョウヒガシゴリョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区東九条東松ノ木町', '26', '26107', '6018029', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '東九条東松ノ木町', 'ヒガシクジョウヒガシマツノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区東九条河辺町', '26', '26107', '6018031', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '東九条河辺町', 'ヒガシクジョウカワベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区東九条石田町', '26', '26107', '6018032', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '東九条石田町', 'ヒガシクジョウイシダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区東九条南石田町', '26', '26107', '6018033', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '東九条南石田町', 'ヒガシクジョウミナミイシダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区東九条南河辺町', '26', '26107', '6018034', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '東九条南河辺町', 'ヒガシクジョウミナミカワベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区東九条南松田町', '26', '26107', '6018035', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '東九条南松田町', 'ヒガシクジョウミナミマツダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区東九条松田町', '26', '26107', '6018036', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '東九条松田町', 'ヒガシクジョウマツダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区東九条西河辺町', '26', '26107', '6018037', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '東九条西河辺町', 'ヒガシクジョウニシカワベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区東九条南烏丸町', '26', '26107', '6018041', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '東九条南烏丸町', 'ヒガシクジョウミナミカラスマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区東九条西御霊町', '26', '26107', '6018042', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '東九条西御霊町', 'ヒガシクジョウニシゴリョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区東九条西札辻町', '26', '26107', '6018043', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '東九条西札辻町', 'ヒガシクジョウニシフダノツジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区東九条明田町', '26', '26107', '6018044', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '東九条明田町', 'ヒガシクジョウアケタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区東九条西明田町', '26', '26107', '6018045', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '東九条西明田町', 'ヒガシクジョウニシアケタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区東九条西山町', '26', '26107', '6018046', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '東九条西山町', 'ヒガシクジョウニシヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区東九条下殿田町', '26', '26107', '6018047', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '東九条下殿田町', 'ヒガシクジョウシモトノダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区東九条中殿田町', '26', '26107', '6018048', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '東九条中殿田町', 'ヒガシクジョウナカトノダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区上鳥羽高畠町', '26', '26107', '6018101', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '上鳥羽高畠町', 'カミトバタカハタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区上鳥羽菅田町', '26', '26107', '6018102', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '上鳥羽菅田町', 'カミトバスガタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区上鳥羽仏現寺町', '26', '26107', '6018103', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '上鳥羽仏現寺町', 'カミトバブツゲンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区上鳥羽角田町', '26', '26107', '6018104', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '上鳥羽角田町', 'カミトバツノダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区上鳥羽上調子町', '26', '26107', '6018105', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '上鳥羽上調子町', 'カミトバカミチョウシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区上鳥羽北中ノ坪町', '26', '26107', '6018106', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '上鳥羽北中ノ坪町', 'カミトバキタナカノツボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区上鳥羽南唐戸町', '26', '26107', '6018107', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '上鳥羽南唐戸町', 'カミトバミナミカラトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区上鳥羽唐戸町', '26', '26107', '6018108', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '上鳥羽唐戸町', 'カミトバカラトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区上鳥羽苗代町', '26', '26107', '6018111', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '上鳥羽苗代町', 'カミトバナワシロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区上鳥羽勧進橋町', '26', '26107', '6018112', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '上鳥羽勧進橋町', 'カミトバカンジンバシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区上鳥羽南苗代町', '26', '26107', '6018113', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '上鳥羽南苗代町', 'カミトバミナミナワシロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区上鳥羽南鉾立町', '26', '26107', '6018114', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '上鳥羽南鉾立町', 'カミトバミナミホコタテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区上鳥羽尻切町', '26', '26107', '6018115', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '上鳥羽尻切町', 'カミトバシリキリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区上鳥羽鉾立町', '26', '26107', '6018116', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '上鳥羽鉾立町', 'カミトバホコタテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区上鳥羽大物町', '26', '26107', '6018121', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '上鳥羽大物町', 'カミトバダイモツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区上鳥羽北塔ノ本町', '26', '26107', '6018122', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '上鳥羽北塔ノ本町', 'カミトバキタトウノモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区上鳥羽南塔ノ本町', '26', '26107', '6018123', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '上鳥羽南塔ノ本町', 'カミトバミナミトウノモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区上鳥羽塔ノ本', '26', '26107', '6018124', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '上鳥羽塔ノ本', 'カミトバトウノモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区上鳥羽花名', '26', '26107', '6018125', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '上鳥羽花名', 'カミトバハナナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区上鳥羽南花名町', '26', '26107', '6018126', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '上鳥羽南花名町', 'カミトバミナミハナナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区上鳥羽北花名町', '26', '26107', '6018127', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '上鳥羽北花名町', 'カミトバキタハナナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区上鳥羽大柳町', '26', '26107', '6018128', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '上鳥羽大柳町', 'カミトバオオヤナギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区上鳥羽鴨田', '26', '26107', '6018131', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '上鳥羽鴨田', 'カミトバカモンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区上鳥羽町田', '26', '26107', '6018132', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '上鳥羽町田', 'カミトバチョウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区上鳥羽藁田', '26', '26107', '6018133', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '上鳥羽藁田', 'カミトバワランデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区上鳥羽大溝', '26', '26107', '6018134', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '上鳥羽大溝', 'カミトバオオミゾ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区上鳥羽石橋町', '26', '26107', '6018135', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '上鳥羽石橋町', 'カミトバイシバシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区上鳥羽岩ノ本町', '26', '26107', '6018136', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '上鳥羽岩ノ本町', 'カミトバイワノモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区上鳥羽城ケ前町', '26', '26107', '6018137', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '上鳥羽城ケ前町', 'カミトバシロガマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区上鳥羽卯ノ花', '26', '26107', '6018141', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '上鳥羽卯ノ花', 'カミトバウノハナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区上鳥羽中河原', '26', '26107', '6018142', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '上鳥羽中河原', 'カミトバナカガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区上鳥羽麻ノ本', '26', '26107', '6018143', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '上鳥羽麻ノ本', 'カミトバアサノモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区上鳥羽火打形町', '26', '26107', '6018144', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '上鳥羽火打形町', 'カミトバヒウチガタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区上鳥羽西浦町', '26', '26107', '6018145', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '上鳥羽西浦町', 'カミトバニシウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区上鳥羽奈須野町', '26', '26107', '6018146', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '上鳥羽奈須野町', 'カミトバナスノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区上鳥羽塔ノ森東向町', '26', '26107', '6018151', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '上鳥羽塔ノ森東向町', 'カミトバトウノモリヒガシムコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区上鳥羽塔ノ森洲崎町', '26', '26107', '6018152', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '上鳥羽塔ノ森洲崎町', 'カミトバトウノモリスザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区上鳥羽塔ノ森下河原', '26', '26107', '6018153', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '上鳥羽塔ノ森下河原', 'カミトバトウノモリシモカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区上鳥羽塔ノ森柳原', '26', '26107', '6018154', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '上鳥羽塔ノ森柳原', 'カミトバトウノモリヤナギハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区上鳥羽塔ノ森上河原', '26', '26107', '6018155', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '上鳥羽塔ノ森上河原', 'カミトバトウノモリカミカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区上鳥羽塔ノ森梅ノ木', '26', '26107', '6018161', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '上鳥羽塔ノ森梅ノ木', 'カミトバトウノモリウメノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区上鳥羽塔ノ森柴東町', '26', '26107', '6018162', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '上鳥羽塔ノ森柴東町', 'カミトバトウノモリシバヒガシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区上鳥羽塔ノ森江川町', '26', '26107', '6018163', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '上鳥羽塔ノ森江川町', 'カミトバトウノモリエガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区上鳥羽塔ノ森四ツ谷町', '26', '26107', '6018164', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '上鳥羽塔ノ森四ツ谷町', 'カミトバトウノモリヨツヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区上鳥羽塔ノ森西河原町', '26', '26107', '6018165', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '上鳥羽塔ノ森西河原町', 'カミトバトウノモリニシガワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区上鳥羽塔ノ森下開ノ内', '26', '26107', '6018166', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '上鳥羽塔ノ森下開ノ内', 'カミトバトウノモリシモヒラキノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区上鳥羽塔ノ森上開ノ内', '26', '26107', '6018167', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '上鳥羽塔ノ森上開ノ内', 'カミトバトウノモリカミヒラキノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区上鳥羽川端町', '26', '26107', '6018171', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '上鳥羽川端町', 'カミトバカワバタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区上鳥羽鍋ケ渕町', '26', '26107', '6018172', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '上鳥羽鍋ケ渕町', 'カミトバナベガフチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区上鳥羽八王神町', '26', '26107', '6018173', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '上鳥羽八王神町', 'カミトバハチオウジンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区上鳥羽清井町', '26', '26107', '6018174', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '上鳥羽清井町', 'カミトバキヨイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区上鳥羽金仏', '26', '26107', '6018175', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '上鳥羽金仏', 'カミトバカナボトケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区上鳥羽山ノ本町', '26', '26107', '6018176', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '上鳥羽山ノ本町', 'カミトバヤマノモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区上鳥羽馬廻', '26', '26107', '6018177', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '上鳥羽馬廻', 'カミトバウママワシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区上鳥羽戒光', '26', '26107', '6018178', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '上鳥羽戒光', 'カミトバカイコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区上鳥羽堀子町', '26', '26107', '6018181', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '上鳥羽堀子町', 'カミトバホリコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区上鳥羽北島田町', '26', '26107', '6018182', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '上鳥羽北島田町', 'カミトバキタシマダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区上鳥羽南島田町', '26', '26107', '6018183', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '上鳥羽南島田町', 'カミトバミナミシマダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区上鳥羽南村山町', '26', '26107', '6018184', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '上鳥羽南村山町', 'カミトバミナミムラヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区上鳥羽戒光町', '26', '26107', '6018185', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '上鳥羽戒光町', 'カミトバカイコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区上鳥羽北戒光町', '26', '26107', '6018186', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '上鳥羽北戒光町', 'カミトバキタカイコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区上鳥羽北村山町', '26', '26107', '6018187', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '上鳥羽北村山町', 'カミトバキタムラヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区上鳥羽南中ノ坪町', '26', '26107', '6018188', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '上鳥羽南中ノ坪町', 'カミトバミナミナカノツボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区久世川原町', '26', '26107', '6018201', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '久世川原町', 'クゼカワハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区久世大築町', '26', '26107', '6018202', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '久世大築町', 'クゼオオツキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区久世築山町', '26', '26107', '6018203', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '久世築山町', 'クゼツキヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区久世東土川町', '26', '26107', '6018204', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '久世東土川町', 'クゼヒガシツチカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区久世殿城町', '26', '26107', '6018205', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '久世殿城町', 'クゼトノシロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区久世大薮町', '26', '26107', '6018206', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '久世大薮町', 'クゼオオヤブチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区久世中久町', '26', '26107', '6018207', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '久世中久町', 'クゼナカヒサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区久世高田町', '26', '26107', '6018211', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '久世高田町', 'クゼタカダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区久世上久世町', '26', '26107', '6018212', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '久世上久世町', 'クゼカミクゼチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区久世中久世町', '26', '26107', '6018213', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '久世中久世町', 'クゼナカクゼチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区吉祥院西ノ庄西浦町', '26', '26107', '6018301', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '吉祥院西ノ庄西浦町', 'キッショウインニシノショウニシウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区吉祥院西ノ庄渕ノ西町', '26', '26107', '6018302', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '吉祥院西ノ庄渕ノ西町', 'キッショウインニシノショウフチノニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区吉祥院西ノ庄西中町', '26', '26107', '6018303', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '吉祥院西ノ庄西中町', 'キッショウインニシノショウニシナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区吉祥院前河原町', '26', '26107', '6018304', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '吉祥院前河原町', 'キッショウインマエガワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区吉祥院宮ノ東町', '26', '26107', '6018305', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '吉祥院宮ノ東町', 'キッショウインミヤノヒガシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区吉祥院宮ノ西町', '26', '26107', '6018306', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '吉祥院宮ノ西町', 'キッショウインミヤノニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区吉祥院向田西町', '26', '26107', '6018307', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '吉祥院向田西町', 'キッショウインムカイダニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区吉祥院向田東町', '26', '26107', '6018308', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '吉祥院向田東町', 'キッショウインムカイダヒガシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区吉祥院西ノ庄向田町', '26', '26107', '6018309', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '吉祥院西ノ庄向田町', 'キッショウインニシノショウムカイダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区吉祥院西ノ庄猪之馬場町', '26', '26107', '6018310', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '吉祥院西ノ庄猪之馬場町', 'キッショウインニシノショウイノババチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区吉祥院西ノ庄東屋敷町', '26', '26107', '6018311', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '吉祥院西ノ庄東屋敷町', 'キッショウインニシノショウヒガシヤシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区吉祥院西ノ庄門口町', '26', '26107', '6018312', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '吉祥院西ノ庄門口町', 'キッショウインニシノショウモングチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区吉祥院中島町', '26', '26107', '6018313', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '吉祥院中島町', 'キッショウインナカジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区吉祥院井ノ口町', '26', '26107', '6018314', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '吉祥院井ノ口町', 'キッショウインイノクチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区吉祥院車道町', '26', '26107', '6018315', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '吉祥院車道町', 'キッショウインクルマミチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区吉祥院池ノ内町', '26', '26107', '6018316', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '吉祥院池ノ内町', 'キッショウインイケノウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区吉祥院新田弐ノ段町', '26', '26107', '6018317', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '吉祥院新田弐ノ段町', 'キッショウインシンデンニノダンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区吉祥院三ノ宮西町', '26', '26107', '6018318', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '吉祥院三ノ宮西町', 'キッショウインサンノミヤニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区吉祥院三ノ宮町', '26', '26107', '6018319', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '吉祥院三ノ宮町', 'キッショウインサンノミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区吉祥院西定成町', '26', '26107', '6018321', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '吉祥院西定成町', 'キッショウインニシサダナリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区吉祥院定成町', '26', '26107', '6018322', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '吉祥院定成町', 'キッショウインサダナリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区吉祥院春日町', '26', '26107', '6018323', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '吉祥院春日町', 'キッショウインカスガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区吉祥院落合町', '26', '26107', '6018324', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '吉祥院落合町', 'キッショウインオチアイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区吉祥院八反田町', '26', '26107', '6018325', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '吉祥院八反田町', 'キッショウインハツタンダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区吉祥院南落合町', '26', '26107', '6018326', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '吉祥院南落合町', 'キッショウインミナミオチアイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区吉祥院御池町', '26', '26107', '6018327', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '吉祥院御池町', 'キッショウインオイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区吉祥院九条町', '26', '26107', '6018328', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '吉祥院九条町', 'キッショウインクジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区吉祥院清水町', '26', '26107', '6018329', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '吉祥院清水町', 'キッショウインシミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区吉祥院船戸町', '26', '26107', '6018330', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '吉祥院船戸町', 'キッショウインフナトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区吉祥院政所町', '26', '26107', '6018331', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '吉祥院政所町', 'キッショウインマンドコロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区吉祥院高畑町', '26', '26107', '6018332', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '吉祥院高畑町', 'キッショウインタカハタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区吉祥院東浦町', '26', '26107', '6018333', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '吉祥院東浦町', 'キッショウインヒガシウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区吉祥院東砂ノ町', '26', '26107', '6018334', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '吉祥院東砂ノ町', 'キッショウインヒガシスナノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区吉祥院砂ノ町', '26', '26107', '6018335', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '吉祥院砂ノ町', 'キッショウインスナノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区吉祥院菅原町', '26', '26107', '6018336', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '吉祥院菅原町', 'キッショウインスガハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区吉祥院這登東町', '26', '26107', '6018337', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '吉祥院這登東町', 'キッショウインハイノボリヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区吉祥院西ノ内町', '26', '26107', '6018338', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '吉祥院西ノ内町', 'キッショウインニシノウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区吉祥院里ノ内町', '26', '26107', '6018339', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '吉祥院里ノ内町', 'キッショウインサトノウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区吉祥院前田町', '26', '26107', '6018341', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '吉祥院前田町', 'キッショウインマエダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区吉祥院東前田町', '26', '26107', '6018342', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '吉祥院東前田町', 'キッショウインヒガシマエダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区吉祥院稲葉町', '26', '26107', '6018343', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '吉祥院稲葉町', 'キッショウインイナバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区吉祥院蒔絵町', '26', '26107', '6018344', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '吉祥院蒔絵町', 'キッショウインマキエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区吉祥院蒔絵南町', '26', '26107', '6018345', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '吉祥院蒔絵南町', 'キッショウインマキエミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区吉祥院池田南町', '26', '26107', '6018346', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '吉祥院池田南町', 'キッショウインイケダミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区吉祥院観音堂南町', '26', '26107', '6018347', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '吉祥院観音堂南町', 'キッショウインカンノンドウミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区吉祥院観音堂町', '26', '26107', '6018348', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '吉祥院観音堂町', 'キッショウインカンノンドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区吉祥院池田町', '26', '26107', '6018349', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '吉祥院池田町', 'キッショウインイケダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区吉祥院這登西町', '26', '26107', '6018351', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '吉祥院這登西町', 'キッショウインハイノボリニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区吉祥院西浦町', '26', '26107', '6018352', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '吉祥院西浦町', 'キッショウインニシウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区吉祥院這登中町', '26', '26107', '6018353', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '吉祥院這登中町', 'キッショウインハイノボリナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区吉祥院仁木ノ森町', '26', '26107', '6018354', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '吉祥院仁木ノ森町', 'キッショウインニキノモリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区吉祥院石原堂ノ後町', '26', '26107', '6018355', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '吉祥院石原堂ノ後町', 'キッショウインイシハラドウノウシロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区吉祥院石原京道町', '26', '26107', '6018356', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '吉祥院石原京道町', 'キッショウインイシハラキョウミチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区吉祥院石原堂ノ後西町', '26', '26107', '6018357', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '吉祥院石原堂ノ後西町', 'キッショウインイシハラドウノウシロニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区吉祥院石原東之口', '26', '26107', '6018361', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '吉祥院石原東之口', 'キッショウインイシハラヒガシノクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区吉祥院長田町', '26', '26107', '6018362', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '吉祥院長田町', 'キッショウインナガタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区吉祥院嶋野間詰町', '26', '26107', '6018363', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '吉祥院嶋野間詰町', 'キッショウインシマノマヅメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区吉祥院石原南町', '26', '26107', '6018364', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '吉祥院石原南町', 'キッショウインイシハラミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区吉祥院石原開町', '26', '26107', '6018365', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '吉祥院石原開町', 'キッショウインイシハラヒラキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区吉祥院石原西町', '26', '26107', '6018366', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '吉祥院石原西町', 'キッショウインイシハラニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区吉祥院石原町', '26', '26107', '6018367', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '吉祥院石原町', 'キッショウインイシハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区吉祥院嶋樫山町', '26', '26107', '6018371', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '吉祥院嶋樫山町', 'キッショウインシマカタギヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区吉祥院嶋高町', '26', '26107', '6018372', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '吉祥院嶋高町', 'キッショウインシマタカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区吉祥院嶋出在家町', '26', '26107', '6018373', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '吉祥院嶋出在家町', 'キッショウインシマデザイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区吉祥院嶋笠井町', '26', '26107', '6018374', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '吉祥院嶋笠井町', 'キッショウインシマカサイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区吉祥院嶋西浦', '26', '26107', '6018375', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '吉祥院嶋西浦', 'キッショウインシマニシウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区吉祥院嶋中ノ島', '26', '26107', '6018376', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '吉祥院嶋中ノ島', 'キッショウインシマナカノシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区吉祥院嶋堂ノ裏', '26', '26107', '6018377', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '吉祥院嶋堂ノ裏', 'キッショウインシマドウノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区吉祥院嶋堤外', '26', '26107', '6018378', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '吉祥院嶋堤外', 'キッショウインシマツツミソト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区吉祥院嶋川原田町', '26', '26107', '6018379', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '吉祥院嶋川原田町', 'キッショウインシマカワラダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区吉祥院新田下ノ向町', '26', '26107', '6018380', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '吉祥院新田下ノ向町', 'キッショウインシンデンシモノムカイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区吉祥院西ノ茶屋町', '26', '26107', '6018381', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '吉祥院西ノ茶屋町', 'キッショウインニシノチャヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区吉祥院石原上川原町', '26', '26107', '6018382', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '吉祥院石原上川原町', 'キッショウインイシハラカミカワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区吉祥院石原長田町', '26', '26107', '6018383', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '吉祥院石原長田町', 'キッショウインイシハラナガタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区吉祥院石原野上町', '26', '26107', '6018384', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '吉祥院石原野上町', 'キッショウインイシハラノガミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区吉祥院石原葭縁', '26', '26107', '6018385', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '吉祥院石原葭縁', 'キッショウインイシハラヨシベリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区吉祥院石原割畑', '26', '26107', '6018386', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '吉祥院石原割畑', 'キッショウインイシハラワリハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区吉祥院石原橋裏', '26', '26107', '6018387', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '吉祥院石原橋裏', 'キッショウインイシハラハシウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区吉祥院石原西ノ開町', '26', '26107', '6018388', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '吉祥院石原西ノ開町', 'キッショウインイシハラニシノヒラキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区吉祥院石原橋上', '26', '26107', '6018389', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '吉祥院石原橋上', 'キッショウインイシハラハシカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区吉祥院流作町', '26', '26107', '6018390', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '吉祥院流作町', 'キッショウインリュウサクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区吉祥院大河原町', '26', '26107', '6018391', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '吉祥院大河原町', 'キッショウインオオガワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区吉祥院内河原町', '26', '26107', '6018392', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '吉祥院内河原町', 'キッショウインウチガワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区吉祥院中河原里西町', '26', '26107', '6018393', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '吉祥院中河原里西町', 'キッショウインナカガワラサトニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区吉祥院中河原里北町', '26', '26107', '6018394', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '吉祥院中河原里北町', 'キッショウインナカガワラサトキタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区吉祥院中河原西屋敷町', '26', '26107', '6018395', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '吉祥院中河原西屋敷町', 'キッショウインナカガワラニシヤシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区吉祥院中河原里南町', '26', '26107', '6018396', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '吉祥院中河原里南町', 'キッショウインナカガワラサトミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区吉祥院新田壱ノ段町', '26', '26107', '6018397', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '吉祥院新田壱ノ段町', 'キッショウインシンデンイチノダンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区吉祥院新田参ノ段町', '26', '26107', '6018398', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '吉祥院新田参ノ段町', 'キッショウインシンデンサンノダンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区吉祥院堤外町', '26', '26107', '6018399', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '吉祥院堤外町', 'キッショウインツツミソトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区塩屋町', '26', '26107', '6018401', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '塩屋町', 'シオヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区大黒町', '26', '26107', '6018402', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '大黒町', 'ダイコクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区古御旅町', '26', '26107', '6018403', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '古御旅町', 'フルオタビチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区西九条小寺町', '26', '26107', '6018404', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '西九条小寺町', 'ニシクジョウコデラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区西九条戒光寺町', '26', '26107', '6018405', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '西九条戒光寺町', 'ニシクジョウカイコウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区戒光寺町', '26', '26107', '6018406', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '戒光寺町', 'カイコウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区西九条寺ノ前町', '26', '26107', '6018407', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '西九条寺ノ前町', 'ニシクジョウテラノマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区西九条北ノ内町', '26', '26107', '6018411', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '西九条北ノ内町', 'ニシクジョウキタノウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区西九条院町', '26', '26107', '6018412', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '西九条院町', 'ニシクジョウインマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区西九条春日町', '26', '26107', '6018413', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '西九条春日町', 'ニシクジョウカスガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区西九条蔵王町', '26', '26107', '6018414', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '西九条蔵王町', 'ニシクジョウザオウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区西九条西蔵王町', '26', '26107', '6018415', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '西九条西蔵王町', 'ニシクジョウニシザオウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区西九条池ノ内町', '26', '26107', '6018416', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '西九条池ノ内町', 'ニシクジョウイケノウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区西九条鳥居口町', '26', '26107', '6018417', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '西九条鳥居口町', 'ニシクジョウトリイグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区西九条藤ノ木町', '26', '26107', '6018421', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '西九条藤ノ木町', 'ニシクジョウフジノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区西九条針小路町', '26', '26107', '6018422', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '西九条針小路町', 'ニシクジョウハリコウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区西九条唐橋町', '26', '26107', '6018423', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '西九条唐橋町', 'ニシクジョウカラハシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区西九条川原城町', '26', '26107', '6018424', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '西九条川原城町', 'ニシクジョウカワラジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区西九条南小路町', '26', '26107', '6018425', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '西九条南小路町', 'ニシクジョウミナミコウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区西九条猪熊町', '26', '26107', '6018426', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '西九条猪熊町', 'ニシクジョウイノクマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区西九条横町', '26', '26107', '6018427', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '西九条横町', 'ニシクジョウヨコマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区東寺東門前町', '26', '26107', '6018428', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '東寺東門前町', 'トウジヒガシモンゼンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区西九条島町', '26', '26107', '6018431', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '西九条島町', 'ニシクジョウシママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区西九条東島町', '26', '26107', '6018432', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '西九条東島町', 'ニシクジョウヒガシシママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区西九条東柳ノ内町', '26', '26107', '6018433', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '西九条東柳ノ内町', 'ニシクジョウヒガシヤナギノウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区西九条仏現寺町', '26', '26107', '6018434', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '西九条仏現寺町', 'ニシクジョウブツゲンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区西九条柳ノ内町', '26', '26107', '6018435', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '西九条柳ノ内町', 'ニシクジョウヤナギノウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区西九条西柳ノ内町', '26', '26107', '6018436', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '西九条西柳ノ内町', 'ニシクジョウニシヤナギノウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区西九条比永城町', '26', '26107', '6018437', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '西九条比永城町', 'ニシクジョウヒエイジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区西九条東比永城町', '26', '26107', '6018438', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '西九条東比永城町', 'ニシクジョウヒガシヒエイジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区西九条開ケ町', '26', '26107', '6018439', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '西九条開ケ町', 'ニシクジョウカイガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区西九条南田町', '26', '26107', '6018441', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '西九条南田町', 'ニシクジョウナンデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区西九条御幸田町', '26', '26107', '6018442', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '西九条御幸田町', 'ニシクジョウゴコウデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区西九条東御幸田町', '26', '26107', '6018443', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '西九条東御幸田町', 'ニシクジョウヒガシゴコウデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区西九条森本町', '26', '26107', '6018444', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '西九条森本町', 'ニシクジョウモリモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区西九条菅田町', '26', '26107', '6018445', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '西九条菅田町', 'ニシクジョウスガタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区西九条高畠町', '26', '26107', '6018446', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '西九条高畠町', 'ニシクジョウタカハタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区西九条唐戸町', '26', '26107', '6018447', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '西九条唐戸町', 'ニシクジョウカラトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区西九条豊田町', '26', '26107', '6018448', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '西九条豊田町', 'ニシクジョウトヨダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区西九条大国町', '26', '26107', '6018449', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '西九条大国町', 'ニシクジョウオオクニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区唐橋川久保町', '26', '26107', '6018451', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '唐橋川久保町', 'カラハシカワクボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区唐橋堂ノ前町', '26', '26107', '6018452', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '唐橋堂ノ前町', 'カラハシドウノマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区唐橋羅城門町', '26', '26107', '6018453', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '唐橋羅城門町', 'カラハシラジョウモンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区唐橋経田町', '26', '26107', '6018454', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '唐橋経田町', 'カラハシケイデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区唐橋芦辺町', '26', '26107', '6018455', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '唐橋芦辺町', 'カラハシアシベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区唐橋南琵琶町', '26', '26107', '6018456', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '唐橋南琵琶町', 'カラハシミナミビワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区唐橋琵琶町', '26', '26107', '6018457', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '唐橋琵琶町', 'カラハシビワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区唐橋門脇町', '26', '26107', '6018461', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '唐橋門脇町', 'カラハシカドワキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区唐橋井園町', '26', '26107', '6018462', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '唐橋井園町', 'カラハシイソノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区唐橋赤金町', '26', '26107', '6018463', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '唐橋赤金町', 'カラハシアカカネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区唐橋高田町', '26', '26107', '6018464', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '唐橋高田町', 'カラハシタカダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区唐橋花園町', '26', '26107', '6018465', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '唐橋花園町', 'カラハシハナゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区唐橋西寺町', '26', '26107', '6018466', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '唐橋西寺町', 'カラハシサイジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区唐橋大宮尻町', '26', '26107', '6018467', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '唐橋大宮尻町', 'カラハシオオミヤジリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区唐橋西平垣町', '26', '26107', '6018468', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '唐橋西平垣町', 'カラハシニシヒラガキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区唐橋平垣町', '26', '26107', '6018469', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '唐橋平垣町', 'カラハシヒラガキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区八条町', '26', '26107', '6018471', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '八条町', 'ハチジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区八条坊門町', '26', '26107', '6018472', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '八条坊門町', 'ハチジョウボウモンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区九条町', '26', '26107', '6018473', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '九条町', 'クジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区四ツ塚町', '26', '26107', '6018474', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '四ツ塚町', 'ヨツヅカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区八条内田町', '26', '26107', '6018475', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '八条内田町', 'ハチジョウウチダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区八条寺ノ内町', '26', '26107', '6018476', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '八条寺ノ内町', 'ハチジョウテラノウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区八条源町', '26', '26107', '6018477', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '八条源町', 'ハチジョウミナモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市南区東寺町', '26', '26107', '6018478', '京都府', 'キョウトフ', '京都市南区', 'キョウトシミナミク', '東寺町', 'トウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区', '26', '26102', '6020000', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('66258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区竹園町', '26', '26102', '6020001', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '竹園町', 'タケゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区継孝院町', '26', '26102', '6020002', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '継孝院町', 'ケイコウインチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区大心院町', '26', '26102', '6020003', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '大心院町', 'ダイシンインチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区道正町', '26', '26102', '6020004', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '道正町', 'ドウショウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区妙顕寺前町', '26', '26102', '6020005', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '妙顕寺前町', 'ミョウケンジマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区禅昌院町', '26', '26102', '6020006', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '禅昌院町', 'ゼンショウインチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区下清蔵口町', '26', '26102', '6020007', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '下清蔵口町', 'シモセイゾウグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区岩栖院町', '26', '26102', '6020008', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '岩栖院町', 'ガンスインチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区森之木町', '26', '26102', '6020011', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '森之木町', 'モリノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区内構町', '26', '26102', '6020012', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '内構町', 'ウチガマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区上柳原町', '26', '26102', '6020013', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '上柳原町', 'カミヤナギハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区下柳原北半町', '26', '26102', '6020014', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '下柳原北半町', 'シモヤナギハラキタハンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区下柳原南半町', '26', '26102', '6020015', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '下柳原南半町', 'シモヤナギハラミナミハンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区畠中町', '26', '26102', '6020016', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '畠中町', 'ハタナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区上木下町', '26', '26102', '6020017', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '上木下町', 'カミキノシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区玄蕃町', '26', '26102', '6020018', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '玄蕃町', 'ゲンバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区下木下町', '26', '26102', '6020019', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '下木下町', 'シモキノシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区柳図子町', '26', '26102', '6020021', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '柳図子町', 'ヤナギノズシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区上立売東町', '26', '26102', '6020022', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '上立売東町', 'カミダチウリヒガシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区御所八幡町', '26', '26102', '6020023', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '御所八幡町', 'ゴショハチマンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区上立売町', '26', '26102', '6020024', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '上立売町', 'カミダチウリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区裏風呂町', '26', '26102', '6020025', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '裏風呂町', 'ウラフロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区古木町', '26', '26102', '6020026', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '古木町', 'フルキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区木下突抜町', '26', '26102', '6020027', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '木下突抜町', 'キノシタツキヌケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区納屋町', '26', '26102', '6020028', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '納屋町', 'ナヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区室町頭町', '26', '26102', '6020029', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '室町頭町', 'ムロマチカシラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区裏築地町', '26', '26102', '6020031', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '裏築地町', 'ウラツキジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区岡松町', '26', '26102', '6020032', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '岡松町', 'オカマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区今出川町烏丸通今出川上る', '26', '26102', '6020033', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '今出川町', 'イマデガワチョウ', null, '烏丸通今出川上る', null, null);
INSERT INTO `ms_addresses` VALUES ('66287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区今出川町烏丸通今出川下る', '26', '26102', '6020033', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '今出川町', 'イマデガワチョウ', null, '烏丸通今出川下る', null, null);
INSERT INTO `ms_addresses` VALUES ('66288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区今出川町今出川通烏丸西入', '26', '26102', '6020033', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '今出川町', 'イマデガワチョウ', null, '今出川通烏丸西入', null, null);
INSERT INTO `ms_addresses` VALUES ('66289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区今出川町今出川通室町東入', '26', '26102', '6020033', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '今出川町', 'イマデガワチョウ', null, '今出川通室町東入', null, null);
INSERT INTO `ms_addresses` VALUES ('66290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区築山南半町', '26', '26102', '6020034', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '築山南半町', 'ツキヤマミナミハンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区畠山町', '26', '26102', '6020035', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '畠山町', 'ハタケヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区蒔鳥屋町', '26', '26102', '6020036', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '蒔鳥屋町', 'マキトリヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区瓢箪図子町', '26', '26102', '6020037', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '瓢箪図子町', 'ヒョウタンズシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区築山北半町', '26', '26102', '6020038', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '築山北半町', 'ツキヤマキタハンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区中御霊図子町', '26', '26102', '6020041', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '中御霊図子町', 'ナカゴリョウズシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区元新在家町', '26', '26102', '6020042', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '元新在家町', 'モトシンザイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区元本満寺町', '26', '26102', '6020043', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '元本満寺町', 'モトホンマンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区北兼康町', '26', '26102', '6020044', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '北兼康町', 'キタカネヤスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区近衛殿北口町', '26', '26102', '6020045', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '近衛殿北口町', 'コノエデンキタグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区西大路町上立売通小川東入', '26', '26102', '6020046', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '西大路町', 'ニシオオジチョウ', null, '上立売通小川東入', null, null);
INSERT INTO `ms_addresses` VALUES ('66301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区西大路町上立売通新町西入', '26', '26102', '6020046', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '西大路町', 'ニシオオジチョウ', null, '上立売通新町西入', null, null);
INSERT INTO `ms_addresses` VALUES ('66302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区西大路町上立売通新町東入', '26', '26102', '6020046', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '西大路町', 'ニシオオジチョウ', null, '上立売通新町東入', null, null);
INSERT INTO `ms_addresses` VALUES ('66303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区西大路町上立売通新町東入上る', '26', '26102', '6020046', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '西大路町', 'ニシオオジチョウ', null, '上立売通新町東入上る', null, null);
INSERT INTO `ms_addresses` VALUES ('66304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区西大路町新町通上立売上る', '26', '26102', '6020046', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '西大路町', 'ニシオオジチョウ', null, '新町通上立売上る', null, null);
INSERT INTO `ms_addresses` VALUES ('66305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区近衛殿表町', '26', '26102', '6020047', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '近衛殿表町', 'コノエデンオモテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区御三軒町', '26', '26102', '6020051', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '御三軒町', 'ゴサンゲンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区上小川町', '26', '26102', '6020052', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '上小川町', 'カミオガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区中小川町', '26', '26102', '6020053', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '中小川町', 'ナカオガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区飛鳥井町', '26', '26102', '6020054', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '飛鳥井町', 'アスカイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区南舟橋町', '26', '26102', '6020055', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '南舟橋町', 'ミナミフナハシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区北舟橋町', '26', '26102', '6020056', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '北舟橋町', 'キタフナハシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区堀之上町', '26', '26102', '6020057', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '堀之上町', 'ホリノウエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区水落町', '26', '26102', '6020058', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '水落町', 'ミズオチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区実相院町', '26', '26102', '6020059', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '実相院町', 'ジッソウインチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区本法寺前町', '26', '26102', '6020061', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '本法寺前町', 'ホンポウジマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区宝鏡院東町', '26', '26102', '6020062', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '宝鏡院東町', 'ホウキョウインヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区内藤町', '26', '26102', '6020063', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '内藤町', 'ナイトウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区安楽小路町', '26', '26102', '6020064', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '安楽小路町', 'アンラクコウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区挽木町', '26', '26102', '6020065', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '挽木町', 'ヒキギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区射場町', '26', '26102', '6020066', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '射場町', 'イバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区竹屋町', '26', '26102', '6020067', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '竹屋町', 'タケヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区扇町堀川通寺之内上る', '26', '26102', '6020071', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '扇町', 'オウギチョウ', null, '堀川通寺之内上る', null, null);
INSERT INTO `ms_addresses` VALUES ('66323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区扇町堀川通上御霊前上る', '26', '26102', '6020071', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '扇町', 'オウギチョウ', null, '堀川通上御霊前上る', null, null);
INSERT INTO `ms_addresses` VALUES ('66324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区扇町上御霊前通堀川東入', '26', '26102', '6020071', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '扇町', 'オウギチョウ', null, '上御霊前通堀川東入', null, null);
INSERT INTO `ms_addresses` VALUES ('66325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区百々町', '26', '26102', '6020072', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '百々町', 'ドドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区寺之内竪町', '26', '26102', '6020073', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '寺之内竪町', 'テラノウチタテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区下天神町', '26', '26102', '6020074', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '下天神町', 'シモテンジンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区瑞光院前町', '26', '26102', '6020081', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '瑞光院前町', 'ズイコウインマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区上天神町', '26', '26102', '6020082', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '上天神町', 'カミテンジンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区新ン町', '26', '26102', '6020083', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '新ン町', 'シンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区若宮横町', '26', '26102', '6020084', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '若宮横町', 'ワカミヤヨコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区若宮竪町', '26', '26102', '6020085', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '若宮竪町', 'ワカミヤタテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区東若宮町', '26', '26102', '6020086', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '東若宮町', 'ヒガシワカミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区天神北町', '26', '26102', '6020087', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '天神北町', 'テンジンキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区筋違橋町', '26', '26102', '6020091', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '筋違橋町', 'スジカイバシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区北仲之町', '26', '26102', '6020092', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '北仲之町', 'キタナカノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区仲之町大宮通上御霊前上る', '26', '26102', '6020093', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '仲之町', 'ナカノチョウ', null, '大宮通上御霊前上る', null, null);
INSERT INTO `ms_addresses` VALUES ('66338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区仲之町大宮通上御霊前下る', '26', '26102', '6020093', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '仲之町', 'ナカノチョウ', null, '大宮通上御霊前下る', null, null);
INSERT INTO `ms_addresses` VALUES ('66339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区仲之町大宮通蘆山寺上る', '26', '26102', '6020093', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '仲之町', 'ナカノチョウ', null, '大宮通蘆山寺上る', null, null);
INSERT INTO `ms_addresses` VALUES ('66340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区仲之町大宮通寺之内上る', '26', '26102', '6020093', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '仲之町', 'ナカノチョウ', null, '大宮通寺之内上る', null, null);
INSERT INTO `ms_addresses` VALUES ('66341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区仲之町大宮通寺之内上る2丁目', '26', '26102', '6020093', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '仲之町', 'ナカノチョウ', null, '大宮通寺之内上る2丁目', null, null);
INSERT INTO `ms_addresses` VALUES ('66342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区仲之町上御霊前通大宮西入', '26', '26102', '6020093', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '仲之町', 'ナカノチョウ', null, '上御霊前通大宮西入', null, null);
INSERT INTO `ms_addresses` VALUES ('66343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区仲之町上御霊前通大宮東入', '26', '26102', '6020093', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '仲之町', 'ナカノチョウ', null, '上御霊前通大宮東入', null, null);
INSERT INTO `ms_addresses` VALUES ('66344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区仲之町蘆山寺通大宮西入', '26', '26102', '6020093', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '仲之町', 'ナカノチョウ', null, '蘆山寺通大宮西入', null, null);
INSERT INTO `ms_addresses` VALUES ('66345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区社横町', '26', '26102', '6020094', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '社横町', 'ヤシロヨコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区社突抜町', '26', '26102', '6020095', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '社突抜町', 'ヤシロツキヌケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区西若宮南半町', '26', '26102', '6020096', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '西若宮南半町', 'ニシワカミヤミナミハンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区西若宮北半町', '26', '26102', '6020097', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '西若宮北半町', 'ニシワカミヤキタハンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区竪社北半町', '26', '26102', '6020098', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '竪社北半町', 'タテヤシロキタハンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区竪社南半町', '26', '26102', '6020099', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '竪社南半町', 'タテヤシロミナミハンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区高徳寺町', '26', '26102', '6020801', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '高徳寺町', 'コウトクジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区鶴山町', '26', '26102', '6020802', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '鶴山町', 'ツルヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区阿弥陀寺前町', '26', '26102', '6020803', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '阿弥陀寺前町', 'アミダジマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区上片原町', '26', '26102', '6020804', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '上片原町', 'カミカタハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区桜木町', '26', '26102', '6020805', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '桜木町', 'サクラギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区藪之下町', '26', '26102', '6020806', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '藪之下町', 'ヤブノシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区不動前町', '26', '26102', '6020807', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '不動前町', 'フドウマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区歓喜寺前町', '26', '26102', '6020808', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '歓喜寺前町', 'カンキジマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区十念寺前町', '26', '26102', '6020811', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '十念寺前町', 'ジュウネンジマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区本満寺前町', '26', '26102', '6020812', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '本満寺前町', 'ホンマンジマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区上神輿町', '26', '26102', '6020813', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '上神輿町', 'カミミコシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区幸神町', '26', '26102', '6020814', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '幸神町', 'サイノカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区上塔之段町', '26', '26102', '6020815', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '上塔之段町', 'カミトウノダンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区毘沙門町上立売通寺町西入', '26', '26102', '6020816', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '毘沙門町', 'ビシャモンチョウ', null, '上立売通寺町西入', null, null);
INSERT INTO `ms_addresses` VALUES ('66365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区毘沙門町上立売通寺町西入上る', '26', '26102', '6020816', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '毘沙門町', 'ビシャモンチョウ', null, '上立売通寺町西入上る', null, null);
INSERT INTO `ms_addresses` VALUES ('66366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区毘沙門町上立売通寺町西入下る', '26', '26102', '6020816', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '毘沙門町', 'ビシャモンチョウ', null, '上立売通寺町西入下る', null, null);
INSERT INTO `ms_addresses` VALUES ('66367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区毘沙門町上立売通寺町西入4筋目下る', '26', '26102', '6020816', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '毘沙門町', 'ビシャモンチョウ', null, '上立売通寺町西入4筋目下る', null, null);
INSERT INTO `ms_addresses` VALUES ('66368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区毘沙門町寺町通今出川上る1筋目西入', '26', '26102', '6020816', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '毘沙門町', 'ビシャモンチョウ', null, '寺町通今出川上る1筋目西入', null, null);
INSERT INTO `ms_addresses` VALUES ('66369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区毘沙門町寺町通今出川上る2丁目', '26', '26102', '6020816', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '毘沙門町', 'ビシャモンチョウ', null, '寺町通今出川上る2丁目', null, null);
INSERT INTO `ms_addresses` VALUES ('66370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区毘沙門町寺町通今出川上る2丁目西入', '26', '26102', '6020816', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '毘沙門町', 'ビシャモンチョウ', null, '寺町通今出川上る2丁目西入', null, null);
INSERT INTO `ms_addresses` VALUES ('66371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区毘沙門町寺町通今出川上る3丁目', '26', '26102', '6020816', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '毘沙門町', 'ビシャモンチョウ', null, '寺町通今出川上る3丁目', null, null);
INSERT INTO `ms_addresses` VALUES ('66372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区毘沙門町寺町通今出川上る3丁目西入', '26', '26102', '6020816', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '毘沙門町', 'ビシャモンチョウ', null, '寺町通今出川上る3丁目西入', null, null);
INSERT INTO `ms_addresses` VALUES ('66373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区毘沙門町寺町通今出川上る4丁目', '26', '26102', '6020816', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '毘沙門町', 'ビシャモンチョウ', null, '寺町通今出川上る4丁目', null, null);
INSERT INTO `ms_addresses` VALUES ('66374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区毘沙門町寺町通今出川上る4丁目西入', '26', '26102', '6020816', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '毘沙門町', 'ビシャモンチョウ', null, '寺町通今出川上る4丁目西入', null, null);
INSERT INTO `ms_addresses` VALUES ('66375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区毘沙門町寺町通今出川西入', '26', '26102', '6020816', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '毘沙門町', 'ビシャモンチョウ', null, '寺町通今出川西入', null, null);
INSERT INTO `ms_addresses` VALUES ('66376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区毘沙門町寺町通今出川2丁目上る西入', '26', '26102', '6020816', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '毘沙門町', 'ビシャモンチョウ', null, '寺町通今出川2丁目上る西入', null, null);
INSERT INTO `ms_addresses` VALUES ('66377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区毘沙門町塔之段寺町通今出川上る', '26', '26102', '6020816', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '毘沙門町', 'ビシャモンチョウ', null, '塔之段寺町通今出川上る', null, null);
INSERT INTO `ms_addresses` VALUES ('66378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区毘沙門横町', '26', '26102', '6020817', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '毘沙門横町', 'ビシャモンヨコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区北横町', '26', '26102', '6020818', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '北横町', 'キタヨコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区松之木町', '26', '26102', '6020819', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '松之木町', 'マツノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区後藤町', '26', '26102', '6020821', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '後藤町', 'ゴトウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区青龍町', '26', '26102', '6020822', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '青龍町', 'セイリュウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区三芳町', '26', '26102', '6020823', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '三芳町', 'ミヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区一真町', '26', '26102', '6020824', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '一真町', 'イッシンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区表町', '26', '26102', '6020825', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '表町', 'オモテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区三栄町', '26', '26102', '6020826', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '三栄町', 'サンエイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区相生町', '26', '26102', '6020827', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '相生町', 'アイオイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区二神町', '26', '26102', '6020828', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '二神町', 'ニシンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区立本寺前町', '26', '26102', '6020831', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '立本寺前町', 'リュウホンジマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区大原口町', '26', '26102', '6020832', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '大原口町', 'オオハラグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区真如堂突抜町', '26', '26102', '6020833', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '真如堂突抜町', 'シンニョドウツキヌケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区大原口突抜町', '26', '26102', '6020834', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '大原口突抜町', 'オオハラグチツキヌケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区革堂内町', '26', '26102', '6020835', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '革堂内町', 'コウドウウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区常盤井殿町', '26', '26102', '6020836', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '常盤井殿町', 'トキワイドノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区下塔之段町', '26', '26102', '6020837', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '下塔之段町', 'シモトウノダンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区柳風呂町', '26', '26102', '6020838', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '柳風呂町', 'ヤナギフロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区下御輿町', '26', '26102', '6020839', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '下御輿町', 'シモミコシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区梶井町', '26', '26102', '6020841', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '梶井町', 'カジイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区栄町石薬師通河原西入', '26', '26102', '6020842', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '栄町', 'サカエチョウ', null, '石薬師通河原西入', null, null);
INSERT INTO `ms_addresses` VALUES ('66400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区栄町河原町通石薬師上る', '26', '26102', '6020842', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '栄町', 'サカエチョウ', null, '河原町通石薬師上る', null, null);
INSERT INTO `ms_addresses` VALUES ('66401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区栄町河原町通石薬師下る', '26', '26102', '6020842', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '栄町', 'サカエチョウ', null, '河原町通石薬師下る', null, null);
INSERT INTO `ms_addresses` VALUES ('66402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区栄町河原町通今出川下る', '26', '26102', '6020842', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '栄町', 'サカエチョウ', null, '河原町通今出川下る', null, null);
INSERT INTO `ms_addresses` VALUES ('66403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区栄町河原町通今出川2筋目下る西', '26', '26102', '6020842', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '栄町', 'サカエチョウ', null, '河原町通今出川2筋目下る西', null, null);
INSERT INTO `ms_addresses` VALUES ('66404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区栄町河原町通今出川下る2丁目', '26', '26102', '6020842', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '栄町', 'サカエチョウ', null, '河原町通今出川下る2丁目', null, null);
INSERT INTO `ms_addresses` VALUES ('66405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区栄町河原町通今出川下る2筋目西', '26', '26102', '6020842', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '栄町', 'サカエチョウ', null, '河原町通今出川下る2筋目西', null, null);
INSERT INTO `ms_addresses` VALUES ('66406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区栄町河原町通今出川下る3丁目', '26', '26102', '6020842', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '栄町', 'サカエチョウ', null, '河原町通今出川下る3丁目', null, null);
INSERT INTO `ms_addresses` VALUES ('66407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区新夷町', '26', '26102', '6020843', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '新夷町', 'シンエビスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区染殿町', '26', '26102', '6020844', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '染殿町', 'ソメドノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区真如堂前町', '26', '26102', '6020845', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '真如堂前町', 'シンニョドウマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区米屋町今出川通寺町東入', '26', '26102', '6020846', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '米屋町', 'コメヤチョウ', null, '今出川通寺町東入', null, null);
INSERT INTO `ms_addresses` VALUES ('66411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区米屋町今出川通寺町東入下る', '26', '26102', '6020846', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '米屋町', 'コメヤチョウ', null, '今出川通寺町東入下る', null, null);
INSERT INTO `ms_addresses` VALUES ('66412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区米屋町今出川通河原町西入上る', '26', '26102', '6020846', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '米屋町', 'コメヤチョウ', null, '今出川通河原町西入上る', null, null);
INSERT INTO `ms_addresses` VALUES ('66413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区米屋町河原町通今出川下る西入', '26', '26102', '6020846', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '米屋町', 'コメヤチョウ', null, '河原町通今出川下る西入', null, null);
INSERT INTO `ms_addresses` VALUES ('66414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区米屋町寺町通今出川下る', '26', '26102', '6020846', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '米屋町', 'コメヤチョウ', null, '寺町通今出川下る', null, null);
INSERT INTO `ms_addresses` VALUES ('66415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区米屋町寺町通今出川下る東入', '26', '26102', '6020846', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '米屋町', 'コメヤチョウ', null, '寺町通今出川下る東入', null, null);
INSERT INTO `ms_addresses` VALUES ('66416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区米屋町中筋通今出川下る', '26', '26102', '6020846', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '米屋町', 'コメヤチョウ', null, '中筋通今出川下る', null, null);
INSERT INTO `ms_addresses` VALUES ('66417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区大宮町今出川通河原町西入', '26', '26102', '6020847', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '大宮町', 'オオミヤチョウ', null, '今出川通河原町西入', null, null);
INSERT INTO `ms_addresses` VALUES ('66418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区大宮町今出川通寺町東入', '26', '26102', '6020847', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '大宮町', 'オオミヤチョウ', null, '今出川通寺町東入', null, null);
INSERT INTO `ms_addresses` VALUES ('66419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区大宮町今出川通寺町東入下る', '26', '26102', '6020847', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '大宮町', 'オオミヤチョウ', null, '今出川通寺町東入下る', null, null);
INSERT INTO `ms_addresses` VALUES ('66420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区大宮町河原町通今出川下る', '26', '26102', '6020847', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '大宮町', 'オオミヤチョウ', null, '河原町通今出川下る', null, null);
INSERT INTO `ms_addresses` VALUES ('66421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区大宮町河原町通今出川下る西入', '26', '26102', '6020847', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '大宮町', 'オオミヤチョウ', null, '河原町通今出川下る西入', null, null);
INSERT INTO `ms_addresses` VALUES ('66422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区大宮町寺町通今出川下る東入', '26', '26102', '6020847', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '大宮町', 'オオミヤチョウ', null, '寺町通今出川下る東入', null, null);
INSERT INTO `ms_addresses` VALUES ('66423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区大宮町中筋通石薬師上る', '26', '26102', '6020847', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '大宮町', 'オオミヤチョウ', null, '中筋通石薬師上る', null, null);
INSERT INTO `ms_addresses` VALUES ('66424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区扇町寺町通今出川下る', '26', '26102', '6020848', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '扇町', 'オウギチョウ', null, '寺町通今出川下る', null, null);
INSERT INTO `ms_addresses` VALUES ('66425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区扇町寺町通石薬師上る', '26', '26102', '6020848', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '扇町', 'オウギチョウ', null, '寺町通石薬師上る', null, null);
INSERT INTO `ms_addresses` VALUES ('66426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区扇町寺町通石薬師下る', '26', '26102', '6020848', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '扇町', 'オウギチョウ', null, '寺町通石薬師下る', null, null);
INSERT INTO `ms_addresses` VALUES ('66427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区扇町寺町通広小路上る', '26', '26102', '6020848', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '扇町', 'オウギチョウ', null, '寺町通広小路上る', null, null);
INSERT INTO `ms_addresses` VALUES ('66428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区扇町石薬師通寺町東入', '26', '26102', '6020848', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '扇町', 'オウギチョウ', null, '石薬師通寺町東入', null, null);
INSERT INTO `ms_addresses` VALUES ('66429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区大猪熊町中筋通石薬師上る', '26', '26102', '6020849', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '大猪熊町', 'オオイノクマチョウ', null, '中筋通石薬師上る', null, null);
INSERT INTO `ms_addresses` VALUES ('66430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区大猪熊町石薬師通河原町西入', '26', '26102', '6020849', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '大猪熊町', 'オオイノクマチョウ', null, '石薬師通河原町西入', null, null);
INSERT INTO `ms_addresses` VALUES ('66431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区大猪熊町石薬師通寺町東入', '26', '26102', '6020849', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '大猪熊町', 'オオイノクマチョウ', null, '石薬師通寺町東入', null, null);
INSERT INTO `ms_addresses` VALUES ('66432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区大猪熊町石薬師通中筋西入', '26', '26102', '6020849', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '大猪熊町', 'オオイノクマチョウ', null, '石薬師通中筋西入', null, null);
INSERT INTO `ms_addresses` VALUES ('66433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区大猪熊町石薬師通中筋東入', '26', '26102', '6020849', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '大猪熊町', 'オオイノクマチョウ', null, '石薬師通中筋東入', null, null);
INSERT INTO `ms_addresses` VALUES ('66434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区九軒町', '26', '26102', '6020851', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '九軒町', 'キュウケンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区北之辺町', '26', '26102', '6020852', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '北之辺町', 'キタノベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区宮垣町', '26', '26102', '6020853', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '宮垣町', 'ミヤガキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区亀屋町河原町通荒神口東入', '26', '26102', '6020854', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '亀屋町', 'カメヤチョウ', null, '河原町通荒神口東入', null, null);
INSERT INTO `ms_addresses` VALUES ('66438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区亀屋町荒神口通河原町東入', '26', '26102', '6020854', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '亀屋町', 'カメヤチョウ', null, '荒神口通河原町東入', null, null);
INSERT INTO `ms_addresses` VALUES ('66439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区上生洲町', '26', '26102', '6020855', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '上生洲町', 'カミイケスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区荒神町河原町通荒神口上る', '26', '26102', '6020856', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '荒神町', 'コウジンチョウ', null, '河原町通荒神口上る', null, null);
INSERT INTO `ms_addresses` VALUES ('66441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区荒神町荒神口通河原町西入', '26', '26102', '6020856', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '荒神町', 'コウジンチョウ', null, '荒神口通河原町西入', null, null);
INSERT INTO `ms_addresses` VALUES ('66442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区荒神町荒神口通河原町東入', '26', '26102', '6020856', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '荒神町', 'コウジンチョウ', null, '荒神口通河原町東入', null, null);
INSERT INTO `ms_addresses` VALUES ('66443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区荒神町荒神口通寺町東入', '26', '26102', '6020856', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '荒神町', 'コウジンチョウ', null, '荒神口通寺町東入', null, null);
INSERT INTO `ms_addresses` VALUES ('66444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区荒神町寺町通荒神口上る', '26', '26102', '6020856', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '荒神町', 'コウジンチョウ', null, '寺町通荒神口上る', null, null);
INSERT INTO `ms_addresses` VALUES ('66445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区中御霊町', '26', '26102', '6020857', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '中御霊町', 'ナカゴリョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区東桜町', '26', '26102', '6020858', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '東桜町', 'ヒガシサクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区新烏丸頭町', '26', '26102', '6020861', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '新烏丸頭町', 'シンカラスマカシラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区出水町', '26', '26102', '6020862', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '出水町', 'デミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区上之町', '26', '26102', '6020863', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '上之町', 'カミノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区中之町東三本木通丸太町上る', '26', '26102', '6020864', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '中之町', 'ナカノチョウ', null, '東三本木通丸太町上る', null, null);
INSERT INTO `ms_addresses` VALUES ('66451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区南町', '26', '26102', '6020865', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '南町', 'ミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区真町', '26', '26102', '6020866', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '真町', 'シンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区松蔭町', '26', '26102', '6020867', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '松蔭町', 'マツカゲチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区袋町', '26', '26102', '6020868', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '袋町', 'フクロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区俵屋町', '26', '26102', '6020871', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '俵屋町', 'タワラヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区駒之町', '26', '26102', '6020872', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '駒之町', 'コマノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区伊勢屋町', '26', '26102', '6020873', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '伊勢屋町', 'イセヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区東土御門町', '26', '26102', '6020874', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '東土御門町', 'ヒガシツチミカドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区信富町', '26', '26102', '6020875', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '信富町', 'シントミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区錦砂町', '26', '26102', '6020876', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '錦砂町', 'キンシャチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区桝屋町河原町通丸太町上る', '26', '26102', '6020877', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '桝屋町', 'マスヤチョウ', null, '河原町通丸太町上る', null, null);
INSERT INTO `ms_addresses` VALUES ('66462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区高島町', '26', '26102', '6020878', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '高島町', 'タカシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区京都御苑', '26', '26102', '6020881', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '京都御苑', 'キョウトギョエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区上御霊馬場町', '26', '26102', '6020891', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '上御霊馬場町', 'カミゴリョウババチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区新北小路町', '26', '26102', '6020892', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '新北小路町', 'シンキタコウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区玄武町', '26', '26102', '6020893', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '玄武町', 'ゲンブチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区上御霊中町', '26', '26102', '6020894', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '上御霊中町', 'カミゴリョウナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区上御霊前町', '26', '26102', '6020895', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '上御霊前町', 'カミゴリョウマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区上御霊竪町', '26', '26102', '6020896', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '上御霊竪町', 'カミゴリョウタテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区新御霊口町', '26', '26102', '6020897', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '新御霊口町', 'シンゴリョウグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区相国寺門前町', '26', '26102', '6020898', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '相国寺門前町', 'ソウコクジモンゼンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区北小路室町', '26', '26102', '6020901', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '北小路室町', 'キタコウジムロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区梅屋町', '26', '26102', '6020902', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '梅屋町', 'ウメヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区観三橘町', '26', '26102', '6020903', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '観三橘町', 'カンサンタチバナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区小島町', '26', '26102', '6020904', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '小島町', 'コジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区一松町', '26', '26102', '6020905', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '一松町', 'イチマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区今図子町', '26', '26102', '6020906', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '今図子町', 'イマズシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区福長町', '26', '26102', '6020907', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '福長町', 'フクナガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区広橋殿町', '26', '26102', '6020911', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '広橋殿町', 'ヒロハシドノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区龍前町', '26', '26102', '6020912', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '龍前町', 'タツマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区東町中立売通烏丸西入', '26', '26102', '6020913', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '東町', 'ヒガシマチ', null, '中立売通烏丸西入', null, null);
INSERT INTO `ms_addresses` VALUES ('66482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区東町中立売通室町東入', '26', '26102', '6020913', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '東町', 'ヒガシマチ', null, '中立売通室町東入', null, null);
INSERT INTO `ms_addresses` VALUES ('66483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区花立町', '26', '26102', '6020914', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '花立町', 'ハナタテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区三丁町', '26', '26102', '6020915', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '三丁町', 'サンテイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区西日野殿町', '26', '26102', '6020916', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '西日野殿町', 'ニシヒノドノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区東日野殿町', '26', '26102', '6020917', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '東日野殿町', 'ヒガシヒノドノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区薬屋町', '26', '26102', '6020918', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '薬屋町', 'クスリヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区正親町', '26', '26102', '6020921', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '正親町', 'オウギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区讃州寺町', '26', '26102', '6020922', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '讃州寺町', 'サンシュウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区油橋詰町', '26', '26102', '6020923', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '油橋詰町', 'アブラハシヅメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区小川町', '26', '26102', '6020924', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '小川町', 'オガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区西之口町', '26', '26102', '6020925', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '西之口町', 'ニシノクチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区元真如堂町', '26', '26102', '6020926', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '元真如堂町', 'モトシンニョドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区堀出シ町', '26', '26102', '6020931', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '堀出シ町', 'ホリダシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区徳大寺殿町', '26', '26102', '6020932', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '徳大寺殿町', 'トクダイジデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区武者小路町', '26', '26102', '6020933', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '武者小路町', 'ムシャコウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区一条殿町', '26', '26102', '6020934', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '一条殿町', 'イチジョウデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区大峰図子町', '26', '26102', '6020935', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '大峰図子町', 'オオミネズシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区西無車小路町', '26', '26102', '6020936', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '西無車小路町', 'ニシムシャコウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区常盤井図子町', '26', '26102', '6020937', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '常盤井図子町', 'トキワイズシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区元図子町', '26', '26102', '6020938', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '元図子町', 'モトズシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区弁財天町', '26', '26102', '6020939', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '弁財天町', 'ベンザイテンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区南兼康町', '26', '26102', '6020941', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '南兼康町', 'ミナミカネヤスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区靭屋町', '26', '26102', '6020942', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '靭屋町', 'ウツボヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区革堂町小川通一条上る', '26', '26102', '6020943', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '革堂町', 'コウドウチョウ', null, '小川通一条上る', null, null);
INSERT INTO `ms_addresses` VALUES ('66506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区革堂町小川通武者小路下る', '26', '26102', '6020943', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '革堂町', 'コウドウチョウ', null, '小川通武者小路下る', null, null);
INSERT INTO `ms_addresses` VALUES ('66507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区革堂町武者小路通小川東入', '26', '26102', '6020943', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '革堂町', 'コウドウチョウ', null, '武者小路通小川東入', null, null);
INSERT INTO `ms_addresses` VALUES ('66508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区一条横町', '26', '26102', '6020944', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '一条横町', 'イチジョウヨコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区革堂仲之町', '26', '26102', '6020945', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '革堂仲之町', 'コウドウナカノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区戒光寺町', '26', '26102', '6020946', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '戒光寺町', 'カイコウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区東町元誓願寺通小川西入', '26', '26102', '6020947', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '東町', 'ヒガシマチ', null, '元誓願寺通小川西入', null, null);
INSERT INTO `ms_addresses` VALUES ('66512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区針屋町', '26', '26102', '6020948', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '針屋町', 'ハリヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区東今町', '26', '26102', '6020951', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '東今町', 'ヒガシイマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区頭町油小路通元誓願寺下る', '26', '26102', '6020952', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '頭町', 'カシラチョウ', null, '油小路通元誓願寺下る', null, null);
INSERT INTO `ms_addresses` VALUES ('66515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区頭町元誓願寺通油小路西入', '26', '26102', '6020952', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '頭町', 'カシラチョウ', null, '元誓願寺通油小路西入', null, null);
INSERT INTO `ms_addresses` VALUES ('66516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区元百万遍町', '26', '26102', '6020953', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '元百万遍町', 'モトヒャクマンベンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区西川端町', '26', '26102', '6020954', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '西川端町', 'ニシカワバタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区竪富田町', '26', '26102', '6020955', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '竪富田町', 'タテトミダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区西町東堀川通元誓願寺下る', '26', '26102', '6020956', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '西町', 'ニシマチ', null, '東堀川通元誓願寺下る', null, null);
INSERT INTO `ms_addresses` VALUES ('66520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区西町元誓願寺通油小路西入', '26', '26102', '6020956', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '西町', 'ニシマチ', null, '元誓願寺通油小路西入', null, null);
INSERT INTO `ms_addresses` VALUES ('66521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区西町元誓願寺通東堀川東入', '26', '26102', '6020956', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '西町', 'ニシマチ', null, '元誓願寺通東堀川東入', null, null);
INSERT INTO `ms_addresses` VALUES ('66522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区西今町', '26', '26102', '6020957', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '西今町', 'ニシイマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区仲之町油小路通今出川下る', '26', '26102', '6020958', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '仲之町', 'ナカノチョウ', null, '油小路通今出川下る', null, null);
INSERT INTO `ms_addresses` VALUES ('66524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区仲之町油小路通元誓願寺上る', '26', '26102', '6020958', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '仲之町', 'ナカノチョウ', null, '油小路通元誓願寺上る', null, null);
INSERT INTO `ms_addresses` VALUES ('66525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区仲之町元誓願寺通油小路西入', '26', '26102', '6020958', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '仲之町', 'ナカノチョウ', null, '元誓願寺通油小路西入', null, null);
INSERT INTO `ms_addresses` VALUES ('66526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区仲之町元誓願寺通油小路東入', '26', '26102', '6020958', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '仲之町', 'ナカノチョウ', null, '元誓願寺通油小路東入', null, null);
INSERT INTO `ms_addresses` VALUES ('66527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区仲之町元誓願寺通堀川東入', '26', '26102', '6020958', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '仲之町', 'ナカノチョウ', null, '元誓願寺通堀川東入', null, null);
INSERT INTO `ms_addresses` VALUES ('66528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区革堂西町', '26', '26102', '6020959', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '革堂西町', 'コウドウニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区元浄花院町', '26', '26102', '6028001', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '元浄花院町', 'モトジョウカインチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区鷹司町下長者町通鳥丸西入', '26', '26102', '6028002', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '鷹司町', 'タカツカサチョウ', null, '下長者町通鳥丸西入', null, null);
INSERT INTO `ms_addresses` VALUES ('66531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区清和院町', '26', '26102', '6028003', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '清和院町', 'セイワインチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区西鷹司町', '26', '26102', '6028004', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '西鷹司町', 'ニシタカツカサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区元頂妙寺町', '26', '26102', '6028005', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '元頂妙寺町', 'モトチョウミョウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区元土御門町', '26', '26102', '6028006', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '元土御門町', 'モトツチミカドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区東長者町', '26', '26102', '6028007', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '東長者町', 'ヒガシチョウジャチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区桜鶴円町', '26', '26102', '6028011', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '桜鶴円町', 'オウカクエンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区中出水町', '26', '26102', '6028012', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '中出水町', 'ナカデミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区五町目町', '26', '26102', '6028013', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '五町目町', 'ゴチョウメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区勘解由小路町', '26', '26102', '6028014', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '勘解由小路町', 'カゲユコウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区常泉院町', '26', '26102', '6028015', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '常泉院町', 'ジョウセンインチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区両御霊町', '26', '26102', '6028016', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '両御霊町', 'リョウゴリョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区西出水町', '26', '26102', '6028017', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '西出水町', 'ニシデミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区御霊町', '26', '26102', '6028018', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '御霊町', 'ゴリョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区近衛町下長者町通室町西入', '26', '26102', '6028019', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '近衛町', 'コノエチョウ', null, '下長者町通室町西入', null, null);
INSERT INTO `ms_addresses` VALUES ('66545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区近衛町下長者町通室町東入', '26', '26102', '6028019', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '近衛町', 'コノエチョウ', null, '下長者町通室町東入', null, null);
INSERT INTO `ms_addresses` VALUES ('66546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区近衛町出水通烏丸西入', '26', '26102', '6028019', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '近衛町', 'コノエチョウ', null, '出水通烏丸西入', null, null);
INSERT INTO `ms_addresses` VALUES ('66547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区近衛町出水通室町東入', '26', '26102', '6028019', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '近衛町', 'コノエチョウ', null, '出水通室町東入', null, null);
INSERT INTO `ms_addresses` VALUES ('66548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区近衛町室町通下長者町下る', '26', '26102', '6028019', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '近衛町', 'コノエチョウ', null, '室町通下長者町下る', null, null);
INSERT INTO `ms_addresses` VALUES ('66549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区近衛町室町通出水上る', '26', '26102', '6028019', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '近衛町', 'コノエチョウ', null, '室町通出水上る', null, null);
INSERT INTO `ms_addresses` VALUES ('66550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区近衛町室町通出水上る東入', '26', '26102', '6028019', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '近衛町', 'コノエチョウ', null, '室町通出水上る東入', null, null);
INSERT INTO `ms_addresses` VALUES ('66551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区堀松町', '26', '26102', '6028021', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '堀松町', 'ホリマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区養安町', '26', '26102', '6028022', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '養安町', 'ヨウアンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区春日町', '26', '26102', '6028023', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '春日町', 'カスガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区大門町', '26', '26102', '6028024', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '大門町', 'ダイモンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区今薬屋町', '26', '26102', '6028025', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '今薬屋町', 'イマクスリヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区春帯町', '26', '26102', '6028026', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '春帯町', 'ハルオビチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区東立売町', '26', '26102', '6028027', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '東立売町', 'ヒガシタチウリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区門跡町', '26', '26102', '6028028', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '門跡町', 'モンゼキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区武衛陣町', '26', '26102', '6028029', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '武衛陣町', 'ブエイジンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区東裏辻町', '26', '26102', '6028031', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '東裏辻町', 'ヒガシウラツジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区夷川町', '26', '26102', '6028032', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '夷川町', 'エビスガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区上鍛冶町', '26', '26102', '6028033', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '上鍛冶町', 'カミカジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区米屋町油小路椹木町下る', '26', '26102', '6028034', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '米屋町', 'コメヤチョウ', null, '油小路椹木町下る', null, null);
INSERT INTO `ms_addresses` VALUES ('66564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区米屋町油小路通丸太町上る', '26', '26102', '6028034', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '米屋町', 'コメヤチョウ', null, '油小路通丸太町上る', null, null);
INSERT INTO `ms_addresses` VALUES ('66565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区米屋町椹木町通油小路西入', '26', '26102', '6028034', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '米屋町', 'コメヤチョウ', null, '椹木町通油小路西入', null, null);
INSERT INTO `ms_addresses` VALUES ('66566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区米屋町椹木町通油小路東入', '26', '26102', '6028034', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '米屋町', 'コメヤチョウ', null, '椹木町通油小路東入', null, null);
INSERT INTO `ms_addresses` VALUES ('66567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区米屋町丸太町通油小路西入', '26', '26102', '6028034', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '米屋町', 'コメヤチョウ', null, '丸太町通油小路西入', null, null);
INSERT INTO `ms_addresses` VALUES ('66568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区米屋町丸太町通油小路東入', '26', '26102', '6028034', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '米屋町', 'コメヤチョウ', null, '丸太町通油小路東入', null, null);
INSERT INTO `ms_addresses` VALUES ('66569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区六町目', '26', '26102', '6028035', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '六町目', 'ロクチョウメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区西山崎町', '26', '26102', '6028036', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '西山崎町', 'ニシヤマザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区八幡町', '26', '26102', '6028037', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '八幡町', 'ハチマンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区東魚屋町', '26', '26102', '6028038', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '東魚屋町', 'ヒガシウオヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区藪之内町', '26', '26102', '6028041', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '藪之内町', 'ヤブノウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区西裏辻町', '26', '26102', '6028042', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '西裏辻町', 'ニシウラツジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区五町目', '26', '26102', '6028043', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '五町目', 'ゴチョウメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区東橋詰町下立売通堀川東入', '26', '26102', '6028044', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '東橋詰町', 'ヒガシハシヅメチョウ', null, '下立売通堀川東入', null, null);
INSERT INTO `ms_addresses` VALUES ('66577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区四町目出水通油小路西入', '26', '26102', '6028045', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '四町目', 'ヨンチョウメ', null, '出水通油小路西入', null, null);
INSERT INTO `ms_addresses` VALUES ('66578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区四町目出水通堀川東入', '26', '26102', '6028045', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '四町目', 'ヨンチョウメ', null, '出水通堀川東入', null, null);
INSERT INTO `ms_addresses` VALUES ('66579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区四町目出水通堀川東入下る', '26', '26102', '6028045', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '四町目', 'ヨンチョウメ', null, '出水通堀川東入下る', null, null);
INSERT INTO `ms_addresses` VALUES ('66580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区四町目出水通東堀川東入', '26', '26102', '6028045', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '四町目', 'ヨンチョウメ', null, '出水通東堀川東入', null, null);
INSERT INTO `ms_addresses` VALUES ('66581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区四町目下立売通堀川東入', '26', '26102', '6028045', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '四町目', 'ヨンチョウメ', null, '下立売通堀川東入', null, null);
INSERT INTO `ms_addresses` VALUES ('66582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区四町目下立売通堀川東入上る', '26', '26102', '6028045', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '四町目', 'ヨンチョウメ', null, '下立売通堀川東入上る', null, null);
INSERT INTO `ms_addresses` VALUES ('66583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区四町目下立売通堀川東入下る', '26', '26102', '6028045', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '四町目', 'ヨンチョウメ', null, '下立売通堀川東入下る', null, null);
INSERT INTO `ms_addresses` VALUES ('66584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区四町目東堀川通下立売上る', '26', '26102', '6028045', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '四町目', 'ヨンチョウメ', null, '東堀川通下立売上る', null, null);
INSERT INTO `ms_addresses` VALUES ('66585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区四町目東堀川通出水下る', '26', '26102', '6028045', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '四町目', 'ヨンチョウメ', null, '東堀川通出水下る', null, null);
INSERT INTO `ms_addresses` VALUES ('66586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区近衛町油小路通下立売上る', '26', '26102', '6028046', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '近衛町', 'コノエチョウ', null, '油小路通下立売上る', null, null);
INSERT INTO `ms_addresses` VALUES ('66587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区近衛町油小路通出水下る', '26', '26102', '6028046', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '近衛町', 'コノエチョウ', null, '油小路通出水下る', null, null);
INSERT INTO `ms_addresses` VALUES ('66588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区近衛町出水通油小路西入', '26', '26102', '6028046', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '近衛町', 'コノエチョウ', null, '出水通油小路西入', null, null);
INSERT INTO `ms_addresses` VALUES ('66589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区近衛町出水通油小路東入', '26', '26102', '6028046', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '近衛町', 'コノエチョウ', null, '出水通油小路東入', null, null);
INSERT INTO `ms_addresses` VALUES ('66590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区勘兵衛町', '26', '26102', '6028047', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '勘兵衛町', 'カンベエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区西大路町油小路通下立売上る', '26', '26102', '6028048', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '西大路町', 'ニシオオジチョウ', null, '油小路通下立売上る', null, null);
INSERT INTO `ms_addresses` VALUES ('66592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区西大路町小川通下立売上る', '26', '26102', '6028048', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '西大路町', 'ニシオオジチョウ', null, '小川通下立売上る', null, null);
INSERT INTO `ms_addresses` VALUES ('66593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区西大路町小川通下立売下る', '26', '26102', '6028048', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '西大路町', 'ニシオオジチョウ', null, '小川通下立売下る', null, null);
INSERT INTO `ms_addresses` VALUES ('66594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区西大路町下立売通油小路東入', '26', '26102', '6028048', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '西大路町', 'ニシオオジチョウ', null, '下立売通油小路東入', null, null);
INSERT INTO `ms_addresses` VALUES ('66595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区西大路町下立売通小川西入', '26', '26102', '6028048', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '西大路町', 'ニシオオジチョウ', null, '下立売通小川西入', null, null);
INSERT INTO `ms_addresses` VALUES ('66596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区西大路町下立売通小川東入', '26', '26102', '6028048', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '西大路町', 'ニシオオジチョウ', null, '下立売通小川東入', null, null);
INSERT INTO `ms_addresses` VALUES ('66597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区中橋詰町', '26', '26102', '6028051', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '中橋詰町', 'ナカハシヅメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区鷹司町下長者町通小川東入', '26', '26102', '6028052', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '鷹司町', 'タカツカサチョウ', null, '下長者町通小川東入', null, null);
INSERT INTO `ms_addresses` VALUES ('66599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区茶屋町', '26', '26102', '6028053', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '茶屋町', 'チャヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区丁子風呂町', '26', '26102', '6028054', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '丁子風呂町', 'チョウジブロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区大黒屋町', '26', '26102', '6028055', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '大黒屋町', 'ダイコクヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区三町目出水通東堀川東入', '26', '26102', '6028056', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '三町目', 'サンチョウメ', null, '出水通東堀川東入', null, null);
INSERT INTO `ms_addresses` VALUES ('66603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区三町目出水通堀川東入', '26', '26102', '6028056', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '三町目', 'サンチョウメ', null, '出水通堀川東入', null, null);
INSERT INTO `ms_addresses` VALUES ('66604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区三町目東堀川通下長者町下る', '26', '26102', '6028056', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '三町目', 'サンチョウメ', null, '東堀川通下長者町下る', null, null);
INSERT INTO `ms_addresses` VALUES ('66605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区三町目東堀川通出水上る', '26', '26102', '6028056', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '三町目', 'サンチョウメ', null, '東堀川通出水上る', null, null);
INSERT INTO `ms_addresses` VALUES ('66606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区紹巴町', '26', '26102', '6028057', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '紹巴町', 'ショウハチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区二町目上長者町通東堀川東入', '26', '26102', '6028058', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '二町目', 'ニチョウメ', null, '上長者町通東堀川東入', null, null);
INSERT INTO `ms_addresses` VALUES ('66608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区二町目東堀川通上長者町下る', '26', '26102', '6028058', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '二町目', 'ニチョウメ', null, '東堀川通上長者町下る', null, null);
INSERT INTO `ms_addresses` VALUES ('66609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区二町目東堀川通下長者町上る', '26', '26102', '6028058', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '二町目', 'ニチョウメ', null, '東堀川通下長者町上る', null, null);
INSERT INTO `ms_addresses` VALUES ('66610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区二町目東堀川通上長者町上る', '26', '26102', '6028058', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '二町目', 'ニチョウメ', null, '東堀川通上長者町上る', null, null);
INSERT INTO `ms_addresses` VALUES ('66611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区甲斐守町', '26', '26102', '6028061', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '甲斐守町', 'カイノカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区亀屋町油小路通上長者町下る', '26', '26102', '6028062', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '亀屋町', 'カメヤチョウ', null, '油小路通上長者町下る', null, null);
INSERT INTO `ms_addresses` VALUES ('66613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区亀屋町油小路通下長者町上る', '26', '26102', '6028062', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '亀屋町', 'カメヤチョウ', null, '油小路通下長者町上る', null, null);
INSERT INTO `ms_addresses` VALUES ('66614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区亀屋町油小路通中長者町上る', '26', '26102', '6028062', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '亀屋町', 'カメヤチョウ', null, '油小路通中長者町上る', null, null);
INSERT INTO `ms_addresses` VALUES ('66615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区亀屋町油小路通中長者町下る', '26', '26102', '6028062', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '亀屋町', 'カメヤチョウ', null, '油小路通中長者町下る', null, null);
INSERT INTO `ms_addresses` VALUES ('66616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区亀屋町上長者町通油小路西入', '26', '26102', '6028062', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '亀屋町', 'カメヤチョウ', null, '上長者町通油小路西入', null, null);
INSERT INTO `ms_addresses` VALUES ('66617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区亀屋町上長者町通油小路東入', '26', '26102', '6028062', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '亀屋町', 'カメヤチョウ', null, '上長者町通油小路東入', null, null);
INSERT INTO `ms_addresses` VALUES ('66618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区橋本町', '26', '26102', '6028063', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '橋本町', 'ハシモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区一町目上長者町通堀川東入', '26', '26102', '6028064', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '一町目', 'イッチョウメ', null, '上長者町通堀川東入', null, null);
INSERT INTO `ms_addresses` VALUES ('66620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区一町目東堀川通上長者町上る', '26', '26102', '6028064', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '一町目', 'イッチョウメ', null, '東堀川通上長者町上る', null, null);
INSERT INTO `ms_addresses` VALUES ('66621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区一町目東堀川通中立売通下る', '26', '26102', '6028064', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '一町目', 'イッチョウメ', null, '東堀川通中立売通下る', null, null);
INSERT INTO `ms_addresses` VALUES ('66622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区突抜町上長者町通堀川東入上る', '26', '26102', '6028065', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '突抜町', 'ツキヌケチョウ', null, '上長者町通堀川東入上る', null, null);
INSERT INTO `ms_addresses` VALUES ('66623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区突抜町中立売通堀川東入下る', '26', '26102', '6028065', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '突抜町', 'ツキヌケチョウ', null, '中立売通堀川東入下る', null, null);
INSERT INTO `ms_addresses` VALUES ('66624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区突抜町油小路堀川の間中立売下る', '26', '26102', '6028065', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '突抜町', 'ツキヌケチョウ', null, '油小路堀川の間中立売下る', null, null);
INSERT INTO `ms_addresses` VALUES ('66625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区東橋詰町中立売通堀川東入', '26', '26102', '6028066', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '東橋詰町', 'ヒガシハシヅメチョウ', null, '中立売通堀川東入', null, null);
INSERT INTO `ms_addresses` VALUES ('66626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区主計町', '26', '26102', '6028067', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '主計町', 'シュケイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区松之下町', '26', '26102', '6028068', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '松之下町', 'マツノシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区仕丁町', '26', '26102', '6028071', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '仕丁町', 'シテイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区仲之町新町通下長者町上る', '26', '26102', '6028072', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '仲之町', 'ナカノチョウ', null, '新町通下長者町上る', null, null);
INSERT INTO `ms_addresses` VALUES ('66630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区仲之町新町通中長者町下る', '26', '26102', '6028072', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '仲之町', 'ナカノチョウ', null, '新町通中長者町下る', null, null);
INSERT INTO `ms_addresses` VALUES ('66631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区仲之町中長者町通新町西入', '26', '26102', '6028072', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '仲之町', 'ナカノチョウ', null, '中長者町通新町西入', null, null);
INSERT INTO `ms_addresses` VALUES ('66632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区仲之町中長者町通西洞院東入', '26', '26102', '6028072', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '仲之町', 'ナカノチョウ', null, '中長者町通西洞院東入', null, null);
INSERT INTO `ms_addresses` VALUES ('66633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区仲之町中長者町通西洞院西入', '26', '26102', '6028072', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '仲之町', 'ナカノチョウ', null, '中長者町通西洞院西入', null, null);
INSERT INTO `ms_addresses` VALUES ('66634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区仲之町西洞院通中長者町上る', '26', '26102', '6028072', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '仲之町', 'ナカノチョウ', null, '西洞院通中長者町上る', null, null);
INSERT INTO `ms_addresses` VALUES ('66635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区仲之町西洞院通上長者町下る', '26', '26102', '6028072', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '仲之町', 'ナカノチョウ', null, '西洞院通上長者町下る', null, null);
INSERT INTO `ms_addresses` VALUES ('66636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区頭町上長者町通西洞院西入', '26', '26102', '6028073', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '頭町', 'カシラチョウ', null, '上長者町通西洞院西入', null, null);
INSERT INTO `ms_addresses` VALUES ('66637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区頭町西洞院通上長者町下る', '26', '26102', '6028073', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '頭町', 'カシラチョウ', null, '西洞院通上長者町下る', null, null);
INSERT INTO `ms_addresses` VALUES ('66638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区頭町西洞院通下長者町上る', '26', '26102', '6028073', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '頭町', 'カシラチョウ', null, '西洞院通下長者町上る', null, null);
INSERT INTO `ms_addresses` VALUES ('66639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区頭町西洞院通中長者町上る', '26', '26102', '6028073', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '頭町', 'カシラチョウ', null, '西洞院通中長者町上る', null, null);
INSERT INTO `ms_addresses` VALUES ('66640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区頭町西洞院通中長者町下る', '26', '26102', '6028073', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '頭町', 'カシラチョウ', null, '西洞院通中長者町下る', null, null);
INSERT INTO `ms_addresses` VALUES ('66641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区有春町', '26', '26102', '6028074', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '有春町', 'アリハルチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区下小川町', '26', '26102', '6028075', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '下小川町', 'シモオガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区菊屋町西洞院通上長者町上る', '26', '26102', '6028076', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '菊屋町', 'キクヤチョウ', null, '西洞院通上長者町上る', null, null);
INSERT INTO `ms_addresses` VALUES ('66644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区菊屋町西洞院通中立売下る', '26', '26102', '6028076', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '菊屋町', 'キクヤチョウ', null, '西洞院通中立売下る', null, null);
INSERT INTO `ms_addresses` VALUES ('66645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区菊屋町上長者町通西洞院西入', '26', '26102', '6028076', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '菊屋町', 'キクヤチョウ', null, '上長者町通西洞院西入', null, null);
INSERT INTO `ms_addresses` VALUES ('66646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区菊屋町上長者町通西洞院東入', '26', '26102', '6028076', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '菊屋町', 'キクヤチョウ', null, '上長者町通西洞院東入', null, null);
INSERT INTO `ms_addresses` VALUES ('66647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区土御門町', '26', '26102', '6028077', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '土御門町', 'ツチミカドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区東辰巳町', '26', '26102', '6028101', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '東辰巳町', 'ヒガシタツミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区東天秤町', '26', '26102', '6028102', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '東天秤町', 'ヒガシテンビンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区一町目松屋町通出水下る', '26', '26102', '6028103', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '一町目', 'イッチョウメ', null, '松屋町通出水下る', null, null);
INSERT INTO `ms_addresses` VALUES ('66651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区一町目松屋町通下立売上る', '26', '26102', '6028103', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '一町目', 'イッチョウメ', null, '松屋町通下立売上る', null, null);
INSERT INTO `ms_addresses` VALUES ('66652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区浮田町', '26', '26102', '6028104', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '浮田町', 'ウキタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区天秤町', '26', '26102', '6028105', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '天秤町', 'テンビンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区秤口町', '26', '26102', '6028106', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '秤口町', 'ハカリグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区西辰巳町', '26', '26102', '6028107', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '西辰巳町', 'ニシタツミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区南清水町', '26', '26102', '6028108', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '南清水町', 'ミナミシミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区西天秤町', '26', '26102', '6028109', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '西天秤町', 'ニシテンビンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区桝屋町西堀川通下長者町下る', '26', '26102', '6028111', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '桝屋町', 'マスヤチョウ', null, '西堀川通下長者町下る', null, null);
INSERT INTO `ms_addresses` VALUES ('66659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区桝屋町西堀川通出水上る', '26', '26102', '6028111', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '桝屋町', 'マスヤチョウ', null, '西堀川通出水上る', null, null);
INSERT INTO `ms_addresses` VALUES ('66660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区四町目西堀川通下立売上る', '26', '26102', '6028112', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '四町目', 'ヨンチョウメ', null, '西堀川通下立売上る', null, null);
INSERT INTO `ms_addresses` VALUES ('66661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区四町目西堀川通出水下る', '26', '26102', '6028112', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '四町目', 'ヨンチョウメ', null, '西堀川通出水下る', null, null);
INSERT INTO `ms_addresses` VALUES ('66662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区元福大明神町', '26', '26102', '6028113', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '元福大明神町', 'モトフクダイミョウジンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区荒神町猪熊通下立売上る', '26', '26102', '6028114', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '荒神町', 'コウジンチョウ', null, '猪熊通下立売上る', null, null);
INSERT INTO `ms_addresses` VALUES ('66664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区荒神町猪熊通出水下る', '26', '26102', '6028114', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '荒神町', 'コウジンチョウ', null, '猪熊通出水下る', null, null);
INSERT INTO `ms_addresses` VALUES ('66665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区荒神町猪熊通椹木町上る', '26', '26102', '6028114', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '荒神町', 'コウジンチョウ', null, '猪熊通椹木町上る', null, null);
INSERT INTO `ms_addresses` VALUES ('66666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区荒神町出水通猪熊西入', '26', '26102', '6028114', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '荒神町', 'コウジンチョウ', null, '出水通猪熊西入', null, null);
INSERT INTO `ms_addresses` VALUES ('66667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区荒神町出水通猪熊東入', '26', '26102', '6028114', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '荒神町', 'コウジンチョウ', null, '出水通猪熊東入', null, null);
INSERT INTO `ms_addresses` VALUES ('66668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区荒神町出水通葭屋町西入', '26', '26102', '6028114', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '荒神町', 'コウジンチョウ', null, '出水通葭屋町西入', null, null);
INSERT INTO `ms_addresses` VALUES ('66669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区北蟹屋町', '26', '26102', '6028115', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '北蟹屋町', 'キタカニヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区清元町', '26', '26102', '6028116', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '清元町', 'キヨモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区吉野町', '26', '26102', '6028117', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '吉野町', 'ヨシノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区蛭子町猪熊通出水上る', '26', '26102', '6028118', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '蛭子町', 'エビスチョウ', null, '猪熊通出水上る', null, null);
INSERT INTO `ms_addresses` VALUES ('66673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区蛭子町猪熊通下長者町下る', '26', '26102', '6028118', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '蛭子町', 'エビスチョウ', null, '猪熊通下長者町下る', null, null);
INSERT INTO `ms_addresses` VALUES ('66674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区蛭子町下長者町通猪熊西入', '26', '26102', '6028118', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '蛭子町', 'エビスチョウ', null, '下長者町通猪熊西入', null, null);
INSERT INTO `ms_addresses` VALUES ('66675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区蛭子町下長者町通猪熊東入', '26', '26102', '6028118', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '蛭子町', 'エビスチョウ', null, '下長者町通猪熊東入', null, null);
INSERT INTO `ms_addresses` VALUES ('66676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区蛭子町出水通猪熊西入', '26', '26102', '6028118', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '蛭子町', 'エビスチョウ', null, '出水通猪熊西入', null, null);
INSERT INTO `ms_addresses` VALUES ('66677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区蛭子町出水通猪熊東入', '26', '26102', '6028118', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '蛭子町', 'エビスチョウ', null, '出水通猪熊東入', null, null);
INSERT INTO `ms_addresses` VALUES ('66678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区亀屋町葭屋町通下長者町下る', '26', '26102', '6028119', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '亀屋町', 'カメヤチョウ', null, '葭屋町通下長者町下る', null, null);
INSERT INTO `ms_addresses` VALUES ('66679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区亀屋町葭屋町通出水上る', '26', '26102', '6028119', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '亀屋町', 'カメヤチョウ', null, '葭屋町通出水上る', null, null);
INSERT INTO `ms_addresses` VALUES ('66680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区亀屋町下長者町通堀川西入', '26', '26102', '6028119', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '亀屋町', 'カメヤチョウ', null, '下長者町通堀川西入', null, null);
INSERT INTO `ms_addresses` VALUES ('66681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区亀屋町下長者町通葭屋町東入', '26', '26102', '6028119', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '亀屋町', 'カメヤチョウ', null, '下長者町通葭屋町東入', null, null);
INSERT INTO `ms_addresses` VALUES ('66682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区亀屋町下長者町通葭屋町西入', '26', '26102', '6028119', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '亀屋町', 'カメヤチョウ', null, '下長者町通葭屋町西入', null, null);
INSERT INTO `ms_addresses` VALUES ('66683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区亀屋町出水通葭屋町西入', '26', '26102', '6028119', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '亀屋町', 'カメヤチョウ', null, '出水通葭屋町西入', null, null);
INSERT INTO `ms_addresses` VALUES ('66684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区亀屋町出水通葭屋町東入', '26', '26102', '6028119', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '亀屋町', 'カメヤチョウ', null, '出水通葭屋町東入', null, null);
INSERT INTO `ms_addresses` VALUES ('66685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区亀屋町出水通堀川西入', '26', '26102', '6028119', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '亀屋町', 'カメヤチョウ', null, '出水通堀川西入', null, null);
INSERT INTO `ms_addresses` VALUES ('66686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区家永町', '26', '26102', '6028121', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '家永町', 'イエナガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区南蟹屋町', '26', '26102', '6028122', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '南蟹屋町', 'ミナミカニヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区橋西二町目', '26', '26102', '6028123', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '橋西二町目', 'ハシニシ02チョウメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区森中町', '26', '26102', '6028124', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '森中町', 'モリナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区菱屋町大宮通椹木町上る', '26', '26102', '6028125', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '菱屋町', 'ヒシヤチョウ', null, '大宮通椹木町上る', null, null);
INSERT INTO `ms_addresses` VALUES ('66691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区菱屋町大宮通下立売下る', '26', '26102', '6028125', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '菱屋町', 'ヒシヤチョウ', null, '大宮通下立売下る', null, null);
INSERT INTO `ms_addresses` VALUES ('66692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区菱屋町椹木町通大宮西入', '26', '26102', '6028125', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '菱屋町', 'ヒシヤチョウ', null, '椹木町通大宮西入', null, null);
INSERT INTO `ms_addresses` VALUES ('66693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区菱屋町椹木町通大宮東入', '26', '26102', '6028125', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '菱屋町', 'ヒシヤチョウ', null, '椹木町通大宮東入', null, null);
INSERT INTO `ms_addresses` VALUES ('66694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区中書町', '26', '26102', '6028126', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '中書町', 'チュウショチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区櫛笥町', '26', '26102', '6028127', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '櫛笥町', 'クシゲチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区二町目松屋町通椹木町上る', '26', '26102', '6028128', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '二町目', 'ニチョウメ', null, '松屋町通椹木町上る', null, null);
INSERT INTO `ms_addresses` VALUES ('66697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区二町目松屋町通下立売下る', '26', '26102', '6028128', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '二町目', 'ニチョウメ', null, '松屋町通下立売下る', null, null);
INSERT INTO `ms_addresses` VALUES ('66698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区長尾町', '26', '26102', '6028131', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '長尾町', 'ナガオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区講堂町', '26', '26102', '6028132', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '講堂町', 'コウドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区小伝馬町', '26', '26102', '6028133', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '小伝馬町', 'コデンマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区一町目大宮通椹木町下る', '26', '26102', '6028134', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '一町目', 'イッチョウメ', null, '大宮通椹木町下る', null, null);
INSERT INTO `ms_addresses` VALUES ('66702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区一町目大宮通丸太町上る', '26', '26102', '6028134', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '一町目', 'イッチョウメ', null, '大宮通丸太町上る', null, null);
INSERT INTO `ms_addresses` VALUES ('66703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区一町目椹木町通大宮西入', '26', '26102', '6028134', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '一町目', 'イッチョウメ', null, '椹木町通大宮西入', null, null);
INSERT INTO `ms_addresses` VALUES ('66704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区一町目丸太町通大宮東入', '26', '26102', '6028134', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '一町目', 'イッチョウメ', null, '丸太町通大宮東入', null, null);
INSERT INTO `ms_addresses` VALUES ('66705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区三町目松屋町通椹木町下る', '26', '26102', '6028135', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '三町目', 'サンチョウメ', null, '松屋町通椹木町下る', null, null);
INSERT INTO `ms_addresses` VALUES ('66706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区三町目松屋町通丸太町上る', '26', '26102', '6028135', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '三町目', 'サンチョウメ', null, '松屋町通丸太町上る', null, null);
INSERT INTO `ms_addresses` VALUES ('66707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区中御門横町', '26', '26102', '6028136', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '中御門横町', 'ナカミカドヨコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区大黒町猪熊通椹木町上る', '26', '26102', '6028137', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '大黒町', 'ダイコクチョウ', null, '猪熊通椹木町上る', null, null);
INSERT INTO `ms_addresses` VALUES ('66709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区大黒町猪熊通下立売下る', '26', '26102', '6028137', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '大黒町', 'ダイコクチョウ', null, '猪熊通下立売下る', null, null);
INSERT INTO `ms_addresses` VALUES ('66710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区大黒町椹木町通猪熊西入', '26', '26102', '6028137', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '大黒町', 'ダイコクチョウ', null, '椹木町通猪熊西入', null, null);
INSERT INTO `ms_addresses` VALUES ('66711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区西橋詰町', '26', '26102', '6028138', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '西橋詰町', 'ニシハシヅメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区丸屋町', '26', '26102', '6028139', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '丸屋町', 'マルヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区上堀川町', '26', '26102', '6028141', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '上堀川町', 'カミホリカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区下堀川町', '26', '26102', '6028142', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '下堀川町', 'シモホリカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区中之町猪熊通竹屋町上る', '26', '26102', '6028143', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '中之町', 'ナカノチョウ', null, '猪熊通竹屋町上る', null, null);
INSERT INTO `ms_addresses` VALUES ('66716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区中之町猪熊通丸太町下る', '26', '26102', '6028143', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '中之町', 'ナカノチョウ', null, '猪熊通丸太町下る', null, null);
INSERT INTO `ms_addresses` VALUES ('66717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区中之町西堀川通丸太町下る', '26', '26102', '6028143', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '中之町', 'ナカノチョウ', null, '西堀川通丸太町下る', null, null);
INSERT INTO `ms_addresses` VALUES ('66718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区藁屋町', '26', '26102', '6028144', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '藁屋町', 'ワラヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区左馬松町', '26', '26102', '6028145', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '左馬松町', 'サママツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区木屋之町', '26', '26102', '6028146', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '木屋之町', 'キヤノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区直家町', '26', '26102', '6028147', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '直家町', 'ナオイエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区西丸太町', '26', '26102', '6028148', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '西丸太町', 'ニシマルタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区西院町', '26', '26102', '6028151', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '西院町', 'サイインチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区北伊勢屋町', '26', '26102', '6028152', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '北伊勢屋町', 'キタイセヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区南伊勢屋町', '26', '26102', '6028153', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '南伊勢屋町', 'ミナミイセヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区四町目竹屋町通日暮西入', '26', '26102', '6028154', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '四町目', 'ヨンチョウメ', null, '竹屋町通日暮西入', null, null);
INSERT INTO `ms_addresses` VALUES ('66727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区四町目日暮通竹屋町上る', '26', '26102', '6028154', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '四町目', 'ヨンチョウメ', null, '日暮通竹屋町上る', null, null);
INSERT INTO `ms_addresses` VALUES ('66728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区四町目日暮通丸太町下る', '26', '26102', '6028154', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '四町目', 'ヨンチョウメ', null, '日暮通丸太町下る', null, null);
INSERT INTO `ms_addresses` VALUES ('66729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区四町目日暮通丸太町下る西入', '26', '26102', '6028154', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '四町目', 'ヨンチョウメ', null, '日暮通丸太町下る西入', null, null);
INSERT INTO `ms_addresses` VALUES ('66730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区主税町', '26', '26102', '6028155', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '主税町', 'シュゼイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区聚楽町', '26', '26102', '6028156', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '聚楽町', 'ジュラクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区小山町', '26', '26102', '6028157', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '小山町', 'コヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区中務町', '26', '26102', '6028158', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '中務町', 'ナカツカサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区新御幸町', '26', '26102', '6028161', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '新御幸町', 'シンゴコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区東神明町', '26', '26102', '6028162', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '東神明町', 'ヒガシシンメイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区田中町', '26', '26102', '6028163', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '田中町', 'タナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区十四軒町', '26', '26102', '6028164', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '十四軒町', 'ジュウヨンケンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区尼ケ崎横町', '26', '26102', '6028165', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '尼ケ崎横町', 'アマガサキヨコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区福島町', '26', '26102', '6028166', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '福島町', 'フクシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区二本松町', '26', '26102', '6028167', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '二本松町', 'ニホンマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区弁天町', '26', '26102', '6028168', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '弁天町', 'ベンテンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区西神明町', '26', '26102', '6028169', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '西神明町', 'ニシシンメイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区山本町', '26', '26102', '6028171', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '山本町', 'ヤマモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区天秤丸町', '26', '26102', '6028172', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '天秤丸町', 'テンビンマルチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区金馬場町', '26', '26102', '6028173', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '金馬場町', 'キンババチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区分銅町', '26', '26102', '6028174', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '分銅町', 'ブンドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区中村町', '26', '26102', '6028175', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '中村町', 'ナカムラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区下丸屋町', '26', '26102', '6028176', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '下丸屋町', 'シモマルヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区田村備前町', '26', '26102', '6028177', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '田村備前町', 'タムラビゼンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区白銀町', '26', '26102', '6028178', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '白銀町', 'シロガネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区坤高町', '26', '26102', '6028179', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '坤高町', 'コンタカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区桝屋町笹屋町通大宮西入', '26', '26102', '6028201', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '桝屋町', 'マスヤチョウ', null, '笹屋町通大宮西入', null, null);
INSERT INTO `ms_addresses` VALUES ('66753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区桝屋町笹屋町通智恵光院東入', '26', '26102', '6028201', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '桝屋町', 'マスヤチョウ', null, '笹屋町通智恵光院東入', null, null);
INSERT INTO `ms_addresses` VALUES ('66754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区栄町大宮通一条上る西入', '26', '26102', '6028202', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '栄町', 'サカエチョウ', null, '大宮通一条上る西入', null, null);
INSERT INTO `ms_addresses` VALUES ('66755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区栄町大宮通中立売下る', '26', '26102', '6028202', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '栄町', 'サカエチョウ', null, '大宮通中立売下る', null, null);
INSERT INTO `ms_addresses` VALUES ('66756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区栄町智恵光院通一条上る東入', '26', '26102', '6028202', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '栄町', 'サカエチョウ', null, '智恵光院通一条上る東入', null, null);
INSERT INTO `ms_addresses` VALUES ('66757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区鏡石町', '26', '26102', '6028203', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '鏡石町', 'カガミイシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区下鏡石町', '26', '26102', '6028204', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '下鏡石町', 'シモカガミイシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区新白水丸町', '26', '26102', '6028205', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '新白水丸町', 'シンハクスイマルチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区南新在家町', '26', '26102', '6028206', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '南新在家町', 'ミナミシンザイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区北新在家町', '26', '26102', '6028207', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '北新在家町', 'キタシンザイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区智恵光院前之町', '26', '26102', '6028208', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '智恵光院前之町', 'チエコウインマエノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区橘町', '26', '26102', '6028209', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '橘町', 'タチバナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区村雲町', '26', '26102', '6028211', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '村雲町', 'ムラクモチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区橋詰町', '26', '26102', '6028212', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '橋詰町', 'ハシヅメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区徳屋町', '26', '26102', '6028213', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '徳屋町', 'トクヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区北之御門町', '26', '26102', '6028214', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '北之御門町', 'キタノゴモンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区寺今町', '26', '26102', '6028215', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '寺今町', 'テライマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区竪門前町', '26', '26102', '6028216', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '竪門前町', 'タテモンゼンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区南門前町', '26', '26102', '6028217', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '南門前町', 'ミナミモンゼンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区富小路町', '26', '26102', '6028218', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '富小路町', 'トミコウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区堀川上之町', '26', '26102', '6028221', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '堀川上之町', 'ホリカワカミノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区晴明町', '26', '26102', '6028222', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '晴明町', 'セイメイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区横神明町', '26', '26102', '6028223', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '横神明町', 'ヨコシンメイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区弾正町', '26', '26102', '6028224', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '弾正町', 'ダンジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区下石橋町', '26', '26102', '6028225', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '下石橋町', 'シモイシバシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区石薬師町', '26', '26102', '6028226', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '石薬師町', 'イシヤクシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区毘沙門町大宮通一条上る東入', '26', '26102', '6028227', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '毘沙門町', 'ビシャモンチョウ', null, '大宮通一条上る東入', null, null);
INSERT INTO `ms_addresses` VALUES ('66779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区毘沙門町黒門通一条上る', '26', '26102', '6028227', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '毘沙門町', 'ビシャモンチョウ', null, '黒門通一条上る', null, null);
INSERT INTO `ms_addresses` VALUES ('66780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区毘沙門町黒門通元誓願寺下る', '26', '26102', '6028227', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '毘沙門町', 'ビシャモンチョウ', null, '黒門通元誓願寺下る', null, null);
INSERT INTO `ms_addresses` VALUES ('66781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区毘沙門町黒門通元誓願寺下る西入', '26', '26102', '6028227', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '毘沙門町', 'ビシャモンチョウ', null, '黒門通元誓願寺下る西入', null, null);
INSERT INTO `ms_addresses` VALUES ('66782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区毘沙門町黒門通一条上る西入', '26', '26102', '6028227', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '毘沙門町', 'ビシャモンチョウ', null, '黒門通一条上る西入', null, null);
INSERT INTO `ms_addresses` VALUES ('66783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区竪神明町', '26', '26102', '6028228', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '竪神明町', 'タテシンメイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区如水町', '26', '26102', '6028231', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '如水町', 'ニョスイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区堀川下之町', '26', '26102', '6028232', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '堀川下之町', 'ホリカワシモノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区福大明神町', '26', '26102', '6028233', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '福大明神町', 'フクダイミョウジンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区小寺町', '26', '26102', '6028234', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '小寺町', 'コデラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区飛弾殿町', '26', '26102', '6028235', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '飛弾殿町', 'ヒダドノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区庇町', '26', '26102', '6028236', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '庇町', 'ヒサシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区梨木町', '26', '26102', '6028237', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '梨木町', 'ナシノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区糸屋町', '26', '26102', '6028238', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '糸屋町', 'イトヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区下石橋南半町', '26', '26102', '6028239', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '下石橋南半町', 'シモイシバシミナミハンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区役人町', '26', '26102', '6028241', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '役人町', 'ヤクニンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区皀莢町', '26', '26102', '6028242', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '皀莢町', 'サイカチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区奈良物町', '26', '26102', '6028243', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '奈良物町', 'ナラモノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区菊屋町葭屋町通上長者町下る', '26', '26102', '6028244', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '菊屋町', 'キクヤチョウ', null, '葭屋町通上長者町下る', null, null);
INSERT INTO `ms_addresses` VALUES ('66797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区菊屋町葭屋町通下長者町上る', '26', '26102', '6028244', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '菊屋町', 'キクヤチョウ', null, '葭屋町通下長者町上る', null, null);
INSERT INTO `ms_addresses` VALUES ('66798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区菊屋町上長者町通葭屋町西入', '26', '26102', '6028244', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '菊屋町', 'キクヤチョウ', null, '上長者町通葭屋町西入', null, null);
INSERT INTO `ms_addresses` VALUES ('66799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区菊屋町上長者町通葭屋町東入', '26', '26102', '6028244', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '菊屋町', 'キクヤチョウ', null, '上長者町通葭屋町東入', null, null);
INSERT INTO `ms_addresses` VALUES ('66800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区菊屋町下長者町通葭屋町西入', '26', '26102', '6028244', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '菊屋町', 'キクヤチョウ', null, '下長者町通葭屋町西入', null, null);
INSERT INTO `ms_addresses` VALUES ('66801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区菊屋町下長者町通葭屋町東入', '26', '26102', '6028244', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '菊屋町', 'キクヤチョウ', null, '下長者町通葭屋町東入', null, null);
INSERT INTO `ms_addresses` VALUES ('66802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区菊屋町下長者町通堀川西入', '26', '26102', '6028244', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '菊屋町', 'キクヤチョウ', null, '下長者町通堀川西入', null, null);
INSERT INTO `ms_addresses` VALUES ('66803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区猪熊', '26', '26102', '6028245', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '猪熊', 'イノクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区杉本町', '26', '26102', '6028246', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '杉本町', 'スギモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区北俵町', '26', '26102', '6028247', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '北俵町', 'キタタワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区南俵町', '26', '26102', '6028248', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '南俵町', 'ミナミタワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区榎町', '26', '26102', '6028251', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '榎町', 'エノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区北小大門町', '26', '26102', '6028252', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '北小大門町', 'キタコダイモンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区南小大門町', '26', '26102', '6028253', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '南小大門町', 'ミナミコダイモンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区藤五郎町', '26', '26102', '6028254', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '藤五郎町', 'トウゴロウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区東堀町', '26', '26102', '6028255', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '東堀町', 'ヒガシホリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区神明町上長者町通松屋町東入', '26', '26102', '6028256', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '神明町', 'シンメイチョウ', null, '上長者町通松屋町東入', null, null);
INSERT INTO `ms_addresses` VALUES ('66813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区神明町松屋町通上長者町上る', '26', '26102', '6028256', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '神明町', 'シンメイチョウ', null, '松屋町通上長者町上る', null, null);
INSERT INTO `ms_addresses` VALUES ('66814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区神明町松屋町通中立売下る', '26', '26102', '6028256', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '神明町', 'シンメイチョウ', null, '松屋町通中立売下る', null, null);
INSERT INTO `ms_addresses` VALUES ('66815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区新元町', '26', '26102', '6028257', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '新元町', 'シンモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区和水町', '26', '26102', '6028258', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '和水町', 'ワスイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区常陸町', '26', '26102', '6028259', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '常陸町', 'ヒタチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区多門町', '26', '26102', '6028261', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '多門町', 'タモンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区須浜池町', '26', '26102', '6028262', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '須浜池町', 'スハマイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区須浜東町', '26', '26102', '6028263', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '須浜東町', 'スハマヒガシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区須浜町', '26', '26102', '6028264', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '須浜町', 'スハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区下山里町', '26', '26102', '6028265', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '下山里町', 'シモヤマザトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区菱丸町', '26', '26102', '6028266', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '菱丸町', 'ヒシマルチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区高台院竪町', '26', '26102', '6028267', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '高台院竪町', 'コウダイインタテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区山里町', '26', '26102', '6028268', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '山里町', 'ヤマザトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区高台院町', '26', '26102', '6028271', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '高台院町', 'コウダイインチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区亀木町', '26', '26102', '6028272', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '亀木町', 'カメキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区長谷町', '26', '26102', '6028273', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '長谷町', 'ハセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区山王町', '26', '26102', '6028274', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '山王町', 'サンノウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区革堂前之町', '26', '26102', '6028275', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '革堂前之町', 'コウドウマエノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区百万遍町', '26', '26102', '6028276', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '百万遍町', 'ヒャクマンベンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区信濃町', '26', '26102', '6028277', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '信濃町', 'シナノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区愛染寺町', '26', '26102', '6028278', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '愛染寺町', 'アイゼンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区新柳馬場頭町', '26', '26102', '6028279', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '新柳馬場頭町', 'シンヤナギノバンバカシラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区加賀屋町', '26', '26102', '6028281', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '加賀屋町', 'カガヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区西富仲町', '26', '26102', '6028282', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '西富仲町', 'ニシトミナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区仲御霊町', '26', '26102', '6028283', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '仲御霊町', 'ナカゴリョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区亀屋町千本通中立売上る', '26', '26102', '6028284', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '亀屋町', 'カメヤチョウ', null, '千本通中立売上る', null, null);
INSERT INTO `ms_addresses` VALUES ('66839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区亀屋町千本通中立売下る', '26', '26102', '6028284', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '亀屋町', 'カメヤチョウ', null, '千本通中立売下る', null, null);
INSERT INTO `ms_addresses` VALUES ('66840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区亀屋町中立売通千本西入', '26', '26102', '6028284', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '亀屋町', 'カメヤチョウ', null, '中立売通千本西入', null, null);
INSERT INTO `ms_addresses` VALUES ('66841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区西中筋町', '26', '26102', '6028285', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '西中筋町', 'ニシナカスジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区玉屋町千本通中立売上る', '26', '26102', '6028286', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '玉屋町', 'タマヤチョウ', null, '千本通中立売上る', null, null);
INSERT INTO `ms_addresses` VALUES ('66843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区玉屋町中立売通千本東入', '26', '26102', '6028286', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '玉屋町', 'タマヤチョウ', null, '中立売通千本東入', null, null);
INSERT INTO `ms_addresses` VALUES ('66844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区丹波屋町', '26', '26102', '6028287', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '丹波屋町', 'タンバヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区田丸町', '26', '26102', '6028288', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '田丸町', 'タマルチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区福本町', '26', '26102', '6028291', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '福本町', 'フクモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区今新在家町', '26', '26102', '6028292', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '今新在家町', 'イマシンザイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区新桝屋町', '26', '26102', '6028293', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '新桝屋町', 'シンマスヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区東西俵屋町', '26', '26102', '6028294', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '東西俵屋町', 'トウザイタワラヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区東石橋町', '26', '26102', '6028295', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '東石橋町', 'ヒガシイシバシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区北伊勢殿構町', '26', '26102', '6028296', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '北伊勢殿構町', 'キタイセドノカマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区伊勢殿構町', '26', '26102', '6028297', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '伊勢殿構町', 'イセドノカマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区泰童町', '26', '26102', '6028298', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '泰童町', 'タイドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区革堂之内町', '26', '26102', '6028299', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '革堂之内町', 'コウドウノウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区西芦山寺町', '26', '26102', '6028301', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '西芦山寺町', 'ニシロザンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区井田町', '26', '26102', '6028302', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '井田町', 'イダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区姥ケ寺之前町', '26', '26102', '6028303', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '姥ケ寺之前町', 'ウバガテラノマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区作庵町', '26', '26102', '6028304', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '作庵町', 'サクアンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区花車町', '26', '26102', '6028305', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '花車町', 'ハナクルマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区西五辻北町', '26', '26102', '6028306', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '西五辻北町', 'ニシイツツジキタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区閻魔前町', '26', '26102', '6028307', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '閻魔前町', 'エンママエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区北玄蕃町', '26', '26102', '6028308', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '北玄蕃町', 'キタゲンバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区柏清盛町', '26', '26102', '6028311', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '柏清盛町', 'カシワキヨモリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区末広町', '26', '26102', '6028312', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '末広町', 'スエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区風呂屋町', '26', '26102', '6028313', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '風呂屋町', 'フロヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区佐竹町', '26', '26102', '6028314', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '佐竹町', 'サタケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区突抜町今出川通七本松東入', '26', '26102', '6028315', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '突抜町', 'ツキヌケチョウ', null, '今出川通七本松東入', null, null);
INSERT INTO `ms_addresses` VALUES ('66868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区突抜町今出川通七本松東入上る', '26', '26102', '6028315', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '突抜町', 'ツキヌケチョウ', null, '今出川通七本松東入上る', null, null);
INSERT INTO `ms_addresses` VALUES ('66869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区突抜町五辻通七本松東入下る', '26', '26102', '6028315', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '突抜町', 'ツキヌケチョウ', null, '五辻通七本松東入下る', null, null);
INSERT INTO `ms_addresses` VALUES ('66870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区突抜町五辻通六軒町西入下る', '26', '26102', '6028315', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '突抜町', 'ツキヌケチョウ', null, '五辻通六軒町西入下る', null, null);
INSERT INTO `ms_addresses` VALUES ('66871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区片原町', '26', '26102', '6028316', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '片原町', 'カタハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区東柳町', '26', '26102', '6028317', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '東柳町', 'ヒガシヤナギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区老松町', '26', '26102', '6028318', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '老松町', 'オイマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区溝前町', '26', '26102', '6028319', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '溝前町', 'ミゾマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区南上善寺町', '26', '26102', '6028321', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '南上善寺町', 'ミナミジョウゼンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区玉屋町元誓願寺通千本西入', '26', '26102', '6028322', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '玉屋町', 'タマヤチョウ', null, '元誓願寺通千本西入', null, null);
INSERT INTO `ms_addresses` VALUES ('66877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区玉屋町元誓願寺通六軒町東入', '26', '26102', '6028322', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '玉屋町', 'タマヤチョウ', null, '元誓願寺通六軒町東入', null, null);
INSERT INTO `ms_addresses` VALUES ('66878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区玉屋町六軒町通元誓願寺上る', '26', '26102', '6028322', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '玉屋町', 'タマヤチョウ', null, '六軒町通元誓願寺上る', null, null);
INSERT INTO `ms_addresses` VALUES ('66879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区玉屋町六軒町通元誓願寺下る', '26', '26102', '6028322', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '玉屋町', 'タマヤチョウ', null, '六軒町通元誓願寺下る', null, null);
INSERT INTO `ms_addresses` VALUES ('66880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区玉屋町葭屋町通元誓願寺下る', '26', '26102', '6028322', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '玉屋町', 'タマヤチョウ', null, '葭屋町通元誓願寺下る', null, null);
INSERT INTO `ms_addresses` VALUES ('66881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区大文字町', '26', '26102', '6028323', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '大文字町', 'ダイモンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区元観音町', '26', '26102', '6028324', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '元観音町', 'モトカンノンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区毘沙門町今出川通七本松西入', '26', '26102', '6028325', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '毘沙門町', 'ビシャモンチョウ', null, '今出川通七本松西入', null, null);
INSERT INTO `ms_addresses` VALUES ('66884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区毘沙門町今出川通七本松西入上る', '26', '26102', '6028325', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '毘沙門町', 'ビシャモンチョウ', null, '今出川通七本松西入上る', null, null);
INSERT INTO `ms_addresses` VALUES ('66885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区毘沙門町七本松通今出川上る', '26', '26102', '6028325', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '毘沙門町', 'ビシャモンチョウ', null, '七本松通今出川上る', null, null);
INSERT INTO `ms_addresses` VALUES ('66886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区毘沙門町七本松通今出川下る', '26', '26102', '6028325', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '毘沙門町', 'ビシャモンチョウ', null, '七本松通今出川下る', null, null);
INSERT INTO `ms_addresses` VALUES ('66887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区毘沙門町七本松通元誓願寺上る', '26', '26102', '6028325', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '毘沙門町', 'ビシャモンチョウ', null, '七本松通元誓願寺上る', null, null);
INSERT INTO `ms_addresses` VALUES ('66888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区毘沙門町七本松通五辻下る', '26', '26102', '6028325', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '毘沙門町', 'ビシャモンチョウ', null, '七本松通五辻下る', null, null);
INSERT INTO `ms_addresses` VALUES ('66889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区西上善寺町', '26', '26102', '6028326', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '西上善寺町', 'ニシジョウゼンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区南佐竹町', '26', '26102', '6028327', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '南佐竹町', 'ミナミサタケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区若松町', '26', '26102', '6028331', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '若松町', 'ワカマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区烏丸町', '26', '26102', '6028332', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '烏丸町', 'カラスマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区三条殿町', '26', '26102', '6028333', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '三条殿町', 'サンジョウデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区西今出川町', '26', '26102', '6028334', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '西今出川町', 'ニシイマデガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区一観音町', '26', '26102', '6028335', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '一観音町', 'イチカンノンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区滝ケ鼻町', '26', '26102', '6028336', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '滝ケ鼻町', 'タキガハナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区新建町', '26', '26102', '6028337', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '新建町', 'シンタケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区松永町', '26', '26102', '6028338', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '松永町', 'マツナガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区三軒町', '26', '26102', '6028341', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '三軒町', 'サンケンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区五番町', '26', '26102', '6028342', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '五番町', 'ゴバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区利生町', '26', '26102', '6028343', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '利生町', 'リセイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区二番町', '26', '26102', '6028344', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '二番町', 'ニバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区一番町', '26', '26102', '6028345', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '一番町', 'イチバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区東町一条通下ノ森西入', '26', '26102', '6028346', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '東町', 'ヒガシマチ', null, '一条通下ノ森西入', null, null);
INSERT INTO `ms_addresses` VALUES ('66905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区東町一条通下ノ森東入', '26', '26102', '6028346', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '東町', 'ヒガシマチ', null, '一条通下ノ森東入', null, null);
INSERT INTO `ms_addresses` VALUES ('66906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区東町一条通七本松西入', '26', '26102', '6028346', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '東町', 'ヒガシマチ', null, '一条通七本松西入', null, null);
INSERT INTO `ms_addresses` VALUES ('66907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区東町中立売通七本松西入', '26', '26102', '6028346', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '東町', 'ヒガシマチ', null, '中立売通七本松西入', null, null);
INSERT INTO `ms_addresses` VALUES ('66908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区四番町', '26', '26102', '6028347', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '四番町', 'ヨンバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区白竹町', '26', '26102', '6028348', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '白竹町', 'シラタケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区六番町', '26', '26102', '6028351', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '六番町', 'ロクバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区稲葉町', '26', '26102', '6028352', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '稲葉町', 'イナバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区長門町', '26', '26102', '6028353', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '長門町', 'ナガトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区西東町', '26', '26102', '6028354', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '西東町', 'サイトウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区天満屋町', '26', '26102', '6028355', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '天満屋町', 'テンマヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区三助町', '26', '26102', '6028356', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '三助町', 'サンスケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区鳳瑞町', '26', '26102', '6028357', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '鳳瑞町', 'ホウズイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区三番町', '26', '26102', '6028358', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '三番町', 'サンバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区七番町', '26', '26102', '6028359', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '七番町', 'シチバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区西上之町', '26', '26102', '6028361', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '西上之町', 'ニシカミノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区仲之町御前通上の下立売上る', '26', '26102', '6028362', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '仲之町', 'ナカノチョウ', null, '御前通上の下立売上る', null, null);
INSERT INTO `ms_addresses` VALUES ('66921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区仲之町御前通上の下立売上る東入', '26', '26102', '6028362', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '仲之町', 'ナカノチョウ', null, '御前通上の下立売上る東入', null, null);
INSERT INTO `ms_addresses` VALUES ('66922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区仲之町御前通上の下立売上る2丁目', '26', '26102', '6028362', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '仲之町', 'ナカノチョウ', null, '御前通上の下立売上る2丁目', null, null);
INSERT INTO `ms_addresses` VALUES ('66923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区仲之町御前通下立売上る', '26', '26102', '6028362', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '仲之町', 'ナカノチョウ', null, '御前通下立売上る', null, null);
INSERT INTO `ms_addresses` VALUES ('66924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区仲之町御前通下立売上る2丁目', '26', '26102', '6028362', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '仲之町', 'ナカノチョウ', null, '御前通下立売上る2丁目', null, null);
INSERT INTO `ms_addresses` VALUES ('66925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区仲之町御前通下立売上る2丁目西入', '26', '26102', '6028362', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '仲之町', 'ナカノチョウ', null, '御前通下立売上る2丁目西入', null, null);
INSERT INTO `ms_addresses` VALUES ('66926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区仲之町御前通下立売上る東入', '26', '26102', '6028362', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '仲之町', 'ナカノチョウ', null, '御前通下立売上る東入', null, null);
INSERT INTO `ms_addresses` VALUES ('66927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区仲之町下ノ森通下立売上る', '26', '26102', '6028362', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '仲之町', 'ナカノチョウ', null, '下ノ森通下立売上る', null, null);
INSERT INTO `ms_addresses` VALUES ('66928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区仲之町下ノ森通下立売上る西入', '26', '26102', '6028362', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '仲之町', 'ナカノチョウ', null, '下ノ森通下立売上る西入', null, null);
INSERT INTO `ms_addresses` VALUES ('66929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区仲之町上の下立売通御前西入上る', '26', '26102', '6028362', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '仲之町', 'ナカノチョウ', null, '上の下立売通御前西入上る', null, null);
INSERT INTO `ms_addresses` VALUES ('66930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区大宮町上の下立売通御前西入', '26', '26102', '6028363', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '大宮町', 'オオミヤチョウ', null, '上の下立売通御前西入', null, null);
INSERT INTO `ms_addresses` VALUES ('66931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区大宮町上の下立売通御前西入上る', '26', '26102', '6028363', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '大宮町', 'オオミヤチョウ', null, '上の下立売通御前西入上る', null, null);
INSERT INTO `ms_addresses` VALUES ('66932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区大宮町上の下立売通天神道東入', '26', '26102', '6028363', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '大宮町', 'オオミヤチョウ', null, '上の下立売通天神道東入', null, null);
INSERT INTO `ms_addresses` VALUES ('66933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区大宮町下立売通御前西入', '26', '26102', '6028363', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '大宮町', 'オオミヤチョウ', null, '下立売通御前西入', null, null);
INSERT INTO `ms_addresses` VALUES ('66934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区大宮町下立売通御前西入上る', '26', '26102', '6028363', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '大宮町', 'オオミヤチョウ', null, '下立売通御前西入上る', null, null);
INSERT INTO `ms_addresses` VALUES ('66935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区突抜町下立売通御前西入', '26', '26102', '6028364', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '突抜町', 'ツキヌケチョウ', null, '下立売通御前西入', null, null);
INSERT INTO `ms_addresses` VALUES ('66936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区突抜町下立売通御前西入下る', '26', '26102', '6028364', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '突抜町', 'ツキヌケチョウ', null, '下立売通御前西入下る', null, null);
INSERT INTO `ms_addresses` VALUES ('66937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区突抜町下立売通天神道東入', '26', '26102', '6028364', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '突抜町', 'ツキヌケチョウ', null, '下立売通天神道東入', null, null);
INSERT INTO `ms_addresses` VALUES ('66938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区突抜町下の下立売通御前西入', '26', '26102', '6028364', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '突抜町', 'ツキヌケチョウ', null, '下の下立売通御前西入', null, null);
INSERT INTO `ms_addresses` VALUES ('66939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区下之町', '26', '26102', '6028365', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '下之町', 'シモノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区行衛町', '26', '26102', '6028366', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '行衛町', 'ユクエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区堀川町', '26', '26102', '6028367', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '堀川町', 'ホリカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区北町上の下立売通天神道西入上る', '26', '26102', '6028368', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '北町', 'キタマチ', null, '上の下立売通天神道西入上る', null, null);
INSERT INTO `ms_addresses` VALUES ('66943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区北町上の下立売通御前西入', '26', '26102', '6028368', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '北町', 'キタマチ', null, '上の下立売通御前西入', null, null);
INSERT INTO `ms_addresses` VALUES ('66944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区北町上の下立売通御前西入上る', '26', '26102', '6028368', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '北町', 'キタマチ', null, '上の下立売通御前西入上る', null, null);
INSERT INTO `ms_addresses` VALUES ('66945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区北町上の下立売通御前西入2丁目', '26', '26102', '6028368', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '北町', 'キタマチ', null, '上の下立売通御前西入2丁目', null, null);
INSERT INTO `ms_addresses` VALUES ('66946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区北町上の下立売通御前西入2筋目', '26', '26102', '6028368', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '北町', 'キタマチ', null, '上の下立売通御前西入2筋目', null, null);
INSERT INTO `ms_addresses` VALUES ('66947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区北町下長者町通御前西入', '26', '26102', '6028368', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '北町', 'キタマチ', null, '下長者町通御前西入', null, null);
INSERT INTO `ms_addresses` VALUES ('66948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区北町天神道上の下立売上る', '26', '26102', '6028368', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '北町', 'キタマチ', null, '天神道上の下立売上る', null, null);
INSERT INTO `ms_addresses` VALUES ('66949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区北町天神道仁和寺街道下る', '26', '26102', '6028368', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '北町', 'キタマチ', null, '天神道仁和寺街道下る', null, null);
INSERT INTO `ms_addresses` VALUES ('66950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区北町天神道下立売上る', '26', '26102', '6028368', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '北町', 'キタマチ', null, '天神道下立売上る', null, null);
INSERT INTO `ms_addresses` VALUES ('66951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区北町天神道妙心寺道上る', '26', '26102', '6028368', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '北町', 'キタマチ', null, '天神道妙心寺道上る', null, null);
INSERT INTO `ms_addresses` VALUES ('66952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区北町天神道妙心寺道上る西入', '26', '26102', '6028368', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '北町', 'キタマチ', null, '天神道妙心寺道上る西入', null, null);
INSERT INTO `ms_addresses` VALUES ('66953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区北町仁和寺街道天神道西入下る', '26', '26102', '6028368', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '北町', 'キタマチ', null, '仁和寺街道天神道西入下る', null, null);
INSERT INTO `ms_addresses` VALUES ('66954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区北町仁和寺街道天神道東入下る', '26', '26102', '6028368', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '北町', 'キタマチ', null, '仁和寺街道天神道東入下る', null, null);
INSERT INTO `ms_addresses` VALUES ('66955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区北町御前通上の下立売上る', '26', '26102', '6028368', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '北町', 'キタマチ', null, '御前通上の下立売上る', null, null);
INSERT INTO `ms_addresses` VALUES ('66956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区北町御前通上の下立売上る西入', '26', '26102', '6028368', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '北町', 'キタマチ', null, '御前通上の下立売上る西入', null, null);
INSERT INTO `ms_addresses` VALUES ('66957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区北町御前通下立売上る', '26', '26102', '6028368', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '北町', 'キタマチ', null, '御前通下立売上る', null, null);
INSERT INTO `ms_addresses` VALUES ('66958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区北町御前通下長者町上る西入', '26', '26102', '6028368', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '北町', 'キタマチ', null, '御前通下長者町上る西入', null, null);
INSERT INTO `ms_addresses` VALUES ('66959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区北町御前通仁和寺街道下る西入', '26', '26102', '6028368', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '北町', 'キタマチ', null, '御前通仁和寺街道下る西入', null, null);
INSERT INTO `ms_addresses` VALUES ('66960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区北町御前通妙心寺道上る西入', '26', '26102', '6028368', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '北町', 'キタマチ', null, '御前通妙心寺道上る西入', null, null);
INSERT INTO `ms_addresses` VALUES ('66961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区北町御前通西裏上の下立売上る', '26', '26102', '6028368', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '北町', 'キタマチ', null, '御前通西裏上の下立売上る', null, null);
INSERT INTO `ms_addresses` VALUES ('66962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区北町御前通西裏下立売上る', '26', '26102', '6028368', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '北町', 'キタマチ', null, '御前通西裏下立売上る', null, null);
INSERT INTO `ms_addresses` VALUES ('66963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区川瀬町', '26', '26102', '6028369', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '川瀬町', 'カワセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区西町一条通御前東入', '26', '26102', '6028371', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '西町', 'ニシマチ', null, '一条通御前東入', null, null);
INSERT INTO `ms_addresses` VALUES ('66965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区下竪町', '26', '26102', '6028372', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '下竪町', 'シモタテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区下横町', '26', '26102', '6028373', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '下横町', 'シモヨコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区西町一条通御前西入', '26', '26102', '6028374', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '西町', 'ニシマチ', null, '一条通御前西入', null, null);
INSERT INTO `ms_addresses` VALUES ('66968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区西町一条通紙屋川東入', '26', '26102', '6028374', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '西町', 'ニシマチ', null, '一条通紙屋川東入', null, null);
INSERT INTO `ms_addresses` VALUES ('66969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区西町一条通天神道西入', '26', '26102', '6028374', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '西町', 'ニシマチ', null, '一条通天神道西入', null, null);
INSERT INTO `ms_addresses` VALUES ('66970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区西町一条通御前3丁目西入', '26', '26102', '6028374', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '西町', 'ニシマチ', null, '一条通御前3丁目西入', null, null);
INSERT INTO `ms_addresses` VALUES ('66971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区西町一条通御前西入上る', '26', '26102', '6028374', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '西町', 'ニシマチ', null, '一条通御前西入上る', null, null);
INSERT INTO `ms_addresses` VALUES ('66972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区西町一条通御前西入上る西入', '26', '26102', '6028374', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '西町', 'ニシマチ', null, '一条通御前西入上る西入', null, null);
INSERT INTO `ms_addresses` VALUES ('66973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区西町一条通御前西入2丁目', '26', '26102', '6028374', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '西町', 'ニシマチ', null, '一条通御前西入2丁目', null, null);
INSERT INTO `ms_addresses` VALUES ('66974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区西町一条通御前西入2丁目上る', '26', '26102', '6028374', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '西町', 'ニシマチ', null, '一条通御前西入2丁目上る', null, null);
INSERT INTO `ms_addresses` VALUES ('66975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区西町一条通御前西入2丁目下る', '26', '26102', '6028374', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '西町', 'ニシマチ', null, '一条通御前西入2丁目下る', null, null);
INSERT INTO `ms_addresses` VALUES ('66976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区西町一条通御前西入2筋目下る', '26', '26102', '6028374', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '西町', 'ニシマチ', null, '一条通御前西入2筋目下る', null, null);
INSERT INTO `ms_addresses` VALUES ('66977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区西町一条通御前西入3丁目', '26', '26102', '6028374', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '西町', 'ニシマチ', null, '一条通御前西入3丁目', null, null);
INSERT INTO `ms_addresses` VALUES ('66978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区西町一条通御前西入3丁目上る', '26', '26102', '6028374', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '西町', 'ニシマチ', null, '一条通御前西入3丁目上る', null, null);
INSERT INTO `ms_addresses` VALUES ('66979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区西町一条通御前西入3丁目下る', '26', '26102', '6028374', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '西町', 'ニシマチ', null, '一条通御前西入3丁目下る', null, null);
INSERT INTO `ms_addresses` VALUES ('66980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区西町一条通御前西入3筋目', '26', '26102', '6028374', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '西町', 'ニシマチ', null, '一条通御前西入3筋目', null, null);
INSERT INTO `ms_addresses` VALUES ('66981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区西町一条通御前西入下る', '26', '26102', '6028374', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '西町', 'ニシマチ', null, '一条通御前西入下る', null, null);
INSERT INTO `ms_addresses` VALUES ('66982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区西町一条通御前西入下る3丁目', '26', '26102', '6028374', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '西町', 'ニシマチ', null, '一条通御前西入下る3丁目', null, null);
INSERT INTO `ms_addresses` VALUES ('66983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区西町一条通紙屋川東入上る', '26', '26102', '6028374', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '西町', 'ニシマチ', null, '一条通紙屋川東入上る', null, null);
INSERT INTO `ms_addresses` VALUES ('66984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区西町一条通紙屋川東入下る', '26', '26102', '6028374', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '西町', 'ニシマチ', null, '一条通紙屋川東入下る', null, null);
INSERT INTO `ms_addresses` VALUES ('66985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区西町天神道一条上る', '26', '26102', '6028374', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '西町', 'ニシマチ', null, '天神道一条上る', null, null);
INSERT INTO `ms_addresses` VALUES ('66986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区西町天神道一条下る', '26', '26102', '6028374', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '西町', 'ニシマチ', null, '天神道一条下る', null, null);
INSERT INTO `ms_addresses` VALUES ('66987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区西町天神道仁和寺街道上る', '26', '26102', '6028374', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '西町', 'ニシマチ', null, '天神道仁和寺街道上る', null, null);
INSERT INTO `ms_addresses` VALUES ('66988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区大上之町', '26', '26102', '6028375', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '大上之町', 'オオカミノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区大東町', '26', '26102', '6028376', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '大東町', 'オオヒガシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区東竪町', '26', '26102', '6028377', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '東竪町', 'ヒガシタテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区真盛町', '26', '26102', '6028381', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '真盛町', 'シンセイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区末之口町', '26', '26102', '6028382', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '末之口町', 'スエノクチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区西今小路町', '26', '26102', '6028383', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '西今小路町', 'ニシイマコウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区紙屋川町', '26', '26102', '6028384', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '紙屋川町', 'カミヤガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区観音寺門前町', '26', '26102', '6028385', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '観音寺門前町', 'カンノンジモンゼンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区馬喰町', '26', '26102', '6028386', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '馬喰町', 'バクロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区東今小路町', '26', '26102', '6028387', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '東今小路町', 'ヒガシイマコウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('66998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区神明町御前通寺之内下る', '26', '26102', '6028391', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '神明町', 'シンメイチョウ', null, '御前通寺之内下る', null, null);
INSERT INTO `ms_addresses` VALUES ('66999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区神明町御前通今出川上る', '26', '26102', '6028391', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '神明町', 'シンメイチョウ', null, '御前通今出川上る', null, null);
INSERT INTO `ms_addresses` VALUES ('67000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区神明町御前通今出川上る2丁目', '26', '26102', '6028391', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '神明町', 'シンメイチョウ', null, '御前通今出川上る2丁目', null, null);
INSERT INTO `ms_addresses` VALUES ('67001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区神明町御前通今出川上る3丁目', '26', '26102', '6028391', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '神明町', 'シンメイチョウ', null, '御前通今出川上る3丁目', null, null);
INSERT INTO `ms_addresses` VALUES ('67002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区神明町寺之内通御前西入', '26', '26102', '6028391', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '神明町', 'シンメイチョウ', null, '寺之内通御前西入', null, null);
INSERT INTO `ms_addresses` VALUES ('67003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区北町御前通五辻上る', '26', '26102', '6028392', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '北町', 'キタマチ', null, '御前通五辻上る', null, null);
INSERT INTO `ms_addresses` VALUES ('67004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区北町御前通今出川上る', '26', '26102', '6028392', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '北町', 'キタマチ', null, '御前通今出川上る', null, null);
INSERT INTO `ms_addresses` VALUES ('67005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区北町御前通今出川上る1丁目', '26', '26102', '6028392', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '北町', 'キタマチ', null, '御前通今出川上る1丁目', null, null);
INSERT INTO `ms_addresses` VALUES ('67006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区北町御前通今出川上る2丁目', '26', '26102', '6028392', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '北町', 'キタマチ', null, '御前通今出川上る2丁目', null, null);
INSERT INTO `ms_addresses` VALUES ('67007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区北町御前通今出川上る2丁目西入', '26', '26102', '6028392', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '北町', 'キタマチ', null, '御前通今出川上る2丁目西入', null, null);
INSERT INTO `ms_addresses` VALUES ('67008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区北町御前通今出川上る2筋目', '26', '26102', '6028392', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '北町', 'キタマチ', null, '御前通今出川上る2筋目', null, null);
INSERT INTO `ms_addresses` VALUES ('67009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区北町御前通今出川上る西入', '26', '26102', '6028392', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '北町', 'キタマチ', null, '御前通今出川上る西入', null, null);
INSERT INTO `ms_addresses` VALUES ('67010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区北町御前通今出川上る東入', '26', '26102', '6028392', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '北町', 'キタマチ', null, '御前通今出川上る東入', null, null);
INSERT INTO `ms_addresses` VALUES ('67011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区北町御前通今出川2丁目上る', '26', '26102', '6028392', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '北町', 'キタマチ', null, '御前通今出川2丁目上る', null, null);
INSERT INTO `ms_addresses` VALUES ('67012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区北町御前通寺之内下る', '26', '26102', '6028392', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '北町', 'キタマチ', null, '御前通寺之内下る', null, null);
INSERT INTO `ms_addresses` VALUES ('67013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区鳥居前町', '26', '26102', '6028393', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '鳥居前町', 'トリイマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区西柳町', '26', '26102', '6028394', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '西柳町', 'ニシヤナギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区社家長屋町', '26', '26102', '6028395', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '社家長屋町', 'シャケナガヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区薬師前町', '26', '26102', '6028401', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '薬師前町', 'ヤクシマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区田畑町', '26', '26102', '6028402', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '田畑町', 'タバタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区中社町', '26', '26102', '6028403', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '中社町', 'ナカヤシロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区西千本町', '26', '26102', '6028404', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '西千本町', 'ニシセンボンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区大猪熊町寺之内通大宮西入', '26', '26102', '6028405', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '大猪熊町', 'オオイノクマチョウ', null, '寺之内通大宮西入', null, null);
INSERT INTO `ms_addresses` VALUES ('67021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区大猪熊町寺之内通智恵光院西入', '26', '26102', '6028405', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '大猪熊町', 'オオイノクマチョウ', null, '寺之内通智恵光院西入', null, null);
INSERT INTO `ms_addresses` VALUES ('67022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区大猪熊町寺之内通智恵光院東入', '26', '26102', '6028405', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '大猪熊町', 'オオイノクマチョウ', null, '寺之内通智恵光院東入', null, null);
INSERT INTO `ms_addresses` VALUES ('67023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区大猪熊町寺之内通大宮東入', '26', '26102', '6028405', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '大猪熊町', 'オオイノクマチョウ', null, '寺之内通大宮東入', null, null);
INSERT INTO `ms_addresses` VALUES ('67024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区大猪熊町智恵光院通寺之内下る', '26', '26102', '6028405', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '大猪熊町', 'オオイノクマチョウ', null, '智恵光院通寺之内下る', null, null);
INSERT INTO `ms_addresses` VALUES ('67025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区花開院町', '26', '26102', '6028406', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '花開院町', 'ケイカインチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区伊佐町', '26', '26102', '6028407', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '伊佐町', 'イサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区古美濃部町', '26', '26102', '6028408', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '古美濃部町', 'フルミノベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区新美濃部町', '26', '26102', '6028409', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '新美濃部町', 'シンミノベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区東西町', '26', '26102', '6028411', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '東西町', 'トウザイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区芝之町', '26', '26102', '6028412', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '芝之町', 'シバノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区大北小路東町', '26', '26102', '6028413', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '大北小路東町', 'オオキタコウジヒガシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区西北小路町猪熊通上立売上る', '26', '26102', '6028414', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '西北小路町', 'ニシキタコウジチョウ', null, '猪熊通上立売上る', null, null);
INSERT INTO `ms_addresses` VALUES ('67033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区西北小路町猪熊通寺之内下る', '26', '26102', '6028414', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '西北小路町', 'ニシキタコウジチョウ', null, '猪熊通寺之内下る', null, null);
INSERT INTO `ms_addresses` VALUES ('67034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区西北小路町大宮通寺之内下る東入', '26', '26102', '6028414', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '西北小路町', 'ニシキタコウジチョウ', null, '大宮通寺之内下る東入', null, null);
INSERT INTO `ms_addresses` VALUES ('67035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区西北小路町大宮通寺之内半丁下る東入', '26', '26102', '6028414', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '西北小路町', 'ニシキタコウジチョウ', null, '大宮通寺之内半丁下る東入', null, null);
INSERT INTO `ms_addresses` VALUES ('67036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区西北小路町大宮通寺之内下る東入1丁目', '26', '26102', '6028414', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '西北小路町', 'ニシキタコウジチョウ', null, '大宮通寺之内下る東入1丁目', null, null);
INSERT INTO `ms_addresses` VALUES ('67037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区西北小路町寺之内通大宮東入下る', '26', '26102', '6028414', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '西北小路町', 'ニシキタコウジチョウ', null, '寺之内通大宮東入下る', null, null);
INSERT INTO `ms_addresses` VALUES ('67038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区西北小路町寺之内通大宮東入1丁目下る', '26', '26102', '6028414', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '西北小路町', 'ニシキタコウジチョウ', null, '寺之内通大宮東入1丁目下る', null, null);
INSERT INTO `ms_addresses` VALUES ('67039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区前之町', '26', '26102', '6028415', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '前之町', 'マエノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区東千本町', '26', '26102', '6028416', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '東千本町', 'ヒガシセンボンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区東社町', '26', '26102', '6028417', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '東社町', 'ヒガシヤシロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区妙蓮寺前町', '26', '26102', '6028418', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '妙蓮寺前町', 'ミョウレンジマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区芝薬師町', '26', '26102', '6028421', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '芝薬師町', 'シバヤクシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区山名町', '26', '26102', '6028422', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '山名町', 'ヤマナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区藤木町', '26', '26102', '6028423', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '藤木町', 'フジノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区阿弥陀寺町', '26', '26102', '6028424', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '阿弥陀寺町', 'アミダジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区樋之口町', '26', '26102', '6028425', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '樋之口町', 'ヒノクチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区曼陀羅町', '26', '26102', '6028426', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '曼陀羅町', 'マンダラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区土田町', '26', '26102', '6028427', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '土田町', 'ツチダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区幸在町', '26', '26102', '6028428', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '幸在町', 'コウザイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区東石屋町', '26', '26102', '6028431', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '東石屋町', 'ヒガシイシヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区北猪熊町', '26', '26102', '6028432', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '北猪熊町', 'キタイノクマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区橋之上町', '26', '26102', '6028433', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '橋之上町', 'ハシノウエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区西船橋町', '26', '26102', '6028434', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '西船橋町', 'ニシフナハシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区元伊佐町', '26', '26102', '6028435', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '元伊佐町', 'モトイサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区慈眼庵町', '26', '26102', '6028436', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '慈眼庵町', 'ジゲンアンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区西石屋町', '26', '26102', '6028437', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '西石屋町', 'ニシイシヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区芝大宮町', '26', '26102', '6028438', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '芝大宮町', 'シバオオミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区硯屋町', '26', '26102', '6028439', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '硯屋町', 'スズリヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区観世町', '26', '26102', '6028441', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '観世町', 'カンゼチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区薬師町', '26', '26102', '6028442', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '薬師町', 'ヤクシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区元妙蓮寺町', '26', '26102', '6028443', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '元妙蓮寺町', 'モトミョウレンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区西北小路町今出川通浄福寺東入', '26', '26102', '6028444', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '西北小路町', 'ニシキタコウジチョウ', null, '今出川通浄福寺東入', null, null);
INSERT INTO `ms_addresses` VALUES ('67064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区西北小路町今出川通智恵光院西入', '26', '26102', '6028444', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '西北小路町', 'ニシキタコウジチョウ', null, '今出川通智恵光院西入', null, null);
INSERT INTO `ms_addresses` VALUES ('67065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区西北小路町今出川通智恵光院東入', '26', '26102', '6028444', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '西北小路町', 'ニシキタコウジチョウ', null, '今出川通智恵光院東入', null, null);
INSERT INTO `ms_addresses` VALUES ('67066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区西北小路町智恵光院通今出川上る', '26', '26102', '6028444', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '西北小路町', 'ニシキタコウジチョウ', null, '智恵光院通今出川上る', null, null);
INSERT INTO `ms_addresses` VALUES ('67067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区西北小路町智恵光院通今出川下る', '26', '26102', '6028444', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '西北小路町', 'ニシキタコウジチョウ', null, '智恵光院通今出川下る', null, null);
INSERT INTO `ms_addresses` VALUES ('67068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区西北小路町五辻通浄福寺東入', '26', '26102', '6028444', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '西北小路町', 'ニシキタコウジチョウ', null, '五辻通浄福寺東入', null, null);
INSERT INTO `ms_addresses` VALUES ('67069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区桜井町', '26', '26102', '6028445', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '桜井町', 'サクライチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区五辻町', '26', '26102', '6028446', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '五辻町', 'イツツジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区紋屋町', '26', '26102', '6028447', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '紋屋町', 'モンヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区元北小路町', '26', '26102', '6028448', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '元北小路町', 'モトキタコウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区横大宮町', '26', '26102', '6028449', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '横大宮町', 'ヨコオオミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区菱屋町中筋通浄福寺東入', '26', '26102', '6028451', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '菱屋町', 'ヒシヤチョウ', null, '中筋通浄福寺東入', null, null);
INSERT INTO `ms_addresses` VALUES ('67075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区菱屋町中筋通智恵光院西入', '26', '26102', '6028451', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '菱屋町', 'ヒシヤチョウ', null, '中筋通智恵光院西入', null, null);
INSERT INTO `ms_addresses` VALUES ('67076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区元中之町', '26', '26102', '6028452', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '元中之町', 'モトナカノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区笹屋', '26', '26102', '6028453', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '笹屋', 'ササヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区今出川町元誓願寺通浄福寺西入', '26', '26102', '6028454', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '今出川町', 'イマデガワチョウ', null, '元誓願寺通浄福寺西入', null, null);
INSERT INTO `ms_addresses` VALUES ('67079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区今出川町元誓願寺通浄福寺東入', '26', '26102', '6028454', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '今出川町', 'イマデガワチョウ', null, '元誓願寺通浄福寺東入', null, null);
INSERT INTO `ms_addresses` VALUES ('67080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区今出川町浄福寺通元誓願寺上る', '26', '26102', '6028454', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '今出川町', 'イマデガワチョウ', null, '浄福寺通元誓願寺上る', null, null);
INSERT INTO `ms_addresses` VALUES ('67081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区今出川町浄福寺通元誓願寺下る', '26', '26102', '6028454', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '今出川町', 'イマデガワチョウ', null, '浄福寺通元誓願寺下る', null, null);
INSERT INTO `ms_addresses` VALUES ('67082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区泰童片原町', '26', '26102', '6028455', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '泰童片原町', 'タイドウカタハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区北小路中之町', '26', '26102', '6028461', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '北小路中之町', 'キタコウジナカノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区竪亀屋町', '26', '26102', '6028462', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '竪亀屋町', 'タテカメヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区革堂町元誓願寺通浄福寺西入', '26', '26102', '6028463', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '革堂町', 'コウドウチョウ', null, '元誓願寺通浄福寺西入', null, null);
INSERT INTO `ms_addresses` VALUES ('67086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区元四丁目', '26', '26102', '6028464', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '元四丁目', 'モトヨンチョウメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区松屋町', '26', '26102', '6028465', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '松屋町', 'マツヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区南辻町', '26', '26102', '6028466', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '南辻町', 'ミナミツジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区西亀屋町', '26', '26102', '6028467', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '西亀屋町', 'ニシカメヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区東上善寺町', '26', '26102', '6028468', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '東上善寺町', 'ヒガシジョウゼンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区中宮町', '26', '26102', '6028469', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '中宮町', 'ナカミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区一色町', '26', '26102', '6028471', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '一色町', 'イッシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区有馬町', '26', '26102', '6028472', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '有馬町', 'アリマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区般舟院前町', '26', '26102', '6028473', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '般舟院前町', 'ハンシュウインマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区上善寺町', '26', '26102', '6028474', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '上善寺町', 'ジョウゼンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区牡丹鉾町', '26', '26102', '6028475', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '牡丹鉾町', 'ボタンボコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区桐木町', '26', '26102', '6028476', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '桐木町', 'キリノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区姥ケ榎木町', '26', '26102', '6028477', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '姥ケ榎木町', 'ウバガエノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区西五辻東町', '26', '26102', '6028478', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '西五辻東町', 'ニシイツツジヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区聖天町', '26', '26102', '6028481', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '聖天町', 'ショウテンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区大黒町上立売通浄福寺西入', '26', '26102', '6028482', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '大黒町', 'ダイコクチョウ', null, '上立売通浄福寺西入', null, null);
INSERT INTO `ms_addresses` VALUES ('67102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区大黒町上立売通浄福寺東入', '26', '26102', '6028482', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '大黒町', 'ダイコクチョウ', null, '上立売通浄福寺東入', null, null);
INSERT INTO `ms_addresses` VALUES ('67103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区大黒町浄福寺通上立売上る', '26', '26102', '6028482', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '大黒町', 'ダイコクチョウ', null, '浄福寺通上立売上る', null, null);
INSERT INTO `ms_addresses` VALUES ('67104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区大黒町浄福寺通寺之内下る', '26', '26102', '6028482', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '大黒町', 'ダイコクチョウ', null, '浄福寺通寺之内下る', null, null);
INSERT INTO `ms_addresses` VALUES ('67105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区杉若町', '26', '26102', '6028483', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '杉若町', 'スギワカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区蛭子町上立売通浄福寺西入', '26', '26102', '6028484', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '蛭子町', 'エビスチョウ', null, '上立売通浄福寺西入', null, null);
INSERT INTO `ms_addresses` VALUES ('67107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区蛭子町浄福寺通上立売下る', '26', '26102', '6028484', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '蛭子町', 'エビスチョウ', null, '浄福寺通上立売下る', null, null);
INSERT INTO `ms_addresses` VALUES ('67108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区姥ケ東西町', '26', '26102', '6028485', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '姥ケ東西町', 'ウバガトウザイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区姥ケ西町', '26', '26102', '6028486', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '姥ケ西町', 'ウバガニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区姥ケ北町', '26', '26102', '6028487', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '姥ケ北町', 'ウバガキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区真倉町', '26', '26102', '6028488', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '真倉町', 'マクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区西社町', '26', '26102', '6028491', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '西社町', 'ニシヤシロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区歓喜町', '26', '26102', '6028492', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '歓喜町', 'カンキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区中猪熊町', '26', '26102', '6028493', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '中猪熊町', 'ナカイノクマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区新猪熊東町', '26', '26102', '6028494', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '新猪熊東町', 'シンイノクマヒガシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区新猪熊町', '26', '26102', '6028495', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '新猪熊町', 'シンイノクマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区木瓜原町', '26', '26102', '6028496', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '木瓜原町', 'ボケハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区戌亥町', '26', '26102', '6028497', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '戌亥町', 'イヌイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市上京区西熊町', '26', '26102', '6028498', '京都府', 'キョウトフ', '京都市上京区', 'キョウトシカミギョウク', '西熊町', 'ニシクマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区', '26', '26101', '6030000', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('67131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区上賀茂十三石山', '26', '26101', '6038001', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '上賀茂十三石山', 'カミガモジュウサンゴクヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区上賀茂神山', '26', '26101', '6038002', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '上賀茂神山', 'カミガモコウヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区上賀茂柊谷町', '26', '26101', '6038003', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '上賀茂柊谷町', 'カミガモヒイラギダニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区上賀茂六段田町', '26', '26101', '6038004', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '上賀茂六段田町', 'カミガモロクダンダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区上賀茂前田町', '26', '26101', '6038005', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '上賀茂前田町', 'カミガモマエダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区上賀茂北ノ原町', '26', '26101', '6038006', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '上賀茂北ノ原町', 'カミガモキタノハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区上賀茂毛穴井町', '26', '26101', '6038007', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '上賀茂毛穴井町', 'カミガモケアナイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区上賀茂中嶋河原町', '26', '26101', '6038008', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '上賀茂中嶋河原町', 'カミガモナカジマガワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区上賀茂二軒家町', '26', '26101', '6038011', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '上賀茂二軒家町', 'カミガモニケンヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区上賀茂葵田町', '26', '26101', '6038012', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '上賀茂葵田町', 'カミガモアオイデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区上賀茂上神原町', '26', '26101', '6038013', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '上賀茂上神原町', 'カミガモカミジンバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区上賀茂下神原町', '26', '26101', '6038014', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '上賀茂下神原町', 'カミガモシモジンバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区上賀茂備後田町', '26', '26101', '6038015', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '上賀茂備後田町', 'カミガモビンゴデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区上賀茂坂口町', '26', '26101', '6038016', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '上賀茂坂口町', 'カミガモサカグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区上賀茂壱町口町', '26', '26101', '6038017', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '上賀茂壱町口町', 'カミガモイッチョウグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区上賀茂赤尾町', '26', '26101', '6038018', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '上賀茂赤尾町', 'カミガモアカオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区上賀茂西後藤町', '26', '26101', '6038021', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '上賀茂西後藤町', 'カミガモニシゴトウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区上賀茂東後藤町', '26', '26101', '6038022', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '上賀茂東後藤町', 'カミガモヒガシゴトウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区上賀茂東上之段町', '26', '26101', '6038023', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '上賀茂東上之段町', 'カミガモヒガシウエノダンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区上賀茂中ノ坂町', '26', '26101', '6038024', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '上賀茂中ノ坂町', 'カミガモナカノサカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区上賀茂舟着町', '26', '26101', '6038025', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '上賀茂舟着町', 'カミガモフナツキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区上賀茂中山町', '26', '26101', '6038026', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '上賀茂中山町', 'カミガモナカヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区上賀茂津ノ国町', '26', '26101', '6038027', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '上賀茂津ノ国町', 'カミガモツノクニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区上賀茂西上之段町', '26', '26101', '6038028', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '上賀茂西上之段町', 'カミガモニシウエノダンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区上賀茂女夫岩町', '26', '26101', '6038031', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '上賀茂女夫岩町', 'カミガモメオトイワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区上賀茂中ノ河原町', '26', '26101', '6038032', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '上賀茂中ノ河原町', 'カミガモナカノカワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区上賀茂馬ノ目町', '26', '26101', '6038033', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '上賀茂馬ノ目町', 'カミガモウマノメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区上賀茂葵之森町', '26', '26101', '6038034', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '上賀茂葵之森町', 'カミガモアオイノモリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区上賀茂朝露ケ原町', '26', '26101', '6038035', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '上賀茂朝露ケ原町', 'カミガモアサツユガハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区上賀茂西河原町', '26', '26101', '6038036', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '上賀茂西河原町', 'カミガモニシガワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区上賀茂大柳町', '26', '26101', '6038037', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '上賀茂大柳町', 'カミガモオオヤナギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区上賀茂音保瀬町', '26', '26101', '6038038', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '上賀茂音保瀬町', 'カミガモオトボセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区上賀茂ケシ山', '26', '26101', '6038041', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '上賀茂ケシ山', 'カミガモケシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区上賀茂狭間町', '26', '26101', '6038042', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '上賀茂狭間町', 'カミガモハザマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区上賀茂池端町', '26', '26101', '6038043', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '上賀茂池端町', 'カミガモイケバタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区上賀茂畔勝町', '26', '26101', '6038044', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '上賀茂畔勝町', 'カミガモアゼカチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区上賀茂豊田町', '26', '26101', '6038045', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '上賀茂豊田町', 'カミガモトヨタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区上賀茂深泥池町', '26', '26101', '6038046', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '上賀茂深泥池町', 'カミガモミドロイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区上賀茂本山', '26', '26101', '6038047', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '上賀茂本山', 'カミガモモトヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区上賀茂榊田町', '26', '26101', '6038051', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '上賀茂榊田町', 'カミガモサカキダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区上賀茂松本町', '26', '26101', '6038052', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '上賀茂松本町', 'カミガモマツモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区上賀茂岩ケ垣内町', '26', '26101', '6038053', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '上賀茂岩ケ垣内町', 'カミガモイワガカキウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区上賀茂桜井町', '26', '26101', '6038054', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '上賀茂桜井町', 'カミガモサクライチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区上賀茂高縄手町', '26', '26101', '6038055', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '上賀茂高縄手町', 'カミガモタカナワテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区上賀茂石計町', '26', '26101', '6038056', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '上賀茂石計町', 'カミガモイシカズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区上賀茂荒草町', '26', '26101', '6038061', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '上賀茂荒草町', 'カミガモアラクサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区上賀茂薮田町', '26', '26101', '6038062', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '上賀茂薮田町', 'カミガモヤブタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区上賀茂今井河原町', '26', '26101', '6038063', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '上賀茂今井河原町', 'カミガモイマイガワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区上賀茂菖蒲園町', '26', '26101', '6038064', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '上賀茂菖蒲園町', 'カミガモショウブエンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区上賀茂御薗口町', '26', '26101', '6038065', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '上賀茂御薗口町', 'カミガモミソノグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区上賀茂池殿町', '26', '26101', '6038066', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '上賀茂池殿町', 'カミガモイケドノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区上賀茂北大路町', '26', '26101', '6038071', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '上賀茂北大路町', 'カミガモキタオオジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区上賀茂竹ケ鼻町', '26', '26101', '6038072', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '上賀茂竹ケ鼻町', 'カミガモタケガハナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区上賀茂烏帽子ケ垣内町', '26', '26101', '6038073', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '上賀茂烏帽子ケ垣内町', 'カミガモエボシガカキウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区上賀茂南大路町', '26', '26101', '6038074', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '上賀茂南大路町', 'カミガモミナミオオジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区上賀茂中大路町', '26', '26101', '6038075', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '上賀茂中大路町', 'カミガモナカオオジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区上賀茂山本町', '26', '26101', '6038076', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '上賀茂山本町', 'カミガモヤマモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区上賀茂藤ノ木町', '26', '26101', '6038077', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '上賀茂藤ノ木町', 'カミガモフジノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区上賀茂岡本町', '26', '26101', '6038081', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '上賀茂岡本町', 'カミガモオカモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区上賀茂岡本口町', '26', '26101', '6038082', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '上賀茂岡本口町', 'カミガモオカモトグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区上賀茂向縄手町', '26', '26101', '6038083', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '上賀茂向縄手町', 'カミガモムカイナワテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区上賀茂土門町', '26', '26101', '6038084', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '上賀茂土門町', 'カミガモツチカドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区上賀茂蝉ケ垣内町', '26', '26101', '6038085', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '上賀茂蝉ケ垣内町', 'カミガモセミガカキウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区上賀茂向梅町', '26', '26101', '6038086', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '上賀茂向梅町', 'カミガモムカイウメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区上賀茂梅ケ辻町', '26', '26101', '6038087', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '上賀茂梅ケ辻町', 'カミガモウメガツジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区紫竹上堀川町', '26', '26101', '6038101', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '紫竹上堀川町', 'シチクカミホリカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区紫竹上長目町', '26', '26101', '6038102', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '紫竹上長目町', 'シチクカミナガメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区小山北玄以町', '26', '26101', '6038103', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '小山北玄以町', 'コヤマキタゲンイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区小山東玄以町', '26', '26101', '6038104', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '小山東玄以町', 'コヤマヒガシゲンイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区小山西玄以町', '26', '26101', '6038105', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '小山西玄以町', 'コヤマニシゲンイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区紫竹下長目町', '26', '26101', '6038106', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '紫竹下長目町', 'シチクシモナガメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区紫竹下ノ岸町', '26', '26101', '6038107', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '紫竹下ノ岸町', 'シチクシモノキシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区紫竹上ノ岸町', '26', '26101', '6038108', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '紫竹上ノ岸町', 'シチクカミノキシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区小山東元町', '26', '26101', '6038111', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '小山東元町', 'コヤマヒガシモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区小山元町', '26', '26101', '6038112', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '小山元町', 'コヤマモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区小山西元町', '26', '26101', '6038113', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '小山西元町', 'コヤマニシモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区紫竹下高才町', '26', '26101', '6038114', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '紫竹下高才町', 'シチクシモコウサイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区紫竹下本町', '26', '26101', '6038115', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '紫竹下本町', 'シチクシモホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区紫竹上本町', '26', '26101', '6038116', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '紫竹上本町', 'シチクカミホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区紫竹上高才町', '26', '26101', '6038117', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '紫竹上高才町', 'シチクカミコウサイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区小山上花ノ木町', '26', '26101', '6038121', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '小山上花ノ木町', 'コヤマカミハナノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区小山花ノ木町', '26', '26101', '6038122', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '小山花ノ木町', 'コヤマハナノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区小山下花ノ木町', '26', '26101', '6038123', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '小山下花ノ木町', 'コヤマシモハナノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区小山下板倉町', '26', '26101', '6038124', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '小山下板倉町', 'コヤマシモイタクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区小山板倉町', '26', '26101', '6038125', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '小山板倉町', 'コヤマイタクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区小山上板倉町', '26', '26101', '6038126', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '小山上板倉町', 'コヤマカミイタクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区小山上内河原町', '26', '26101', '6038131', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '小山上内河原町', 'コヤマカミウチカワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区小山下内河原町', '26', '26101', '6038132', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '小山下内河原町', 'コヤマシモウチカワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区出雲路松ノ下町', '26', '26101', '6038133', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '出雲路松ノ下町', 'イズモジマツノシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区出雲路立テ本町', '26', '26101', '6038134', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '出雲路立テ本町', 'イズモジタテモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区出雲路俵町', '26', '26101', '6038135', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '出雲路俵町', 'イズモジタワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区出雲路神楽町', '26', '26101', '6038136', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '出雲路神楽町', 'イズモジカグラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区鞍馬口町', '26', '26101', '6038137', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '鞍馬口町', 'クラマグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区天寧寺門前町', '26', '26101', '6038138', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '天寧寺門前町', 'テンネイジモンゼンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区上善寺門前町', '26', '26101', '6038139', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '上善寺門前町', 'ジョウゼンジモンゼンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区小山西上総町', '26', '26101', '6038141', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '小山西上総町', 'コヤマニシカミフサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区小山北上総町', '26', '26101', '6038142', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '小山北上総町', 'コヤマキタカミフサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区小山上総町', '26', '26101', '6038143', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '小山上総町', 'コヤマカミフサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区小山東花池町', '26', '26101', '6038144', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '小山東花池町', 'コヤマヒガシハナイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区小山堀池町', '26', '26101', '6038145', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '小山堀池町', 'コヤマホリイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区新御霊口町', '26', '26101', '6038146', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '新御霊口町', 'シンゴリョウグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区上御霊上江町', '26', '26101', '6038147', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '上御霊上江町', 'カミゴリョウカミエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区小山西花池町', '26', '26101', '6038148', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '小山西花池町', 'コヤマニシハナイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区小山南上総町', '26', '26101', '6038149', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '小山南上総町', 'コヤマミナミカミフサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区小山下総町', '26', '26101', '6038151', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '小山下総町', 'コヤマシモフサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区小山町', '26', '26101', '6038152', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '小山町', 'コヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区長乗東町', '26', '26101', '6038153', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '長乗東町', 'チョウジョウヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区長乗西町', '26', '26101', '6038154', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '長乗西町', 'チョウジョウニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区上清蔵口町', '26', '26101', '6038155', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '上清蔵口町', 'カミセイゾウグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区小山中溝町', '26', '26101', '6038156', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '小山中溝町', 'コヤマナカミゾチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区紫野宮東町', '26', '26101', '6038157', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '紫野宮東町', 'ムラサキノミヤヒガシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区紫野宮西町', '26', '26101', '6038158', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '紫野宮西町', 'ムラサキノミヤニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区小山北大野町', '26', '26101', '6038161', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '小山北大野町', 'コヤマキタオオノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区小山東大野町', '26', '26101', '6038162', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '小山東大野町', 'コヤマヒガシオオノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区小山南大野町', '26', '26101', '6038163', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '小山南大野町', 'コヤマミナミオオノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区紫野東御所田町', '26', '26101', '6038164', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '紫野東御所田町', 'ムラサキノヒガシゴショデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区紫野西御所田町', '26', '26101', '6038165', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '紫野西御所田町', 'ムラサキノニシゴショデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区紫野上御所田町', '26', '26101', '6038166', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '紫野上御所田町', 'ムラサキノカミゴショデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区小山西大野町', '26', '26101', '6038167', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '小山西大野町', 'コヤマニシオオノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区小山上初音町', '26', '26101', '6038171', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '小山上初音町', 'コヤマカミハツネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区小山初音町', '26', '26101', '6038172', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '小山初音町', 'コヤマハツネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区小山下初音町', '26', '26101', '6038173', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '小山下初音町', 'コヤマシモハツネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区紫野下柳町', '26', '26101', '6038174', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '紫野下柳町', 'ムラサキノシモヤナギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区紫野下鳥田町', '26', '26101', '6038175', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '紫野下鳥田町', 'ムラサキノシモトリダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区紫野上鳥田町', '26', '26101', '6038176', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '紫野上鳥田町', 'ムラサキノカミトリダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区紫野上柳町', '26', '26101', '6038177', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '紫野上柳町', 'ムラサキノカミヤナギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区紫竹下梅ノ木町', '26', '26101', '6038178', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '紫竹下梅ノ木町', 'シチクシモウメノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区紫竹上梅ノ木町', '26', '26101', '6038179', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '紫竹上梅ノ木町', 'シチクカミウメノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区紫竹桃ノ本町', '26', '26101', '6038201', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '紫竹桃ノ本町', 'シチクモモノモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区紫竹東桃ノ本町', '26', '26101', '6038202', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '紫竹東桃ノ本町', 'シチクヒガシモモノモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区紫竹東高縄町', '26', '26101', '6038203', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '紫竹東高縄町', 'シチクヒガシタカナワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区紫竹高縄町', '26', '26101', '6038204', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '紫竹高縄町', 'シチクタカナワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区紫竹西高縄町', '26', '26101', '6038205', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '紫竹西高縄町', 'シチクニシタカナワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区紫竹西南町', '26', '26101', '6038206', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '紫竹西南町', 'シチクセイナンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区紫竹牛若町', '26', '26101', '6038207', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '紫竹牛若町', 'シチクウシワカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区紫竹西桃ノ本町', '26', '26101', '6038208', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '紫竹西桃ノ本町', 'シチクニシモモノモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区紫野上石龍町', '26', '26101', '6038211', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '紫野上石龍町', 'ムラサキノカミセキリュウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区紫野石龍町', '26', '26101', '6038212', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '紫野石龍町', 'ムラサキノセキリュウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区紫野下石龍町', '26', '26101', '6038213', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '紫野下石龍町', 'ムラサキノシモセキリュウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区紫野雲林院町', '26', '26101', '6038214', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '紫野雲林院町', 'ムラサキノウンリンインチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区紫野下門前町', '26', '26101', '6038215', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '紫野下門前町', 'ムラサキノシモモンゼンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区紫野門前町', '26', '26101', '6038216', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '紫野門前町', 'ムラサキノモンゼンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区紫野上門前町', '26', '26101', '6038217', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '紫野上門前町', 'ムラサキノカミモンゼンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区紫野上築山町', '26', '26101', '6038221', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '紫野上築山町', 'ムラサキノカミツキヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区紫野下築山町', '26', '26101', '6038222', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '紫野下築山町', 'ムラサキノシモツキヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区紫野東藤ノ森町', '26', '26101', '6038223', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '紫野東藤ノ森町', 'ムラサキノヒガシフジノモリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区紫野西藤ノ森町', '26', '26101', '6038224', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '紫野西藤ノ森町', 'ムラサキノニシフジノモリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区紫野南舟岡町', '26', '26101', '6038225', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '紫野南舟岡町', 'ムラサキノミナミフナオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区紫野西舟岡町', '26', '26101', '6038226', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '紫野西舟岡町', 'ムラサキノニシフナオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区紫野北舟岡町', '26', '26101', '6038227', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '紫野北舟岡町', 'ムラサキノキタフナオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区紫野東舟岡町', '26', '26101', '6038228', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '紫野東舟岡町', 'ムラサキノヒガシフナオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区紫野大徳寺町', '26', '26101', '6038231', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '紫野大徳寺町', 'ムラサキノダイトクジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区紫野東野町', '26', '26101', '6038232', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '紫野東野町', 'ムラサキノヒガシノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区紫野西野町', '26', '26101', '6038233', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '紫野西野町', 'ムラサキノニシノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区紫野下若草町', '26', '26101', '6038234', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '紫野下若草町', 'ムラサキノシモワカクサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区紫野下御輿町', '26', '26101', '6038235', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '紫野下御輿町', 'ムラサキノシモミコシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区紫野上御輿町', '26', '26101', '6038236', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '紫野上御輿町', 'ムラサキノカミミコシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区紫野上若草町', '26', '26101', '6038237', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '紫野上若草町', 'ムラサキノカミワカクサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区紫野東泉堂町', '26', '26101', '6038241', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '紫野東泉堂町', 'ムラサキノヒガシセンドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区紫野上野町', '26', '26101', '6038242', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '紫野上野町', 'ムラサキノウエノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区紫野今宮町', '26', '26101', '6038243', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '紫野今宮町', 'ムラサキノイマミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区紫野東蓮台野町', '26', '26101', '6038244', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '紫野東蓮台野町', 'ムラサキノヒガシレンダイノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区紫野西蓮台野町', '26', '26101', '6038245', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '紫野西蓮台野町', 'ムラサキノニシレンダイノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区紫野西泉堂町', '26', '26101', '6038246', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '紫野西泉堂町', 'ムラサキノニシセンドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区紫野泉堂町', '26', '26101', '6038247', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '紫野泉堂町', 'ムラサキノセンドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区紫野北花ノ坊町', '26', '26101', '6038301', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '紫野北花ノ坊町', 'ムラサキノキタハナノボウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区紫野花ノ坊町', '26', '26101', '6038302', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '紫野花ノ坊町', 'ムラサキノハナノボウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区紫野十二坊町', '26', '26101', '6038303', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '紫野十二坊町', 'ムラサキノジュウニボウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区紫野郷ノ上町', '26', '26101', '6038304', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '紫野郷ノ上町', 'ムラサキノゴウノウエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区紫野南花ノ坊町', '26', '26101', '6038305', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '紫野南花ノ坊町', 'ムラサキノミナミハナノボウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区紫野上柏野町', '26', '26101', '6038311', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '紫野上柏野町', 'ムラサキノカミカシワノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区紫野中柏野町', '26', '26101', '6038312', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '紫野中柏野町', 'ムラサキノナカカシワノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区紫野下柏野町', '26', '26101', '6038313', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '紫野下柏野町', 'ムラサキノシモカシワノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区紫野西土居町', '26', '26101', '6038314', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '紫野西土居町', 'ムラサキノニシドイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区衣笠荒見町', '26', '26101', '6038315', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '衣笠荒見町', 'キヌガサアラミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区衣笠北荒見町', '26', '26101', '6038316', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '衣笠北荒見町', 'キヌガサキタアラミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区平野鳥居前町', '26', '26101', '6038321', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '平野鳥居前町', 'ヒラノトリイマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区平野宮本町', '26', '26101', '6038322', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '平野宮本町', 'ヒラノミヤモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区北野東紅梅町', '26', '26101', '6038323', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '北野東紅梅町', 'キタノヒガシコウバイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区北野紅梅町', '26', '26101', '6038324', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '北野紅梅町', 'キタノコウバイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区北野上白梅町', '26', '26101', '6038325', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '北野上白梅町', 'キタノカミハクバイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区北野下白梅町', '26', '26101', '6038326', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '北野下白梅町', 'キタノシモハクバイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区北野西白梅町', '26', '26101', '6038327', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '北野西白梅町', 'キタノニシハクバイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区大将軍西町', '26', '26101', '6038331', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '大将軍西町', 'タイショウグンニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区大将軍川端町', '26', '26101', '6038332', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '大将軍川端町', 'タイショウグンカワバタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区大将軍東鷹司町', '26', '26101', '6038333', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '大将軍東鷹司町', 'タイショウグンヒガシタカツカサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区大将軍西鷹司町', '26', '26101', '6038334', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '大将軍西鷹司町', 'タイショウグンニシタカツカサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区大将軍坂田町', '26', '26101', '6038335', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '大将軍坂田町', 'タイショウグンサカタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区大将軍一条町', '26', '26101', '6038336', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '大将軍一条町', 'タイショウグンイチジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区大将軍南一条町', '26', '26101', '6038337', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '大将軍南一条町', 'タイショウグンミナミイチジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区小松原北町', '26', '26101', '6038341', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '小松原北町', 'コマツバラキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区小松原南町', '26', '26101', '6038342', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '小松原南町', 'コマツバラミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区等持院東町', '26', '26101', '6038343', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '等持院東町', 'トウジインヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区等持院南町', '26', '26101', '6038344', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '等持院南町', 'トウジインミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区平野八丁柳町', '26', '26101', '6038345', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '平野八丁柳町', 'ヒラノハッチョウヤナギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区等持院北町', '26', '26101', '6038346', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '等持院北町', 'トウジインキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区等持院中町', '26', '26101', '6038347', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '等持院中町', 'トウジインナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区衣笠大祓町', '26', '26101', '6038351', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '衣笠大祓町', 'キヌガサオオハライチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区平野宮北町', '26', '26101', '6038352', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '平野宮北町', 'ヒラノミヤキタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区平野上八丁柳町', '26', '26101', '6038353', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '平野上八丁柳町', 'ヒラノカミハッチョウヤナギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区等持院西町', '26', '26101', '6038354', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '等持院西町', 'トウジインニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区平野上柳町', '26', '26101', '6038355', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '平野上柳町', 'ヒラノカミヤナギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区平野東柳町', '26', '26101', '6038356', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '平野東柳町', 'ヒラノヒガシヤナギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区平野宮西町', '26', '26101', '6038357', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '平野宮西町', 'ヒラノミヤニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区金閣寺町', '26', '26101', '6038361', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '金閣寺町', 'キンカクジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区衣笠馬場町', '26', '26101', '6038362', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '衣笠馬場町', 'キヌガサババチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区衣笠総門町', '26', '26101', '6038363', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '衣笠総門町', 'キヌガサソウモンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区平野桜木町', '26', '26101', '6038364', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '平野桜木町', 'ヒラノサクラギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区平野宮敷町', '26', '26101', '6038365', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '平野宮敷町', 'ヒラノミヤジキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区衣笠西馬場町', '26', '26101', '6038366', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '衣笠西馬場町', 'キヌガサニシババチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区衣笠東御所ノ内町', '26', '26101', '6038371', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '衣笠東御所ノ内町', 'キヌガサヒガシゴショノウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区衣笠街道町', '26', '26101', '6038372', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '衣笠街道町', 'キヌガサガイドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区衣笠北高橋町', '26', '26101', '6038373', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '衣笠北高橋町', 'キヌガサキタタカハシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区衣笠高橋町', '26', '26101', '6038374', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '衣笠高橋町', 'キヌガサタカハシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区衣笠天神森町', '26', '26101', '6038375', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '衣笠天神森町', 'キヌガサテンジンモリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区衣笠北天神森町', '26', '26101', '6038376', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '衣笠北天神森町', 'キヌガサキタテンジンモリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区衣笠西御所ノ内町', '26', '26101', '6038377', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '衣笠西御所ノ内町', 'キヌガサニシゴショノウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区衣笠御所ノ内町', '26', '26101', '6038378', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '衣笠御所ノ内町', 'キヌガサゴショノウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区大宮上ノ岸町', '26', '26101', '6038401', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '大宮上ノ岸町', 'オオミヤカミノキシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区大宮南椿原町', '26', '26101', '6038402', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '大宮南椿原町', 'オオミヤミナミツバキハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区大宮南林町', '26', '26101', '6038403', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '大宮南林町', 'オオミヤミナミバヤシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区大宮中林町', '26', '26101', '6038404', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '大宮中林町', 'オオミヤナカバヤシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区大宮西小野堀町', '26', '26101', '6038405', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '大宮西小野堀町', 'オオミヤニシオノボリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区大宮東小野堀町', '26', '26101', '6038406', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '大宮東小野堀町', 'オオミヤヒガシオノボリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区大宮北林町', '26', '26101', '6038407', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '大宮北林町', 'オオミヤキタバヤシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区大宮北椿原町', '26', '26101', '6038408', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '大宮北椿原町', 'オオミヤキタツバキハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区紫竹上竹殿町', '26', '26101', '6038411', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '紫竹上竹殿町', 'シチクカミタケドノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区紫竹下竹殿町', '26', '26101', '6038412', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '紫竹下竹殿町', 'シチクシモタケドノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区紫竹東大門町', '26', '26101', '6038413', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '紫竹東大門町', 'シチクヒガシダイモンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区紫竹大門町', '26', '26101', '6038414', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '紫竹大門町', 'シチクダイモンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区紫竹西大門町', '26', '26101', '6038415', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '紫竹西大門町', 'シチクニシダイモンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区紫竹北大門町', '26', '26101', '6038416', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '紫竹北大門町', 'シチクキタダイモンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区紫竹竹殿町', '26', '26101', '6038417', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '紫竹竹殿町', 'シチクタケドノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区紫竹上園生町', '26', '26101', '6038421', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '紫竹上園生町', 'シチクカミソノウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区紫竹下園生町', '26', '26101', '6038422', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '紫竹下園生町', 'シチクシモソノウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区紫竹上芝本町', '26', '26101', '6038423', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '紫竹上芝本町', 'シチクカミシバモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区紫竹下芝本町', '26', '26101', '6038424', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '紫竹下芝本町', 'シチクシモシバモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区紫竹下緑町', '26', '26101', '6038425', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '紫竹下緑町', 'シチクシモミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区紫竹西北町', '26', '26101', '6038426', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '紫竹西北町', 'シチクセイホクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区紫竹上緑町', '26', '26101', '6038427', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '紫竹上緑町', 'シチクカミミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区大宮東脇台町', '26', '26101', '6038431', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '大宮東脇台町', 'オオミヤヒガシワキダイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区大宮西脇台町', '26', '26101', '6038432', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '大宮西脇台町', 'オオミヤニシワキダイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区紫竹北栗栖町', '26', '26101', '6038433', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '紫竹北栗栖町', 'シチクキタクリスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区紫竹東栗栖町', '26', '26101', '6038434', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '紫竹東栗栖町', 'シチクヒガシクリスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区紫竹栗栖町', '26', '26101', '6038435', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '紫竹栗栖町', 'シチククリスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区紫竹西栗栖町', '26', '26101', '6038436', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '紫竹西栗栖町', 'シチクニシクリスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区大宮開町', '26', '26101', '6038437', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '大宮開町', 'オオミヤヒラキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区大宮土居町', '26', '26101', '6038441', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '大宮土居町', 'オオミヤドイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区紫竹西野山東町', '26', '26101', '6038442', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '紫竹西野山東町', 'シチクニシノヤマヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区紫竹西野山町', '26', '26101', '6038443', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '紫竹西野山町', 'シチクニシノヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区大宮西野山町', '26', '26101', '6038444', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '大宮西野山町', 'オオミヤニシノヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区鷹峯藤林町', '26', '26101', '6038445', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '鷹峯藤林町', 'タカガミネフジバヤシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区鷹峯上ノ町', '26', '26101', '6038446', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '鷹峯上ノ町', 'タカガミネカミノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区鷹峯木ノ畑町', '26', '26101', '6038447', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '鷹峯木ノ畑町', 'タカガミネキノハタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区鷹峯旧土居町', '26', '26101', '6038448', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '鷹峯旧土居町', 'タカガミネキュウドイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区衣笠鏡石町', '26', '26101', '6038451', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '衣笠鏡石町', 'キヌガサカガミイシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区衣笠開キ町', '26', '26101', '6038452', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '衣笠開キ町', 'キヌガサヒラキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区衣笠東開キ町', '26', '26101', '6038453', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '衣笠東開キ町', 'キヌガサヒガシヒラキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区衣笠西開キ町', '26', '26101', '6038454', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '衣笠西開キ町', 'キヌガサニシヒラキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区衣笠東尊上院町', '26', '26101', '6038455', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '衣笠東尊上院町', 'キヌガサヒガシソンジョウインチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区衣笠西尊上院町', '26', '26101', '6038456', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '衣笠西尊上院町', 'キヌガサニシソンジョウインチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区大北山不動山町', '26', '26101', '6038457', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '大北山不動山町', 'オオキタヤマフドウサンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区大宮玄琢北東町', '26', '26101', '6038461', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '大宮玄琢北東町', 'オオミヤゲンタクキタヒガシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区大宮玄琢北町', '26', '26101', '6038462', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '大宮玄琢北町', 'オオミヤゲンタクキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区大宮玄琢南町', '26', '26101', '6038463', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '大宮玄琢南町', 'オオミヤゲンタクミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区鷹峯黒門町', '26', '26101', '6038464', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '鷹峯黒門町', 'タカガミネクロモンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区鷹峯土天井町', '26', '26101', '6038465', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '鷹峯土天井町', 'タカガミネツチテンジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区鷹峯光悦町', '26', '26101', '6038466', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '鷹峯光悦町', 'タカガミネコウエツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区鷹峯南鷹峯町', '26', '26101', '6038467', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '鷹峯南鷹峯町', 'タカガミネミナミタカガミネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区鷹峯北鷹峯町', '26', '26101', '6038468', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '鷹峯北鷹峯町', 'タカガミネキタタカガミネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区鷹峯千束町', '26', '26101', '6038469', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '鷹峯千束町', 'タカガミネセンゾクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区大宮西山ノ前町', '26', '26101', '6038471', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '大宮西山ノ前町', 'オオミヤニシヤマノマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区大宮北山ノ前町', '26', '26101', '6038472', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '大宮北山ノ前町', 'オオミヤキタヤマノマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区大宮南山ノ前町', '26', '26101', '6038473', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '大宮南山ノ前町', 'オオミヤミナミヤマノマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区大宮薬師山東町', '26', '26101', '6038474', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '大宮薬師山東町', 'オオミヤヤクシヤマヒガシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区大宮北箱ノ井町', '26', '26101', '6038475', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '大宮北箱ノ井町', 'オオミヤキタハコノイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区大宮南箱ノ井町', '26', '26101', '6038476', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '大宮南箱ノ井町', 'オオミヤミナミハコノイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区大宮一ノ井町', '26', '26101', '6038477', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '大宮一ノ井町', 'オオミヤイチノイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区大宮釈迦谷', '26', '26101', '6038478', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '大宮釈迦谷', 'オオミヤシャカダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区大宮薬師山西町', '26', '26101', '6038479', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '大宮薬師山西町', 'オオミヤヤクシヤマニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区大北山鏡石町', '26', '26101', '6038481', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '大北山鏡石町', 'オオキタヤマカガミイシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区大北山天神岡町', '26', '26101', '6038482', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '大北山天神岡町', 'オオキタヤマテンジンオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区大北山蓮ケ谷町', '26', '26101', '6038483', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '大北山蓮ケ谷町', 'オオキタヤマハスガダニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区衣笠氷室町', '26', '26101', '6038484', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '衣笠氷室町', 'キヌガサヒムロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区衣笠衣笠山町', '26', '26101', '6038485', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '衣笠衣笠山町', 'キヌガサキヌガサヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区衣笠赤阪町', '26', '26101', '6038486', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '衣笠赤阪町', 'キヌガサアカサカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区大北山原谷乾町', '26', '26101', '6038487', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '大北山原谷乾町', 'オオキタヤマハラダニイヌイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区大北山長谷町', '26', '26101', '6038488', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '大北山長谷町', 'オオキタヤマハセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区鷹峯仏谷', '26', '26101', '6038491', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '鷹峯仏谷', 'タカガミネホトケダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区鷹峯堂ノ庭町', '26', '26101', '6038492', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '鷹峯堂ノ庭町', 'タカガミネドウノニワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区鷹峯大谷町', '26', '26101', '6038493', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '鷹峯大谷町', 'タカガミネオオタニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区鷹峯堀越町', '26', '26101', '6038494', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '鷹峯堀越町', 'タカガミネホリコシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区西賀茂下庄田町', '26', '26101', '6038801', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '西賀茂下庄田町', 'ニシガモシモショウダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区西賀茂上庄田町', '26', '26101', '6038802', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '西賀茂上庄田町', 'ニシガモカミショウダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区西賀茂樋ノ口町', '26', '26101', '6038803', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '西賀茂樋ノ口町', 'ニシガモヒノクチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区西賀茂井ノ口町', '26', '26101', '6038804', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '西賀茂井ノ口町', 'ニシガモイノクチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区西賀茂蟹ケ坂町', '26', '26101', '6038805', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '西賀茂蟹ケ坂町', 'ニシガモカニガサカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区西賀茂円峰', '26', '26101', '6038806', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '西賀茂円峰', 'ニシガモマルミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区西賀茂蛙ケ谷', '26', '26101', '6038807', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '西賀茂蛙ケ谷', 'ニシガモカエルガタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区西賀茂北山ノ森町', '26', '26101', '6038811', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '西賀茂北山ノ森町', 'ニシガモキタヤマノモリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区西賀茂山ノ森町', '26', '26101', '6038812', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '西賀茂山ノ森町', 'ニシガモヤマノモリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区西賀茂大道口町', '26', '26101', '6038813', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '西賀茂大道口町', 'ニシガモオオドグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区西賀茂南川上町', '26', '26101', '6038814', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '西賀茂南川上町', 'ニシガモミナミカワカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区西賀茂中川上町', '26', '26101', '6038815', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '西賀茂中川上町', 'ニシガモナカカワカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区西賀茂北川上町', '26', '26101', '6038816', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '西賀茂北川上町', 'ニシガモキタカワカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区西賀茂川上町', '26', '26101', '6038817', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '西賀茂川上町', 'ニシガモカワカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区西賀茂柿ノ木町', '26', '26101', '6038821', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '西賀茂柿ノ木町', 'ニシガモカキノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区西賀茂鹿ノ下町', '26', '26101', '6038822', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '西賀茂鹿ノ下町', 'ニシガモカノシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区西賀茂榿ノ木町', '26', '26101', '6038823', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '西賀茂榿ノ木町', 'ニシガモハリノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区西賀茂南大栗町', '26', '26101', '6038824', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '西賀茂南大栗町', 'ニシガモミナミオオクリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区西賀茂丸川町', '26', '26101', '6038825', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '西賀茂丸川町', 'ニシガモマルカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区西賀茂坊ノ後町', '26', '26101', '6038826', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '西賀茂坊ノ後町', 'ニシガモボウノウシロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区西賀茂水垣町', '26', '26101', '6038827', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '西賀茂水垣町', 'ニシガモミズガキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区西賀茂大栗町', '26', '26101', '6038828', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '西賀茂大栗町', 'ニシガモオオクリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区大宮北ノ岸町', '26', '26101', '6038831', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '大宮北ノ岸町', 'オオミヤキタノキシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区大宮南田尻町', '26', '26101', '6038832', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '大宮南田尻町', 'オオミヤミナミタジリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区大宮東総門口町', '26', '26101', '6038833', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '大宮東総門口町', 'オオミヤヒガシソウモングチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区大宮中総門口町', '26', '26101', '6038834', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '大宮中総門口町', 'オオミヤナカソウモングチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区大宮西総門口町', '26', '26101', '6038835', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '大宮西総門口町', 'オオミヤニシソウモングチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区西賀茂神光院町', '26', '26101', '6038836', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '西賀茂神光院町', 'ニシガモジンコウインチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区大宮中ノ社町', '26', '26101', '6038837', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '大宮中ノ社町', 'オオミヤナカノヤシロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区大宮田尻町', '26', '26101', '6038838', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '大宮田尻町', 'オオミヤタジリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区西賀茂北今原町', '26', '26101', '6038841', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '西賀茂北今原町', 'ニシガモキタイマハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区西賀茂今原町', '26', '26101', '6038842', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '西賀茂今原町', 'ニシガモイマハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区西賀茂南今原町', '26', '26101', '6038843', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '西賀茂南今原町', 'ニシガモミナミイマハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区西賀茂大深町', '26', '26101', '6038844', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '西賀茂大深町', 'ニシガモオオブケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区西賀茂角社町', '26', '26101', '6038845', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '西賀茂角社町', 'ニシガモスミヤシロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区西賀茂鎮守菴町', '26', '26101', '6038846', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '西賀茂鎮守菴町', 'ニシガモチンジュアンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区西賀茂北鎮守菴町', '26', '26101', '6038847', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '西賀茂北鎮守菴町', 'ニシガモキタチンジュアンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区西賀茂船山', '26', '26101', '6038848', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '西賀茂船山', 'ニシガモフネヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区西賀茂鑓磨岩', '26', '26101', '6038851', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '西賀茂鑓磨岩', 'ニシガモヤリトギイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区西賀茂笠松', '26', '26101', '6038852', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '西賀茂笠松', 'ニシガモカサマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区西賀茂城山', '26', '26101', '6038853', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '西賀茂城山', 'ニシガモシロヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区西賀茂西氷室町', '26', '26101', '6038854', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '西賀茂西氷室町', 'ニシガモニシヒムロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区西賀茂氷室町', '26', '26101', '6038855', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '西賀茂氷室町', 'ニシガモヒムロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区西賀茂蓬来谷', '26', '26101', '6038856', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '西賀茂蓬来谷', 'ニシガモホウライダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区雲ケ畑出谷町', '26', '26101', '6038861', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '雲ケ畑出谷町', 'クモガハタデタニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区雲ケ畑中津川町', '26', '26101', '6038862', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '雲ケ畑中津川町', 'クモガハタナカツガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市北区雲ケ畑中畑町', '26', '26101', '6038863', '京都府', 'キョウトフ', '京都市北区', 'キョウトシキタク', '雲ケ畑中畑町', 'クモガハタナカハタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区', '26', '26104', '6040000', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('67474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区道場町', '26', '26104', '6040001', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '道場町', 'ドウジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区鏡屋町', '26', '26104', '6040002', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '鏡屋町', 'カガミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区花立町', '26', '26104', '6040003', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '花立町', 'ハナタテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区相生町', '26', '26104', '6040004', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '相生町', 'アイオイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区玉植町', '26', '26104', '6040005', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '玉植町', 'タマウエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区冷泉町', '26', '26104', '6040011', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '冷泉町', 'レイセンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区竪大恩寺町', '26', '26104', '6040012', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '竪大恩寺町', 'タテダイオンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区二条新町', '26', '26104', '6040013', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '二条新町', 'ニジョウシンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区大黒町釜座通夷川下る', '26', '26104', '6040014', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '大黒町', 'ダイコクチョウ', null, '釜座通夷川下る', null, null);
INSERT INTO `ms_addresses` VALUES ('67483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区大黒町釜座通二条上る', '26', '26104', '6040014', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '大黒町', 'ダイコクチョウ', null, '釜座通二条上る', null, null);
INSERT INTO `ms_addresses` VALUES ('67484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区大黒町夷川通釜座東入', '26', '26104', '6040014', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '大黒町', 'ダイコクチョウ', null, '夷川通釜座東入', null, null);
INSERT INTO `ms_addresses` VALUES ('67485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区大黒町夷川通釜座西入', '26', '26104', '6040014', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '大黒町', 'ダイコクチョウ', null, '夷川通釜座西入', null, null);
INSERT INTO `ms_addresses` VALUES ('67486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区泉町', '26', '26104', '6040015', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '泉町', 'イズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区蛸薬師町', '26', '26104', '6040021', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '蛸薬師町', 'タコヤクシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区御池之町', '26', '26104', '6040022', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '御池之町', 'オイケノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区西横町', '26', '26104', '6040023', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '西横町', 'ニシヨコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区下妙覚寺町', '26', '26104', '6040024', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '下妙覚寺町', 'シモミョウカクジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区上妙覚寺町', '26', '26104', '6040025', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '上妙覚寺町', 'カミミョウカクジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区大恩寺町', '26', '26104', '6040026', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '大恩寺町', 'ダイオンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区頭町', '26', '26104', '6040031', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '頭町', 'カシラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区中之町新町通御池上る', '26', '26104', '6040032', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '中之町', 'ナカノチョウ', null, '新町通御池上る', null, null);
INSERT INTO `ms_addresses` VALUES ('67495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区中之町新町通押小路下る', '26', '26104', '6040032', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '中之町', 'ナカノチョウ', null, '新町通押小路下る', null, null);
INSERT INTO `ms_addresses` VALUES ('67496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区橋之町', '26', '26104', '6040033', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '橋之町', 'ハシノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区下松屋町', '26', '26104', '6040034', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '下松屋町', 'シモマツヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区上松屋町', '26', '26104', '6040035', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '上松屋町', 'カミマツヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区正行寺町', '26', '26104', '6040036', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '正行寺町', 'ショウギョウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区二条西洞院町', '26', '26104', '6040041', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '二条西洞院町', 'ニジョウニシノトウインチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区押西洞院町', '26', '26104', '6040042', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '押西洞院町', 'オシニシノトウインチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区石橋町御池通小川西入', '26', '26104', '6040043', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '石橋町', 'イシバシチョウ', null, '御池通小川西入', null, null);
INSERT INTO `ms_addresses` VALUES ('67503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区石橋町御池通小川東入', '26', '26104', '6040043', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '石橋町', 'イシバシチョウ', null, '御池通小川東入', null, null);
INSERT INTO `ms_addresses` VALUES ('67504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区石橋町御池通西洞院西入', '26', '26104', '6040043', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '石橋町', 'イシバシチョウ', null, '御池通西洞院西入', null, null);
INSERT INTO `ms_addresses` VALUES ('67505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区石橋町御池通油小路東入', '26', '26104', '6040043', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '石橋町', 'イシバシチョウ', null, '御池通油小路東入', null, null);
INSERT INTO `ms_addresses` VALUES ('67506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区石橋町小川通御池下る', '26', '26104', '6040043', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '石橋町', 'イシバシチョウ', null, '小川通御池下る', null, null);
INSERT INTO `ms_addresses` VALUES ('67507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区下古城町', '26', '26104', '6040044', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '下古城町', 'シモフルシロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区古城町', '26', '26104', '6040045', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '古城町', 'フルシロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区二条油小路町', '26', '26104', '6040051', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '二条油小路町', 'ニジョウアブラノコウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区押油小路町', '26', '26104', '6040052', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '押油小路町', 'オシアブラノコウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区森ノ木町', '26', '26104', '6040053', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '森ノ木町', 'モリノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区押堀町', '26', '26104', '6040054', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '押堀町', 'オシボリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区土橋町', '26', '26104', '6040055', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '土橋町', 'ツチバシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区槌屋町小川通夷川下る', '26', '26104', '6040061', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '槌屋町', 'ツチヤチョウ', null, '小川通夷川下る', null, null);
INSERT INTO `ms_addresses` VALUES ('67515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区槌屋町小川通二条上る', '26', '26104', '6040061', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '槌屋町', 'ツチヤチョウ', null, '小川通二条上る', null, null);
INSERT INTO `ms_addresses` VALUES ('67516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区薬師町', '26', '26104', '6040062', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '薬師町', 'ヤクシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区西大黒町', '26', '26104', '6040063', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '西大黒町', 'ニシダイコクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区矢幡町', '26', '26104', '6040064', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '矢幡町', 'ヤワタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区九町目', '26', '26104', '6040065', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '九町目', 'キュウチョウメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区薬屋町', '26', '26104', '6040066', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '薬屋町', 'クスリヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区大文字町丸太町通堀川東入', '26', '26104', '6040071', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '大文字町', 'ダイモンジチョウ', null, '丸太町通堀川東入', null, null);
INSERT INTO `ms_addresses` VALUES ('67522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区大文字町丸太町通油小路西入', '26', '26104', '6040071', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '大文字町', 'ダイモンジチョウ', null, '丸太町通油小路西入', null, null);
INSERT INTO `ms_addresses` VALUES ('67523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区大文字町丸太町通油小路東入', '26', '26104', '6040071', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '大文字町', 'ダイモンジチョウ', null, '丸太町通油小路東入', null, null);
INSERT INTO `ms_addresses` VALUES ('67524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区大文字町丸太町通小川西入', '26', '26104', '6040071', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '大文字町', 'ダイモンジチョウ', null, '丸太町通小川西入', null, null);
INSERT INTO `ms_addresses` VALUES ('67525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区大文字町油小路通竹屋町上る', '26', '26104', '6040071', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '大文字町', 'ダイモンジチョウ', null, '油小路通竹屋町上る', null, null);
INSERT INTO `ms_addresses` VALUES ('67526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区大文字町竹屋町通油小路東入', '26', '26104', '6040071', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '大文字町', 'ダイモンジチョウ', null, '竹屋町通油小路東入', null, null);
INSERT INTO `ms_addresses` VALUES ('67527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区橋本町', '26', '26104', '6040072', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '橋本町', 'ハシモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区西夷川町', '26', '26104', '6040073', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '西夷川町', 'ニシエビスガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区八町目', '26', '26104', '6040074', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '八町目', 'ハチチョウメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区西竹屋町', '26', '26104', '6040075', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '西竹屋町', 'ニシタケヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区七町目', '26', '26104', '6040076', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '七町目', 'ナナチョウメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区丸太町', '26', '26104', '6040077', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '丸太町', 'マルタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区田中町', '26', '26104', '6040081', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '田中町', 'タナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区毘沙門町西洞院通竹屋町下る', '26', '26104', '6040082', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '毘沙門町', 'ビシャモンチョウ', null, '西洞院通竹屋町下る', null, null);
INSERT INTO `ms_addresses` VALUES ('67535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区毘沙門町西洞院通夷川上る', '26', '26104', '6040082', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '毘沙門町', 'ビシャモンチョウ', null, '西洞院通夷川上る', null, null);
INSERT INTO `ms_addresses` VALUES ('67536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区毘沙門町竹屋町通西洞院西入', '26', '26104', '6040082', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '毘沙門町', 'ビシャモンチョウ', null, '竹屋町通西洞院西入', null, null);
INSERT INTO `ms_addresses` VALUES ('67537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区毘沙門町竹屋町通西洞院東入', '26', '26104', '6040082', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '毘沙門町', 'ビシャモンチョウ', null, '竹屋町通西洞院東入', null, null);
INSERT INTO `ms_addresses` VALUES ('67538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区毘沙門町夷川通西洞院東入', '26', '26104', '6040082', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '毘沙門町', 'ビシャモンチョウ', null, '夷川通西洞院東入', null, null);
INSERT INTO `ms_addresses` VALUES ('67539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区東夷川町', '26', '26104', '6040083', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '東夷川町', 'ヒガシエビスガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区下丸屋町小川通夷川下る', '26', '26104', '6040084', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '下丸屋町', 'シモマルヤチョウ', null, '小川通夷川下る', null, null);
INSERT INTO `ms_addresses` VALUES ('67541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区下丸屋町小川通夷川上る', '26', '26104', '6040084', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '下丸屋町', 'シモマルヤチョウ', null, '小川通夷川上る', null, null);
INSERT INTO `ms_addresses` VALUES ('67542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区東竹屋町', '26', '26104', '6040085', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '東竹屋町', 'ヒガシタケヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区中之町小川通丸太町下る', '26', '26104', '6040086', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '中之町', 'ナカノチョウ', null, '小川通丸太町下る', null, null);
INSERT INTO `ms_addresses` VALUES ('67544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区中之町小川通竹屋町上る', '26', '26104', '6040086', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '中之町', 'ナカノチョウ', null, '小川通竹屋町上る', null, null);
INSERT INTO `ms_addresses` VALUES ('67545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区横鍛冶町', '26', '26104', '6040087', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '横鍛冶町', 'ヨコカジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区梅屋町丸太町通釜座西入', '26', '26104', '6040091', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '梅屋町', 'ウメヤチョウ', null, '丸太町通釜座西入', null, null);
INSERT INTO `ms_addresses` VALUES ('67547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区梅屋町丸太町通釜座東入', '26', '26104', '6040091', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '梅屋町', 'ウメヤチョウ', null, '丸太町通釜座東入', null, null);
INSERT INTO `ms_addresses` VALUES ('67548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区梅屋町丸太町通新町西入', '26', '26104', '6040091', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '梅屋町', 'ウメヤチョウ', null, '丸太町通新町西入', null, null);
INSERT INTO `ms_addresses` VALUES ('67549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区梅屋町丸太町通西洞院東入', '26', '26104', '6040091', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '梅屋町', 'ウメヤチョウ', null, '丸太町通西洞院東入', null, null);
INSERT INTO `ms_addresses` VALUES ('67550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区梅屋町釜座通丸太町上る', '26', '26104', '6040091', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '梅屋町', 'ウメヤチョウ', null, '釜座通丸太町上る', null, null);
INSERT INTO `ms_addresses` VALUES ('67551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区大炊町新町通丸太町下る', '26', '26104', '6040092', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '大炊町', 'オオイチョウ', null, '新町通丸太町下る', null, null);
INSERT INTO `ms_addresses` VALUES ('67552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区大炊町新町通竹屋町上る', '26', '26104', '6040092', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '大炊町', 'オオイチョウ', null, '新町通竹屋町上る', null, null);
INSERT INTO `ms_addresses` VALUES ('67553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区大炊町丸太町通新町西入', '26', '26104', '6040092', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '大炊町', 'オオイチョウ', null, '丸太町通新町西入', null, null);
INSERT INTO `ms_addresses` VALUES ('67554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区大炊町丸太町通新町東入', '26', '26104', '6040092', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '大炊町', 'オオイチョウ', null, '丸太町通新町東入', null, null);
INSERT INTO `ms_addresses` VALUES ('67555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区大炊町竹屋町通新町西入', '26', '26104', '6040092', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '大炊町', 'オオイチョウ', null, '竹屋町通新町西入', null, null);
INSERT INTO `ms_addresses` VALUES ('67556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区大炊町竹屋町通新町東入', '26', '26104', '6040092', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '大炊町', 'オオイチョウ', null, '竹屋町通新町東入', null, null);
INSERT INTO `ms_addresses` VALUES ('67557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区弁財天町', '26', '26104', '6040093', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '弁財天町', 'ベンザイテンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区亀屋町釜座通竹屋町下る', '26', '26104', '6040094', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '亀屋町', 'カメヤチョウ', null, '釜座通竹屋町下る', null, null);
INSERT INTO `ms_addresses` VALUES ('67559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区亀屋町釜座通夷川上る', '26', '26104', '6040094', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '亀屋町', 'カメヤチョウ', null, '釜座通夷川上る', null, null);
INSERT INTO `ms_addresses` VALUES ('67560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区亀屋町夷川通釜座西入', '26', '26104', '6040094', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '亀屋町', 'カメヤチョウ', null, '夷川通釜座西入', null, null);
INSERT INTO `ms_addresses` VALUES ('67561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区亀屋町夷川通釜座東入', '26', '26104', '6040094', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '亀屋町', 'カメヤチョウ', null, '夷川通釜座東入', null, null);
INSERT INTO `ms_addresses` VALUES ('67562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区亀屋町夷川通西洞院東入', '26', '26104', '6040094', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '亀屋町', 'カメヤチョウ', null, '夷川通西洞院東入', null, null);
INSERT INTO `ms_addresses` VALUES ('67563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区亀屋町夷川通新町西入', '26', '26104', '6040094', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '亀屋町', 'カメヤチョウ', null, '夷川通新町西入', null, null);
INSERT INTO `ms_addresses` VALUES ('67564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区指物屋町', '26', '26104', '6040095', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '指物屋町', 'サシモノヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区桝屋町釜座通丸太町下る', '26', '26104', '6040096', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '桝屋町', 'マスヤチョウ', null, '釜座通丸太町下る', null, null);
INSERT INTO `ms_addresses` VALUES ('67566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区桝屋町釜座通竹屋町上る', '26', '26104', '6040096', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '桝屋町', 'マスヤチョウ', null, '釜座通竹屋町上る', null, null);
INSERT INTO `ms_addresses` VALUES ('67567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区鍵屋町丸太町通堺町東入', '26', '26104', '6040801', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '鍵屋町', 'カギヤチョウ', null, '丸太町通堺町東入', null, null);
INSERT INTO `ms_addresses` VALUES ('67568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区鍵屋町丸太町通堺町西入', '26', '26104', '6040801', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '鍵屋町', 'カギヤチョウ', null, '丸太町通堺町西入', null, null);
INSERT INTO `ms_addresses` VALUES ('67569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区鍵屋町丸太町通柳馬場東入', '26', '26104', '6040801', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '鍵屋町', 'カギヤチョウ', null, '丸太町通柳馬場東入', null, null);
INSERT INTO `ms_addresses` VALUES ('67570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区鍵屋町丸太町通高倉東入', '26', '26104', '6040801', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '鍵屋町', 'カギヤチョウ', null, '丸太町通高倉東入', null, null);
INSERT INTO `ms_addresses` VALUES ('67571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区橘町堺町通丸太町下る', '26', '26104', '6040802', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '橘町', 'タチバナチョウ', null, '堺町通丸太町下る', null, null);
INSERT INTO `ms_addresses` VALUES ('67572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区橘町堺町通竹屋町上る', '26', '26104', '6040802', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '橘町', 'タチバナチョウ', null, '堺町通竹屋町上る', null, null);
INSERT INTO `ms_addresses` VALUES ('67573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区橘町竹屋町通堺町西入', '26', '26104', '6040802', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '橘町', 'タチバナチョウ', null, '竹屋町通堺町西入', null, null);
INSERT INTO `ms_addresses` VALUES ('67574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区橘町竹屋町通堺町東入', '26', '26104', '6040802', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '橘町', 'タチバナチョウ', null, '竹屋町通堺町東入', null, null);
INSERT INTO `ms_addresses` VALUES ('67575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区和久屋町竹屋町通柳馬場西入', '26', '26104', '6040803', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '和久屋町', 'ワクヤチョウ', null, '竹屋町通柳馬場西入', null, null);
INSERT INTO `ms_addresses` VALUES ('67576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区和久屋町竹屋町通堺町東入', '26', '26104', '6040803', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '和久屋町', 'ワクヤチョウ', null, '竹屋町通堺町東入', null, null);
INSERT INTO `ms_addresses` VALUES ('67577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区和久屋町竹屋町通堺町西入', '26', '26104', '6040803', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '和久屋町', 'ワクヤチョウ', null, '竹屋町通堺町西入', null, null);
INSERT INTO `ms_addresses` VALUES ('67578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区和久屋町竹屋町通高倉東入', '26', '26104', '6040803', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '和久屋町', 'ワクヤチョウ', null, '竹屋町通高倉東入', null, null);
INSERT INTO `ms_addresses` VALUES ('67579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区絹屋町', '26', '26104', '6040804', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '絹屋町', 'キヌヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区百足屋町夷川通柳馬場西入', '26', '26104', '6040805', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '百足屋町', 'ムカデヤチョウ', null, '夷川通柳馬場西入', null, null);
INSERT INTO `ms_addresses` VALUES ('67581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区百足屋町夷川通堺町東入', '26', '26104', '6040805', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '百足屋町', 'ムカデヤチョウ', null, '夷川通堺町東入', null, null);
INSERT INTO `ms_addresses` VALUES ('67582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区百足屋町夷川通堺町西入', '26', '26104', '6040805', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '百足屋町', 'ムカデヤチョウ', null, '夷川通堺町西入', null, null);
INSERT INTO `ms_addresses` VALUES ('67583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区百足屋町夷川通高倉東入', '26', '26104', '6040805', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '百足屋町', 'ムカデヤチョウ', null, '夷川通高倉東入', null, null);
INSERT INTO `ms_addresses` VALUES ('67584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区亀屋町堺町通夷川下る', '26', '26104', '6040811', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '亀屋町', 'カメヤチョウ', null, '堺町通夷川下る', null, null);
INSERT INTO `ms_addresses` VALUES ('67585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区亀屋町堺町通二条上る', '26', '26104', '6040811', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '亀屋町', 'カメヤチョウ', null, '堺町通二条上る', null, null);
INSERT INTO `ms_addresses` VALUES ('67586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区亀屋町夷川通堺町西入', '26', '26104', '6040811', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '亀屋町', 'カメヤチョウ', null, '夷川通堺町西入', null, null);
INSERT INTO `ms_addresses` VALUES ('67587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区亀屋町夷川通堺町東入', '26', '26104', '6040811', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '亀屋町', 'カメヤチョウ', null, '夷川通堺町東入', null, null);
INSERT INTO `ms_addresses` VALUES ('67588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区天守町', '26', '26104', '6040812', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '天守町', 'テンシュチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区夷町', '26', '26104', '6040813', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '夷町', 'エビスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区壺屋町東洞院通夷川下る', '26', '26104', '6040814', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '壺屋町', 'ツボヤチョウ', null, '東洞院通夷川下る', null, null);
INSERT INTO `ms_addresses` VALUES ('67591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区壺屋町東洞院通二条上る', '26', '26104', '6040814', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '壺屋町', 'ツボヤチョウ', null, '東洞院通二条上る', null, null);
INSERT INTO `ms_addresses` VALUES ('67592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区壺屋町夷川通東洞院西入', '26', '26104', '6040814', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '壺屋町', 'ツボヤチョウ', null, '夷川通東洞院西入', null, null);
INSERT INTO `ms_addresses` VALUES ('67593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区壺屋町夷川通東洞院東入', '26', '26104', '6040814', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '壺屋町', 'ツボヤチョウ', null, '夷川通東洞院東入', null, null);
INSERT INTO `ms_addresses` VALUES ('67594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区山中町', '26', '26104', '6040815', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '山中町', 'ヤマナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区観音町', '26', '26104', '6040821', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '観音町', 'カンノンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区杉屋町', '26', '26104', '6040822', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '杉屋町', 'スギヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区竹屋町', '26', '26104', '6040823', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '竹屋町', 'タケヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区扇屋町', '26', '26104', '6040824', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '扇屋町', 'オウギヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区御所八幡町', '26', '26104', '6040825', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '御所八幡町', 'ゴショハチマンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区柊町', '26', '26104', '6040826', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '柊町', 'ヒイラギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区瓦町', '26', '26104', '6040827', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '瓦町', 'カワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区松屋町', '26', '26104', '6040831', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '松屋町', 'マツヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区鍵屋町間之町通二条下る', '26', '26104', '6040832', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '鍵屋町', 'カギヤチョウ', null, '間之町通二条下る', null, null);
INSERT INTO `ms_addresses` VALUES ('67604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区鍵屋町間之町通押小路上る', '26', '26104', '6040832', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '鍵屋町', 'カギヤチョウ', null, '間之町通押小路上る', null, null);
INSERT INTO `ms_addresses` VALUES ('67605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区左京町', '26', '26104', '6040833', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '左京町', 'サキョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区高田町', '26', '26104', '6040834', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '高田町', 'タカダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区高宮町御池通高倉西入', '26', '26104', '6040835', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '高宮町', 'タカミヤチョウ', null, '御池通高倉西入', null, null);
INSERT INTO `ms_addresses` VALUES ('67608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区高宮町御池通東洞院東入', '26', '26104', '6040835', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '高宮町', 'タカミヤチョウ', null, '御池通東洞院東入', null, null);
INSERT INTO `ms_addresses` VALUES ('67609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区高宮町御池通間之町東入', '26', '26104', '6040835', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '高宮町', 'タカミヤチョウ', null, '御池通間之町東入', null, null);
INSERT INTO `ms_addresses` VALUES ('67610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区高宮町御池通間之町西入', '26', '26104', '6040835', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '高宮町', 'タカミヤチョウ', null, '御池通間之町西入', null, null);
INSERT INTO `ms_addresses` VALUES ('67611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区船屋町東洞院通押小路下る', '26', '26104', '6040836', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '船屋町', 'フナヤチョウ', null, '東洞院通押小路下る', null, null);
INSERT INTO `ms_addresses` VALUES ('67612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区船屋町東洞院通御池上る', '26', '26104', '6040836', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '船屋町', 'フナヤチョウ', null, '東洞院通御池上る', null, null);
INSERT INTO `ms_addresses` VALUES ('67613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区船屋町押小路通東洞院西入', '26', '26104', '6040836', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '船屋町', 'フナヤチョウ', null, '押小路通東洞院西入', null, null);
INSERT INTO `ms_addresses` VALUES ('67614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区船屋町押小路通東洞院東入', '26', '26104', '6040836', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '船屋町', 'フナヤチョウ', null, '押小路通東洞院東入', null, null);
INSERT INTO `ms_addresses` VALUES ('67615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区瓦之町', '26', '26104', '6040837', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '瓦之町', 'カワラノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区仁王門突抜町', '26', '26104', '6040841', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '仁王門突抜町', 'ニオウモンツキヌケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区西押小路町', '26', '26104', '6040842', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '西押小路町', 'ニシオシコウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区塗師屋町', '26', '26104', '6040843', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '塗師屋町', 'ヌシヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区仲保利町', '26', '26104', '6040844', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '仲保利町', 'ナカホリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区二条殿町', '26', '26104', '6040845', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '二条殿町', 'ニジョウデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区金吹町', '26', '26104', '6040846', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '金吹町', 'キンブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区秋野々町', '26', '26104', '6040847', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '秋野々町', 'アキノノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区西九軒町', '26', '26104', '6040851', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '西九軒町', 'ニシキュウケンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区東九軒町', '26', '26104', '6040852', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '東九軒町', 'ヒガシキュウケンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区真如堂町', '26', '26104', '6040853', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '真如堂町', 'シンニョドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区仁王門町', '26', '26104', '6040854', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '仁王門町', 'ニオウモンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区東玉屋町', '26', '26104', '6040855', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '東玉屋町', 'ヒガシタマヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区北小路町', '26', '26104', '6040856', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '北小路町', 'キタコウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区蒔絵屋町', '26', '26104', '6040857', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '蒔絵屋町', 'マキエヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区大倉町', '26', '26104', '6040861', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '大倉町', 'オオクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区少将井町', '26', '26104', '6040862', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '少将井町', 'ショウショウイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区巴町', '26', '26104', '6040863', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '巴町', 'トモエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区松竹町', '26', '26104', '6040864', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '松竹町', 'ショウチクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区亀屋町竹屋町通烏丸西入', '26', '26104', '6040865', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '亀屋町', 'カメヤチョウ', null, '竹屋町通烏丸西入', null, null);
INSERT INTO `ms_addresses` VALUES ('67635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区亀屋町竹屋町通両替町東入', '26', '26104', '6040865', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '亀屋町', 'カメヤチョウ', null, '竹屋町通両替町東入', null, null);
INSERT INTO `ms_addresses` VALUES ('67636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区亀屋町竹屋町通両替町西入', '26', '26104', '6040865', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '亀屋町', 'カメヤチョウ', null, '竹屋町通両替町西入', null, null);
INSERT INTO `ms_addresses` VALUES ('67637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区亀屋町竹屋町通室町東入', '26', '26104', '6040865', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '亀屋町', 'カメヤチョウ', null, '竹屋町通室町東入', null, null);
INSERT INTO `ms_addresses` VALUES ('67638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区亀屋町両替町通室町下る', '26', '26104', '6040865', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '亀屋町', 'カメヤチョウ', null, '両替町通室町下る', null, null);
INSERT INTO `ms_addresses` VALUES ('67639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区西方寺町', '26', '26104', '6040866', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '西方寺町', 'サイホウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区常真横町', '26', '26104', '6040867', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '常真横町', 'ジョウシンヨコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区三本木町', '26', '26104', '6040871', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '三本木町', 'サンボンギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区三本木五丁目', '26', '26104', '6040872', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '三本木五丁目', 'サンボンギゴチョウメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区少将井御旅町', '26', '26104', '6040873', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '少将井御旅町', 'ショウショウイオタビチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区清水町竹屋町通烏丸東入', '26', '26104', '6040874', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '清水町', 'シミズチョウ', null, '竹屋町通烏丸東入', null, null);
INSERT INTO `ms_addresses` VALUES ('67645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区清水町竹屋町通東洞院西入', '26', '26104', '6040874', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '清水町', 'シミズチョウ', null, '竹屋町通東洞院西入', null, null);
INSERT INTO `ms_addresses` VALUES ('67646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区清水町竹屋町通車屋町西入', '26', '26104', '6040874', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '清水町', 'シミズチョウ', null, '竹屋町通車屋町西入', null, null);
INSERT INTO `ms_addresses` VALUES ('67647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区清水町竹屋町通車屋町東入', '26', '26104', '6040874', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '清水町', 'シミズチョウ', null, '竹屋町通車屋町東入', null, null);
INSERT INTO `ms_addresses` VALUES ('67648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区清水町車屋町通竹屋町下る', '26', '26104', '6040874', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '清水町', 'シミズチョウ', null, '車屋町通竹屋町下る', null, null);
INSERT INTO `ms_addresses` VALUES ('67649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区砂金町', '26', '26104', '6040875', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '砂金町', 'シャキンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区光リ堂町', '26', '26104', '6040876', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '光リ堂町', 'ヒカリドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区坂本町', '26', '26104', '6040881', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '坂本町', 'サカモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区福屋町', '26', '26104', '6040882', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '福屋町', 'フクヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区楠町', '26', '26104', '6040883', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '楠町', 'クスノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区塀之内町', '26', '26104', '6040884', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '塀之内町', 'ヘイノウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区大津町', '26', '26104', '6040885', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '大津町', 'オオツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区関東屋町', '26', '26104', '6040886', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '関東屋町', 'カントウヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区末丸町', '26', '26104', '6040901', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '末丸町', 'スエマルチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区鉾田町', '26', '26104', '6040902', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '鉾田町', 'ホコデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区指物町', '26', '26104', '6040903', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '指物町', 'サシモノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区西革堂町', '26', '26104', '6040904', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '西革堂町', 'ニシコウドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区梅之木町新烏丸通竹屋町上る', '26', '26104', '6040905', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '梅之木町', 'ウメノキチョウ', null, '新烏丸通竹屋町上る', null, null);
INSERT INTO `ms_addresses` VALUES ('67662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区梅之木町新烏丸通竹屋町下る', '26', '26104', '6040905', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '梅之木町', 'ウメノキチョウ', null, '新烏丸通竹屋町下る', null, null);
INSERT INTO `ms_addresses` VALUES ('67663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区梅之木町新烏丸通夷川上る', '26', '26104', '6040905', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '梅之木町', 'ウメノキチョウ', null, '新烏丸通夷川上る', null, null);
INSERT INTO `ms_addresses` VALUES ('67664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区梅之木町夷川通新烏丸東入', '26', '26104', '6040905', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '梅之木町', 'ウメノキチョウ', null, '夷川通新烏丸東入', null, null);
INSERT INTO `ms_addresses` VALUES ('67665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区梅之木町夷川通新椹木町西入', '26', '26104', '6040905', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '梅之木町', 'ウメノキチョウ', null, '夷川通新椹木町西入', null, null);
INSERT INTO `ms_addresses` VALUES ('67666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区梅之木町竹屋町通新烏丸東入', '26', '26104', '6040905', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '梅之木町', 'ウメノキチョウ', null, '竹屋町通新烏丸東入', null, null);
INSERT INTO `ms_addresses` VALUES ('67667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区梅之木町竹屋町通椹木町西入', '26', '26104', '6040905', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '梅之木町', 'ウメノキチョウ', null, '竹屋町通椹木町西入', null, null);
INSERT INTO `ms_addresses` VALUES ('67668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区梅之木町新烏丸通御霊図子下る', '26', '26104', '6040905', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '梅之木町', 'ウメノキチョウ', null, '新烏丸通御霊図子下る', null, null);
INSERT INTO `ms_addresses` VALUES ('67669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区東椹木町', '26', '26104', '6040906', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '東椹木町', 'ヒガシサワラギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区大文字町河原町通御霊図子下る', '26', '26104', '6040907', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '大文字町', 'ダイモンジチョウ', null, '河原町通御霊図子下る', null, null);
INSERT INTO `ms_addresses` VALUES ('67671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区大文字町河原町通竹屋町上る', '26', '26104', '6040907', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '大文字町', 'ダイモンジチョウ', null, '河原町通竹屋町上る', null, null);
INSERT INTO `ms_addresses` VALUES ('67672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区清水町河原町通夷川下る', '26', '26104', '6040911', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '清水町', 'シミズチョウ', null, '河原町通夷川下る', null, null);
INSERT INTO `ms_addresses` VALUES ('67673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区清水町河原町通二条上る', '26', '26104', '6040911', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '清水町', 'シミズチョウ', null, '河原町通二条上る', null, null);
INSERT INTO `ms_addresses` VALUES ('67674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区清水町夷川通河原町東入', '26', '26104', '6040911', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '清水町', 'シミズチョウ', null, '夷川通河原町東入', null, null);
INSERT INTO `ms_addresses` VALUES ('67675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区清水町夷川通土手町西入', '26', '26104', '6040911', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '清水町', 'シミズチョウ', null, '夷川通土手町西入', null, null);
INSERT INTO `ms_addresses` VALUES ('67676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区清水町夷川通土手町東入', '26', '26104', '6040911', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '清水町', 'シミズチョウ', null, '夷川通土手町東入', null, null);
INSERT INTO `ms_addresses` VALUES ('67677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区樋之口町', '26', '26104', '6040912', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '樋之口町', 'ヒノクチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区角倉町', '26', '26104', '6040913', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '角倉町', 'スミクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区橘柳町', '26', '26104', '6040914', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '橘柳町', 'タチバナヤナギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区常盤木町', '26', '26104', '6040915', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '常盤木町', 'トキワギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区要法寺前町', '26', '26104', '6040916', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '要法寺前町', 'ヨウホウジマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区丸屋町夷川通寺町西入', '26', '26104', '6040917', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '丸屋町', 'マルヤチョウ', null, '夷川通寺町西入', null, null);
INSERT INTO `ms_addresses` VALUES ('67683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区丸屋町夷川通御幸町東入', '26', '26104', '6040917', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '丸屋町', 'マルヤチョウ', null, '夷川通御幸町東入', null, null);
INSERT INTO `ms_addresses` VALUES ('67684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区西生洲町', '26', '26104', '6040921', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '西生洲町', 'ニシイケスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区東生洲町', '26', '26104', '6040922', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '東生洲町', 'ヒガシイケスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区上樵木町', '26', '26104', '6040923', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '上樵木町', 'カミコリキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区一之船入町', '26', '26104', '6040924', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '一之船入町', 'イチノフナイリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区上本能寺前町', '26', '26104', '6040925', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '上本能寺前町', 'カミホンノウジマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区榎木町', '26', '26104', '6040931', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '榎木町', 'エノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区妙満寺前町', '26', '26104', '6040932', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '妙満寺前町', 'ミョウマンジマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区山本町', '26', '26104', '6040933', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '山本町', 'ヤマモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区尾張町', '26', '26104', '6040934', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '尾張町', 'オワリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区丁子屋町', '26', '26104', '6040935', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '丁子屋町', 'チョウジヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区亀屋町御幸町通御池上る', '26', '26104', '6040941', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '亀屋町', 'カメヤチョウ', null, '御幸町通御池上る', null, null);
INSERT INTO `ms_addresses` VALUES ('67695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区亀屋町御幸町通押小路下る', '26', '26104', '6040941', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '亀屋町', 'カメヤチョウ', null, '御幸町通押小路下る', null, null);
INSERT INTO `ms_addresses` VALUES ('67696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区亀屋町御幸町通押小路西入', '26', '26104', '6040941', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '亀屋町', 'カメヤチョウ', null, '御幸町通押小路西入', null, null);
INSERT INTO `ms_addresses` VALUES ('67697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区亀屋町御幸町通押小路東入', '26', '26104', '6040941', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '亀屋町', 'カメヤチョウ', null, '御幸町通押小路東入', null, null);
INSERT INTO `ms_addresses` VALUES ('67698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区亀屋町押小路通寺町西入', '26', '26104', '6040941', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '亀屋町', 'カメヤチョウ', null, '押小路通寺町西入', null, null);
INSERT INTO `ms_addresses` VALUES ('67699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区亀屋町御池通御幸町西入', '26', '26104', '6040941', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '亀屋町', 'カメヤチョウ', null, '御池通御幸町西入', null, null);
INSERT INTO `ms_addresses` VALUES ('67700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区亀屋町御池通御幸町東入', '26', '26104', '6040941', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '亀屋町', 'カメヤチョウ', null, '御池通御幸町東入', null, null);
INSERT INTO `ms_addresses` VALUES ('67701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区御池大東町', '26', '26104', '6040942', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '御池大東町', 'オイケダイトウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区上白山町', '26', '26104', '6040943', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '上白山町', 'カミハクサンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区橘町押小路通御幸町西入', '26', '26104', '6040944', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '橘町', 'タチバナチョウ', null, '押小路通御幸町西入', null, null);
INSERT INTO `ms_addresses` VALUES ('67704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区橘町押小路通麩屋町西入', '26', '26104', '6040944', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '橘町', 'タチバナチョウ', null, '押小路通麩屋町西入', null, null);
INSERT INTO `ms_addresses` VALUES ('67705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区橘町押小路通麩屋町東入', '26', '26104', '6040944', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '橘町', 'タチバナチョウ', null, '押小路通麩屋町東入', null, null);
INSERT INTO `ms_addresses` VALUES ('67706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区橘町押小路通富小路西入', '26', '26104', '6040944', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '橘町', 'タチバナチョウ', null, '押小路通富小路西入', null, null);
INSERT INTO `ms_addresses` VALUES ('67707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区橘町押小路通富小路東入', '26', '26104', '6040944', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '橘町', 'タチバナチョウ', null, '押小路通富小路東入', null, null);
INSERT INTO `ms_addresses` VALUES ('67708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区橘町押小路通柳馬場東入', '26', '26104', '6040944', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '橘町', 'タチバナチョウ', null, '押小路通柳馬場東入', null, null);
INSERT INTO `ms_addresses` VALUES ('67709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区晴明町', '26', '26104', '6040951', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '晴明町', 'セイメイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区俵屋町富小路通二条下る', '26', '26104', '6040952', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '俵屋町', 'タワラヤチョウ', null, '富小路通二条下る', null, null);
INSERT INTO `ms_addresses` VALUES ('67711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区俵屋町富小路通押小路上る', '26', '26104', '6040952', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '俵屋町', 'タワラヤチョウ', null, '富小路通押小路上る', null, null);
INSERT INTO `ms_addresses` VALUES ('67712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区守山町', '26', '26104', '6040953', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '守山町', 'モリヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区東八幡町', '26', '26104', '6040954', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '東八幡町', 'ヒガシハチマンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区虎石町', '26', '26104', '6040955', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '虎石町', 'トライシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区等持寺町', '26', '26104', '6040956', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '等持寺町', 'トウジジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区木屋町', '26', '26104', '6040961', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '木屋町', 'キヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区達磨町', '26', '26104', '6040962', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '達磨町', 'ダルマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区布袋屋町', '26', '26104', '6040963', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '布袋屋町', 'ホテイヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区鍛冶屋町富小路通夷川下る', '26', '26104', '6040964', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '鍛冶屋町', 'カジヤチョウ', null, '富小路通夷川下る', null, null);
INSERT INTO `ms_addresses` VALUES ('67720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区鍛冶屋町富小路通二条上る', '26', '26104', '6040964', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '鍛冶屋町', 'カジヤチョウ', null, '富小路通二条上る', null, null);
INSERT INTO `ms_addresses` VALUES ('67721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区鍛冶屋町夷川通富小路西入', '26', '26104', '6040964', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '鍛冶屋町', 'カジヤチョウ', null, '夷川通富小路西入', null, null);
INSERT INTO `ms_addresses` VALUES ('67722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区鍛冶屋町夷川通富小路東入', '26', '26104', '6040964', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '鍛冶屋町', 'カジヤチョウ', null, '夷川通富小路東入', null, null);
INSERT INTO `ms_addresses` VALUES ('67723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区六丁目', '26', '26104', '6040965', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '六丁目', 'ロクチョウメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区俵屋町夷川通富小路西入', '26', '26104', '6040966', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '俵屋町', 'タワラヤチョウ', null, '夷川通富小路西入', null, null);
INSERT INTO `ms_addresses` VALUES ('67725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区俵屋町夷川通柳馬場東入', '26', '26104', '6040966', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '俵屋町', 'タワラヤチョウ', null, '夷川通柳馬場東入', null, null);
INSERT INTO `ms_addresses` VALUES ('67726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区桝屋町富小路通丸太町下る', '26', '26104', '6040971', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '桝屋町', 'マスヤチョウ', null, '富小路通丸太町下る', null, null);
INSERT INTO `ms_addresses` VALUES ('67727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区桝屋町富小路通竹屋町上る', '26', '26104', '6040971', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '桝屋町', 'マスヤチョウ', null, '富小路通竹屋町上る', null, null);
INSERT INTO `ms_addresses` VALUES ('67728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区桝屋町丸太町通富小路東入', '26', '26104', '6040971', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '桝屋町', 'マスヤチョウ', null, '丸太町通富小路東入', null, null);
INSERT INTO `ms_addresses` VALUES ('67729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区桝屋町竹屋町通富小路東入', '26', '26104', '6040971', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '桝屋町', 'マスヤチョウ', null, '竹屋町通富小路東入', null, null);
INSERT INTO `ms_addresses` VALUES ('67730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区桝屋町丸太町通富小路西入', '26', '26104', '6040971', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '桝屋町', 'マスヤチョウ', null, '丸太町通富小路西入', null, null);
INSERT INTO `ms_addresses` VALUES ('67731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区桝屋町竹屋町通富小路西入', '26', '26104', '6040971', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '桝屋町', 'マスヤチョウ', null, '竹屋町通富小路西入', null, null);
INSERT INTO `ms_addresses` VALUES ('67732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区大炊町富小路通竹屋町下る', '26', '26104', '6040972', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '大炊町', 'オオイチョウ', null, '富小路通竹屋町下る', null, null);
INSERT INTO `ms_addresses` VALUES ('67733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区大炊町富小路通夷川上る', '26', '26104', '6040972', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '大炊町', 'オオイチョウ', null, '富小路通夷川上る', null, null);
INSERT INTO `ms_addresses` VALUES ('67734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区大炊町竹屋町通富小路西入', '26', '26104', '6040972', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '大炊町', 'オオイチョウ', null, '竹屋町通富小路西入', null, null);
INSERT INTO `ms_addresses` VALUES ('67735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区大炊町竹屋町通富小路東入', '26', '26104', '6040972', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '大炊町', 'オオイチョウ', null, '竹屋町通富小路東入', null, null);
INSERT INTO `ms_addresses` VALUES ('67736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区大炊町夷川通富小路西入', '26', '26104', '6040972', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '大炊町', 'オオイチョウ', null, '夷川通富小路西入', null, null);
INSERT INTO `ms_addresses` VALUES ('67737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区大炊町夷川通富小路東入', '26', '26104', '6040972', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '大炊町', 'オオイチョウ', null, '夷川通富小路東入', null, null);
INSERT INTO `ms_addresses` VALUES ('67738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区五丁目', '26', '26104', '6040973', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '五丁目', 'ゴチョウメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区四丁目', '26', '26104', '6040974', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '四丁目', 'ヨンチョウメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区菊屋町竹屋町通富小路西入', '26', '26104', '6040975', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '菊屋町', 'キクヤチョウ', null, '竹屋町通富小路西入', null, null);
INSERT INTO `ms_addresses` VALUES ('67741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区菊屋町竹屋町通柳馬場東入', '26', '26104', '6040975', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '菊屋町', 'キクヤチョウ', null, '竹屋町通柳馬場東入', null, null);
INSERT INTO `ms_addresses` VALUES ('67742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区桑原町', '26', '26104', '6040976', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '桑原町', 'クワバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区毘沙門町御幸町通丸太町下る', '26', '26104', '6040981', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '毘沙門町', 'ビシャモンチョウ', null, '御幸町通丸太町下る', null, null);
INSERT INTO `ms_addresses` VALUES ('67744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区毘沙門町御幸町通竹屋町上る', '26', '26104', '6040981', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '毘沙門町', 'ビシャモンチョウ', null, '御幸町通竹屋町上る', null, null);
INSERT INTO `ms_addresses` VALUES ('67745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区毘沙門町丸太町通御幸町西入', '26', '26104', '6040981', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '毘沙門町', 'ビシャモンチョウ', null, '丸太町通御幸町西入', null, null);
INSERT INTO `ms_addresses` VALUES ('67746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区毘沙門町丸太町通御幸町東入', '26', '26104', '6040981', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '毘沙門町', 'ビシャモンチョウ', null, '丸太町通御幸町東入', null, null);
INSERT INTO `ms_addresses` VALUES ('67747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区毘沙門町竹屋町通御幸町西入', '26', '26104', '6040981', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '毘沙門町', 'ビシャモンチョウ', null, '竹屋町通御幸町西入', null, null);
INSERT INTO `ms_addresses` VALUES ('67748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区毘沙門町竹屋町通御幸町東入', '26', '26104', '6040981', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '毘沙門町', 'ビシャモンチョウ', null, '竹屋町通御幸町東入', null, null);
INSERT INTO `ms_addresses` VALUES ('67749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区毘沙門町竹屋町通麩屋町東入', '26', '26104', '6040981', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '毘沙門町', 'ビシャモンチョウ', null, '竹屋町通麩屋町東入', null, null);
INSERT INTO `ms_addresses` VALUES ('67750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区松本町御幸町通竹屋町下る', '26', '26104', '6040982', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '松本町', 'マツモトチョウ', null, '御幸町通竹屋町下る', null, null);
INSERT INTO `ms_addresses` VALUES ('67751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区松本町御幸町通夷川上る', '26', '26104', '6040982', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '松本町', 'マツモトチョウ', null, '御幸町通夷川上る', null, null);
INSERT INTO `ms_addresses` VALUES ('67752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区松本町御幸町通竹屋町西入', '26', '26104', '6040982', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '松本町', 'マツモトチョウ', null, '御幸町通竹屋町西入', null, null);
INSERT INTO `ms_addresses` VALUES ('67753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区松本町御幸町通竹屋町東入', '26', '26104', '6040982', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '松本町', 'マツモトチョウ', null, '御幸町通竹屋町東入', null, null);
INSERT INTO `ms_addresses` VALUES ('67754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区松本町夷川通御幸町西入', '26', '26104', '6040982', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '松本町', 'マツモトチョウ', null, '夷川通御幸町西入', null, null);
INSERT INTO `ms_addresses` VALUES ('67755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区松本町夷川通御幸町東入', '26', '26104', '6040982', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '松本町', 'マツモトチョウ', null, '夷川通御幸町東入', null, null);
INSERT INTO `ms_addresses` VALUES ('67756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区笹屋町麩屋町通竹屋町下る', '26', '26104', '6040983', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '笹屋町', 'ササヤチョウ', null, '麩屋町通竹屋町下る', null, null);
INSERT INTO `ms_addresses` VALUES ('67757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区笹屋町麩屋町通夷川上る', '26', '26104', '6040983', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '笹屋町', 'ササヤチョウ', null, '麩屋町通夷川上る', null, null);
INSERT INTO `ms_addresses` VALUES ('67758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区笹屋町竹屋町通麩屋町西入', '26', '26104', '6040983', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '笹屋町', 'ササヤチョウ', null, '竹屋町通麩屋町西入', null, null);
INSERT INTO `ms_addresses` VALUES ('67759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区笹屋町竹屋町通麩屋町東入', '26', '26104', '6040983', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '笹屋町', 'ササヤチョウ', null, '竹屋町通麩屋町東入', null, null);
INSERT INTO `ms_addresses` VALUES ('67760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区笹屋町竹屋町通御幸町西入', '26', '26104', '6040983', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '笹屋町', 'ササヤチョウ', null, '竹屋町通御幸町西入', null, null);
INSERT INTO `ms_addresses` VALUES ('67761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区笹屋町夷川通麩屋町西入', '26', '26104', '6040983', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '笹屋町', 'ササヤチョウ', null, '夷川通麩屋町西入', null, null);
INSERT INTO `ms_addresses` VALUES ('67762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区笹屋町夷川通麩屋町東入', '26', '26104', '6040983', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '笹屋町', 'ササヤチョウ', null, '夷川通麩屋町東入', null, null);
INSERT INTO `ms_addresses` VALUES ('67763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区魚屋町', '26', '26104', '6040984', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '魚屋町', 'ウオヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区舟屋町', '26', '26104', '6040985', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '舟屋町', 'フナヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区昆布屋町', '26', '26104', '6040986', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '昆布屋町', 'コンブヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区行願寺門前町', '26', '26104', '6040991', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '行願寺門前町', 'ギョウガンジモンゼンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区藤木町', '26', '26104', '6040992', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '藤木町', 'フジキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区久遠院前町', '26', '26104', '6040993', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '久遠院前町', 'クエンインマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区甘露町', '26', '26104', '6040994', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '甘露町', 'カンロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区下御霊前町', '26', '26104', '6040995', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '下御霊前町', 'シモゴリョウマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区石屋町丸太町通寺町西入', '26', '26104', '6040996', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '石屋町', 'イシヤチョウ', null, '丸太町通寺町西入', null, null);
INSERT INTO `ms_addresses` VALUES ('67772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区石屋町丸太町通御幸町東入', '26', '26104', '6040996', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '石屋町', 'イシヤチョウ', null, '丸太町通御幸町東入', null, null);
INSERT INTO `ms_addresses` VALUES ('67773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区上大阪町', '26', '26104', '6048001', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '上大阪町', 'カミオオサカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区石屋町木屋町通三条下る', '26', '26104', '6048002', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '石屋町', 'イシヤチョウ', null, '木屋町通三条下る', null, null);
INSERT INTO `ms_addresses` VALUES ('67775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区石屋町先斗町通三条下る', '26', '26104', '6048002', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '石屋町', 'イシヤチョウ', null, '先斗町通三条下る', null, null);
INSERT INTO `ms_addresses` VALUES ('67776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区石屋町木屋町通四条上る', '26', '26104', '6048002', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '石屋町', 'イシヤチョウ', null, '木屋町通四条上る', null, null);
INSERT INTO `ms_addresses` VALUES ('67777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区橋下町', '26', '26104', '6048003', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '橋下町', 'ハシシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区中島町', '26', '26104', '6048004', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '中島町', 'ナカジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区恵比須町', '26', '26104', '6048005', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '恵比須町', 'エビスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区下丸屋町御池通河原町東入', '26', '26104', '6048006', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '下丸屋町', 'シモマルヤチョウ', null, '御池通河原町東入', null, null);
INSERT INTO `ms_addresses` VALUES ('67781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区下丸屋町河原町通御池下る', '26', '26104', '6048006', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '下丸屋町', 'シモマルヤチョウ', null, '河原町通御池下る', null, null);
INSERT INTO `ms_addresses` VALUES ('67782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区下丸屋町河原町通姉小路上る', '26', '26104', '6048006', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '下丸屋町', 'シモマルヤチョウ', null, '河原町通姉小路上る', null, null);
INSERT INTO `ms_addresses` VALUES ('67783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区下丸屋町御池通木屋町西入', '26', '26104', '6048006', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '下丸屋町', 'シモマルヤチョウ', null, '御池通木屋町西入', null, null);
INSERT INTO `ms_addresses` VALUES ('67784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区下丸屋町木屋町通御池下る', '26', '26104', '6048006', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '下丸屋町', 'シモマルヤチョウ', null, '木屋町通御池下る', null, null);
INSERT INTO `ms_addresses` VALUES ('67785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区下丸屋町木屋町通姉小路上る', '26', '26104', '6048006', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '下丸屋町', 'シモマルヤチョウ', null, '木屋町通姉小路上る', null, null);
INSERT INTO `ms_addresses` VALUES ('67786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区若松町', '26', '26104', '6048011', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '若松町', 'ワカマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区梅之木町先斗町通三条下る', '26', '26104', '6048012', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '梅之木町', 'ウメノキチョウ', null, '先斗町通三条下る', null, null);
INSERT INTO `ms_addresses` VALUES ('67788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区梅之木町先斗町通蛸薬師上る', '26', '26104', '6048012', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '梅之木町', 'ウメノキチョウ', null, '先斗町通蛸薬師上る', null, null);
INSERT INTO `ms_addresses` VALUES ('67789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区梅之木町先斗町通蛸薬師下る', '26', '26104', '6048012', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '梅之木町', 'ウメノキチョウ', null, '先斗町通蛸薬師下る', null, null);
INSERT INTO `ms_addresses` VALUES ('67790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区梅之木町先斗町通四条上る', '26', '26104', '6048012', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '梅之木町', 'ウメノキチョウ', null, '先斗町通四条上る', null, null);
INSERT INTO `ms_addresses` VALUES ('67791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区松本町先斗町通四条上る', '26', '26104', '6048013', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '松本町', 'マツモトチョウ', null, '先斗町通四条上る', null, null);
INSERT INTO `ms_addresses` VALUES ('67792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区松本町先斗町通三条下る', '26', '26104', '6048013', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '松本町', 'マツモトチョウ', null, '先斗町通三条下る', null, null);
INSERT INTO `ms_addresses` VALUES ('67793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区柏屋町', '26', '26104', '6048014', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '柏屋町', 'カシワヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区鍋屋町', '26', '26104', '6048015', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '鍋屋町', 'ナベヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区下樵木町', '26', '26104', '6048016', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '下樵木町', 'シモコリキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区材木町', '26', '26104', '6048017', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '材木町', 'ザイモクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区北車屋町', '26', '26104', '6048021', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '北車屋町', 'キタクルマヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区南車屋町', '26', '26104', '6048022', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '南車屋町', 'ミナミクルマヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区備前島町', '26', '26104', '6048023', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '備前島町', 'ビゼンジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区紙屋町', '26', '26104', '6048024', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '紙屋町', 'カミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区下大阪町', '26', '26104', '6048025', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '下大阪町', 'シモオオサカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区米屋町', '26', '26104', '6048026', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '米屋町', 'コメヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区塩屋町河原町通蛸薬師下る', '26', '26104', '6048027', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '塩屋町', 'シオヤチョウ', null, '河原町通蛸薬師下る', null, null);
INSERT INTO `ms_addresses` VALUES ('67804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区塩屋町河原町通四条上る', '26', '26104', '6048027', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '塩屋町', 'シオヤチョウ', null, '河原町通四条上る', null, null);
INSERT INTO `ms_addresses` VALUES ('67805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区塩屋町蛸薬師通河原町西入', '26', '26104', '6048027', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '塩屋町', 'シオヤチョウ', null, '蛸薬師通河原町西入', null, null);
INSERT INTO `ms_addresses` VALUES ('67806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区大黒町河原町通三条下る', '26', '26104', '6048031', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '大黒町', 'ダイコクチョウ', null, '河原町通三条下る', null, null);
INSERT INTO `ms_addresses` VALUES ('67807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区大黒町三条通河原町東入', '26', '26104', '6048031', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '大黒町', 'ダイコクチョウ', null, '三条通河原町東入', null, null);
INSERT INTO `ms_addresses` VALUES ('67808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区大黒町三条通河原町西入', '26', '26104', '6048031', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '大黒町', 'ダイコクチョウ', null, '三条通河原町西入', null, null);
INSERT INTO `ms_addresses` VALUES ('67809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区大黒町河原町通六角上る', '26', '26104', '6048031', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '大黒町', 'ダイコクチョウ', null, '河原町通六角上る', null, null);
INSERT INTO `ms_addresses` VALUES ('67810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区大黒町西木屋町通三条下る', '26', '26104', '6048031', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '大黒町', 'ダイコクチョウ', null, '西木屋町通三条下る', null, null);
INSERT INTO `ms_addresses` VALUES ('67811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区大黒町西木屋町通六角上る', '26', '26104', '6048031', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '大黒町', 'ダイコクチョウ', null, '西木屋町通六角上る', null, null);
INSERT INTO `ms_addresses` VALUES ('67812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区山崎町', '26', '26104', '6048032', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '山崎町', 'ヤマザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区奈良屋町', '26', '26104', '6048033', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '奈良屋町', 'ナラヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区松ケ枝町', '26', '26104', '6048034', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '松ケ枝町', 'マツガエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区桜之町', '26', '26104', '6048035', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '桜之町', 'サクラノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区石橋町三条通河原町西入', '26', '26104', '6048036', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '石橋町', 'イシバシチョウ', null, '三条通河原町西入', null, null);
INSERT INTO `ms_addresses` VALUES ('67817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区石橋町三条通寺町東入', '26', '26104', '6048036', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '石橋町', 'イシバシチョウ', null, '三条通寺町東入', null, null);
INSERT INTO `ms_addresses` VALUES ('67818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区石橋町三条通新京極西入', '26', '26104', '6048036', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '石橋町', 'イシバシチョウ', null, '三条通新京極西入', null, null);
INSERT INTO `ms_addresses` VALUES ('67819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区石橋町三条通新京極東入', '26', '26104', '6048036', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '石橋町', 'イシバシチョウ', null, '三条通新京極東入', null, null);
INSERT INTO `ms_addresses` VALUES ('67820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区石橋町寺町通三条下る', '26', '26104', '6048036', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '石橋町', 'イシバシチョウ', null, '寺町通三条下る', null, null);
INSERT INTO `ms_addresses` VALUES ('67821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区石橋町寺町通三条上る', '26', '26104', '6048036', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '石橋町', 'イシバシチョウ', null, '寺町通三条上る', null, null);
INSERT INTO `ms_addresses` VALUES ('67822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区裏寺町', '26', '26104', '6048041', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '裏寺町', 'ウラデラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区中之町寺町通錦小路下る', '26', '26104', '6048042', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '中之町', 'ナカノチョウ', null, '寺町通錦小路下る', null, null);
INSERT INTO `ms_addresses` VALUES ('67824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区中之町寺町通四条上る', '26', '26104', '6048042', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '中之町', 'ナカノチョウ', null, '寺町通四条上る', null, null);
INSERT INTO `ms_addresses` VALUES ('67825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区中之町新京極通錦小路下る', '26', '26104', '6048042', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '中之町', 'ナカノチョウ', null, '新京極通錦小路下る', null, null);
INSERT INTO `ms_addresses` VALUES ('67826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区中之町新京極通四条上る', '26', '26104', '6048042', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '中之町', 'ナカノチョウ', null, '新京極通四条上る', null, null);
INSERT INTO `ms_addresses` VALUES ('67827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区中之町錦小路通寺町東入', '26', '26104', '6048042', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '中之町', 'ナカノチョウ', null, '錦小路通寺町東入', null, null);
INSERT INTO `ms_addresses` VALUES ('67828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区中之町裏寺町通蛸薬師下る', '26', '26104', '6048042', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '中之町', 'ナカノチョウ', null, '裏寺町通蛸薬師下る', null, null);
INSERT INTO `ms_addresses` VALUES ('67829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区中之町裏寺町通四条上る', '26', '26104', '6048042', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '中之町', 'ナカノチョウ', null, '裏寺町通四条上る', null, null);
INSERT INTO `ms_addresses` VALUES ('67830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区東大文字町', '26', '26104', '6048043', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '東大文字町', 'ヒガシダイモンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区大日町', '26', '26104', '6048044', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '大日町', 'ダイニチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区円福寺前町', '26', '26104', '6048045', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '円福寺前町', 'エンプクジマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区東側町', '26', '26104', '6048046', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '東側町', 'ヒガシガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区中筋町', '26', '26104', '6048047', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '中筋町', 'ナカスジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区船屋町御幸町通蛸薬師下る', '26', '26104', '6048051', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '船屋町', 'フナヤチョウ', null, '御幸町通蛸薬師下る', null, null);
INSERT INTO `ms_addresses` VALUES ('67836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区船屋町御幸町通錦小路上る', '26', '26104', '6048051', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '船屋町', 'フナヤチョウ', null, '御幸町通錦小路上る', null, null);
INSERT INTO `ms_addresses` VALUES ('67837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区船屋町蛸薬師通御幸町東入', '26', '26104', '6048051', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '船屋町', 'フナヤチョウ', null, '蛸薬師通御幸町東入', null, null);
INSERT INTO `ms_addresses` VALUES ('67838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区船屋町錦小路通御幸町東入', '26', '26104', '6048051', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '船屋町', 'フナヤチョウ', null, '錦小路通御幸町東入', null, null);
INSERT INTO `ms_addresses` VALUES ('67839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区鍛冶屋町錦小路通御幸町西入', '26', '26104', '6048052', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '鍛冶屋町', 'カジヤチョウ', null, '錦小路通御幸町西入', null, null);
INSERT INTO `ms_addresses` VALUES ('67840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区鍛冶屋町錦小路通麸屋町東入', '26', '26104', '6048052', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '鍛冶屋町', 'カジヤチョウ', null, '錦小路通麸屋町東入', null, null);
INSERT INTO `ms_addresses` VALUES ('67841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区桝屋町麩屋町通錦小路下る', '26', '26104', '6048053', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '桝屋町', 'マスヤチョウ', null, '麩屋町通錦小路下る', null, null);
INSERT INTO `ms_addresses` VALUES ('67842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区桝屋町麩屋町通四条上る', '26', '26104', '6048053', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '桝屋町', 'マスヤチョウ', null, '麩屋町通四条上る', null, null);
INSERT INTO `ms_addresses` VALUES ('67843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区桝屋町錦小路通麩屋町西入', '26', '26104', '6048053', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '桝屋町', 'マスヤチョウ', null, '錦小路通麩屋町西入', null, null);
INSERT INTO `ms_addresses` VALUES ('67844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区桝屋町錦小路通麩屋町東入', '26', '26104', '6048053', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '桝屋町', 'マスヤチョウ', null, '錦小路通麩屋町東入', null, null);
INSERT INTO `ms_addresses` VALUES ('67845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区西大文字町', '26', '26104', '6048054', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '西大文字町', 'ニシダイモンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区東魚屋町', '26', '26104', '6048055', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '東魚屋町', 'ヒガシウオヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区高宮町富小路通錦小路上る', '26', '26104', '6048056', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '高宮町', 'タカミヤチョウ', null, '富小路通錦小路上る', null, null);
INSERT INTO `ms_addresses` VALUES ('67848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区高宮町富小路通蛸薬師下る', '26', '26104', '6048056', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '高宮町', 'タカミヤチョウ', null, '富小路通蛸薬師下る', null, null);
INSERT INTO `ms_addresses` VALUES ('67849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区梅屋町麸屋町通錦小路上る', '26', '26104', '6048057', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '梅屋町', 'ウメヤチョウ', null, '麸屋町通錦小路上る', null, null);
INSERT INTO `ms_addresses` VALUES ('67850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区梅屋町麸屋町通蛸薬師下る', '26', '26104', '6048057', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '梅屋町', 'ウメヤチョウ', null, '麸屋町通蛸薬師下る', null, null);
INSERT INTO `ms_addresses` VALUES ('67851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区式部町', '26', '26104', '6048061', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '式部町', 'シキブチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区蛸屋町', '26', '26104', '6048062', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '蛸屋町', 'タコヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区油屋町蛸薬師通麸屋町西入', '26', '26104', '6048063', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '油屋町', 'アブラヤチョウ', null, '蛸薬師通麸屋町西入', null, null);
INSERT INTO `ms_addresses` VALUES ('67854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区油屋町蛸薬師通富小路東入', '26', '26104', '6048063', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '油屋町', 'アブラヤチョウ', null, '蛸薬師通富小路東入', null, null);
INSERT INTO `ms_addresses` VALUES ('67855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区油屋町蛸薬師通富小路西入', '26', '26104', '6048063', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '油屋町', 'アブラヤチョウ', null, '蛸薬師通富小路西入', null, null);
INSERT INTO `ms_addresses` VALUES ('67856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区油屋町蛸薬師通柳馬場東入', '26', '26104', '6048063', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '油屋町', 'アブラヤチョウ', null, '蛸薬師通柳馬場東入', null, null);
INSERT INTO `ms_addresses` VALUES ('67857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区油屋町富小路通蛸薬師上る', '26', '26104', '6048063', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '油屋町', 'アブラヤチョウ', null, '富小路通蛸薬師上る', null, null);
INSERT INTO `ms_addresses` VALUES ('67858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区油屋町富小路通蛸薬師下る', '26', '26104', '6048063', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '油屋町', 'アブラヤチョウ', null, '富小路通蛸薬師下る', null, null);
INSERT INTO `ms_addresses` VALUES ('67859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区骨屋之町', '26', '26104', '6048064', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '骨屋之町', 'ホネヤノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区坂井町', '26', '26104', '6048065', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '坂井町', 'サカイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区伊勢屋町', '26', '26104', '6048066', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '伊勢屋町', 'イセヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区永楽町', '26', '26104', '6048071', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '永楽町', 'エイラクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区八百屋町六角通寺町西入', '26', '26104', '6048072', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '八百屋町', 'ヤオヤチョウ', null, '六角通寺町西入', null, null);
INSERT INTO `ms_addresses` VALUES ('67864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区八百屋町六角通御幸町東入', '26', '26104', '6048072', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '八百屋町', 'ヤオヤチョウ', null, '六角通御幸町東入', null, null);
INSERT INTO `ms_addresses` VALUES ('67865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区八百屋町六角通御幸町西入', '26', '26104', '6048072', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '八百屋町', 'ヤオヤチョウ', null, '六角通御幸町西入', null, null);
INSERT INTO `ms_addresses` VALUES ('67866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区八百屋町六角通麩屋町東入', '26', '26104', '6048072', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '八百屋町', 'ヤオヤチョウ', null, '六角通麩屋町東入', null, null);
INSERT INTO `ms_addresses` VALUES ('67867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区八百屋町御幸町通麩屋町下る', '26', '26104', '6048072', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '八百屋町', 'ヤオヤチョウ', null, '御幸町通麩屋町下る', null, null);
INSERT INTO `ms_addresses` VALUES ('67868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区八百屋町麩屋町通六角下る', '26', '26104', '6048072', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '八百屋町', 'ヤオヤチョウ', null, '麩屋町通六角下る', null, null);
INSERT INTO `ms_addresses` VALUES ('67869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区大黒町麩屋町通六角上る', '26', '26104', '6048073', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '大黒町', 'ダイコクチョウ', null, '麩屋町通六角上る', null, null);
INSERT INTO `ms_addresses` VALUES ('67870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区大黒町麩屋町通六角下る', '26', '26104', '6048073', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '大黒町', 'ダイコクチョウ', null, '麩屋町通六角下る', null, null);
INSERT INTO `ms_addresses` VALUES ('67871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区大黒町六角通麩屋町西入', '26', '26104', '6048073', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '大黒町', 'ダイコクチョウ', null, '六角通麩屋町西入', null, null);
INSERT INTO `ms_addresses` VALUES ('67872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区大黒町富小路通六角上る', '26', '26104', '6048073', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '大黒町', 'ダイコクチョウ', null, '富小路通六角上る', null, null);
INSERT INTO `ms_addresses` VALUES ('67873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区大黒町富小路通六角下る', '26', '26104', '6048073', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '大黒町', 'ダイコクチョウ', null, '富小路通六角下る', null, null);
INSERT INTO `ms_addresses` VALUES ('67874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区大黒町六角通富小路西入', '26', '26104', '6048073', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '大黒町', 'ダイコクチョウ', null, '六角通富小路西入', null, null);
INSERT INTO `ms_addresses` VALUES ('67875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区大黒町六角通富小路東入', '26', '26104', '6048073', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '大黒町', 'ダイコクチョウ', null, '六角通富小路東入', null, null);
INSERT INTO `ms_addresses` VALUES ('67876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区大黒町六角通柳馬場東入', '26', '26104', '6048073', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '大黒町', 'ダイコクチョウ', null, '六角通柳馬場東入', null, null);
INSERT INTO `ms_addresses` VALUES ('67877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区朝倉町', '26', '26104', '6048074', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '朝倉町', 'アサクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区白壁町', '26', '26104', '6048075', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '白壁町', 'シラカベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区海老屋町', '26', '26104', '6048076', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '海老屋町', 'エビヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区天性寺前町', '26', '26104', '6048081', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '天性寺前町', 'テンショウジマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区弁慶石町', '26', '26104', '6048082', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '弁慶石町', 'ベンケイイシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区中之町三条通麩屋町西入', '26', '26104', '6048083', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '中之町', 'ナカノチョウ', null, '三条通麩屋町西入', null, null);
INSERT INTO `ms_addresses` VALUES ('67883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区中之町三条通富小路西入', '26', '26104', '6048083', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '中之町', 'ナカノチョウ', null, '三条通富小路西入', null, null);
INSERT INTO `ms_addresses` VALUES ('67884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区中之町三条通富小路東入', '26', '26104', '6048083', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '中之町', 'ナカノチョウ', null, '三条通富小路東入', null, null);
INSERT INTO `ms_addresses` VALUES ('67885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区中之町三条通柳馬場東入', '26', '26104', '6048083', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '中之町', 'ナカノチョウ', null, '三条通柳馬場東入', null, null);
INSERT INTO `ms_addresses` VALUES ('67886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区中之町富小路通三条下る', '26', '26104', '6048083', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '中之町', 'ナカノチョウ', null, '富小路通三条下る', null, null);
INSERT INTO `ms_addresses` VALUES ('67887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区福長町', '26', '26104', '6048084', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '福長町', 'フクナガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区下白山町', '26', '26104', '6048085', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '下白山町', 'シモハクサンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区丸屋町御幸町通姉小路下る', '26', '26104', '6048086', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '丸屋町', 'マルヤチョウ', null, '御幸町通姉小路下る', null, null);
INSERT INTO `ms_addresses` VALUES ('67890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区丸屋町御幸町通三条上る', '26', '26104', '6048086', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '丸屋町', 'マルヤチョウ', null, '御幸町通三条上る', null, null);
INSERT INTO `ms_addresses` VALUES ('67891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区丸屋町姉小路通御幸町西入', '26', '26104', '6048086', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '丸屋町', 'マルヤチョウ', null, '姉小路通御幸町西入', null, null);
INSERT INTO `ms_addresses` VALUES ('67892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区丸屋町姉小路通御幸町東入', '26', '26104', '6048086', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '丸屋町', 'マルヤチョウ', null, '姉小路通御幸町東入', null, null);
INSERT INTO `ms_addresses` VALUES ('67893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区下本能寺前町', '26', '26104', '6048091', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '下本能寺前町', 'シモホンノウジマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区姉大東町', '26', '26104', '6048092', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '姉大東町', 'アネダイトウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区松下町', '26', '26104', '6048093', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '松下町', 'マツシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区中白山町', '26', '26104', '6048094', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '中白山町', 'ナカハクサンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区大文字町御幸町通御池下る', '26', '26104', '6048095', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '大文字町', 'ダイモンジチョウ', null, '御幸町通御池下る', null, null);
INSERT INTO `ms_addresses` VALUES ('67898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区大文字町御幸町通姉小路上る', '26', '26104', '6048095', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '大文字町', 'ダイモンジチョウ', null, '御幸町通姉小路上る', null, null);
INSERT INTO `ms_addresses` VALUES ('67899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区大文字町御池通御幸町西入', '26', '26104', '6048095', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '大文字町', 'ダイモンジチョウ', null, '御池通御幸町西入', null, null);
INSERT INTO `ms_addresses` VALUES ('67900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区大文字町御池通御幸町東入', '26', '26104', '6048095', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '大文字町', 'ダイモンジチョウ', null, '御池通御幸町東入', null, null);
INSERT INTO `ms_addresses` VALUES ('67901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区大文字町姉小路通御幸町西入', '26', '26104', '6048095', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '大文字町', 'ダイモンジチョウ', null, '姉小路通御幸町西入', null, null);
INSERT INTO `ms_addresses` VALUES ('67902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区大文字町姉小路通御幸町東入', '26', '26104', '6048095', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '大文字町', 'ダイモンジチョウ', null, '姉小路通御幸町東入', null, null);
INSERT INTO `ms_addresses` VALUES ('67903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区柳八幡町', '26', '26104', '6048101', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '柳八幡町', 'ヤナギハチマンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区菊屋町姉小路通富小路西入', '26', '26104', '6048102', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '菊屋町', 'キクヤチョウ', null, '姉小路通富小路西入', null, null);
INSERT INTO `ms_addresses` VALUES ('67905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区菊屋町姉小路通柳馬場東入', '26', '26104', '6048102', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '菊屋町', 'キクヤチョウ', null, '姉小路通柳馬場東入', null, null);
INSERT INTO `ms_addresses` VALUES ('67906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区油屋町柳馬場通姉小路下る', '26', '26104', '6048103', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '油屋町', 'アブラヤチョウ', null, '柳馬場通姉小路下る', null, null);
INSERT INTO `ms_addresses` VALUES ('67907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区油屋町柳馬場通三条上る', '26', '26104', '6048103', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '油屋町', 'アブラヤチョウ', null, '柳馬場通三条上る', null, null);
INSERT INTO `ms_addresses` VALUES ('67908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区油屋町姉小路通柳馬場東入', '26', '26104', '6048103', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '油屋町', 'アブラヤチョウ', null, '姉小路通柳馬場東入', null, null);
INSERT INTO `ms_addresses` VALUES ('67909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区油屋町姉小路通柳馬場西入', '26', '26104', '6048103', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '油屋町', 'アブラヤチョウ', null, '姉小路通柳馬場西入', null, null);
INSERT INTO `ms_addresses` VALUES ('67910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区木之下町', '26', '26104', '6048104', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '木之下町', 'キノシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区亀甲屋町', '26', '26104', '6048105', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '亀甲屋町', 'キッコウヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区丸木材木町', '26', '26104', '6048106', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '丸木材木町', 'マルキザイモクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区桝屋町柳馬場通三条上る', '26', '26104', '6048111', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '桝屋町', 'マスヤチョウ', null, '柳馬場通三条上る', null, null);
INSERT INTO `ms_addresses` VALUES ('67914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区桝屋町柳馬場通三条下る', '26', '26104', '6048111', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '桝屋町', 'マスヤチョウ', null, '柳馬場通三条下る', null, null);
INSERT INTO `ms_addresses` VALUES ('67915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区桝屋町堺町通三条上る', '26', '26104', '6048111', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '桝屋町', 'マスヤチョウ', null, '堺町通三条上る', null, null);
INSERT INTO `ms_addresses` VALUES ('67916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区桝屋町堺町通三条下る', '26', '26104', '6048111', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '桝屋町', 'マスヤチョウ', null, '堺町通三条下る', null, null);
INSERT INTO `ms_addresses` VALUES ('67917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区桝屋町高倉通三条上る', '26', '26104', '6048111', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '桝屋町', 'マスヤチョウ', null, '高倉通三条上る', null, null);
INSERT INTO `ms_addresses` VALUES ('67918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区桝屋町高倉通三条下る', '26', '26104', '6048111', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '桝屋町', 'マスヤチョウ', null, '高倉通三条下る', null, null);
INSERT INTO `ms_addresses` VALUES ('67919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区桝屋町三条通柳馬場西入', '26', '26104', '6048111', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '桝屋町', 'マスヤチョウ', null, '三条通柳馬場西入', null, null);
INSERT INTO `ms_addresses` VALUES ('67920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区桝屋町三条通堺町西入', '26', '26104', '6048111', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '桝屋町', 'マスヤチョウ', null, '三条通堺町西入', null, null);
INSERT INTO `ms_addresses` VALUES ('67921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区桝屋町三条通堺町東入', '26', '26104', '6048111', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '桝屋町', 'マスヤチョウ', null, '三条通堺町東入', null, null);
INSERT INTO `ms_addresses` VALUES ('67922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区桝屋町三条通高倉東入', '26', '26104', '6048111', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '桝屋町', 'マスヤチョウ', null, '三条通高倉東入', null, null);
INSERT INTO `ms_addresses` VALUES ('67923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区槌屋町柳馬場通三条下る', '26', '26104', '6048112', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '槌屋町', 'ツチヤチョウ', null, '柳馬場通三条下る', null, null);
INSERT INTO `ms_addresses` VALUES ('67924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区槌屋町柳馬場通六角上る', '26', '26104', '6048112', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '槌屋町', 'ツチヤチョウ', null, '柳馬場通六角上る', null, null);
INSERT INTO `ms_addresses` VALUES ('67925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区槌屋町六角通柳馬場西入', '26', '26104', '6048112', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '槌屋町', 'ツチヤチョウ', null, '六角通柳馬場西入', null, null);
INSERT INTO `ms_addresses` VALUES ('67926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区槌屋町六角通柳馬場東入', '26', '26104', '6048112', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '槌屋町', 'ツチヤチョウ', null, '六角通柳馬場東入', null, null);
INSERT INTO `ms_addresses` VALUES ('67927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区井筒屋町', '26', '26104', '6048113', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '井筒屋町', 'イヅツヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区甲屋町', '26', '26104', '6048114', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '甲屋町', 'カブトヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区雁金町', '26', '26104', '6048115', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '雁金町', 'カリガネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区和久屋町高倉通六角下る', '26', '26104', '6048116', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '和久屋町', 'ワクヤチョウ', null, '高倉通六角下る', null, null);
INSERT INTO `ms_addresses` VALUES ('67931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区和久屋町高倉通蛸薬師上る', '26', '26104', '6048116', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '和久屋町', 'ワクヤチョウ', null, '高倉通蛸薬師上る', null, null);
INSERT INTO `ms_addresses` VALUES ('67932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区堀之上町', '26', '26104', '6048117', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '堀之上町', 'ホリノウエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区道祐町', '26', '26104', '6048118', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '道祐町', 'ドウユウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区十文字町', '26', '26104', '6048121', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '十文字町', 'ジュウモンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区瀬戸屋町', '26', '26104', '6048122', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '瀬戸屋町', 'セトヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区八百屋町堺町通錦小路下る', '26', '26104', '6048123', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '八百屋町', 'ヤオヤチョウ', null, '堺町通錦小路下る', null, null);
INSERT INTO `ms_addresses` VALUES ('67937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区八百屋町堺町通四条上る', '26', '26104', '6048123', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '八百屋町', 'ヤオヤチョウ', null, '堺町通四条上る', null, null);
INSERT INTO `ms_addresses` VALUES ('67938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区帯屋町', '26', '26104', '6048124', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '帯屋町', 'オビヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区中魚屋町', '26', '26104', '6048125', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '中魚屋町', 'ナカウオヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区貝屋町', '26', '26104', '6048126', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '貝屋町', 'カイヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区菊屋町堺町通蛸薬師下る', '26', '26104', '6048127', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '菊屋町', 'キクヤチョウ', null, '堺町通蛸薬師下る', null, null);
INSERT INTO `ms_addresses` VALUES ('67942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区菊屋町堺町通錦小路上る', '26', '26104', '6048127', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '菊屋町', 'キクヤチョウ', null, '堺町通錦小路上る', null, null);
INSERT INTO `ms_addresses` VALUES ('67943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区菊屋町錦小路通堺町東入', '26', '26104', '6048127', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '菊屋町', 'キクヤチョウ', null, '錦小路通堺町東入', null, null);
INSERT INTO `ms_addresses` VALUES ('67944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区菊屋町錦小路通柳馬場西入', '26', '26104', '6048127', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '菊屋町', 'キクヤチョウ', null, '錦小路通柳馬場西入', null, null);
INSERT INTO `ms_addresses` VALUES ('67945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区菱屋町', '26', '26104', '6048131', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '菱屋町', 'ヒシヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区丸屋町高倉通三条下る', '26', '26104', '6048132', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '丸屋町', 'マルヤチョウ', null, '高倉通三条下る', null, null);
INSERT INTO `ms_addresses` VALUES ('67947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区丸屋町高倉通六角上る', '26', '26104', '6048132', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '丸屋町', 'マルヤチョウ', null, '高倉通六角上る', null, null);
INSERT INTO `ms_addresses` VALUES ('67948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区滕屋町', '26', '26104', '6048133', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '滕屋町', 'チギリヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区堂之前町', '26', '26104', '6048134', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '堂之前町', 'ドウノマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区三文字町東洞院通三条下る', '26', '26104', '6048135', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '三文字町', 'サンモンジチョウ', null, '東洞院通三条下る', null, null);
INSERT INTO `ms_addresses` VALUES ('67951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区三文字町東洞院通六角上る', '26', '26104', '6048135', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '三文字町', 'サンモンジチョウ', null, '東洞院通六角上る', null, null);
INSERT INTO `ms_addresses` VALUES ('67952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区三文字町六角通東洞院西入', '26', '26104', '6048135', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '三文字町', 'サンモンジチョウ', null, '六角通東洞院西入', null, null);
INSERT INTO `ms_addresses` VALUES ('67953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区三文字町六角通東洞院東入', '26', '26104', '6048135', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '三文字町', 'サンモンジチョウ', null, '六角通東洞院東入', null, null);
INSERT INTO `ms_addresses` VALUES ('67954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区梅忠町', '26', '26104', '6048136', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '梅忠町', 'ウメタダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区泉正寺町', '26', '26104', '6048141', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '泉正寺町', 'センショウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区西魚屋町', '26', '26104', '6048142', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '西魚屋町', 'ニシウオヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区阪東屋町', '26', '26104', '6048143', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '阪東屋町', 'バントウヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区元法然寺町', '26', '26104', '6048144', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '元法然寺町', 'モトホウネンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区元竹田町', '26', '26104', '6048145', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '元竹田町', 'モトタケダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区一蓮社町', '26', '26104', '6048146', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '一蓮社町', 'イチレンシャチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区御射山町', '26', '26104', '6048147', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '御射山町', 'ミサヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区橋弁慶町', '26', '26104', '6048151', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '橋弁慶町', 'ハシベンケイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区手洗水町', '26', '26104', '6048152', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '手洗水町', 'テアライミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区笋町', '26', '26104', '6048153', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '笋町', 'タカンナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区菊水鉾町', '26', '26104', '6048154', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '菊水鉾町', 'キクスイボコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区占出山町', '26', '26104', '6048155', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '占出山町', 'ウラデヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区山伏山町', '26', '26104', '6048156', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '山伏山町', 'ヤマブシヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区饅頭屋町', '26', '26104', '6048161', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '饅頭屋町', 'マンジュウヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区七観音町', '26', '26104', '6048162', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '七観音町', 'シチカンノンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区鯉山町', '26', '26104', '6048163', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '鯉山町', 'コイヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区骨屋町', '26', '26104', '6048164', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '骨屋町', 'ホネヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区烏帽子屋町', '26', '26104', '6048165', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '烏帽子屋町', 'エボウシヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区御倉町', '26', '26104', '6048166', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '御倉町', 'ミクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区虎屋町', '26', '26104', '6048171', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '虎屋町', 'トラヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区場之町', '26', '26104', '6048172', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '場之町', 'バノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区柿本町', '26', '26104', '6048173', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '柿本町', 'カキモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区役行者町', '26', '26104', '6048174', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '役行者町', 'エンノギョウジャチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区円福寺町', '26', '26104', '6048175', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '円福寺町', 'エンプクジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区龍池町', '26', '26104', '6048176', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '龍池町', 'タツイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区綿屋町', '26', '26104', '6048181', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '綿屋町', 'ワタヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区大阪材木町', '26', '26104', '6048182', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '大阪材木町', 'オオサカザイモクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区東片町', '26', '26104', '6048183', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '東片町', 'ヒガシカタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区曇華院前町', '26', '26104', '6048184', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '曇華院前町', 'ドンゲインマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区車屋町', '26', '26104', '6048185', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '車屋町', 'クルマヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区梅屋町御池通烏丸東入', '26', '26104', '6048186', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '梅屋町', 'ウメヤチョウ', null, '御池通烏丸東入', null, null);
INSERT INTO `ms_addresses` VALUES ('67986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区梅屋町御池通東洞院西入', '26', '26104', '6048186', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '梅屋町', 'ウメヤチョウ', null, '御池通東洞院西入', null, null);
INSERT INTO `ms_addresses` VALUES ('67987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区笹屋町御池通東洞院東入', '26', '26104', '6048187', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '笹屋町', 'ササヤチョウ', null, '御池通東洞院東入', null, null);
INSERT INTO `ms_addresses` VALUES ('67988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区笹屋町御池通東洞院西入', '26', '26104', '6048187', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '笹屋町', 'ササヤチョウ', null, '御池通東洞院西入', null, null);
INSERT INTO `ms_addresses` VALUES ('67989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区笹屋町御池通烏丸東入', '26', '26104', '6048187', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '笹屋町', 'ササヤチョウ', null, '御池通烏丸東入', null, null);
INSERT INTO `ms_addresses` VALUES ('67990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区笹屋町東洞院通姉小路上る', '26', '26104', '6048187', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '笹屋町', 'ササヤチョウ', null, '東洞院通姉小路上る', null, null);
INSERT INTO `ms_addresses` VALUES ('67991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区笹屋町姉小路通東洞院東入', '26', '26104', '6048187', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '笹屋町', 'ササヤチョウ', null, '姉小路通東洞院東入', null, null);
INSERT INTO `ms_addresses` VALUES ('67992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区長浜町', '26', '26104', '6048201', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '長浜町', 'ナガハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('67993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区突抜町衣棚通姉小路下る', '26', '26104', '6048202', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '突抜町', 'ツキヌケチョウ', null, '衣棚通姉小路下る', null, null);
INSERT INTO `ms_addresses` VALUES ('67994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区突抜町衣棚通三条上る', '26', '26104', '6048202', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '突抜町', 'ツキヌケチョウ', null, '衣棚通三条上る', null, null);
INSERT INTO `ms_addresses` VALUES ('67995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区突抜町姉小路通室町西入', '26', '26104', '6048202', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '突抜町', 'ツキヌケチョウ', null, '姉小路通室町西入', null, null);
INSERT INTO `ms_addresses` VALUES ('67996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区突抜町姉小路通衣棚西入', '26', '26104', '6048202', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '突抜町', 'ツキヌケチョウ', null, '姉小路通衣棚西入', null, null);
INSERT INTO `ms_addresses` VALUES ('67997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区突抜町姉小路通衣棚東入', '26', '26104', '6048202', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '突抜町', 'ツキヌケチョウ', null, '姉小路通衣棚東入', null, null);
INSERT INTO `ms_addresses` VALUES ('67998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区突抜町姉小路通新町東入', '26', '26104', '6048202', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '突抜町', 'ツキヌケチョウ', null, '姉小路通新町東入', null, null);
INSERT INTO `ms_addresses` VALUES ('67999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区衣棚町', '26', '26104', '6048203', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '衣棚町', 'コロモノタナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区了頓図子町', '26', '26104', '6048204', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '了頓図子町', 'リョウトンズシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区三条町', '26', '26104', '6048205', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '三条町', 'サンジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区町頭町', '26', '26104', '6048206', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '町頭町', 'マチガシラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区神明町', '26', '26104', '6048207', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '神明町', 'シンメイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区玉蔵町', '26', '26104', '6048211', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '玉蔵町', 'タマクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区六角町', '26', '26104', '6048212', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '六角町', 'ロッカクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区姥柳町', '26', '26104', '6048213', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '姥柳町', 'ウバヤナギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区百足屋町新町通蛸薬師下る', '26', '26104', '6048214', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '百足屋町', 'ムカデヤチョウ', null, '新町通蛸薬師下る', null, null);
INSERT INTO `ms_addresses` VALUES ('68008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区百足屋町新町通錦小路上る', '26', '26104', '6048214', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '百足屋町', 'ムカデヤチョウ', null, '新町通錦小路上る', null, null);
INSERT INTO `ms_addresses` VALUES ('68009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区百足屋町蛸薬師通新町西入', '26', '26104', '6048214', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '百足屋町', 'ムカデヤチョウ', null, '蛸薬師通新町西入', null, null);
INSERT INTO `ms_addresses` VALUES ('68010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区百足屋町錦小路通新町西入', '26', '26104', '6048214', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '百足屋町', 'ムカデヤチョウ', null, '錦小路通新町西入', null, null);
INSERT INTO `ms_addresses` VALUES ('68011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区百足屋町錦小路通新町東入', '26', '26104', '6048214', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '百足屋町', 'ムカデヤチョウ', null, '錦小路通新町東入', null, null);
INSERT INTO `ms_addresses` VALUES ('68012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区不動町', '26', '26104', '6048215', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '不動町', 'フドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区池須町', '26', '26104', '6048216', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '池須町', 'イケスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区西六角町', '26', '26104', '6048217', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '西六角町', 'ニシロッカクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区天神山町', '26', '26104', '6048221', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '天神山町', 'テンジンヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区観音堂町', '26', '26104', '6048222', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '観音堂町', 'カンノンドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区小結棚町', '26', '26104', '6048223', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '小結棚町', 'コムスビダナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区炭之座町', '26', '26104', '6048224', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '炭之座町', 'スミノザチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区蟷螂山町', '26', '26104', '6048225', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '蟷螂山町', 'トウロウヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区西錦小路町', '26', '26104', '6048226', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '西錦小路町', 'ニシニシキコウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区古西町', '26', '26104', '6048227', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '古西町', 'フルニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区元本能寺南町', '26', '26104', '6048231', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '元本能寺南町', 'モトホンノウジミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区空也町', '26', '26104', '6048232', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '空也町', 'クウヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区藤本町', '26', '26104', '6048233', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '藤本町', 'フジモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区藤西町', '26', '26104', '6048234', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '藤西町', 'フジニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区錦堀川町', '26', '26104', '6048235', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '錦堀川町', 'ニシキホリカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区三文字町錦小路通堀川東入', '26', '26104', '6048236', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '三文字町', 'サンモンジチョウ', null, '錦小路通堀川東入', null, null);
INSERT INTO `ms_addresses` VALUES ('68028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区三文字町錦小路通油小路西入', '26', '26104', '6048236', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '三文字町', 'サンモンジチョウ', null, '錦小路通油小路西入', null, null);
INSERT INTO `ms_addresses` VALUES ('68029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区三文字町堀川通錦小路下る', '26', '26104', '6048236', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '三文字町', 'サンモンジチョウ', null, '堀川通錦小路下る', null, null);
INSERT INTO `ms_addresses` VALUES ('68030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区三文字町醒ケ井通錦小路下る', '26', '26104', '6048236', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '三文字町', 'サンモンジチョウ', null, '醒ケ井通錦小路下る', null, null);
INSERT INTO `ms_addresses` VALUES ('68031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区三文字町醒ケ井通錦小路東入', '26', '26104', '6048236', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '三文字町', 'サンモンジチョウ', null, '醒ケ井通錦小路東入', null, null);
INSERT INTO `ms_addresses` VALUES ('68032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区三文字町醒ケ井通錦小路西入', '26', '26104', '6048236', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '三文字町', 'サンモンジチョウ', null, '醒ケ井通錦小路西入', null, null);
INSERT INTO `ms_addresses` VALUES ('68033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区山田町', '26', '26104', '6048237', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '山田町', 'ヤマダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区釜座町', '26', '26104', '6048241', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '釜座町', 'カマンザチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区柳水町', '26', '26104', '6048242', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '柳水町', 'リュウスイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区本能寺町', '26', '26104', '6048243', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '本能寺町', 'ホンノウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区元本能寺町', '26', '26104', '6048244', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '元本能寺町', 'モトホンノウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区六角油小路町', '26', '26104', '6048245', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '六角油小路町', 'ロッカクアブラノコウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区猩々町', '26', '26104', '6048246', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '猩々町', 'ショウジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区塩屋町三条通西洞院西入', '26', '26104', '6048247', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '塩屋町', 'シオヤチョウ', null, '三条通西洞院西入', null, null);
INSERT INTO `ms_addresses` VALUES ('68041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区塩屋町三条通小川東入', '26', '26104', '6048247', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '塩屋町', 'シオヤチョウ', null, '三条通小川東入', null, null);
INSERT INTO `ms_addresses` VALUES ('68042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区塩屋町三条通小川西入', '26', '26104', '6048247', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '塩屋町', 'シオヤチョウ', null, '三条通小川西入', null, null);
INSERT INTO `ms_addresses` VALUES ('68043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区塩屋町三条通油小路東入', '26', '26104', '6048247', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '塩屋町', 'シオヤチョウ', null, '三条通油小路東入', null, null);
INSERT INTO `ms_addresses` VALUES ('68044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区三条油小路町', '26', '26104', '6048251', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '三条油小路町', 'サンジョウアブラノコウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区越後突抜町', '26', '26104', '6048252', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '越後突抜町', 'エチゴツキヌケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区亀屋町蛸薬師通堀川東入', '26', '26104', '6048253', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '亀屋町', 'カメヤチョウ', null, '蛸薬師通堀川東入', null, null);
INSERT INTO `ms_addresses` VALUES ('68047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区亀屋町堀川通蛸薬師下る', '26', '26104', '6048253', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '亀屋町', 'カメヤチョウ', null, '堀川通蛸薬師下る', null, null);
INSERT INTO `ms_addresses` VALUES ('68048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区亀屋町蛸薬師通油小路西入', '26', '26104', '6048253', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '亀屋町', 'カメヤチョウ', null, '蛸薬師通油小路西入', null, null);
INSERT INTO `ms_addresses` VALUES ('68049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区四坊堀川町', '26', '26104', '6048254', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '四坊堀川町', 'シボウホリカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区壺屋町堀川通六角下る', '26', '26104', '6048255', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '壺屋町', 'ツボヤチョウ', null, '堀川通六角下る', null, null);
INSERT INTO `ms_addresses` VALUES ('68051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区壺屋町六角通堀川東入', '26', '26104', '6048255', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '壺屋町', 'ツボヤチョウ', null, '六角通堀川東入', null, null);
INSERT INTO `ms_addresses` VALUES ('68052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区壺屋町堀川通蛸薬師上る', '26', '26104', '6048255', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '壺屋町', 'ツボヤチョウ', null, '堀川通蛸薬師上る', null, null);
INSERT INTO `ms_addresses` VALUES ('68053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区越後町', '26', '26104', '6048256', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '越後町', 'エチゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区橋浦町', '26', '26104', '6048257', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '橋浦町', 'ハシウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区橋東詰町', '26', '26104', '6048258', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '橋東詰町', 'ハシヒガシヅメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区式阿弥町', '26', '26104', '6048261', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '式阿弥町', 'シキアミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区宗林町', '26', '26104', '6048262', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '宗林町', 'ソウリンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区姉東堀川町', '26', '26104', '6048263', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '姉東堀川町', 'アネヒガシホリカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区姉西堀川町', '26', '26104', '6048264', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '姉西堀川町', 'アネニシホリカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区西三坊堀川町', '26', '26104', '6048265', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '西三坊堀川町', 'ニシサンボウホリカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区三坊堀川町', '26', '26104', '6048266', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '三坊堀川町', 'サンボウホリカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区鍛冶町', '26', '26104', '6048267', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '鍛冶町', 'カジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区津軽町', '26', '26104', '6048271', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '津軽町', 'ツガルチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区突抜町釜座通姉小路下る', '26', '26104', '6048272', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '突抜町', 'ツキヌケチョウ', null, '釜座通姉小路下る', null, null);
INSERT INTO `ms_addresses` VALUES ('68065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区突抜町釜座通三条上る', '26', '26104', '6048272', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '突抜町', 'ツキヌケチョウ', null, '釜座通三条上る', null, null);
INSERT INTO `ms_addresses` VALUES ('68066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区突抜町姉小路通新町西入', '26', '26104', '6048272', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '突抜町', 'ツキヌケチョウ', null, '姉小路通新町西入', null, null);
INSERT INTO `ms_addresses` VALUES ('68067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区突抜町姉小路通釜座西入', '26', '26104', '6048272', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '突抜町', 'ツキヌケチョウ', null, '姉小路通釜座西入', null, null);
INSERT INTO `ms_addresses` VALUES ('68068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区突抜町姉小路通釜座東入', '26', '26104', '6048272', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '突抜町', 'ツキヌケチョウ', null, '姉小路通釜座東入', null, null);
INSERT INTO `ms_addresses` VALUES ('68069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区突抜町姉小路通西洞院東入', '26', '26104', '6048272', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '突抜町', 'ツキヌケチョウ', null, '姉小路通西洞院東入', null, null);
INSERT INTO `ms_addresses` VALUES ('68070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区姉西洞院町', '26', '26104', '6048273', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '姉西洞院町', 'アネニシノトウインチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区西堂町', '26', '26104', '6048274', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '西堂町', 'セイドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区宮木町', '26', '26104', '6048275', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '宮木町', 'ミヤギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区壺屋町小川通御池下る', '26', '26104', '6048276', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '壺屋町', 'ツボヤチョウ', null, '小川通御池下る', null, null);
INSERT INTO `ms_addresses` VALUES ('68074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区壺屋町小川通姉小路上る', '26', '26104', '6048276', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '壺屋町', 'ツボヤチョウ', null, '小川通姉小路上る', null, null);
INSERT INTO `ms_addresses` VALUES ('68075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区三坊西洞院町', '26', '26104', '6048277', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '三坊西洞院町', 'サンボウニシノトウインチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区二条城町', '26', '26104', '6048301', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '二条城町', 'ニジョウジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区池元町', '26', '26104', '6048302', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '池元町', 'イケモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区最上町', '26', '26104', '6048303', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '最上町', 'モガミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区織物屋町', '26', '26104', '6048304', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '織物屋町', 'オリモノヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区市之町', '26', '26104', '6048305', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '市之町', 'イチノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区門前町', '26', '26104', '6048306', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '門前町', 'モンゼンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区俵屋町御池通猪熊西入', '26', '26104', '6048311', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '俵屋町', 'タワラヤチョウ', null, '御池通猪熊西入', null, null);
INSERT INTO `ms_addresses` VALUES ('68083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区俵屋町御池通黒門東入', '26', '26104', '6048311', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '俵屋町', 'タワラヤチョウ', null, '御池通黒門東入', null, null);
INSERT INTO `ms_addresses` VALUES ('68084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区上巴町', '26', '26104', '6048312', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '上巴町', 'カミトモエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区三坊猪熊町北組', '26', '26104', '6048313', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '三坊猪熊町北組', 'サンボウイノクマチョウキタグミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区三坊猪熊町南組', '26', '26104', '6048314', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '三坊猪熊町南組', 'サンボウイノクマチョウミナミグミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区大文字町黒門通御池下る', '26', '26104', '6048315', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '大文字町', 'ダイモンジチョウ', null, '黒門通御池下る', null, null);
INSERT INTO `ms_addresses` VALUES ('68088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区大文字町黒門通姉小路上る', '26', '26104', '6048315', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '大文字町', 'ダイモンジチョウ', null, '黒門通姉小路上る', null, null);
INSERT INTO `ms_addresses` VALUES ('68089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区大文字町御池通黒門西入', '26', '26104', '6048315', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '大文字町', 'ダイモンジチョウ', null, '御池通黒門西入', null, null);
INSERT INTO `ms_addresses` VALUES ('68090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区大文字町御池通黒門東入', '26', '26104', '6048315', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '大文字町', 'ダイモンジチョウ', null, '御池通黒門東入', null, null);
INSERT INTO `ms_addresses` VALUES ('68091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区大文字町御池通猪熊西入', '26', '26104', '6048315', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '大文字町', 'ダイモンジチョウ', null, '御池通猪熊西入', null, null);
INSERT INTO `ms_addresses` VALUES ('68092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区三坊大宮町', '26', '26104', '6048316', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '三坊大宮町', 'サンボウオオミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区倉本町', '26', '26104', '6048321', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '倉本町', 'クラモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区樽屋町', '26', '26104', '6048322', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '樽屋町', 'タルヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区上八文字町', '26', '26104', '6048323', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '上八文字町', 'カミハチモンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区姉猪熊町', '26', '26104', '6048324', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '姉猪熊町', 'アネイノクマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区上一文字町', '26', '26104', '6048325', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '上一文字町', 'カミイチモンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区姉大宮町東側', '26', '26104', '6048326', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '姉大宮町東側', 'アネオオミヤチョウヒガシガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区姉大宮町西側', '26', '26104', '6048327', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '姉大宮町西側', 'アネオオミヤチョウニシガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区御供町', '26', '26104', '6048331', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '御供町', 'オントモチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区橋西町', '26', '26104', '6048332', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '橋西町', 'ハシニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区下八文字町', '26', '26104', '6048333', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '下八文字町', 'シモハチモンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区三条猪熊町', '26', '26104', '6048334', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '三条猪熊町', 'サンジョウイノクマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区下一文字町', '26', '26104', '6048335', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '下一文字町', 'シモイチモンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区三条大宮町', '26', '26104', '6048336', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '三条大宮町', 'サンジョウオオミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区岩上町', '26', '26104', '6048341', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '岩上町', 'イワガミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区六角猪熊町', '26', '26104', '6048342', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '六角猪熊町', 'ロッカクイノクマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区上黒門町', '26', '26104', '6048343', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '上黒門町', 'カミクロモンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区六角大宮町', '26', '26104', '6048344', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '六角大宮町', 'ロッカクオオミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区鍛冶屋町六角通猪熊西入', '26', '26104', '6048345', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '鍛冶屋町', 'カジヤチョウ', null, '六角通猪熊西入', null, null);
INSERT INTO `ms_addresses` VALUES ('68111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区鍛冶屋町六角通黒門東入', '26', '26104', '6048345', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '鍛冶屋町', 'カジヤチョウ', null, '六角通黒門東入', null, null);
INSERT INTO `ms_addresses` VALUES ('68112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区鍛冶屋町六角通黒門西入', '26', '26104', '6048345', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '鍛冶屋町', 'カジヤチョウ', null, '六角通黒門西入', null, null);
INSERT INTO `ms_addresses` VALUES ('68113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区鍛冶屋町六角通大宮東入', '26', '26104', '6048345', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '鍛冶屋町', 'カジヤチョウ', null, '六角通大宮東入', null, null);
INSERT INTO `ms_addresses` VALUES ('68114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区畳屋町', '26', '26104', '6048351', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '畳屋町', 'タタミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区金屋町', '26', '26104', '6048352', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '金屋町', 'カナヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区宮本町', '26', '26104', '6048353', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '宮本町', 'ミヤモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区下瓦町', '26', '26104', '6048354', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '下瓦町', 'シモカワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区下黒門町', '26', '26104', '6048355', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '下黒門町', 'シモクロモンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区四坊大宮町', '26', '26104', '6048356', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '四坊大宮町', 'シボウオオミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区吉野町', '26', '26104', '6048361', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '吉野町', 'ヨシノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区松浦町', '26', '26104', '6048362', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '松浦町', 'マツウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区錦猪熊町', '26', '26104', '6048363', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '錦猪熊町', 'ニシキイノクマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区藤岡町', '26', '26104', '6048364', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '藤岡町', 'フジオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区錦大宮町', '26', '26104', '6048365', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '錦大宮町', 'ニシキオオミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区七軒町', '26', '26104', '6048366', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '七軒町', 'シチケンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区神泉苑町', '26', '26104', '6048371', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '神泉苑町', 'シンセンエンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区姉西町', '26', '26104', '6048372', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '姉西町', 'アネニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区瓦師町', '26', '26104', '6048373', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '瓦師町', 'カワラシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区上瓦町', '26', '26104', '6048374', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '上瓦町', 'カミカワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区西ノ京池ノ内町', '26', '26104', '6048375', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '西ノ京池ノ内町', 'ニシノキョウイケノウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区西ノ京職司町', '26', '26104', '6048381', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '西ノ京職司町', 'ニシノキョウショクシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区西ノ京北聖町', '26', '26104', '6048382', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '西ノ京北聖町', 'ニシノキョウホクセイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区西ノ京小堀町', '26', '26104', '6048383', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '西ノ京小堀町', 'ニシノキョウコボリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区西ノ京式部町', '26', '26104', '6048384', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '西ノ京式部町', 'ニシノキョウシキブチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区聚楽廻松下町', '26', '26104', '6048401', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '聚楽廻松下町', 'ジュラクマワリマツシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区聚楽廻西町', '26', '26104', '6048402', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '聚楽廻西町', 'ジュラクマワリニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区聚楽廻中町', '26', '26104', '6048403', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '聚楽廻中町', 'ジュラクマワリナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区聚楽廻東町', '26', '26104', '6048404', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '聚楽廻東町', 'ジュラクマワリヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区西ノ京車坂町', '26', '26104', '6048405', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '西ノ京車坂町', 'ニシノキョウクルマザカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区聚楽廻南町', '26', '26104', '6048411', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '聚楽廻南町', 'ジュラクマワリミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区西ノ京南聖町', '26', '26104', '6048412', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '西ノ京南聖町', 'ニシノキョウナンセイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区西ノ京勧学院町', '26', '26104', '6048413', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '西ノ京勧学院町', 'ニシノキョウカンガクインチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区西ノ京小倉町', '26', '26104', '6048414', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '西ノ京小倉町', 'ニシノキョウオグラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区西ノ京栂尾町', '26', '26104', '6048415', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '西ノ京栂尾町', 'ニシノキョウトガノオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区西ノ京星池町', '26', '26104', '6048416', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '西ノ京星池町', 'ニシノキョウホシガイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区西ノ京内畑町', '26', '26104', '6048417', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '西ノ京内畑町', 'ニシノキョウウチハタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区西ノ京永本町', '26', '26104', '6048421', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '西ノ京永本町', 'ニシノキョウナガモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区西ノ京東月光町', '26', '26104', '6048422', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '西ノ京東月光町', 'ニシノキョウヒガシゲッコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区西ノ京西月光町', '26', '26104', '6048423', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '西ノ京西月光町', 'ニシノキョウニシゲツコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区西ノ京樋ノ口町', '26', '26104', '6048424', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '西ノ京樋ノ口町', 'ニシノキョウヒノクチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区西ノ京銅駝町', '26', '26104', '6048425', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '西ノ京銅駝町', 'ニシノキョウドウダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区西ノ京船塚町', '26', '26104', '6048426', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '西ノ京船塚町', 'ニシノキョウフナヅカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区西ノ京原町', '26', '26104', '6048431', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '西ノ京原町', 'ニシノキョウハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区西ノ京南原町', '26', '26104', '6048432', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '西ノ京南原町', 'ニシノキョウミナミハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区西ノ京北小路町', '26', '26104', '6048433', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '西ノ京北小路町', 'ニシノキョウキタコウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区西ノ京新建町', '26', '26104', '6048434', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '西ノ京新建町', 'ニシノキョウシンダテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区西ノ京三条坊町', '26', '26104', '6048435', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '西ノ京三条坊町', 'ニシノキョウサンジョウボウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区西ノ京下合町', '26', '26104', '6048436', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '西ノ京下合町', 'ニシノキョウシモアイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区西ノ京東中合町', '26', '26104', '6048437', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '西ノ京東中合町', 'ニシノキョウヒガシナカアイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区西ノ京西中合町', '26', '26104', '6048441', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '西ノ京西中合町', 'ニシノキョウニシナカアイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区西ノ京桑原町', '26', '26104', '6048442', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '西ノ京桑原町', 'ニシノキョウクワバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区西ノ京島ノ内町', '26', '26104', '6048443', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '西ノ京島ノ内町', 'ニシノキョウシマノウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区西ノ京月輪町', '26', '26104', '6048444', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '西ノ京月輪町', 'ニシノキョウツキノワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区西ノ京徳大寺町', '26', '26104', '6048445', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '西ノ京徳大寺町', 'ニシノキョウトクダイジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区西ノ京日扇町', '26', '26104', '6048446', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '西ノ京日扇町', 'ニシノキョウヒオウギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区西ノ京御輿岡町', '26', '26104', '6048451', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '西ノ京御輿岡町', 'ニシノキョウミコシガオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区西ノ京伯楽町', '26', '26104', '6048452', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '西ノ京伯楽町', 'ニシノキョウハクラクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区西ノ京春日町', '26', '26104', '6048453', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '西ノ京春日町', 'ニシノキョウカスガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区西ノ京小堀池町', '26', '26104', '6048454', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '西ノ京小堀池町', 'ニシノキョウコボリイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区西ノ京藤ノ木町', '26', '26104', '6048455', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '西ノ京藤ノ木町', 'ニシノキョウフジノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区西ノ京壺ノ内町', '26', '26104', '6048456', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '西ノ京壺ノ内町', 'ニシノキョウツボノウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区西ノ京馬代町', '26', '26104', '6048457', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '西ノ京馬代町', 'ニシノキョウバダイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区西ノ京中保町', '26', '26104', '6048461', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '西ノ京中保町', 'ニシノキョウナカホチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区西ノ京北円町', '26', '26104', '6048462', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '西ノ京北円町', 'ニシノキョウキタエンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区西ノ京円町', '26', '26104', '6048463', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '西ノ京円町', 'ニシノキョウエンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区西ノ京南円町', '26', '26104', '6048464', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '西ノ京南円町', 'ニシノキョウミナミエンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区西ノ京西円町', '26', '26104', '6048465', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '西ノ京西円町', 'ニシノキョウニシエンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区西ノ京南大炊御門町', '26', '26104', '6048466', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '西ノ京南大炊御門町', 'ニシノキョウミナミオオイゴモンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区西ノ京大炊御門町', '26', '26104', '6048467', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '西ノ京大炊御門町', 'ニシノキョウオオイゴモンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区西ノ京中御門東町', '26', '26104', '6048471', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '西ノ京中御門東町', 'ニシノキョウナカゴモンヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区西ノ京北壺井町', '26', '26104', '6048472', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '西ノ京北壺井町', 'ニシノキョウキタツボイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区西ノ京南壺井町', '26', '26104', '6048473', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '西ノ京南壺井町', 'ニシノキョウミナミツボイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区西ノ京塚本町', '26', '26104', '6048474', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '西ノ京塚本町', 'ニシノキョウツカモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区西ノ京中御門西町', '26', '26104', '6048475', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '西ノ京中御門西町', 'ニシノキョウナカゴモンニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区西ノ京冷泉町', '26', '26104', '6048481', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '西ノ京冷泉町', 'ニシノキョウレイセンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区西ノ京笠殿町', '26', '26104', '6048482', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '西ノ京笠殿町', 'ニシノキョウカサドノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区西ノ京南上合町', '26', '26104', '6048483', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '西ノ京南上合町', 'ニシノキョウミナミカミアイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区西ノ京上合町', '26', '26104', '6048484', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '西ノ京上合町', 'ニシノキョウカミアイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区西ノ京平町', '26', '26104', '6048485', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '西ノ京平町', 'ニシノキョウヒラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区西ノ京左馬寮町', '26', '26104', '6048491', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '西ノ京左馬寮町', 'ニシノキョウサマリョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区西ノ京右馬寮町', '26', '26104', '6048492', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '西ノ京右馬寮町', 'ニシノキョウウマリョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区西ノ京南両町', '26', '26104', '6048493', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '西ノ京南両町', 'ニシノキョウミナミリョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区西ノ京上平町', '26', '26104', '6048494', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '西ノ京上平町', 'ニシノキョウカミヒラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区西ノ京西鹿垣町', '26', '26104', '6048495', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '西ノ京西鹿垣町', 'ニシノキョウニシシカガキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区西ノ京鹿垣町', '26', '26104', '6048496', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '西ノ京鹿垣町', 'ニシノキョウシカガキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区西ノ京両町', '26', '26104', '6048497', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '西ノ京両町', 'ニシノキョウリョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区今新在家西町', '26', '26104', '6048801', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '今新在家西町', 'イマシンザイケニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区今新在家東町', '26', '26104', '6048802', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '今新在家東町', 'イマシンザイケヒガシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区因幡町', '26', '26104', '6048803', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '因幡町', 'イナバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区壬生坊城町', '26', '26104', '6048804', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '壬生坊城町', 'ミブボウジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区壬生馬場町', '26', '26104', '6048805', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '壬生馬場町', 'ミブバンバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区壬生賀陽御所町', '26', '26104', '6048811', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '壬生賀陽御所町', 'ミブカヨウゴショチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区壬生相合町', '26', '26104', '6048812', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '壬生相合町', 'ミブアイアイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区壬生梛ノ宮町', '26', '26104', '6048821', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '壬生梛ノ宮町', 'ミブナギノミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区壬生辻町', '26', '26104', '6048822', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '壬生辻町', 'ミブツジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区壬生松原町', '26', '26104', '6048823', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '壬生松原町', 'ミブマツバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区壬生高樋町', '26', '26104', '6048824', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '壬生高樋町', 'ミブタカヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区壬生森前町', '26', '26104', '6048831', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '壬生森前町', 'ミブモリマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区壬生下溝町', '26', '26104', '6048832', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '壬生下溝町', 'ミブシモミゾチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区壬生東土居ノ内町', '26', '26104', '6048841', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '壬生東土居ノ内町', 'ミブヒガシドイノウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区壬生土居ノ内町', '26', '26104', '6048842', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '壬生土居ノ内町', 'ミブドイノウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区壬生東桧町', '26', '26104', '6048843', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '壬生東桧町', 'ミブヒガシヒノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区壬生桧町', '26', '26104', '6048844', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '壬生桧町', 'ミブヒノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区壬生東高田町', '26', '26104', '6048845', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '壬生東高田町', 'ミブヒガシタカダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区壬生西桧町', '26', '26104', '6048846', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '壬生西桧町', 'ミブニシヒノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区壬生西土居ノ内町', '26', '26104', '6048847', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '壬生西土居ノ内町', 'ミブニシドイノウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区壬生上大竹町', '26', '26104', '6048851', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '壬生上大竹町', 'ミブカミオオタケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区壬生東大竹町', '26', '26104', '6048852', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '壬生東大竹町', 'ミブヒガシオオタケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区壬生東淵田町', '26', '26104', '6048853', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '壬生東淵田町', 'ミブヒガシフチダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区壬生仙念町', '26', '26104', '6048854', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '壬生仙念町', 'ミブセンネンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区壬生淵田町', '26', '26104', '6048855', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '壬生淵田町', 'ミブフチダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区壬生西大竹町', '26', '26104', '6048856', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '壬生西大竹町', 'ミブニシオオタケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区壬生神明町', '26', '26104', '6048861', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '壬生神明町', 'ミブシンメイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区壬生森町', '26', '26104', '6048862', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '壬生森町', 'ミブモリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区壬生中川町', '26', '26104', '6048863', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '壬生中川町', 'ミブナカガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区壬生朱雀町', '26', '26104', '6048871', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '壬生朱雀町', 'ミブシュジャクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区壬生御所ノ内町', '26', '26104', '6048872', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '壬生御所ノ内町', 'ミブゴショノウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区壬生花井町', '26', '26104', '6048873', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '壬生花井町', 'ミブハナイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市中京区壬生天池町', '26', '26104', '6048874', '京都府', 'キョウトフ', '京都市中京区', 'キョウトシナカギョウク', '壬生天池町', 'ミブアマガイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区', '26', '26105', '6050000', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('68252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区二町目', '26', '26105', '6050001', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '二町目', 'ニチョウメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区教業町', '26', '26105', '6050002', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '教業町', 'キョウギョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区若竹町', '26', '26105', '6050003', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '若竹町', 'ワカタケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区若松町', '26', '26105', '6050004', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '若松町', 'ワカマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区三町目', '26', '26105', '6050005', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '三町目', 'サンチョウメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区新五軒町', '26', '26105', '6050006', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '新五軒町', 'シンゴケンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区五軒町大和大路通三条下る', '26', '26105', '6050007', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '五軒町', 'ゴケンチョウ', null, '大和大路通三条下る', null, null);
INSERT INTO `ms_addresses` VALUES ('68259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区五軒町大和大路通三条下る西入', '26', '26105', '6050007', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '五軒町', 'ゴケンチョウ', null, '大和大路通三条下る西入', null, null);
INSERT INTO `ms_addresses` VALUES ('68260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区大黒町大和大路三条下る', '26', '26105', '6050008', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '大黒町', 'ダイコクチョウ', null, '大和大路三条下る', null, null);
INSERT INTO `ms_addresses` VALUES ('68261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区大橋町', '26', '26105', '6050009', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '大橋町', 'オオハシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区七軒町三条大橋東4丁目', '26', '26105', '6050011', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '七軒町', 'シチケンチョウ', null, '三条大橋東4丁目', null, null);
INSERT INTO `ms_addresses` VALUES ('68263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区七軒町三条大橋東入4丁目', '26', '26105', '6050011', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '七軒町', 'シチケンチョウ', null, '三条大橋東入4丁目', null, null);
INSERT INTO `ms_addresses` VALUES ('68264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区西海子町', '26', '26105', '6050012', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '西海子町', 'サイカイシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区南西海子町', '26', '26105', '6050013', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '南西海子町', 'ミナミサイカイシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区北木之元町', '26', '26105', '6050014', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '北木之元町', 'キタキノモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区南木之元町', '26', '26105', '6050015', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '南木之元町', 'ミナミキノモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区進之町', '26', '26105', '6050016', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '進之町', 'シンノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区高畑町', '26', '26105', '6050017', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '高畑町', 'タカバタケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区巽町', '26', '26105', '6050018', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '巽町', 'タツミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区長光町', '26', '26105', '6050019', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '長光町', 'ナガミツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区石泉院町', '26', '26105', '6050021', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '石泉院町', 'セキセンインチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区大井手町', '26', '26105', '6050022', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '大井手町', 'オオイデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区今小路町', '26', '26105', '6050023', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '今小路町', 'イマコウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区土居之内町', '26', '26105', '6050024', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '土居之内町', 'ドイノウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区堤町', '26', '26105', '6050025', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '堤町', 'ツツミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区古川町', '26', '26105', '6050026', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '古川町', 'フルカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区八軒町', '26', '26105', '6050027', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '八軒町', 'ハチケンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区分木町', '26', '26105', '6050028', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '分木町', 'ブンキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区東姉小路町', '26', '26105', '6050029', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '東姉小路町', 'ヒガシアネコウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区定法寺町', '26', '26105', '6050031', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '定法寺町', 'ジョウホウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区柚之木町', '26', '26105', '6050032', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '柚之木町', 'ユノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区夷町', '26', '26105', '6050033', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '夷町', 'エビスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区中之町三条通神宮道東入2丁目', '26', '26105', '6050034', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '中之町', 'ナカノチョウ', null, '三条通神宮道東入2丁目', null, null);
INSERT INTO `ms_addresses` VALUES ('68285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区中之町三条通白川橋東入4丁目', '26', '26105', '6050034', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '中之町', 'ナカノチョウ', null, '三条通白川橋東入4丁目', null, null);
INSERT INTO `ms_addresses` VALUES ('68286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区中之町三条通白川橋東4丁目', '26', '26105', '6050034', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '中之町', 'ナカノチョウ', null, '三条通白川橋東4丁目', null, null);
INSERT INTO `ms_addresses` VALUES ('68287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区粟田口三条坊町', '26', '26105', '6050035', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '粟田口三条坊町', 'アワダグチサンジョウボウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区五軒町三条通白川橋東入', '26', '26105', '6050036', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '五軒町', 'ゴケンチョウ', null, '三条通白川橋東入', null, null);
INSERT INTO `ms_addresses` VALUES ('68289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区五軒町三条通白川橋下る東入', '26', '26105', '6050036', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '五軒町', 'ゴケンチョウ', null, '三条通白川橋下る東入', null, null);
INSERT INTO `ms_addresses` VALUES ('68290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区五軒町白川筋三条下る', '26', '26105', '6050036', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '五軒町', 'ゴケンチョウ', null, '白川筋三条下る', null, null);
INSERT INTO `ms_addresses` VALUES ('68291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区西町', '26', '26105', '6050037', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '西町', 'ニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区堀池町', '26', '26105', '6050038', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '堀池町', 'ホリイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区東町', '26', '26105', '6050041', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '東町', 'ヒガシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区今道町', '26', '26105', '6050042', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '今道町', 'イマミチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区西小物座町', '26', '26105', '6050043', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '西小物座町', 'ニシコモノザチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区東小物座町', '26', '26105', '6050044', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '東小物座町', 'ヒガシコモノザチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区谷川町', '26', '26105', '6050045', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '谷川町', 'タニガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区東分木町', '26', '26105', '6050046', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '東分木町', 'ヒガシブンキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区粟田口鍛冶町', '26', '26105', '6050051', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '粟田口鍛冶町', 'アワダグチカジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区粟田口華頂町', '26', '26105', '6050052', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '粟田口華頂町', 'アワダグチカチョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区梅宮町', '26', '26105', '6050061', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '梅宮町', 'ウメミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区林下町', '26', '26105', '6050062', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '林下町', 'リンカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区松原町', '26', '26105', '6050063', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '松原町', 'マツバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区梅本町', '26', '26105', '6050064', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '梅本町', 'ウメモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区古西町', '26', '26105', '6050065', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '古西町', 'フルニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区石橋町', '26', '26105', '6050066', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '石橋町', 'イシバシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区稲荷町南組', '26', '26105', '6050067', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '稲荷町南組', 'イナリチョウミナミグミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区稲荷町北組', '26', '26105', '6050068', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '稲荷町北組', 'イナリチョウキタグミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区唐戸鼻町', '26', '26105', '6050069', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '唐戸鼻町', 'カラトハナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区円山町', '26', '26105', '6050071', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '円山町', 'マルヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区鷲尾町', '26', '26105', '6050072', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '鷲尾町', 'ワシオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区祇園町北側', '26', '26105', '6050073', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '祇園町北側', 'ギオンマチキタガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区祇園町南側', '26', '26105', '6050074', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '祇園町南側', 'ギオンマチミナミガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区中之町四条通大和大路西入', '26', '26105', '6050075', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '中之町', 'ナカノチョウ', null, '四条通大和大路西入', null, null);
INSERT INTO `ms_addresses` VALUES ('68315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区川端町', '26', '26105', '6050076', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '川端町', 'カワバタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区廿一軒町', '26', '26105', '6050077', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '廿一軒町', 'ニジュウイッケンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区富永町', '26', '26105', '6050078', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '富永町', 'トミナガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区常盤町大和大路通四条上る', '26', '26105', '6050079', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '常盤町', 'トキワチョウ', null, '大和大路通四条上る', null, null);
INSERT INTO `ms_addresses` VALUES ('68319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区常盤町川端通四条上る', '26', '26105', '6050079', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '常盤町', 'トキワチョウ', null, '川端通四条上る', null, null);
INSERT INTO `ms_addresses` VALUES ('68320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区三吉町', '26', '26105', '6050081', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '三吉町', 'ミヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区中之町新門前通大和大路東入', '26', '26105', '6050082', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '中之町', 'ナカノチョウ', null, '新門前通大和大路東入', null, null);
INSERT INTO `ms_addresses` VALUES ('68322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区中之町新門前通大和大路東入2丁目', '26', '26105', '6050082', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '中之町', 'ナカノチョウ', null, '新門前通大和大路東入2丁目', null, null);
INSERT INTO `ms_addresses` VALUES ('68323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区橋本町', '26', '26105', '6050083', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '橋本町', 'ハシモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区清本町', '26', '26105', '6050084', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '清本町', 'キヨモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区末吉町', '26', '26105', '6050085', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '末吉町', 'スエヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区弁財天町', '26', '26105', '6050086', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '弁財天町', 'ベンザイテンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区元吉町', '26', '26105', '6050087', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '元吉町', 'モトヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区西之町', '26', '26105', '6050088', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '西之町', 'ニシノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区元町', '26', '26105', '6050089', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '元町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区宮川筋', '26', '26105', '6050801', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '宮川筋', 'ミヤガワスジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区大和町', '26', '26105', '6050802', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '大和町', 'ヤマトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区亀井町', '26', '26105', '6050803', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '亀井町', 'カメイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区井手町', '26', '26105', '6050804', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '井手町', 'イデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区博多町', '26', '26105', '6050805', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '博多町', 'ハカタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区六軒町', '26', '26105', '6050806', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '六軒町', 'ロッケンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区上柳町', '26', '26105', '6050807', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '上柳町', 'カミヤナギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区下柳町', '26', '26105', '6050808', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '下柳町', 'シモヤナギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区小松町', '26', '26105', '6050811', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '小松町', 'コマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区毘沙門町', '26', '26105', '6050812', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '毘沙門町', 'ビシャモンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区轆轤町', '26', '26105', '6050813', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '轆轤町', 'ロクロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区薬師町', '26', '26105', '6050814', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '薬師町', 'ヤクシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区北御門町', '26', '26105', '6050815', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '北御門町', 'キタゴモンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区西御門町', '26', '26105', '6050816', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '西御門町', 'ニシゴモンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区弓矢町', '26', '26105', '6050817', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '弓矢町', 'ユミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区清井町', '26', '26105', '6050821', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '清井町', 'キヨイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区上弁天町', '26', '26105', '6050822', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '上弁天町', 'カミベンテンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区下弁天町', '26', '26105', '6050823', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '下弁天町', 'シモベンテンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区南町', '26', '26105', '6050824', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '南町', 'ミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区下河原町', '26', '26105', '6050825', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '下河原町', 'シモカワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区桝屋町', '26', '26105', '6050826', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '桝屋町', 'マスヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区八坂上町', '26', '26105', '6050827', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '八坂上町', 'ヤサカカミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区金園町', '26', '26105', '6050828', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '金園町', 'キンエンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区月見町', '26', '26105', '6050829', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '月見町', 'ツキミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区山城町', '26', '26105', '6050831', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '山城町', 'ヤマシロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区大黒町大黒町通柿町下る', '26', '26105', '6050832', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '大黒町', 'ダイコクチョウ', null, '大黒町通柿町下る', null, null);
INSERT INTO `ms_addresses` VALUES ('68356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区大黒町大黒町通五条上る', '26', '26105', '6050832', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '大黒町', 'ダイコクチョウ', null, '大黒町通五条上る', null, null);
INSERT INTO `ms_addresses` VALUES ('68357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区大黒町大黒町通五条上る2丁目', '26', '26105', '6050832', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '大黒町', 'ダイコクチョウ', null, '大黒町通五条上る2丁目', null, null);
INSERT INTO `ms_addresses` VALUES ('68358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区大黒町大黒町通松原下る3丁目', '26', '26105', '6050832', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '大黒町', 'ダイコクチョウ', null, '大黒町通松原下る3丁目', null, null);
INSERT INTO `ms_addresses` VALUES ('68359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区音羽町', '26', '26105', '6050833', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '音羽町', 'オトワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区金屋町', '26', '26105', '6050834', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '金屋町', 'カナヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区田中町', '26', '26105', '6050835', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '田中町', 'タナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区森下町', '26', '26105', '6050836', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '森下町', 'モリシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区山田町', '26', '26105', '6050837', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '山田町', 'ヤマダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区西川原町', '26', '26105', '6050838', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '西川原町', 'ニシカワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区東川原町', '26', '26105', '6050839', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '東川原町', 'ヒガシカワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区山崎町', '26', '26105', '6050841', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '山崎町', 'ヤマザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区三盛町', '26', '26105', '6050842', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '三盛町', 'ミツモリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区門脇町', '26', '26105', '6050843', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '門脇町', 'カドワキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区多門町', '26', '26105', '6050844', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '多門町', 'タモンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区竹村町', '26', '26105', '6050845', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '竹村町', 'タケムラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区五条橋東', '26', '26105', '6050846', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '五条橋東', 'ゴジョウハシヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区東橋詰町', '26', '26105', '6050847', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '東橋詰町', 'ヒガシハシヅメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区池殿町', '26', '26105', '6050848', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '池殿町', 'イケドノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区玉水町', '26', '26105', '6050851', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '玉水町', 'タマミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区上田町', '26', '26105', '6050852', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '上田町', 'ウエダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区星野町', '26', '26105', '6050853', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '星野町', 'ホシノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区月輪町', '26', '26105', '6050854', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '月輪町', 'ツキノワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区辰巳町東大路松原上る', '26', '26105', '6050855', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '辰巳町', 'タツミチョウ', null, '東大路松原上る', null, null);
INSERT INTO `ms_addresses` VALUES ('68379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区新シ町', '26', '26105', '6050856', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '新シ町', 'アタラシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区興善町', '26', '26105', '6050857', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '興善町', 'コウゼンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区小島町', '26', '26105', '6050858', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '小島町', 'コジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区清閑寺霊山町', '26', '26105', '6050861', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '清閑寺霊山町', 'セイカンジリョウザンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区清水', '26', '26105', '6050862', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '清水', 'キヨミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区梅林町', '26', '26105', '6050863', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '梅林町', 'バイリンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区遊行前町', '26', '26105', '6050864', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '遊行前町', 'ユウギョウマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区白糸町', '26', '26105', '6050865', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '白糸町', 'シライトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区慈法院庵町', '26', '26105', '6050871', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '慈法院庵町', 'ジホウインアンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区東音羽町', '26', '26105', '6050872', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '東音羽町', 'ヒガシオトワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区下馬町', '26', '26105', '6050873', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '下馬町', 'シモウマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区常盤町東大路通渋谷上る', '26', '26105', '6050874', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '常盤町', 'トキワチョウ', null, '東大路通渋谷上る', null, null);
INSERT INTO `ms_addresses` VALUES ('68391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区常盤町渋谷通東大路東入', '26', '26105', '6050874', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '常盤町', 'トキワチョウ', null, '渋谷通東大路東入', null, null);
INSERT INTO `ms_addresses` VALUES ('68392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区常盤町渋谷通東大路東入2丁目', '26', '26105', '6050874', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '常盤町', 'トキワチョウ', null, '渋谷通東大路東入2丁目', null, null);
INSERT INTO `ms_addresses` VALUES ('68393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区常盤町東大路五条下る', '26', '26105', '6050874', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '常盤町', 'トキワチョウ', null, '東大路五条下る', null, null);
INSERT INTO `ms_addresses` VALUES ('68394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区鐘鋳町', '26', '26105', '6050875', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '鐘鋳町', 'カネイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区上梅屋町', '26', '26105', '6050876', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '上梅屋町', 'カミウメヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区上新シ町', '26', '26105', '6050877', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '上新シ町', 'カミアタラシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区芳野町', '26', '26105', '6050878', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '芳野町', 'ヨシノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区朱雀町', '26', '26105', '6050901', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '朱雀町', 'スジャクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区鞘町', '26', '26105', '6050902', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '鞘町', 'サヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区上人町', '26', '26105', '6050903', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '上人町', 'ショウニンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区大阪町', '26', '26105', '6050904', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '大阪町', 'オオサカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区豊浦町', '26', '26105', '6050905', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '豊浦町', 'トヨウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区東橘町', '26', '26105', '6050906', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '東橘町', 'ヒガシタチバナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区西橘町', '26', '26105', '6050907', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '西橘町', 'ニシタチバナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区正面町', '26', '26105', '6050908', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '正面町', 'ショウメンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区鍵屋町', '26', '26105', '6050909', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '鍵屋町', 'カギヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区袋町', '26', '26105', '6050911', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '袋町', 'フクロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区石垣町西側', '26', '26105', '6050912', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '石垣町西側', 'イシガキマチニシガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区石垣町東側', '26', '26105', '6050913', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '石垣町東側', 'イシガキマチヒガシガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区下新シ町', '26', '26105', '6050914', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '下新シ町', 'シモアタラシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区下梅屋町', '26', '26105', '6050915', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '下梅屋町', 'シモウメヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区上棟梁町', '26', '26105', '6050916', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '上棟梁町', 'カミトウリョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区蛭子町北組', '26', '26105', '6050917', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '蛭子町北組', 'エビスチョウキタグミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区北棟梁町', '26', '26105', '6050918', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '北棟梁町', 'キタトウリョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区瓦役町', '26', '26105', '6050921', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '瓦役町', 'カワラヤクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区清閑寺山ノ内町', '26', '26105', '6050922', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '清閑寺山ノ内町', 'セイカンジヤマノウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区清閑寺池田町', '26', '26105', '6050923', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '清閑寺池田町', 'セイカンジイケダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区今熊野阿弥陀ケ峰町', '26', '26105', '6050924', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '今熊野阿弥陀ケ峰町', 'イマグマノアミダガミネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区今熊野日吉町', '26', '26105', '6050925', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '今熊野日吉町', 'イマグマノヒヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区今熊野北日吉町', '26', '26105', '6050926', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '今熊野北日吉町', 'イマグマノキタヒヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区上馬町', '26', '26105', '6050927', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '上馬町', 'カミウマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区茶屋町', '26', '26105', '6050931', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '茶屋町', 'チャヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区妙法院前側町', '26', '26105', '6050932', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '妙法院前側町', 'ミョウホウインマエカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区大和大路', '26', '26105', '6050933', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '大和大路', 'ヤマトオオジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区塗師屋町', '26', '26105', '6050934', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '塗師屋町', 'ヌシヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区西棟梁町', '26', '26105', '6050935', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '西棟梁町', 'ニシトウリョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区蛭子町南組', '26', '26105', '6050936', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '蛭子町南組', 'エビスチョウミナミグミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区下棟梁町', '26', '26105', '6050937', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '下棟梁町', 'シモトウリョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区南梅屋町', '26', '26105', '6050938', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '南梅屋町', 'ミナミウメヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区三十三間堂廻り町', '26', '26105', '6050941', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '三十三間堂廻り町', 'サンジュウサンゲンドウマワリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区蒔田町', '26', '26105', '6050942', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '蒔田町', 'マキタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区七軒町大和大路通七条下る3丁目', '26', '26105', '6050943', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '七軒町', 'シチケンチョウ', null, '大和大路通七条下る3丁目', null, null);
INSERT INTO `ms_addresses` VALUES ('68433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区七軒町塩小路通大和大路西入', '26', '26105', '6050943', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '七軒町', 'シチケンチョウ', null, '塩小路通大和大路西入', null, null);
INSERT INTO `ms_addresses` VALUES ('68434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区南棟梁町', '26', '26105', '6050944', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '南棟梁町', 'ミナミトウリョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区辰巳町大和大路通七条下る2丁目', '26', '26105', '6050945', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '辰巳町', 'タツミチョウ', null, '大和大路通七条下る2丁目', null, null);
INSERT INTO `ms_addresses` VALUES ('68436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区北斗町', '26', '26105', '6050946', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '北斗町', 'ホクトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区西之門町', '26', '26105', '6050947', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '西之門町', 'ニシノモンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区東瓦町', '26', '26105', '6050951', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '東瓦町', 'ヒガシカワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区今熊野宝蔵町', '26', '26105', '6050952', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '今熊野宝蔵町', 'イマグマノホウゾウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区今熊野南日吉町', '26', '26105', '6050953', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '今熊野南日吉町', 'イマグマノミナミヒヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区今熊野小松山町', '26', '26105', '6050954', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '今熊野小松山町', 'イマグマノコマツヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区今熊野総山町', '26', '26105', '6050955', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '今熊野総山町', 'イマグマノソウザンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区今熊野梅ケ谷町', '26', '26105', '6050956', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '今熊野梅ケ谷町', 'イマグマノウメガタニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区今熊野泉山町', '26', '26105', '6050957', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '今熊野泉山町', 'イマグマノセンザンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区新瓦町西組', '26', '26105', '6050961', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '新瓦町西組', 'シンカワラチョウニシグミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区新瓦町東組', '26', '26105', '6050962', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '新瓦町東組', 'シンカワラチョウヒガシグミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区本瓦町', '26', '26105', '6050963', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '本瓦町', 'ホンカワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区南瓦町', '26', '26105', '6050964', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '南瓦町', 'ミナミカワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区今熊野池田町', '26', '26105', '6050965', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '今熊野池田町', 'イマグマノイケダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区下池田町', '26', '26105', '6050966', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '下池田町', 'シモイケダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区本池田町', '26', '26105', '6050967', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '本池田町', 'ホンイケダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区上池田町', '26', '26105', '6050968', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '上池田町', 'カミイケダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区今熊野椥ノ森町', '26', '26105', '6050971', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '今熊野椥ノ森町', 'イマグマノナギノモリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区今熊野剣宮町', '26', '26105', '6050972', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '今熊野剣宮町', 'イマグマノツルギノミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区泉涌寺門前町', '26', '26105', '6050973', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '泉涌寺門前町', 'センニュウジモンゼンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区泉涌寺五葉ノ辻町', '26', '26105', '6050974', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '泉涌寺五葉ノ辻町', 'センニュウジゴヨウノツジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区泉涌寺雀ケ森町', '26', '26105', '6050975', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '泉涌寺雀ケ森町', 'センニュウジスズメガモリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区泉涌寺東林町', '26', '26105', '6050976', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '泉涌寺東林町', 'センニュウジトウリンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区泉涌寺山内町', '26', '26105', '6050977', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '泉涌寺山内町', 'センニュウジヤマノウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区今熊野本多山町', '26', '26105', '6050978', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '今熊野本多山町', 'イマグマノホンダヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区今熊野南谷町', '26', '26105', '6050979', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '今熊野南谷町', 'イマグマノミナミダニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区本町', '26', '26105', '6050981', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区福稲下高松町', '26', '26105', '6050982', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '福稲下高松町', 'フクイネシモタカマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区福稲上高松町', '26', '26105', '6050983', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '福稲上高松町', 'フクイネカミタカマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区福稲高原町', '26', '26105', '6050984', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '福稲高原町', 'フクイネタカハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区福稲柿本町', '26', '26105', '6050985', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '福稲柿本町', 'フクイネカキモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区福稲岸ノ上町', '26', '26105', '6050986', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '福稲岸ノ上町', 'フクイネキシノカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区福稲御所ノ内町', '26', '26105', '6050987', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '福稲御所ノ内町', 'フクイネゴショノウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区福稲川原町', '26', '26105', '6050988', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '福稲川原町', 'フクイネカワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区本町新', '26', '26105', '6050989', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '本町新', 'ホンマチシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区上堀詰町', '26', '26105', '6050991', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '上堀詰町', 'カミホリツメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区下堀詰町', '26', '26105', '6050992', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '下堀詰町', 'シモホリツメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区日吉町', '26', '26105', '6050993', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '日吉町', 'ヒヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区一橋宮ノ内町', '26', '26105', '6050994', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '一橋宮ノ内町', 'イチノハシミヤノウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市東山区一橋野本町', '26', '26105', '6050995', '京都府', 'キョウトフ', '京都市東山区', 'キョウトシヒガシヤマク', '一橋野本町', 'イチノハシノモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区', '26', '26103', '6060000', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('68480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区岩倉大鷺町', '26', '26103', '6060001', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '岩倉大鷺町', 'イワクラオオサギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区岩倉中大鷺町', '26', '26103', '6060002', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '岩倉中大鷺町', 'イワクラナカオオサギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区岩倉南大鷺町', '26', '26103', '6060003', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '岩倉南大鷺町', 'イワクラミナミオオサギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区岩倉北池田町', '26', '26103', '6060004', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '岩倉北池田町', 'イワクラキタイケダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区岩倉南池田町', '26', '26103', '6060005', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '岩倉南池田町', 'イワクラミナミイケダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区岩倉西五田町', '26', '26103', '6060006', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '岩倉西五田町', 'イワクラニシゴダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区岩倉東五田町', '26', '26103', '6060007', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '岩倉東五田町', 'イワクラヒガシゴダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区岩倉西宮田町', '26', '26103', '6060011', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '岩倉西宮田町', 'イワクラニシミヤタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区岩倉東宮田町', '26', '26103', '6060012', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '岩倉東宮田町', 'イワクラヒガシミヤタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区岩倉下在地町', '26', '26103', '6060013', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '岩倉下在地町', 'イワクラシモザイジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区岩倉西河原町', '26', '26103', '6060014', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '岩倉西河原町', 'イワクラニシガワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区岩倉幡枝町', '26', '26103', '6060015', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '岩倉幡枝町', 'イワクラハタエダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区岩倉木野町', '26', '26103', '6060016', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '岩倉木野町', 'イワクラキノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区岩倉上蔵町', '26', '26103', '6060017', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '岩倉上蔵町', 'イワクラアグラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区岩倉忠在地町', '26', '26103', '6060021', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '岩倉忠在地町', 'イワクラチュウザイジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区岩倉三宅町', '26', '26103', '6060022', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '岩倉三宅町', 'イワクラミヤケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区岩倉南三宅町', '26', '26103', '6060023', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '岩倉南三宅町', 'イワクラミナミミヤケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区岩倉花園町', '26', '26103', '6060024', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '岩倉花園町', 'イワクラハナゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区岩倉中町', '26', '26103', '6060025', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '岩倉中町', 'イワクラナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区岩倉長谷町', '26', '26103', '6060026', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '岩倉長谷町', 'イワクラナガタニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区岩倉中在地町', '26', '26103', '6060027', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '岩倉中在地町', 'イワクラナカザイジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区岩倉南桑原町', '26', '26103', '6060031', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '岩倉南桑原町', 'イワクラミナミクワハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区岩倉南平岡町', '26', '26103', '6060032', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '岩倉南平岡町', 'イワクラミナミヒラオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区岩倉南四ノ坪町', '26', '26103', '6060033', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '岩倉南四ノ坪町', 'イワクラミナミヨンノツボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区岩倉村松町', '26', '26103', '6060034', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '岩倉村松町', 'イワクラムラマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区上高野三宅町', '26', '26103', '6060035', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '上高野三宅町', 'カミタカノミヤケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区上高野北田町', '26', '26103', '6060036', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '上高野北田町', 'カミタカノキタタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区上高野流田町', '26', '26103', '6060037', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '上高野流田町', 'カミタカノナガレダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区上高野石田町', '26', '26103', '6060041', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '上高野石田町', 'カミタカノイシダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区上高野鷺町', '26', '26103', '6060042', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '上高野鷺町', 'カミタカノサギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区上高野古川町', '26', '26103', '6060043', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '上高野古川町', 'カミタカノフルカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区上高野仲町', '26', '26103', '6060044', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '上高野仲町', 'カミタカノナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区上高野深田町', '26', '26103', '6060045', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '上高野深田町', 'カミタカノフカダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区上高野諸木町', '26', '26103', '6060046', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '上高野諸木町', 'カミタカノモロキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区上高野薩田町', '26', '26103', '6060047', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '上高野薩田町', 'カミタカノサツタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区上高野大湯手町', '26', '26103', '6060048', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '上高野大湯手町', 'カミタカノオオユデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区上高野野上町', '26', '26103', '6060051', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '上高野野上町', 'カミタカノノカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区上高野鳥脇町', '26', '26103', '6060052', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '上高野鳥脇町', 'カミタカノトリワキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区上高野車地町', '26', '26103', '6060053', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '上高野車地町', 'カミタカノクルマジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区上高野三反田町', '26', '26103', '6060054', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '上高野三反田町', 'カミタカノサンタンダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区上高野尾保地町', '26', '26103', '6060055', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '上高野尾保地町', 'カミタカノオホチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区上高野市川町', '26', '26103', '6060056', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '上高野市川町', 'カミタカノイチカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区上高野池ノ内町', '26', '26103', '6060057', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '上高野池ノ内町', 'カミタカノイケノウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区上高野小野町', '26', '26103', '6060058', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '上高野小野町', 'カミタカノオノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区上高野北川原町', '26', '26103', '6060059', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '上高野北川原町', 'カミタカノキタカワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区上高野川原町', '26', '26103', '6060061', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '上高野川原町', 'カミタカノカワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区上高野大橋町', '26', '26103', '6060062', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '上高野大橋町', 'カミタカノオオハシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区上高野大明神町', '26', '26103', '6060063', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '上高野大明神町', 'カミタカノダイミョウジンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区上高野西明寺山', '26', '26103', '6060064', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '上高野西明寺山', 'カミタカノサイミョウジヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区上高野八幡町', '26', '26103', '6060065', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '上高野八幡町', 'カミタカノハチマンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区上高野水車町', '26', '26103', '6060066', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '上高野水車町', 'カミタカノスイシャチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区上高野東山', '26', '26103', '6060067', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '上高野東山', 'カミタカノヒガシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区八瀬野瀬町', '26', '26103', '6060068', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '八瀬野瀬町', 'ヤセノセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区上高野防山', '26', '26103', '6060071', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '上高野防山', 'カミタカノボウヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区上高野掃部林町', '26', '26103', '6060072', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '上高野掃部林町', 'カミタカノカモンハヤシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区上高野釜土町', '26', '26103', '6060073', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '上高野釜土町', 'カミタカノカマツチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区上高野下東野町', '26', '26103', '6060074', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '上高野下東野町', 'カミタカノシモヒガシノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区上高野奥東野町', '26', '26103', '6060075', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '上高野奥東野町', 'カミタカノオクヒガシノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区上高野口小森町', '26', '26103', '6060076', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '上高野口小森町', 'カミタカノグチコモリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区上高野奥小森町', '26', '26103', '6060077', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '上高野奥小森町', 'カミタカノオクコモリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区上高野東田町', '26', '26103', '6060078', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '上高野東田町', 'カミタカノヒガシダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区上高野畑町', '26', '26103', '6060081', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '上高野畑町', 'カミタカノハタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区上高野畑ケ田町', '26', '26103', '6060082', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '上高野畑ケ田町', 'カミタカノハタガダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区上高野松田町', '26', '26103', '6060083', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '上高野松田町', 'カミタカノマツダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区上高野鐘突町', '26', '26103', '6060084', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '上高野鐘突町', 'カミタカノカネツキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区上高野隣好町', '26', '26103', '6060085', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '上高野隣好町', 'カミタカノリンコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区上高野木ノ下町', '26', '26103', '6060086', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '上高野木ノ下町', 'カミタカノキノシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区上高野稲荷町', '26', '26103', '6060087', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '上高野稲荷町', 'カミタカノイナリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区上高野植ノ町', '26', '26103', '6060088', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '上高野植ノ町', 'カミタカノウエノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区上高野上畑町', '26', '26103', '6060089', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '上高野上畑町', 'カミタカノウエハタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区上高野大塚町', '26', '26103', '6060091', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '上高野大塚町', 'カミタカノオオツカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区上高野下荒蒔町', '26', '26103', '6060092', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '上高野下荒蒔町', 'カミタカノシモアラマキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区上高野上荒蒔町', '26', '26103', '6060093', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '上高野上荒蒔町', 'カミタカノカミアラマキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区上高野東氷室町', '26', '26103', '6060094', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '上高野東氷室町', 'カミタカノヒガシヒムロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区上高野西氷室町', '26', '26103', '6060095', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '上高野西氷室町', 'カミタカノニシヒムロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区上高野山ノ橋町', '26', '26103', '6060096', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '上高野山ノ橋町', 'カミタカノヤマノハシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区上高野前田町', '26', '26103', '6060097', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '上高野前田町', 'カミタカノマエダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区上高野沢渕町', '26', '26103', '6060098', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '上高野沢渕町', 'カミタカノサワブチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区下鴨宮河町', '26', '26103', '6060801', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '下鴨宮河町', 'シモガモミヤカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区下鴨宮崎町', '26', '26103', '6060802', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '下鴨宮崎町', 'シモガモミヤザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区下鴨下川原町', '26', '26103', '6060803', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '下鴨下川原町', 'シモガモシモガワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区下鴨松原町', '26', '26103', '6060804', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '下鴨松原町', 'シモガモマツバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区下鴨森本町', '26', '26103', '6060805', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '下鴨森本町', 'シモガモモリモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区下鴨蓼倉町', '26', '26103', '6060806', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '下鴨蓼倉町', 'シモガモタデクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区下鴨泉川町', '26', '26103', '6060807', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '下鴨泉川町', 'シモガモイズミガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区下鴨中川原町', '26', '26103', '6060811', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '下鴨中川原町', 'シモガモナカガワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区下鴨上川原町', '26', '26103', '6060812', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '下鴨上川原町', 'シモガモカミガワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区下鴨貴船町', '26', '26103', '6060813', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '下鴨貴船町', 'シモガモキブネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区下鴨芝本町', '26', '26103', '6060814', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '下鴨芝本町', 'シモガモシバモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区下鴨膳部町', '26', '26103', '6060815', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '下鴨膳部町', 'シモガモカシワベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区下鴨松ノ木町', '26', '26103', '6060816', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '下鴨松ノ木町', 'シモガモマツノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区下鴨西林町', '26', '26103', '6060817', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '下鴨西林町', 'シモガモニシバヤシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区賀茂今井町', '26', '26103', '6060821', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '賀茂今井町', 'カモイマイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区賀茂半木町', '26', '26103', '6060822', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '賀茂半木町', 'カモハンギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区下鴨半木町', '26', '26103', '6060823', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '下鴨半木町', 'シモガモハンギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区下鴨東半木町', '26', '26103', '6060824', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '下鴨東半木町', 'シモガモヒガシハンギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区下鴨西梅ノ木町', '26', '26103', '6060825', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '下鴨西梅ノ木町', 'シモガモニシウメノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区下鴨西本町', '26', '26103', '6060826', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '下鴨西本町', 'シモガモニシホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区下鴨西半木町', '26', '26103', '6060827', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '下鴨西半木町', 'シモガモニシハンギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区下鴨北園町', '26', '26103', '6060831', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '下鴨北園町', 'シモガモキタゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区下鴨萩ケ垣内町', '26', '26103', '6060832', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '下鴨萩ケ垣内町', 'シモガモハギガカキウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区下鴨前萩町', '26', '26103', '6060833', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '下鴨前萩町', 'シモガモマエハギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区下鴨狗子田町', '26', '26103', '6060834', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '下鴨狗子田町', 'シモガモイノコダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区下鴨神殿町', '26', '26103', '6060835', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '下鴨神殿町', 'シモガモコウドノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区下鴨梁田町', '26', '26103', '6060836', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '下鴨梁田町', 'シモガモヤナダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区下鴨夜光町', '26', '26103', '6060837', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '下鴨夜光町', 'シモガモヤコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区下鴨南芝町', '26', '26103', '6060841', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '下鴨南芝町', 'シモガモミナミシバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区下鴨北芝町', '26', '26103', '6060842', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '下鴨北芝町', 'シモガモキタシバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区下鴨水口町', '26', '26103', '6060843', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '下鴨水口町', 'シモガモミナクチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区下鴨北茶ノ木町', '26', '26103', '6060844', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '下鴨北茶ノ木町', 'シモガモキタチャノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区下鴨南茶ノ木町', '26', '26103', '6060845', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '下鴨南茶ノ木町', 'シモガモミナミチャノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区下鴨北野々神町', '26', '26103', '6060846', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '下鴨北野々神町', 'シモガモキタノノガミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区下鴨南野々神町', '26', '26103', '6060847', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '下鴨南野々神町', 'シモガモミナミノノガミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区下鴨梅ノ木町', '26', '26103', '6060851', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '下鴨梅ノ木町', 'シモガモウメノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区下鴨東梅ノ木町', '26', '26103', '6060852', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '下鴨東梅ノ木町', 'シモガモヒガシウメノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区下鴨岸本町', '26', '26103', '6060853', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '下鴨岸本町', 'シモガモキシモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区下鴨東岸本町', '26', '26103', '6060854', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '下鴨東岸本町', 'シモガモヒガシキシモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区下鴨東塚本町', '26', '26103', '6060855', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '下鴨東塚本町', 'シモガモヒガシツカモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区下鴨塚本町', '26', '26103', '6060856', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '下鴨塚本町', 'シモガモツカモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区下鴨西高木町', '26', '26103', '6060861', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '下鴨西高木町', 'シモガモニシタカギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区下鴨本町', '26', '26103', '6060862', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '下鴨本町', 'シモガモホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区下鴨東本町', '26', '26103', '6060863', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '下鴨東本町', 'シモガモヒガシホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区下鴨高木町', '26', '26103', '6060864', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '下鴨高木町', 'シモガモタカギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区下鴨東高木町', '26', '26103', '6060865', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '下鴨東高木町', 'シモガモヒガシタカギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区下鴨東森ケ前町', '26', '26103', '6060866', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '下鴨東森ケ前町', 'シモガモヒガシモリガマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区下鴨森ケ前町', '26', '26103', '6060867', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '下鴨森ケ前町', 'シモガモモリガマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区松ケ崎東桜木町', '26', '26103', '6060901', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '松ケ崎東桜木町', 'マツガサキヒガシサクラギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区松ケ崎桜木町', '26', '26103', '6060902', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '松ケ崎桜木町', 'マツガサキサクラギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区松ケ崎西桜木町', '26', '26103', '6060903', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '松ケ崎西桜木町', 'マツガサキニシサクラギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区松ケ崎柳井田町', '26', '26103', '6060904', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '松ケ崎柳井田町', 'マツガサキヤナイダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区松ケ崎杉ケ海道町', '26', '26103', '6060905', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '松ケ崎杉ケ海道町', 'マツガサキスギガカイドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区松ケ崎中海道町', '26', '26103', '6060906', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '松ケ崎中海道町', 'マツガサキナカカイドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区松ケ崎村ケ内町', '26', '26103', '6060907', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '松ケ崎村ケ内町', 'マツガサキムラガウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区松ケ崎泉川町', '26', '26103', '6060911', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '松ケ崎泉川町', 'マツガサキイズミガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区松ケ崎呼返町', '26', '26103', '6060912', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '松ケ崎呼返町', 'マツガサキヨビカエリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区松ケ崎芝本町', '26', '26103', '6060913', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '松ケ崎芝本町', 'マツガサキシバモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区松ケ崎今海道町', '26', '26103', '6060914', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '松ケ崎今海道町', 'マツガサキイマカイドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区松ケ崎六ノ坪町', '26', '26103', '6060915', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '松ケ崎六ノ坪町', 'マツガサキロクノツボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区松ケ崎三反長町', '26', '26103', '6060916', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '松ケ崎三反長町', 'マツガサキサンダンオサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区松ケ崎堂ノ上町', '26', '26103', '6060917', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '松ケ崎堂ノ上町', 'マツガサキドウノウエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区松ケ崎平田町', '26', '26103', '6060921', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '松ケ崎平田町', 'マツガサキヒラタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区松ケ崎南池ノ内町', '26', '26103', '6060922', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '松ケ崎南池ノ内町', 'マツガサキミナミイケノウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区松ケ崎総作町', '26', '26103', '6060923', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '松ケ崎総作町', 'マツガサキソウサクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区松ケ崎東池ノ内町', '26', '26103', '6060924', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '松ケ崎東池ノ内町', 'マツガサキヒガシイケノウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区松ケ崎林山', '26', '26103', '6060925', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '松ケ崎林山', 'マツガサキハヤシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区松ケ崎中町', '26', '26103', '6060926', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '松ケ崎中町', 'マツガサキナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区松ケ崎西町', '26', '26103', '6060927', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '松ケ崎西町', 'マツガサキニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区松ケ崎井出ケ海道町', '26', '26103', '6060931', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '松ケ崎井出ケ海道町', 'マツガサキイデガカイドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区松ケ崎西池ノ内町', '26', '26103', '6060932', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '松ケ崎西池ノ内町', 'マツガサキニシイケノウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区松ケ崎西山', '26', '26103', '6060933', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '松ケ崎西山', 'マツガサキニシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区松ケ崎狐坂', '26', '26103', '6060934', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '松ケ崎狐坂', 'マツガサキキツネサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区松ケ崎高山', '26', '26103', '6060935', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '松ケ崎高山', 'マツガサキタカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区松ケ崎榎実ケ芝', '26', '26103', '6060936', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '松ケ崎榎実ケ芝', 'マツガサキエノミガシバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区松ケ崎北裏町', '26', '26103', '6060937', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '松ケ崎北裏町', 'マツガサキキタウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区松ケ崎木燈籠町', '26', '26103', '6060938', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '松ケ崎木燈籠町', 'マツガサキキトウロウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区松ケ崎河原田町', '26', '26103', '6060941', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '松ケ崎河原田町', 'マツガサキカワラダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区松ケ崎樋ノ上町', '26', '26103', '6060942', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '松ケ崎樋ノ上町', 'マツガサキヒノエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区松ケ崎東町', '26', '26103', '6060943', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '松ケ崎東町', 'マツガサキヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区松ケ崎御所ノ内町', '26', '26103', '6060944', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '松ケ崎御所ノ内町', 'マツガサキゴショノウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区松ケ崎堀町', '26', '26103', '6060945', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '松ケ崎堀町', 'マツガサキホリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区松ケ崎東山', '26', '26103', '6060946', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '松ケ崎東山', 'マツガサキヒガシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区松ケ崎井出ケ鼻町', '26', '26103', '6060947', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '松ケ崎井出ケ鼻町', 'マツガサキイデガハナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区松ケ崎橋上町', '26', '26103', '6060951', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '松ケ崎橋上町', 'マツガサキハシカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区松ケ崎木ノ本町', '26', '26103', '6060952', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '松ケ崎木ノ本町', 'マツガサキキノモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区松ケ崎海尻町', '26', '26103', '6060953', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '松ケ崎海尻町', 'マツガサキカイジリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区松ケ崎壱町田町', '26', '26103', '6060954', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '松ケ崎壱町田町', 'マツガサキイッチョウダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区松ケ崎雲路町', '26', '26103', '6060955', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '松ケ崎雲路町', 'マツガサキクモジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区松ケ崎鞍馬田町', '26', '26103', '6060956', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '松ケ崎鞍馬田町', 'マツガサキクラマダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区松ケ崎小脇町', '26', '26103', '6060957', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '松ケ崎小脇町', 'マツガサキコワキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区松ケ崎久土町', '26', '26103', '6060961', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '松ケ崎久土町', 'マツガサキクドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区松ケ崎御所海道町', '26', '26103', '6060962', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '松ケ崎御所海道町', 'マツガサキゴショカイドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区松ケ崎糺田町', '26', '26103', '6060963', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '松ケ崎糺田町', 'マツガサキタダスデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区松ケ崎修理式町', '26', '26103', '6060964', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '松ケ崎修理式町', 'マツガサキシュウリシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区松ケ崎横縄手町', '26', '26103', '6060965', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '松ケ崎横縄手町', 'マツガサキヨコナワテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区松ケ崎正田町', '26', '26103', '6060966', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '松ケ崎正田町', 'マツガサキショウデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区松ケ崎小竹薮町', '26', '26103', '6060967', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '松ケ崎小竹薮町', 'マツガサキコタケヤブチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区山端柳ケ坪町', '26', '26103', '6068001', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '山端柳ケ坪町', 'ヤマバナヤナガツボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区山端大城田町', '26', '26103', '6068002', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '山端大城田町', 'ヤマバナダイジョウデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区山端川原町', '26', '26103', '6068003', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '山端川原町', 'ヤマバナカワハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区山端川端町', '26', '26103', '6068004', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '山端川端町', 'ヤマバナカワバタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区山端川岸町', '26', '26103', '6068005', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '山端川岸町', 'ヤマバナカワギシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区山端橋ノ本町', '26', '26103', '6068006', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '山端橋ノ本町', 'ヤマバナハシノモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区山端壱町田町', '26', '26103', '6068007', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '山端壱町田町', 'ヤマバナイッチョウダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区山端森本町', '26', '26103', '6068011', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '山端森本町', 'ヤマバナモリモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区山端滝ケ鼻町', '26', '26103', '6068012', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '山端滝ケ鼻町', 'ヤマバナタキガハナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区山端大君町', '26', '26103', '6068013', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '山端大君町', 'ヤマバナオオキミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区山端大塚町', '26', '26103', '6068014', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '山端大塚町', 'ヤマバナオオツカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区修学院沖殿町', '26', '26103', '6068021', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '修学院沖殿町', 'シュウガクインオキドノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区修学院高部町', '26', '26103', '6068022', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '修学院高部町', 'シュウガクインタカベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区修学院水上田町', '26', '26103', '6068023', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '修学院水上田町', 'シュウガクインスイジョウデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区修学院千万田町', '26', '26103', '6068024', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '修学院千万田町', 'シュウガクインセンマンダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区修学院山ノ鼻町', '26', '26103', '6068025', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '修学院山ノ鼻町', 'シュウガクインヤマノハナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区修学院川尻町', '26', '26103', '6068026', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '修学院川尻町', 'シュウガクインカワジリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区修学院水川原町', '26', '26103', '6068027', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '修学院水川原町', 'シュウガクインミズカワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区修学院西沮沢町', '26', '26103', '6068031', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '修学院西沮沢町', 'シュウガクインニシフケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区修学院北沮沢町', '26', '26103', '6068032', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '修学院北沮沢町', 'シュウガクインキタフケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区修学院山添町', '26', '26103', '6068033', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '修学院山添町', 'シュウガクインヤマゾエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区修学院桧峠町', '26', '26103', '6068034', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '修学院桧峠町', 'シュウガクインヒノキトウゲチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区修学院守禅庵', '26', '26103', '6068035', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '修学院守禅庵', 'シュウガクインシュゼンアン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区修学院開根坊町', '26', '26103', '6068036', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '修学院開根坊町', 'シュウガクインカイコンボウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区修学院大道町', '26', '26103', '6068037', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '修学院大道町', 'シュウガクインダイドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区修学院仏者町', '26', '26103', '6068041', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '修学院仏者町', 'シュウガクインブッシャチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区修学院泉殿町', '26', '26103', '6068042', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '修学院泉殿町', 'シュウガクインイズミドノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区修学院貝原町', '26', '26103', '6068043', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '修学院貝原町', 'シュウガクインカイバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区修学院馬場脇町', '26', '26103', '6068044', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '修学院馬場脇町', 'シュウガクインババワキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区修学院安養坊', '26', '26103', '6068045', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '修学院安養坊', 'シュウガクインアンヨウボウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区修学院室町', '26', '26103', '6068046', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '修学院室町', 'シュウガクインムロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区修学院烏丸町', '26', '26103', '6068047', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '修学院烏丸町', 'シュウガクインカラスマルチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区修学院中新開', '26', '26103', '6068051', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '修学院中新開', 'シュウガクインナカシンカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区修学院薮添', '26', '26103', '6068052', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '修学院薮添', 'シュウガクインヤブソエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区修学院宮ノ前', '26', '26103', '6068053', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '修学院宮ノ前', 'シュウガクインミヤノマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区修学院山神町', '26', '26103', '6068054', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '修学院山神町', 'シュウガクインヤマカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区修学院高岸町', '26', '26103', '6068055', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '修学院高岸町', 'シュウガクインタカギシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区修学院松本町', '26', '26103', '6068056', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '修学院松本町', 'シュウガクインマツモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区修学院林ノ脇', '26', '26103', '6068057', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '修学院林ノ脇', 'シュウガクインハヤシノワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区修学院宮ノ脇町', '26', '26103', '6068061', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '修学院宮ノ脇町', 'シュウガクインミヤノワキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区修学院南代', '26', '26103', '6068062', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '修学院南代', 'シュウガクインミナミシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区修学院後安堂', '26', '26103', '6068063', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '修学院後安堂', 'シュウガクインゴアンドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区修学院辻ノ田町', '26', '26103', '6068064', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '修学院辻ノ田町', 'シュウガクインツジノダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区修学院月輪寺町', '26', '26103', '6068065', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '修学院月輪寺町', 'シュウガクインガツリンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区修学院狭間町', '26', '26103', '6068071', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '修学院狭間町', 'シュウガクインハザマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区修学院登リ内町', '26', '26103', '6068072', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '修学院登リ内町', 'シュウガクインノボリウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区修学院茶屋ノ前町', '26', '26103', '6068073', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '修学院茶屋ノ前町', 'シュウガクインチャヤノマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区修学院石掛町', '26', '26103', '6068074', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '修学院石掛町', 'シュウガクインイシカケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区修学院坪江町', '26', '26103', '6068075', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '修学院坪江町', 'シュウガクインツボエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区修学院大林町', '26', '26103', '6068081', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '修学院大林町', 'シュウガクインオオバヤシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区修学院鹿ノ下町', '26', '26103', '6068082', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '修学院鹿ノ下町', 'シュウガクインカノシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区修学院犬塚町', '26', '26103', '6068083', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '修学院犬塚町', 'シュウガクインイヌヅカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区修学院薬師堂町', '26', '26103', '6068084', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '修学院薬師堂町', 'シュウガクインヤクシドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区修学院中林町', '26', '26103', '6068085', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '修学院中林町', 'シュウガクインナカバヤシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区修学院十権寺町', '26', '26103', '6068086', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '修学院十権寺町', 'シュウガクインジュウゴンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区高野蓼原町', '26', '26103', '6068101', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '高野蓼原町', 'タカノタデハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区高野清水町', '26', '26103', '6068102', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '高野清水町', 'タカノシミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区高野西開町', '26', '26103', '6068103', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '高野西開町', 'タカノニシビラキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区高野竹屋町', '26', '26103', '6068104', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '高野竹屋町', 'タカノタケヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区高野上竹屋町', '26', '26103', '6068105', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '高野上竹屋町', 'タカノカミタケヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区高野玉岡町', '26', '26103', '6068106', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '高野玉岡町', 'タカノタマオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区高野東開町', '26', '26103', '6068107', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '高野東開町', 'タカノヒガシヒラキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区高野泉町', '26', '26103', '6068111', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '高野泉町', 'タカノイズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区一乗寺西杉ノ宮町', '26', '26103', '6068112', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '一乗寺西杉ノ宮町', 'イチジョウジニシスギノミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区一乗寺東杉ノ宮町', '26', '26103', '6068113', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '一乗寺東杉ノ宮町', 'イチジョウジヒガシスギノミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区一乗寺北大丸町', '26', '26103', '6068114', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '一乗寺北大丸町', 'イチジョウジキタオオマルチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区一乗寺里ノ西町', '26', '26103', '6068115', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '一乗寺里ノ西町', 'イチジョウジサトノニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区一乗寺宮ノ東町', '26', '26103', '6068116', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '一乗寺宮ノ東町', 'イチジョウジミヤノヒガシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区一乗寺里ノ前町', '26', '26103', '6068117', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '一乗寺里ノ前町', 'イチジョウジサトノマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区一乗寺青城町', '26', '26103', '6068121', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '一乗寺青城町', 'イチジョウジアオジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区一乗寺東閉川原町', '26', '26103', '6068122', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '一乗寺東閉川原町', 'イチジョウジヒガシトジカワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区一乗寺西閉川原町', '26', '26103', '6068123', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '一乗寺西閉川原町', 'イチジョウジニシトジカワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区一乗寺松田町', '26', '26103', '6068124', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '一乗寺松田町', 'イチジョウジマツダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区一乗寺清水町', '26', '26103', '6068125', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '一乗寺清水町', 'イチジョウジシミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区一乗寺向畑町', '26', '26103', '6068126', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '一乗寺向畑町', 'イチジョウジムカイバタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区一乗寺西浦畑町', '26', '26103', '6068127', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '一乗寺西浦畑町', 'イチジョウジニシウラバタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区一乗寺稲荷町', '26', '26103', '6068131', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '一乗寺稲荷町', 'イチジョウジイナリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区一乗寺馬場町', '26', '26103', '6068132', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '一乗寺馬場町', 'イチジョウジババチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区一乗寺月輪寺町', '26', '26103', '6068133', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '一乗寺月輪寺町', 'イチジョウジガツリンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区一乗寺竹ノ内町', '26', '26103', '6068134', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '一乗寺竹ノ内町', 'イチジョウジタケノウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区一乗寺水掛町', '26', '26103', '6068135', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '一乗寺水掛町', 'イチジョウジミズガケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区一乗寺東浦町', '26', '26103', '6068136', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '一乗寺東浦町', 'イチジョウジヒガシウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区一乗寺釈迦堂町', '26', '26103', '6068141', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '一乗寺釈迦堂町', 'イチジョウジシャカドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区一乗寺燈籠本町', '26', '26103', '6068142', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '一乗寺燈籠本町', 'イチジョウジトウロウモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区一乗寺堀ノ内町', '26', '26103', '6068143', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '一乗寺堀ノ内町', 'イチジョウジホリノウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区一乗寺堂ノ前町', '26', '26103', '6068144', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '一乗寺堂ノ前町', 'イチジョウジドウノマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区一乗寺葉山町', '26', '26103', '6068145', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '一乗寺葉山町', 'イチジョウジハヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区一乗寺病ダレ', '26', '26103', '6068146', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '一乗寺病ダレ', 'イチジョウジヤマイダレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区一乗寺小谷町', '26', '26103', '6068147', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '一乗寺小谷町', 'イチジョウジコタニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区一乗寺花ノ木町', '26', '26103', '6068151', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '一乗寺花ノ木町', 'イチジョウジハナノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区一乗寺下リ松町', '26', '26103', '6068152', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '一乗寺下リ松町', 'イチジョウジサガリマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区一乗寺谷田町', '26', '26103', '6068153', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '一乗寺谷田町', 'イチジョウジタニダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区一乗寺門口町', '26', '26103', '6068154', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '一乗寺門口町', 'イチジョウジモングチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区一乗寺薬師堂町', '26', '26103', '6068155', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '一乗寺薬師堂町', 'イチジョウジヤクシドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区一乗寺松原町', '26', '26103', '6068156', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '一乗寺松原町', 'イチジョウジマツハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区一乗寺才形町', '26', '26103', '6068157', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '一乗寺才形町', 'イチジョウジサイカタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区一乗寺大谷', '26', '26103', '6068158', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '一乗寺大谷', 'イチジョウジオオタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区一乗寺木ノ本町', '26', '26103', '6068161', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '一乗寺木ノ本町', 'イチジョウジキノモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区一乗寺御祭田町', '26', '26103', '6068162', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '一乗寺御祭田町', 'イチジョウジゴサイデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区一乗寺中ノ田町', '26', '26103', '6068163', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '一乗寺中ノ田町', 'イチジョウジナカノダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区一乗寺出口町', '26', '26103', '6068164', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '一乗寺出口町', 'イチジョウジデグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区一乗寺野田町', '26', '26103', '6068165', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '一乗寺野田町', 'イチジョウジノダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区一乗寺庵野町', '26', '26103', '6068166', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '一乗寺庵野町', 'イチジョウジイオリノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区一乗寺樋ノ口町', '26', '26103', '6068167', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '一乗寺樋ノ口町', 'イチジョウジヒノクチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区一乗寺西水干町', '26', '26103', '6068171', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '一乗寺西水干町', 'イチジョウジニシミズボシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区一乗寺河原田町', '26', '26103', '6068172', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '一乗寺河原田町', 'イチジョウジカワハラダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区一乗寺梅ノ木町', '26', '26103', '6068173', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '一乗寺梅ノ木町', 'イチジョウジウメノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区一乗寺染殿町', '26', '26103', '6068174', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '一乗寺染殿町', 'イチジョウジソメドノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区一乗寺築田町', '26', '26103', '6068175', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '一乗寺築田町', 'イチジョウジツクダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区一乗寺塚本町', '26', '26103', '6068176', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '一乗寺塚本町', 'イチジョウジツカモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区一乗寺東水干町', '26', '26103', '6068177', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '一乗寺東水干町', 'イチジョウジヒガシミズボシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区一乗寺地蔵本町', '26', '26103', '6068181', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '一乗寺地蔵本町', 'イチジョウジジゾウモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区一乗寺赤ノ宮町', '26', '26103', '6068182', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '一乗寺赤ノ宮町', 'イチジョウジアカノミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区一乗寺大新開町', '26', '26103', '6068183', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '一乗寺大新開町', 'イチジョウジダイシンカイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区一乗寺払殿町', '26', '26103', '6068184', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '一乗寺払殿町', 'イチジョウジハライトノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区一乗寺高槻町', '26', '26103', '6068185', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '一乗寺高槻町', 'イチジョウジタカツキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区一乗寺南大丸町', '26', '26103', '6068186', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '一乗寺南大丸町', 'イチジョウジミナミオオマルチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区一乗寺大原田町', '26', '26103', '6068187', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '一乗寺大原田町', 'イチジョウジオオハラダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区田中玄京町', '26', '26103', '6068201', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '田中玄京町', 'タナカゲンキョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区田中大堰町', '26', '26103', '6068202', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '田中大堰町', 'タナカオオイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区田中関田町', '26', '26103', '6068203', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '田中関田町', 'タナカセキデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区田中下柳町', '26', '26103', '6068204', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '田中下柳町', 'タナカシモヤナギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区田中上柳町', '26', '26103', '6068205', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '田中上柳町', 'タナカカミヤナギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区田中馬場町', '26', '26103', '6068206', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '田中馬場町', 'タナカババチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区田中西大久保町', '26', '26103', '6068211', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '田中西大久保町', 'タナカニシオオクボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区田中里ノ内町', '26', '26103', '6068212', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '田中里ノ内町', 'タナカサトノウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区田中野神町', '26', '26103', '6068213', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '田中野神町', 'タナカノガミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区田中南大久保町', '26', '26103', '6068214', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '田中南大久保町', 'タナカミナミオオクボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区田中上玄京町', '26', '26103', '6068215', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '田中上玄京町', 'タナカカミゲンキョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区田中南西浦町', '26', '26103', '6068216', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '田中南西浦町', 'タナカミナミニシウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区田中西浦町', '26', '26103', '6068217', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '田中西浦町', 'タナカニシウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区田中西樋ノ口町', '26', '26103', '6068221', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '田中西樋ノ口町', 'タナカニシヒノクチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区田中樋ノ口町', '26', '26103', '6068222', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '田中樋ノ口町', 'タナカヒノクチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区田中東樋ノ口町', '26', '26103', '6068223', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '田中東樋ノ口町', 'タナカヒガシヒノクチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区北白川追分町', '26', '26103', '6068224', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '北白川追分町', 'キタシラカワオイワケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区田中門前町', '26', '26103', '6068225', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '田中門前町', 'タナカモンゼンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区田中飛鳥井町', '26', '26103', '6068226', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '田中飛鳥井町', 'タナカアスカイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区田中里ノ前町', '26', '26103', '6068227', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '田中里ノ前町', 'タナカサトノマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区田中上古川町', '26', '26103', '6068231', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '田中上古川町', 'タナカカミフルカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区田中古川町', '26', '26103', '6068232', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '田中古川町', 'タナカフルカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区田中北春菜町', '26', '26103', '6068233', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '田中北春菜町', 'タナカキタハルナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区田中春菜町', '26', '26103', '6068234', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '田中春菜町', 'タナカハルナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区田中西春菜町', '26', '26103', '6068235', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '田中西春菜町', 'タナカニシハルナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区田中大久保町', '26', '26103', '6068236', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '田中大久保町', 'タナカオオクボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区田中上大久保町', '26', '26103', '6068237', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '田中上大久保町', 'タナカカミオオクボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区田中西高原町', '26', '26103', '6068241', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '田中西高原町', 'タナカニシタカハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区田中高原町', '26', '26103', '6068242', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '田中高原町', 'タナカタカハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区田中東高原町', '26', '26103', '6068243', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '田中東高原町', 'タナカヒガシタカハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区北白川東平井町', '26', '26103', '6068244', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '北白川東平井町', 'キタシラカワヒガシヒライチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区北白川平井町', '26', '26103', '6068245', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '北白川平井町', 'キタシラカワヒライチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区北白川西平井町', '26', '26103', '6068246', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '北白川西平井町', 'キタシラカワニシヒライチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区田中東春菜町', '26', '26103', '6068247', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '田中東春菜町', 'タナカヒガシハルナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区北白川東伊織町', '26', '26103', '6068251', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '北白川東伊織町', 'キタシラカワヒガシイオリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区北白川上終町', '26', '26103', '6068252', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '北白川上終町', 'キタシラカワカミハテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区北白川瀬ノ内町', '26', '26103', '6068253', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '北白川瀬ノ内町', 'キタシラカワセノウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区北白川東瀬ノ内町', '26', '26103', '6068254', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '北白川東瀬ノ内町', 'キタシラカワヒガシセノウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区北白川西瀬ノ内町', '26', '26103', '6068255', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '北白川西瀬ノ内町', 'キタシラカワニシセノウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区北白川伊織町', '26', '26103', '6068256', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '北白川伊織町', 'キタシラカワイオリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区北白川西伊織町', '26', '26103', '6068257', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '北白川西伊織町', 'キタシラカワニシイオリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区北白川西蔦町', '26', '26103', '6068261', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '北白川西蔦町', 'キタシラカワニシツタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区北白川蔦町', '26', '26103', '6068262', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '北白川蔦町', 'キタシラカワツタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区北白川東蔦町', '26', '26103', '6068263', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '北白川東蔦町', 'キタシラカワヒガシツタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区北白川小倉町', '26', '26103', '6068264', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '北白川小倉町', 'キタシラカワオグラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区北白川東小倉町', '26', '26103', '6068265', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '北白川東小倉町', 'キタシラカワヒガシオグラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区北白川久保田町', '26', '26103', '6068266', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '北白川久保田町', 'キタシラカワクボタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区北白川西町', '26', '26103', '6068267', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '北白川西町', 'キタシラカワニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区北白川瓜生山町', '26', '26103', '6068271', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '北白川瓜生山町', 'キタシラカワウリュウザンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区北白川山田町', '26', '26103', '6068272', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '北白川山田町', 'キタシラカワヤマダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区北白川山ノ元町', '26', '26103', '6068273', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '北白川山ノ元町', 'キタシラカワヤマノモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区北白川大堂町', '26', '26103', '6068274', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '北白川大堂町', 'キタシラカワダイドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区北白川上別当町', '26', '26103', '6068275', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '北白川上別当町', 'キタシラカワカミベットウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区北白川別当町', '26', '26103', '6068276', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '北白川別当町', 'キタシラカワベットウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区北白川堂ノ前町', '26', '26103', '6068277', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '北白川堂ノ前町', 'キタシラカワドウノマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区北白川丸山町', '26', '26103', '6068281', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '北白川丸山町', 'キタシラカワマルヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区北白川外山町', '26', '26103', '6068282', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '北白川外山町', 'キタシラカワトヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区北白川仕伏町', '26', '26103', '6068283', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '北白川仕伏町', 'キタシラカワシブセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区北白川下池田町', '26', '26103', '6068284', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '北白川下池田町', 'キタシラカワシモイケダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区北白川東久保田町', '26', '26103', '6068285', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '北白川東久保田町', 'キタシラカワヒガシクボタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区北白川下別当町', '26', '26103', '6068286', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '北白川下別当町', 'キタシラカワシモベットウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区北白川上池田町', '26', '26103', '6068287', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '北白川上池田町', 'キタシラカワカミイケダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区北白川岩坂町', '26', '26103', '6068291', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '北白川岩坂町', 'キタシラカワイワサカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区北白川重石町', '26', '26103', '6068292', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '北白川重石町', 'キタシラカワカサネイシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区北白川琵琶町', '26', '26103', '6068293', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '北白川琵琶町', 'キタシラカワビワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区北白川地蔵谷町', '26', '26103', '6068294', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '北白川地蔵谷町', 'キタシラカワジゾウダニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区北白川清沢口町', '26', '26103', '6068295', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '北白川清沢口町', 'キタシラカワキヨザワグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区吉田泉殿町', '26', '26103', '6068301', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '吉田泉殿町', 'ヨシダイズミデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区吉田牛ノ宮町', '26', '26103', '6068302', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '吉田牛ノ宮町', 'ヨシダウシノミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区吉田橘町', '26', '26103', '6068303', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '吉田橘町', 'ヨシダタチバナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区吉田下阿達町', '26', '26103', '6068304', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '吉田下阿達町', 'ヨシダシモアダチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区吉田河原町', '26', '26103', '6068305', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '吉田河原町', 'ヨシダカワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区吉田中阿達町', '26', '26103', '6068306', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '吉田中阿達町', 'ヨシダナカアダチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区吉田上阿達町', '26', '26103', '6068307', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '吉田上阿達町', 'ヨシダカミアダチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区吉田神楽岡町', '26', '26103', '6068311', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '吉田神楽岡町', 'ヨシダカグラオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区吉田上大路町', '26', '26103', '6068312', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '吉田上大路町', 'ヨシダカミオオジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区吉田中大路町', '26', '26103', '6068313', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '吉田中大路町', 'ヨシダナカオオジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区吉田下大路町', '26', '26103', '6068314', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '吉田下大路町', 'ヨシダシモオオジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区吉田近衛町', '26', '26103', '6068315', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '吉田近衛町', 'ヨシダコノエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区吉田二本松町', '26', '26103', '6068316', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '吉田二本松町', 'ヨシダニホンマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区吉田本町', '26', '26103', '6068317', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '吉田本町', 'ヨシダホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区岡崎東福ノ川町', '26', '26103', '6068321', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '岡崎東福ノ川町', 'オカザキヒガシフクノカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区岡崎入江町', '26', '26103', '6068322', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '岡崎入江町', 'オカザキイリエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区聖護院円頓美町', '26', '26103', '6068323', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '聖護院円頓美町', 'ショウゴインエントミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区聖護院中町', '26', '26103', '6068324', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '聖護院中町', 'ショウゴインナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区聖護院東町', '26', '26103', '6068325', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '聖護院東町', 'ショウゴインヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区岡崎西福ノ川町', '26', '26103', '6068326', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '岡崎西福ノ川町', 'オカザキニシフクノカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区黒谷町', '26', '26103', '6068331', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '黒谷町', 'クロダニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区岡崎東天王町', '26', '26103', '6068332', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '岡崎東天王町', 'オカザキヒガシテンノウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区岡崎法勝寺町', '26', '26103', '6068333', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '岡崎法勝寺町', 'オカザキホウショウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区岡崎南御所町', '26', '26103', '6068334', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '岡崎南御所町', 'オカザキミナミゴショチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区岡崎天王町', '26', '26103', '6068335', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '岡崎天王町', 'オカザキテンノウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区岡崎北御所町', '26', '26103', '6068336', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '岡崎北御所町', 'オカザキキタゴショチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区岡崎西天王町', '26', '26103', '6068341', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '岡崎西天王町', 'オカザキニシテンノウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区岡崎最勝寺町', '26', '26103', '6068342', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '岡崎最勝寺町', 'オカザキサイショウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区岡崎成勝寺町', '26', '26103', '6068343', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '岡崎成勝寺町', 'オカザキセイショウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区岡崎円勝寺町', '26', '26103', '6068344', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '岡崎円勝寺町', 'オカザキエンショウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区東門前町', '26', '26103', '6068345', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '東門前町', 'ヒガシモンゼンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区南門前町', '26', '26103', '6068346', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '南門前町', 'ミナミモンゼンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区岡崎徳成町', '26', '26103', '6068351', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '岡崎徳成町', 'オカザキトクセイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区北門前町', '26', '26103', '6068352', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '北門前町', 'キタモンゼンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区正往寺町', '26', '26103', '6068353', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '正往寺町', 'ショウオウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区頭町', '26', '26103', '6068354', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '頭町', 'カシラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区新東洞院町', '26', '26103', '6068355', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '新東洞院町', 'シンヒガシドウインチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区石原町', '26', '26103', '6068356', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '石原町', 'イシワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区聖護院蓮華蔵町', '26', '26103', '6068357', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '聖護院蓮華蔵町', 'ショウゴインレンゲゾウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区福本町', '26', '26103', '6068361', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '福本町', 'フクモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区法皇寺町', '26', '26103', '6068362', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '法皇寺町', 'ホウオウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区和国町', '26', '26103', '6068363', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '和国町', 'ワコクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区菊鉾町', '26', '26103', '6068364', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '菊鉾町', 'キクホコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区讃州寺町', '26', '26103', '6068365', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '讃州寺町', 'サンシュウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区超勝寺門前町', '26', '26103', '6068366', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '超勝寺門前町', 'チョウショウジモンゼンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区秋築町', '26', '26103', '6068371', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '秋築町', 'アキツキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区吉永町', '26', '26103', '6068372', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '吉永町', 'ヨシナガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区杉本町', '26', '26103', '6068373', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '杉本町', 'スギモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区難波町', '26', '26103', '6068374', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '難波町', 'ナンバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区新車屋町', '26', '26103', '6068375', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '新車屋町', 'シンクルマヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区大菊町', '26', '26103', '6068376', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '大菊町', 'オオキクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区中川町', '26', '26103', '6068381', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '中川町', 'ナカガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区大文字町', '26', '26103', '6068382', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '大文字町', 'ダイモンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区新先斗町', '26', '26103', '6068383', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '新先斗町', 'シンポントチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区新生洲町', '26', '26103', '6068384', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '新生洲町', 'シンイケスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区孫橋町', '26', '26103', '6068385', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '孫橋町', 'マゴハシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区新丸太町', '26', '26103', '6068386', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '新丸太町', 'シンマルタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区法林寺門前町', '26', '26103', '6068387', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '法林寺門前町', 'ホウリンジモンゼンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区聖護院西町', '26', '26103', '6068391', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '聖護院西町', 'ショウゴインニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区聖護院山王町', '26', '26103', '6068392', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '聖護院山王町', 'ショウゴインサンノウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区東竹屋町', '26', '26103', '6068393', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '東竹屋町', 'ヒガシタケヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区聖護院東寺領町', '26', '26103', '6068394', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '聖護院東寺領町', 'ショウゴインヒガシジリョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区東丸太町', '26', '26103', '6068395', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '東丸太町', 'ヒガシマルタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区下堤町', '26', '26103', '6068396', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '下堤町', 'シモツツミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区聖護院川原町', '26', '26103', '6068397', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '聖護院川原町', 'ショウゴインカワハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区浄土寺小山町', '26', '26103', '6068401', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '浄土寺小山町', 'ジョウドジコヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区銀閣寺町', '26', '26103', '6068402', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '銀閣寺町', 'ギンカクジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区浄土寺南田町', '26', '26103', '6068403', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '浄土寺南田町', 'ジョウドジミナミダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区浄土寺下南田町', '26', '26103', '6068404', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '浄土寺下南田町', 'ジョウドジシモミナミダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区浄土寺上南田町', '26', '26103', '6068405', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '浄土寺上南田町', 'ジョウドジカミミナミダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区浄土寺石橋町', '26', '26103', '6068406', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '浄土寺石橋町', 'ジョウドジイシバシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区銀閣寺前町', '26', '26103', '6068407', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '銀閣寺前町', 'ギンカクジマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区浄土寺東田町', '26', '26103', '6068411', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '浄土寺東田町', 'ジョウドジヒガシダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区浄土寺馬場町', '26', '26103', '6068412', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '浄土寺馬場町', 'ジョウドジバンバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区浄土寺下馬場町', '26', '26103', '6068413', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '浄土寺下馬場町', 'ジョウドジシモバンバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区浄土寺真如町', '26', '26103', '6068414', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '浄土寺真如町', 'ジョウドジシンニョチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区岡崎真如堂前町', '26', '26103', '6068415', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '岡崎真如堂前町', 'オカザキシンニョドウマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区浄土寺上馬場町', '26', '26103', '6068416', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '浄土寺上馬場町', 'ジョウドジカミバンバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区浄土寺西田町', '26', '26103', '6068417', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '浄土寺西田町', 'ジョウドジニシダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区鹿ケ谷法然院町', '26', '26103', '6068421', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '鹿ケ谷法然院町', 'シシガタニホウネンインチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区鹿ケ谷御所ノ段町', '26', '26103', '6068422', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '鹿ケ谷御所ノ段町', 'シシガタニゴショノダンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区鹿ケ谷桜谷町', '26', '26103', '6068423', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '鹿ケ谷桜谷町', 'シシガタニサクラダニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区鹿ケ谷宮ノ前町', '26', '26103', '6068424', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '鹿ケ谷宮ノ前町', 'シシガタニミヤノマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区鹿ケ谷西寺ノ前町', '26', '26103', '6068425', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '鹿ケ谷西寺ノ前町', 'シシガタニニシテラノマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区鹿ケ谷寺ノ前町', '26', '26103', '6068426', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '鹿ケ谷寺ノ前町', 'シシガタニテラノマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区鹿ケ谷法然院西町', '26', '26103', '6068427', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '鹿ケ谷法然院西町', 'シシガタニホウネンインニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区鹿ケ谷栗木谷町', '26', '26103', '6068428', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '鹿ケ谷栗木谷町', 'シシガタニクリキタニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区鹿ケ谷下宮ノ前町', '26', '26103', '6068431', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '鹿ケ谷下宮ノ前町', 'シシガタニシモミヤノマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区鹿ケ谷高岸町', '26', '26103', '6068432', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '鹿ケ谷高岸町', 'シシガタニタカギシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区永観堂西町', '26', '26103', '6068433', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '永観堂西町', 'エイカンドウニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区南禅寺下河原町', '26', '26103', '6068434', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '南禅寺下河原町', 'ナンゼンジシモカワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区南禅寺福地町', '26', '26103', '6068435', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '南禅寺福地町', 'ナンゼンジフクチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区粟田口鳥居町', '26', '26103', '6068436', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '粟田口鳥居町', 'アワタグチトリイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区南禅寺草川町', '26', '26103', '6068437', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '南禅寺草川町', 'ナンゼンジクサガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区鹿ケ谷徳善谷町', '26', '26103', '6068441', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '鹿ケ谷徳善谷町', 'シシガタニトクゼンダニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区鹿ケ谷大黒谷町', '26', '26103', '6068442', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '鹿ケ谷大黒谷町', 'シシガタニダイコクダニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区粟田口山下町', '26', '26103', '6068443', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '粟田口山下町', 'アワタグチヤマシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区若王子町', '26', '26103', '6068444', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '若王子町', 'ニャクオウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区永観堂町', '26', '26103', '6068445', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '永観堂町', 'エイカンドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区南禅寺北ノ坊町', '26', '26103', '6068446', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '南禅寺北ノ坊町', 'ナンゼンジキタノボウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区鹿ケ谷上宮ノ前町', '26', '26103', '6068447', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '鹿ケ谷上宮ノ前町', 'シシガタニカミミヤノマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区北白川中山町', '26', '26103', '6068451', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '北白川中山町', 'キタシラカワナカヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区粟田口如意ケ嶽町', '26', '26103', '6068452', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '粟田口如意ケ嶽町', 'アワタグチニョイガダケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区北白川南ケ原町', '26', '26103', '6068453', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '北白川南ケ原町', 'キタシラカワミナミガハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区北白川向ケ谷町', '26', '26103', '6068454', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '北白川向ケ谷町', 'キタシラカワムコウガダニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市左京区北白川小亀谷町', '26', '26103', '6068455', '京都府', 'キョウトフ', '京都市左京区', 'キョウトシサキョウク', '北白川小亀谷町', 'キタシラカワコガメダニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区', '26', '26110', '6070000', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('68961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区安朱毘沙門堂町', '26', '26110', '6078001', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '安朱毘沙門堂町', 'アンシュビシャモンドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区安朱東谷', '26', '26110', '6078002', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '安朱東谷', 'アンシュヒガシダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区安朱稲荷山町', '26', '26110', '6078003', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '安朱稲荷山町', 'アンシュイナリヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区安朱屋敷町', '26', '26110', '6078004', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '安朱屋敷町', 'アンシュヤシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区安朱堂ノ後町', '26', '26110', '6078005', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '安朱堂ノ後町', 'アンシュドウノウシロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区安朱馬場ノ東町', '26', '26110', '6078006', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '安朱馬場ノ東町', 'アンシュババノヒガシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区安朱馬場ノ西町', '26', '26110', '6078007', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '安朱馬場ノ西町', 'アンシュババノニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区安朱東海道町', '26', '26110', '6078008', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '安朱東海道町', 'アンシュヒガシカイドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区安朱北屋敷町', '26', '26110', '6078009', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '安朱北屋敷町', 'アンシュキタヤシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区安朱南屋敷町', '26', '26110', '6078011', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '安朱南屋敷町', 'アンシュミナミヤシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区安朱桟敷町', '26', '26110', '6078012', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '安朱桟敷町', 'アンシュサジキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区安朱中小路町', '26', '26110', '6078013', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '安朱中小路町', 'アンシュナカコウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区安朱山田', '26', '26110', '6078014', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '安朱山田', 'アンシュヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区安朱山川町', '26', '26110', '6078015', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '安朱山川町', 'アンシュヤマカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区安朱中溝町', '26', '26110', '6078016', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '安朱中溝町', 'アンシュナカミゾチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区安朱川向町', '26', '26110', '6078017', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '安朱川向町', 'アンシュカワムカイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区安朱奥ノ田', '26', '26110', '6078018', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '安朱奥ノ田', 'アンシュオクノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区四ノ宮行者谷', '26', '26110', '6078021', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '四ノ宮行者谷', 'シノミヤギョウジャダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区四ノ宮小金塚', '26', '26110', '6078022', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '四ノ宮小金塚', 'シノミヤコガネヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区四ノ宮新開畑', '26', '26110', '6078023', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '四ノ宮新開畑', 'シノミヤシンカイバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区四ノ宮熊ケ谷', '26', '26110', '6078024', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '四ノ宮熊ケ谷', 'シノミヤクマガダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区四ノ宮柳山町', '26', '26110', '6078025', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '四ノ宮柳山町', 'シノミヤヤナギヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区四ノ宮山田町', '26', '26110', '6078026', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '四ノ宮山田町', 'シノミヤヤマダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区四ノ宮川原町', '26', '26110', '6078027', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '四ノ宮川原町', 'シノミヤカワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区四ノ宮岩久保町', '26', '26110', '6078028', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '四ノ宮岩久保町', 'シノミヤイワクボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区四ノ宮大将軍町', '26', '26110', '6078029', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '四ノ宮大将軍町', 'シノミヤタイショウグンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区四ノ宮鎌手町', '26', '26110', '6078031', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '四ノ宮鎌手町', 'シノミヤカマテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区四ノ宮奈良野町', '26', '26110', '6078032', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '四ノ宮奈良野町', 'シノミヤナラノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区四ノ宮芝畑町', '26', '26110', '6078033', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '四ノ宮芝畑町', 'シノミヤシバハタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区四ノ宮泓', '26', '26110', '6078034', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '四ノ宮泓', 'シノミヤフケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区四ノ宮神田町', '26', '26110', '6078035', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '四ノ宮神田町', 'シノミヤカンダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区四ノ宮垣ノ内町', '26', '26110', '6078041', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '四ノ宮垣ノ内町', 'シノミヤカキノウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区四ノ宮南河原町', '26', '26110', '6078042', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '四ノ宮南河原町', 'シノミヤミナミガワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区四ノ宮中在寺町', '26', '26110', '6078043', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '四ノ宮中在寺町', 'シノミヤチュウザイジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区四ノ宮泉水町', '26', '26110', '6078044', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '四ノ宮泉水町', 'シノミヤセンスイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区四ノ宮堂ノ後町', '26', '26110', '6078045', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '四ノ宮堂ノ後町', 'シノミヤドウノゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区髭茶屋桃燈町', '26', '26110', '6078051', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '髭茶屋桃燈町', 'ヒゲチャヤチョウチンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区髭茶屋屋敷町', '26', '26110', '6078052', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '髭茶屋屋敷町', 'ヒゲチャヤヤシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('68999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区音羽草田町', '26', '26110', '6078061', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '音羽草田町', 'オトワクサダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区音羽珍事町', '26', '26110', '6078062', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '音羽珍事町', 'オトワチンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区音羽平林町', '26', '26110', '6078063', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '音羽平林町', 'オトワヒラバヤシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区音羽八ノ坪', '26', '26110', '6078064', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '音羽八ノ坪', 'オトワハチノツボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区音羽山等地', '26', '26110', '6078065', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '音羽山等地', 'オトワサントウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区音羽森廻り町', '26', '26110', '6078066', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '音羽森廻り町', 'オトワモリマワリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区音羽前田町', '26', '26110', '6078067', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '音羽前田町', 'オトワマエダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区音羽稲芝', '26', '26110', '6078068', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '音羽稲芝', 'オトワイナシバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区音羽中芝町', '26', '26110', '6078069', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '音羽中芝町', 'オトワナカシバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区音羽千本町', '26', '26110', '6078071', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '音羽千本町', 'オトワセンボンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区音羽伊勢宿町', '26', '26110', '6078072', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '音羽伊勢宿町', 'オトワイセジュクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区音羽西林', '26', '26110', '6078073', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '音羽西林', 'オトワニシバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区音羽乙出町', '26', '26110', '6078074', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '音羽乙出町', 'オトワオツデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区音羽野田町', '26', '26110', '6078075', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '音羽野田町', 'オトワノダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区音羽役出町', '26', '26110', '6078076', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '音羽役出町', 'オトワヤクデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区音羽沢町', '26', '26110', '6078077', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '音羽沢町', 'オトワサワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区音羽初田町', '26', '26110', '6078078', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '音羽初田町', 'オトワハツダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区音羽前出町', '26', '26110', '6078079', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '音羽前出町', 'オトワマエデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区竹鼻竹ノ街道町', '26', '26110', '6078080', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '竹鼻竹ノ街道町', 'タケハナタケノカイドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区竹鼻外田町', '26', '26110', '6078081', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '竹鼻外田町', 'タケハナソトダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区竹鼻扇町', '26', '26110', '6078082', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '竹鼻扇町', 'タケハナオウギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区竹鼻木ノ本町', '26', '26110', '6078083', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '竹鼻木ノ本町', 'タケハナキノモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区竹鼻立原町', '26', '26110', '6078084', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '竹鼻立原町', 'タケハナタテハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区竹鼻堂ノ前町', '26', '26110', '6078085', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '竹鼻堂ノ前町', 'タケハナドウノマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区竹鼻四丁野町', '26', '26110', '6078086', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '竹鼻四丁野町', 'タケハナシチョウノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区竹鼻サイカシ町', '26', '26110', '6078087', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '竹鼻サイカシ町', 'タケハナサイカシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区竹鼻地蔵寺南町', '26', '26110', '6078088', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '竹鼻地蔵寺南町', 'タケハナジゾウジミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区竹鼻西ノ口町', '26', '26110', '6078089', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '竹鼻西ノ口町', 'タケハナニシノグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区八軒屋敷町', '26', '26110', '6078091', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '八軒屋敷町', 'ハチケンヤシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区小山神無森町', '26', '26110', '6078101', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '小山神無森町', 'コヤマカミナシモリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区小山下ノ池', '26', '26110', '6078102', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '小山下ノ池', 'コヤマシモノイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区小山一石畑', '26', '26110', '6078103', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '小山一石畑', 'コヤマイッコクバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区小山谷田町', '26', '26110', '6078104', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '小山谷田町', 'コヤマタニダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区小山松原畑町', '26', '26110', '6078105', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '小山松原畑町', 'コヤママツハラバタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区小山御坊ノ内町', '26', '26110', '6078106', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '小山御坊ノ内町', 'コヤマゴボウノウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区小山小川町', '26', '26110', '6078107', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '小山小川町', 'コヤマオガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区小山中島町', '26', '26110', '6078108', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '小山中島町', 'コヤマナカジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区小山西御所町', '26', '26110', '6078109', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '小山西御所町', 'コヤマニシゴショチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区小山南溝町', '26', '26110', '6078111', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '小山南溝町', 'コヤマミナミミゾチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区小山中ノ川町', '26', '26110', '6078112', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '小山中ノ川町', 'コヤマナカノカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区小山北溝町', '26', '26110', '6078113', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '小山北溝町', 'コヤマキタミゾチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区小山姫子町', '26', '26110', '6078114', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '小山姫子町', 'コヤマヒメコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区小山北林町', '26', '26110', '6078115', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '小山北林町', 'コヤマキタバヤシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区小山鎮守町', '26', '26110', '6078116', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '小山鎮守町', 'コヤマチンジュチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区大塚向畑町', '26', '26110', '6078121', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '大塚向畑町', 'オオツカムカイバタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区大塚高岩', '26', '26110', '6078122', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '大塚高岩', 'オオツカタカイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区大塚大岩', '26', '26110', '6078123', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '大塚大岩', 'オオツカオオイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区大塚檀ノ浦', '26', '26110', '6078124', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '大塚檀ノ浦', 'オオツカダンノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区大塚西浦町', '26', '26110', '6078125', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '大塚西浦町', 'オオツカニシウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区大塚元屋敷町', '26', '26110', '6078126', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '大塚元屋敷町', 'オオツカモトヤシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区大塚南溝町', '26', '26110', '6078131', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '大塚南溝町', 'オオツカミナミミゾチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区大塚森町', '26', '26110', '6078132', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '大塚森町', 'オオツカモリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区大塚中溝', '26', '26110', '6078133', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '大塚中溝', 'オオツカナカミゾ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区大塚北溝町', '26', '26110', '6078134', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '大塚北溝町', 'オオツカキタミゾチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区大塚野溝町', '26', '26110', '6078135', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '大塚野溝町', 'オオツカノミゾチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区大塚丹田', '26', '26110', '6078136', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '大塚丹田', 'オオツカタンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区東野北井ノ上町', '26', '26110', '6078141', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '東野北井ノ上町', 'ヒガシノキタイノウエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区東野中井ノ上町', '26', '26110', '6078142', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '東野中井ノ上町', 'ヒガシノナカイノウエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区東野南井ノ上町', '26', '26110', '6078143', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '東野南井ノ上町', 'ヒガシノミナミイノウエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区東野井ノ上町', '26', '26110', '6078144', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '東野井ノ上町', 'ヒガシノイノウエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区東野八反畑町', '26', '26110', '6078145', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '東野八反畑町', 'ヒガシノハッタンバタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区東野舞台町', '26', '26110', '6078146', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '東野舞台町', 'ヒガシノブタイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区東野森野町', '26', '26110', '6078147', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '東野森野町', 'ヒガシノモリノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区東野竹田', '26', '26110', '6078151', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '東野竹田', 'ヒガシノタケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区東野八代', '26', '26110', '6078152', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '東野八代', 'ヒガシノヤシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区東野百拍子町', '26', '26110', '6078153', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '東野百拍子町', 'ヒガシノヒャクビョウシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区東野門口町', '26', '26110', '6078154', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '東野門口町', 'ヒガシノモングチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区東野狐藪町', '26', '26110', '6078155', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '東野狐藪町', 'ヒガシノキツネヤブチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区東野片下リ町', '26', '26110', '6078156', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '東野片下リ町', 'ヒガシノカタサガリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区椥辻東浦町', '26', '26110', '6078160', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '椥辻東浦町', 'ナギツジヒガシウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区椥辻中在家町', '26', '26110', '6078161', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '椥辻中在家町', 'ナギツジチュウザイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区椥辻草海道町', '26', '26110', '6078162', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '椥辻草海道町', 'ナギツジクサカイドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区椥辻東潰', '26', '26110', '6078163', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '椥辻東潰', 'ナギツジヒガシツブシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区椥辻西潰', '26', '26110', '6078164', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '椥辻西潰', 'ナギツジニシツブシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区椥辻平田町', '26', '26110', '6078165', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '椥辻平田町', 'ナギツジヒラタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区椥辻番所ケ口町', '26', '26110', '6078166', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '椥辻番所ケ口町', 'ナギツジバンショウガグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区椥辻封シ川町', '26', '26110', '6078167', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '椥辻封シ川町', 'ナギツジフウシガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区椥辻池尻町', '26', '26110', '6078168', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '椥辻池尻町', 'ナギツジイケジリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区椥辻西浦町', '26', '26110', '6078169', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '椥辻西浦町', 'ナギツジニシウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区大宅向山', '26', '26110', '6078170', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '大宅向山', 'オオヤケムカイヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区大宅御所山', '26', '26110', '6078171', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '大宅御所山', 'オオヤケゴショヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区大宅岩屋殿', '26', '26110', '6078172', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '大宅岩屋殿', 'オオヤケイワヤデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区大宅奥山田', '26', '26110', '6078173', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '大宅奥山田', 'オオヤケオクヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区大宅鳥井脇町', '26', '26110', '6078174', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '大宅鳥井脇町', 'オオヤケトリイワキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区大宅山田', '26', '26110', '6078175', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '大宅山田', 'オオヤケヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区大宅中小路町', '26', '26110', '6078176', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '大宅中小路町', 'オオヤケナカコウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区大宅古海道町', '26', '26110', '6078177', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '大宅古海道町', 'オオヤケフルカイドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区大宅五反畑町', '26', '26110', '6078178', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '大宅五反畑町', 'オオヤケゴタンバタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区大宅御所田町', '26', '26110', '6078179', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '大宅御所田町', 'オオヤケゴショデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区大宅打明町', '26', '26110', '6078181', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '大宅打明町', 'オオヤケウチアケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区大宅坂ノ辻町', '26', '26110', '6078182', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '大宅坂ノ辻町', 'オオヤケサカノツジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区大宅辻脇町', '26', '26110', '6078183', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '大宅辻脇町', 'オオヤケツジワキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区大宅甲ノ辻町', '26', '26110', '6078184', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '大宅甲ノ辻町', 'オオヤケコウノツジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区大宅神納町', '26', '26110', '6078185', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '大宅神納町', 'オオヤケカンノウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区大宅早稲ノ内町', '26', '26110', '6078186', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '大宅早稲ノ内町', 'オオヤケワセノウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区大宅石郡町', '26', '26110', '6078187', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '大宅石郡町', 'オオヤケイシゴオリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区大宅関生町', '26', '26110', '6078188', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '大宅関生町', 'オオヤケセキショウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区大宅細田町', '26', '26110', '6078189', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '大宅細田町', 'オオヤケホソダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区大宅烏田町', '26', '26110', '6078191', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '大宅烏田町', 'オオヤケカラスダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区大宅御供田町', '26', '26110', '6078192', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '大宅御供田町', 'オオヤケゴクデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区大宅沢町', '26', '26110', '6078193', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '大宅沢町', 'オオヤケサワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区大宅桟敷', '26', '26110', '6078194', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '大宅桟敷', 'オオヤケサジキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区栗栖野狐塚', '26', '26110', '6078201', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '栗栖野狐塚', 'クリスノキツネヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区栗栖野中臣町', '26', '26110', '6078202', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '栗栖野中臣町', 'クリスノナカトミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区栗栖野打越町', '26', '26110', '6078203', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '栗栖野打越町', 'クリスノウチコシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区栗栖野華ノ木町', '26', '26110', '6078204', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '栗栖野華ノ木町', 'クリスノハナノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区勧修寺東栗栖野町', '26', '26110', '6078211', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '勧修寺東栗栖野町', 'カンシュウジヒガシクリスノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区勧修寺西栗栖野町', '26', '26110', '6078212', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '勧修寺西栗栖野町', 'カンシュウジニシクリスノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区勧修寺東金ケ崎', '26', '26110', '6078213', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '勧修寺東金ケ崎', 'カンシュウジヒガシカナガサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区勧修寺平田', '26', '26110', '6078214', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '勧修寺平田', 'カンシュウジヒラタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区勧修寺縄手町', '26', '26110', '6078215', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '勧修寺縄手町', 'カンシュウジナワテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区勧修寺東出町', '26', '26110', '6078216', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '勧修寺東出町', 'カンシュウジヒガシデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区勧修寺閑林寺', '26', '26110', '6078217', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '勧修寺閑林寺', 'カンシュウジカンリンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区勧修寺御所内町', '26', '26110', '6078218', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '勧修寺御所内町', 'カンシュウジゴショウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区勧修寺風呂尻町', '26', '26110', '6078219', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '勧修寺風呂尻町', 'カンシュウジフロジリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区勧修寺西金ケ崎', '26', '26110', '6078221', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '勧修寺西金ケ崎', 'カンシュウジニシカナガサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区勧修寺東堂田町', '26', '26110', '6078222', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '勧修寺東堂田町', 'カンシュウジヒガシドウデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区勧修寺瀬戸河原', '26', '26110', '6078223', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '勧修寺瀬戸河原', 'カンシュウジセトガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区勧修寺東北出町', '26', '26110', '6078224', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '勧修寺東北出町', 'カンシュウジヒガシキタデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区勧修寺西北出町', '26', '26110', '6078225', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '勧修寺西北出町', 'カンシュウジニシキタデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区勧修寺仁王堂町', '26', '26110', '6078226', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '勧修寺仁王堂町', 'カンシュウジニオウドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区勧修寺下ノ茶屋町', '26', '26110', '6078227', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '勧修寺下ノ茶屋町', 'カンシュウジシモノチャヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区勧修寺本堂山町', '26', '26110', '6078228', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '勧修寺本堂山町', 'カンシュウジホンドウヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区勧修寺泉玉', '26', '26110', '6078229', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '勧修寺泉玉', 'カンシュウジセンギョク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区勧修寺堂田', '26', '26110', '6078231', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '勧修寺堂田', 'カンシュウジドウデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区勧修寺福岡町', '26', '26110', '6078232', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '勧修寺福岡町', 'カンシュウジフクオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区勧修寺南谷町', '26', '26110', '6078233', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '勧修寺南谷町', 'カンシュウジミナミダニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区勧修寺南大日町', '26', '26110', '6078234', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '勧修寺南大日町', 'カンシュウジミナミダイニチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区勧修寺南大日', '26', '26110', '6078235', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '勧修寺南大日', 'カンシュウジミナミダイニチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区勧修寺小松原町', '26', '26110', '6078236', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '勧修寺小松原町', 'カンシュウジコマツバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区勧修寺北大日町', '26', '26110', '6078237', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '勧修寺北大日町', 'カンシュウジキタダイニチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区勧修寺北大日', '26', '26110', '6078238', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '勧修寺北大日', 'カンシュウジキタダイニチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区勧修寺丸山町', '26', '26110', '6078239', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '勧修寺丸山町', 'カンシュウジマルヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区勧修寺冷尻', '26', '26110', '6078241', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '勧修寺冷尻', 'カンシュウジヒエジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区勧修寺柴山', '26', '26110', '6078242', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '勧修寺柴山', 'カンシュウジシバヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区小野蚊ケ瀬', '26', '26110', '6078251', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '小野蚊ケ瀬', 'オノカガセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区小野河原町', '26', '26110', '6078252', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '小野河原町', 'オノカワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区小野弓田町', '26', '26110', '6078253', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '小野弓田町', 'オノユミデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区小野高芝町', '26', '26110', '6078254', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '小野高芝町', 'オノタカシバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区小野御所ノ内町', '26', '26110', '6078255', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '小野御所ノ内町', 'オノゴショノウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区小野荘司町', '26', '26110', '6078256', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '小野荘司町', 'オノショウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区小野御霊町', '26', '26110', '6078257', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '小野御霊町', 'オノゴリョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区小野西浦', '26', '26110', '6078258', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '小野西浦', 'オノニシウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区小野葛篭尻町', '26', '26110', '6078259', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '小野葛篭尻町', 'オノツヅラジリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区小野鐘付田町', '26', '26110', '6078261', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '小野鐘付田町', 'オノカネツキデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区西野山百々町', '26', '26110', '6078301', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '西野山百々町', 'ニシノヤマドドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区西野山欠ノ上町', '26', '26110', '6078302', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '西野山欠ノ上町', 'ニシノヤマカケノウエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区西野山中畑町', '26', '26110', '6078303', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '西野山中畑町', 'ニシノヤマナカハタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区西野山南畑町', '26', '26110', '6078304', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '西野山南畑町', 'ニシノヤマミナミハタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区西野山中臣町', '26', '26110', '6078305', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '西野山中臣町', 'ニシノヤマナカトミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区西野山中鳥井町', '26', '26110', '6078306', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '西野山中鳥井町', 'ニシノヤマナカトリイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区西野山射庭ノ上町', '26', '26110', '6078307', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '西野山射庭ノ上町', 'ニシノヤマイバノウエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区西野山桜ノ馬場町', '26', '26110', '6078308', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '西野山桜ノ馬場町', 'ニシノヤマサクラノババチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区西野山岩ケ谷町', '26', '26110', '6078309', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '西野山岩ケ谷町', 'ニシノヤマイワガタニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区西野山山田', '26', '26110', '6078311', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '西野山山田', 'ニシノヤマヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区川田岩ケ谷', '26', '26110', '6078321', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '川田岩ケ谷', 'カワタイワガタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区川田清水焼団地町', '26', '26110', '6078322', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '川田清水焼団地町', 'カワタキヨミズヤキダンチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区川田岡ノ西', '26', '26110', '6078323', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '川田岡ノ西', 'カワタオカノニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区川田百々', '26', '26110', '6078324', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '川田百々', 'カワタドド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区川田土仏', '26', '26110', '6078325', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '川田土仏', 'カワタツチボトケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区川田御出町', '26', '26110', '6078326', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '川田御出町', 'カワタオイデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区川田山田', '26', '26110', '6078327', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '川田山田', 'カワタヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区川田南山', '26', '26110', '6078328', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '川田南山', 'カワタミナミヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区川田梅ケ谷町', '26', '26110', '6078329', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '川田梅ケ谷町', 'カワタウメガタニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区川田御輿塚町', '26', '26110', '6078331', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '川田御輿塚町', 'カワタミコシヅカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区川田西浦町', '26', '26110', '6078332', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '川田西浦町', 'カワタニシウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区川田前畑町', '26', '26110', '6078333', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '川田前畑町', 'カワタマエハタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区川田欠ノ上', '26', '26110', '6078334', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '川田欠ノ上', 'カワタカケノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区川田南畑町', '26', '26110', '6078335', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '川田南畑町', 'カワタミナミバタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区川田中畑町', '26', '26110', '6078336', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '川田中畑町', 'カワタナカバタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区川田菱尾田', '26', '26110', '6078337', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '川田菱尾田', 'カワタヒシオダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区西野今屋敷町', '26', '26110', '6078341', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '西野今屋敷町', 'ニシノイマヤシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区西野様子見町', '26', '26110', '6078342', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '西野様子見町', 'ニシノヨウスミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区西野阿芸沢町', '26', '26110', '6078343', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '西野阿芸沢町', 'ニシノアゲザワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区西野大手先町', '26', '26110', '6078344', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '西野大手先町', 'ニシノオオテサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区西野離宮町', '26', '26110', '6078345', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '西野離宮町', 'ニシノリキュウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区西野山階町', '26', '26110', '6078346', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '西野山階町', 'ニシノサンカイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区西野左義長町', '26', '26110', '6078347', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '西野左義長町', 'ニシノサギチョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区西野広見町', '26', '26110', '6078348', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '西野広見町', 'ニシノヒロミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区西野八幡田町', '26', '26110', '6078351', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '西野八幡田町', 'ニシノハチマンデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区西野岸ノ下町', '26', '26110', '6078352', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '西野岸ノ下町', 'ニシノキシノシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区西野野色町', '26', '26110', '6078353', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '西野野色町', 'ニシノノイロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区西野小柳町', '26', '26110', '6078354', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '西野小柳町', 'ニシノコヤナギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区西野大鳥井町', '26', '26110', '6078355', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '西野大鳥井町', 'ニシノオオトリイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区西野後藤', '26', '26110', '6078356', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '西野後藤', 'ニシノゴトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区西野櫃川町', '26', '26110', '6078357', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '西野櫃川町', 'ニシノヒツガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区西野楳本町', '26', '26110', '6078358', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '西野楳本町', 'ニシノムメモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区御陵沢ノ川町', '26', '26110', '6078401', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '御陵沢ノ川町', 'ミササギサワノカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区御陵黒岩', '26', '26110', '6078402', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '御陵黒岩', 'ミササギクロイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区御陵大岩', '26', '26110', '6078403', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '御陵大岩', 'ミササギオオイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区御陵大谷町', '26', '26110', '6078404', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '御陵大谷町', 'ミササギオオタニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区御陵田山町', '26', '26110', '6078405', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '御陵田山町', 'ミササギタヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区御陵平林町', '26', '26110', '6078406', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '御陵平林町', 'ミササギヒラバヤシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区御陵安祥寺町', '26', '26110', '6078407', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '御陵安祥寺町', 'ミササギアンショウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区御陵鳥ノ向町', '26', '26110', '6078408', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '御陵鳥ノ向町', 'ミササギトリノムカイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区御陵天徳町', '26', '26110', '6078409', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '御陵天徳町', 'ミササギテントクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区御陵大津畑町', '26', '26110', '6078411', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '御陵大津畑町', 'ミササギオオツバタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区御陵四丁野町', '26', '26110', '6078412', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '御陵四丁野町', 'ミササギシチョウノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区御陵三蔵町', '26', '26110', '6078413', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '御陵三蔵町', 'ミササギサンゾウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区御陵中内町', '26', '26110', '6078414', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '御陵中内町', 'ミササギナカウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区御陵中筋町', '26', '26110', '6078415', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '御陵中筋町', 'ミササギナカスジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区御陵進藤町', '26', '26110', '6078416', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '御陵進藤町', 'ミササギシンドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区御陵別所町', '26', '26110', '6078417', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '御陵別所町', 'ミササギベッシヨチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区御陵牛尾町', '26', '26110', '6078418', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '御陵牛尾町', 'ミササギウシオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区御陵檀ノ後', '26', '26110', '6078419', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '御陵檀ノ後', 'ミササギダンノウシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区御陵岡ノ西町', '26', '26110', '6078421', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '御陵岡ノ西町', 'ミササギオカノニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区御陵封ジ山町', '26', '26110', '6078422', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '御陵封ジ山町', 'ミササギフウジヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区御陵山ノ谷', '26', '26110', '6078423', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '御陵山ノ谷', 'ミササギヤマノタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区御陵原西町', '26', '26110', '6078424', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '御陵原西町', 'ミササギハラニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区御陵上御廟野町', '26', '26110', '6078425', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '御陵上御廟野町', 'ミササギカミゴビョウノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区御陵下御廟野町', '26', '26110', '6078426', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '御陵下御廟野町', 'ミササギシモゴビョウノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区御陵久保町', '26', '26110', '6078427', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '御陵久保町', 'ミササギクボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区御陵血洗町', '26', '26110', '6078428', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '御陵血洗町', 'ミササギチアライチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区御陵荒巻町', '26', '26110', '6078429', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '御陵荒巻町', 'ミササギアラマキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区御陵岡町', '26', '26110', '6078431', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '御陵岡町', 'ミササギオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区御陵鴨戸町', '26', '26110', '6078432', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '御陵鴨戸町', 'ミササギカモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区御陵池堤町', '26', '26110', '6078433', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '御陵池堤町', 'ミササギイケツツミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区上野御所ノ内町', '26', '26110', '6078441', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '上野御所ノ内町', 'ウエノゴショノウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区上野山田', '26', '26110', '6078442', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '上野山田', 'ウエノヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区上野寺井町', '26', '26110', '6078443', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '上野寺井町', 'ウエノテライチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区厨子奥若林町', '26', '26110', '6078451', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '厨子奥若林町', 'ズシオクワカバヤシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区厨子奥矢倉町', '26', '26110', '6078452', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '厨子奥矢倉町', 'ズシオクヤクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区厨子奥尾上町', '26', '26110', '6078453', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '厨子奥尾上町', 'ズシオクオノエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区厨子奥苗代元町', '26', '26110', '6078454', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '厨子奥苗代元町', 'ズシオクナワシロモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区厨子奥長通', '26', '26110', '6078455', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '厨子奥長通', 'ズシオクナガミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区厨子奥花鳥町', '26', '26110', '6078456', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '厨子奥花鳥町', 'ズシオクカチョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区上花山旭山町', '26', '26110', '6078461', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '上花山旭山町', 'カミカザンアサヒヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区上花山花ノ岡町', '26', '26110', '6078462', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '上花山花ノ岡町', 'カミカザンハナノオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区上花山講田町', '26', '26110', '6078463', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '上花山講田町', 'カミカザンコウダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区上花山久保町', '26', '26110', '6078464', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '上花山久保町', 'カミカザンクボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区上花山坂尻', '26', '26110', '6078465', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '上花山坂尻', 'カミカザンサカジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区上花山桜谷', '26', '26110', '6078466', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '上花山桜谷', 'カミカザンサクラダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区北花山大峰町', '26', '26110', '6078471', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '北花山大峰町', 'キタカザンオオミネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区北花山山田町', '26', '26110', '6078472', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '北花山山田町', 'キタカザンヤマダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区北花山六反田町', '26', '26110', '6078473', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '北花山六反田町', 'キタカザンロクタンダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区北花山寺内町', '26', '26110', '6078474', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '北花山寺内町', 'キタカザンテラウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区北花山横田町', '26', '26110', '6078475', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '北花山横田町', 'キタカザンヨコタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区北花山河原町', '26', '26110', '6078476', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '北花山河原町', 'キタカザンカワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区北花山中道町', '26', '26110', '6078481', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '北花山中道町', 'キタカザンナカミチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区北花山大林町', '26', '26110', '6078482', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '北花山大林町', 'キタカザンオオハヤシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区北花山市田町', '26', '26110', '6078483', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '北花山市田町', 'キタカザンイチダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区北花山西ノ野町', '26', '26110', '6078484', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '北花山西ノ野町', 'キタカザンニシノノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区北花山上稚児ケ池', '26', '26110', '6078485', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '北花山上稚児ケ池', 'キタカザンカミチゴガイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区日ノ岡一切経谷町', '26', '26110', '6078491', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '日ノ岡一切経谷町', 'ヒノオカイッサイキョウダニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区日ノ岡夷谷町', '26', '26110', '6078492', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '日ノ岡夷谷町', 'ヒノオカエビスダニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区日ノ岡朝田町', '26', '26110', '6078493', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '日ノ岡朝田町', 'ヒノオカアサダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区日ノ岡堤谷町', '26', '26110', '6078494', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '日ノ岡堤谷町', 'ヒノオカツツミダニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区日ノ岡鴨土町', '26', '26110', '6078495', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '日ノ岡鴨土町', 'ヒノオカカモドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区日ノ岡坂脇町', '26', '26110', '6078496', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '日ノ岡坂脇町', 'ヒノオカサカワキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区日ノ岡ホッパラ町', '26', '26110', '6078497', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '日ノ岡ホッパラ町', 'ヒノオカホッパラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市山科区日ノ岡石塚町', '26', '26110', '6078498', '京都府', 'キョウトフ', '京都市山科区', 'キョウトシヤマシナク', '日ノ岡石塚町', 'ヒノオカイシヅカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市手稲区新発寒1条', '01', '01109', '0060801', '北海道', 'ホッカイドウ', '札幌市手稲区', 'サッポロシテイネク', '新発寒1条', 'シンハッサム01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市手稲区新発寒2条', '01', '01109', '0060802', '北海道', 'ホッカイドウ', '札幌市手稲区', 'サッポロシテイネク', '新発寒2条', 'シンハッサム02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市手稲区新発寒3条', '01', '01109', '0060803', '北海道', 'ホッカイドウ', '札幌市手稲区', 'サッポロシテイネク', '新発寒3条', 'シンハッサム03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市手稲区新発寒4条', '01', '01109', '0060804', '北海道', 'ホッカイドウ', '札幌市手稲区', 'サッポロシテイネク', '新発寒4条', 'シンハッサム04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市手稲区新発寒5条', '01', '01109', '0060805', '北海道', 'ホッカイドウ', '札幌市手稲区', 'サッポロシテイネク', '新発寒5条', 'シンハッサム05ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市手稲区新発寒6条', '01', '01109', '0060806', '北海道', 'ホッカイドウ', '札幌市手稲区', 'サッポロシテイネク', '新発寒6条', 'シンハッサム06ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市手稲区新発寒7条', '01', '01109', '0060807', '北海道', 'ホッカイドウ', '札幌市手稲区', 'サッポロシテイネク', '新発寒7条', 'シンハッサム07ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市手稲区前田1条', '01', '01109', '0060811', '北海道', 'ホッカイドウ', '札幌市手稲区', 'サッポロシテイネク', '前田1条', 'マエダ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市手稲区前田2条', '01', '01109', '0060812', '北海道', 'ホッカイドウ', '札幌市手稲区', 'サッポロシテイネク', '前田2条', 'マエダ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市手稲区前田3条', '01', '01109', '0060813', '北海道', 'ホッカイドウ', '札幌市手稲区', 'サッポロシテイネク', '前田3条', 'マエダ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市手稲区前田4条', '01', '01109', '0060814', '北海道', 'ホッカイドウ', '札幌市手稲区', 'サッポロシテイネク', '前田4条', 'マエダ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市手稲区前田5条', '01', '01109', '0060815', '北海道', 'ホッカイドウ', '札幌市手稲区', 'サッポロシテイネク', '前田5条', 'マエダ05ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市手稲区前田6条', '01', '01109', '0060816', '北海道', 'ホッカイドウ', '札幌市手稲区', 'サッポロシテイネク', '前田6条', 'マエダ06ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市手稲区前田7条', '01', '01109', '0060817', '北海道', 'ホッカイドウ', '札幌市手稲区', 'サッポロシテイネク', '前田7条', 'マエダ07ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市手稲区前田8条', '01', '01109', '0060818', '北海道', 'ホッカイドウ', '札幌市手稲区', 'サッポロシテイネク', '前田8条', 'マエダ08ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市手稲区前田9条', '01', '01109', '0060819', '北海道', 'ホッカイドウ', '札幌市手稲区', 'サッポロシテイネク', '前田9条', 'マエダ09ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市手稲区前田10条', '01', '01109', '0060820', '北海道', 'ホッカイドウ', '札幌市手稲区', 'サッポロシテイネク', '前田10条', 'マエダ10ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市手稲区前田11条', '01', '01109', '0060821', '北海道', 'ホッカイドウ', '札幌市手稲区', 'サッポロシテイネク', '前田11条', 'マエダ11ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市手稲区前田12条', '01', '01109', '0060822', '北海道', 'ホッカイドウ', '札幌市手稲区', 'サッポロシテイネク', '前田12条', 'マエダ12ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市手稲区前田13条', '01', '01109', '0060823', '北海道', 'ホッカイドウ', '札幌市手稲区', 'サッポロシテイネク', '前田13条', 'マエダ13ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市手稲区手稲前田', '01', '01109', '0060829', '北海道', 'ホッカイドウ', '札幌市手稲区', 'サッポロシテイネク', '手稲前田', 'テイネマエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市手稲区曙1条', '01', '01109', '0060831', '北海道', 'ホッカイドウ', '札幌市手稲区', 'サッポロシテイネク', '曙1条', 'アケボノ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市手稲区曙2条', '01', '01109', '0060832', '北海道', 'ホッカイドウ', '札幌市手稲区', 'サッポロシテイネク', '曙2条', 'アケボノ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市手稲区曙3条', '01', '01109', '0060833', '北海道', 'ホッカイドウ', '札幌市手稲区', 'サッポロシテイネク', '曙3条', 'アケボノ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市手稲区曙4条', '01', '01109', '0060834', '北海道', 'ホッカイドウ', '札幌市手稲区', 'サッポロシテイネク', '曙4条', 'アケボノ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市手稲区曙5条', '01', '01109', '0060835', '北海道', 'ホッカイドウ', '札幌市手稲区', 'サッポロシテイネク', '曙5条', 'アケボノ05ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市手稲区曙6条', '01', '01109', '0060836', '北海道', 'ホッカイドウ', '札幌市手稲区', 'サッポロシテイネク', '曙6条', 'アケボノ06ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市手稲区曙7条', '01', '01109', '0060837', '北海道', 'ホッカイドウ', '札幌市手稲区', 'サッポロシテイネク', '曙7条', 'アケボノ07ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市手稲区曙8条', '01', '01109', '0060838', '北海道', 'ホッカイドウ', '札幌市手稲区', 'サッポロシテイネク', '曙8条', 'アケボノ08ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市手稲区曙9条', '01', '01109', '0060839', '北海道', 'ホッカイドウ', '札幌市手稲区', 'サッポロシテイネク', '曙9条', 'アケボノ09ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市手稲区曙10条', '01', '01109', '0060840', '北海道', 'ホッカイドウ', '札幌市手稲区', 'サッポロシテイネク', '曙10条', 'アケボノ10ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市手稲区曙11条', '01', '01109', '0060841', '北海道', 'ホッカイドウ', '札幌市手稲区', 'サッポロシテイネク', '曙11条', 'アケボノ11ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市手稲区曙12条', '01', '01109', '0060842', '北海道', 'ホッカイドウ', '札幌市手稲区', 'サッポロシテイネク', '曙12条', 'アケボノ12ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市手稲区星置1条', '01', '01109', '0060851', '北海道', 'ホッカイドウ', '札幌市手稲区', 'サッポロシテイネク', '星置1条', 'ホシオキ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市手稲区星置2条', '01', '01109', '0060852', '北海道', 'ホッカイドウ', '札幌市手稲区', 'サッポロシテイネク', '星置2条', 'ホシオキ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市手稲区星置3条', '01', '01109', '0060853', '北海道', 'ホッカイドウ', '札幌市手稲区', 'サッポロシテイネク', '星置3条', 'ホシオキ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市手稲区手稲星置', '01', '01109', '0060859', '北海道', 'ホッカイドウ', '札幌市手稲区', 'サッポロシテイネク', '手稲星置', 'テイネホシオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市手稲区手稲山口', '01', '01109', '0060860', '北海道', 'ホッカイドウ', '札幌市手稲区', 'サッポロシテイネク', '手稲山口', 'テイネヤマグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市手稲区明日風', '01', '01109', '0060861', '北海道', 'ホッカイドウ', '札幌市手稲区', 'サッポロシテイネク', '明日風', 'アスカゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区', '26', '26111', '6100000', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('69447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府城陽市', '26', '26207', '6100100', '京都府', 'キョウトフ', '城陽市', 'ジョウヨウシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('69448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府城陽市平川', '26', '26207', '6100101', '京都府', 'キョウトフ', '城陽市', 'ジョウヨウシ', '平川', 'ヒラカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府城陽市久世', '26', '26207', '6100102', '京都府', 'キョウトフ', '城陽市', 'ジョウヨウシ', '久世', 'クセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府城陽市上津屋', '26', '26207', '6100103', '京都府', 'キョウトフ', '城陽市', 'ジョウヨウシ', '上津屋', 'コウヅヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府城陽市富野', '26', '26207', '6100111', '京都府', 'キョウトフ', '城陽市', 'ジョウヨウシ', '富野', 'トノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府城陽市長池', '26', '26207', '6100112', '京都府', 'キョウトフ', '城陽市', 'ジョウヨウシ', '長池', 'ナガイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府城陽市中', '26', '26207', '6100113', '京都府', 'キョウトフ', '城陽市', 'ジョウヨウシ', '中', 'ナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府城陽市市辺', '26', '26207', '6100114', '京都府', 'キョウトフ', '城陽市', 'ジョウヨウシ', '市辺', 'イチノベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府城陽市観音堂', '26', '26207', '6100115', '京都府', 'キョウトフ', '城陽市', 'ジョウヨウシ', '観音堂', 'カンノンドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府城陽市奈島', '26', '26207', '6100116', '京都府', 'キョウトフ', '城陽市', 'ジョウヨウシ', '奈島', 'ナシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府城陽市枇杷庄', '26', '26207', '6100117', '京都府', 'キョウトフ', '城陽市', 'ジョウヨウシ', '枇杷庄', 'ビワノショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府城陽市水主', '26', '26207', '6100118', '京都府', 'キョウトフ', '城陽市', 'ジョウヨウシ', '水主', 'ミズシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府城陽市寺田', '26', '26207', '6100121', '京都府', 'キョウトフ', '城陽市', 'ジョウヨウシ', '寺田', 'テラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綴喜郡宇治田原町', '26', '26344', '6100200', '京都府', 'キョウトフ', '綴喜郡宇治田原町', 'ツヅキグンウジタワラチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('69464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綴喜郡宇治田原町禅定寺', '26', '26344', '6100201', '京都府', 'キョウトフ', '綴喜郡宇治田原町', 'ツヅキグンウジタワラチョウ', '禅定寺', 'ゼンジョウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綴喜郡宇治田原町緑苑坂', '26', '26344', '6100202', '京都府', 'キョウトフ', '綴喜郡宇治田原町', 'ツヅキグンウジタワラチョウ', '緑苑坂', 'リョクエンザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綴喜郡宇治田原町奥山田', '26', '26344', '6100211', '京都府', 'キョウトフ', '綴喜郡宇治田原町', 'ツヅキグンウジタワラチョウ', '奥山田', 'オクヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綴喜郡宇治田原町湯屋谷', '26', '26344', '6100221', '京都府', 'キョウトフ', '綴喜郡宇治田原町', 'ツヅキグンウジタワラチョウ', '湯屋谷', 'ユヤダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綴喜郡宇治田原町立川', '26', '26344', '6100231', '京都府', 'キョウトフ', '綴喜郡宇治田原町', 'ツヅキグンウジタワラチョウ', '立川', 'タチカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綴喜郡宇治田原町南', '26', '26344', '6100241', '京都府', 'キョウトフ', '綴喜郡宇治田原町', 'ツヅキグンウジタワラチョウ', '南', 'ミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綴喜郡宇治田原町高尾', '26', '26344', '6100251', '京都府', 'キョウトフ', '綴喜郡宇治田原町', 'ツヅキグンウジタワラチョウ', '高尾', 'コウノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綴喜郡宇治田原町荒木', '26', '26344', '6100252', '京都府', 'キョウトフ', '綴喜郡宇治田原町', 'ツヅキグンウジタワラチョウ', '荒木', 'アラキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綴喜郡宇治田原町贄田', '26', '26344', '6100253', '京都府', 'キョウトフ', '綴喜郡宇治田原町', 'ツヅキグンウジタワラチョウ', '贄田', 'ネダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綴喜郡宇治田原町銘城台', '26', '26344', '6100254', '京都府', 'キョウトフ', '綴喜郡宇治田原町', 'ツヅキグンウジタワラチョウ', '銘城台', 'メイジョウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綴喜郡宇治田原町郷之口', '26', '26344', '6100255', '京都府', 'キョウトフ', '綴喜郡宇治田原町', 'ツヅキグンウジタワラチョウ', '郷之口', 'ゴウノクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綴喜郡宇治田原町岩山', '26', '26344', '6100261', '京都府', 'キョウトフ', '綴喜郡宇治田原町', 'ツヅキグンウジタワラチョウ', '岩山', 'イワヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京田辺市', '26', '26211', '6100300', '京都府', 'キョウトフ', '京田辺市', 'キョウタナベシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('69480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綴喜郡井手町', '26', '26343', '6100300', '京都府', 'キョウトフ', '綴喜郡井手町', 'ツヅキグンイデチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('69481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綴喜郡井手町多賀', '26', '26343', '6100301', '京都府', 'キョウトフ', '綴喜郡井手町', 'ツヅキグンイデチョウ', '多賀', 'タガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綴喜郡井手町井手', '26', '26343', '6100302', '京都府', 'キョウトフ', '綴喜郡井手町', 'ツヅキグンイデチョウ', '井手', 'イデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綴喜郡井手町田村新田', '26', '26343', '6100303', '京都府', 'キョウトフ', '綴喜郡井手町', 'ツヅキグンイデチョウ', '田村新田', 'タムラシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京田辺市草内', '26', '26211', '6100311', '京都府', 'キョウトフ', '京田辺市', 'キョウタナベシ', '草内', 'クサウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京田辺市飯岡', '26', '26211', '6100312', '京都府', 'キョウトフ', '京田辺市', 'キョウタナベシ', '飯岡', 'イノオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京田辺市三山木', '26', '26211', '6100313', '京都府', 'キョウトフ', '京田辺市', 'キョウタナベシ', '三山木', 'ミヤマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京田辺市宮津', '26', '26211', '6100314', '京都府', 'キョウトフ', '京田辺市', 'キョウタナベシ', '宮津', 'ミヤヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京田辺市多々羅', '26', '26211', '6100321', '京都府', 'キョウトフ', '京田辺市', 'キョウタナベシ', '多々羅', 'タタラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京田辺市普賢寺', '26', '26211', '6100322', '京都府', 'キョウトフ', '京田辺市', 'キョウタナベシ', '普賢寺', 'フゲンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京田辺市水取', '26', '26211', '6100323', '京都府', 'キョウトフ', '京田辺市', 'キョウタナベシ', '水取', 'ミズトリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京田辺市打田', '26', '26211', '6100324', '京都府', 'キョウトフ', '京田辺市', 'キョウタナベシ', '打田', 'ウツタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京田辺市高船', '26', '26211', '6100325', '京都府', 'キョウトフ', '京田辺市', 'キョウタナベシ', '高船', 'タカフネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京田辺市天王', '26', '26211', '6100326', '京都府', 'キョウトフ', '京田辺市', 'キョウタナベシ', '天王', 'テンノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京田辺市田辺', '26', '26211', '6100331', '京都府', 'キョウトフ', '京田辺市', 'キョウタナベシ', '田辺', 'タナベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京田辺市興戸', '26', '26211', '6100332', '京都府', 'キョウトフ', '京田辺市', 'キョウタナベシ', '興戸', 'コウド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京田辺市甘南備台', '26', '26211', '6100333', '京都府', 'キョウトフ', '京田辺市', 'キョウタナベシ', '甘南備台', 'カンナビダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京田辺市田辺中央', '26', '26211', '6100334', '京都府', 'キョウトフ', '京田辺市', 'キョウタナベシ', '田辺中央', 'タナベチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京田辺市薪', '26', '26211', '6100341', '京都府', 'キョウトフ', '京田辺市', 'キョウタナベシ', '薪', 'タキギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京田辺市松井', '26', '26211', '6100342', '京都府', 'キョウトフ', '京田辺市', 'キョウタナベシ', '松井', 'マツイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京田辺市大住', '26', '26211', '6100343', '京都府', 'キョウトフ', '京田辺市', 'キョウタナベシ', '大住', 'オオスミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京田辺市大住ケ丘', '26', '26211', '6100351', '京都府', 'キョウトフ', '京田辺市', 'キョウタナベシ', '大住ケ丘', 'オオスミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京田辺市花住坂', '26', '26211', '6100352', '京都府', 'キョウトフ', '京田辺市', 'キョウタナベシ', '花住坂', 'カスミザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京田辺市松井ケ丘', '26', '26211', '6100353', '京都府', 'キョウトフ', '京田辺市', 'キョウタナベシ', '松井ケ丘', 'マツイガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京田辺市山手南', '26', '26211', '6100354', '京都府', 'キョウトフ', '京田辺市', 'キョウタナベシ', '山手南', 'ヤマテミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京田辺市山手西', '26', '26211', '6100355', '京都府', 'キョウトフ', '京田辺市', 'キョウタナベシ', '山手西', 'ヤマテニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京田辺市山手中央', '26', '26211', '6100356', '京都府', 'キョウトフ', '京田辺市', 'キョウタナベシ', '山手中央', 'ヤマテチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京田辺市山手東', '26', '26211', '6100357', '京都府', 'キョウトフ', '京田辺市', 'キョウタナベシ', '山手東', 'ヤマテヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京田辺市河原', '26', '26211', '6100361', '京都府', 'キョウトフ', '京田辺市', 'キョウタナベシ', '河原', 'カワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京田辺市東', '26', '26211', '6100362', '京都府', 'キョウトフ', '京田辺市', 'キョウタナベシ', '東', 'ヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区大枝北沓掛町', '26', '26111', '6101101', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '大枝北沓掛町', 'オオエキタクツカケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区御陵大枝山町', '26', '26111', '6101102', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '御陵大枝山町', 'ゴリョウオオエヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区御陵峰ケ堂町', '26', '26111', '6101103', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '御陵峰ケ堂町', 'ゴリョウミネガドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区大枝中山町', '26', '26111', '6101104', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '大枝中山町', 'オオエナカヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区大枝塚原町', '26', '26111', '6101105', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '大枝塚原町', 'オオエツカハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区大枝沓掛町', '26', '26111', '6101106', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '大枝沓掛町', 'オオエクツカケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区大枝東長町', '26', '26111', '6101111', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '大枝東長町', 'オオエヒガシナガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区大枝北福西町', '26', '26111', '6101112', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '大枝北福西町', 'オオエキタフクニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区大枝南福西町', '26', '26111', '6101113', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '大枝南福西町', 'オオエミナミフクニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区大原野上里北ノ町', '26', '26111', '6101121', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '大原野上里北ノ町', 'オオハラノカミザトキタノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区大原野東野町', '26', '26111', '6101122', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '大原野東野町', 'オオハラノヒガシノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区大原野上里南ノ町', '26', '26111', '6101123', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '大原野上里南ノ町', 'オオハラノカミザトミナミノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区大原野上里紅葉町', '26', '26111', '6101124', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '大原野上里紅葉町', 'オオハラノカミザトモミジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区大原野上里勝山町', '26', '26111', '6101125', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '大原野上里勝山町', 'オオハラノカミザトカツヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区大原野上里男鹿町', '26', '26111', '6101126', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '大原野上里男鹿町', 'オオハラノカミザトオジカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区大原野上里鳥見町', '26', '26111', '6101127', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '大原野上里鳥見町', 'オオハラノカミザトトリミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区大原野石見町', '26', '26111', '6101128', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '大原野石見町', 'オオハラノイワミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区大原野上羽町', '26', '26111', '6101131', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '大原野上羽町', 'オオハラノウエバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区大原野灰方町', '26', '26111', '6101132', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '大原野灰方町', 'オオハラノハイガタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区大原野小塩町', '26', '26111', '6101133', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '大原野小塩町', 'オオハラノオシオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区大原野石作町', '26', '26111', '6101134', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '大原野石作町', 'オオハラノイシヅクリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区大原野出灰町', '26', '26111', '6101135', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '大原野出灰町', 'オオハラノイズリハチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区大原野外畑町', '26', '26111', '6101136', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '大原野外畑町', 'オオハラノトノハタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区大枝西新林町', '26', '26111', '6101141', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '大枝西新林町', 'オオエニシシンバヤシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区大枝東新林町', '26', '26111', '6101142', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '大枝東新林町', 'オオエヒガシシンバヤシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区大原野東境谷町', '26', '26111', '6101143', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '大原野東境谷町', 'オオハラノヒガシサカイダニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区大原野東竹の里町', '26', '26111', '6101144', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '大原野東竹の里町', 'オオハラノヒガシタケノサトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区大原野西竹の里町', '26', '26111', '6101145', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '大原野西竹の里町', 'オオハラノニシタケノサトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区大原野西境谷町', '26', '26111', '6101146', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '大原野西境谷町', 'オオハラノニシサカイダニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区大枝西長町', '26', '26111', '6101151', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '大枝西長町', 'オオエニシナガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区大原野北春日町', '26', '26111', '6101152', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '大原野北春日町', 'オオハラノキタカスガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区大原野南春日町', '26', '26111', '6101153', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '大原野南春日町', 'オオハラノミナミカスガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩郡当別町', '01', '01303', '0610200', '北海道', 'ホッカイドウ', '石狩郡当別町', 'イシカリグントウベツチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('69551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩郡当別町青山', '01', '01303', '0610201', '北海道', 'ホッカイドウ', '石狩郡当別町', 'イシカリグントウベツチョウ', '青山', 'アオヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩郡当別町茂平沢', '01', '01303', '0610202', '北海道', 'ホッカイドウ', '石狩郡当別町', 'イシカリグントウベツチョウ', '茂平沢', 'モヘイザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩郡当別町みどり野', '01', '01303', '0610203', '北海道', 'ホッカイドウ', '石狩郡当別町', 'イシカリグントウベツチョウ', 'みどり野', 'ミドリノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩郡当別町若葉', '01', '01303', '0610204', '北海道', 'ホッカイドウ', '石狩郡当別町', 'イシカリグントウベツチョウ', '若葉', 'ワカバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩郡当別町下川町', '01', '01303', '0610205', '北海道', 'ホッカイドウ', '石狩郡当別町', 'イシカリグントウベツチョウ', '下川町', 'シモカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩郡当別町川下', '01', '01303', '0610206', '北海道', 'ホッカイドウ', '石狩郡当別町', 'イシカリグントウベツチョウ', '川下', 'カワシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩郡当別町上当別', '01', '01303', '0610207', '北海道', 'ホッカイドウ', '石狩郡当別町', 'イシカリグントウベツチョウ', '上当別', 'カミトウベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩郡当別町弁華別', '01', '01303', '0610208', '北海道', 'ホッカイドウ', '石狩郡当別町', 'イシカリグントウベツチョウ', '弁華別', 'ベンケベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩郡当別町中小屋', '01', '01303', '0610211', '北海道', 'ホッカイドウ', '石狩郡当別町', 'イシカリグントウベツチョウ', '中小屋', 'ナカゴヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩郡当別町金沢', '01', '01303', '0610212', '北海道', 'ホッカイドウ', '石狩郡当別町', 'イシカリグントウベツチョウ', '金沢', 'カナザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩郡当別町東裏', '01', '01303', '0610213', '北海道', 'ホッカイドウ', '石狩郡当別町', 'イシカリグントウベツチョウ', '東裏', 'ヒガシウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩郡当別町蕨岱', '01', '01303', '0610214', '北海道', 'ホッカイドウ', '石狩郡当別町', 'イシカリグントウベツチョウ', '蕨岱', 'ワラビタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩郡当別町対雁', '01', '01303', '0610215', '北海道', 'ホッカイドウ', '石狩郡当別町', 'イシカリグントウベツチョウ', '対雁', 'ツイシカリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩郡当別町栄町', '01', '01303', '0610216', '北海道', 'ホッカイドウ', '石狩郡当別町', 'イシカリグントウベツチョウ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩郡当別町幸町', '01', '01303', '0610217', '北海道', 'ホッカイドウ', '石狩郡当別町', 'イシカリグントウベツチョウ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩郡当別町樺戸町', '01', '01303', '0610218', '北海道', 'ホッカイドウ', '石狩郡当別町', 'イシカリグントウベツチョウ', '樺戸町', 'カバトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩郡当別町東町', '01', '01303', '0610221', '北海道', 'ホッカイドウ', '石狩郡当別町', 'イシカリグントウベツチョウ', '東町', 'ヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩郡当別町元町', '01', '01303', '0610222', '北海道', 'ホッカイドウ', '石狩郡当別町', 'イシカリグントウベツチョウ', '元町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩郡当別町弥生', '01', '01303', '0610223', '北海道', 'ホッカイドウ', '石狩郡当別町', 'イシカリグントウベツチョウ', '弥生', 'ヤヨイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩郡当別町末広', '01', '01303', '0610224', '北海道', 'ホッカイドウ', '石狩郡当別町', 'イシカリグントウベツチョウ', '末広', 'スエヒロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩郡当別町美里', '01', '01303', '0610225', '北海道', 'ホッカイドウ', '石狩郡当別町', 'イシカリグントウベツチョウ', '美里', 'ミサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩郡当別町錦町', '01', '01303', '0610226', '北海道', 'ホッカイドウ', '石狩郡当別町', 'イシカリグントウベツチョウ', '錦町', 'ニシキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩郡当別町園生', '01', '01303', '0610227', '北海道', 'ホッカイドウ', '石狩郡当別町', 'イシカリグントウベツチョウ', '園生', 'ソノオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩郡当別町緑町', '01', '01303', '0610228', '北海道', 'ホッカイドウ', '石狩郡当別町', 'イシカリグントウベツチョウ', '緑町', 'ミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩郡当別町六軒町', '01', '01303', '0610231', '北海道', 'ホッカイドウ', '石狩郡当別町', 'イシカリグントウベツチョウ', '六軒町', 'ロッケンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩郡当別町春日町', '01', '01303', '0610232', '北海道', 'ホッカイドウ', '石狩郡当別町', 'イシカリグントウベツチョウ', '春日町', 'カスガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩郡当別町白樺町', '01', '01303', '0610233', '北海道', 'ホッカイドウ', '石狩郡当別町', 'イシカリグントウベツチョウ', '白樺町', 'シラカバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩郡当別町西町', '01', '01303', '0610234', '北海道', 'ホッカイドウ', '石狩郡当別町', 'イシカリグントウベツチョウ', '西町', 'ニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩郡当別町北栄町', '01', '01303', '0610235', '北海道', 'ホッカイドウ', '石狩郡当別町', 'イシカリグントウベツチョウ', '北栄町', 'ホクエイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩郡当別町青山奥四番川', '01', '01303', '0610251', '北海道', 'ホッカイドウ', '石狩郡当別町', 'イシカリグントウベツチョウ', '青山奥四番川', 'アオヤマオク04バンガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩郡当別町青山奥三番川', '01', '01303', '0610252', '北海道', 'ホッカイドウ', '石狩郡当別町', 'イシカリグントウベツチョウ', '青山奥三番川', 'アオヤマオク03バンガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩郡当別町青山奥二番川', '01', '01303', '0610253', '北海道', 'ホッカイドウ', '石狩郡当別町', 'イシカリグントウベツチョウ', '青山奥二番川', 'アオヤマオク02バンガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩郡当別町青山中央青山奥', '01', '01303', '0610254', '北海道', 'ホッカイドウ', '石狩郡当別町', 'イシカリグントウベツチョウ', '青山中央', 'アオヤマチュウオウ', null, null, '青山奥', 'アオヤマオク');
INSERT INTO `ms_addresses` VALUES ('69588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道樺戸郡月形町', '01', '01430', '0610500', '北海道', 'ホッカイドウ', '樺戸郡月形町', 'カバトグンツキガタチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('69589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道樺戸郡月形町新生', '01', '01430', '0610501', '北海道', 'ホッカイドウ', '樺戸郡月形町', 'カバトグンツキガタチョウ', '新生', 'シンセイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道樺戸郡月形町北農場', '01', '01430', '0610502', '北海道', 'ホッカイドウ', '樺戸郡月形町', 'カバトグンツキガタチョウ', '北農場', 'キタノウジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道樺戸郡月形町豊ケ丘', '01', '01430', '0610503', '北海道', 'ホッカイドウ', '樺戸郡月形町', 'カバトグンツキガタチョウ', '豊ケ丘', 'トヨガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道樺戸郡月形町新富', '01', '01430', '0610504', '北海道', 'ホッカイドウ', '樺戸郡月形町', 'カバトグンツキガタチョウ', '新富', 'シントミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道樺戸郡月形町札比内', '01', '01430', '0610505', '北海道', 'ホッカイドウ', '樺戸郡月形町', 'カバトグンツキガタチョウ', '札比内', 'サッピナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道樺戸郡月形町新宮', '01', '01430', '0610506', '北海道', 'ホッカイドウ', '樺戸郡月形町', 'カバトグンツキガタチョウ', '新宮', 'シングウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道樺戸郡月形町南札比内', '01', '01430', '0610507', '北海道', 'ホッカイドウ', '樺戸郡月形町', 'カバトグンツキガタチョウ', '南札比内', 'ミナミサッピナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道樺戸郡月形町厚栄', '01', '01430', '0610508', '北海道', 'ホッカイドウ', '樺戸郡月形町', 'カバトグンツキガタチョウ', '厚栄', 'コウエイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道樺戸郡月形町市北', '01', '01430', '0610511', '北海道', 'ホッカイドウ', '樺戸郡月形町', 'カバトグンツキガタチョウ', '市北', 'シホク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道樺戸郡月形町市南', '01', '01430', '0610512', '北海道', 'ホッカイドウ', '樺戸郡月形町', 'カバトグンツキガタチョウ', '市南', 'シナン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道樺戸郡月形町農事会', '01', '01430', '0610513', '北海道', 'ホッカイドウ', '樺戸郡月形町', 'カバトグンツキガタチョウ', '農事会', 'ノウジカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道樺戸郡月形町麻生', '01', '01430', '0610514', '北海道', 'ホッカイドウ', '樺戸郡月形町', 'カバトグンツキガタチョウ', '麻生', 'アザブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道樺戸郡月形町五耕地山', '01', '01430', '0610515', '北海道', 'ホッカイドウ', '樺戸郡月形町', 'カバトグンツキガタチョウ', '五耕地山', 'ゴコウチヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道樺戸郡月形町知来乙', '01', '01430', '0610516', '北海道', 'ホッカイドウ', '樺戸郡月形町', 'カバトグンツキガタチョウ', '知来乙', 'チライオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道樺戸郡月形町北郷', '01', '01430', '0610517', '北海道', 'ホッカイドウ', '樺戸郡月形町', 'カバトグンツキガタチョウ', '北郷', 'キタゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道樺戸郡月形町赤川', '01', '01430', '0610518', '北海道', 'ホッカイドウ', '樺戸郡月形町', 'カバトグンツキガタチョウ', '赤川', 'アカガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道樺戸郡月形町南耕地', '01', '01430', '0610521', '北海道', 'ホッカイドウ', '樺戸郡月形町', 'カバトグンツキガタチョウ', '南耕地', 'ミナミコウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道樺戸郡月形町月浜', '01', '01430', '0610522', '北海道', 'ホッカイドウ', '樺戸郡月形町', 'カバトグンツキガタチョウ', '月浜', 'ツキハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道樺戸郡月形町昭栄', '01', '01430', '0610523', '北海道', 'ホッカイドウ', '樺戸郡月形町', 'カバトグンツキガタチョウ', '昭栄', 'ショウエイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道樺戸郡月形町南新田', '01', '01430', '0610524', '北海道', 'ホッカイドウ', '樺戸郡月形町', 'カバトグンツキガタチョウ', '南新田', 'ミナミシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道樺戸郡月形町新栄', '01', '01430', '0610525', '北海道', 'ホッカイドウ', '樺戸郡月形町', 'カバトグンツキガタチョウ', '新栄', 'シンエイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道樺戸郡月形町新田', '01', '01430', '0610526', '北海道', 'ホッカイドウ', '樺戸郡月形町', 'カバトグンツキガタチョウ', '新田', 'シンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道樺戸郡月形町共和', '01', '01430', '0610527', '北海道', 'ホッカイドウ', '樺戸郡月形町', 'カバトグンツキガタチョウ', '共和', 'キョウワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道樺戸郡月形町月ケ岡', '01', '01430', '0610528', '北海道', 'ホッカイドウ', '樺戸郡月形町', 'カバトグンツキガタチョウ', '月ケ岡', 'ツキガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道樺戸郡浦臼町', '01', '01431', '0610600', '北海道', 'ホッカイドウ', '樺戸郡浦臼町', 'カバトグンウラウスチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('69616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道樺戸郡浦臼町鶴沼第1', '01', '01431', '0610601', '北海道', 'ホッカイドウ', '樺戸郡浦臼町', 'カバトグンウラウスチョウ', '鶴沼第1', 'ツルヌマダイ01', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道樺戸郡浦臼町鶴沼第2', '01', '01431', '0610602', '北海道', 'ホッカイドウ', '樺戸郡浦臼町', 'カバトグンウラウスチョウ', '鶴沼第2', 'ツルヌマダイ02', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道樺戸郡浦臼町鶴沼第3', '01', '01431', '0610603', '北海道', 'ホッカイドウ', '樺戸郡浦臼町', 'カバトグンウラウスチョウ', '鶴沼第3', 'ツルヌマダイ03', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道樺戸郡浦臼町浦臼第1', '01', '01431', '0610611', '北海道', 'ホッカイドウ', '樺戸郡浦臼町', 'カバトグンウラウスチョウ', '浦臼第1', 'ウラウスダイ01', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道樺戸郡浦臼町浦臼第2', '01', '01431', '0610612', '北海道', 'ホッカイドウ', '樺戸郡浦臼町', 'カバトグンウラウスチョウ', '浦臼第2', 'ウラウスダイ02', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道樺戸郡浦臼町浦臼第3', '01', '01431', '0610613', '北海道', 'ホッカイドウ', '樺戸郡浦臼町', 'カバトグンウラウスチョウ', '浦臼第3', 'ウラウスダイ03', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道樺戸郡浦臼町浦臼第4', '01', '01431', '0610614', '北海道', 'ホッカイドウ', '樺戸郡浦臼町', 'カバトグンウラウスチョウ', '浦臼第4', 'ウラウスダイ04', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道樺戸郡浦臼町浦臼第5', '01', '01431', '0610615', '北海道', 'ホッカイドウ', '樺戸郡浦臼町', 'カバトグンウラウスチョウ', '浦臼第5', 'ウラウスダイ05', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道樺戸郡浦臼町浦臼第6', '01', '01431', '0610616', '北海道', 'ホッカイドウ', '樺戸郡浦臼町', 'カバトグンウラウスチョウ', '浦臼第6', 'ウラウスダイ06', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道樺戸郡浦臼町浦臼第7', '01', '01431', '0610617', '北海道', 'ホッカイドウ', '樺戸郡浦臼町', 'カバトグンウラウスチョウ', '浦臼第7', 'ウラウスダイ07', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道樺戸郡浦臼町浦臼第8', '01', '01431', '0610618', '北海道', 'ホッカイドウ', '樺戸郡浦臼町', 'カバトグンウラウスチョウ', '浦臼第8', 'ウラウスダイ08', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道樺戸郡浦臼町晩生内第1', '01', '01431', '0610621', '北海道', 'ホッカイドウ', '樺戸郡浦臼町', 'カバトグンウラウスチョウ', '晩生内第1', 'オソキナイダイ01', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道樺戸郡浦臼町晩生内第2', '01', '01431', '0610622', '北海道', 'ホッカイドウ', '樺戸郡浦臼町', 'カバトグンウラウスチョウ', '晩生内第2', 'オソキナイダイ02', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道樺戸郡浦臼町晩生内第3', '01', '01431', '0610623', '北海道', 'ホッカイドウ', '樺戸郡浦臼町', 'カバトグンウラウスチョウ', '晩生内第3', 'オソキナイダイ03', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宇治市', '26', '26204', '6110000', '京都府', 'キョウトフ', '宇治市', 'ウジシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('69632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宇治市六地蔵', '26', '26204', '6110001', '京都府', 'キョウトフ', '宇治市', 'ウジシ', '六地蔵', 'ロクジゾウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宇治市木幡', '26', '26204', '6110002', '京都府', 'キョウトフ', '宇治市', 'ウジシ', '木幡', 'コハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宇治市平尾台', '26', '26204', '6110003', '京都府', 'キョウトフ', '宇治市', 'ウジシ', '平尾台', 'ヒラオダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宇治市五ケ庄', '26', '26204', '6110011', '京都府', 'キョウトフ', '宇治市', 'ウジシ', '五ケ庄', 'ゴカショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宇治市羽戸山', '26', '26204', '6110012', '京都府', 'キョウトフ', '宇治市', 'ウジシ', '羽戸山', 'ハドヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宇治市菟道', '26', '26204', '6110013', '京都府', 'キョウトフ', '宇治市', 'ウジシ', '菟道', 'トドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宇治市明星町', '26', '26204', '6110014', '京都府', 'キョウトフ', '宇治市', 'ウジシ', '明星町', 'ミョウジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宇治市志津川', '26', '26204', '6110015', '京都府', 'キョウトフ', '宇治市', 'ウジシ', '志津川', 'シツカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宇治市宇治', '26', '26204', '6110021', '京都府', 'キョウトフ', '宇治市', 'ウジシ', '宇治', 'ウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宇治市白川', '26', '26204', '6110022', '京都府', 'キョウトフ', '宇治市', 'ウジシ', '白川', 'シラガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宇治市折居台', '26', '26204', '6110023', '京都府', 'キョウトフ', '宇治市', 'ウジシ', '折居台', 'オリイダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宇治市琵琶台', '26', '26204', '6110024', '京都府', 'キョウトフ', '宇治市', 'ウジシ', '琵琶台', 'ビワダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宇治市神明', '26', '26204', '6110025', '京都府', 'キョウトフ', '宇治市', 'ウジシ', '神明', 'シンメイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宇治市開町', '26', '26204', '6110026', '京都府', 'キョウトフ', '宇治市', 'ウジシ', '開町', 'ヒラキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宇治市羽拍子町', '26', '26204', '6110027', '京都府', 'キョウトフ', '宇治市', 'ウジシ', '羽拍子町', 'ハビョウシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宇治市南陵町', '26', '26204', '6110028', '京都府', 'キョウトフ', '宇治市', 'ウジシ', '南陵町', 'ナンリョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宇治市天神台', '26', '26204', '6110029', '京都府', 'キョウトフ', '宇治市', 'ウジシ', '天神台', 'テンジンダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宇治市広野町', '26', '26204', '6110031', '京都府', 'キョウトフ', '宇治市', 'ウジシ', '広野町', 'ヒロノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宇治市寺山台', '26', '26204', '6110032', '京都府', 'キョウトフ', '宇治市', 'ウジシ', '寺山台', 'テラヤマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宇治市大久保町', '26', '26204', '6110033', '京都府', 'キョウトフ', '宇治市', 'ウジシ', '大久保町', 'オオクボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宇治市槇島町', '26', '26204', '6110041', '京都府', 'キョウトフ', '宇治市', 'ウジシ', '槇島町', 'マキシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宇治市小倉町', '26', '26204', '6110042', '京都府', 'キョウトフ', '宇治市', 'ウジシ', '小倉町', 'オグラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宇治市伊勢田町', '26', '26204', '6110043', '京都府', 'キョウトフ', '宇治市', 'ウジシ', '伊勢田町', 'イセダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宇治市伊勢田町名木', '26', '26204', '6110044', '京都府', 'キョウトフ', '宇治市', 'ウジシ', '伊勢田町名木', 'イセダチョウナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宇治市安田町', '26', '26204', '6110045', '京都府', 'キョウトフ', '宇治市', 'ウジシ', '安田町', 'ヤスダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北広島市', '01', '01234', '0611100', '北海道', 'ホッカイドウ', '北広島市', 'キタヒロシマシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('69658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北広島市中の沢', '01', '01234', '0611101', '北海道', 'ホッカイドウ', '北広島市', 'キタヒロシマシ', '中の沢', 'ナカノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北広島市西の里', '01', '01234', '0611102', '北海道', 'ホッカイドウ', '北広島市', 'キタヒロシマシ', '西の里', 'ニシノサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北広島市虹ケ丘', '01', '01234', '0611103', '北海道', 'ホッカイドウ', '北広島市', 'キタヒロシマシ', '虹ケ丘', 'ニジガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北広島市西の里北', '01', '01234', '0611104', '北海道', 'ホッカイドウ', '北広島市', 'キタヒロシマシ', '西の里北', 'ニシノサトキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北広島市西の里東', '01', '01234', '0611105', '北海道', 'ホッカイドウ', '北広島市', 'キタヒロシマシ', '西の里東', 'ニシノサトヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北広島市西の里南', '01', '01234', '0611106', '北海道', 'ホッカイドウ', '北広島市', 'キタヒロシマシ', '西の里南', 'ニシノサトミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北広島市北の里', '01', '01234', '0611111', '北海道', 'ホッカイドウ', '北広島市', 'キタヒロシマシ', '北の里', 'キタノサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北広島市共栄', '01', '01234', '0611112', '北海道', 'ホッカイドウ', '北広島市', 'キタヒロシマシ', '共栄', 'キョウエイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北広島市共栄町', '01', '01234', '0611113', '北海道', 'ホッカイドウ', '北広島市', 'キタヒロシマシ', '共栄町', 'キョウエイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北広島市東共栄', '01', '01234', '0611114', '北海道', 'ホッカイドウ', '北広島市', 'キタヒロシマシ', '東共栄', 'ヒガシキョウエイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北広島市美咲き野', '01', '01234', '0611115', '北海道', 'ホッカイドウ', '北広島市', 'キタヒロシマシ', '美咲き野', 'ミサキノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北広島市中央', '01', '01234', '0611121', '北海道', 'ホッカイドウ', '北広島市', 'キタヒロシマシ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北広島市広島', '01', '01234', '0611122', '北海道', 'ホッカイドウ', '北広島市', 'キタヒロシマシ', '広島', 'ヒロシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北広島市朝日町', '01', '01234', '0611123', '北海道', 'ホッカイドウ', '北広島市', 'キタヒロシマシ', '朝日町', 'アサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北広島市稲穂町西', '01', '01234', '0611124', '北海道', 'ホッカイドウ', '北広島市', 'キタヒロシマシ', '稲穂町西', 'イナホチョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北広島市稲穂町東', '01', '01234', '0611125', '北海道', 'ホッカイドウ', '北広島市', 'キタヒロシマシ', '稲穂町東', 'イナホチョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北広島市新富町東', '01', '01234', '0611126', '北海道', 'ホッカイドウ', '北広島市', 'キタヒロシマシ', '新富町東', 'シントミチョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北広島市新富町西', '01', '01234', '0611127', '北海道', 'ホッカイドウ', '北広島市', 'キタヒロシマシ', '新富町西', 'シントミチョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北広島市美沢', '01', '01234', '0611131', '北海道', 'ホッカイドウ', '北広島市', 'キタヒロシマシ', '美沢', 'ミサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北広島市北進町', '01', '01234', '0611132', '北海道', 'ホッカイドウ', '北広島市', 'キタヒロシマシ', '北進町', 'ホクシンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北広島市栄町', '01', '01234', '0611133', '北海道', 'ホッカイドウ', '北広島市', 'キタヒロシマシ', '栄町', 'サカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北広島市広葉町', '01', '01234', '0611134', '北海道', 'ホッカイドウ', '北広島市', 'キタヒロシマシ', '広葉町', 'コウヨウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北広島市輝美町', '01', '01234', '0611135', '北海道', 'ホッカイドウ', '北広島市', 'キタヒロシマシ', '輝美町', 'テルミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北広島市松葉町', '01', '01234', '0611136', '北海道', 'ホッカイドウ', '北広島市', 'キタヒロシマシ', '松葉町', 'マツバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北広島市緑陽町', '01', '01234', '0611137', '北海道', 'ホッカイドウ', '北広島市', 'キタヒロシマシ', '緑陽町', 'リョクヨウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北広島市青葉町', '01', '01234', '0611141', '北海道', 'ホッカイドウ', '北広島市', 'キタヒロシマシ', '青葉町', 'アオバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北広島市若葉町', '01', '01234', '0611142', '北海道', 'ホッカイドウ', '北広島市', 'キタヒロシマシ', '若葉町', 'ワカバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北広島市南町', '01', '01234', '0611143', '北海道', 'ホッカイドウ', '北広島市', 'キタヒロシマシ', '南町', 'ミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北広島市白樺町', '01', '01234', '0611144', '北海道', 'ホッカイドウ', '北広島市', 'キタヒロシマシ', '白樺町', 'シラカバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北広島市泉町', '01', '01234', '0611145', '北海道', 'ホッカイドウ', '北広島市', 'キタヒロシマシ', '泉町', 'イズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北広島市高台町', '01', '01234', '0611146', '北海道', 'ホッカイドウ', '北広島市', 'キタヒロシマシ', '高台町', 'タカダイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北広島市里見町', '01', '01234', '0611147', '北海道', 'ホッカイドウ', '北広島市', 'キタヒロシマシ', '里見町', 'サトミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北広島市山手町', '01', '01234', '0611148', '北海道', 'ホッカイドウ', '北広島市', 'キタヒロシマシ', '山手町', 'ヤマテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北広島市東の里', '01', '01234', '0611151', '北海道', 'ホッカイドウ', '北広島市', 'キタヒロシマシ', '東の里', 'ヒガシノサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北広島市中の沢', '01', '01234', '0611152', '北海道', 'ホッカイドウ', '北広島市', 'キタヒロシマシ', '中の沢', 'ナカノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北広島市富ケ岡', '01', '01234', '0611153', '北海道', 'ホッカイドウ', '北広島市', 'キタヒロシマシ', '富ケ岡', 'トミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北広島市南の里', '01', '01234', '0611154', '北海道', 'ホッカイドウ', '北広島市', 'キタヒロシマシ', '南の里', 'ミナミノサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北広島市希望ケ丘', '01', '01234', '0611261', '北海道', 'ホッカイドウ', '北広島市', 'キタヒロシマシ', '希望ケ丘', 'キボウガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北広島市輪厚', '01', '01234', '0611264', '北海道', 'ホッカイドウ', '北広島市', 'キタヒロシマシ', '輪厚', 'ワッツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北広島市島松', '01', '01234', '0611265', '北海道', 'ホッカイドウ', '北広島市', 'キタヒロシマシ', '島松', 'シママツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北広島市三島', '01', '01234', '0611266', '北海道', 'ホッカイドウ', '北広島市', 'キタヒロシマシ', '三島', 'ミシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北広島市仁別', '01', '01234', '0611267', '北海道', 'ホッカイドウ', '北広島市', 'キタヒロシマシ', '仁別', 'ニベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北広島市輪厚中央', '01', '01234', '0611268', '北海道', 'ホッカイドウ', '北広島市', 'キタヒロシマシ', '輪厚中央', 'ワッツチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北広島市輪厚元町', '01', '01234', '0611269', '北海道', 'ホッカイドウ', '北広島市', 'キタヒロシマシ', '輪厚元町', 'ワッツモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北広島市大曲', '01', '01234', '0611270', '北海道', 'ホッカイドウ', '北広島市', 'キタヒロシマシ', '大曲', 'オオマガリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北広島市大曲中央', '01', '01234', '0611271', '北海道', 'ホッカイドウ', '北広島市', 'キタヒロシマシ', '大曲中央', 'オオマガリチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北広島市大曲末広', '01', '01234', '0611272', '北海道', 'ホッカイドウ', '北広島市', 'キタヒロシマシ', '大曲末広', 'オオマガリスエヒロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北広島市大曲柏葉', '01', '01234', '0611273', '北海道', 'ホッカイドウ', '北広島市', 'キタヒロシマシ', '大曲柏葉', 'オオマガリハクヨウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北広島市大曲工業団地', '01', '01234', '0611274', '北海道', 'ホッカイドウ', '北広島市', 'キタヒロシマシ', '大曲工業団地', 'オオマガリコウギョウダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北広島市大曲南ケ丘', '01', '01234', '0611275', '北海道', 'ホッカイドウ', '北広島市', 'キタヒロシマシ', '大曲南ケ丘', 'オオマガリミナミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北広島市大曲緑ケ丘', '01', '01234', '0611276', '北海道', 'ホッカイドウ', '北広島市', 'キタヒロシマシ', '大曲緑ケ丘', 'オオマガリミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北広島市大曲光', '01', '01234', '0611277', '北海道', 'ホッカイドウ', '北広島市', 'キタヒロシマシ', '大曲光', 'オオマガリヒカリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北広島市大曲幸町', '01', '01234', '0611278', '北海道', 'ホッカイドウ', '北広島市', 'キタヒロシマシ', '大曲幸町', 'オオマガリサイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北広島市大曲並木', '01', '01234', '0611279', '北海道', 'ホッカイドウ', '北広島市', 'キタヒロシマシ', '大曲並木', 'オオマガリナミキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道恵庭市島松東町', '01', '01231', '0611351', '北海道', 'ホッカイドウ', '恵庭市', 'エニワシ', '島松東町', 'シママツヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道恵庭市島松仲町', '01', '01231', '0611352', '北海道', 'ホッカイドウ', '恵庭市', 'エニワシ', '島松仲町', 'シママツナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道恵庭市島松本町', '01', '01231', '0611353', '北海道', 'ホッカイドウ', '恵庭市', 'エニワシ', '島松本町', 'シママツホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道恵庭市島松旭町', '01', '01231', '0611354', '北海道', 'ホッカイドウ', '恵庭市', 'エニワシ', '島松旭町', 'シママツアサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道恵庭市島松寿町', '01', '01231', '0611355', '北海道', 'ホッカイドウ', '恵庭市', 'エニワシ', '島松寿町', 'シママツコトブキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道恵庭市西島松', '01', '01231', '0611356', '北海道', 'ホッカイドウ', '恵庭市', 'エニワシ', '西島松', 'ニシシママツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道恵庭市林田', '01', '01231', '0611361', '北海道', 'ホッカイドウ', '恵庭市', 'エニワシ', '林田', 'ハヤシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道恵庭市中島松', '01', '01231', '0611362', '北海道', 'ホッカイドウ', '恵庭市', 'エニワシ', '中島松', 'ナカシママツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道恵庭市桜森', '01', '01231', '0611363', '北海道', 'ホッカイドウ', '恵庭市', 'エニワシ', '桜森', 'サクラモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道恵庭市島松沢', '01', '01231', '0611363', '北海道', 'ホッカイドウ', '恵庭市', 'エニワシ', '島松沢', 'シママツザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道恵庭市下島松', '01', '01231', '0611364', '北海道', 'ホッカイドウ', '恵庭市', 'エニワシ', '下島松', 'シモシママツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道恵庭市穂栄', '01', '01231', '0611365', '北海道', 'ホッカイドウ', '恵庭市', 'エニワシ', '穂栄', 'ホエイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道恵庭市北島', '01', '01231', '0611366', '北海道', 'ホッカイドウ', '恵庭市', 'エニワシ', '北島', 'キタジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道恵庭市恵み野東', '01', '01231', '0611371', '北海道', 'ホッカイドウ', '恵庭市', 'エニワシ', '恵み野東', 'メグミノヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道恵庭市恵み野南', '01', '01231', '0611372', '北海道', 'ホッカイドウ', '恵庭市', 'エニワシ', '恵み野南', 'メグミノミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道恵庭市恵み野西', '01', '01231', '0611373', '北海道', 'ホッカイドウ', '恵庭市', 'エニワシ', '恵み野西', 'メグミノニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道恵庭市恵み野北', '01', '01231', '0611374', '北海道', 'ホッカイドウ', '恵庭市', 'エニワシ', '恵み野北', 'メグミノキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道恵庭市南島松', '01', '01231', '0611375', '北海道', 'ホッカイドウ', '恵庭市', 'エニワシ', '南島松', 'ミナミシママツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道恵庭市', '01', '01231', '0611400', '北海道', 'ホッカイドウ', '恵庭市', 'エニワシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('69739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道恵庭市漁太', '01', '01231', '0611401', '北海道', 'ホッカイドウ', '恵庭市', 'エニワシ', '漁太', 'イザリブト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道恵庭市春日', '01', '01231', '0611402', '北海道', 'ホッカイドウ', '恵庭市', 'エニワシ', '春日', 'カスガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道恵庭市中央', '01', '01231', '0611403', '北海道', 'ホッカイドウ', '恵庭市', 'エニワシ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道恵庭市上山口', '01', '01231', '0611404', '北海道', 'ホッカイドウ', '恵庭市', 'エニワシ', '上山口', 'カミヤマグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道恵庭市戸磯', '01', '01231', '0611405', '北海道', 'ホッカイドウ', '恵庭市', 'エニワシ', '戸磯', 'トイソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道恵庭市和光町', '01', '01231', '0611406', '北海道', 'ホッカイドウ', '恵庭市', 'エニワシ', '和光町', 'ワコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道恵庭市黄金北', '01', '01231', '0611407', '北海道', 'ホッカイドウ', '恵庭市', 'エニワシ', '黄金北', 'コガネキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道恵庭市黄金南', '01', '01231', '0611409', '北海道', 'ホッカイドウ', '恵庭市', 'エニワシ', '黄金南', 'コガネミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道恵庭市恵南', '01', '01231', '0611411', '北海道', 'ホッカイドウ', '恵庭市', 'エニワシ', '恵南', 'エナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道恵庭市白樺町', '01', '01231', '0611412', '北海道', 'ホッカイドウ', '恵庭市', 'エニワシ', '白樺町', 'シラカバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道恵庭市本町', '01', '01231', '0611413', '北海道', 'ホッカイドウ', '恵庭市', 'エニワシ', '本町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道恵庭市漁町', '01', '01231', '0611414', '北海道', 'ホッカイドウ', '恵庭市', 'エニワシ', '漁町', 'イザリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道恵庭市泉町', '01', '01231', '0611415', '北海道', 'ホッカイドウ', '恵庭市', 'エニワシ', '泉町', 'イズミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道恵庭市桜町', '01', '01231', '0611416', '北海道', 'ホッカイドウ', '恵庭市', 'エニワシ', '桜町', 'サクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道恵庭市駒場町', '01', '01231', '0611417', '北海道', 'ホッカイドウ', '恵庭市', 'エニワシ', '駒場町', 'コマバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道恵庭市牧場', '01', '01231', '0611421', '北海道', 'ホッカイドウ', '恵庭市', 'エニワシ', '牧場', 'マキバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道恵庭市盤尻', '01', '01231', '0611422', '北海道', 'ホッカイドウ', '恵庭市', 'エニワシ', '盤尻', 'バンジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道恵庭市柏木町', '01', '01231', '0611423', '北海道', 'ホッカイドウ', '恵庭市', 'エニワシ', '柏木町', 'カシワギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道恵庭市大町', '01', '01231', '0611424', '北海道', 'ホッカイドウ', '恵庭市', 'エニワシ', '大町', 'オオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道恵庭市文京町', '01', '01231', '0611425', '北海道', 'ホッカイドウ', '恵庭市', 'エニワシ', '文京町', 'ブンキョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道恵庭市幸町', '01', '01231', '0611426', '北海道', 'ホッカイドウ', '恵庭市', 'エニワシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道恵庭市美咲野', '01', '01231', '0611427', '北海道', 'ホッカイドウ', '恵庭市', 'エニワシ', '美咲野', 'ミサキノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道恵庭市有明町', '01', '01231', '0611431', '北海道', 'ホッカイドウ', '恵庭市', 'エニワシ', '有明町', 'アリアケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道恵庭市恵央町', '01', '01231', '0611432', '北海道', 'ホッカイドウ', '恵庭市', 'エニワシ', '恵央町', 'ケイオウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道恵庭市北柏木町', '01', '01231', '0611433', '北海道', 'ホッカイドウ', '恵庭市', 'エニワシ', '北柏木町', 'キタカシワギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道恵庭市柏陽町', '01', '01231', '0611434', '北海道', 'ホッカイドウ', '恵庭市', 'エニワシ', '柏陽町', 'ハクヨウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道恵庭市中島町', '01', '01231', '0611435', '北海道', 'ホッカイドウ', '恵庭市', 'エニワシ', '中島町', 'ナカジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道恵庭市住吉町', '01', '01231', '0611441', '北海道', 'ホッカイドウ', '恵庭市', 'エニワシ', '住吉町', 'スミヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道恵庭市緑町', '01', '01231', '0611442', '北海道', 'ホッカイドウ', '恵庭市', 'エニワシ', '緑町', 'ミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道恵庭市栄恵町', '01', '01231', '0611443', '北海道', 'ホッカイドウ', '恵庭市', 'エニワシ', '栄恵町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道恵庭市京町', '01', '01231', '0611444', '北海道', 'ホッカイドウ', '恵庭市', 'エニワシ', '京町', 'キョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道恵庭市新町', '01', '01231', '0611445', '北海道', 'ホッカイドウ', '恵庭市', 'エニワシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道恵庭市末広町', '01', '01231', '0611446', '北海道', 'ホッカイドウ', '恵庭市', 'エニワシ', '末広町', 'スエヒロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道恵庭市福住町', '01', '01231', '0611447', '北海道', 'ホッカイドウ', '恵庭市', 'エニワシ', '福住町', 'フクズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道恵庭市相生町', '01', '01231', '0611448', '北海道', 'ホッカイドウ', '恵庭市', 'エニワシ', '相生町', 'アイオイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道恵庭市黄金中央', '01', '01231', '0611449', '北海道', 'ホッカイドウ', '恵庭市', 'エニワシ', '黄金中央', 'コガネチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区', '26', '26109', '6120000', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('69784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草下高松町', '26', '26109', '6120001', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草下高松町', 'フカクサシモタカマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草中川原町', '26', '26109', '6120002', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草中川原町', 'フカクサナカガワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草藤田坪町', '26', '26109', '6120003', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草藤田坪町', 'フカクサフジタノツボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草相深町', '26', '26109', '6120004', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草相深町', 'フカクサアイフカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草森吉町', '26', '26109', '6120005', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草森吉町', 'フカクサモリヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草上横縄町', '26', '26109', '6120006', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草上横縄町', 'フカクサカミヨコナワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草下横縄町', '26', '26109', '6120007', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草下横縄町', 'フカクサシモヨコナワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草六反田町', '26', '26109', '6120008', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草六反田町', 'フカクサロクタンダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草西川原町', '26', '26109', '6120009', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草西川原町', 'フカクサニシガワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草鈴塚町', '26', '26109', '6120011', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草鈴塚町', 'フカクサスズツカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草一ノ坪町', '26', '26109', '6120012', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草一ノ坪町', 'フカクサイチノツボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草祓川町', '26', '26109', '6120013', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草祓川町', 'フカクサハライガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草稲荷鳥居前町', '26', '26109', '6120014', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草稲荷鳥居前町', 'フカクサイナリトリイマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草ススハキ町', '26', '26109', '6120015', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草ススハキ町', 'フカクサススハキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草ケナサ町', '26', '26109', '6120016', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草ケナサ町', 'フカクサケナサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草今在家町', '26', '26109', '6120017', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草今在家町', 'フカクサイマザイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草フケノ内町', '26', '26109', '6120018', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草フケノ内町', 'フカクサフケノウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草平田町', '26', '26109', '6120019', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草平田町', 'フカクサヒラタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草塚本町', '26', '26109', '6120021', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草塚本町', 'フカクサツカモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草綿森町', '26', '26109', '6120022', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草綿森町', 'フカクサワタモリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草町通町', '26', '26109', '6120023', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草町通町', 'フカクサチョウドオリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草野田町', '26', '26109', '6120024', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草野田町', 'フカクサノダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草キトロ町', '26', '26109', '6120025', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草キトロ町', 'フカクサキトロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草堀田町', '26', '26109', '6120026', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草堀田町', 'フカクサホツタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草極楽町', '26', '26109', '6120027', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草極楽町', 'フカクサゴクラクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草飯食町', '26', '26109', '6120028', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草飯食町', 'フカクサイジキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草西浦町', '26', '26109', '6120029', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草西浦町', 'フカクサニシウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草池ノ内町', '26', '26109', '6120031', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草池ノ内町', 'フカクサイケノウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草西飯食町', '26', '26109', '6120032', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草西飯食町', 'フカクサニシイジキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草寺内町', '26', '26109', '6120033', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草寺内町', 'フカクサテラウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草七瀬川町', '26', '26109', '6120034', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草七瀬川町', 'フカクサナナセガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草北蓮池町', '26', '26109', '6120035', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草北蓮池町', 'フカクサキタハスイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草南蓮池町', '26', '26109', '6120036', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草南蓮池町', 'フカクサミナミハスイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草関屋敷町', '26', '26109', '6120037', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草関屋敷町', 'フカクサセキヤシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草仙石屋敷町', '26', '26109', '6120038', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草仙石屋敷町', 'フカクサセンゴクヤシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草北鍵屋町', '26', '26109', '6120041', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草北鍵屋町', 'フカクサキタカギヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草芳永町', '26', '26109', '6120042', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草芳永町', 'フカクサヨシナガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草芳本町', '26', '26109', '6120043', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草芳本町', 'フカクサヨシモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草北新町', '26', '26109', '6120044', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草北新町', 'フカクサキタシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草石橋町', '26', '26109', '6120045', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草石橋町', 'フカクサイシバシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草大亀谷八島町', '26', '26109', '6120046', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草大亀谷八島町', 'フカクサオオカメダニヤシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草大亀谷内膳町', '26', '26109', '6120047', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草大亀谷内膳町', 'フカクサオオカメダニナイゼンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草大亀谷金森出雲町', '26', '26109', '6120048', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草大亀谷金森出雲町', 'フカクサオオカメダニカナモリイズモチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草中ノ島町', '26', '26109', '6120049', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草中ノ島町', 'フカクサナカノシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区墨染町', '26', '26109', '6120051', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '墨染町', 'スミゾメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草墨染町', '26', '26109', '6120052', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草墨染町', 'フカクサスミゾメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区桃山町丹下', '26', '26109', '6120053', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '桃山町丹下', 'モモヤマチョウタンゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区桃山最上町', '26', '26109', '6120054', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '桃山最上町', 'モモヤマモガミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区桃山水野左近東町', '26', '26109', '6120055', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '桃山水野左近東町', 'モモヤマミズノサコンヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区桃山長岡越中北町', '26', '26109', '6120056', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '桃山長岡越中北町', 'モモヤマナガオカエッチュウキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区桃山長岡越中東町', '26', '26109', '6120057', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '桃山長岡越中東町', 'モモヤマナガオカエッチュウヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区桃山長岡越中南町', '26', '26109', '6120058', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '桃山長岡越中南町', 'モモヤマナガオカエッチュウミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区桃山水野左近西町', '26', '26109', '6120059', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '桃山水野左近西町', 'モモヤマミズノサコンニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区桃山福島太夫北町', '26', '26109', '6120061', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '桃山福島太夫北町', 'モモヤマフクシマダユウキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区桃山福島太夫南町', '26', '26109', '6120062', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '桃山福島太夫南町', 'モモヤマフクシマダユウミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区桃山毛利長門東町', '26', '26109', '6120063', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '桃山毛利長門東町', 'モモヤマモウリナガトヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区桃山毛利長門西町', '26', '26109', '6120064', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '桃山毛利長門西町', 'モモヤマモウリナガトニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区桃山羽柴長吉東町', '26', '26109', '6120065', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '桃山羽柴長吉東町', 'モモヤマハシバチョウキチヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区桃山羽柴長吉中町', '26', '26109', '6120066', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '桃山羽柴長吉中町', 'モモヤマハシバチョウキチナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区桃山羽柴長吉西町', '26', '26109', '6120067', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '桃山羽柴長吉西町', 'モモヤマハシバチョウキチニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区桃山福島太夫西町', '26', '26109', '6120068', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '桃山福島太夫西町', 'モモヤマフクシマダユウニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区桃山井伊掃部東町', '26', '26109', '6120071', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '桃山井伊掃部東町', 'モモヤマイイカモンヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区桃山筒井伊賀東町', '26', '26109', '6120072', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '桃山筒井伊賀東町', 'モモヤマツツイイガヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区桃山筒井伊賀西町', '26', '26109', '6120073', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '桃山筒井伊賀西町', 'モモヤマツツイイガニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区桃山井伊掃部西町', '26', '26109', '6120074', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '桃山井伊掃部西町', 'モモヤマイイカモンニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草大島屋敷町', '26', '26109', '6120081', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草大島屋敷町', 'フカクサオオシマヤシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草山村町', '26', '26109', '6120082', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草山村町', 'フカクサヤマムラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区西桝屋町', '26', '26109', '6120083', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '西桝屋町', 'ニシマスヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区鑓屋町', '26', '26109', '6120084', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '鑓屋町', 'ヤリヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区撞木町', '26', '26109', '6120085', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '撞木町', 'シュモクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区桃山町真斉', '26', '26109', '6120086', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '桃山町真斉', 'モモヤマチョウシンサイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草紺屋町', '26', '26109', '6120087', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草紺屋町', 'フカクサコンヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草出羽屋敷町', '26', '26109', '6120088', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草出羽屋敷町', 'フカクサデワヤシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草佐野屋敷町', '26', '26109', '6120089', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草佐野屋敷町', 'フカクササノヤシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草正覚町', '26', '26109', '6120801', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草正覚町', 'フカクサショウカクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草南明町', '26', '26109', '6120802', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草南明町', 'フカクサナンメイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草車阪町', '26', '26109', '6120803', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草車阪町', 'フカクサクルマザカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区稲荷山官有地', '26', '26109', '6120804', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '稲荷山官有地', 'イナリヤマカンユウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草開土口町', '26', '26109', '6120805', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草開土口町', 'フカクサカイドグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草開土町', '26', '26109', '6120806', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草開土町', 'フカクサカイドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草稲荷中之町', '26', '26109', '6120807', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草稲荷中之町', 'フカクサイナリナカノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草稲荷榎木橋町', '26', '26109', '6120808', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草稲荷榎木橋町', 'フカクサイナリエノキバシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草願成町', '26', '26109', '6120809', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草願成町', 'フカクサガンショウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草笹山町', '26', '26109', '6120811', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草笹山町', 'フカクサササヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草坊山町', '26', '26109', '6120812', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草坊山町', 'フカクサボウヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草極楽寺山町', '26', '26109', '6120813', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草極楽寺山町', 'フカクサゴクラクジヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草砥粉山町', '26', '26109', '6120814', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草砥粉山町', 'フカクサトノコヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草飯食山町', '26', '26109', '6120815', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草飯食山町', 'フカクサイジキヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草馬谷町', '26', '26109', '6120816', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草馬谷町', 'フカクサウマタニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草向ケ原町', '26', '26109', '6120817', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草向ケ原町', 'フカクサムカイガハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草中ノ郷山町', '26', '26109', '6120818', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草中ノ郷山町', 'フカクサナカノゴウヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草僧坊山町', '26', '26109', '6120819', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草僧坊山町', 'フカクサソウボウヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草東瓦町', '26', '26109', '6120821', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草東瓦町', 'フカクサヒガシガワラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草鞍ケ谷', '26', '26109', '6120822', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草鞍ケ谷', 'フカクサクラガタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草東軸町', '26', '26109', '6120823', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草東軸町', 'フカクサトウジクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草霧ケ谷町', '26', '26109', '6120824', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草霧ケ谷町', 'フカクサキリガタニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草鐙ケ谷町', '26', '26109', '6120825', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草鐙ケ谷町', 'フカクサアブミガタニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草兜山町', '26', '26109', '6120826', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草兜山町', 'フカクサカブトヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草宮谷町', '26', '26109', '6120827', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草宮谷町', 'フカクサミヤタニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草砂子谷町', '26', '26109', '6120828', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草砂子谷町', 'フカクサスナコダニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草谷口町', '26', '26109', '6120829', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草谷口町', 'フカクサタニグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区桃山町古城山', '26', '26109', '6120831', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '桃山町古城山', 'モモヤマチョウコジョウザン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草大亀谷東安信町', '26', '26109', '6120832', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草大亀谷東安信町', 'フカクサオオカメダニヒガシアンシンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草大亀谷岩山町', '26', '26109', '6120833', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草大亀谷岩山町', 'フカクサオオカメダニイワヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区桃山町安芸山', '26', '26109', '6120834', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '桃山町安芸山', 'モモヤマチョウアキヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区桃山紅雪町', '26', '26109', '6120835', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '桃山紅雪町', 'モモヤマコウセツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草大亀谷安信町', '26', '26109', '6120836', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草大亀谷安信町', 'フカクサオオカメダニアンシンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草稲荷山町', '26', '26109', '6120837', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草稲荷山町', 'フカクサイナリヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草神明講谷町', '26', '26109', '6120838', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草神明講谷町', 'フカクサシンメイコウダニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草本寺山町', '26', '26109', '6120839', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草本寺山町', 'フカクサホンジヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草大亀谷東久宝寺町', '26', '26109', '6120841', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草大亀谷東久宝寺町', 'フカクサオオカメダニヒガシキュウホウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草大亀谷大谷町', '26', '26109', '6120842', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草大亀谷大谷町', 'フカクサオオカメダニオオタニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草大亀谷古御香町', '26', '26109', '6120843', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草大亀谷古御香町', 'フカクサオオカメダニフルゴコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草大亀谷東古御香町', '26', '26109', '6120844', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草大亀谷東古御香町', 'フカクサオオカメダニヒガシフルゴコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草大亀谷敦賀町', '26', '26109', '6120845', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草大亀谷敦賀町', 'フカクサオオカメダニツルガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草大亀谷万帖敷町', '26', '26109', '6120846', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草大亀谷万帖敷町', 'フカクサオオカメダニマンジョウジキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草大亀谷大山町', '26', '26109', '6120847', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草大亀谷大山町', 'フカクサオオカメダニオオヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草大亀谷東寺町', '26', '26109', '6120848', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草大亀谷東寺町', 'フカクサオオカメダニヒガシデラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草大亀谷西寺町', '26', '26109', '6120849', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草大亀谷西寺町', 'フカクサオオカメダニニシデラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草大亀谷六躰町', '26', '26109', '6120851', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草大亀谷六躰町', 'フカクサオオカメダニロクタイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草大亀谷五郎太町', '26', '26109', '6120852', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草大亀谷五郎太町', 'フカクサオオカメダニゴロウタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区桃山町大蔵', '26', '26109', '6120853', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '桃山町大蔵', 'モモヤマチョウオオクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区桃山町島津', '26', '26109', '6120854', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '桃山町島津', 'モモヤマチョウシマヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区桃山町永井久太郎', '26', '26109', '6120855', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '桃山町永井久太郎', 'モモヤマチョウナガイキュウタロウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区桃山町正宗', '26', '26109', '6120856', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '桃山町正宗', 'モモヤマチョウマサムネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草向畑町', '26', '26109', '6120861', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草向畑町', 'フカクサムカイハタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草大亀谷西久宝寺町', '26', '26109', '6120862', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草大亀谷西久宝寺町', 'フカクサオオカメダニニシキュウホウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草藤森町', '26', '26109', '6120863', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草藤森町', 'フカクサフジノモリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草鳥居崎町', '26', '26109', '6120864', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草鳥居崎町', 'フカクサトリイザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草藤森玄蕃町', '26', '26109', '6120865', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草藤森玄蕃町', 'フカクサフジノモリゲンバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草十九軒町', '26', '26109', '6120866', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草十九軒町', 'フカクサジュウキュウケンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草直違橋片町', '26', '26109', '6120867', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草直違橋片町', 'フカクサスジカイバシカタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草直違橋南', '26', '26109', '6120868', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草直違橋南', 'フカクサスジカイバシミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草直違橋北', '26', '26109', '6120869', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草直違橋北', 'フカクサスジカイバシキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草坊町', '26', '26109', '6120871', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草坊町', 'フカクサボウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草真宗院山町', '26', '26109', '6120872', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草真宗院山町', 'フカクサシンジュウインヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草瓦町', '26', '26109', '6120873', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草瓦町', 'フカクサカワラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草東伊達町', '26', '26109', '6120874', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草東伊達町', 'フカクサヒガシダテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草枯木町', '26', '26109', '6120875', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草枯木町', 'フカクサカレキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草西伊達町', '26', '26109', '6120876', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草西伊達町', 'フカクサニシダテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草僧坊町', '26', '26109', '6120877', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草僧坊町', 'フカクサソウボウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草田谷町', '26', '26109', '6120878', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草田谷町', 'フカクサタヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草西出町', '26', '26109', '6120879', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草西出町', 'フカクサニシデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草稲荷御前町', '26', '26109', '6120881', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草稲荷御前町', 'フカクサイナリオンマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草薮之内町', '26', '26109', '6120882', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草薮之内町', 'フカクサヤブノウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草石峰寺山町', '26', '26109', '6120883', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草石峰寺山町', 'フカクサセキホウジヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草西出山町', '26', '26109', '6120884', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草西出山町', 'フカクサニシデヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草宝塔寺山町', '26', '26109', '6120885', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草宝塔寺山町', 'フカクサホウトウジヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草極楽寺町', '26', '26109', '6120886', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草極楽寺町', 'フカクサゴクラクジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草野手町', '26', '26109', '6120887', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草野手町', 'フカクサノデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草大門町', '26', '26109', '6120888', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草大門町', 'フカクサダイモンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草直違橋', '26', '26109', '6120889', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草直違橋', 'フカクサスジカイバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市南区簾舞1条', '01', '01106', '0612261', '北海道', 'ホッカイドウ', '札幌市南区', 'サッポロシミナミク', '簾舞1条', 'ミスマイ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市南区簾舞2条', '01', '01106', '0612262', '北海道', 'ホッカイドウ', '札幌市南区', 'サッポロシミナミク', '簾舞2条', 'ミスマイ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市南区簾舞3条', '01', '01106', '0612263', '北海道', 'ホッカイドウ', '札幌市南区', 'サッポロシミナミク', '簾舞3条', 'ミスマイ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市南区簾舞4条', '01', '01106', '0612264', '北海道', 'ホッカイドウ', '札幌市南区', 'サッポロシミナミク', '簾舞4条', 'ミスマイ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市南区簾舞5条', '01', '01106', '0612265', '北海道', 'ホッカイドウ', '札幌市南区', 'サッポロシミナミク', '簾舞5条', 'ミスマイ05ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市南区簾舞6条', '01', '01106', '0612266', '北海道', 'ホッカイドウ', '札幌市南区', 'サッポロシミナミク', '簾舞6条', 'ミスマイ06ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市南区藤野', '01', '01106', '0612271', '北海道', 'ホッカイドウ', '札幌市南区', 'サッポロシミナミク', '藤野', 'フジノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市南区簾舞', '01', '01106', '0612272', '北海道', 'ホッカイドウ', '札幌市南区', 'サッポロシミナミク', '簾舞', 'ミスマイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市南区豊滝', '01', '01106', '0612273', '北海道', 'ホッカイドウ', '札幌市南区', 'サッポロシミナミク', '豊滝', 'トヨタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市南区小金湯', '01', '01106', '0612274', '北海道', 'ホッカイドウ', '札幌市南区', 'サッポロシミナミク', '小金湯', 'コガネユ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市南区砥山', '01', '01106', '0612275', '北海道', 'ホッカイドウ', '札幌市南区', 'サッポロシミナミク', '砥山', 'トヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市南区白川', '01', '01106', '0612276', '北海道', 'ホッカイドウ', '札幌市南区', 'サッポロシミナミク', '白川', 'シラカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市南区藤野1条', '01', '01106', '0612281', '北海道', 'ホッカイドウ', '札幌市南区', 'サッポロシミナミク', '藤野1条', 'フジノ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市南区藤野2条', '01', '01106', '0612282', '北海道', 'ホッカイドウ', '札幌市南区', 'サッポロシミナミク', '藤野2条', 'フジノ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市南区藤野3条', '01', '01106', '0612283', '北海道', 'ホッカイドウ', '札幌市南区', 'サッポロシミナミク', '藤野3条', 'フジノ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市南区藤野4条', '01', '01106', '0612284', '北海道', 'ホッカイドウ', '札幌市南区', 'サッポロシミナミク', '藤野4条', 'フジノ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市南区藤野5条', '01', '01106', '0612285', '北海道', 'ホッカイドウ', '札幌市南区', 'サッポロシミナミク', '藤野5条', 'フジノ05ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市南区藤野6条', '01', '01106', '0612286', '北海道', 'ホッカイドウ', '札幌市南区', 'サッポロシミナミク', '藤野6条', 'フジノ06ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市南区定山渓', '01', '01106', '0612301', '北海道', 'ホッカイドウ', '札幌市南区', 'サッポロシミナミク', '定山渓', 'ジョウザンケイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市南区定山渓温泉東', '01', '01106', '0612302', '北海道', 'ホッカイドウ', '札幌市南区', 'サッポロシミナミク', '定山渓温泉東', 'ジョウザンケイオンセンヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市南区定山渓温泉西', '01', '01106', '0612303', '北海道', 'ホッカイドウ', '札幌市南区', 'サッポロシミナミク', '定山渓温泉西', 'ジョウザンケイオンセンニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区桃山町日向', '26', '26109', '6128001', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '桃山町日向', 'モモヤマチョウヒュウガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区桃山町山ノ下', '26', '26109', '6128002', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '桃山町山ノ下', 'モモヤマチョウヤマノシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区桃山町西尾', '26', '26109', '6128003', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '桃山町西尾', 'モモヤマチョウニシオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区桃山町町並', '26', '26109', '6128004', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '桃山町町並', 'モモヤマチョウマチナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区桃山町中島町', '26', '26109', '6128005', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '桃山町中島町', 'モモヤマチョウナカジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区桃山町大島', '26', '26109', '6128006', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '桃山町大島', 'モモヤマチョウオオシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区桃山町因幡', '26', '26109', '6128007', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '桃山町因幡', 'モモヤマチョウイナバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区桃山町東町', '26', '26109', '6128008', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '桃山町東町', 'モモヤマチョウヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区桃山町見附町', '26', '26109', '6128009', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '桃山町見附町', 'モモヤマチョウミツケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区桃山町伊庭', '26', '26109', '6128011', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '桃山町伊庭', 'モモヤマチョウイバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区桃山町遠山', '26', '26109', '6128012', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '桃山町遠山', 'モモヤマチョウトオヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区桃山町西町', '26', '26109', '6128013', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '桃山町西町', 'モモヤマチョウニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区桃山町大津町', '26', '26109', '6128014', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '桃山町大津町', 'モモヤマチョウオオツマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区桃山町和泉', '26', '26109', '6128015', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '桃山町和泉', 'モモヤマチョウイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区桃山町養斉', '26', '26109', '6128016', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '桃山町養斉', 'モモヤマチョウヨウサイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区桃山南大島町', '26', '26109', '6128017', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '桃山南大島町', 'モモヤマミナミオオシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区桃山町丹後', '26', '26109', '6128018', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '桃山町丹後', 'モモヤマチョウタンゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区桃山町新町', '26', '26109', '6128019', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '桃山町新町', 'モモヤマチョウシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区桃山町下野', '26', '26109', '6128021', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '桃山町下野', 'モモヤマチョウシモズケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区桃山町駿河', '26', '26109', '6128022', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '桃山町駿河', 'モモヤマチョウスルガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区桃山町美濃', '26', '26109', '6128023', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '桃山町美濃', 'モモヤマチョウミノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区桃山町根来', '26', '26109', '6128024', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '桃山町根来', 'モモヤマチョウネゴロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区桃山与五郎町', '26', '26109', '6128025', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '桃山与五郎町', 'モモヤマヨゴロウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区桃山町伊賀', '26', '26109', '6128026', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '桃山町伊賀', 'モモヤマチョウイガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区桃山町本多上野', '26', '26109', '6128027', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '桃山町本多上野', 'モモヤマチョウホンダコウズケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区桃山町板倉周防', '26', '26109', '6128028', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '桃山町板倉周防', 'モモヤマチョウイタクラスオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区桃山町三河', '26', '26109', '6128029', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '桃山町三河', 'モモヤマチョウミカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区桃山町松平筑前', '26', '26109', '6128031', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '桃山町松平筑前', 'モモヤマチョウマツダイラチクゼン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区桃山筑前台町', '26', '26109', '6128032', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '桃山筑前台町', 'モモヤマチクゼンダイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区桃山町松平武蔵', '26', '26109', '6128033', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '桃山町松平武蔵', 'モモヤマチョウマツダイラムサシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区桃山町泰長老', '26', '26109', '6128034', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '桃山町泰長老', 'モモヤマチョウタイチョウロウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区桃山町立売', '26', '26109', '6128036', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '桃山町立売', 'モモヤマチョウタチウリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区桃山町鍋島', '26', '26109', '6128037', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '桃山町鍋島', 'モモヤマチョウナベシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区鍋島町', '26', '26109', '6128038', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '鍋島町', 'ナベシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区御香宮門前町', '26', '26109', '6128039', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '御香宮門前町', 'ゴコウグウモンゼンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区魚屋町', '26', '26109', '6128041', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '魚屋町', 'ウオヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区柿木浜町', '26', '26109', '6128042', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '柿木浜町', 'カキノキハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区本材木町', '26', '26109', '6128043', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '本材木町', 'モトザイモクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区丹後町', '26', '26109', '6128044', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '丹後町', 'タンゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区南浜町', '26', '26109', '6128045', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '南浜町', 'ミナミハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区塩屋町', '26', '26109', '6128046', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '塩屋町', 'シオヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('69999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区上油掛町', '26', '26109', '6128047', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '上油掛町', 'カミアブラカケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区大阪町', '26', '26109', '6128048', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '大阪町', 'オオサカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区今町', '26', '26109', '6128051', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '今町', 'イママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区瀬戸物町', '26', '26109', '6128052', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '瀬戸物町', 'セトモノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区東大手町', '26', '26109', '6128053', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '東大手町', 'ヒガシオオテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区御堂前町', '26', '26109', '6128054', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '御堂前町', 'ミドウマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区伯耆町', '26', '26109', '6128055', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '伯耆町', 'ホウキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区中油掛町', '26', '26109', '6128056', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '中油掛町', 'ナカアブラカケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区平野町', '26', '26109', '6128057', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '平野町', 'ヒラノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区風呂屋町', '26', '26109', '6128058', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '風呂屋町', 'フロヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区南部町', '26', '26109', '6128059', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '南部町', 'ナンブマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区竹中町', '26', '26109', '6128061', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '竹中町', 'タケナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区鷹匠町', '26', '26109', '6128062', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '鷹匠町', 'タカジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区東組町', '26', '26109', '6128063', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '東組町', 'ヒガシクミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区紺屋町', '26', '26109', '6128064', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '紺屋町', 'コンヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区御駕篭町', '26', '26109', '6128065', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '御駕篭町', 'オカゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区東堺町', '26', '26109', '6128066', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '東堺町', 'ヒガシサカイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区城通町', '26', '26109', '6128067', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '城通町', 'ジョウドオリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区鍛冶屋町', '26', '26109', '6128071', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '鍛冶屋町', 'カジヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区丹波橋町', '26', '26109', '6128072', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '丹波橋町', 'タンババシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区下板橋町', '26', '26109', '6128073', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '下板橋町', 'シモイタバシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区指物町', '26', '26109', '6128074', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '指物町', 'サシモノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区桝形町', '26', '26109', '6128075', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '桝形町', 'マスガタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区南尼崎町', '26', '26109', '6128076', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '南尼崎町', 'ミナミアマガサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区北尼崎町', '26', '26109', '6128077', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '北尼崎町', 'キタアマガサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区大宮町', '26', '26109', '6128078', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '大宮町', 'オオミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区新町', '26', '26109', '6128081', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区両替町', '26', '26109', '6128082', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '両替町', 'リョウガエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区京町', '26', '26109', '6128083', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '京町', 'キョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区京町8丁目横町', '26', '26109', '6128084', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '京町8丁目横町', 'キョウマチハッチョウメヨコマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区京町南', '26', '26109', '6128085', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '京町南', 'キョウマチミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区京町北', '26', '26109', '6128086', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '京町北', 'キョウマチキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区京町大黒町', '26', '26109', '6128087', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '京町大黒町', 'キョウマチダイコクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区桃山町金森出雲', '26', '26109', '6128088', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '桃山町金森出雲', 'モモヤマチョウカナモリイズモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区銀座町', '26', '26109', '6128089', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '銀座町', 'ギンザチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区観音寺町', '26', '26109', '6128101', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '観音寺町', 'カンノンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区道阿弥町', '26', '26109', '6128102', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '道阿弥町', 'ドウアミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区片桐町', '26', '26109', '6128103', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '片桐町', 'カタギリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区西奉行町', '26', '26109', '6128104', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '西奉行町', 'ニシブギョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区東奉行町', '26', '26109', '6128105', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '東奉行町', 'ヒガシブギョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区豊後橋町', '26', '26109', '6128106', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '豊後橋町', 'ブンゴバシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区桃陵町', '26', '26109', '6128107', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '桃陵町', 'トウリョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区奉行前町', '26', '26109', '6128108', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '奉行前町', 'ブギョウマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区讃岐町', '26', '26109', '6128109', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '讃岐町', 'サヌキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区向島橋詰町', '26', '26109', '6128111', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '向島橋詰町', 'ムカイジマハシヅメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区向島本丸町', '26', '26109', '6128112', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '向島本丸町', 'ムカイジマホンマルチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区向島中島町', '26', '26109', '6128113', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '向島中島町', 'ムカイジマナカジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区向島下之町', '26', '26109', '6128114', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '向島下之町', 'ムカイジマシモノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区向島中之町', '26', '26109', '6128115', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '向島中之町', 'ムカイジマナカノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区向島西堤町', '26', '26109', '6128116', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '向島西堤町', 'ムカイジマニシツツミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区向島善阿弥町', '26', '26109', '6128121', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '向島善阿弥町', 'ムカイジマゼンアミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区向島庚申町', '26', '26109', '6128122', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '向島庚申町', 'ムカイジマコウシンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区向島立河原町', '26', '26109', '6128123', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '向島立河原町', 'ムカイジマタテガワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区向島吹田河原町', '26', '26109', '6128124', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '向島吹田河原町', 'ムカイジマスイタガワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区向島東泉寺町', '26', '26109', '6128125', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '向島東泉寺町', 'ムカイジマトウセンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区向島丸町', '26', '26109', '6128131', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '向島丸町', 'ムカイジママルマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区向島藤ノ木町', '26', '26109', '6128132', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '向島藤ノ木町', 'ムカイジマフジノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区向島鷹場町', '26', '26109', '6128133', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '向島鷹場町', 'ムカイジマタカバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区向島清水町', '26', '26109', '6128134', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '向島清水町', 'ムカイジマシミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区向島渡シ場町', '26', '26109', '6128135', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '向島渡シ場町', 'ムカイジマワタシバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区向島四ツ谷池', '26', '26109', '6128136', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '向島四ツ谷池', 'ムカイジマヨツヤイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区向島二ノ丸町', '26', '26109', '6128141', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '向島二ノ丸町', 'ムカイジマニノマルチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区向島上林町', '26', '26109', '6128151', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '向島上林町', 'ムカイジマカンバヤシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区向島新上林', '26', '26109', '6128152', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '向島新上林', 'ムカイジマシンカンバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区向島二本柳', '26', '26109', '6128153', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '向島二本柳', 'ムカイジマニホンヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区向島津田町', '26', '26109', '6128154', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '向島津田町', 'ムカイジマツダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区向島東定請', '26', '26109', '6128155', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '向島東定請', 'ムカイジマヒガシジョウウケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区向島西定請', '26', '26109', '6128156', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '向島西定請', 'ムカイジマニシジョウウケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区向島大黒', '26', '26109', '6128157', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '向島大黒', 'ムカイジマダイコク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区向島上五反田', '26', '26109', '6128158', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '向島上五反田', 'ムカイジマカミゴタンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区恵美酒町', '26', '26109', '6128201', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '恵美酒町', 'エビスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区過書町', '26', '26109', '6128202', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '過書町', 'カショマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区阿波橋町', '26', '26109', '6128203', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '阿波橋町', 'アワバシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区八幡町', '26', '26109', '6128204', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '八幡町', 'ヤワタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区横大路三栖大黒町', '26', '26109', '6128205', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '横大路三栖大黒町', 'ヨコオオジミスダイコクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区下鳥羽六反長町', '26', '26109', '6128206', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '下鳥羽六反長町', 'シモトバロクタンナガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区横大路三栖山城屋敷町', '26', '26109', '6128207', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '横大路三栖山城屋敷町', 'ヨコオオジミスヤマシロヤシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区下鳥羽但馬町', '26', '26109', '6128208', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '下鳥羽但馬町', 'シモトバタジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区下鳥羽南六反長町', '26', '26109', '6128209', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '下鳥羽南六反長町', 'シモトバミナミロクタンナガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区東柳町', '26', '26109', '6128211', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '東柳町', 'ヒガシヤナギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区西柳町', '26', '26109', '6128212', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '西柳町', 'ニシヤナギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区東浜南町', '26', '26109', '6128213', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '東浜南町', 'ヒガシハマミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区西浜町', '26', '26109', '6128214', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '西浜町', 'ニシハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区新中町', '26', '26109', '6128215', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '新中町', 'シンナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区下中町', '26', '26109', '6128216', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '下中町', 'シモナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区上中町', '26', '26109', '6128217', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '上中町', 'カミナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区北浜町', '26', '26109', '6128218', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '北浜町', 'キタハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区表町', '26', '26109', '6128219', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '表町', 'オモテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区弾正町', '26', '26109', '6128221', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '弾正町', 'ダンジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区平戸町', '26', '26109', '6128222', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '平戸町', 'ヒラドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区桃山町弾正島', '26', '26109', '6128223', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '桃山町弾正島', 'モモヤマチョウダンジョウジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区葭島矢倉町', '26', '26109', '6128224', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '葭島矢倉町', 'ヨシジマヤグラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区葭島金井戸町', '26', '26109', '6128225', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '葭島金井戸町', 'ヨシジマカナイドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区桃山町金井戸島', '26', '26109', '6128226', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '桃山町金井戸島', 'モモヤマチョウカナイドジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区三栖向町', '26', '26109', '6128227', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '三栖向町', 'ミスムコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区南新地', '26', '26109', '6128228', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '南新地', 'ミナミシンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区杉本町', '26', '26109', '6128231', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '杉本町', 'スギモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区三栖半町', '26', '26109', '6128232', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '三栖半町', 'ミスハンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区三栖町', '26', '26109', '6128233', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '三栖町', 'ミスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区横大路三栖木下屋敷町', '26', '26109', '6128234', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '横大路三栖木下屋敷町', 'ヨコオオジミスキノシタヤシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区横大路下三栖東ノ口', '26', '26109', '6128235', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '横大路下三栖東ノ口', 'ヨコオオジシモミスヒガシノクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区横大路下三栖里ノ内', '26', '26109', '6128236', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '横大路下三栖里ノ内', 'ヨコオオジシモミスサトノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区横大路三栖池田屋敷町', '26', '26109', '6128237', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '横大路三栖池田屋敷町', 'ヨコオオジミスイケダヤシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区横大路下三栖山殿', '26', '26109', '6128238', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '横大路下三栖山殿', 'ヨコオオジシモミスヤマデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区横大路三栖泥町跡町', '26', '26109', '6128239', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '横大路三栖泥町跡町', 'ヨコオオジミスドロマチアトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区横大路下三栖辻堂町', '26', '26109', '6128241', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '横大路下三栖辻堂町', 'ヨコオオジシモミスツジドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区横大路下三栖梶原町', '26', '26109', '6128242', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '横大路下三栖梶原町', 'ヨコオオジシモミスカジワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区横大路下三栖城ノ前町', '26', '26109', '6128243', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '横大路下三栖城ノ前町', 'ヨコオオジシモミスジョウノマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区横大路千両松町', '26', '26109', '6128244', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '横大路千両松町', 'ヨコオオジセンリョウマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区横大路下三栖宮ノ後', '26', '26109', '6128245', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '横大路下三栖宮ノ後', 'ヨコオオジシモミスミヤノゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区横大路芝生', '26', '26109', '6128246', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '横大路芝生', 'ヨコオオジシバフ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区横大路下三栖南郷', '26', '26109', '6128247', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '横大路下三栖南郷', 'ヨコオオジシモミスナンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区下鳥羽上三栖町', '26', '26109', '6128248', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '下鳥羽上三栖町', 'シモトバカミミスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区横大路沼', '26', '26109', '6128249', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '横大路沼', 'ヨコオオジヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区横大路菅本', '26', '26109', '6128251', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '横大路菅本', 'ヨコオオジスガモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区横大路一本木', '26', '26109', '6128252', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '横大路一本木', 'ヨコオオジイッポンギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区横大路八反田', '26', '26109', '6128253', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '横大路八反田', 'ヨコオオジハッタンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区横大路北ノ口町', '26', '26109', '6128254', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '横大路北ノ口町', 'ヨコオオジキタノクチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区横大路六反畑', '26', '26109', '6128255', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '横大路六反畑', 'ヨコオオジロクタンハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区横大路前川町', '26', '26109', '6128256', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '横大路前川町', 'ヨコオオジマエガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区横大路富ノ森町', '26', '26109', '6128257', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '横大路富ノ森町', 'ヨコオオジトミノモリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区横大路西海道', '26', '26109', '6128261', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '横大路西海道', 'ヨコオオジサイカイドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区横大路神宮寺', '26', '26109', '6128262', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '横大路神宮寺', 'ヨコオオジジングウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区横大路下ノ坪', '26', '26109', '6128263', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '横大路下ノ坪', 'ヨコオオジシモノツボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区横大路松林', '26', '26109', '6128264', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '横大路松林', 'ヨコオオジマツバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区葭島渡場島町', '26', '26109', '6128265', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '葭島渡場島町', 'ヨシジマワタシバジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区向島又兵衛', '26', '26109', '6128266', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '向島又兵衛', 'ムカイジママタベエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区納所下野', '26', '26109', '6128267', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '納所下野', 'ノウソシモノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区納所大野', '26', '26109', '6128268', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '納所大野', 'ノウソオオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区納所岸ノ下', '26', '26109', '6128271', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '納所岸ノ下', 'ノウソキシノシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区納所中河原', '26', '26109', '6128272', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '納所中河原', 'ノウソナカガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区納所和泉屋', '26', '26109', '6128273', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '納所和泉屋', 'ノウソイズミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区納所星柳', '26', '26109', '6128274', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '納所星柳', 'ノウソホシヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区納所町', '26', '26109', '6128275', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '納所町', 'ノウソチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区納所薬師堂', '26', '26109', '6128276', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '納所薬師堂', 'ノウソヤクシドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区納所妙徳寺', '26', '26109', '6128277', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '納所妙徳寺', 'ノウソミョウトクジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区納所南城堀', '26', '26109', '6128278', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '納所南城堀', 'ノウソミナミシロボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区納所北城堀', '26', '26109', '6128279', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '納所北城堀', 'ノウソキタシロボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区横大路上ノ浜町', '26', '26109', '6128281', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '横大路上ノ浜町', 'ヨコオオジカミノハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区横大路畑中町', '26', '26109', '6128282', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '横大路畑中町', 'ヨコオオジハタナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区横大路向ヒ', '26', '26109', '6128283', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '横大路向ヒ', 'ヨコオオジムカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区横大路畔ノ内', '26', '26109', '6128284', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '横大路畔ノ内', 'ヨコオオジクロノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区横大路龍ケ池', '26', '26109', '6128285', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '横大路龍ケ池', 'ヨコオオジタツガイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区横大路長畑町', '26', '26109', '6128286', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '横大路長畑町', 'ヨコオオジナガハタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区横大路中ノ島町', '26', '26109', '6128287', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '横大路中ノ島町', 'ヨコオオジナカノシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区横大路天王後', '26', '26109', '6128291', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '横大路天王後', 'ヨコオオジテンノウゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区横大路朱雀', '26', '26109', '6128292', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '横大路朱雀', 'ヨコオオジシュジャク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区横大路橋本', '26', '26109', '6128293', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '横大路橋本', 'ヨコオオジハシモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区横大路天王前', '26', '26109', '6128294', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '横大路天王前', 'ヨコオオジテンノウマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区横大路鍬ノ本', '26', '26109', '6128295', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '横大路鍬ノ本', 'ヨコオオジクワノモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区横大路柿ノ本町', '26', '26109', '6128296', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '横大路柿ノ本町', 'ヨコオオジカキノモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区横大路貴船', '26', '26109', '6128297', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '横大路貴船', 'ヨコオオジキフネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区加賀屋町', '26', '26109', '6128301', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '加賀屋町', 'カガヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区雁金町', '26', '26109', '6128302', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '雁金町', 'カリガネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区菱屋町', '26', '26109', '6128303', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '菱屋町', 'ヒシヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区榎町', '26', '26109', '6128304', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '榎町', 'エノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区上神泉苑町', '26', '26109', '6128305', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '上神泉苑町', 'カミシンセンエンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区下神泉苑町', '26', '26109', '6128306', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '下神泉苑町', 'シモシンセンエンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区景勝町', '26', '26109', '6128307', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '景勝町', 'カゲカツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区鳥羽町', '26', '26109', '6128308', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '鳥羽町', 'トバマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区奈良屋町', '26', '26109', '6128311', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '奈良屋町', 'ナラヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区津知橋町', '26', '26109', '6128312', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '津知橋町', 'ツチバシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区西鍵屋町', '26', '26109', '6128313', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '西鍵屋町', 'ニシカギヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区住吉町', '26', '26109', '6128314', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '住吉町', 'スミヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区中之町', '26', '26109', '6128315', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '中之町', 'ナカノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区上板橋町', '26', '26109', '6128316', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '上板橋町', 'カミイタバシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区堀詰町', '26', '26109', '6128317', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '堀詰町', 'ホリヅメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区紙子屋町', '26', '26109', '6128318', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '紙子屋町', 'カミコヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区石屋町', '26', '26109', '6128319', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '石屋町', 'イシヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区越前町', '26', '26109', '6128321', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '越前町', 'エチゼンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区桝屋町', '26', '26109', '6128322', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '桝屋町', 'マスヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区大和町', '26', '26109', '6128323', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '大和町', 'ヤマトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区小豆屋町', '26', '26109', '6128324', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '小豆屋町', 'アズキヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区清水町', '26', '26109', '6128325', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '清水町', 'シミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区東朱雀町', '26', '26109', '6128326', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '東朱雀町', 'ヒガシシュジャクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区西朱雀町', '26', '26109', '6128327', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '西朱雀町', 'ニシシュジャクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区等安町', '26', '26109', '6128328', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '等安町', 'トウアンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区黒茶屋町', '26', '26109', '6128329', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '黒茶屋町', 'クロチャヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区菊屋町', '26', '26109', '6128331', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '菊屋町', 'キクヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区樽屋町', '26', '26109', '6128332', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '樽屋町', 'タルヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区白銀町', '26', '26109', '6128333', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '白銀町', 'シロガネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区東大文字町', '26', '26109', '6128334', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '東大文字町', 'ヒガシダイモンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区海老屋町', '26', '26109', '6128335', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '海老屋町', 'エビヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区東大黒町', '26', '26109', '6128336', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '東大黒町', 'ヒガシダイコクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区西大黒町', '26', '26109', '6128337', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '西大黒町', 'ニシダイコクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区舞台町', '26', '26109', '6128338', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '舞台町', 'ブタイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区聚楽町', '26', '26109', '6128341', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '聚楽町', 'ジュラクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区久米町', '26', '26109', '6128342', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '久米町', 'クメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区聚楽町', '26', '26109', '6128343', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '聚楽町', 'ジュラクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区大津町', '26', '26109', '6128344', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '大津町', 'オオツマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区西堺町', '26', '26109', '6128345', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '西堺町', 'ニシサカイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区松屋町', '26', '26109', '6128346', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '松屋町', 'マツヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区成町', '26', '26109', '6128347', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '成町', 'ナルマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区土橋町', '26', '26109', '6128351', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '土橋町', 'ドバシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区肥後町', '26', '26109', '6128352', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '肥後町', 'ヒゴマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区東町', '26', '26109', '6128353', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '東町', 'ヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区西町', '26', '26109', '6128354', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '西町', 'ニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区東菱屋町', '26', '26109', '6128355', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '東菱屋町', 'ヒガシヒシヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区革屋町', '26', '26109', '6128356', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '革屋町', 'カワヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区帯屋町', '26', '26109', '6128357', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '帯屋町', 'オビヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区西尼崎町', '26', '26109', '6128358', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '西尼崎町', 'ニシアマガサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区問屋町', '26', '26109', '6128359', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '問屋町', 'トイヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区片原町', '26', '26109', '6128361', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '片原町', 'カタハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区西大手町', '26', '26109', '6128362', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '西大手町', 'ニシオオテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区納屋町', '26', '26109', '6128363', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '納屋町', 'ナヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区下油掛町', '26', '26109', '6128364', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '下油掛町', 'シモアブラカケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区車町', '26', '26109', '6128365', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '車町', 'クルママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区京橋町', '26', '26109', '6128366', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '京橋町', 'キョウバシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区山崎町', '26', '26109', '6128367', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '山崎町', 'ヤマザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区周防町', '26', '26109', '6128368', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '周防町', 'スオウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区村上町', '26', '26109', '6128369', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '村上町', 'ムラカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区竹田松林町', '26', '26109', '6128371', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '竹田松林町', 'タケダマツバヤシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区北端町', '26', '26109', '6128372', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '北端町', 'キタハタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区毛利町', '26', '26109', '6128373', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '毛利町', 'モウリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区治部町', '26', '26109', '6128374', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '治部町', 'ジブチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区川東町', '26', '26109', '6128375', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '川東町', 'カワヒガシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区西大文字町', '26', '26109', '6128376', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '西大文字町', 'ニシダイモンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区島津町', '26', '26109', '6128377', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '島津町', 'シマヅチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区南寝小屋町', '26', '26109', '6128379', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '南寝小屋町', 'ミナミネコヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区下鳥羽葭田町', '26', '26109', '6128381', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '下鳥羽葭田町', 'シモトバヨシデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区下鳥羽浄春ケ前町', '26', '26109', '6128384', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '下鳥羽浄春ケ前町', 'シモトバジョウシュンガマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区下鳥羽小柳町', '26', '26109', '6128385', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '下鳥羽小柳町', 'シモトバコヤナギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区下鳥羽澱女町', '26', '26109', '6128386', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '下鳥羽澱女町', 'シモトバヨドメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区下鳥羽平塚町', '26', '26109', '6128387', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '下鳥羽平塚町', 'シモトバヒラツカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区北寝小屋町', '26', '26109', '6128388', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '北寝小屋町', 'キタネコヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区下鳥羽芹川町', '26', '26109', '6128391', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '下鳥羽芹川町', 'シモトバセリカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区下鳥羽北ノ口町', '26', '26109', '6128392', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '下鳥羽北ノ口町', 'シモトバキタノクチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区下鳥羽渡瀬町', '26', '26109', '6128393', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '下鳥羽渡瀬町', 'シモトバワタリセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区下鳥羽西芹川町', '26', '26109', '6128394', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '下鳥羽西芹川町', 'シモトバニシセリカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区下鳥羽東芹川町', '26', '26109', '6128395', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '下鳥羽東芹川町', 'シモトバヒガシセリカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草下川原町', '26', '26109', '6128401', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草下川原町', 'フカクサシモガワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草川久保町', '26', '26109', '6128402', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草川久保町', 'フカクサカワクボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草ヲカヤ町', '26', '26109', '6128403', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草ヲカヤ町', 'フカクサオカヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草向川原町', '26', '26109', '6128404', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草向川原町', 'フカクサムカイガワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草勧進橋町', '26', '26109', '6128405', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草勧進橋町', 'フカクサカンジンバシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区竹田久保町', '26', '26109', '6128411', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '竹田久保町', 'タケダクボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区竹田中川原町', '26', '26109', '6128412', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '竹田中川原町', 'タケダナカガワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区竹田三ツ杭町', '26', '26109', '6128413', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '竹田三ツ杭町', 'タケダミツクイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区竹田段川原町', '26', '26109', '6128414', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '竹田段川原町', 'タケダダンノガワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区竹田中島町', '26', '26109', '6128415', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '竹田中島町', 'タケダナカジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区竹田流池町', '26', '26109', '6128416', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '竹田流池町', 'タケダリュウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区竹田向代町川町', '26', '26109', '6128417', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '竹田向代町川町', 'タケダムカイダイマチカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区竹田向代町', '26', '26109', '6128418', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '竹田向代町', 'タケダムカイダイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区竹田桶ノ井町', '26', '26109', '6128421', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '竹田桶ノ井町', 'タケダオケノイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区竹田七瀬川町', '26', '26109', '6128422', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '竹田七瀬川町', 'タケダナナセガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区竹田内畑町', '26', '26109', '6128423', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '竹田内畑町', 'タケダウチハタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区竹田田中殿町', '26', '26109', '6128425', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '竹田田中殿町', 'タケダタナカデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区竹田青池町', '26', '26109', '6128426', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '竹田青池町', 'タケダアオイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区竹田真幡木町', '26', '26109', '6128427', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '竹田真幡木町', 'タケダマハタギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区竹田西桶ノ井町', '26', '26109', '6128428', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '竹田西桶ノ井町', 'タケダニシオケノイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草越後屋敷町', '26', '26109', '6128431', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草越後屋敷町', 'フカクサエチゴヤシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草柴田屋敷町', '26', '26109', '6128432', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草柴田屋敷町', 'フカクサシバタヤシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草善導寺町', '26', '26109', '6128433', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草善導寺町', 'フカクサゼンドウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草加賀屋敷町', '26', '26109', '6128434', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草加賀屋敷町', 'フカクサカガヤシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草泓ノ壺町', '26', '26109', '6128435', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草泓ノ壺町', 'フカクサフケノツボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草新門丈町', '26', '26109', '6128436', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草新門丈町', 'フカクサシンモンジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草小久保町', '26', '26109', '6128437', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草小久保町', 'フカクサコクボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草フチ町', '26', '26109', '6128438', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草フチ町', 'フカクサフチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区深草五反田町', '26', '26109', '6128439', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '深草五反田町', 'フカクサゴタンダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区竹田醍醐田町', '26', '26109', '6128441', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '竹田醍醐田町', 'タケダダイゴデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区竹田狩賀町', '26', '26109', '6128442', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '竹田狩賀町', 'タケダカルガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区竹田藁屋町', '26', '26109', '6128443', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '竹田藁屋町', 'タケダワラヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区竹田田中宮町', '26', '26109', '6128444', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '竹田田中宮町', 'タケダタナカミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区竹田浄菩提院町', '26', '26109', '6128445', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '竹田浄菩提院町', 'タケダジョウボダイインチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区竹田中内畑町', '26', '26109', '6128446', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '竹田中内畑町', 'タケダナカウチハタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区竹田西内畑町', '26', '26109', '6128447', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '竹田西内畑町', 'タケダニシウチハタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区竹田東小屋ノ内町', '26', '26109', '6128448', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '竹田東小屋ノ内町', 'タケダヒガシコヤノウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区竹田西小屋ノ内町', '26', '26109', '6128449', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '竹田西小屋ノ内町', 'タケダニシコヤノウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区竹田鳥羽殿町', '26', '26109', '6128450', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '竹田鳥羽殿町', 'タケダトバドノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区中島北ノ口町', '26', '26109', '6128451', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '中島北ノ口町', 'ナカジマキタノクチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区中島堀端町', '26', '26109', '6128452', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '中島堀端町', 'ナカジマホリバタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区竹田泓ノ川町', '26', '26109', '6128454', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '竹田泓ノ川町', 'タケダフケノガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区中島外山町', '26', '26109', '6128455', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '中島外山町', 'ナカジマソトヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区中島中道町', '26', '26109', '6128456', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '中島中道町', 'ナカジマナカミチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区中島宮ノ前町', '26', '26109', '6128457', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '中島宮ノ前町', 'ナカジマミヤノマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区中島鳥羽離宮町', '26', '26109', '6128459', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '中島鳥羽離宮町', 'ナカジマトバリキュウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区中島流作町', '26', '26109', '6128461', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '中島流作町', 'ナカジマリュウサクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区中島秋ノ山町', '26', '26109', '6128462', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '中島秋ノ山町', 'ナカジマアキノヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区中島御所ノ内町', '26', '26109', '6128463', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '中島御所ノ内町', 'ナカジマゴショノウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区中島前山町', '26', '26109', '6128464', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '中島前山町', 'ナカジママエヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区中島樋ノ上町', '26', '26109', '6128465', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '中島樋ノ上町', 'ナカジマヒノカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区下鳥羽城ノ越町', '26', '26109', '6128466', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '下鳥羽城ノ越町', 'シモトバシロノコシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区下鳥羽前田町', '26', '26109', '6128467', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '下鳥羽前田町', 'シモトバマエダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区下鳥羽上向島町', '26', '26109', '6128468', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '下鳥羽上向島町', 'シモトバカミムカイジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区中島河原田町', '26', '26109', '6128469', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '中島河原田町', 'ナカジマカワラデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区下鳥羽長田町', '26', '26109', '6128471', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '下鳥羽長田町', 'シモトバオサダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区下鳥羽広長町', '26', '26109', '6128473', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '下鳥羽広長町', 'シモトバヒロオサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区下鳥羽北三町', '26', '26109', '6128476', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '下鳥羽北三町', 'シモトバキタサンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区下鳥羽中三町', '26', '26109', '6128477', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '下鳥羽中三町', 'シモトバナカサンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区下鳥羽南三町', '26', '26109', '6128478', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '下鳥羽南三町', 'シモトバミナミサンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区横大路東裏町', '26', '26109', '6128481', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '横大路東裏町', 'ヨコオオジヒガシウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区横大路中ノ庄町', '26', '26109', '6128482', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '横大路中ノ庄町', 'ヨコオオジナカノショウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区横大路草津町', '26', '26109', '6128483', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '横大路草津町', 'ヨコオオジクサツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区羽束師鴨川町', '26', '26109', '6128484', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '羽束師鴨川町', 'ハヅカシカモガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区羽束師志水町', '26', '26109', '6128485', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '羽束師志水町', 'ハヅカシシミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区羽束師古川町', '26', '26109', '6128486', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '羽束師古川町', 'ハヅカシフルカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区羽束師菱川町', '26', '26109', '6128487', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '羽束師菱川町', 'ハヅカシヒシカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区下鳥羽東柳長町', '26', '26109', '6128488', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '下鳥羽東柳長町', 'シモトバヒガシヤナギオサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区下鳥羽西柳長町', '26', '26109', '6128489', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '下鳥羽西柳長町', 'シモトバニシヤナギオサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区下鳥羽南柳長町', '26', '26109', '6128490', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '下鳥羽南柳長町', 'シモトバミナミヤナギオサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区久我石原町', '26', '26109', '6128491', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '久我石原町', 'コガイシハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区久我本町', '26', '26109', '6128492', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '久我本町', 'コガホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区久我御旅町', '26', '26109', '6128493', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '久我御旅町', 'コガオタビチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区久我東町', '26', '26109', '6128494', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '久我東町', 'コガアズマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区久我森の宮町', '26', '26109', '6128495', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '久我森の宮町', 'コガモリノミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区久我西出町', '26', '26109', '6128496', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '久我西出町', 'コガニシデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区下鳥羽北円面田町', '26', '26109', '6128497', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '下鳥羽北円面田町', 'シモトバキタエンメンデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区下鳥羽中円面田町', '26', '26109', '6128498', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '下鳥羽中円面田町', 'シモトバナカエンメンデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区下鳥羽南円面田町', '26', '26109', '6128499', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '下鳥羽南円面田町', 'シモトバミナミエンメンデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府久世郡久御山町', '26', '26322', '6130000', '京都府', 'キョウトフ', '久世郡久御山町', 'クセグンクミヤマチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('70322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府久世郡久御山町東一口', '26', '26322', '6130021', '京都府', 'キョウトフ', '久世郡久御山町', 'クセグンクミヤマチョウ', '東一口', 'ヒガシイモアライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府久世郡久御山町市田', '26', '26322', '6130022', '京都府', 'キョウトフ', '久世郡久御山町', 'クセグンクミヤマチョウ', '市田', 'イチダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府久世郡久御山町野村', '26', '26322', '6130023', '京都府', 'キョウトフ', '久世郡久御山町', 'クセグンクミヤマチョウ', '野村', 'ノムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府久世郡久御山町森', '26', '26322', '6130024', '京都府', 'キョウトフ', '久世郡久御山町', 'クセグンクミヤマチョウ', '森', 'モリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府久世郡久御山町相島', '26', '26322', '6130025', '京都府', 'キョウトフ', '久世郡久御山町', 'クセグンクミヤマチョウ', '相島', 'オジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府久世郡久御山町西一口', '26', '26322', '6130026', '京都府', 'キョウトフ', '久世郡久御山町', 'クセグンクミヤマチョウ', '西一口', 'ニシイモアライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府久世郡久御山町佐古', '26', '26322', '6130031', '京都府', 'キョウトフ', '久世郡久御山町', 'クセグンクミヤマチョウ', '佐古', 'サコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府久世郡久御山町栄', '26', '26322', '6130032', '京都府', 'キョウトフ', '久世郡久御山町', 'クセグンクミヤマチョウ', '栄', 'サカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府久世郡久御山町林', '26', '26322', '6130033', '京都府', 'キョウトフ', '久世郡久御山町', 'クセグンクミヤマチョウ', '林', 'ハヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府久世郡久御山町佐山', '26', '26322', '6130034', '京都府', 'キョウトフ', '久世郡久御山町', 'クセグンクミヤマチョウ', '佐山', 'サヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府久世郡久御山町下津屋', '26', '26322', '6130035', '京都府', 'キョウトフ', '久世郡久御山町', 'クセグンクミヤマチョウ', '下津屋', 'シモツヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府久世郡久御山町田井', '26', '26322', '6130036', '京都府', 'キョウトフ', '久世郡久御山町', 'クセグンクミヤマチョウ', '田井', 'タイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府久世郡久御山町中島', '26', '26322', '6130041', '京都府', 'キョウトフ', '久世郡久御山町', 'クセグンクミヤマチョウ', '中島', 'ナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府久世郡久御山町坊之池', '26', '26322', '6130042', '京都府', 'キョウトフ', '久世郡久御山町', 'クセグンクミヤマチョウ', '坊之池', 'ボウノイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府久世郡久御山町島田', '26', '26322', '6130043', '京都府', 'キョウトフ', '久世郡久御山町', 'クセグンクミヤマチョウ', '島田', 'シマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府久世郡久御山町藤和田', '26', '26322', '6130044', '京都府', 'キョウトフ', '久世郡久御山町', 'クセグンクミヤマチョウ', '藤和田', 'フジワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府久世郡久御山町北川顔', '26', '26322', '6130045', '京都府', 'キョウトフ', '久世郡久御山町', 'クセグンクミヤマチョウ', '北川顔', 'キタカワヅラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府久世郡久御山町大橋辺', '26', '26322', '6130046', '京都府', 'キョウトフ', '久世郡久御山町', 'クセグンクミヤマチョウ', '大橋辺', 'オオハシベリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市川口高原', '26', '26210', '6130851', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '川口高原', 'カワグチタカハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市八幡樋ノ口', '26', '26210', '6130852', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '八幡樋ノ口', 'ヤワタヒノクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市八幡長町', '26', '26210', '6130853', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '八幡長町', 'ヤワタナガマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区淀樋爪町', '26', '26109', '6130901', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '淀樋爪町', 'ヨドヒヅメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区淀水垂町', '26', '26109', '6130902', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '淀水垂町', 'ヨドミズタレチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区淀本町', '26', '26109', '6130903', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '淀本町', 'ヨドホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区淀池上町', '26', '26109', '6130904', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '淀池上町', 'ヨドイケガミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区淀下津町', '26', '26109', '6130905', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '淀下津町', 'ヨドシモヅチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区淀新町', '26', '26109', '6130906', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '淀新町', 'ヨドシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区淀大下津町', '26', '26109', '6130907', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '淀大下津町', 'ヨドオオシモヅチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区淀木津町', '26', '26109', '6130911', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '淀木津町', 'ヨドキヅチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区淀川顔町', '26', '26109', '6130912', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '淀川顔町', 'ヨドカワヅラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区向島下五反田', '26', '26109', '6130913', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '向島下五反田', 'ムカイジマシモゴタンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区淀生津町', '26', '26109', '6130914', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '淀生津町', 'ヨドナマヅチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区淀際目町', '26', '26109', '6130915', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '淀際目町', 'ヨドサイメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市伏見区淀美豆町', '26', '26109', '6130916', '京都府', 'キョウトフ', '京都市伏見区', 'キョウトシフシミク', '淀美豆町', 'ヨドミヅチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩市浜益区浜益', '01', '01235', '0613101', '北海道', 'ホッカイドウ', '石狩市', 'イシカリシ', '浜益区浜益', 'ハママスクハママス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩市浜益区群別', '01', '01235', '0613102', '北海道', 'ホッカイドウ', '石狩市', 'イシカリシ', '浜益区群別', 'ハママスクグンベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩市浜益区幌', '01', '01235', '0613103', '北海道', 'ホッカイドウ', '石狩市', 'イシカリシ', '浜益区幌', 'ハママスクホロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩市浜益区床丹', '01', '01235', '0613104', '北海道', 'ホッカイドウ', '石狩市', 'イシカリシ', '浜益区床丹', 'ハママスクトコタン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩市浜益区千代志別', '01', '01235', '0613105', '北海道', 'ホッカイドウ', '石狩市', 'イシカリシ', '浜益区千代志別', 'ハママスクチヨシベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩市浜益区川下', '01', '01235', '0613106', '北海道', 'ホッカイドウ', '石狩市', 'イシカリシ', '浜益区川下', 'ハママスクカワシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩市浜益区柏木', '01', '01235', '0613107', '北海道', 'ホッカイドウ', '石狩市', 'イシカリシ', '浜益区柏木', 'ハママスクカシワギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩市浜益区実田', '01', '01235', '0613108', '北海道', 'ホッカイドウ', '石狩市', 'イシカリシ', '浜益区実田', 'ハママスクミタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩市浜益区御料地', '01', '01235', '0613109', '北海道', 'ホッカイドウ', '石狩市', 'イシカリシ', '浜益区御料地', 'ハママスクゴリョウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩市浜益区毘砂別', '01', '01235', '0613111', '北海道', 'ホッカイドウ', '石狩市', 'イシカリシ', '浜益区毘砂別', 'ハママスクビシャベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩市浜益区送毛', '01', '01235', '0613112', '北海道', 'ホッカイドウ', '石狩市', 'イシカリシ', '浜益区送毛', 'ハママスクオクリゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩市浜益区濃昼', '01', '01235', '0613113', '北海道', 'ホッカイドウ', '石狩市', 'イシカリシ', '浜益区濃昼', 'ハママスクゴキビル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩市厚田区濃昼', '01', '01235', '0613151', '北海道', 'ホッカイドウ', '石狩市', 'イシカリシ', '厚田区濃昼', 'アツタクゴキビル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩市', '01', '01235', '0613200', '北海道', 'ホッカイドウ', '石狩市', 'イシカリシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('70371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩市花川南1条', '01', '01235', '0613201', '北海道', 'ホッカイドウ', '石狩市', 'イシカリシ', '花川南1条', 'ハナカワミナミ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩市花川南2条', '01', '01235', '0613202', '北海道', 'ホッカイドウ', '石狩市', 'イシカリシ', '花川南2条', 'ハナカワミナミ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩市花川南3条', '01', '01235', '0613203', '北海道', 'ホッカイドウ', '石狩市', 'イシカリシ', '花川南3条', 'ハナカワミナミ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩市花川南4条', '01', '01235', '0613204', '北海道', 'ホッカイドウ', '石狩市', 'イシカリシ', '花川南4条', 'ハナカワミナミ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩市花川南5条', '01', '01235', '0613205', '北海道', 'ホッカイドウ', '石狩市', 'イシカリシ', '花川南5条', 'ハナカワミナミ05ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩市花川南6条', '01', '01235', '0613206', '北海道', 'ホッカイドウ', '石狩市', 'イシカリシ', '花川南6条', 'ハナカワミナミ06ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩市花川南7条', '01', '01235', '0613207', '北海道', 'ホッカイドウ', '石狩市', 'イシカリシ', '花川南7条', 'ハナカワミナミ07ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩市花川南8条', '01', '01235', '0613208', '北海道', 'ホッカイドウ', '石狩市', 'イシカリシ', '花川南8条', 'ハナカワミナミ08ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩市花川南9条', '01', '01235', '0613209', '北海道', 'ホッカイドウ', '石狩市', 'イシカリシ', '花川南9条', 'ハナカワミナミ09ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩市花川南10条', '01', '01235', '0613210', '北海道', 'ホッカイドウ', '石狩市', 'イシカリシ', '花川南10条', 'ハナカワミナミ10ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩市花川北1条', '01', '01235', '0613211', '北海道', 'ホッカイドウ', '石狩市', 'イシカリシ', '花川北1条', 'ハナカワキタ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩市花川北2条', '01', '01235', '0613212', '北海道', 'ホッカイドウ', '石狩市', 'イシカリシ', '花川北2条', 'ハナカワキタ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩市花川北3条', '01', '01235', '0613213', '北海道', 'ホッカイドウ', '石狩市', 'イシカリシ', '花川北3条', 'ハナカワキタ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩市花川北4条', '01', '01235', '0613214', '北海道', 'ホッカイドウ', '石狩市', 'イシカリシ', '花川北4条', 'ハナカワキタ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩市花川北5条', '01', '01235', '0613215', '北海道', 'ホッカイドウ', '石狩市', 'イシカリシ', '花川北5条', 'ハナカワキタ05ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩市花川北6条', '01', '01235', '0613216', '北海道', 'ホッカイドウ', '石狩市', 'イシカリシ', '花川北6条', 'ハナカワキタ06ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩市花川北7条', '01', '01235', '0613217', '北海道', 'ホッカイドウ', '石狩市', 'イシカリシ', '花川北7条', 'ハナカワキタ07ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩市花畔', '01', '01235', '0613218', '北海道', 'ホッカイドウ', '石狩市', 'イシカリシ', '花畔', 'バンナグロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩市花川', '01', '01235', '0613219', '北海道', 'ホッカイドウ', '石狩市', 'イシカリシ', '花川', 'ハナカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩市志美', '01', '01235', '0613220', '北海道', 'ホッカイドウ', '石狩市', 'イシカリシ', '志美', 'シビ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩市緑苑台東1条', '01', '01235', '0613221', '北海道', 'ホッカイドウ', '石狩市', 'イシカリシ', '緑苑台東1条', 'リョクエンダイヒガシ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩市緑苑台東2条', '01', '01235', '0613222', '北海道', 'ホッカイドウ', '石狩市', 'イシカリシ', '緑苑台東2条', 'リョクエンダイヒガシ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩市緑苑台東3条', '01', '01235', '0613223', '北海道', 'ホッカイドウ', '石狩市', 'イシカリシ', '緑苑台東3条', 'リョクエンダイヒガシ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩市緑苑台中央', '01', '01235', '0613230', '北海道', 'ホッカイドウ', '石狩市', 'イシカリシ', '緑苑台中央', 'リョクエンダイチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩市緑苑台西1条', '01', '01235', '0613231', '北海道', 'ホッカイドウ', '石狩市', 'イシカリシ', '緑苑台西1条', 'リョクエンダイニシ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩市緑苑台西2条', '01', '01235', '0613232', '北海道', 'ホッカイドウ', '石狩市', 'イシカリシ', '緑苑台西2条', 'リョクエンダイニシ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩市新港西', '01', '01235', '0613241', '北海道', 'ホッカイドウ', '石狩市', 'イシカリシ', '新港西', 'シンコウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩市新港中央', '01', '01235', '0613242', '北海道', 'ホッカイドウ', '石狩市', 'イシカリシ', '新港中央', 'シンコウチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩市新港東', '01', '01235', '0613243', '北海道', 'ホッカイドウ', '石狩市', 'イシカリシ', '新港東', 'シンコウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩市新港南', '01', '01235', '0613244', '北海道', 'ホッカイドウ', '石狩市', 'イシカリシ', '新港南', 'シンコウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩市生振', '01', '01235', '0613245', '北海道', 'ホッカイドウ', '石狩市', 'イシカリシ', '生振', 'オヤフル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩市花川東', '01', '01235', '0613248', '北海道', 'ホッカイドウ', '石狩市', 'イシカリシ', '花川東', 'ハナカワヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩市樽川', '01', '01235', '0613251', '北海道', 'ホッカイドウ', '石狩市', 'イシカリシ', '樽川', 'タルカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩市樽川3条', '01', '01235', '0613253', '北海道', 'ホッカイドウ', '石狩市', 'イシカリシ', '樽川3条', 'タルカワ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩市樽川4条', '01', '01235', '0613254', '北海道', 'ホッカイドウ', '石狩市', 'イシカリシ', '樽川4条', 'タルカワ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩市樽川5条', '01', '01235', '0613255', '北海道', 'ホッカイドウ', '石狩市', 'イシカリシ', '樽川5条', 'タルカワ05ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩市樽川6条', '01', '01235', '0613256', '北海道', 'ホッカイドウ', '石狩市', 'イシカリシ', '樽川6条', 'タルカワ06ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩市樽川7条', '01', '01235', '0613257', '北海道', 'ホッカイドウ', '石狩市', 'イシカリシ', '樽川7条', 'タルカワ07ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩市樽川8条', '01', '01235', '0613258', '北海道', 'ホッカイドウ', '石狩市', 'イシカリシ', '樽川8条', 'タルカワ08ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩市樽川9条', '01', '01235', '0613259', '北海道', 'ホッカイドウ', '石狩市', 'イシカリシ', '樽川9条', 'タルカワ09ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩市花川東1条', '01', '01235', '0613261', '北海道', 'ホッカイドウ', '石狩市', 'イシカリシ', '花川東1条', 'ハナカワヒガシ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩市花川東2条', '01', '01235', '0613262', '北海道', 'ホッカイドウ', '石狩市', 'イシカリシ', '花川東2条', 'ハナカワヒガシ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道小樽市銭函4丁目', '01', '01203', '0613271', '北海道', 'ホッカイドウ', '小樽市', 'オタルシ', '銭函', 'ゼニバコ', null, null, '4丁目', '04チョウメ');
INSERT INTO `ms_addresses` VALUES ('70414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道小樽市銭函5丁目', '01', '01203', '0613271', '北海道', 'ホッカイドウ', '小樽市', 'オタルシ', '銭函', 'ゼニバコ', null, null, '5丁目', '05チョウメ');
INSERT INTO `ms_addresses` VALUES ('70415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩市花畔1条', '01', '01235', '0613281', '北海道', 'ホッカイドウ', '石狩市', 'イシカリシ', '花畔1条', 'バンナグロ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩市花畔2条', '01', '01235', '0613282', '北海道', 'ホッカイドウ', '石狩市', 'イシカリシ', '花畔2条', 'バンナグロ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩市花畔3条', '01', '01235', '0613283', '北海道', 'ホッカイドウ', '石狩市', 'イシカリシ', '花畔3条', 'バンナグロ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩市花畔4条', '01', '01235', '0613284', '北海道', 'ホッカイドウ', '石狩市', 'イシカリシ', '花畔4条', 'バンナグロ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩市厚田区聚富シラツカリ', '01', '01235', '0613331', '北海道', 'ホッカイドウ', '石狩市', 'イシカリシ', '厚田区聚富', 'アツタクシュップ', null, null, 'シラツカリ', 'シラツカリ');
INSERT INTO `ms_addresses` VALUES ('70425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩市厚田区聚富中央', '01', '01235', '0613331', '北海道', 'ホッカイドウ', '石狩市', 'イシカリシ', '厚田区聚富', 'アツタクシュップ', null, null, '中央', 'チュウオウ');
INSERT INTO `ms_addresses` VALUES ('70426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩市厚田区虹が原', '01', '01235', '0613332', '北海道', 'ホッカイドウ', '石狩市', 'イシカリシ', '厚田区虹が原', 'アツタクニジガハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩市八幡', '01', '01235', '0613361', '北海道', 'ホッカイドウ', '石狩市', 'イシカリシ', '八幡', 'ハチマン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩市北生振', '01', '01235', '0613362', '北海道', 'ホッカイドウ', '石狩市', 'イシカリシ', '北生振', 'キタオヤフル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩市若生町', '01', '01235', '0613363', '北海道', 'ホッカイドウ', '石狩市', 'イシカリシ', '若生町', 'ワカオイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩市親船東1条', '01', '01235', '0613365', '北海道', 'ホッカイドウ', '石狩市', 'イシカリシ', '親船東1条', 'オヤフネヒガシ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩市親船東2条', '01', '01235', '0613366', '北海道', 'ホッカイドウ', '石狩市', 'イシカリシ', '親船東2条', 'オヤフネヒガシ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩市親船東3条', '01', '01235', '0613367', '北海道', 'ホッカイドウ', '石狩市', 'イシカリシ', '親船東3条', 'オヤフネヒガシ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩市美登位', '01', '01235', '0613368', '北海道', 'ホッカイドウ', '石狩市', 'イシカリシ', '美登位', 'ビトイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩市浜町', '01', '01235', '0613371', '北海道', 'ホッカイドウ', '石狩市', 'イシカリシ', '浜町', 'ハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩市弁天町', '01', '01235', '0613372', '北海道', 'ホッカイドウ', '石狩市', 'イシカリシ', '弁天町', 'ベンテンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩市新町', '01', '01235', '0613373', '北海道', 'ホッカイドウ', '石狩市', 'イシカリシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩市仲町', '01', '01235', '0613374', '北海道', 'ホッカイドウ', '石狩市', 'イシカリシ', '仲町', 'ナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩市本町', '01', '01235', '0613375', '北海道', 'ホッカイドウ', '石狩市', 'イシカリシ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩市横町', '01', '01235', '0613376', '北海道', 'ホッカイドウ', '石狩市', 'イシカリシ', '横町', 'ヨコマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩市親船町', '01', '01235', '0613377', '北海道', 'ホッカイドウ', '石狩市', 'イシカリシ', '親船町', 'オヤフネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩市船場町', '01', '01235', '0613378', '北海道', 'ホッカイドウ', '石狩市', 'イシカリシ', '船場町', 'フナバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩市厚田区聚富', '01', '01235', '0613441', '北海道', 'ホッカイドウ', '石狩市', 'イシカリシ', '厚田区聚富', 'アツタクシュップ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩市八幡町五の沢', '01', '01235', '0613480', '北海道', 'ホッカイドウ', '石狩市', 'イシカリシ', '八幡町', 'ハチマンチョウ', null, null, '五の沢', 'ゴノサワ');
INSERT INTO `ms_addresses` VALUES ('70444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩市八幡町高岡', '01', '01235', '0613481', '北海道', 'ホッカイドウ', '石狩市', 'イシカリシ', '八幡町', 'ハチマンチョウ', null, null, '高岡', 'タカオカ');
INSERT INTO `ms_addresses` VALUES ('70445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩市八幡町', '01', '01235', '0613482', '北海道', 'ホッカイドウ', '石狩市', 'イシカリシ', '八幡町', 'ハチマンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩市緑ケ原', '01', '01235', '0613483', '北海道', 'ホッカイドウ', '石狩市', 'イシカリシ', '緑ケ原', 'ミドリガハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩市八幡', '01', '01235', '0613484', '北海道', 'ホッカイドウ', '石狩市', 'イシカリシ', '八幡', 'ハチマン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩市厚田区古潭', '01', '01235', '0613521', '北海道', 'ホッカイドウ', '石狩市', 'イシカリシ', '厚田区古潭', 'アツタクコタン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩市厚田区嶺泊', '01', '01235', '0613522', '北海道', 'ホッカイドウ', '石狩市', 'イシカリシ', '厚田区嶺泊', 'アツタクミネトマリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩市厚田区望来', '01', '01235', '0613523', '北海道', 'ホッカイドウ', '石狩市', 'イシカリシ', '厚田区望来', 'アツタクモウライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩市厚田区厚田', '01', '01235', '0613601', '北海道', 'ホッカイドウ', '石狩市', 'イシカリシ', '厚田区厚田', 'アツタクアツタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩市厚田区押琴', '01', '01235', '0613602', '北海道', 'ホッカイドウ', '石狩市', 'イシカリシ', '厚田区押琴', 'アツタクオシコト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩市厚田区小谷', '01', '01235', '0613603', '北海道', 'ホッカイドウ', '石狩市', 'イシカリシ', '厚田区小谷', 'アツタクコタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩市厚田区別狩', '01', '01235', '0613605', '北海道', 'ホッカイドウ', '石狩市', 'イシカリシ', '厚田区別狩', 'アツタクベツカリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩市厚田区安瀬', '01', '01235', '0613606', '北海道', 'ホッカイドウ', '石狩市', 'イシカリシ', '厚田区安瀬', 'アツタクヤスセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩郡当別町高岡', '01', '01303', '0613771', '北海道', 'ホッカイドウ', '石狩郡当別町', 'イシカリグントウベツチョウ', '高岡', 'タカオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩郡当別町獅子内', '01', '01303', '0613772', '北海道', 'ホッカイドウ', '石狩郡当別町', 'イシカリグントウベツチョウ', '獅子内', 'シシナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩郡当別町当別太', '01', '01303', '0613773', '北海道', 'ホッカイドウ', '石狩郡当別町', 'イシカリグントウベツチョウ', '当別太', 'トウベツブト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩郡当別町川下', '01', '01303', '0613774', '北海道', 'ホッカイドウ', '石狩郡当別町', 'イシカリグントウベツチョウ', '川下', 'カワシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩郡当別町ビトエ', '01', '01303', '0613775', '北海道', 'ホッカイドウ', '石狩郡当別町', 'イシカリグントウベツチョウ', 'ビトエ', 'ビトエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩郡当別町太美町', '01', '01303', '0613776', '北海道', 'ホッカイドウ', '石狩郡当別町', 'イシカリグントウベツチョウ', '太美町', 'フトミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩郡当別町スウェーデンヒルズ', '01', '01303', '0613777', '北海道', 'ホッカイドウ', '石狩郡当別町', 'イシカリグントウベツチョウ', 'スウェーデンヒルズ', 'スウェーデンヒルズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩郡当別町太美南', '01', '01303', '0613778', '北海道', 'ホッカイドウ', '石狩郡当別町', 'イシカリグントウベツチョウ', '太美南', 'フトミミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩郡当別町太美スターライト', '01', '01303', '0613779', '北海道', 'ホッカイドウ', '石狩郡当別町', 'イシカリグントウベツチョウ', '太美スターライト', 'フトミスターライト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市', '26', '26210', '6140000', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('70468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市八幡科手', '26', '26210', '6148001', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '八幡科手', 'ヤワタシナデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市八幡土井', '26', '26210', '6148002', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '八幡土井', 'ヤワタドイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市八幡千束', '26', '26210', '6148003', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '八幡千束', 'ヤワタセンゾク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市八幡山柴', '26', '26210', '6148004', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '八幡山柴', 'ヤワタヤマシバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市八幡高坊', '26', '26210', '6148005', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '八幡高坊', 'ヤワタタカボウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市八幡大谷', '26', '26210', '6148006', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '八幡大谷', 'ヤワタオオタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市八幡西高坊', '26', '26210', '6148007', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '八幡西高坊', 'ヤワタニシタカボウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市八幡平ノ山', '26', '26210', '6148008', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '八幡平ノ山', 'ヤワタヒラノヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市八幡垣内山', '26', '26210', '6148011', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '八幡垣内山', 'ヤワタカイトヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市八幡吉野', '26', '26210', '6148012', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '八幡吉野', 'ヤワタヨシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市八幡吉野垣内', '26', '26210', '6148013', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '八幡吉野垣内', 'ヤワタヨシノガイト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市八幡北浦', '26', '26210', '6148014', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '八幡北浦', 'ヤワタキタウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市八幡旦所', '26', '26210', '6148015', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '八幡旦所', 'ヤワタダンジョ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市八幡山路', '26', '26210', '6148016', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '八幡山路', 'ヤワタヤマジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市八幡柴座', '26', '26210', '6148017', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '八幡柴座', 'ヤワタシバザ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市八幡森垣内', '26', '26210', '6148021', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '八幡森垣内', 'ヤワタモリガイト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市八幡東浦', '26', '26210', '6148022', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '八幡東浦', 'ヤワタヒガシウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市八幡名残', '26', '26210', '6148023', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '八幡名残', 'ヤワタナゴリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市八幡双栗', '26', '26210', '6148024', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '八幡双栗', 'ヤワタソグリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市八幡源氏垣外', '26', '26210', '6148025', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '八幡源氏垣外', 'ヤワタゲンジガイト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市八幡森', '26', '26210', '6148026', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '八幡森', 'ヤワタモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市八幡東島', '26', '26210', '6148030', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '八幡東島', 'ヤワタヒガシジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市八幡小西', '26', '26210', '6148031', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '八幡小西', 'ヤワタコニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市八幡番賀', '26', '26210', '6148032', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '八幡番賀', 'ヤワタバンガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市八幡西島', '26', '26210', '6148033', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '八幡西島', 'ヤワタニシジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市八幡舞台', '26', '26210', '6148034', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '八幡舞台', 'ヤワタブタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市八幡小松', '26', '26210', '6148035', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '八幡小松', 'ヤワタコマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市八幡柿木垣内', '26', '26210', '6148036', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '八幡柿木垣内', 'ヤワタカキノキガイト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市八幡高畑', '26', '26210', '6148037', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '八幡高畑', 'ヤワタタカバタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市八幡園内', '26', '26210', '6148038', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '八幡園内', 'ヤワタソノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市八幡苗田', '26', '26210', '6148039', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '八幡苗田', 'ヤワタナエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市八幡吉原', '26', '26210', '6148041', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '八幡吉原', 'ヤワタヨシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市八幡盛戸', '26', '26210', '6148042', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '八幡盛戸', 'ヤワタサカンド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市八幡一ノ坪', '26', '26210', '6148043', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '八幡一ノ坪', 'ヤワタイチノツボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市八幡御幸谷', '26', '26210', '6148044', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '八幡御幸谷', 'ヤワタゴコウダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市八幡久保田', '26', '26210', '6148045', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '八幡久保田', 'ヤワタクボタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市八幡砂田', '26', '26210', '6148046', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '八幡砂田', 'ヤワタサデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市八幡月夜田', '26', '26210', '6148047', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '八幡月夜田', 'ヤワタツキヨダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市八幡備前', '26', '26210', '6148048', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '八幡備前', 'ヤワタビゼン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市八幡山田', '26', '26210', '6148051', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '八幡山田', 'ヤワタヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市八幡武蔵芝', '26', '26210', '6148052', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '八幡武蔵芝', 'ヤワタムサシシバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市八幡水珀', '26', '26210', '6148053', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '八幡水珀', 'ヤワタスイハク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市八幡南山', '26', '26210', '6148054', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '八幡南山', 'ヤワタミナミヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市八幡柿ケ谷', '26', '26210', '6148055', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '八幡柿ケ谷', 'ヤワタカキガダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市八幡福禄谷', '26', '26210', '6148056', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '八幡福禄谷', 'ヤワタフクロクダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市八幡安居塚', '26', '26210', '6148057', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '八幡安居塚', 'ヤワタアンゴヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市八幡長谷', '26', '26210', '6148058', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '八幡長谷', 'ヤワタナガタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市八幡式部谷', '26', '26210', '6148061', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '八幡式部谷', 'ヤワタシキブダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市八幡清水井', '26', '26210', '6148062', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '八幡清水井', 'ヤワタシミズイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市八幡岸本', '26', '26210', '6148063', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '八幡岸本', 'ヤワタキシモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市八幡松原', '26', '26210', '6148064', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '八幡松原', 'ヤワタマツバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市八幡山下', '26', '26210', '6148065', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '八幡山下', 'ヤワタヤマシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市八幡大芝', '26', '26210', '6148066', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '八幡大芝', 'ヤワタオオシバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市八幡中ノ山', '26', '26210', '6148067', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '八幡中ノ山', 'ヤワタナカノヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市八幡隅田口', '26', '26210', '6148068', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '八幡隅田口', 'ヤワタスミダグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市八幡五反田', '26', '26210', '6148071', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '八幡五反田', 'ヤワタゴタンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市八幡長田', '26', '26210', '6148072', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '八幡長田', 'ヤワタオサダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市八幡軸', '26', '26210', '6148073', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '八幡軸', 'ヤワタジク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市八幡渡ル瀬', '26', '26210', '6148074', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '八幡渡ル瀬', 'ヤワタワタルセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市八幡三反長', '26', '26210', '6148075', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '八幡三反長', 'ヤワタサンダオサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市八幡植松', '26', '26210', '6148076', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '八幡植松', 'ヤワタウエマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市八幡女郎花', '26', '26210', '6148077', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '八幡女郎花', 'ヤワタオミナエシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市八幡広門', '26', '26210', '6148078', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '八幡広門', 'ヤワタヒロカド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市八幡東林', '26', '26210', '6148079', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '八幡東林', 'ヤワタトウリン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市八幡御馬所', '26', '26210', '6148081', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '八幡御馬所', 'ヤワタゴバショ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市八幡菖蒲池', '26', '26210', '6148082', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '八幡菖蒲池', 'ヤワタショウブイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市八幡山本', '26', '26210', '6148083', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '八幡山本', 'ヤワタヤマモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市八幡今田', '26', '26210', '6148084', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '八幡今田', 'ヤワタイマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市八幡馬場', '26', '26210', '6148085', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '八幡馬場', 'ヤワタババ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市八幡河原崎', '26', '26210', '6148086', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '八幡河原崎', 'ヤワタカワラザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市八幡神原', '26', '26210', '6148087', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '八幡神原', 'ヤワタカミハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市八幡石不動', '26', '26210', '6148088', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '八幡石不動', 'ヤワタイシフドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市八幡平谷', '26', '26210', '6148091', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '八幡平谷', 'ヤワタビョウダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市八幡城ノ内', '26', '26210', '6148092', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '八幡城ノ内', 'ヤワタジョウノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市八幡三本橋', '26', '26210', '6148093', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '八幡三本橋', 'ヤワタサンボンバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市八幡平田', '26', '26210', '6148094', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '八幡平田', 'ヤワタヒラタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市八幡沓田', '26', '26210', '6148095', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '八幡沓田', 'ヤワタクツデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市八幡三ノ甲', '26', '26210', '6148096', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '八幡三ノ甲', 'ヤワタサンノコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市川口浜', '26', '26210', '6148101', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '川口浜', 'カワグチハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市川口北浦', '26', '26210', '6148102', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '川口北浦', 'カワグチキタウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市川口堀ノ内', '26', '26210', '6148103', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '川口堀ノ内', 'カワグチホリノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市川口東頭', '26', '26210', '6148104', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '川口東頭', 'カワグチヒガシガシラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市川口擬宝珠', '26', '26210', '6148105', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '川口擬宝珠', 'カワグチギボシュ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市川口天神崎', '26', '26210', '6148106', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '川口天神崎', 'カワグチテンジンザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市川口小西', '26', '26210', '6148111', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '川口小西', 'カワグチコニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市川口馬屋尻', '26', '26210', '6148112', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '川口馬屋尻', 'カワグチウマヤジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市川口萩原', '26', '26210', '6148113', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '川口萩原', 'カワグチハギハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市川口別所', '26', '26210', '6148114', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '川口別所', 'カワグチベッシヨ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市川口扇ノ芝', '26', '26210', '6148115', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '川口扇ノ芝', 'カワグチオウギノシバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市川口東扇', '26', '26210', '6148116', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '川口東扇', 'カワグチヒガシオウギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市川口西扇', '26', '26210', '6148117', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '川口西扇', 'カワグチニシオウギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市下奈良小宮', '26', '26210', '6148121', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '下奈良小宮', 'シモナラコミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市下奈良一丁堤', '26', '26210', '6148122', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '下奈良一丁堤', 'シモナライッチョウヅツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市下奈良名越', '26', '26210', '6148123', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '下奈良名越', 'シモナラナゴシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市下奈良奥垣内', '26', '26210', '6148124', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '下奈良奥垣内', 'シモナラオクガイト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市下奈良出垣内', '26', '26210', '6148125', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '下奈良出垣内', 'シモナラデガイト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市下奈良下三床', '26', '26210', '6148126', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '下奈良下三床', 'シモナラシモサンドコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市下奈良隅田', '26', '26210', '6148127', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '下奈良隅田', 'シモナラスミダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市下奈良野神', '26', '26210', '6148128', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '下奈良野神', 'シモナラノガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市下奈良宮ノ道', '26', '26210', '6148131', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '下奈良宮ノ道', 'シモナラミヤノミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市下奈良榊', '26', '26210', '6148132', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '下奈良榊', 'シモナラサカキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市下奈良新下', '26', '26210', '6148133', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '下奈良新下', 'シモナラシンゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市下奈良中ノ坪', '26', '26210', '6148134', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '下奈良中ノ坪', 'シモナラナカノツボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市下奈良蜻蛉尻筋', '26', '26210', '6148135', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '下奈良蜻蛉尻筋', 'シモナラトンボジリスジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市下奈良蜻蛉尻', '26', '26210', '6148136', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '下奈良蜻蛉尻', 'シモナラトンボジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市下奈良上三床', '26', '26210', '6148141', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '下奈良上三床', 'シモナラカミサンドコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市下奈良南頭', '26', '26210', '6148142', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '下奈良南頭', 'シモナラミナミガシラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市下奈良一丁地', '26', '26210', '6148143', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '下奈良一丁地', 'シモナライッチョウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市下奈良奈良元', '26', '26210', '6148144', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '下奈良奈良元', 'シモナラナラモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市下奈良二階堂', '26', '26210', '6148145', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '下奈良二階堂', 'シモナラニカイドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市下奈良上ノ段', '26', '26210', '6148146', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '下奈良上ノ段', 'シモナラカミノダン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市下奈良今里', '26', '26210', '6148147', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '下奈良今里', 'シモナライマザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市下奈良井関', '26', '26210', '6148148', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '下奈良井関', 'シモナライゼキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市下奈良竹垣内', '26', '26210', '6148149', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '下奈良竹垣内', 'シモナラタケガイト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市上奈良小端', '26', '26210', '6148151', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '上奈良小端', 'カミナラオバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市上奈良御園', '26', '26210', '6148152', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '上奈良御園', 'カミナラミソノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市上奈良サグリ前', '26', '26210', '6148153', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '上奈良サグリ前', 'カミナラサグリマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市上奈良宮ノ西', '26', '26210', '6148154', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '上奈良宮ノ西', 'カミナラミヤノニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市上奈良城垣内', '26', '26210', '6148155', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '上奈良城垣内', 'カミナラシロガイト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市上奈良奈良里', '26', '26210', '6148156', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '上奈良奈良里', 'カミナラナラザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市上奈良東ノ口', '26', '26210', '6148157', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '上奈良東ノ口', 'カミナラヒガシノクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市上奈良北ノ口', '26', '26210', '6148158', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '上奈良北ノ口', 'カミナラキタノクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市上奈良大門', '26', '26210', '6148159', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '上奈良大門', 'カミナラダイモン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市上奈良宮ノ東', '26', '26210', '6148161', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '上奈良宮ノ東', 'カミナラミヤノヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市上奈良日ノ尾', '26', '26210', '6148162', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '上奈良日ノ尾', 'カミナラヒノオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市上奈良長池', '26', '26210', '6148163', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '上奈良長池', 'カミナラナガイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市上奈良南ノ口', '26', '26210', '6148164', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '上奈良南ノ口', 'カミナラミナミノクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市上奈良池ノ向', '26', '26210', '6148165', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '上奈良池ノ向', 'カミナライケノムコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市上奈良堂島', '26', '26210', '6148166', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '上奈良堂島', 'カミナラドウジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市上津屋尼ケ池', '26', '26210', '6148171', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '上津屋尼ケ池', 'コウヅヤアマガイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市上津屋林', '26', '26210', '6148172', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '上津屋林', 'コウヅヤハヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市上津屋里垣内', '26', '26210', '6148173', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '上津屋里垣内', 'コウヅヤサトガイト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市上津屋八王子', '26', '26210', '6148174', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '上津屋八王子', 'コウヅヤハチオウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市上津屋石ノ塔', '26', '26210', '6148175', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '上津屋石ノ塔', 'コウヅヤイシノトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市上津屋中堤', '26', '26210', '6148176', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '上津屋中堤', 'コウヅヤナカヅツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市上津屋浜垣内', '26', '26210', '6148181', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '上津屋浜垣内', 'コウヅヤハマガイト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市上津屋南村', '26', '26210', '6148182', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '上津屋南村', 'コウヅヤミナミムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市上津屋西久保', '26', '26210', '6148183', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '上津屋西久保', 'コウヅヤニシクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市上津屋八丁', '26', '26210', '6148184', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '上津屋八丁', 'コウヅヤハッチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市野尻北ノ口', '26', '26210', '6148191', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '野尻北ノ口', 'ノジリキタノクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市野尻土井ノ内', '26', '26210', '6148192', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '野尻土井ノ内', 'ノジリドイノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市野尻一庵', '26', '26210', '6148193', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '野尻一庵', 'ノジリイチアン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市野尻円ノ元', '26', '26210', '6148194', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '野尻円ノ元', 'ノジリエンノモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市野尻城究', '26', '26210', '6148195', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '野尻城究', 'ノジリジョウギワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市野尻正畑', '26', '26210', '6148196', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '野尻正畑', 'ノジリショウハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市野尻倉掛', '26', '26210', '6148197', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '野尻倉掛', 'ノジリクラカケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市戸津南小路', '26', '26210', '6148201', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '戸津南小路', 'トウヅミナミショウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市戸津東ノ口', '26', '26210', '6148202', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '戸津東ノ口', 'トウヅヒガシノクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市戸津中垣内', '26', '26210', '6148203', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '戸津中垣内', 'トウヅナカガイト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市戸津蜻蛉尻', '26', '26210', '6148204', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '戸津蜻蛉尻', 'トウヅトンボジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市戸津東代', '26', '26210', '6148205', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '戸津東代', 'トウヅヒガシダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市戸津正ノ竹', '26', '26210', '6148206', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '戸津正ノ竹', 'トウヅショウノタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市戸津北小路', '26', '26210', '6148207', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '戸津北小路', 'トウヅキタショウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市戸津荒堀', '26', '26210', '6148208', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '戸津荒堀', 'トウヅアラホリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市戸津小中代', '26', '26210', '6148211', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '戸津小中代', 'トウヅコナカダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市戸津中代', '26', '26210', '6148212', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '戸津中代', 'トウヅナカダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市戸津南代', '26', '26210', '6148213', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '戸津南代', 'トウヅミナミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市戸津水戸城', '26', '26210', '6148214', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '戸津水戸城', 'トウヅミトシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市戸津堂田', '26', '26210', '6148215', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '戸津堂田', 'トウヅドウデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市戸津谷ノ口', '26', '26210', '6148216', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '戸津谷ノ口', 'トウヅタニノクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市内里蜻蛉尻', '26', '26210', '6148221', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '内里蜻蛉尻', 'ウチザトトンボジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市内里極楽橋', '26', '26210', '6148222', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '内里極楽橋', 'ウチザトゴクラクバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市内里北ノ山', '26', '26210', '6148223', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '内里北ノ山', 'ウチザトキタノヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市内里別所', '26', '26210', '6148224', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '内里別所', 'ウチザトベッシヨ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市内里砂田', '26', '26210', '6148225', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '内里砂田', 'ウチザトスナダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市内里東ノ口', '26', '26210', '6148226', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '内里東ノ口', 'ウチザトヒガシノクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市内里内', '26', '26210', '6148227', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '内里内', 'ウチザトウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市内里菅井', '26', '26210', '6148228', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '内里菅井', 'ウチザトスガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市内里北ノ口', '26', '26210', '6148229', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '内里北ノ口', 'ウチザトキタノクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市内里平尾', '26', '26210', '6148230', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '内里平尾', 'ウチザトヒラオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市内里安居芝', '26', '26210', '6148231', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '内里安居芝', 'ウチザトアンゴシバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市内里荒場', '26', '26210', '6148232', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '内里荒場', 'ウチザトアレバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市内里河原', '26', '26210', '6148233', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '内里河原', 'ウチザトカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市内里女谷', '26', '26210', '6148234', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '内里女谷', 'ウチザトオンナダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市内里穴ケ谷', '26', '26210', '6148235', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '内里穴ケ谷', 'ウチザトアナガダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市内里柿谷', '26', '26210', '6148236', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '内里柿谷', 'ウチザトカキダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市内里西山川', '26', '26210', '6148237', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '内里西山川', 'ウチザトニシヤマカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市内里砂畠', '26', '26210', '6148238', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '内里砂畠', 'ウチザトスナハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市内里大谷', '26', '26210', '6148239', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '内里大谷', 'ウチザトオオタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市内里宮ノ前', '26', '26210', '6148241', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '内里宮ノ前', 'ウチザトミヤノマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市内里巽ノ口', '26', '26210', '6148242', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '内里巽ノ口', 'ウチザトタツミノクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市内里松ケ外', '26', '26210', '6148243', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '内里松ケ外', 'ウチザトマツガソト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市内里東山川', '26', '26210', '6148244', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '内里東山川', 'ウチザトヒガシヤマカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市内里古溜池', '26', '26210', '6148245', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '内里古溜池', 'ウチザトフルタメイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市内里南ノ口', '26', '26210', '6148246', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '内里南ノ口', 'ウチザトミナミノクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市内里日向堂', '26', '26210', '6148247', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '内里日向堂', 'ウチザトヒュウガドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市内里中島', '26', '26210', '6148248', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '内里中島', 'ウチザトナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市岩田茶屋ノ前', '26', '26210', '6148251', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '岩田茶屋ノ前', 'イワタチャヤノマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市岩田大将軍', '26', '26210', '6148252', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '岩田大将軍', 'イワタダイショウグン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市岩田西玉造', '26', '26210', '6148253', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '岩田西玉造', 'イワタニシタマツクリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市岩田北ノ口', '26', '26210', '6148254', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '岩田北ノ口', 'イワタキタノクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市岩田竹綱', '26', '26210', '6148255', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '岩田竹綱', 'イワタタケヅナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市岩田岩ノ前', '26', '26210', '6148256', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '岩田岩ノ前', 'イワタイワノマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市岩田橋溝', '26', '26210', '6148257', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '岩田橋溝', 'イワタハシミゾ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市岩田加賀ノ辻', '26', '26210', '6148258', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '岩田加賀ノ辻', 'イワタカガノツジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市岩田辻垣内', '26', '26210', '6148261', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '岩田辻垣内', 'イワタツジガイト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市岩田松原', '26', '26210', '6148262', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '岩田松原', 'イワタマツバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市岩田六ノ坪', '26', '26210', '6148263', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '岩田六ノ坪', 'イワタロクノツボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市岩田南野', '26', '26210', '6148264', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '岩田南野', 'イワタミナミノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市岩田南浅地', '26', '26210', '6148265', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '岩田南浅地', 'イワタミナミアサジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市岩田八丁', '26', '26210', '6148266', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '岩田八丁', 'イワタハッチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市岩田北浅地', '26', '26210', '6148267', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '岩田北浅地', 'イワタキタアサジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市岩田高木', '26', '26210', '6148268', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '岩田高木', 'イワタタカギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市美濃山ヒル塚', '26', '26210', '6148271', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '美濃山ヒル塚', 'ミノヤマヒルヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市美濃山御幸', '26', '26210', '6148272', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '美濃山御幸', 'ミノヤマミユキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市美濃山井ノ元', '26', '26210', '6148273', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '美濃山井ノ元', 'ミノヤマイノモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市美濃山野神', '26', '26210', '6148274', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '美濃山野神', 'ミノヤマノガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市美濃山中尾', '26', '26210', '6148275', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '美濃山中尾', 'ミノヤマナカオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市美濃山宮道', '26', '26210', '6148276', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '美濃山宮道', 'ミノヤマミヤミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市美濃山宮ノ背', '26', '26210', '6148277', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '美濃山宮ノ背', 'ミノヤマミヤノセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市美濃山西ノ口', '26', '26210', '6148278', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '美濃山西ノ口', 'ミノヤマニシノクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市美濃山幸水', '26', '26210', '6148279', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '美濃山幸水', 'ミノヤマコウスイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市戸津奥谷', '26', '26210', '6148280', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '戸津奥谷', 'トウヅオクタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市美濃山狐谷', '26', '26210', '6148281', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '美濃山狐谷', 'ミノヤマキツネダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市美濃山大塚', '26', '26210', '6148282', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '美濃山大塚', 'ミノヤマオオツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市美濃山細谷', '26', '26210', '6148283', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '美濃山細谷', 'ミノヤマホソダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市美濃山馬ケ背', '26', '26210', '6148284', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '美濃山馬ケ背', 'ミノヤマウマガセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市美濃山御幸谷', '26', '26210', '6148285', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '美濃山御幸谷', 'ミノヤマミユキダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市美濃山千原谷', '26', '26210', '6148286', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '美濃山千原谷', 'ミノヤマチハラダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市美濃山出口', '26', '26210', '6148287', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '美濃山出口', 'ミノヤマデグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市美濃山出島', '26', '26210', '6148288', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '美濃山出島', 'ミノヤマデジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市美濃山一ノ谷', '26', '26210', '6148289', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '美濃山一ノ谷', 'ミノヤマイチノタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市松井栂谷', '26', '26210', '6148291', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '松井栂谷', 'マツイトガダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市松井交野ケ原', '26', '26210', '6148292', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '松井交野ケ原', 'マツイカタノガハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市松井手水ケ谷', '26', '26210', '6148293', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '松井手水ケ谷', 'マツイテミズガダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市欽明台北', '26', '26210', '6148294', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '欽明台北', 'キンメイダイキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市欽明台中央', '26', '26210', '6148295', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '欽明台中央', 'キンメイダイチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市欽明台東', '26', '26210', '6148296', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '欽明台東', 'キンメイダイヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市欽明台西', '26', '26210', '6148297', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '欽明台西', 'キンメイダイニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市八幡池ノ首', '26', '26210', '6148301', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '八幡池ノ首', 'ヤワタイケノクビ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市八幡カイトリ', '26', '26210', '6148302', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '八幡カイトリ', 'ヤワタカイトリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市八幡菰池', '26', '26210', '6148303', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '八幡菰池', 'ヤワタコモイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市八幡源野', '26', '26210', '6148304', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '八幡源野', 'ヤワタゲンノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市八幡焼木', '26', '26210', '6148305', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '八幡焼木', 'ヤワタヤケギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市八幡沢', '26', '26210', '6148306', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '八幡沢', 'ヤワタサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市八幡在応寺', '26', '26210', '6148307', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '八幡在応寺', 'ヤワタザイオウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市八幡八萩', '26', '26210', '6148308', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '八幡八萩', 'ヤワタヤハギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市橋本奥ノ町', '26', '26210', '6148311', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '橋本奥ノ町', 'ハシモトオクノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市橋本尻江', '26', '26210', '6148312', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '橋本尻江', 'ハシモトシリエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市橋本東山本', '26', '26210', '6148313', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '橋本東山本', 'ハシモトヒガシヤマモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市橋本西山本', '26', '26210', '6148314', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '橋本西山本', 'ハシモトニシヤマモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市橋本北ノ町', '26', '26210', '6148315', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '橋本北ノ町', 'ハシモトキタノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市橋本米ノ尾', '26', '26210', '6148321', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '橋本米ノ尾', 'ハシモトコメノオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市橋本狩尾', '26', '26210', '6148322', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '橋本狩尾', 'ハシモトトガノオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市橋本興正', '26', '26210', '6148323', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '橋本興正', 'ハシモトコウショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市橋本東浄土ケ原', '26', '26210', '6148324', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '橋本東浄土ケ原', 'ハシモトヒガシジョウドガハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市橋本北浄土ケ原', '26', '26210', '6148325', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '橋本北浄土ケ原', 'ハシモトキタジョウドガハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市橋本石ケ谷', '26', '26210', '6148326', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '橋本石ケ谷', 'ハシモトイシガダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市橋本栗ケ谷', '26', '26210', '6148327', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '橋本栗ケ谷', 'ハシモトクリガダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市橋本意足', '26', '26210', '6148331', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '橋本意足', 'ハシモトイソク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市橋本新石', '26', '26210', '6148332', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '橋本新石', 'ハシモトシンセキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市橋本東刈又', '26', '26210', '6148333', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '橋本東刈又', 'ハシモトヒガシカリマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市橋本西刈又', '26', '26210', '6148334', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '橋本西刈又', 'ハシモトニシカリマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市橋本中ノ池尻', '26', '26210', '6148335', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '橋本中ノ池尻', 'ハシモトナカノイケジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市橋本向山', '26', '26210', '6148336', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '橋本向山', 'ハシモトムカイヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市橋本中ノ町', '26', '26210', '6148341', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '橋本中ノ町', 'ハシモトナカノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市橋本小金川', '26', '26210', '6148342', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '橋本小金川', 'ハシモトコガネガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市橋本焼野', '26', '26210', '6148343', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '橋本焼野', 'ハシモトヤケノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市橋本堂ケ原', '26', '26210', '6148344', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '橋本堂ケ原', 'ハシモトドウガハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市橋本愛宕山', '26', '26210', '6148345', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '橋本愛宕山', 'ハシモトアタゴヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市橋本塩釜', '26', '26210', '6148346', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '橋本塩釜', 'ハシモトシオガマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市橋本平野山', '26', '26210', '6148347', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '橋本平野山', 'ハシモトヒラノヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市橋本東原', '26', '26210', '6148348', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '橋本東原', 'ハシモトヒガシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市橋本糸ケ上', '26', '26210', '6148349', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '橋本糸ケ上', 'ハシモトイトガウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市西山足立', '26', '26210', '6148351', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '西山足立', 'ニシヤマアダチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市西山和気', '26', '26210', '6148352', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '西山和気', 'ニシヤマワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市西山丸尾', '26', '26210', '6148353', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '西山丸尾', 'ニシヤママルオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市男山指月', '26', '26210', '6148361', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '男山指月', 'オトコヤマシゲツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市男山美桜', '26', '26210', '6148362', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '男山美桜', 'オトコヤマミザクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市男山吉井', '26', '26210', '6148363', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '男山吉井', 'オトコヤマヨシイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市男山松里', '26', '26210', '6148364', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '男山松里', 'オトコヤママツサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市男山金振', '26', '26210', '6148365', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '男山金振', 'オトコヤマカナブリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市男山泉', '26', '26210', '6148366', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '男山泉', 'オトコヤマイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市男山長沢', '26', '26210', '6148367', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '男山長沢', 'オトコヤマナガサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市男山雄徳', '26', '26210', '6148371', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '男山雄徳', 'オトコヤマユウトク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市男山笹谷', '26', '26210', '6148372', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '男山笹谷', 'オトコヤマササタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市男山八望', '26', '26210', '6148373', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '男山八望', 'オトコヤマハチボウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市男山石城', '26', '26210', '6148374', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '男山石城', 'オトコヤマイシシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市男山弓岡', '26', '26210', '6148375', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '男山弓岡', 'オトコヤマユミオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市男山竹園', '26', '26210', '6148376', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '男山竹園', 'オトコヤマタケゾノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府八幡市男山香呂', '26', '26210', '6148377', '京都府', 'キョウトフ', '八幡市', 'ヤワタシ', '男山香呂', 'オトコヤマコウロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西院上今田町', '26', '26108', '6150001', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西院上今田町', 'サイインカミイマダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西院東今田町', '26', '26108', '6150002', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西院東今田町', 'サイインヒガシイマダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西院西今田町', '26', '26108', '6150003', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西院西今田町', 'サイインニシイマダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西院下花田町', '26', '26108', '6150004', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西院下花田町', 'サイインシモハナダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西院春栄町', '26', '26108', '6150005', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西院春栄町', 'サイインシュンエイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西院金槌町', '26', '26108', '6150006', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西院金槌町', 'サイインカナヅチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西院上花田町', '26', '26108', '6150007', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西院上花田町', 'サイインカミハナダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西院東淳和院町', '26', '26108', '6150011', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西院東淳和院町', 'サイインヒガシジュンナインチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西院高山寺町', '26', '26108', '6150012', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西院高山寺町', 'サイインコウザンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西院松井町', '26', '26108', '6150013', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西院松井町', 'サイインマツイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西院巽町', '26', '26108', '6150014', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西院巽町', 'サイインタツミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西院春日町', '26', '26108', '6150015', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西院春日町', 'サイインカスガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西院西淳和院町', '26', '26108', '6150016', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西院西淳和院町', 'サイインニシジュンナインチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西院三蔵町', '26', '26108', '6150021', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西院三蔵町', 'サイインサンゾウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西院平町', '26', '26108', '6150022', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西院平町', 'サイインヒラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西院西平町', '26', '26108', '6150023', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西院西平町', 'サイインニシヒラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西院矢掛町', '26', '26108', '6150024', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西院矢掛町', 'サイインヤカケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西院西矢掛町', '26', '26108', '6150025', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西院西矢掛町', 'サイインニシヤカケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西院北矢掛町', '26', '26108', '6150026', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西院北矢掛町', 'サイインキタヤカケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西院西三蔵町', '26', '26108', '6150027', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西院西三蔵町', 'サイインニシサンゾウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西院高田町', '26', '26108', '6150031', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西院高田町', 'サイインタカダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西院西高田町', '26', '26108', '6150032', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西院西高田町', 'サイインニシタカダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西院寿町', '26', '26108', '6150033', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西院寿町', 'サイインコトブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西院西寿町', '26', '26108', '6150034', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西院西寿町', 'サイインニシコトブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西院追分町', '26', '26108', '6150035', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西院追分町', 'サイインオイワケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西院太田町', '26', '26108', '6150036', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西院太田町', 'サイインオオタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西院南井御料町', '26', '26108', '6150037', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西院南井御料町', 'サイインミナミイゴリョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西院南高田町', '26', '26108', '6150041', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西院南高田町', 'サイインミナミタカダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西院東中水町', '26', '26108', '6150042', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西院東中水町', 'サイインヒガシナカミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西院中水町', '26', '26108', '6150043', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西院中水町', 'サイインナカミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西院西中水町', '26', '26108', '6150044', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西院西中水町', 'サイインニシナカミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西院溝崎町', '26', '26108', '6150045', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西院溝崎町', 'サイインミゾサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西院西溝崎町', '26', '26108', '6150046', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西院西溝崎町', 'サイインニシミゾサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西院六反田町', '26', '26108', '6150047', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西院六反田町', 'サイインロクタンダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西院南寿町', '26', '26108', '6150048', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西院南寿町', 'サイインミナミコトブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西院安塚町', '26', '26108', '6150051', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西院安塚町', 'サイインヤスヅカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西院清水町', '26', '26108', '6150052', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西院清水町', 'サイインシミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西院久保田町', '26', '26108', '6150053', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西院久保田町', 'サイインクボタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西院月双町', '26', '26108', '6150054', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西院月双町', 'サイインツキソウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西院西田町', '26', '26108', '6150055', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西院西田町', 'サイインニシダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西院西貝川町', '26', '26108', '6150056', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西院西貝川町', 'サイインニシカイガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西院東貝川町', '26', '26108', '6150057', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西院東貝川町', 'サイインヒガシカイガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西院笠目町', '26', '26108', '6150058', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西院笠目町', 'サイインカサメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西院乾町', '26', '26108', '6150061', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西院乾町', 'サイインイヌイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西院坤町', '26', '26108', '6150062', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西院坤町', 'サイインヒツジサルチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西院北井御料町', '26', '26108', '6150063', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西院北井御料町', 'サイインキタイゴリョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西院久田町', '26', '26108', '6150064', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西院久田町', 'サイインクデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西院日照町', '26', '26108', '6150065', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西院日照町', 'サイインヒデリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西院四条畑町', '26', '26108', '6150066', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西院四条畑町', 'サイインシジョウバタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西院小米町', '26', '26108', '6150067', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西院小米町', 'サイインコゴメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区山ノ内西裏町', '26', '26108', '6150071', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '山ノ内西裏町', 'ヤマノウチニシウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区山ノ内池尻町', '26', '26108', '6150072', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '山ノ内池尻町', 'ヤマノウチイケジリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区山ノ内荒木町', '26', '26108', '6150073', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '山ノ内荒木町', 'ヤマノウチアラキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区山ノ内苗町', '26', '26108', '6150074', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '山ノ内苗町', 'ヤマノウチナエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区山ノ内養老町', '26', '26108', '6150081', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '山ノ内養老町', 'ヤマノウチヨウロウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区山ノ内赤山町', '26', '26108', '6150082', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '山ノ内赤山町', 'ヤマノウチセキサンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区山ノ内瀬戸畑町', '26', '26108', '6150083', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '山ノ内瀬戸畑町', 'ヤマノウチセトハタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区山ノ内山ノ下町', '26', '26108', '6150084', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '山ノ内山ノ下町', 'ヤマノウチヤマノシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区山ノ内中畑町', '26', '26108', '6150085', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '山ノ内中畑町', 'ヤマノウチナカハタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区山ノ内御堂殿町', '26', '26108', '6150091', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '山ノ内御堂殿町', 'ヤマノウチミドウデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区山ノ内宮脇町', '26', '26108', '6150092', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '山ノ内宮脇町', 'ヤマノウチミヤワキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区山ノ内宮前町', '26', '26108', '6150093', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '山ノ内宮前町', 'ヤマノウチミヤマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区山ノ内北ノ口町', '26', '26108', '6150094', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '山ノ内北ノ口町', 'ヤマノウチキタノクチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区山ノ内西八反田町', '26', '26108', '6150095', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '山ノ内西八反田町', 'ヤマノウチニシハッタンダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区山ノ内五反田町', '26', '26108', '6150096', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '山ノ内五反田町', 'ヤマノウチゴタンダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区山ノ内大町', '26', '26108', '6150097', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '山ノ内大町', 'ヤマノウチオオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西京極豆田町', '26', '26108', '6150801', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西京極豆田町', 'ニシキョウゴクマメダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西京極北庄境町', '26', '26108', '6150802', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西京極北庄境町', 'ニシキョウゴクキタショウザカイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西京極南庄境町', '26', '26108', '6150803', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西京極南庄境町', 'ニシキョウゴクミナミショウザカイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西京極町ノ坪町', '26', '26108', '6150804', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西京極町ノ坪町', 'ニシキョウゴクチョウノツボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西京極東池田町', '26', '26108', '6150805', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西京極東池田町', 'ニシキョウゴクヒガシイケダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西京極畔勝町', '26', '26108', '6150806', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西京極畔勝町', 'ニシキョウゴクアゼカツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西京極東大丸町', '26', '26108', '6150807', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西京極東大丸町', 'ニシキョウゴクヒガシオオマルチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西京極中溝町', '26', '26108', '6150811', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西京極中溝町', 'ニシキョウゴクナカミゾチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西京極大門町', '26', '26108', '6150812', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西京極大門町', 'ニシキョウゴクダイモンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西京極佃田町', '26', '26108', '6150813', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西京極佃田町', 'ニシキョウゴクツクダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西京極下沢町', '26', '26108', '6150814', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西京極下沢町', 'ニシキョウゴクシモザワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西京極中沢町', '26', '26108', '6150815', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西京極中沢町', 'ニシキョウゴクナカザワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西京極東町', '26', '26108', '6150816', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西京極東町', 'ニシキョウゴクヒガシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西京極宮ノ東町', '26', '26108', '6150817', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西京極宮ノ東町', 'ニシキョウゴクミヤノヒガシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西京極三反田町', '26', '26108', '6150818', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西京極三反田町', 'ニシキョウゴクサンタンダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西京極北裏町', '26', '26108', '6150821', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西京極北裏町', 'ニシキョウゴクキタウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西京極中町', '26', '26108', '6150822', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西京極中町', 'ニシキョウゴクナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西京極前田町', '26', '26108', '6150823', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西京極前田町', 'ニシキョウゴクマエダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西京極畑田町', '26', '26108', '6150824', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西京極畑田町', 'ニシキョウゴクハタダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西京極東向河原町', '26', '26108', '6150825', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西京極東向河原町', 'ニシキョウゴクヒガシムコウガワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西京極芝ノ下町', '26', '26108', '6150826', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西京極芝ノ下町', 'ニシキョウゴクシバノシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西京極南方町', '26', '26108', '6150827', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西京極南方町', 'ニシキョウゴクナンポウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西京極長町', '26', '26108', '6150831', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西京極長町', 'ニシキョウゴクナガマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西京極走上リ町', '26', '26108', '6150832', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西京極走上リ町', 'ニシキョウゴクハシアガリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西京極橋詰町', '26', '26108', '6150833', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西京極橋詰町', 'ニシキョウゴクハシヅメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西京極殿田町', '26', '26108', '6150834', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西京極殿田町', 'ニシキョウゴクトノダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西京極堤下町', '26', '26108', '6150835', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西京極堤下町', 'ニシキョウゴクツツミシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西京極河原町裏町', '26', '26108', '6150836', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西京極河原町裏町', 'ニシキョウゴクカワラチョウウラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西京極西向河原町', '26', '26108', '6150837', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西京極西向河原町', 'ニシキョウゴクニシムコウガワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西京極薮ノ下町', '26', '26108', '6150838', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西京極薮ノ下町', 'ニシキョウゴクヤブノシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西京極火打畑町', '26', '26108', '6150841', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西京極火打畑町', 'ニシキョウゴクヒウチバタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西京極薮開町', '26', '26108', '6150842', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西京極薮開町', 'ニシキョウゴクヤブビラキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西京極河原町', '26', '26108', '6150843', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西京極河原町', 'ニシキョウゴクカワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西京極東側町', '26', '26108', '6150844', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西京極東側町', 'ニシキョウゴクヒガシガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西京極末広町', '26', '26108', '6150845', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西京極末広町', 'ニシキョウゴクスエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西京極徳大寺団子田町', '26', '26108', '6150846', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西京極徳大寺団子田町', 'ニシキョウゴクトクダイジダンゴデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西京極西池田町', '26', '26108', '6150851', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西京極西池田町', 'ニシキョウゴクニシイケダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西京極西川町', '26', '26108', '6150852', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西京極西川町', 'ニシキョウゴクニシカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西京極郡醍醐田町', '26', '26108', '6150853', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西京極郡醍醐田町', 'ニシキョウゴクゴオリダイゴデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西京極堤外町', '26', '26108', '6150854', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西京極堤外町', 'ニシキョウゴクツツミソトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西京極西団子田町', '26', '26108', '6150855', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西京極西団子田町', 'ニシキョウゴクニシダンゴデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西京極古浜町', '26', '26108', '6150856', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西京極古浜町', 'ニシキョウゴクフルハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西京極郡猪馬場町', '26', '26108', '6150857', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西京極郡猪馬場町', 'ニシキョウゴクゴオリイノババチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西京極郡沢町', '26', '26108', '6150858', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西京極郡沢町', 'ニシキョウゴクゴオリサワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西京極野田町', '26', '26108', '6150861', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西京極野田町', 'ニシキョウゴクノダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西京極西大丸町', '26', '26108', '6150862', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西京極西大丸町', 'ニシキョウゴクニシオオマルチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西京極堤町', '26', '26108', '6150863', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西京極堤町', 'ニシキョウゴクツツミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西京極新明町', '26', '26108', '6150864', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西京極新明町', 'ニシキョウゴクシンメイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西京極東衣手町', '26', '26108', '6150871', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西京極東衣手町', 'ニシキョウゴクヒガシコロモデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西京極南衣手町', '26', '26108', '6150872', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西京極南衣手町', 'ニシキョウゴクミナミコロモデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西京極浜ノ本町', '26', '26108', '6150873', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西京極浜ノ本町', 'ニシキョウゴクハマノモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西京極新田町', '26', '26108', '6150874', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西京極新田町', 'ニシキョウゴクシンデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西京極徳大寺西団子田町', '26', '26108', '6150875', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西京極徳大寺西団子田町', 'ニシキョウゴクトクダイジニシダンゴデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西京極郡附洲町', '26', '26108', '6150876', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西京極郡附洲町', 'ニシキョウゴクゴオリフズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西京極西衣手町', '26', '26108', '6150877', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西京極西衣手町', 'ニシキョウゴクニシコロモデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西京極北衣手町', '26', '26108', '6150878', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西京極北衣手町', 'ニシキョウゴクキタコロモデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西京極北大入町', '26', '26108', '6150881', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西京極北大入町', 'ニシキョウゴクキタオオイリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西京極葛野町', '26', '26108', '6150882', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西京極葛野町', 'ニシキョウゴクカドノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西京極南大入町', '26', '26108', '6150883', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西京極南大入町', 'ニシキョウゴクミナミオオイリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西京極郡町', '26', '26108', '6150884', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西京極郡町', 'ニシキョウゴクゴオリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区西京極午塚町', '26', '26108', '6150885', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '西京極午塚町', 'ニシキョウゴクウマヅカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区梅津南広町', '26', '26108', '6150901', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '梅津南広町', 'ウメヅミナミヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区梅津神田町', '26', '26108', '6150902', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '梅津神田町', 'ウメヅカンダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区梅津堤下町', '26', '26108', '6150903', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '梅津堤下町', 'ウメヅツツミシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区梅津堤上町', '26', '26108', '6150904', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '梅津堤上町', 'ウメヅツツミカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区梅津石灘町', '26', '26108', '6150905', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '梅津石灘町', 'ウメヅイシナダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区梅津高畝町', '26', '26108', '6150906', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '梅津高畝町', 'ウメヅタカゼチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区梅津段町', '26', '26108', '6150907', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '梅津段町', 'ウメヅダンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区梅津北町', '26', '26108', '6150911', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '梅津北町', 'ウメヅキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区梅津構口町', '26', '26108', '6150912', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '梅津構口町', 'ウメヅカマエグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区梅津南上田町', '26', '26108', '6150913', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '梅津南上田町', 'ウメヅミナミウエダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区梅津東構口町', '26', '26108', '6150914', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '梅津東構口町', 'ウメヅヒガシカマエグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区梅津南町', '26', '26108', '6150915', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '梅津南町', 'ウメヅミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区梅津中村町', '26', '26108', '6150916', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '梅津中村町', 'ウメヅナカムラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区梅津西浦町', '26', '26108', '6150917', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '梅津西浦町', 'ウメヅニシウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区梅津フケノ川町', '26', '26108', '6150921', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '梅津フケノ川町', 'ウメヅフケノカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区梅津前田町', '26', '26108', '6150922', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '梅津前田町', 'ウメヅマエダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区梅津中倉町', '26', '26108', '6150923', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '梅津中倉町', 'ウメヅナカクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区梅津尻溝町', '26', '26108', '6150924', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '梅津尻溝町', 'ウメヅシリミゾチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区梅津大縄場町', '26', '26108', '6150925', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '梅津大縄場町', 'ウメヅオオナワバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区梅津罧原町', '26', '26108', '6150926', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '梅津罧原町', 'ウメヅフシハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区梅津開キ町', '26', '26108', '6150931', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '梅津開キ町', 'ウメヅヒラキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区梅津上田町', '26', '26108', '6150932', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '梅津上田町', 'ウメヅウエダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区梅津後藤町', '26', '26108', '6150933', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '梅津後藤町', 'ウメヅゴトウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区梅津北浦町', '26', '26108', '6150934', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '梅津北浦町', 'ウメヅキタウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区梅津徳丸町', '26', '26108', '6150935', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '梅津徳丸町', 'ウメヅトクマルチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区梅津林口町', '26', '26108', '6150936', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '梅津林口町', 'ウメヅハヤシクチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区梅津北川町', '26', '26108', '6150937', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '梅津北川町', 'ウメヅキタガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区梅津坂本町', '26', '26108', '6150938', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '梅津坂本町', 'ウメヅサカモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区桂上野北町', '26', '26111', '6158001', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '桂上野北町', 'カツラカミノキタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区桂上野中町', '26', '26111', '6158002', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '桂上野中町', 'カツラカミノナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区桂上野東町', '26', '26111', '6158003', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '桂上野東町', 'カツラカミノヒガシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区桂畑ケ田町', '26', '26111', '6158004', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '桂畑ケ田町', 'カツラハタケダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区桂上野南町', '26', '26111', '6158005', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '桂上野南町', 'カツラカミノミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区桂上野西町', '26', '26111', '6158006', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '桂上野西町', 'カツラカミノニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区桂上野今井町', '26', '26111', '6158007', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '桂上野今井町', 'カツラカミノイマイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区桂上野川原町', '26', '26111', '6158008', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '桂上野川原町', 'カツラカミノカワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区桂大縄町', '26', '26111', '6158011', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '桂大縄町', 'カツラオオナワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区桂後水町', '26', '26111', '6158012', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '桂後水町', 'カツラコウズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区桂清水町', '26', '26111', '6158013', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '桂清水町', 'カツラシミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区桂御園', '26', '26111', '6158014', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '桂御園', 'カツラミソノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区徳大寺清水町', '26', '26111', '6158015', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '徳大寺清水町', 'トクダイジシミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区桂久方町', '26', '26111', '6158016', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '桂久方町', 'カツラヒサカタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区桂河田町', '26', '26111', '6158017', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '桂河田町', 'カツラカワダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区桂徳大寺町', '26', '26111', '6158018', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '桂徳大寺町', 'カツラトクダイジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区桂浅原町', '26', '26111', '6158021', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '桂浅原町', 'カツラアサハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区桂北滝川町', '26', '26111', '6158022', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '桂北滝川町', 'カツラキタタキガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区桂南滝川町', '26', '26111', '6158023', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '桂南滝川町', 'カツラミナミタキガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区桂西滝川町', '26', '26111', '6158024', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '桂西滝川町', 'カツラニシタキガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区桂稲荷山町', '26', '26111', '6158025', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '桂稲荷山町', 'カツライナリヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区桂市ノ前町', '26', '26111', '6158026', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '桂市ノ前町', 'カツライチノマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区桂朝日町', '26', '26111', '6158027', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '桂朝日町', 'カツラアサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区牛ケ瀬林ノ本町', '26', '26111', '6158031', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '牛ケ瀬林ノ本町', 'ウシガセハヤシノモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区牛ケ瀬奥ノ防町', '26', '26111', '6158032', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '牛ケ瀬奥ノ防町', 'ウシガセオクノボウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区下津林東大般若町', '26', '26111', '6158033', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '下津林東大般若町', 'シモツバヤシヒガシダイハンニャチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区下津林東芝ノ宮町', '26', '26111', '6158034', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '下津林東芝ノ宮町', 'シモツバヤシヒガシシバノミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区下津林芝ノ宮町', '26', '26111', '6158035', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '下津林芝ノ宮町', 'シモツバヤシシバノミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区下津林南大般若町', '26', '26111', '6158036', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '下津林南大般若町', 'シモツバヤシミナミダイハンニャチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区下津林大般若町', '26', '26111', '6158037', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '下津林大般若町', 'シモツバヤシダイハンニャチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区牛ケ瀬青柳町', '26', '26111', '6158041', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '牛ケ瀬青柳町', 'ウシガセアオヤギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区牛ケ瀬川原口町', '26', '26111', '6158042', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '牛ケ瀬川原口町', 'ウシガセカハラグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区牛ケ瀬新田泓町', '26', '26111', '6158043', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '牛ケ瀬新田泓町', 'ウシガセシンデンブケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区牛ケ瀬山柿町', '26', '26111', '6158044', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '牛ケ瀬山柿町', 'ウシガセヤマガキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区牛ケ瀬南ノ口町', '26', '26111', '6158045', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '牛ケ瀬南ノ口町', 'ウシガセミナミノクチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区牛ケ瀬弥生町', '26', '26111', '6158046', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '牛ケ瀬弥生町', 'ウシガセヤヨイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区牛ケ瀬西柿町', '26', '26111', '6158051', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '牛ケ瀬西柿町', 'ウシガセニシガキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区牛ケ瀬堂田町', '26', '26111', '6158052', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '牛ケ瀬堂田町', 'ウシガセドウデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区下津林中島町', '26', '26111', '6158053', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '下津林中島町', 'シモツバヤシナカジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区下津林南中島町', '26', '26111', '6158054', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '下津林南中島町', 'シモツバヤシミナミナカジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区下津林佃', '26', '26111', '6158055', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '下津林佃', 'シモツバヤシツクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区下津林番条', '26', '26111', '6158056', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '下津林番条', 'シモツバヤシバンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区下津林番条町', '26', '26111', '6158057', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '下津林番条町', 'シモツバヤシバンジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区下津林北浦町', '26', '26111', '6158061', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '下津林北浦町', 'シモツバヤシキタウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区下津林前泓町', '26', '26111', '6158062', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '下津林前泓町', 'シモツバヤシマエブケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区下津林六反田', '26', '26111', '6158063', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '下津林六反田', 'シモツバヤシロクタンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区下津林水掛町', '26', '26111', '6158064', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '下津林水掛町', 'シモツバヤシミズカケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区下津林楠町', '26', '26111', '6158065', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '下津林楠町', 'シモツバヤシクスノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区桂春日町', '26', '26111', '6158071', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '桂春日町', 'カツラカスガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区桂木ノ下町', '26', '26111', '6158072', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '桂木ノ下町', 'カツラキノシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区桂野里町', '26', '26111', '6158073', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '桂野里町', 'カツラノザトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区桂南巽町', '26', '26111', '6158074', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '桂南巽町', 'カツラミナミタツミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区桂巽町', '26', '26111', '6158075', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '桂巽町', 'カツラタツミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区桂下豆田町', '26', '26111', '6158076', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '桂下豆田町', 'カツラシモマメダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区桂芝ノ下町', '26', '26111', '6158077', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '桂芝ノ下町', 'カツラシバノシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区桂池尻町', '26', '26111', '6158081', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '桂池尻町', 'カツライケジリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区桂上豆田町', '26', '26111', '6158082', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '桂上豆田町', 'カツラカミマメダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区桂艮町', '26', '26111', '6158083', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '桂艮町', 'カツラウシトラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区桂坤町', '26', '26111', '6158084', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '桂坤町', 'カツラヒツジサルチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区桂千代原町', '26', '26111', '6158085', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '桂千代原町', 'カツラチヨハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区桂乾町', '26', '26111', '6158086', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '桂乾町', 'カツライヌイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区桂御所町', '26', '26111', '6158087', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '桂御所町', 'カツラゴショチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区川島東代町', '26', '26111', '6158101', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '川島東代町', 'カワシマヒガシダイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区川島松ノ木本町', '26', '26111', '6158102', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '川島松ノ木本町', 'カワシママツノキモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区川島六ノ坪町', '26', '26111', '6158103', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '川島六ノ坪町', 'カワシマロクノツボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区川島五反長町', '26', '26111', '6158104', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '川島五反長町', 'カワシマゴタンオサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区川島莚田町', '26', '26111', '6158105', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '川島莚田町', 'カワシマムシロデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区川島滑樋町', '26', '26111', '6158106', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '川島滑樋町', 'カワシマナメラヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区川島北裏町', '26', '26111', '6158107', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '川島北裏町', 'カワシマキタウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区川島松園町', '26', '26111', '6158111', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '川島松園町', 'カワシママツゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区川島竹園町', '26', '26111', '6158112', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '川島竹園町', 'カワシマタケゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区川島梅園町', '26', '26111', '6158113', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '川島梅園町', 'カワシマウメゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区川島桜園町', '26', '26111', '6158114', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '川島桜園町', 'カワシマサクラゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区川島流田町', '26', '26111', '6158115', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '川島流田町', 'カワシマナガレダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区樫原甲水', '26', '26111', '6158116', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '樫原甲水', 'カタギハラコウスイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区樫原六反田', '26', '26111', '6158117', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '樫原六反田', 'カタギハラロクタンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区川島三重町', '26', '26111', '6158118', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '川島三重町', 'カワシマサンジュウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区川島野田町', '26', '26111', '6158121', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '川島野田町', 'カワシマノダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区樫原八反田', '26', '26111', '6158122', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '樫原八反田', 'カタギハラハッタンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区樫原山路', '26', '26111', '6158123', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '樫原山路', 'カタギハラヤマジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区樫原三宅町', '26', '26111', '6158124', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '樫原三宅町', 'カタギハラミヤケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区川島調子町', '26', '26111', '6158125', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '川島調子町', 'カワシマチョウシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区樫原五反田', '26', '26111', '6158131', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '樫原五反田', 'カタギハラゴタンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区樫原庭井', '26', '26111', '6158132', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '樫原庭井', 'カタギハラニワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区樫原井戸', '26', '26111', '6158133', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '樫原井戸', 'カタギハライド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区樫原比恵田町', '26', '26111', '6158134', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '樫原比恵田町', 'カタギハラヒエダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区樫原江ノ本町', '26', '26111', '6158135', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '樫原江ノ本町', 'カタギハラエノモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区樫原口戸', '26', '26111', '6158136', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '樫原口戸', 'カタギハラクチド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区樫原平田町', '26', '26111', '6158141', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '樫原平田町', 'カタギハラヒラタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区樫原畔ノ海道', '26', '26111', '6158142', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '樫原畔ノ海道', 'カタギハラアゼノカイドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区樫原里ノ垣外町', '26', '26111', '6158143', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '樫原里ノ垣外町', 'カタギハラサトノカイトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区樫原釘貫', '26', '26111', '6158144', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '樫原釘貫', 'カタギハラクギヌキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('70999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区樫原角田町', '26', '26111', '6158145', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '樫原角田町', 'カタギハラスミタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区樫原田中町', '26', '26111', '6158146', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '樫原田中町', 'カタギハラタナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区樫原塚ノ本町', '26', '26111', '6158147', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '樫原塚ノ本町', 'カタギハラツカノモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区樫原杉原町', '26', '26111', '6158151', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '樫原杉原町', 'カタギハラスギハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区樫原内垣外町', '26', '26111', '6158152', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '樫原内垣外町', 'カタギハラウチカイトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区樫原前田町', '26', '26111', '6158153', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '樫原前田町', 'カタギハラマエダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区樫原岡南ノ庄', '26', '26111', '6158154', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '樫原岡南ノ庄', 'カタギハラオカミナミノショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区樫原大亀谷', '26', '26111', '6158155', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '樫原大亀谷', 'カタギハラオオカメダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区樫原百々ケ池', '26', '26111', '6158156', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '樫原百々ケ池', 'カタギハラドドガイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区樫原芋峠', '26', '26111', '6158157', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '樫原芋峠', 'カタギハライモトウゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区樫原秤谷町', '26', '26111', '6158158', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '樫原秤谷町', 'カタギハラハカリダニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区樫原蛸田町', '26', '26111', '6158161', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '樫原蛸田町', 'カタギハラタコデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区樫原上ノ町', '26', '26111', '6158162', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '樫原上ノ町', 'カタギハラカミノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区樫原山ノ上町', '26', '26111', '6158163', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '樫原山ノ上町', 'カタギハラヤマノウエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区樫原鴫谷', '26', '26111', '6158164', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '樫原鴫谷', 'カタギハラシギタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区樫原盆山', '26', '26111', '6158165', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '樫原盆山', 'カタギハラボンヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区樫原久保町', '26', '26111', '6158171', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '樫原久保町', 'カタギハラクボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区樫原宇治井西町', '26', '26111', '6158172', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '樫原宇治井西町', 'カタギハラウジイニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区樫原下池田町', '26', '26111', '6158173', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '樫原下池田町', 'カタギハラシモイケダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区樫原中垣外', '26', '26111', '6158174', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '樫原中垣外', 'カタギハラナカカイト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区樫原硲町', '26', '26111', '6158175', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '樫原硲町', 'カタギハラハガマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区樫原上池田町', '26', '26111', '6158176', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '樫原上池田町', 'カタギハラカミイケダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区樫原下ノ町', '26', '26111', '6158177', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '樫原下ノ町', 'カタギハラシモノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区樫原池ノ上町', '26', '26111', '6158178', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '樫原池ノ上町', 'カタギハライケノウエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区樫原石畑町', '26', '26111', '6158181', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '樫原石畑町', 'カタギハライシバタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区樫原茶ノ木本町', '26', '26111', '6158182', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '樫原茶ノ木本町', 'カタギハラチャノキモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区樫原分田', '26', '26111', '6158183', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '樫原分田', 'カタギハラワケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区樫原水築町', '26', '26111', '6158184', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '樫原水築町', 'カタギハラミズツキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区樫原宇治井町', '26', '26111', '6158185', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '樫原宇治井町', 'カタギハラウジイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区樫原佃', '26', '26111', '6158186', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '樫原佃', 'カタギハラツクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区川島有栖川町', '26', '26111', '6158191', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '川島有栖川町', 'カワシマアリスガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区川島寺田町', '26', '26111', '6158192', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '川島寺田町', 'カワシマテラデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区川島玉頭町', '26', '26111', '6158193', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '川島玉頭町', 'カワシマタマガシラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区川島粟田町', '26', '26111', '6158194', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '川島粟田町', 'カワシマアワタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区川島権田町', '26', '26111', '6158195', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '川島権田町', 'カワシマゴンデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区川島尻堀町', '26', '26111', '6158196', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '川島尻堀町', 'カワシマシリボリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区上桂今井町', '26', '26111', '6158201', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '上桂今井町', 'カミカツライマイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区松室吾田神町', '26', '26111', '6158202', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '松室吾田神町', 'マツムロアタガミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区松室荒堀町', '26', '26111', '6158203', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '松室荒堀町', 'マツムロアラボリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区松室北河原町', '26', '26111', '6158204', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '松室北河原町', 'マツムロキタカワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区松室中溝町', '26', '26111', '6158205', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '松室中溝町', 'マツムロナカミゾチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区松室追上ゲ町', '26', '26111', '6158206', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '松室追上ゲ町', 'マツムロオイアゲチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区松室河原町', '26', '26111', '6158207', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '松室河原町', 'マツムロカワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区上桂樋ノ口町', '26', '26111', '6158208', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '上桂樋ノ口町', 'カミカツラヒノクチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区上桂前川町', '26', '26111', '6158211', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '上桂前川町', 'カミカツラマエガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区上桂北ノ口町', '26', '26111', '6158212', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '上桂北ノ口町', 'カミカツラキタノクチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区上桂北村町', '26', '26111', '6158213', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '上桂北村町', 'カミカツラキタムラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区上桂東居町', '26', '26111', '6158214', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '上桂東居町', 'カミカツラヒガシイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区上桂大野町', '26', '26111', '6158215', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '上桂大野町', 'カミカツラオオノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区松尾鈴川町', '26', '26111', '6158216', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '松尾鈴川町', 'マツオスズカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区松尾東ノ口町', '26', '26111', '6158217', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '松尾東ノ口町', 'マツオヒガシノクチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区上桂東ノ口町', '26', '26111', '6158221', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '上桂東ノ口町', 'カミカツラヒガシノクチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区上桂御正町', '26', '26111', '6158222', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '上桂御正町', 'カミカツラミショウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区上桂前田町', '26', '26111', '6158223', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '上桂前田町', 'カミカツラマエダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区上桂三ノ宮町', '26', '26111', '6158224', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '上桂三ノ宮町', 'カミカツラサンノミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区上桂森下町', '26', '26111', '6158225', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '上桂森下町', 'カミカツラモリシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区上桂森上町', '26', '26111', '6158226', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '上桂森上町', 'カミカツラモリカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区上桂宮ノ後町', '26', '26111', '6158227', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '上桂宮ノ後町', 'カミカツラミヤノゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区上桂西居町', '26', '26111', '6158228', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '上桂西居町', 'カミカツラニシイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区御陵溝浦町', '26', '26111', '6158231', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '御陵溝浦町', 'ゴリョウミゾウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区御陵南荒木町', '26', '26111', '6158232', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '御陵南荒木町', 'ゴリョウミナミアラキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区御陵荒木町', '26', '26111', '6158233', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '御陵荒木町', 'ゴリョウアラキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区御陵塚ノ越町', '26', '26111', '6158234', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '御陵塚ノ越町', 'ゴリョウツカノコシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区御陵内町', '26', '26111', '6158235', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '御陵内町', 'ゴリョウウチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区山田大吉見町', '26', '26111', '6158236', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '山田大吉見町', 'ヤマダオオヨシミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区山田中吉見町', '26', '26111', '6158237', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '山田中吉見町', 'ヤマダナカヨシミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区山田車塚町', '26', '26111', '6158238', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '山田車塚町', 'ヤマダクルマツカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区御陵谷町', '26', '26111', '6158241', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '御陵谷町', 'ゴリョウタニマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区御陵鴫谷', '26', '26111', '6158242', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '御陵鴫谷', 'ゴリョウシギタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区御陵御茶屋山', '26', '26111', '6158243', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '御陵御茶屋山', 'ゴリョウオチャヤヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区御陵池ノ谷', '26', '26111', '6158244', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '御陵池ノ谷', 'ゴリョウイケノタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区御陵大原', '26', '26111', '6158245', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '御陵大原', 'ゴリョウオオハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区京都大学桂', '26', '26111', '6158246', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '京都大学桂', 'キョウトダイガクカツラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区山田猫塚町', '26', '26111', '6158251', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '山田猫塚町', 'ヤマダネコツカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区御陵北山下町', '26', '26111', '6158252', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '御陵北山下町', 'ゴリョウキタヤマシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区御陵北山町', '26', '26111', '6158253', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '御陵北山町', 'ゴリョウキタヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区御陵細谷', '26', '26111', '6158254', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '御陵細谷', 'ゴリョウホソタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区山田箱塚町', '26', '26111', '6158255', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '山田箱塚町', 'ヤマダハコヅカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区山田平尾町', '26', '26111', '6158256', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '山田平尾町', 'ヤマダヒラオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区山田庄田町', '26', '26111', '6158261', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '山田庄田町', 'ヤマダショウダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区山田四ノ坪町', '26', '26111', '6158262', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '山田四ノ坪町', 'ヤマダシノツボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区山田久田町', '26', '26111', '6158263', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '山田久田町', 'ヤマダヒサダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区山田六ノ坪町', '26', '26111', '6158264', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '山田六ノ坪町', 'ヤマダロクノツボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区山田御道路町', '26', '26111', '6158265', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '山田御道路町', 'ヤマダオドロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区山田南山田町', '26', '26111', '6158266', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '山田南山田町', 'ヤマダミナミヤマダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区山田北山田町', '26', '26111', '6158267', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '山田北山田町', 'ヤマダキタヤマダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区山田弦馳町', '26', '26111', '6158271', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '山田弦馳町', 'ヤマダツルハゼチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区山田畑田町', '26', '26111', '6158272', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '山田畑田町', 'ヤマダハタケダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区山田出口町', '26', '26111', '6158273', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '山田出口町', 'ヤマダデグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区山田上ノ町', '26', '26111', '6158274', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '山田上ノ町', 'ヤマダウエノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区山田南町', '26', '26111', '6158275', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '山田南町', 'ヤマダミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区山田開キ町', '26', '26111', '6158276', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '山田開キ町', 'ヤマダヒラキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区山田葉室町', '26', '26111', '6158277', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '山田葉室町', 'ヤマダハムロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区松尾木ノ曽町', '26', '26111', '6158281', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '松尾木ノ曽町', 'マツオキノソチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区松尾大利町', '26', '26111', '6158282', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '松尾大利町', 'マツオダイリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区松尾井戸町', '26', '26111', '6158283', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '松尾井戸町', 'マツオイドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区松尾上ノ山町', '26', '26111', '6158284', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '松尾上ノ山町', 'マツオウエノヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区山田北ノ町', '26', '26111', '6158285', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '山田北ノ町', 'ヤマダキタノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区松尾神ケ谷町', '26', '26111', '6158286', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '松尾神ケ谷町', 'マツオジンガタニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区松尾万石町', '26', '26111', '6158287', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '松尾万石町', 'マツオマンゴクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区松室扇田町', '26', '26111', '6158291', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '松室扇田町', 'マツムロオウギダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区松室田中町', '26', '26111', '6158292', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '松室田中町', 'マツムロタナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区松室庄田町', '26', '26111', '6158293', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '松室庄田町', 'マツムロショウダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区松室地家町', '26', '26111', '6158294', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '松室地家町', 'マツムロジケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区松室地家山', '26', '26111', '6158295', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '松室地家山', 'マツムロジケヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区松室山添町', '26', '26111', '6158296', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '松室山添町', 'マツムロヤマゾエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区桂徳大寺北町', '26', '26111', '6158301', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '桂徳大寺北町', 'カツラトクダイジキタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区桂徳大寺南町', '26', '26111', '6158302', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '桂徳大寺南町', 'カツラトクダイジミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区桂徳大寺東町', '26', '26111', '6158303', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '桂徳大寺東町', 'カツラトクダイジヒガシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区', '26', '26108', '6160000', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('71119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区嵐山上河原町', '26', '26111', '6160001', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '嵐山上河原町', 'アラシヤマカミカワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区嵐山東一川町', '26', '26111', '6160002', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '嵐山東一川町', 'アラシヤマヒガシイチカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区嵐山西一川町', '26', '26111', '6160003', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '嵐山西一川町', 'アラシヤマニシイチカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区嵐山中尾下町', '26', '26111', '6160004', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '嵐山中尾下町', 'アラシヤマナカオシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区嵐山山田町', '26', '26111', '6160005', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '嵐山山田町', 'アラシヤマヤマダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区嵐山虚空蔵山町', '26', '26111', '6160006', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '嵐山虚空蔵山町', 'アラシヤマコクゾウヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区嵐山元録山町', '26', '26111', '6160007', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '嵐山元録山町', 'アラシヤマゲンロクザンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区嵐山樋ノ上町', '26', '26111', '6160011', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '嵐山樋ノ上町', 'アラシヤマヒノカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区嵐山東海道町', '26', '26111', '6160012', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '嵐山東海道町', 'アラシヤマヒガシカイドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区嵐山風呂ノ橋町', '26', '26111', '6160013', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '嵐山風呂ノ橋町', 'アラシヤマフロノハシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区嵐山谷ケ辻子町', '26', '26111', '6160014', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '嵐山谷ケ辻子町', 'アラシヤマタニガツジコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区嵐山山ノ下町', '26', '26111', '6160015', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '嵐山山ノ下町', 'アラシヤマヤマノシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区嵐山上海道町', '26', '26111', '6160016', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '嵐山上海道町', 'アラシヤマカミカイドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区嵐山茶尻町', '26', '26111', '6160017', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '嵐山茶尻町', 'アラシヤマチャジリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区嵐山森ノ前町', '26', '26111', '6160021', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '嵐山森ノ前町', 'アラシヤマモリノマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区嵐山朝月町', '26', '26111', '6160022', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '嵐山朝月町', 'アラシヤマアサツキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区嵐山宮ノ前町', '26', '26111', '6160023', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '嵐山宮ノ前町', 'アラシヤマミヤノマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区嵐山宮町', '26', '26111', '6160024', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '嵐山宮町', 'アラシヤマミヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区嵐山宮ノ北町', '26', '26111', '6160025', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '嵐山宮ノ北町', 'アラシヤマミヤノキタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区嵐山薬師下町', '26', '26111', '6160026', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '嵐山薬師下町', 'アラシヤマヤクシシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市西京区嵐山内田町', '26', '26111', '6160027', '京都府', 'キョウトフ', '京都市西京区', 'キョウトシニシキョウク', '嵐山内田町', 'アラシヤマウチダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区龍安寺御陵ノ下町', '26', '26108', '6168001', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '龍安寺御陵ノ下町', 'リョウアンジゴリョウノシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区龍安寺衣笠下町', '26', '26108', '6168002', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '龍安寺衣笠下町', 'リョウアンジキヌガサシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区龍安寺池ノ下町', '26', '26108', '6168003', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '龍安寺池ノ下町', 'リョウアンジイケノシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区龍安寺玉津芝町', '26', '26108', '6168004', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '龍安寺玉津芝町', 'リョウアンジタマツシバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区龍安寺塔ノ下町', '26', '26108', '6168005', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '龍安寺塔ノ下町', 'リョウアンジトウノシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区龍安寺住吉町', '26', '26108', '6168006', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '龍安寺住吉町', 'リョウアンジスミヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区龍安寺山田町', '26', '26108', '6168007', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '龍安寺山田町', 'リョウアンジヤマタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区龍安寺斎宮町', '26', '26108', '6168011', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '龍安寺斎宮町', 'リョウアンジサイグウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区谷口垣ノ内町', '26', '26108', '6168012', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '谷口垣ノ内町', 'タニグチカキノウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区谷口唐田ノ内町', '26', '26108', '6168013', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '谷口唐田ノ内町', 'タニグチカラタノウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区谷口梅津間町', '26', '26108', '6168014', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '谷口梅津間町', 'タニグチウメヅマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区谷口園町', '26', '26108', '6168015', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '谷口園町', 'タニグチソノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区龍安寺西ノ川町', '26', '26108', '6168016', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '龍安寺西ノ川町', 'リョウアンジニシノカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区龍安寺五反田町', '26', '26108', '6168017', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '龍安寺五反田町', 'リョウアンジゴタンダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区花園天授ケ岡町', '26', '26108', '6168021', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '花園天授ケ岡町', 'ハナゾノテンジュガオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区谷口円成寺町', '26', '26108', '6168022', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '谷口円成寺町', 'タニグチエンジョウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区花園大薮町', '26', '26108', '6168023', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '花園大薮町', 'ハナゾノオオヤブチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区花園一条田町', '26', '26108', '6168024', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '花園一条田町', 'ハナゾノイチジョウデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区花園土堂町', '26', '26108', '6168025', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '花園土堂町', 'ハナゾノツチドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区花園岡ノ本町', '26', '26108', '6168026', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '花園岡ノ本町', 'ハナゾノオカノモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区花園円成寺町', '26', '26108', '6168027', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '花園円成寺町', 'ハナゾノエンジョウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区花園鷹司町', '26', '26108', '6168031', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '花園鷹司町', 'ハナゾノタカツカサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区花園馬代町', '26', '26108', '6168032', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '花園馬代町', 'ハナゾノバダイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区花園艮北町', '26', '26108', '6168033', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '花園艮北町', 'ハナゾノコンボクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区花園木辻北町', '26', '26108', '6168034', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '花園木辻北町', 'ハナゾノキツジキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区花園妙心寺町', '26', '26108', '6168035', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '花園妙心寺町', 'ハナゾノミョウシンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区花園寺ノ中町', '26', '26108', '6168036', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '花園寺ノ中町', 'ハナゾノテラノナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区花園猪ノ毛町', '26', '26108', '6168037', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '花園猪ノ毛町', 'ハナゾノイノケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区花園寺ノ前町', '26', '26108', '6168041', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '花園寺ノ前町', 'ハナゾノテラノマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区花園伊町', '26', '26108', '6168042', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '花園伊町', 'ハナゾノイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区花園寺ノ内町', '26', '26108', '6168043', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '花園寺ノ内町', 'ハナゾノテラノウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区花園扇野町', '26', '26108', '6168044', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '花園扇野町', 'ハナゾノオウギノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区花園内畑町', '26', '26108', '6168045', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '花園内畑町', 'ハナゾノウチハタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区花園段ノ岡町', '26', '26108', '6168046', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '花園段ノ岡町', 'ハナゾノダンノオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区花園宮ノ上町', '26', '26108', '6168047', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '花園宮ノ上町', 'ハナゾノミヤノカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区花園巽南町', '26', '26108', '6168051', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '花園巽南町', 'ハナゾノソンナンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区花園薮ノ下町', '26', '26108', '6168052', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '花園薮ノ下町', 'ハナゾノヤブノシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区花園八ツ口町', '26', '26108', '6168053', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '花園八ツ口町', 'ハナゾノヤツクチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区花園中御門町', '26', '26108', '6168054', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '花園中御門町', 'ハナゾノナカミカドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区花園車道町', '26', '26108', '6168055', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '花園車道町', 'ハナゾノクルマミチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区花園坤南町', '26', '26108', '6168056', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '花園坤南町', 'ハナゾノコンナンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区花園木辻南町', '26', '26108', '6168057', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '花園木辻南町', 'ハナゾノキツジミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区花園春日町', '26', '26108', '6168061', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '花園春日町', 'ハナゾノカスガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区太秦安井春日町', '26', '26108', '6168062', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '太秦安井春日町', 'ウズマサヤスイカスガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区太秦安井東裏町', '26', '26108', '6168063', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '太秦安井東裏町', 'ウズマサヤスイヒガシウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区太秦安井北御所町', '26', '26108', '6168064', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '太秦安井北御所町', 'ウズマサヤスイキタゴショチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区太秦安井西裏町', '26', '26108', '6168065', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '太秦安井西裏町', 'ウズマサヤスイニシウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区太秦安井車道町', '26', '26108', '6168066', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '太秦安井車道町', 'ウズマサヤスイクルマミチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区太秦安井小山町', '26', '26108', '6168067', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '太秦安井小山町', 'ウズマサヤスイコヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区太秦安井藤ノ木町', '26', '26108', '6168071', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '太秦安井藤ノ木町', 'ウズマサヤスイフジノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区太秦安井辰巳町', '26', '26108', '6168072', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '太秦安井辰巳町', 'ウズマサヤスイタツミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区太秦安井水戸田町', '26', '26108', '6168073', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '太秦安井水戸田町', 'ウズマサヤスイミトデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区太秦安井二条裏町', '26', '26108', '6168074', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '太秦安井二条裏町', 'ウズマサヤスイニジョウウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区太秦安井柳通町', '26', '26108', '6168075', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '太秦安井柳通町', 'ウズマサヤスイヤナギドオリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区太秦安井辻ノ内町', '26', '26108', '6168076', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '太秦安井辻ノ内町', 'ウズマサヤスイツジノウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区太秦安井馬塚町', '26', '26108', '6168077', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '太秦安井馬塚町', 'ウズマサヤスイウマヅカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区太秦安井池田町', '26', '26108', '6168081', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '太秦安井池田町', 'ウズマサヤスイイケダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区太秦安井奥畑町', '26', '26108', '6168082', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '太秦安井奥畑町', 'ウズマサヤスイオクハタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区太秦安井西沢町', '26', '26108', '6168083', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '太秦安井西沢町', 'ウズマサヤスイニシザワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区太秦安井一町田町', '26', '26108', '6168084', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '太秦安井一町田町', 'ウズマサヤスイイッチョウデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区太秦安井松本町', '26', '26108', '6168085', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '太秦安井松本町', 'ウズマサヤスイマツモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区御室住吉山町', '26', '26108', '6168091', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '御室住吉山町', 'オムロスミヨシヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区御室大内', '26', '26108', '6168092', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '御室大内', 'オムロオオウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区御室竪町', '26', '26108', '6168093', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '御室竪町', 'オムロタテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区御室小松野町', '26', '26108', '6168094', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '御室小松野町', 'オムロコマツノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区御室芝橋町', '26', '26108', '6168095', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '御室芝橋町', 'オムロシバハシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区御室岡ノ裾町', '26', '26108', '6168096', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '御室岡ノ裾町', 'オムロオカノスソチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区御室双岡町', '26', '26108', '6168097', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '御室双岡町', 'オムロナラビガオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区太秦和泉式部町', '26', '26108', '6168101', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '太秦和泉式部町', 'ウズマサイズミシキブチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区太秦森ケ東町', '26', '26108', '6168102', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '太秦森ケ東町', 'ウズマサモリガヒガシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区太秦上刑部町', '26', '26108', '6168103', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '太秦上刑部町', 'ウズマサカミケイブチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区太秦下刑部町', '26', '26108', '6168104', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '太秦下刑部町', 'ウズマサシモケイブチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区太秦森ケ前町', '26', '26108', '6168105', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '太秦森ケ前町', 'ウズマサモリガマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区太秦森ケ西町', '26', '26108', '6168106', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '太秦森ケ西町', 'ウズマサモリガニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区太秦一ノ井町', '26', '26108', '6168107', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '太秦一ノ井町', 'ウズマサイチノイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区太秦下角田町', '26', '26108', '6168111', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '太秦下角田町', 'ウズマサシモカクダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区太秦木ノ下町', '26', '26108', '6168112', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '太秦木ノ下町', 'ウズマサキノシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区太秦野元町', '26', '26108', '6168113', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '太秦野元町', 'ウズマサノモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区太秦巽町', '26', '26108', '6168114', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '太秦巽町', 'ウズマサタツミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区太秦東唐渡町', '26', '26108', '6168115', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '太秦東唐渡町', 'ウズマサヒガシカラトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区太秦松本町', '26', '26108', '6168116', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '太秦松本町', 'ウズマサマツモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区太秦門田町', '26', '26108', '6168117', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '太秦門田町', 'ウズマサモンダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区太秦垣内町', '26', '26108', '6168121', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '太秦垣内町', 'ウズマサカキウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区太秦井戸ケ尻町', '26', '26108', '6168122', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '太秦井戸ケ尻町', 'ウズマサイドガジリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区太秦海正寺町', '26', '26108', '6168123', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '太秦海正寺町', 'ウズマサカイショウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区太秦辻ケ本町', '26', '26108', '6168124', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '太秦辻ケ本町', 'ウズマサツジガモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区太秦組石町', '26', '26108', '6168125', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '太秦組石町', 'ウズマサクミイシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区太秦椙ケ本町', '26', '26108', '6168126', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '太秦椙ケ本町', 'ウズマサスガモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区太秦奥殿町', '26', '26108', '6168127', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '太秦奥殿町', 'ウズマサオクドノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区太秦藤ケ森町', '26', '26108', '6168131', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '太秦藤ケ森町', 'ウズマサフジガモリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区太秦滝ケ花町', '26', '26108', '6168132', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '太秦滝ケ花町', 'ウズマサタキガハナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区太秦中堤町', '26', '26108', '6168133', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '太秦中堤町', 'ウズマサナカツツミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区太秦唐渡町', '26', '26108', '6168134', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '太秦唐渡町', 'ウズマサカラトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区太秦小手角町', '26', '26108', '6168135', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '太秦小手角町', 'ウズマサコテスミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区太秦荒木町', '26', '26108', '6168136', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '太秦荒木町', 'ウズマサアラキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区太秦朱雀町', '26', '26108', '6168137', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '太秦朱雀町', 'ウズマサスジャクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区太秦棚森町', '26', '26108', '6168141', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '太秦棚森町', 'ウズマサタナモリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区太秦樋ノ内町', '26', '26108', '6168142', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '太秦樋ノ内町', 'ウズマサヒノウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区太秦川所町', '26', '26108', '6168143', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '太秦川所町', 'ウズマサカワドコロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区太秦百合ケ本町', '26', '26108', '6168144', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '太秦百合ケ本町', 'ウズマサユリガモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区太秦八反田町', '26', '26108', '6168145', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '太秦八反田町', 'ウズマサハッタンダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区太秦前ノ田町', '26', '26108', '6168146', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '太秦前ノ田町', 'ウズマサマエノダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区太秦土本町', '26', '26108', '6168147', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '太秦土本町', 'ウズマサツチモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区太秦帷子ケ辻町', '26', '26108', '6168151', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '太秦帷子ケ辻町', 'ウズマサカタビラノツジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区太秦堀ケ内町', '26', '26108', '6168152', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '太秦堀ケ内町', 'ウズマサホリガウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区太秦面影町', '26', '26108', '6168153', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '太秦面影町', 'ウズマサオモカゲチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区太秦皆正寺町', '26', '26108', '6168154', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '太秦皆正寺町', 'ウズマサミナセイジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区太秦袴田町', '26', '26108', '6168155', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '太秦袴田町', 'ウズマサハカマダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区太秦西野町', '26', '26108', '6168156', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '太秦西野町', 'ウズマサニシノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区太秦御所ノ内町', '26', '26108', '6168157', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '太秦御所ノ内町', 'ウズマサゴショノウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区太秦東蜂岡町', '26', '26108', '6168161', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '太秦東蜂岡町', 'ウズマサヒガシハチオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区太秦蜂岡町', '26', '26108', '6168162', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '太秦蜂岡町', 'ウズマサハチオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区太秦西蜂岡町', '26', '26108', '6168163', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '太秦西蜂岡町', 'ウズマサニシハチオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区太秦桂木町', '26', '26108', '6168164', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '太秦桂木町', 'ウズマサカツラギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区太秦桂ケ原町', '26', '26108', '6168165', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '太秦桂ケ原町', 'ウズマサカツラガハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区太秦石垣町', '26', '26108', '6168166', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '太秦石垣町', 'ウズマサイシガキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区太秦多薮町', '26', '26108', '6168167', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '太秦多薮町', 'ウズマサタヤブチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区太秦青木ケ原町', '26', '26108', '6168171', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '太秦青木ケ原町', 'ウズマサアオキガハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区太秦青木元町', '26', '26108', '6168172', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '太秦青木元町', 'ウズマサアオキモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区太秦上ノ段町', '26', '26108', '6168173', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '太秦上ノ段町', 'ウズマサカミノダンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区太秦垂箕山町', '26', '26108', '6168174', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '太秦垂箕山町', 'ウズマサタルミヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区太秦一町芝町', '26', '26108', '6168175', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '太秦一町芝町', 'ウズマサイッチョウシバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区太秦乾町', '26', '26108', '6168176', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '太秦乾町', 'ウズマサイヌイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区太秦馬塚町', '26', '26108', '6168177', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '太秦馬塚町', 'ウズマサウマヅカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区太秦京ノ道町', '26', '26108', '6168181', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '太秦京ノ道町', 'ウズマサキョウノミチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区太秦北路町', '26', '26108', '6168182', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '太秦北路町', 'ウズマサキタロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区太秦宮ノ前町', '26', '26108', '6168183', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '太秦宮ノ前町', 'ウズマサミヤノマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区太秦中筋町', '26', '26108', '6168184', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '太秦中筋町', 'ウズマサナカスジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区太秦開日町', '26', '26108', '6168185', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '太秦開日町', 'ウズマサカイニチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区太秦堀池町', '26', '26108', '6168186', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '太秦堀池町', 'ウズマサホリイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区太秦御領田町', '26', '26108', '6168187', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '太秦御領田町', 'ウズマサゴリョウデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区太秦中山町', '26', '26108', '6168191', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '太秦中山町', 'ウズマサナカヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区太秦三尾町', '26', '26108', '6168192', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '太秦三尾町', 'ウズマササンビチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区山越巽町', '26', '26108', '6168193', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '山越巽町', 'ヤマゴエタツミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区山越東町', '26', '26108', '6168194', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '山越東町', 'ヤマゴエヒガシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区山越中町', '26', '26108', '6168195', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '山越中町', 'ヤマゴエナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区山越西町', '26', '26108', '6168196', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '山越西町', 'ヤマゴエニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区山越乾町', '26', '26108', '6168197', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '山越乾町', 'ヤマゴエイヌイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区宇多野北ノ院町', '26', '26108', '6168201', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '宇多野北ノ院町', 'ウタノキタノインチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区宇多野馬場町', '26', '26108', '6168202', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '宇多野馬場町', 'ウタノババチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区宇多野柴橋町', '26', '26108', '6168203', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '宇多野柴橋町', 'ウタノシバハシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区宇多野御池町', '26', '26108', '6168204', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '宇多野御池町', 'ウタノオイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区宇多野御屋敷町', '26', '26108', '6168205', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '宇多野御屋敷町', 'ウタノオヤシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区宇多野法安寺町', '26', '26108', '6168206', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '宇多野法安寺町', 'ウタノホウアンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区宇多野長尾町', '26', '26108', '6168207', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '宇多野長尾町', 'ウタノナガオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区宇多野福王子町', '26', '26108', '6168208', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '宇多野福王子町', 'ウタノフクオウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区宇多野芝町', '26', '26108', '6168209', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '宇多野芝町', 'ウタノシバマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区常盤御池町', '26', '26108', '6168211', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '常盤御池町', 'トキワオイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区常盤山下町', '26', '26108', '6168212', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '常盤山下町', 'トキワヤマシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区常盤音戸町', '26', '26108', '6168213', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '常盤音戸町', 'トキワオントチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区常盤古御所町', '26', '26108', '6168214', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '常盤古御所町', 'トキワフルゴショチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区常盤森町', '26', '26108', '6168215', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '常盤森町', 'トキワモリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区常盤一ノ井町', '26', '26108', '6168216', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '常盤一ノ井町', 'トキワイチノイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区常盤東ノ町', '26', '26108', '6168217', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '常盤東ノ町', 'トキワヒガシノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区常盤出口町', '26', '26108', '6168218', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '常盤出口町', 'トキワデグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区常盤神田町', '26', '26108', '6168219', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '常盤神田町', 'トキワカンダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区常盤村ノ内町', '26', '26108', '6168221', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '常盤村ノ内町', 'トキワムラノウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区常盤仲之町', '26', '26108', '6168222', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '常盤仲之町', 'トキワナカノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区常盤西町', '26', '26108', '6168223', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '常盤西町', 'トキワニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区常盤窪町', '26', '26108', '6168224', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '常盤窪町', 'トキワクボマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区常盤馬塚町', '26', '26108', '6168225', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '常盤馬塚町', 'トキワウマヅカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区常盤段ノ上町', '26', '26108', '6168226', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '常盤段ノ上町', 'トキワダンノウエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区常盤草木町', '26', '26108', '6168227', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '常盤草木町', 'トキワクサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区常盤下田町', '26', '26108', '6168228', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '常盤下田町', 'トキワシモダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区常盤北裏町', '26', '26108', '6168229', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '常盤北裏町', 'トキワキタウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区常盤柏ノ木町', '26', '26108', '6168231', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '常盤柏ノ木町', 'トキワカシノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区鳴滝蓮花寺町', '26', '26108', '6168232', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '鳴滝蓮花寺町', 'ナルタキレンゲジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区鳴滝中道町', '26', '26108', '6168233', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '鳴滝中道町', 'ナルタキナカミチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区鳴滝嵯峨園町', '26', '26108', '6168234', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '鳴滝嵯峨園町', 'ナルタキサガソノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区鳴滝西嵯峨園町', '26', '26108', '6168235', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '鳴滝西嵯峨園町', 'ナルタキニシサガソノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区鳴滝春木町', '26', '26108', '6168236', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '鳴滝春木町', 'ナルタキハルキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区鳴滝瑞穂町', '26', '26108', '6168237', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '鳴滝瑞穂町', 'ナルタキミズホチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区鳴滝桐ケ淵町', '26', '26108', '6168238', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '鳴滝桐ケ淵町', 'ナルタキキリガフチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区鳴滝泉殿町', '26', '26108', '6168241', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '鳴滝泉殿町', 'ナルタキイズミデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区鳴滝本町', '26', '26108', '6168242', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '鳴滝本町', 'ナルタキホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区鳴滝安井殿町', '26', '26108', '6168243', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '鳴滝安井殿町', 'ナルタキヤスイデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区鳴滝藤ノ木町', '26', '26108', '6168244', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '鳴滝藤ノ木町', 'ナルタキフジノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区音戸山山ノ茶屋町', '26', '26108', '6168245', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '音戸山山ノ茶屋町', 'オンドヤマヤマノチャヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区鳴滝川西町', '26', '26108', '6168246', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '鳴滝川西町', 'ナルタキカワニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区鳴滝蓮池町', '26', '26108', '6168247', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '鳴滝蓮池町', 'ナルタキハスイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区鳴滝宇多野谷', '26', '26108', '6168251', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '鳴滝宇多野谷', 'ナルタキウダノタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区宇多野上ノ谷町', '26', '26108', '6168252', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '宇多野上ノ谷町', 'ウタノカミノタニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区鳴滝泉谷町', '26', '26108', '6168253', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '鳴滝泉谷町', 'ナルタキイズミタニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区鳴滝宅間町', '26', '26108', '6168254', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '鳴滝宅間町', 'ナルタキタクマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区鳴滝音戸山町', '26', '26108', '6168255', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '鳴滝音戸山町', 'ナルタキオンドヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区鳴滝松本町', '26', '26108', '6168256', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '鳴滝松本町', 'ナルタキマツモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区鳴滝白砂', '26', '26108', '6168257', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '鳴滝白砂', 'ナルタキシラスナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区鳴滝般若寺町', '26', '26108', '6168258', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '鳴滝般若寺町', 'ナルタキハンニャジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区梅ケ畑高鼻町', '26', '26108', '6168261', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '梅ケ畑高鼻町', 'ウメガハタタカハナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区梅ケ畑向ノ地町', '26', '26108', '6168262', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '梅ケ畑向ノ地町', 'ウメガハタムコウノチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区梅ケ畑畑ノ下町', '26', '26108', '6168263', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '梅ケ畑畑ノ下町', 'ウメガハタハタノシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区梅ケ畑薮ノ下町', '26', '26108', '6168264', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '梅ケ畑薮ノ下町', 'ウメガハタヤブノシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区梅ケ畑畑町', '26', '26108', '6168265', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '梅ケ畑畑町', 'ウメガハタハタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区梅ケ畑中田町', '26', '26108', '6168266', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '梅ケ畑中田町', 'ウメガハタナカタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区梅ケ畑山崎町', '26', '26108', '6168267', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '梅ケ畑山崎町', 'ウメガハタヤマサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区梅ケ畑古田町', '26', '26108', '6168268', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '梅ケ畑古田町', 'ウメガハタフルタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区梅ケ畑宮ノ口町', '26', '26108', '6168271', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '梅ケ畑宮ノ口町', 'ウメガハタミヤノクチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区梅ケ畑猪ノ尻町', '26', '26108', '6168272', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '梅ケ畑猪ノ尻町', 'ウメガハタイノシリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区梅ケ畑中縄手町', '26', '26108', '6168273', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '梅ケ畑中縄手町', 'ウメガハタナカナワテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区梅ケ畑上ノ町', '26', '26108', '6168274', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '梅ケ畑上ノ町', 'ウメガハタウエノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区梅ケ畑篝町', '26', '26108', '6168275', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '梅ケ畑篝町', 'ウメガハタカガリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区梅ケ畑清水町', '26', '26108', '6168276', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '梅ケ畑清水町', 'ウメガハタシミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区梅ケ畑広芝町', '26', '26108', '6168277', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '梅ケ畑広芝町', 'ウメガハタヒロシバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区梅ケ畑菖蒲谷', '26', '26108', '6168278', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '梅ケ畑菖蒲谷', 'ウメガハタショウブタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区梅ケ畑久保谷町', '26', '26108', '6168281', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '梅ケ畑久保谷町', 'ウメガハタクボタニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区梅ケ畑上砥町', '26', '26108', '6168282', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '梅ケ畑上砥町', 'ウメガハタウエトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区梅ケ畑奥殿町', '26', '26108', '6168283', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '梅ケ畑奥殿町', 'ウメガハタオクトノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区梅ケ畑御経坂町', '26', '26108', '6168284', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '梅ケ畑御経坂町', 'ウメガハタミキョウサカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区梅ケ畑檜社町', '26', '26108', '6168285', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '梅ケ畑檜社町', 'ウメガハタヒノキヤシロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区梅ケ畑御所ノ口町', '26', '26108', '6168286', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '梅ケ畑御所ノ口町', 'ウメガハタゴショノグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区梅ケ畑中嶋町', '26', '26108', '6168287', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '梅ケ畑中嶋町', 'ウメガハタナカジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区梅ケ畑笹江辺町', '26', '26108', '6168288', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '梅ケ畑笹江辺町', 'ウメガハタササエベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区梅ケ畑西ノ畑町', '26', '26108', '6168289', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '梅ケ畑西ノ畑町', 'ウメガハタニシノハタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区梅ケ畑槇尾町', '26', '26108', '6168291', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '梅ケ畑槇尾町', 'ウメガハタマキノオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区梅ケ畑高雄町', '26', '26108', '6168292', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '梅ケ畑高雄町', 'ウメガハタタカオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区梅ケ畑殿畑町', '26', '26108', '6168293', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '梅ケ畑殿畑町', 'ウメガハタトノハタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区梅ケ畑引地町', '26', '26108', '6168294', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '梅ケ畑引地町', 'ウメガハタヒキジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区梅ケ畑栂尾町', '26', '26108', '6168295', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '梅ケ畑栂尾町', 'ウメガハタトガノオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区梅ケ畑川西町', '26', '26108', '6168296', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '梅ケ畑川西町', 'ウメガハタカワニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区梅ケ畑亀石町', '26', '26108', '6168297', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '梅ケ畑亀石町', 'ウメガハタカメイシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨広沢町', '26', '26108', '6168301', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨広沢町', 'サガヒロサワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨広沢北下馬野町', '26', '26108', '6168302', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨広沢北下馬野町', 'サガヒロサワキタゲバノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨広沢南下馬野町', '26', '26108', '6168303', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨広沢南下馬野町', 'サガヒロサワミナミゲバノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨広沢南野町', '26', '26108', '6168304', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨広沢南野町', 'サガヒロサワミナミノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨広沢御所ノ内町', '26', '26108', '6168305', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨広沢御所ノ内町', 'サガヒロサワゴショノウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨広沢西裏町', '26', '26108', '6168306', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨広沢西裏町', 'サガヒロサワニシウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨広沢池下町', '26', '26108', '6168307', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨広沢池下町', 'サガヒロサワイケシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨野嵯峨ノ段町', '26', '26108', '6168311', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨野嵯峨ノ段町', 'サガノサガノダンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨野清水町', '26', '26108', '6168312', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨野清水町', 'サガノシミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨野開町', '26', '26108', '6168313', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨野開町', 'サガノヒラキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨野秋街道町', '26', '26108', '6168314', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨野秋街道町', 'サガノアキカイドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨野宮ノ元町', '26', '26108', '6168315', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨野宮ノ元町', 'サガノミヤノモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨野有栖川町', '26', '26108', '6168316', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨野有栖川町', 'サガノアリスガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨野神ノ木町', '26', '26108', '6168317', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨野神ノ木町', 'サガノカミノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨野千代ノ道町', '26', '26108', '6168321', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨野千代ノ道町', 'サガノチヨノミチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨野芝野町', '26', '26108', '6168322', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨野芝野町', 'サガノシバノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨野投渕町', '26', '26108', '6168323', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨野投渕町', 'サガノナゲブチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨野南浦町', '26', '26108', '6168324', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨野南浦町', 'サガノミナミウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨野高田町', '26', '26108', '6168325', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨野高田町', 'サガノタカダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨野東田町', '26', '26108', '6168326', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨野東田町', 'サガノヒガシダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨野六反田町', '26', '26108', '6168327', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨野六反田町', 'サガノロクタンダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨野内田町', '26', '26108', '6168331', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨野内田町', 'サガノウチダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨野北野町', '26', '26108', '6168332', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨野北野町', 'サガノキタノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨野西ノ藤町', '26', '26108', '6168333', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨野西ノ藤町', 'サガノニシノフジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨罧原町', '26', '26108', '6168334', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨罧原町', 'サガフシハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨石ケ坪町', '26', '26108', '6168335', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨石ケ坪町', 'サガイシガツボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨蜻蛉尻町', '26', '26108', '6168336', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨蜻蛉尻町', 'サガトンボジリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨明星町', '26', '26108', '6168337', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨明星町', 'サガミョウジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨甲塚町', '26', '26108', '6168341', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨甲塚町', 'サガカブトヅカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨苅分町', '26', '26108', '6168342', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨苅分町', 'サガカリワケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨朝日町', '26', '26108', '6168343', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨朝日町', 'サガアサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨梅ノ木町', '26', '26108', '6168344', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨梅ノ木町', 'サガウメノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨折戸町', '26', '26108', '6168345', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨折戸町', 'サガオリトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨天龍寺油掛町', '26', '26108', '6168346', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨天龍寺油掛町', 'サガテンリュウジアブラカケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨中又町', '26', '26108', '6168347', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨中又町', 'サガナカマタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨釣殿町', '26', '26108', '6168351', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨釣殿町', 'サガツリドノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨大沢落久保町', '26', '26108', '6168352', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨大沢落久保町', 'サガオオサワオチクボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨大沢柳井手町', '26', '26108', '6168353', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨大沢柳井手町', 'サガオオサワヤナギイデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨一本木町', '26', '26108', '6168354', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨一本木町', 'サガイッポンギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨新宮町', '26', '26108', '6168355', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨新宮町', 'サガシングウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨天龍寺中島町', '26', '26108', '6168356', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨天龍寺中島町', 'サガテンリュウジナカジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨天龍寺椎野町', '26', '26108', '6168357', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨天龍寺椎野町', 'サガテンリュウジシイノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨中通町', '26', '26108', '6168361', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨中通町', 'サガナカドオリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨五島町', '26', '26108', '6168362', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨五島町', 'サガゴトウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨柳田町', '26', '26108', '6168363', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨柳田町', 'サガヤナギダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨中山町', '26', '26108', '6168364', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨中山町', 'サガナカヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨伊勢ノ上町', '26', '26108', '6168365', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨伊勢ノ上町', 'サガイセノカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨天龍寺今堀町', '26', '26108', '6168366', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨天龍寺今堀町', 'サガテンリュウジイマホリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨北堀町', '26', '26108', '6168367', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨北堀町', 'サガキタボリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨天龍寺若宮町', '26', '26108', '6168371', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨天龍寺若宮町', 'サガテンリュウジワカミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨天龍寺広道町', '26', '26108', '6168372', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨天龍寺広道町', 'サガテンリュウジヒロミチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨天龍寺車道町', '26', '26108', '6168373', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨天龍寺車道町', 'サガテンリュウジクルマミチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨天龍寺北造路町', '26', '26108', '6168374', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨天龍寺北造路町', 'サガテンリュウジキタツクリミチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨天龍寺立石町', '26', '26108', '6168375', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨天龍寺立石町', 'サガテンリュウジタテイシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨天龍寺瀬戸川町', '26', '26108', '6168376', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨天龍寺瀬戸川町', 'サガテンリュウジセトガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨天龍寺龍門町', '26', '26108', '6168381', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨天龍寺龍門町', 'サガテンリュウジリュウモンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨天龍寺角倉町', '26', '26108', '6168382', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨天龍寺角倉町', 'サガテンリュウジスミノクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨中之島町', '26', '26108', '6168383', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨中之島町', 'サガナカノシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨天龍寺造路町', '26', '26108', '6168384', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨天龍寺造路町', 'サガテンリュウジツクリミチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨天龍寺芒ノ馬場町', '26', '26108', '6168385', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨天龍寺芒ノ馬場町', 'サガテンリュウジススキノババチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨亀ノ尾町', '26', '26108', '6168386', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨亀ノ尾町', 'サガカメノオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨亀山町', '26', '26108', '6168387', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨亀山町', 'サガカメヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨小倉山緋明神町', '26', '26108', '6168391', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨小倉山緋明神町', 'サガオグラヤマヒノミョウジンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨小倉山堂ノ前町', '26', '26108', '6168392', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨小倉山堂ノ前町', 'サガオグラヤマドウノマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨野々宮町', '26', '26108', '6168393', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨野々宮町', 'サガノノミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨小倉山田渕山町', '26', '26108', '6168394', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨小倉山田渕山町', 'サガオグラヤマタブチヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨小倉山町', '26', '26108', '6168395', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨小倉山町', 'サガオグラヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨小倉山山本町', '26', '26108', '6168396', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨小倉山山本町', 'サガオグラヤマヤマモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨小倉山小倉町', '26', '26108', '6168397', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨小倉山小倉町', 'サガオグラヤマオグラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区北嵯峨長刀坂町', '26', '26108', '6168401', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '北嵯峨長刀坂町', 'キタサガナギナタザカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区北嵯峨六代芝町', '26', '26108', '6168402', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '北嵯峨六代芝町', 'キタサガロクダイシバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区北嵯峨洞ノ内町', '26', '26108', '6168403', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '北嵯峨洞ノ内町', 'キタサガホラノウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区北嵯峨八丈町', '26', '26108', '6168404', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '北嵯峨八丈町', 'キタサガハチジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区北嵯峨名古曽町', '26', '26108', '6168405', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '北嵯峨名古曽町', 'キタサガナコソチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区北嵯峨山王町', '26', '26108', '6168406', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '北嵯峨山王町', 'キタサガサンオウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区北嵯峨赤坂町', '26', '26108', '6168407', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '北嵯峨赤坂町', 'キタサガアカサカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨大沢町', '26', '26108', '6168411', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨大沢町', 'サガオオサワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨大覚寺門前登り町', '26', '26108', '6168412', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨大覚寺門前登り町', 'サガダイカクジモンゼンノボリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨大覚寺門前堂ノ前町', '26', '26108', '6168413', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨大覚寺門前堂ノ前町', 'サガダイカクジモンゼンドウノマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨大覚寺門前八軒町', '26', '26108', '6168414', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨大覚寺門前八軒町', 'サガダイカクジモンゼンハッケンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨大覚寺門前宮ノ下町', '26', '26108', '6168415', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨大覚寺門前宮ノ下町', 'サガダイカクジモンゼンミヤノシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨大覚寺門前井頭町', '26', '26108', '6168416', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨大覚寺門前井頭町', 'サガダイカクジモンゼンイトウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨大覚寺門前六道町', '26', '26108', '6168417', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨大覚寺門前六道町', 'サガダイカクジモンゼンロクドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨釈迦堂門前瀬戸川町', '26', '26108', '6168421', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨釈迦堂門前瀬戸川町', 'サガシャカドウモンゼンセトガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨釈迦堂大門町', '26', '26108', '6168422', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨釈迦堂大門町', 'サガシャカドウダイモンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨釈迦堂門前裏柳町', '26', '26108', '6168423', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨釈迦堂門前裏柳町', 'サガシャカドウモンゼンウラヤナギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨釈迦堂門前南中院町', '26', '26108', '6168424', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨釈迦堂門前南中院町', 'サガシャカドウモンゼンミナミチュウインチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨二尊院門前長神町', '26', '26108', '6168425', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨二尊院門前長神町', 'サガニソンインモンゼンチョウジンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨二尊院門前往生院町', '26', '26108', '6168426', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨二尊院門前往生院町', 'サガニソンインモンゼンオウジョウインチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨二尊院門前善光寺山町', '26', '26108', '6168427', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨二尊院門前善光寺山町', 'サガニソンインモンゼンゼンコウジヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨二尊院門前北中院町', '26', '26108', '6168428', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨二尊院門前北中院町', 'サガニソンインモンゼンキタチュウインチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨鳥居本一華表町', '26', '26108', '6168431', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨鳥居本一華表町', 'サガトリイモトイッカヒョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨鳥居本北代町', '26', '26108', '6168432', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨鳥居本北代町', 'サガトリイモトキタダイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨鳥居本中筋町', '26', '26108', '6168433', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨鳥居本中筋町', 'サガトリイモトナカスジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨鳥居本仏餉田町', '26', '26108', '6168434', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨鳥居本仏餉田町', 'サガトリイモトブツショウデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨鳥居本小坂町', '26', '26108', '6168435', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨鳥居本小坂町', 'サガトリイモトコザカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨鳥居本化野町', '26', '26108', '6168436', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨鳥居本化野町', 'サガトリイモトアダシノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨鳥居本仙翁町', '26', '26108', '6168437', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨鳥居本仙翁町', 'サガトリイモトセンノウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨鳥居本六反町', '26', '26108', '6168438', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨鳥居本六反町', 'サガトリイモトロクタンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨鳥居本深谷町', '26', '26108', '6168439', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨鳥居本深谷町', 'サガトリイモトフカタニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区北嵯峨北ノ段町', '26', '26108', '6168441', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '北嵯峨北ノ段町', 'キタサガキタノダンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区北嵯峨気比社町', '26', '26108', '6168442', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '北嵯峨気比社町', 'キタサガキビシャチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨観空寺明水町', '26', '26108', '6168443', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨観空寺明水町', 'サガカンクウジミョウズイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨観空寺久保殿町', '26', '26108', '6168444', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨観空寺久保殿町', 'サガカンクウジクボデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨観空寺岡崎町', '26', '26108', '6168445', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨観空寺岡崎町', 'サガカンクウジオカザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨観空寺谷町', '26', '26108', '6168446', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨観空寺谷町', 'サガカンクウジダニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨釈迦堂藤ノ木町', '26', '26108', '6168447', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨釈迦堂藤ノ木町', 'サガシャカドウフジノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨清滝一華表町', '26', '26108', '6168451', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨清滝一華表町', 'サガキヨタキイッカヒョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨清滝町', '26', '26108', '6168452', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨清滝町', 'サガキヨタキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨清滝大谷町', '26', '26108', '6168453', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨清滝大谷町', 'サガキヨタキオオタニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨清滝深谷町', '26', '26108', '6168454', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨清滝深谷町', 'サガキヨタキフカタニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨清滝田鶴原町', '26', '26108', '6168455', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨清滝田鶴原町', 'サガキヨタキタヅハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨清滝月ノ輪町', '26', '26108', '6168456', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨清滝月ノ輪町', 'サガキヨタキツキノワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨清滝空也滝町', '26', '26108', '6168457', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨清滝空也滝町', 'サガキヨタキクウヤダキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨愛宕町', '26', '26108', '6168458', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨愛宕町', 'サガアタゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨水尾鳩ケ巣', '26', '26108', '6168461', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨水尾鳩ケ巣', 'サガミズオハトガス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨水尾岡ノ窪町', '26', '26108', '6168462', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨水尾岡ノ窪町', 'サガミズオオカノクボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨水尾竹ノ尻町', '26', '26108', '6168463', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨水尾竹ノ尻町', 'サガミズオタケノシリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨水尾武蔵嶋町', '26', '26108', '6168464', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨水尾武蔵嶋町', 'サガミズオムサシジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨水尾宮ノ脇町', '26', '26108', '6168465', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨水尾宮ノ脇町', 'サガミズオミヤノワキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨水尾清和', '26', '26108', '6168466', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨水尾清和', 'サガミズオセイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨水尾大岩', '26', '26108', '6168467', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨水尾大岩', 'サガミズオオオイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨水尾北垣内町', '26', '26108', '6168468', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨水尾北垣内町', 'サガミズオキタガイチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨樒原稲荷元町', '26', '26108', '6168471', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨樒原稲荷元町', 'サガシキミガハライナリモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨樒原高見町', '26', '26108', '6168472', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨樒原高見町', 'サガシキミガハラタカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨樒原若宮下町', '26', '26108', '6168473', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨樒原若宮下町', 'サガシキミガハラワカミヤシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨樒原清水町', '26', '26108', '6168474', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨樒原清水町', 'サガシキミガハラシミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨樒原宮ノ上町', '26', '26108', '6168475', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨樒原宮ノ上町', 'サガシキミガハラミヤノウエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨越畑桃原', '26', '26108', '6168481', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨越畑桃原', 'サガコシハタモモハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨越畑正権条', '26', '26108', '6168482', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨越畑正権条', 'サガコシハタショウゴンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨越畑鍋浦', '26', '26108', '6168483', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨越畑鍋浦', 'サガコシハタナベウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨越畑筋違', '26', '26108', '6168484', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨越畑筋違', 'サガコシハタスジチガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨越畑兵庫前町', '26', '26108', '6168485', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨越畑兵庫前町', 'サガコシハタヒョウゴマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨越畑南ノ町', '26', '26108', '6168486', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨越畑南ノ町', 'サガコシハタミナミノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨越畑中ノ町', '26', '26108', '6168487', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨越畑中ノ町', 'サガコシハタナカノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨越畑北ノ町', '26', '26108', '6168491', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨越畑北ノ町', 'サガコシハタキタノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨越畑天慶', '26', '26108', '6168492', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨越畑天慶', 'サガコシハタテンケイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨越畑桃原垣内', '26', '26108', '6168493', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨越畑桃原垣内', 'サガコシハタモモハラガイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京都市右京区嵯峨越畑尻谷', '26', '26108', '6168494', '京都府', 'キョウトフ', '京都市右京区', 'キョウトシウキョウク', '嵯峨越畑尻谷', 'サガコシハタシリタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府向日市', '26', '26208', '6170000', '京都府', 'キョウトフ', '向日市', 'ムコウシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('71507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府長岡京市', '26', '26209', '6170000', '京都府', 'キョウトフ', '長岡京市', 'ナガオカキョウシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('71508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府向日市物集女町', '26', '26208', '6170001', '京都府', 'キョウトフ', '向日市', 'ムコウシ', '物集女町', 'モズメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府向日市寺戸町', '26', '26208', '6170002', '京都府', 'キョウトフ', '向日市', 'ムコウシ', '寺戸町', 'テラドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府向日市森本町', '26', '26208', '6170003', '京都府', 'キョウトフ', '向日市', 'ムコウシ', '森本町', 'モリモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府向日市鶏冠井町', '26', '26208', '6170004', '京都府', 'キョウトフ', '向日市', 'ムコウシ', '鶏冠井町', 'カイデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府向日市向日町', '26', '26208', '6170005', '京都府', 'キョウトフ', '向日市', 'ムコウシ', '向日町', 'ムコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府向日市上植野町', '26', '26208', '6170006', '京都府', 'キョウトフ', '向日市', 'ムコウシ', '上植野町', 'カミウエノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府長岡京市粟生', '26', '26209', '6170811', '京都府', 'キョウトフ', '長岡京市', 'ナガオカキョウシ', '粟生', 'アオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府長岡京市長法寺', '26', '26209', '6170812', '京都府', 'キョウトフ', '長岡京市', 'ナガオカキョウシ', '長法寺', 'チョウホウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府長岡京市井ノ内', '26', '26209', '6170813', '京都府', 'キョウトフ', '長岡京市', 'ナガオカキョウシ', '井ノ内', 'イノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府長岡京市今里', '26', '26209', '6170814', '京都府', 'キョウトフ', '長岡京市', 'ナガオカキョウシ', '今里', 'イマザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府長岡京市うぐいす台', '26', '26209', '6170815', '京都府', 'キョウトフ', '長岡京市', 'ナガオカキョウシ', 'うぐいす台', 'ウグイスダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府長岡京市西の京', '26', '26209', '6170816', '京都府', 'キョウトフ', '長岡京市', 'ナガオカキョウシ', '西の京', 'ニシノキョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府長岡京市滝ノ町', '26', '26209', '6170817', '京都府', 'キョウトフ', '長岡京市', 'ナガオカキョウシ', '滝ノ町', 'タキノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府長岡京市柴の里', '26', '26209', '6170818', '京都府', 'キョウトフ', '長岡京市', 'ナガオカキョウシ', '柴の里', 'シバノサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府長岡京市野添', '26', '26209', '6170821', '京都府', 'キョウトフ', '長岡京市', 'ナガオカキョウシ', '野添', 'ノゾエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府長岡京市八条が丘', '26', '26209', '6170822', '京都府', 'キョウトフ', '長岡京市', 'ナガオカキョウシ', '八条が丘', 'ハチジョウガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府長岡京市長岡', '26', '26209', '6170823', '京都府', 'キョウトフ', '長岡京市', 'ナガオカキョウシ', '長岡', 'ナガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府長岡京市天神', '26', '26209', '6170824', '京都府', 'キョウトフ', '長岡京市', 'ナガオカキョウシ', '天神', 'テンジン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府長岡京市一文橋', '26', '26209', '6170825', '京都府', 'キョウトフ', '長岡京市', 'ナガオカキョウシ', '一文橋', 'イチモンバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府長岡京市開田', '26', '26209', '6170826', '京都府', 'キョウトフ', '長岡京市', 'ナガオカキョウシ', '開田', 'カイデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府長岡京市竹の台', '26', '26209', '6170827', '京都府', 'キョウトフ', '長岡京市', 'ナガオカキョウシ', '竹の台', 'タケノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府長岡京市馬場', '26', '26209', '6170828', '京都府', 'キョウトフ', '長岡京市', 'ナガオカキョウシ', '馬場', 'ババ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府長岡京市一里塚', '26', '26209', '6170831', '京都府', 'キョウトフ', '長岡京市', 'ナガオカキョウシ', '一里塚', 'イチリヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府長岡京市東神足', '26', '26209', '6170832', '京都府', 'キョウトフ', '長岡京市', 'ナガオカキョウシ', '東神足', 'ヒガシコウタリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府長岡京市神足', '26', '26209', '6170833', '京都府', 'キョウトフ', '長岡京市', 'ナガオカキョウシ', '神足', 'コウタリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府長岡京市東和苑', '26', '26209', '6170834', '京都府', 'キョウトフ', '長岡京市', 'ナガオカキョウシ', '東和苑', 'トウワエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府長岡京市城の里', '26', '26209', '6170835', '京都府', 'キョウトフ', '長岡京市', 'ナガオカキョウシ', '城の里', 'シロノサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府長岡京市勝竜寺', '26', '26209', '6170836', '京都府', 'キョウトフ', '長岡京市', 'ナガオカキョウシ', '勝竜寺', 'ショウリュウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府長岡京市久貝', '26', '26209', '6170837', '京都府', 'キョウトフ', '長岡京市', 'ナガオカキョウシ', '久貝', 'クガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府長岡京市緑が丘', '26', '26209', '6170838', '京都府', 'キョウトフ', '長岡京市', 'ナガオカキョウシ', '緑が丘', 'ミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府長岡京市梅が丘', '26', '26209', '6170841', '京都府', 'キョウトフ', '長岡京市', 'ナガオカキョウシ', '梅が丘', 'ウメガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府長岡京市花山', '26', '26209', '6170842', '京都府', 'キョウトフ', '長岡京市', 'ナガオカキョウシ', '花山', 'ハナヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府長岡京市友岡', '26', '26209', '6170843', '京都府', 'キョウトフ', '長岡京市', 'ナガオカキョウシ', '友岡', 'トモオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府長岡京市調子', '26', '26209', '6170844', '京都府', 'キョウトフ', '長岡京市', 'ナガオカキョウシ', '調子', 'チョウシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府長岡京市下海印寺', '26', '26209', '6170845', '京都府', 'キョウトフ', '長岡京市', 'ナガオカキョウシ', '下海印寺', 'シモカイインジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府長岡京市泉が丘', '26', '26209', '6170846', '京都府', 'キョウトフ', '長岡京市', 'ナガオカキョウシ', '泉が丘', 'イズミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府長岡京市高台', '26', '26209', '6170847', '京都府', 'キョウトフ', '長岡京市', 'ナガオカキョウシ', '高台', 'タカダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府長岡京市光風台', '26', '26209', '6170851', '京都府', 'キョウトフ', '長岡京市', 'ナガオカキョウシ', '光風台', 'コウフウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府長岡京市河陽が丘', '26', '26209', '6170852', '京都府', 'キョウトフ', '長岡京市', 'ナガオカキョウシ', '河陽が丘', 'カヨウガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府長岡京市奥海印寺', '26', '26209', '6170853', '京都府', 'キョウトフ', '長岡京市', 'ナガオカキョウシ', '奥海印寺', 'オクカイインジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府長岡京市こがねが丘', '26', '26209', '6170854', '京都府', 'キョウトフ', '長岡京市', 'ナガオカキョウシ', 'こがねが丘', 'コガネガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府長岡京市浄土谷', '26', '26209', '6170855', '京都府', 'キョウトフ', '長岡京市', 'ナガオカキョウシ', '浄土谷', 'ジョウドダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府長岡京市金ケ原', '26', '26209', '6170856', '京都府', 'キョウトフ', '長岡京市', 'ナガオカキョウシ', '金ケ原', 'カネガハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府長岡京市高台西', '26', '26209', '6170857', '京都府', 'キョウトフ', '長岡京市', 'ナガオカキョウシ', '高台西', 'タカダイニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府乙訓郡大山崎町', '26', '26303', '6180000', '京都府', 'キョウトフ', '乙訓郡大山崎町', 'オトクニグンオオヤマザキチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('71565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府三島郡島本町', '27', '27301', '6180000', '大阪府', 'オオサカフ', '三島郡島本町', 'ミシマグンシマモトチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('71566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府三島郡島本町山崎', '27', '27301', '6180001', '大阪府', 'オオサカフ', '三島郡島本町', 'ミシマグンシマモトチョウ', '山崎', 'ヤマザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府三島郡島本町東大寺', '27', '27301', '6180002', '大阪府', 'オオサカフ', '三島郡島本町', 'ミシマグンシマモトチョウ', '東大寺', 'トウダイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府三島郡島本町尺代', '27', '27301', '6180003', '大阪府', 'オオサカフ', '三島郡島本町', 'ミシマグンシマモトチョウ', '尺代', 'シャクダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府三島郡島本町大沢', '27', '27301', '6180004', '大阪府', 'オオサカフ', '三島郡島本町', 'ミシマグンシマモトチョウ', '大沢', 'オオサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府三島郡島本町広瀬', '27', '27301', '6180011', '大阪府', 'オオサカフ', '三島郡島本町', 'ミシマグンシマモトチョウ', '広瀬', 'ヒロセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府三島郡島本町高浜', '27', '27301', '6180012', '大阪府', 'オオサカフ', '三島郡島本町', 'ミシマグンシマモトチョウ', '高浜', 'タカハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府三島郡島本町江川', '27', '27301', '6180013', '大阪府', 'オオサカフ', '三島郡島本町', 'ミシマグンシマモトチョウ', '江川', 'エガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府三島郡島本町水無瀬', '27', '27301', '6180014', '大阪府', 'オオサカフ', '三島郡島本町', 'ミシマグンシマモトチョウ', '水無瀬', 'ミナセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府三島郡島本町青葉', '27', '27301', '6180015', '大阪府', 'オオサカフ', '三島郡島本町', 'ミシマグンシマモトチョウ', '青葉', 'アオバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府三島郡島本町百山', '27', '27301', '6180021', '大阪府', 'オオサカフ', '三島郡島本町', 'ミシマグンシマモトチョウ', '百山', 'ヒャクヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府三島郡島本町桜井', '27', '27301', '6180022', '大阪府', 'オオサカフ', '三島郡島本町', 'ミシマグンシマモトチョウ', '桜井', 'サクライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府三島郡島本町桜井台', '27', '27301', '6180023', '大阪府', 'オオサカフ', '三島郡島本町', 'ミシマグンシマモトチョウ', '桜井台', 'サクライダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府三島郡島本町若山台', '27', '27301', '6180024', '大阪府', 'オオサカフ', '三島郡島本町', 'ミシマグンシマモトチョウ', '若山台', 'ワカヤマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府乙訓郡大山崎町大山崎', '26', '26303', '6180071', '京都府', 'キョウトフ', '乙訓郡大山崎町', 'オトクニグンオオヤマザキチョウ', '大山崎', 'オオヤマザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府乙訓郡大山崎町下植野', '26', '26303', '6180081', '京都府', 'キョウトフ', '乙訓郡大山崎町', 'オトクニグンオオヤマザキチョウ', '下植野', 'シモウエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府乙訓郡大山崎町円明寺', '26', '26303', '6180091', '京都府', 'キョウトフ', '乙訓郡大山崎町', 'オトクニグンオオヤマザキチョウ', '円明寺', 'エンミョウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府木津川市', '26', '26214', '6190200', '京都府', 'キョウトフ', '木津川市', 'キヅガワシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('71593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府相楽郡精華町', '26', '26366', '6190200', '京都府', 'キョウトフ', '相楽郡精華町', 'ソウラクグンセイカチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('71594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府木津川市山城町綺田', '26', '26214', '6190201', '京都府', 'キョウトフ', '木津川市', 'キヅガワシ', '山城町綺田', 'ヤマシロチョウカバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府木津川市山城町平尾', '26', '26214', '6190202', '京都府', 'キョウトフ', '木津川市', 'キヅガワシ', '山城町平尾', 'ヤマシロチョウヒラオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府木津川市山城町神童子', '26', '26214', '6190203', '京都府', 'キョウトフ', '木津川市', 'キヅガワシ', '山城町神童子', 'ヤマシロチョウジンドウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府木津川市山城町上狛', '26', '26214', '6190204', '京都府', 'キョウトフ', '木津川市', 'キヅガワシ', '山城町上狛', 'ヤマシロチョウカミコマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府木津川市山城町椿井', '26', '26214', '6190205', '京都府', 'キョウトフ', '木津川市', 'キヅガワシ', '山城町椿井', 'ヤマシロチョウツバイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府木津川市山城町北河原', '26', '26214', '6190206', '京都府', 'キョウトフ', '木津川市', 'キヅガワシ', '山城町北河原', 'ヤマシロチョウキタガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府木津川市鹿背山', '26', '26214', '6190211', '京都府', 'キョウトフ', '木津川市', 'キヅガワシ', '鹿背山', 'カセヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府木津川市梅谷', '26', '26214', '6190212', '京都府', 'キョウトフ', '木津川市', 'キヅガワシ', '梅谷', 'ウメダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府木津川市市坂', '26', '26214', '6190213', '京都府', 'キョウトフ', '木津川市', 'キヅガワシ', '市坂', 'イチサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府木津川市木津', '26', '26214', '6190214', '京都府', 'キョウトフ', '木津川市', 'キヅガワシ', '木津', 'キヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府木津川市梅美台', '26', '26214', '6190215', '京都府', 'キョウトフ', '木津川市', 'キヅガワシ', '梅美台', 'ウメミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府木津川市州見台', '26', '26214', '6190216', '京都府', 'キョウトフ', '木津川市', 'キヅガワシ', '州見台', 'クニミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府木津川市木津町', '26', '26214', '6190217', '京都府', 'キョウトフ', '木津川市', 'キヅガワシ', '木津町', 'キヅマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府木津川市吐師', '26', '26214', '6190221', '京都府', 'キョウトフ', '木津川市', 'キヅガワシ', '吐師', 'ハゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府木津川市相楽', '26', '26214', '6190222', '京都府', 'キョウトフ', '木津川市', 'キヅガワシ', '相楽', 'サガナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府木津川市相楽台', '26', '26214', '6190223', '京都府', 'キョウトフ', '木津川市', 'キヅガワシ', '相楽台', 'サガナカダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府木津川市兜台', '26', '26214', '6190224', '京都府', 'キョウトフ', '木津川市', 'キヅガワシ', '兜台', 'カブトダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府木津川市木津川台', '26', '26214', '6190225', '京都府', 'キョウトフ', '木津川市', 'キヅガワシ', '木津川台', 'キヅガワダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府相楽郡精華町山田', '26', '26366', '6190231', '京都府', 'キョウトフ', '相楽郡精華町', 'ソウラクグンセイカチョウ', '山田', 'ヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府相楽郡精華町桜が丘', '26', '26366', '6190232', '京都府', 'キョウトフ', '相楽郡精華町', 'ソウラクグンセイカチョウ', '桜が丘', 'サクラガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府相楽郡精華町乾谷', '26', '26366', '6190233', '京都府', 'キョウトフ', '相楽郡精華町', 'ソウラクグンセイカチョウ', '乾谷', 'イヌイダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府相楽郡精華町柘榴', '26', '26366', '6190234', '京都府', 'キョウトフ', '相楽郡精華町', 'ソウラクグンセイカチョウ', '柘榴', 'ザクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府相楽郡精華町東畑', '26', '26366', '6190235', '京都府', 'キョウトフ', '相楽郡精華町', 'ソウラクグンセイカチョウ', '東畑', 'ヒガシバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府相楽郡精華町植田', '26', '26366', '6190236', '京都府', 'キョウトフ', '相楽郡精華町', 'ソウラクグンセイカチョウ', '植田', 'ウエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府相楽郡精華町光台', '26', '26366', '6190237', '京都府', 'キョウトフ', '相楽郡精華町', 'ソウラクグンセイカチョウ', '光台', 'ヒカリダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府相楽郡精華町精華台', '26', '26366', '6190238', '京都府', 'キョウトフ', '相楽郡精華町', 'ソウラクグンセイカチョウ', '精華台', 'セイカダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府相楽郡精華町祝園西', '26', '26366', '6190240', '京都府', 'キョウトフ', '相楽郡精華町', 'ソウラクグンセイカチョウ', '祝園西', 'ホウソノニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府相楽郡精華町祝園', '26', '26366', '6190241', '京都府', 'キョウトフ', '相楽郡精華町', 'ソウラクグンセイカチョウ', '祝園', 'ホウソノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府相楽郡精華町菅井', '26', '26366', '6190242', '京都府', 'キョウトフ', '相楽郡精華町', 'ソウラクグンセイカチョウ', '菅井', 'スガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府相楽郡精華町南稲八妻', '26', '26366', '6190243', '京都府', 'キョウトフ', '相楽郡精華町', 'ソウラクグンセイカチョウ', '南稲八妻', 'ミナミイナヤヅマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府相楽郡精華町北稲八間', '26', '26366', '6190244', '京都府', 'キョウトフ', '相楽郡精華町', 'ソウラクグンセイカチョウ', '北稲八間', 'キタイナヤヅマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府相楽郡精華町下狛', '26', '26366', '6190245', '京都府', 'キョウトフ', '相楽郡精華町', 'ソウラクグンセイカチョウ', '下狛', 'シモコマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府相楽郡精華町菱田', '26', '26366', '6190246', '京都府', 'キョウトフ', '相楽郡精華町', 'ソウラクグンセイカチョウ', '菱田', 'ヒシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府木津川市加茂町銭司', '26', '26214', '6191101', '京都府', 'キョウトフ', '木津川市', 'キヅガワシ', '加茂町銭司', 'カモチョウゼズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府木津川市加茂町井平尾', '26', '26214', '6191102', '京都府', 'キョウトフ', '木津川市', 'キヅガワシ', '加茂町井平尾', 'カモチョウイビラオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府木津川市加茂町岡崎', '26', '26214', '6191103', '京都府', 'キョウトフ', '木津川市', 'キヅガワシ', '加茂町岡崎', 'カモチョウオカザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府木津川市加茂町河原', '26', '26214', '6191104', '京都府', 'キョウトフ', '木津川市', 'キヅガワシ', '加茂町河原', 'カモチョウカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府木津川市加茂町西', '26', '26214', '6191105', '京都府', 'キョウトフ', '木津川市', 'キヅガワシ', '加茂町西', 'カモチョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府木津川市加茂町例幣', '26', '26214', '6191106', '京都府', 'キョウトフ', '木津川市', 'キヅガワシ', '加茂町例幣', 'カモチョウレイヘイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府木津川市加茂町奥畑', '26', '26214', '6191107', '京都府', 'キョウトフ', '木津川市', 'キヅガワシ', '加茂町奥畑', 'カモチョウオクハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府木津川市加茂町山田', '26', '26214', '6191111', '京都府', 'キョウトフ', '木津川市', 'キヅガワシ', '加茂町山田', 'カモチョウヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府木津川市加茂町兎並', '26', '26214', '6191112', '京都府', 'キョウトフ', '木津川市', 'キヅガワシ', '加茂町兎並', 'カモチョウウナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府木津川市加茂町北', '26', '26214', '6191113', '京都府', 'キョウトフ', '木津川市', 'キヅガワシ', '加茂町北', 'カモチョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府木津川市加茂町北下手', '26', '26214', '6191121', '京都府', 'キョウトフ', '木津川市', 'キヅガワシ', '加茂町北下手', 'カモチョウキタシモデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府木津川市加茂町南下手', '26', '26214', '6191122', '京都府', 'キョウトフ', '木津川市', 'キヅガワシ', '加茂町南下手', 'カモチョウミナミシモデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府木津川市加茂町森', '26', '26214', '6191123', '京都府', 'キョウトフ', '木津川市', 'キヅガワシ', '加茂町森', 'カモチョウモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府木津川市加茂町勝風', '26', '26214', '6191124', '京都府', 'キョウトフ', '木津川市', 'キヅガワシ', '加茂町勝風', 'カモチョウショウブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府木津川市加茂町高去', '26', '26214', '6191125', '京都府', 'キョウトフ', '木津川市', 'キヅガワシ', '加茂町高去', 'カモチョウタカサリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府木津川市加茂町尻枝', '26', '26214', '6191126', '京都府', 'キョウトフ', '木津川市', 'キヅガワシ', '加茂町尻枝', 'カモチョウシリエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府木津川市南加茂台', '26', '26214', '6191127', '京都府', 'キョウトフ', '木津川市', 'キヅガワシ', '南加茂台', 'ナガモダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府木津川市加茂町辻', '26', '26214', '6191131', '京都府', 'キョウトフ', '木津川市', 'キヅガワシ', '加茂町辻', 'カモチョウツジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府木津川市加茂町大畑', '26', '26214', '6191132', '京都府', 'キョウトフ', '木津川市', 'キヅガワシ', '加茂町大畑', 'カモチョウオオハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府木津川市加茂町岩船', '26', '26214', '6191133', '京都府', 'キョウトフ', '木津川市', 'キヅガワシ', '加茂町岩船', 'カモチョウイワフネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府木津川市加茂町東小上', '26', '26214', '6191134', '京都府', 'キョウトフ', '木津川市', 'キヅガワシ', '加茂町東小上', 'カモチョウヒガシオカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府木津川市加茂町東小下', '26', '26214', '6191134', '京都府', 'キョウトフ', '木津川市', 'キヅガワシ', '加茂町東小下', 'カモチョウヒガシオシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府木津川市加茂町西小', '26', '26214', '6191135', '京都府', 'キョウトフ', '木津川市', 'キヅガワシ', '加茂町西小', 'カモチョウニシオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府木津川市加茂町北大門', '26', '26214', '6191136', '京都府', 'キョウトフ', '木津川市', 'キヅガワシ', '加茂町北大門', 'カモチョウキタダイモン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府木津川市加茂町南大門', '26', '26214', '6191136', '京都府', 'キョウトフ', '木津川市', 'キヅガワシ', '加茂町南大門', 'カモチョウミナミダイモン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府木津川市加茂町法花寺野', '26', '26214', '6191141', '京都府', 'キョウトフ', '木津川市', 'キヅガワシ', '加茂町法花寺野', 'カモチョウホッケジノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府木津川市加茂町大野', '26', '26214', '6191142', '京都府', 'キョウトフ', '木津川市', 'キヅガワシ', '加茂町大野', 'カモチョウオオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府木津川市加茂町観音寺', '26', '26214', '6191143', '京都府', 'キョウトフ', '木津川市', 'キヅガワシ', '加茂町観音寺', 'カモチョウカンオンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府木津川市加茂町高田', '26', '26214', '6191144', '京都府', 'キョウトフ', '木津川市', 'キヅガワシ', '加茂町高田', 'カモチョウタカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府木津川市加茂町美浪', '26', '26214', '6191151', '京都府', 'キョウトフ', '木津川市', 'キヅガワシ', '加茂町美浪', 'カモチョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府木津川市加茂町里', '26', '26214', '6191152', '京都府', 'キョウトフ', '木津川市', 'キヅガワシ', '加茂町里', 'カモチョウサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府木津川市加茂町駅西', '26', '26214', '6191153', '京都府', 'キョウトフ', '木津川市', 'キヅガワシ', '加茂町駅西', 'カモチョウエキニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府木津川市加茂町駅東', '26', '26214', '6191154', '京都府', 'キョウトフ', '木津川市', 'キヅガワシ', '加茂町駅東', 'カモチョウエキヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府相楽郡和束町', '26', '26365', '6191200', '京都府', 'キョウトフ', '相楽郡和束町', 'ソウラクグンワヅカチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('71672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府相楽郡和束町園', '26', '26365', '6191201', '京都府', 'キョウトフ', '相楽郡和束町', 'ソウラクグンワヅカチョウ', '園', 'ソノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府相楽郡和束町原山', '26', '26365', '6191202', '京都府', 'キョウトフ', '相楽郡和束町', 'ソウラクグンワヅカチョウ', '原山', 'ハラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府相楽郡和束町湯船', '26', '26365', '6191203', '京都府', 'キョウトフ', '相楽郡和束町', 'ソウラクグンワヅカチョウ', '湯船', 'ユブネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府相楽郡和束町門前', '26', '26365', '6191204', '京都府', 'キョウトフ', '相楽郡和束町', 'ソウラクグンワヅカチョウ', '門前', 'モンゼン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府相楽郡和束町中', '26', '26365', '6191205', '京都府', 'キョウトフ', '相楽郡和束町', 'ソウラクグンワヅカチョウ', '中', 'ナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府相楽郡和束町別所', '26', '26365', '6191211', '京都府', 'キョウトフ', '相楽郡和束町', 'ソウラクグンワヅカチョウ', '別所', 'ベッショ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府相楽郡和束町釜塚', '26', '26365', '6191212', '京都府', 'キョウトフ', '相楽郡和束町', 'ソウラクグンワヅカチョウ', '釜塚', 'カマツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府相楽郡和束町南', '26', '26365', '6191213', '京都府', 'キョウトフ', '相楽郡和束町', 'ソウラクグンワヅカチョウ', '南', 'ミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府相楽郡和束町石寺', '26', '26365', '6191221', '京都府', 'キョウトフ', '相楽郡和束町', 'ソウラクグンワヅカチョウ', '石寺', 'イシテラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府相楽郡和束町白栖', '26', '26365', '6191222', '京都府', 'キョウトフ', '相楽郡和束町', 'ソウラクグンワヅカチョウ', '白栖', 'シラス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府相楽郡和束町杣田', '26', '26365', '6191223', '京都府', 'キョウトフ', '相楽郡和束町', 'ソウラクグンワヅカチョウ', '杣田', 'ソマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府相楽郡和束町木屋', '26', '26365', '6191224', '京都府', 'キョウトフ', '相楽郡和束町', 'ソウラクグンワヅカチョウ', '木屋', 'コヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府相楽郡和束町撰原', '26', '26365', '6191225', '京都府', 'キョウトフ', '相楽郡和束町', 'ソウラクグンワヅカチョウ', '撰原', 'エリハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府相楽郡和束町下島', '26', '26365', '6191226', '京都府', 'キョウトフ', '相楽郡和束町', 'ソウラクグンワヅカチョウ', '下島', 'シモジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府相楽郡笠置町', '26', '26364', '6191300', '京都府', 'キョウトフ', '相楽郡笠置町', 'ソウラクグンカサギチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('71688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府相楽郡笠置町有市', '26', '26364', '6191301', '京都府', 'キョウトフ', '相楽郡笠置町', 'ソウラクグンカサギチョウ', '有市', 'アリイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府相楽郡笠置町飛鳥路', '26', '26364', '6191302', '京都府', 'キョウトフ', '相楽郡笠置町', 'ソウラクグンカサギチョウ', '飛鳥路', 'アスカジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府相楽郡笠置町笠置', '26', '26364', '6191303', '京都府', 'キョウトフ', '相楽郡笠置町', 'ソウラクグンカサギチョウ', '笠置', 'カサギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府相楽郡笠置町切山', '26', '26364', '6191304', '京都府', 'キョウトフ', '相楽郡笠置町', 'ソウラクグンカサギチョウ', '切山', 'キリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府相楽郡南山城村', '26', '26367', '6191400', '京都府', 'キョウトフ', '相楽郡南山城村', 'ソウラクグンミナミヤマシロムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('71694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府相楽郡南山城村童仙房', '26', '26367', '6191401', '京都府', 'キョウトフ', '相楽郡南山城村', 'ソウラクグンミナミヤマシロムラ', '童仙房', 'ドウセンボウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府相楽郡南山城村野殿', '26', '26367', '6191402', '京都府', 'キョウトフ', '相楽郡南山城村', 'ソウラクグンミナミヤマシロムラ', '野殿', 'ノドノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府相楽郡南山城村北大河原', '26', '26367', '6191411', '京都府', 'キョウトフ', '相楽郡南山城村', 'ソウラクグンミナミヤマシロムラ', '北大河原', 'キタオオカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府相楽郡南山城村南大河原', '26', '26367', '6191412', '京都府', 'キョウトフ', '相楽郡南山城村', 'ソウラクグンミナミヤマシロムラ', '南大河原', 'ミナミオオカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府相楽郡南山城村田山', '26', '26367', '6191421', '京都府', 'キョウトフ', '相楽郡南山城村', 'ソウラクグンミナミヤマシロムラ', '田山', 'タヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府相楽郡南山城村高尾', '26', '26367', '6191422', '京都府', 'キョウトフ', '相楽郡南山城村', 'ソウラクグンミナミヤマシロムラ', '高尾', 'タカオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市豊平区', '01', '01105', '0620000', '北海道', 'ホッカイドウ', '札幌市豊平区', 'サッポロシトヨヒラク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('71701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市', '26', '26201', '6200000', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('71702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市山野口', '26', '26201', '6200001', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '山野口', 'ヤマノクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市報恩寺', '26', '26201', '6200002', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '報恩寺', 'ホオジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市私市', '26', '26201', '6200003', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '私市', 'キサイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市川北', '26', '26201', '6200004', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '川北', 'カワギタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市印内', '26', '26201', '6200005', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '印内', 'インナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市豊平区美園1条', '01', '01105', '0620001', '北海道', 'ホッカイドウ', '札幌市豊平区', 'サッポロシトヨヒラク', '美園1条', 'ミソノ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市筈巻', '26', '26201', '6200011', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '筈巻', 'ハズマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市安井', '26', '26201', '6200012', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '安井', 'ヤスイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市池部', '26', '26201', '6200013', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '池部', 'イケベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市中', '26', '26201', '6200014', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '中', 'ナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市下猪崎', '26', '26201', '6200015', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '下猪崎', 'シモイザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市城山', '26', '26201', '6200016', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '城山', 'シロヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市猪崎', '26', '26201', '6200017', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '猪崎', 'イザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市豊平区美園2条', '01', '01105', '0620002', '北海道', 'ホッカイドウ', '札幌市豊平区', 'サッポロシトヨヒラク', '美園2条', 'ミソノ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市寺', '26', '26201', '6200021', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '寺', 'テラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市下柳', '26', '26201', '6200022', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '下柳', 'シモヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市菱屋', '26', '26201', '6200023', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '菱屋', 'ヒシヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市東長町', '26', '26201', '6200024', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '東長町', 'ヒガシナガマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市西長町', '26', '26201', '6200025', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '西長町', 'ニシナガマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市呉服', '26', '26201', '6200026', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '呉服', 'ゴフク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市京', '26', '26201', '6200027', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '京', 'キョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市上新', '26', '26201', '6200028', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '上新', 'カミシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市下新', '26', '26201', '6200029', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '下新', 'シモシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市豊平区美園3条', '01', '01105', '0620003', '北海道', 'ホッカイドウ', '札幌市豊平区', 'サッポロシトヨヒラク', '美園3条', 'ミソノ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市鋳物師', '26', '26201', '6200031', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '鋳物師', 'イモジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市下紺屋', '26', '26201', '6200032', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '下紺屋', 'シモコヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市上紺屋', '26', '26201', '6200033', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '上紺屋', 'カミコヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市鍛冶', '26', '26201', '6200034', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '鍛冶', 'カジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市内記', '26', '26201', '6200035', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '内記', 'ナイキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市中ノ町', '26', '26201', '6200036', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '中ノ町', 'ナカノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市東中ノ町', '26', '26201', '6200037', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '東中ノ町', 'ヒガシナカノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市西中ノ町', '26', '26201', '6200038', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '西中ノ町', 'ニシナカノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市西町', '26', '26201', '6200039', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '西町', 'ニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市豊平区美園4条', '01', '01105', '0620004', '北海道', 'ホッカイドウ', '札幌市豊平区', 'サッポロシトヨヒラク', '美園4条', 'ミソノ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市北本町一区', '26', '26201', '6200041', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '北本町一区', 'キタホンマチイック', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市北本町二区', '26', '26201', '6200042', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '北本町二区', 'キタホンマチニク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市北栄町', '26', '26201', '6200043', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '北栄町', 'キタサカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市南栄町', '26', '26201', '6200044', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '南栄町', 'ミナミサカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市駅前町', '26', '26201', '6200045', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '駅前町', 'エキマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市南本町', '26', '26201', '6200046', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '南本町', 'ミナミホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市東本町', '26', '26201', '6200047', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '東本町', 'ヒガシホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市豊平区美園5条', '01', '01105', '0620005', '北海道', 'ホッカイドウ', '札幌市豊平区', 'サッポロシトヨヒラク', '美園5条', 'ミソノ05ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市昭和新町', '26', '26201', '6200051', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '昭和新町', 'ショウワシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市昭和町', '26', '26201', '6200052', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '昭和町', 'ショウワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市西本町', '26', '26201', '6200053', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '西本町', 'ニシホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市末広町', '26', '26201', '6200054', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '末広町', 'スエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市篠尾新町', '26', '26201', '6200055', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '篠尾新町', 'サソオシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市厚中町', '26', '26201', '6200056', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '厚中町', 'アツナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市問屋町', '26', '26201', '6200057', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '問屋町', 'トンヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市厚', '26', '26201', '6200058', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '厚', 'アツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市厚東町', '26', '26201', '6200059', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '厚東町', 'アツヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市豊平区美園6条', '01', '01105', '0620006', '北海道', 'ホッカイドウ', '札幌市豊平区', 'サッポロシトヨヒラク', '美園6条', 'ミソノ06ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市荒河東町', '26', '26201', '6200061', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '荒河東町', 'アラガヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市和久市町', '26', '26201', '6200062', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '和久市町', 'ワクイチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市荒河新町', '26', '26201', '6200063', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '荒河新町', 'アラガシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市岩井東町', '26', '26201', '6200064', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '岩井東町', 'イワイヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市上荒河', '26', '26201', '6200065', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '上荒河', 'カミアラガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市下荒河', '26', '26201', '6200066', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '下荒河', 'シモアラガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市豊平区美園7条', '01', '01105', '0620007', '北海道', 'ホッカイドウ', '札幌市豊平区', 'サッポロシトヨヒラク', '美園7条', 'ミソノ07ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市一尾', '26', '26201', '6200071', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '一尾', 'イチオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市下天津', '26', '26201', '6200072', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '下天津', 'シモアマヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市勅使', '26', '26201', '6200073', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '勅使', 'チョクシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市石本', '26', '26201', '6200074', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '石本', 'イシモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市波江', '26', '26201', '6200075', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '波江', 'ハエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市漆端', '26', '26201', '6200076', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '漆端', 'ウルシガハナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市大呂', '26', '26201', '6200077', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '大呂', 'オオロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市瘤木', '26', '26201', '6200078', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '瘤木', 'コブノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市豊平区美園8条', '01', '01105', '0620008', '北海道', 'ホッカイドウ', '札幌市豊平区', 'サッポロシトヨヒラク', '美園8条', 'ミソノ08ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市豊平区美園9条', '01', '01105', '0620009', '北海道', 'ホッカイドウ', '札幌市豊平区', 'サッポロシトヨヒラク', '美園9条', 'ミソノ09ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市豊平区美園10条', '01', '01105', '0620010', '北海道', 'ホッカイドウ', '札幌市豊平区', 'サッポロシトヨヒラク', '美園10条', 'ミソノ10ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市豊平区美園11条', '01', '01105', '0620011', '北海道', 'ホッカイドウ', '札幌市豊平区', 'サッポロシトヨヒラク', '美園11条', 'ミソノ11ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市豊平区美園12条', '01', '01105', '0620012', '北海道', 'ホッカイドウ', '札幌市豊平区', 'サッポロシトヨヒラク', '美園12条', 'ミソノ12ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市豊平区月寒中央通', '01', '01105', '0620020', '北海道', 'ホッカイドウ', '札幌市豊平区', 'サッポロシトヨヒラク', '月寒中央通', 'ツキサムチュウオウドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市天座', '26', '26201', '6200201', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '天座', 'アマザ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市豊平区月寒西1条', '01', '01105', '0620021', '北海道', 'ホッカイドウ', '札幌市豊平区', 'サッポロシトヨヒラク', '月寒西1条', 'ツキサムニシ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市下野条', '26', '26201', '6200211', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '下野条', 'シモノウジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市行積', '26', '26201', '6200212', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '行積', 'イツモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市長尾', '26', '26201', '6200213', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '長尾', 'ナガオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市上野条', '26', '26201', '6200214', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '上野条', 'カミノウジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市豊平区月寒西2条', '01', '01105', '0620022', '北海道', 'ホッカイドウ', '札幌市豊平区', 'サッポロシトヨヒラク', '月寒西2条', 'ツキサムニシ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市雲原', '26', '26201', '6200221', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '雲原', 'クモハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市豊平区月寒西3条', '01', '01105', '0620023', '北海道', 'ホッカイドウ', '札幌市豊平区', 'サッポロシトヨヒラク', '月寒西3条', 'ツキサムニシ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市豊平区月寒西4条', '01', '01105', '0620024', '北海道', 'ホッカイドウ', '札幌市豊平区', 'サッポロシトヨヒラク', '月寒西4条', 'ツキサムニシ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市豊平区月寒西5条', '01', '01105', '0620025', '北海道', 'ホッカイドウ', '札幌市豊平区', 'サッポロシトヨヒラク', '月寒西5条', 'ツキサムニシ05ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市大江町河守', '26', '26201', '6200301', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '大江町河守', 'オオエチョウコウモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市大江町関', '26', '26201', '6200302', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '大江町関', 'オオエチョウセキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市大江町金屋', '26', '26201', '6200303', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '大江町金屋', 'オオエチョウカナヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市大江町上野', '26', '26201', '6200304', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '大江町上野', 'オオエチョウウエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市大江町波美', '26', '26201', '6200305', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '大江町波美', 'オオエチョウハビ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市豊平区西岡1条', '01', '01105', '0620031', '北海道', 'ホッカイドウ', '札幌市豊平区', 'サッポロシトヨヒラク', '西岡1条', 'ニシオカ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市大江町蓼原', '26', '26201', '6200311', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '大江町蓼原', 'オオエチョウタデワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市大江町公庄', '26', '26201', '6200312', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '大江町公庄', 'オオエチョウグジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市大江町日藤', '26', '26201', '6200313', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '大江町日藤', 'オオエチョウヒトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市大江町小原田', '26', '26201', '6200314', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '大江町小原田', 'オオエチョウオワラタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市豊平区西岡2条', '01', '01105', '0620032', '北海道', 'ホッカイドウ', '札幌市豊平区', 'サッポロシトヨヒラク', '西岡2条', 'ニシオカ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市大江町仏性寺', '26', '26201', '6200321', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '大江町仏性寺', 'オオエチョウブツショウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市大江町毛原', '26', '26201', '6200322', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '大江町毛原', 'オオエチョウケワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市大江町内宮', '26', '26201', '6200323', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '大江町内宮', 'オオエチョウナイク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市大江町二俣', '26', '26201', '6200324', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '大江町二俣', 'オオエチョウフタマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市大江町天田内', '26', '26201', '6200325', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '大江町天田内', 'オオエチョウアマダウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市大江町橋谷', '26', '26201', '6200326', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '大江町橋谷', 'オオエチョウハシダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市大江町北原', '26', '26201', '6200327', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '大江町北原', 'オオエチョウキタバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市豊平区西岡3条', '01', '01105', '0620033', '北海道', 'ホッカイドウ', '札幌市豊平区', 'サッポロシトヨヒラク', '西岡3条', 'ニシオカ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市大江町三河', '26', '26201', '6200331', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '大江町三河', 'オオエチョウソウゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市大江町高津江', '26', '26201', '6200332', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '大江町高津江', 'オオエチョウタカツエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市大江町二箇', '26', '26201', '6200333', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '大江町二箇', 'オオエチョウニカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市大江町市原谷', '26', '26201', '6200334', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '大江町市原谷', 'オオエチョウイチワラダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市豊平区西岡4条', '01', '01105', '0620034', '北海道', 'ホッカイドウ', '札幌市豊平区', 'サッポロシトヨヒラク', '西岡4条', 'ニシオカ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市大江町北有路', '26', '26201', '6200341', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '大江町北有路', 'オオエチョウキタアリジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市大江町南有路', '26', '26201', '6200342', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '大江町南有路', 'オオエチョウミナミアリジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市豊平区西岡5条', '01', '01105', '0620035', '北海道', 'ホッカイドウ', '札幌市豊平区', 'サッポロシトヨヒラク', '西岡5条', 'ニシオカ05ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市大江町千原', '26', '26201', '6200351', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '大江町千原', 'オオエチョウセンバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市大江町南山', '26', '26201', '6200352', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '大江町南山', 'オオエチョウミナミヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市大江町夏間', '26', '26201', '6200353', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '大江町夏間', 'オオエチョウナツマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市大江町在田', '26', '26201', '6200354', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '大江町在田', 'オオエチョウアリタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市大江町常津', '26', '26201', '6200355', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '大江町常津', 'オオエチョウツネヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市大江町尾藤', '26', '26201', '6200356', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '大江町尾藤', 'オオエチョウビトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市豊平区西岡', '01', '01105', '0620039', '北海道', 'ホッカイドウ', '札幌市豊平区', 'サッポロシトヨヒラク', '西岡', 'ニシオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市豊平区福住1条', '01', '01105', '0620041', '北海道', 'ホッカイドウ', '札幌市豊平区', 'サッポロシトヨヒラク', '福住1条', 'フクズミ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市豊平区福住2条', '01', '01105', '0620042', '北海道', 'ホッカイドウ', '札幌市豊平区', 'サッポロシトヨヒラク', '福住2条', 'フクズミ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市豊平区福住3条', '01', '01105', '0620043', '北海道', 'ホッカイドウ', '札幌市豊平区', 'サッポロシトヨヒラク', '福住3条', 'フクズミ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市豊平区羊ケ丘', '01', '01105', '0620045', '北海道', 'ホッカイドウ', '札幌市豊平区', 'サッポロシトヨヒラク', '羊ケ丘', 'ヒツジガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市豊平区月寒東1条', '01', '01105', '0620051', '北海道', 'ホッカイドウ', '札幌市豊平区', 'サッポロシトヨヒラク', '月寒東1条', 'ツキサムヒガシ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市豊平区月寒東2条', '01', '01105', '0620052', '北海道', 'ホッカイドウ', '札幌市豊平区', 'サッポロシトヨヒラク', '月寒東2条', 'ツキサムヒガシ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市豊平区月寒東3条', '01', '01105', '0620053', '北海道', 'ホッカイドウ', '札幌市豊平区', 'サッポロシトヨヒラク', '月寒東3条', 'ツキサムヒガシ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市豊平区月寒東4条', '01', '01105', '0620054', '北海道', 'ホッカイドウ', '札幌市豊平区', 'サッポロシトヨヒラク', '月寒東4条', 'ツキサムヒガシ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市豊平区月寒東5条', '01', '01105', '0620055', '北海道', 'ホッカイドウ', '札幌市豊平区', 'サッポロシトヨヒラク', '月寒東5条', 'ツキサムヒガシ05ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市戸田', '26', '26201', '6200801', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '戸田', 'トダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市興', '26', '26201', '6200802', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '興', 'オキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市観音寺', '26', '26201', '6200803', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '観音寺', 'カンノンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市石原', '26', '26201', '6200804', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '石原', 'イサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市南土野町', '26', '26201', '6200805', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '南土野町', 'ミナミツチノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市聖佳町', '26', '26201', '6200806', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '聖佳町', 'セイカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市東野町', '26', '26201', '6200807', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '東野町', 'ヒガシノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市土', '26', '26201', '6200808', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '土', 'ツチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市北平野町', '26', '26201', '6200811', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '北平野町', 'キタヒラノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市東平野町', '26', '26201', '6200812', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '東平野町', 'ヒガシヒラノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市南平野町', '26', '26201', '6200813', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '南平野町', 'ミナミヒラノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市西平野町', '26', '26201', '6200814', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '西平野町', 'ニシヒラノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市長山町', '26', '26201', '6200815', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '長山町', 'ナガヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市大池坂町', '26', '26201', '6200816', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '大池坂町', 'オオイケザカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市中坂町', '26', '26201', '6200817', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '中坂町', 'ナカサカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市三俣', '26', '26201', '6200821', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '三俣', 'ミマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市萩原', '26', '26201', '6200822', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '萩原', 'ハギワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市生野', '26', '26201', '6200823', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '生野', 'イクノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市堀越', '26', '26201', '6200824', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '堀越', 'ホリコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市上野', '26', '26201', '6200825', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '上野', 'ウエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市正後寺', '26', '26201', '6200826', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '正後寺', 'ショウゴジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市坂室', '26', '26201', '6200827', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '坂室', 'サカムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市正坂', '26', '26201', '6200828', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '正坂', 'ショウサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市岩崎', '26', '26201', '6200831', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '岩崎', 'イワサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市池田', '26', '26201', '6200832', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '池田', 'イケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市宮', '26', '26201', '6200833', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '宮', 'ミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市中地', '26', '26201', '6200834', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '中地', 'ナカチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市後正寺', '26', '26201', '6200835', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '後正寺', 'ゴショウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市大内', '26', '26201', '6200836', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '大内', 'オオチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市田野', '26', '26201', '6200837', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '田野', 'タノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市笹場', '26', '26201', '6200838', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '笹場', 'ササバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市下地', '26', '26201', '6200839', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '下地', 'シモジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市駒場', '26', '26201', '6200841', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '駒場', 'コマバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市長田北', '26', '26201', '6200842', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '長田北', 'オサダキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市長田南', '26', '26201', '6200843', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '長田南', 'オサダミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市多保市', '26', '26201', '6200844', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '多保市', 'トオノイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市上松', '26', '26201', '6200845', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '上松', 'ウエマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市長田段', '26', '26201', '6200846', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '長田段', 'オサダダン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市岩間', '26', '26201', '6200847', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '岩間', 'イワマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市市の谷', '26', '26201', '6200848', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '市の谷', 'イチノタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市砂子町', '26', '26201', '6200849', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '砂子町', 'スナゴマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市大野下', '26', '26201', '6200851', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '大野下', 'オオノシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市大野上', '26', '26201', '6200852', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '大野上', 'オオノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市長田野町', '26', '26201', '6200853', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '長田野町', 'オサダノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市高畑', '26', '26201', '6200854', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '高畑', 'タカバタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市土師新町', '26', '26201', '6200855', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '土師', 'ハゼ', null, null, '新町', 'シンマチ');
INSERT INTO `ms_addresses` VALUES ('71875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市土師宮町', '26', '26201', '6200856', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '土師', 'ハゼ', null, null, '宮町', 'ミヤマチ');
INSERT INTO `ms_addresses` VALUES ('71876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市土師', '26', '26201', '6200857', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '土師', 'ハゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市大野', '26', '26201', '6200858', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '大野', 'オオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市桔梗が丘', '26', '26201', '6200859', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '桔梗が丘', 'キキョウガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市秋津が丘', '26', '26201', '6200861', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '秋津が丘', 'アキツガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市東佳屋野町', '26', '26201', '6200862', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '東佳屋野町', 'ヒガシカヤノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市小松ケ丘', '26', '26201', '6200863', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '小松ケ丘', 'コマツガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市南佳屋野町', '26', '26201', '6200864', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '南佳屋野町', 'ミナミカヤノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市西佳屋野町', '26', '26201', '6200865', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '西佳屋野町', 'ニシカヤノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市前田新町', '26', '26201', '6200866', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '前田新町', 'マエダシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市前田', '26', '26201', '6200867', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '前田', 'マエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市岡ノ二町', '26', '26201', '6200871', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '岡ノ二町', 'オカノ02マチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市岡ノ一町', '26', '26201', '6200872', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '岡ノ一町', 'オカノ01マチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市岡ノ三町', '26', '26201', '6200873', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '岡ノ三町', 'オカノ03マチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市堀口', '26', '26201', '6200874', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '堀口', 'ホリグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市蛇ケ端', '26', '26201', '6200875', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '蛇ケ端', 'ジャガハナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市水内', '26', '26201', '6200876', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '水内', 'ミズウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市森垣', '26', '26201', '6200877', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '森垣', 'モリガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市日吉ケ丘', '26', '26201', '6200878', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '日吉ケ丘', 'ヒヨシガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市荒木', '26', '26201', '6200879', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '荒木', 'アラキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市内田町', '26', '26201', '6200881', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '内田町', 'ウチダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市東堀', '26', '26201', '6200882', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '東堀', 'ヒガシボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市本堀', '26', '26201', '6200883', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '本堀', 'ホンボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市南本堀', '26', '26201', '6200884', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '南本堀', 'ミナミホンボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市南小谷ケ丘', '26', '26201', '6200885', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '南小谷ケ丘', 'ミナミコタニガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市西小谷ケ丘', '26', '26201', '6200886', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '西小谷ケ丘', 'ニシコタニガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市東小谷ケ丘', '26', '26201', '6200887', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '東小谷ケ丘', 'ヒガシコタニガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市野家', '26', '26201', '6200888', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '野家', 'ノケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市岡ノ上町', '26', '26201', '6200891', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '岡ノ上町', 'オカノウエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市東岡町', '26', '26201', '6200892', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '東岡町', 'ヒガシオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市北小谷ケ丘', '26', '26201', '6200893', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '北小谷ケ丘', 'キタコタニガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市丸田ケ丘', '26', '26201', '6200894', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '丸田ケ丘', 'マルタガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市緑ケ丘町', '26', '26201', '6200895', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '緑ケ丘町', 'ミドリガオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市上佐々木', '26', '26201', '6200901', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '上佐々木', 'カミササキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市喜多', '26', '26201', '6200902', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '喜多', 'キタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市日尾', '26', '26201', '6200903', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '日尾', 'ヒノオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市常願寺', '26', '26201', '6200904', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '常願寺', 'ジョウガンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市田和', '26', '26201', '6200905', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '田和', 'タワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市新宮', '26', '26201', '6200906', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '新宮', 'シングウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市一ノ宮', '26', '26201', '6200907', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '一ノ宮', 'イチノミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市下佐々木', '26', '26201', '6200908', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '下佐々木', 'シモササキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市中佐々木', '26', '26201', '6200909', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '中佐々木', 'ナカササキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市上大内', '26', '26201', '6200911', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '上大内', 'カミオオチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市下大内', '26', '26201', '6200912', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '下大内', 'シモオオチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市牧', '26', '26201', '6200913', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '牧', 'マキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市立原', '26', '26201', '6200914', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '立原', 'タツワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市十二', '26', '26201', '6200915', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '十二', 'ジュウニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市六十内', '26', '26201', '6200916', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '六十内', 'ムソチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市野花', '26', '26201', '6200917', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '野花', 'ノバナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市夷', '26', '26201', '6200918', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '夷', 'エビス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市岩井新町', '26', '26201', '6200920', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '岩井新町', 'イワイシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市かしの木台', '26', '26201', '6200921', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', 'かしの木台', 'カシノキダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市岩井', '26', '26201', '6200922', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '岩井', 'イワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市本庄', '26', '26201', '6200923', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '本庄', 'ホンショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市下篠尾', '26', '26201', '6200924', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '下篠尾', 'シモサソオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市上篠尾', '26', '26201', '6200925', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '上篠尾', 'カミサソオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市新庄', '26', '26201', '6200926', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '新庄', 'シンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市和久寺', '26', '26201', '6200927', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '和久寺', 'ワクデラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市奥野部', '26', '26201', '6200928', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '奥野部', 'オクノベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市北羽合', '26', '26201', '6200931', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '北羽合', 'キタハゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市西羽合', '26', '26201', '6200932', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '西羽合', 'ニシハゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市東羽合', '26', '26201', '6200933', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '東羽合', 'ヒガシハゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市南羽合', '26', '26201', '6200934', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '南羽合', 'ミナミハゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市向野', '26', '26201', '6200935', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '向野', 'ムカイノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市正明寺', '26', '26201', '6200936', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '正明寺', 'ショウミョウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市室', '26', '26201', '6200937', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '室', 'ムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市小野脇', '26', '26201', '6200938', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '小野脇', 'オノワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市市寺', '26', '26201', '6200939', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '市寺', 'イチデラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市駅南町', '26', '26201', '6200940', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '駅南町', 'エキナンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市北岡町', '26', '26201', '6200943', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '北岡町', 'キタオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市南岡町', '26', '26201', '6200944', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '南岡町', 'ミナミオカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市広峯町', '26', '26201', '6200945', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '広峯町', 'ヒロミネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市南天田町', '26', '26201', '6200946', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '南天田町', 'ミナミアマダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市旭が丘', '26', '26201', '6200947', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '旭が丘', 'アサヒガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市夕陽が丘', '26', '26201', '6200948', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '夕陽が丘', 'ユウヒガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市つつじケ丘', '26', '26201', '6200949', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', 'つつじケ丘', 'ツツジガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市十三丘', '26', '26201', '6200951', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '十三丘', 'トミオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市大門', '26', '26201', '6200952', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '大門', 'ダイモン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市今安', '26', '26201', '6200953', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '今安', 'イマヤス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市半田', '26', '26201', '6200954', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '半田', 'ハンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市拝師', '26', '26201', '6200955', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '拝師', 'ハイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市額塚', '26', '26201', '6200956', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '額塚', 'スクモヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市山崎', '26', '26201', '6200957', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '山崎', 'ヤマザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市さつきケ丘', '26', '26201', '6200958', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', 'さつきケ丘', 'サツキガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市石場', '26', '26201', '6200961', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '石場', 'イシバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市口榎原', '26', '26201', '6200962', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '口榎原', 'クチエバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市奥榎原', '26', '26201', '6200963', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '奥榎原', 'オクエバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市甘栗', '26', '26201', '6200964', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '甘栗', 'アマグリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市樽水', '26', '26201', '6200965', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '樽水', 'タルミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市辻', '26', '26201', '6200966', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '辻', 'ツジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市畑中', '26', '26201', '6200967', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '畑中', 'ハタケナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市北山', '26', '26201', '6200968', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '北山', 'キタヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市茅ノ台', '26', '26201', '6200969', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '茅ノ台', 'カヤノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市下戸', '26', '26201', '6200971', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '下戸', 'サゲト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市小牧', '26', '26201', '6200972', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '小牧', 'コマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市談', '26', '26201', '6200973', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '談', 'ダン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市法用', '26', '26201', '6200974', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '法用', 'ホウヨウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市小田', '26', '26201', '6200981', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '小田', 'オダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市下小田', '26', '26201', '6200982', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '下小田', 'シモオダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市野笹', '26', '26201', '6200983', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '野笹', 'ノザサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市猪野々', '26', '26201', '6200984', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '猪野々', 'イノノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市梅谷', '26', '26201', '6200985', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '梅谷', 'ウメダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市宮垣', '26', '26201', '6200986', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '宮垣', 'ミヤガキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市鴨野町', '26', '26201', '6200987', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '鴨野町', 'カモノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市大見長祖', '26', '26201', '6200988', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '大見長祖', 'オオミナガソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市住所大山', '26', '26201', '6200989', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '住所大山', 'スミンジョオオヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市三和町大原', '26', '26201', '6201301', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '三和町大原', 'ミワチョウオオバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市三和町台頭', '26', '26201', '6201302', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '三和町台頭', 'ミワチョウダイト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市三和町上川合', '26', '26201', '6201311', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '三和町上川合', 'ミワチョウカミガワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市三和町岼', '26', '26201', '6201312', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '三和町岼', 'ミワチョウユリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市三和町下川合', '26', '26201', '6201313', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '三和町下川合', 'ミワチョウシモカワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市三和町加用', '26', '26201', '6201314', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '三和町加用', 'ミワチョウカヨウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市三和町大身', '26', '26201', '6201421', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '三和町大身', 'ミワチョウオオミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市三和町菟原中', '26', '26201', '6201422', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '三和町菟原中', 'ミワチョウウバラナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市三和町高杉', '26', '26201', '6201423', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '三和町高杉', 'ミワチョウタカスギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市三和町友渕', '26', '26201', '6201424', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '三和町友渕', 'ミワチョウトモブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市三和町菟原下', '26', '26201', '6201425', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '三和町菟原下', 'ミワチョウウバラシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市三和町辻', '26', '26201', '6201431', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '三和町辻', 'ミワチョウツジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市三和町中出', '26', '26201', '6201432', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '三和町中出', 'ミワチョウナカデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市三和町田ノ谷', '26', '26201', '6201433', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '三和町田ノ谷', 'ミワチョウタノタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市三和町西松', '26', '26201', '6201434', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '三和町西松', 'ミワチョウサイマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市三和町草山', '26', '26201', '6201435', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '三和町草山', 'ミワチョウクサヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('71999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市三和町梅原', '26', '26201', '6201441', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '三和町梅原', 'ミワチョウウメハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市三和町千束', '26', '26201', '6201442', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '三和町千束', 'ミワチョウセンゾク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市三和町寺尾', '26', '26201', '6201443', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '三和町寺尾', 'ミワチョウテラオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市三和町芦渕', '26', '26201', '6201444', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '三和町芦渕', 'ミワチョウアシブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市三和町みわ', '26', '26201', '6201445', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '三和町みわ', 'ミワチョウミワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市豊平区豊平1条', '01', '01105', '0620901', '北海道', 'ホッカイドウ', '札幌市豊平区', 'サッポロシトヨヒラク', '豊平1条', 'トヨヒラ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市豊平区豊平2条', '01', '01105', '0620902', '北海道', 'ホッカイドウ', '札幌市豊平区', 'サッポロシトヨヒラク', '豊平2条', 'トヨヒラ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市豊平区豊平3条', '01', '01105', '0620903', '北海道', 'ホッカイドウ', '札幌市豊平区', 'サッポロシトヨヒラク', '豊平3条', 'トヨヒラ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市豊平区豊平4条', '01', '01105', '0620904', '北海道', 'ホッカイドウ', '札幌市豊平区', 'サッポロシトヨヒラク', '豊平4条', 'トヨヒラ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市豊平区豊平5条', '01', '01105', '0620905', '北海道', 'ホッカイドウ', '札幌市豊平区', 'サッポロシトヨヒラク', '豊平5条', 'トヨヒラ05ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市豊平区豊平6条', '01', '01105', '0620906', '北海道', 'ホッカイドウ', '札幌市豊平区', 'サッポロシトヨヒラク', '豊平6条', 'トヨヒラ06ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市豊平区豊平7条', '01', '01105', '0620907', '北海道', 'ホッカイドウ', '札幌市豊平区', 'サッポロシトヨヒラク', '豊平7条', 'トヨヒラ07ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市豊平区豊平8条', '01', '01105', '0620908', '北海道', 'ホッカイドウ', '札幌市豊平区', 'サッポロシトヨヒラク', '豊平8条', 'トヨヒラ08ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市豊平区豊平9条', '01', '01105', '0620909', '北海道', 'ホッカイドウ', '札幌市豊平区', 'サッポロシトヨヒラク', '豊平9条', 'トヨヒラ09ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市豊平区旭町', '01', '01105', '0620911', '北海道', 'ホッカイドウ', '札幌市豊平区', 'サッポロシトヨヒラク', '旭町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市豊平区水車町', '01', '01105', '0620912', '北海道', 'ホッカイドウ', '札幌市豊平区', 'サッポロシトヨヒラク', '水車町', 'スイシャチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市豊平区中の島1条', '01', '01105', '0620921', '北海道', 'ホッカイドウ', '札幌市豊平区', 'サッポロシトヨヒラク', '中の島1条', 'ナカノシマ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市豊平区中の島2条', '01', '01105', '0620922', '北海道', 'ホッカイドウ', '札幌市豊平区', 'サッポロシトヨヒラク', '中の島2条', 'ナカノシマ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市豊平区平岸1条', '01', '01105', '0620931', '北海道', 'ホッカイドウ', '札幌市豊平区', 'サッポロシトヨヒラク', '平岸1条', 'ヒラギシ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市豊平区平岸2条', '01', '01105', '0620932', '北海道', 'ホッカイドウ', '札幌市豊平区', 'サッポロシトヨヒラク', '平岸2条', 'ヒラギシ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市豊平区平岸3条', '01', '01105', '0620933', '北海道', 'ホッカイドウ', '札幌市豊平区', 'サッポロシトヨヒラク', '平岸3条', 'ヒラギシ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市豊平区平岸4条', '01', '01105', '0620934', '北海道', 'ホッカイドウ', '札幌市豊平区', 'サッポロシトヨヒラク', '平岸4条', 'ヒラギシ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市豊平区平岸5条', '01', '01105', '0620935', '北海道', 'ホッカイドウ', '札幌市豊平区', 'サッポロシトヨヒラク', '平岸5条', 'ヒラギシ05ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市豊平区平岸6条', '01', '01105', '0620936', '北海道', 'ホッカイドウ', '札幌市豊平区', 'サッポロシトヨヒラク', '平岸6条', 'ヒラギシ06ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市豊平区平岸7条', '01', '01105', '0620937', '北海道', 'ホッカイドウ', '札幌市豊平区', 'サッポロシトヨヒラク', '平岸7条', 'ヒラギシ07ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市豊平区平岸8条', '01', '01105', '0620938', '北海道', 'ホッカイドウ', '札幌市豊平区', 'サッポロシトヨヒラク', '平岸8条', 'ヒラギシ08ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市', '26', '26206', '6210000', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('72035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市旭町', '26', '26206', '6210001', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '旭町', 'アサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市千歳町千歳', '26', '26206', '6210002', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '千歳町千歳', 'チトセチョウチトセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市千歳町国分', '26', '26206', '6210003', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '千歳町国分', 'チトセチョウコクブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市千歳町毘沙門', '26', '26206', '6210004', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '千歳町毘沙門', 'チトセチョウビシャモン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市保津町', '26', '26206', '6210005', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '保津町', 'ホヅチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市河原林町勝林島', '26', '26206', '6210006', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '河原林町勝林島', 'カワラバヤシチョウショウリンジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市河原林町河原尻', '26', '26206', '6210007', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '河原林町河原尻', 'カワラバヤシチョウカワラジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市馬路町', '26', '26206', '6210008', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '馬路町', 'ウマジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市大井町土田', '26', '26206', '6210011', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '大井町土田', 'オオイチョウツチダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市大井町かすみケ丘', '26', '26206', '6210012', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '大井町かすみケ丘', 'オオイチョウカスミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市大井町並河', '26', '26206', '6210013', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '大井町並河', 'オオイチョウナミカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市吉川町穴川', '26', '26206', '6210014', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '吉川町穴川', 'ヨシカワチョウアナガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市吉川町吉田', '26', '26206', '6210015', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '吉川町吉田', 'ヨシカワチョウヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市大井町南金岐', '26', '26206', '6210016', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '大井町南金岐', 'オオイチョウミナミカナゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市大井町北金岐', '26', '26206', '6210017', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '大井町北金岐', 'オオイチョウキタカナゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市大井町小金岐', '26', '26206', '6210018', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '大井町小金岐', 'オオイチョウコカナゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市曽我部町重利', '26', '26206', '6210021', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '曽我部町重利', 'ソガベチョウシゲトシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市曽我部町南条', '26', '26206', '6210022', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '曽我部町南条', 'ソガベチョウナンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市曽我部町寺', '26', '26206', '6210023', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '曽我部町寺', 'ソガベチョウテラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市曽我部町春日部', '26', '26206', '6210024', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '曽我部町春日部', 'ソガベチョウカスカベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市曽我部町中', '26', '26206', '6210025', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '曽我部町中', 'ソガベチョウナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市曽我部町法貴', '26', '26206', '6210026', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '曽我部町法貴', 'ソガベチョウホウキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市曽我部町犬飼', '26', '26206', '6210027', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '曽我部町犬飼', 'ソガベチョウイヌカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市曽我部町西条', '26', '26206', '6210028', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '曽我部町西条', 'ソガベチョウニシジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市曽我部町穴太', '26', '26206', '6210029', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '曽我部町穴太', 'ソガベチョウアナオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市ひえ田野町太田', '26', '26206', '6210031', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', 'ひえ田野町太田', 'ヒエダノチョウオオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市ひえ田野町天川', '26', '26206', '6210032', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', 'ひえ田野町天川', 'ヒエダノチョウテンガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市ひえ田野町佐伯', '26', '26206', '6210033', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', 'ひえ田野町佐伯', 'ヒエダノチョウサエキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市ひえ田野町芦ノ山', '26', '26206', '6210034', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', 'ひえ田野町芦ノ山', 'ヒエダノチョウアシノヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市ひえ田野町奥条', '26', '26206', '6210035', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', 'ひえ田野町奥条', 'ヒエダノチョウオクジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市ひえ田野町柿花', '26', '26206', '6210036', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', 'ひえ田野町柿花', 'ヒエダノチョウカキハナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市ひえ田野町鹿谷', '26', '26206', '6210037', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', 'ひえ田野町鹿谷', 'ヒエダノチョウロクヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市千代川町小川', '26', '26206', '6210041', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '千代川町小川', 'チヨカワチョウオガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市千代川町高野林', '26', '26206', '6210042', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '千代川町高野林', 'チヨカワチョウタカノハヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市千代川町小林', '26', '26206', '6210043', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '千代川町小林', 'チヨカワチョウオバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市千代川町日吉台', '26', '26206', '6210044', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '千代川町日吉台', 'チヨカワチョウヒヨシダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市千代川町湯井', '26', '26206', '6210045', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '千代川町湯井', 'チヨカワチョウユイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市千代川町北ノ庄', '26', '26206', '6210046', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '千代川町北ノ庄', 'チヨカワチョウキタノショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市千代川町今津', '26', '26206', '6210051', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '千代川町今津', 'チヨカワチョウイマヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市千代川町千原', '26', '26206', '6210052', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '千代川町千原', 'チヨカワチョウチハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市千代川町拝田', '26', '26206', '6210053', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '千代川町拝田', 'チヨカワチョウハイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市千代川町川関', '26', '26206', '6210054', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '千代川町川関', 'チヨカワチョウカワゼキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市東別院町小泉', '26', '26206', '6210101', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '東別院町小泉', 'ヒガシベツインチョウコイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市東別院町神原', '26', '26206', '6210102', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '東別院町神原', 'ヒガシベツインチョウカミハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市東別院町東掛', '26', '26206', '6210103', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '東別院町東掛', 'ヒガシベツインチョウトウゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市東別院町大野', '26', '26206', '6210104', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '東別院町大野', 'ヒガシベツインチョウオオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市東別院町南掛', '26', '26206', '6210111', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '東別院町南掛', 'ヒガシベツインチョウナンゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市東別院町湯谷', '26', '26206', '6210112', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '東別院町湯谷', 'ヒガシベツインチョウユヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市東別院町倉谷', '26', '26206', '6210113', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '東別院町倉谷', 'ヒガシベツインチョウクラダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市東別院町鎌倉', '26', '26206', '6210114', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '東別院町鎌倉', 'ヒガシベツインチョウカマクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市東別院町栢原', '26', '26206', '6210115', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '東別院町栢原', 'ヒガシベツインチョウカイバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市西別院町大槻並', '26', '26206', '6210121', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '西別院町大槻並', 'ニシベツインチョウオオツクナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市西別院町万願寺', '26', '26206', '6210122', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '西別院町万願寺', 'ニシベツインチョウマンガンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市西別院町寺田', '26', '26206', '6210123', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '西別院町寺田', 'ニシベツインチョウテラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市西別院町柚原', '26', '26206', '6210124', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '西別院町柚原', 'ニシベツインチョウユノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市西別院町笑路', '26', '26206', '6210125', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '西別院町笑路', 'ニシベツインチョウワロウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市西別院町犬甘野', '26', '26206', '6210126', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '西別院町犬甘野', 'ニシベツインチョウイヌカンノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市西別院町神地', '26', '26206', '6210127', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '西別院町神地', 'ニシベツインチョウコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市東本梅町大内', '26', '26206', '6210231', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '東本梅町大内', 'ヒガシホンメチョウオオウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市東本梅町松熊', '26', '26206', '6210232', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '東本梅町松熊', 'ヒガシホンメチョウマツクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市東本梅町中野', '26', '26206', '6210233', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '東本梅町中野', 'ヒガシホンメチョウナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市東本梅町赤熊', '26', '26206', '6210234', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '東本梅町赤熊', 'ヒガシホンメチョウアカクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市東本梅町東大谷', '26', '26206', '6210235', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '東本梅町東大谷', 'ヒガシホンメチョウヒガシオオタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市宮前町猪倉', '26', '26206', '6210241', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '宮前町猪倉', 'ミヤザキチョウイノクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市宮前町神前', '26', '26206', '6210242', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '宮前町神前', 'ミヤザキチョウコウザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市宮前町宮川', '26', '26206', '6210243', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '宮前町宮川', 'ミヤザキチョウミヤガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市本梅町平松', '26', '26206', '6210251', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '本梅町平松', 'ホンメチョウヒラマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市本梅町中野', '26', '26206', '6210252', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '本梅町中野', 'ホンメチョウナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市本梅町井手', '26', '26206', '6210253', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '本梅町井手', 'ホンメチョウイデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市本梅町東加舎', '26', '26206', '6210254', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '本梅町東加舎', 'ホンメチョウヒガシカヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市本梅町西加舎', '26', '26206', '6210255', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '本梅町西加舎', 'ホンメチョウニシカヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市畑野町千ケ畑', '26', '26206', '6210261', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '畑野町千ケ畑', 'ハタノチョウセンガハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市畑野町広野', '26', '26206', '6210262', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '畑野町広野', 'ハタノチョウヒロノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市畑野町土ケ畑', '26', '26206', '6210263', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '畑野町土ケ畑', 'ハタノチョウドンガハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市宇津根町', '26', '26206', '6210801', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '宇津根町', 'ウツネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市北河原町', '26', '26206', '6210802', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '北河原町', 'キタカワラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市河原町', '26', '26206', '6210803', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '河原町', 'カワラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市追分町', '26', '26206', '6210804', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '追分町', 'オイワケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市安町', '26', '26206', '6210805', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '安町', 'ヤスマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市余部町', '26', '26206', '6210806', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '余部町', 'アマルベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市北古世町', '26', '26206', '6210811', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '北古世町', 'キタコセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市横町', '26', '26206', '6210812', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '横町', 'ヨコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市突抜町', '26', '26206', '6210813', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '突抜町', 'ツキヌケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市三宅町', '26', '26206', '6210814', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '三宅町', 'ミヤケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市古世町', '26', '26206', '6210815', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '古世町', 'コセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市東竪町', '26', '26206', '6210816', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '東竪町', 'ヒガシタツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市西竪町', '26', '26206', '6210817', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '西竪町', 'ニシタツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市京町', '26', '26206', '6210818', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '京町', 'キョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市呉服町', '26', '26206', '6210819', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '呉服町', 'ゴフクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市篠町柏原', '26', '26206', '6210821', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '篠町柏原', 'シノチョウカセバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市篠町野条', '26', '26206', '6210822', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '篠町野条', 'シノチョウノジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市篠町馬堀', '26', '26206', '6210823', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '篠町馬堀', 'シノチョウウマホリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市篠町見晴', '26', '26206', '6210824', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '篠町見晴', 'シノチョウミハル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市篠町山本', '26', '26206', '6210825', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '篠町山本', 'シノチョウヤマモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市篠町篠', '26', '26206', '6210826', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '篠町篠', 'シノチョウシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市篠町王子', '26', '26206', '6210827', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '篠町王子', 'シノチョウオウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市篠町馬堀駅前', '26', '26206', '6210828', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '篠町馬堀駅前', 'シノチョウウマホリエキマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市篠町森', '26', '26206', '6210831', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '篠町森', 'シノチョウモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市東つつじケ丘都台', '26', '26206', '6210832', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '東つつじケ丘都台', 'ヒガシツツジガオカミヤコダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市東つつじケ丘曙台', '26', '26206', '6210833', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '東つつじケ丘曙台', 'ヒガシツツジガオカアケボノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市篠町広田', '26', '26206', '6210834', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '篠町広田', 'シノチョウヒロタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市篠町浄法寺', '26', '26206', '6210835', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '篠町浄法寺', 'シノチョウジョウボウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市西つつじケ丘五月台', '26', '26206', '6210841', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '西つつじケ丘五月台', 'ニシツツジガオカサツキダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市西つつじケ丘雲仙台', '26', '26206', '6210842', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '西つつじケ丘雲仙台', 'ニシツツジガオカウンゼンダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市西つつじケ丘大山台', '26', '26206', '6210843', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '西つつじケ丘大山台', 'ニシツツジガオカダイセンダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市西つつじケ丘霧島台', '26', '26206', '6210844', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '西つつじケ丘霧島台', 'ニシツツジガオカキリシマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市西つつじケ丘美山台', '26', '26206', '6210845', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '西つつじケ丘美山台', 'ニシツツジガオカミヤマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市南つつじケ丘大葉台', '26', '26206', '6210846', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '南つつじケ丘大葉台', 'ミナミツツジガオカオオバダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市南つつじケ丘桜台', '26', '26206', '6210847', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '南つつじケ丘桜台', 'ミナミツツジガオカサクラダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市荒塚町', '26', '26206', '6210851', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '荒塚町', 'アラツカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市紺屋町', '26', '26206', '6210852', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '紺屋町', 'コンヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市矢田町', '26', '26206', '6210853', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '矢田町', 'ヤダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市下矢田町', '26', '26206', '6210854', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '下矢田町', 'シモヤダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市中矢田町', '26', '26206', '6210855', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '中矢田町', 'ナカヤダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市上矢田町', '26', '26206', '6210856', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '上矢田町', 'カミヤダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市北町', '26', '26206', '6210861', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '北町', 'キタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市西町', '26', '26206', '6210862', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '西町', 'ニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市南郷町', '26', '26206', '6210863', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '南郷町', 'ナンゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市内丸町', '26', '26206', '6210864', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '内丸町', 'ウチマルチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市新町', '26', '26206', '6210865', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市旅籠町', '26', '26206', '6210866', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '旅籠町', 'ハタゴマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市塩屋町', '26', '26206', '6210867', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '塩屋町', 'シオヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市柳町', '26', '26206', '6210868', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '柳町', 'ヤナギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府亀岡市本町', '26', '26206', '6210869', '京都府', 'キョウトフ', '亀岡市', 'カメオカシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市', '26', '26213', '6220000', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('72164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市園部町宮町', '26', '26213', '6220001', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '園部町宮町', 'ソノベチョウミヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市園部町美園町', '26', '26213', '6220002', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '園部町美園町', 'ソノベチョウミソノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市園部町新町', '26', '26213', '6220003', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '園部町新町', 'ソノベチョウシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市園部町小桜町', '26', '26213', '6220004', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '園部町小桜町', 'ソノベチョウコザクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市園部町上木崎町', '26', '26213', '6220011', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '園部町上木崎町', 'ソノベチョウカミキザキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市園部町内林町', '26', '26213', '6220012', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '園部町内林町', 'ソノベチョウウチバヤシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市園部町本町', '26', '26213', '6220013', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '園部町本町', 'ソノベチョウホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市園部町上本町', '26', '26213', '6220014', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '園部町上本町', 'ソノベチョウカミホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市園部町木崎町', '26', '26213', '6220015', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '園部町木崎町', 'ソノベチョウキザキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市園部町河原町', '26', '26213', '6220016', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '園部町河原町', 'ソノベチョウカワラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市園部町若松町', '26', '26213', '6220017', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '園部町若松町', 'ソノベチョウワカマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市園部町瓜生野', '26', '26213', '6220021', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '園部町瓜生野', 'ソノベチョウウリウノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市園部町熊崎', '26', '26213', '6220022', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '園部町熊崎', 'ソノベチョウクマザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市園部町新堂', '26', '26213', '6220023', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '園部町新堂', 'ソノベチョウシンドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市園部町千妻', '26', '26213', '6220024', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '園部町千妻', 'ソノベチョウセンヅマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市園部町曽我谷', '26', '26213', '6220025', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '園部町曽我谷', 'ソノベチョウソガダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市園部町船岡', '26', '26213', '6220031', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '園部町船岡', 'ソノベチョウフナオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市園部町高屋', '26', '26213', '6220032', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '園部町高屋', 'ソノベチョウタカヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市園部町大戸', '26', '26213', '6220033', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '園部町大戸', 'ソノベチョウオオド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市園部町熊原', '26', '26213', '6220034', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '園部町熊原', 'ソノベチョウクマハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市園部町佐切', '26', '26213', '6220035', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '園部町佐切', 'ソノベチョウサギリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市園部町越方', '26', '26213', '6220036', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '園部町越方', 'ソノベチョウオチカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市園部町小山東町', '26', '26213', '6220041', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '園部町小山東町', 'ソノベチョウオヤマヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市園部町栄町', '26', '26213', '6220042', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '園部町栄町', 'ソノベチョウサカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市園部町小山西町', '26', '26213', '6220043', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '園部町小山西町', 'ソノベチョウオヤマニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市園部町城南町', '26', '26213', '6220044', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '園部町城南町', 'ソノベチョウジョウナンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市園部町半田', '26', '26213', '6220045', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '園部町半田', 'ソノベチョウハンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市園部町口人', '26', '26213', '6220046', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '園部町口人', 'ソノベチョウクチウド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市園部町口司', '26', '26213', '6220047', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '園部町口司', 'ソノベチョウコウシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市園部町横田', '26', '26213', '6220051', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '園部町横田', 'ソノベチョウヨコタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市園部町黒田', '26', '26213', '6220052', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '園部町黒田', 'ソノベチョウクロダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市園部町船阪', '26', '26213', '6220053', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '園部町船阪', 'ソノベチョウフナサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市園部町大西', '26', '26213', '6220054', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '園部町大西', 'ソノベチョウオオニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市園部町宍人', '26', '26213', '6220055', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '園部町宍人', 'ソノベチョウシシウド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市園部町埴生', '26', '26213', '6220056', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '園部町埴生', 'ソノベチョウハブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市園部町殿谷', '26', '26213', '6220057', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '園部町殿谷', 'ソノベチョウトノダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市園部町若森', '26', '26213', '6220058', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '園部町若森', 'ソノベチョウワカモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市園部町南大谷', '26', '26213', '6220059', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '園部町南大谷', 'ソノベチョウミナミオオタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市園部町仁江', '26', '26213', '6220061', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '園部町仁江', 'ソノベチョウニエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市園部町竹井', '26', '26213', '6220062', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '園部町竹井', 'ソノベチョウタケイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市園部町天引', '26', '26213', '6220063', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '園部町天引', 'ソノベチョウアマビキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市園部町法京', '26', '26213', '6220064', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '園部町法京', 'ソノベチョウホウキョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市園部町大河内', '26', '26213', '6220065', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '園部町大河内', 'ソノベチョウオオカワチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市園部町南八田', '26', '26213', '6220066', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '園部町南八田', 'ソノベチョウミナミハツタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府船井郡京丹波町', '26', '26407', '6220200', '京都府', 'キョウトフ', '船井郡京丹波町', 'フナイグンキョウタンバチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('72209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府船井郡京丹波町下山', '26', '26407', '6220201', '京都府', 'キョウトフ', '船井郡京丹波町', 'フナイグンキョウタンバチョウ', '下山', 'シモヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府船井郡京丹波町実勢', '26', '26407', '6220202', '京都府', 'キョウトフ', '船井郡京丹波町', 'フナイグンキョウタンバチョウ', '実勢', 'ジッセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府船井郡京丹波町富田', '26', '26407', '6220203', '京都府', 'キョウトフ', '船井郡京丹波町', 'フナイグンキョウタンバチョウ', '富田', 'トミタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府船井郡京丹波町上野', '26', '26407', '6220211', '京都府', 'キョウトフ', '船井郡京丹波町', 'フナイグンキョウタンバチョウ', '上野', 'ウエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府船井郡京丹波町市森', '26', '26407', '6220212', '京都府', 'キョウトフ', '船井郡京丹波町', 'フナイグンキョウタンバチョウ', '市森', 'イチモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府船井郡京丹波町須知', '26', '26407', '6220213', '京都府', 'キョウトフ', '船井郡京丹波町', 'フナイグンキョウタンバチョウ', '須知', 'シュウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府船井郡京丹波町蒲生', '26', '26407', '6220214', '京都府', 'キョウトフ', '船井郡京丹波町', 'フナイグンキョウタンバチョウ', '蒲生', 'コモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府船井郡京丹波町水戸', '26', '26407', '6220221', '京都府', 'キョウトフ', '船井郡京丹波町', 'フナイグンキョウタンバチョウ', '水戸', 'ミト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府船井郡京丹波町新水戸', '26', '26407', '6220222', '京都府', 'キョウトフ', '船井郡京丹波町', 'フナイグンキョウタンバチョウ', '新水戸', 'シンミト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府船井郡京丹波町口八田', '26', '26407', '6220223', '京都府', 'キョウトフ', '船井郡京丹波町', 'フナイグンキョウタンバチョウ', '口八田', 'クチハッタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府船井郡京丹波町高岡', '26', '26407', '6220224', '京都府', 'キョウトフ', '船井郡京丹波町', 'フナイグンキョウタンバチョウ', '高岡', 'タカオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府船井郡京丹波町豊田', '26', '26407', '6220231', '京都府', 'キョウトフ', '船井郡京丹波町', 'フナイグンキョウタンバチョウ', '豊田', 'トヨタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府船井郡京丹波町曽根', '26', '26407', '6220232', '京都府', 'キョウトフ', '船井郡京丹波町', 'フナイグンキョウタンバチョウ', '曽根', 'ソネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府船井郡京丹波町森', '26', '26407', '6220233', '京都府', 'キョウトフ', '船井郡京丹波町', 'フナイグンキョウタンバチョウ', '森', 'モリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府船井郡京丹波町塩田谷', '26', '26407', '6220234', '京都府', 'キョウトフ', '船井郡京丹波町', 'フナイグンキョウタンバチョウ', '塩田谷', 'シオタダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府船井郡京丹波町安井', '26', '26407', '6220235', '京都府', 'キョウトフ', '船井郡京丹波町', 'フナイグンキョウタンバチョウ', '安井', 'ヤスイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府船井郡京丹波町院内', '26', '26407', '6220236', '京都府', 'キョウトフ', '船井郡京丹波町', 'フナイグンキョウタンバチョウ', '院内', 'インナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府船井郡京丹波町粟野', '26', '26407', '6220301', '京都府', 'キョウトフ', '船井郡京丹波町', 'フナイグンキョウタンバチョウ', '粟野', 'アワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府船井郡京丹波町妙楽寺', '26', '26407', '6220302', '京都府', 'キョウトフ', '船井郡京丹波町', 'フナイグンキョウタンバチョウ', '妙楽寺', 'ミョウラクジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府船井郡京丹波町三ノ宮', '26', '26407', '6220303', '京都府', 'キョウトフ', '船井郡京丹波町', 'フナイグンキョウタンバチョウ', '三ノ宮', 'サンノミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府船井郡京丹波町猪鼻', '26', '26407', '6220304', '京都府', 'キョウトフ', '船井郡京丹波町', 'フナイグンキョウタンバチョウ', '猪鼻', 'イノハナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府船井郡京丹波町和田', '26', '26407', '6220311', '京都府', 'キョウトフ', '船井郡京丹波町', 'フナイグンキョウタンバチョウ', '和田', 'ワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府船井郡京丹波町井脇', '26', '26407', '6220312', '京都府', 'キョウトフ', '船井郡京丹波町', 'フナイグンキョウタンバチョウ', '井脇', 'イワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府船井郡京丹波町保井谷', '26', '26407', '6220313', '京都府', 'キョウトフ', '船井郡京丹波町', 'フナイグンキョウタンバチョウ', '保井谷', 'ホイダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府船井郡京丹波町水呑', '26', '26407', '6220314', '京都府', 'キョウトフ', '船井郡京丹波町', 'フナイグンキョウタンバチョウ', '水呑', 'ミズノミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府船井郡京丹波町質志', '26', '26407', '6220315', '京都府', 'キョウトフ', '船井郡京丹波町', 'フナイグンキョウタンバチョウ', '質志', 'シズシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府船井郡京丹波町戸津川', '26', '26407', '6220316', '京都府', 'キョウトフ', '船井郡京丹波町', 'フナイグンキョウタンバチョウ', '戸津川', 'トツカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府船井郡京丹波町橋爪', '26', '26407', '6220321', '京都府', 'キョウトフ', '船井郡京丹波町', 'フナイグンキョウタンバチョウ', '橋爪', 'ハシヅメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府船井郡京丹波町大朴', '26', '26407', '6220322', '京都府', 'キョウトフ', '船井郡京丹波町', 'フナイグンキョウタンバチョウ', '大朴', 'オボソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府船井郡京丹波町井尻', '26', '26407', '6220323', '京都府', 'キョウトフ', '船井郡京丹波町', 'フナイグンキョウタンバチョウ', '井尻', 'イジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府船井郡京丹波町八田', '26', '26407', '6220324', '京都府', 'キョウトフ', '船井郡京丹波町', 'フナイグンキョウタンバチョウ', '八田', 'ハッタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府船井郡京丹波町小野', '26', '26407', '6220325', '京都府', 'キョウトフ', '船井郡京丹波町', 'フナイグンキョウタンバチョウ', '小野', 'コノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府船井郡京丹波町中台', '26', '26407', '6220331', '京都府', 'キョウトフ', '船井郡京丹波町', 'フナイグンキョウタンバチョウ', '中台', 'チュウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府船井郡京丹波町質美', '26', '26407', '6220332', '京都府', 'キョウトフ', '船井郡京丹波町', 'フナイグンキョウタンバチョウ', '質美', 'シツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府船井郡京丹波町坂井', '26', '26407', '6220441', '京都府', 'キョウトフ', '船井郡京丹波町', 'フナイグンキョウタンバチョウ', '坂井', 'サカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府船井郡京丹波町鎌谷下', '26', '26407', '6220442', '京都府', 'キョウトフ', '船井郡京丹波町', 'フナイグンキョウタンバチョウ', '鎌谷下', 'カマダニシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府船井郡京丹波町東又', '26', '26407', '6220443', '京都府', 'キョウトフ', '船井郡京丹波町', 'フナイグンキョウタンバチョウ', '東又', 'ヒガシマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府船井郡京丹波町鎌谷中', '26', '26407', '6220444', '京都府', 'キョウトフ', '船井郡京丹波町', 'フナイグンキョウタンバチョウ', '鎌谷中', 'カマダニナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府船井郡京丹波町鎌谷奥', '26', '26407', '6220445', '京都府', 'キョウトフ', '船井郡京丹波町', 'フナイグンキョウタンバチョウ', '鎌谷奥', 'カマダニオク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府船井郡京丹波町下大久保', '26', '26407', '6220451', '京都府', 'キョウトフ', '船井郡京丹波町', 'フナイグンキョウタンバチョウ', '下大久保', 'シモオオクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府船井郡京丹波町上大久保', '26', '26407', '6220452', '京都府', 'キョウトフ', '船井郡京丹波町', 'フナイグンキョウタンバチョウ', '上大久保', 'カミオオクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府船井郡京丹波町水原', '26', '26407', '6220453', '京都府', 'キョウトフ', '船井郡京丹波町', 'フナイグンキョウタンバチョウ', '水原', 'ミズハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市', '26', '26203', '6230000', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('72254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市小呂町', '26', '26203', '6230001', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '小呂町', 'オロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市高倉町', '26', '26203', '6230002', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '高倉町', 'タカクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市城山町', '26', '26203', '6230003', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '城山町', 'シロヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市多田町', '26', '26203', '6230004', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '多田町', 'タダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市里町', '26', '26203', '6230005', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '里町', 'サトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市有岡町', '26', '26203', '6230006', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '有岡町', 'アリオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市星原町', '26', '26203', '6230007', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '星原町', 'ホシバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市桜ケ丘', '26', '26203', '6230008', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '桜ケ丘', 'サクラガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市青野町', '26', '26203', '6230011', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '青野町', 'アオノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市川糸町', '26', '26203', '6230012', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '川糸町', 'カワイトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市綾中町', '26', '26203', '6230013', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '綾中町', 'アヤナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市若竹町', '26', '26203', '6230014', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '若竹町', 'ワカタケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市若松町', '26', '26203', '6230015', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '若松町', 'ワカマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市西町', '26', '26203', '6230016', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '西町', 'ニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市本町', '26', '26203', '6230021', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市新宮町', '26', '26203', '6230022', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '新宮町', 'シングウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市新町', '26', '26203', '6230023', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市田町', '26', '26203', '6230024', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '田町', 'タマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市月見町', '26', '26203', '6230025', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '月見町', 'ツキミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市神宮寺町', '26', '26203', '6230026', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '神宮寺町', 'ジングウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市味方町', '26', '26203', '6230031', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '味方町', 'ミカタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市野田町', '26', '26203', '6230032', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '野田町', 'ノダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市寺町', '26', '26203', '6230033', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '寺町', 'テラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市田野町', '26', '26203', '6230034', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '田野町', 'タノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市上野町', '26', '26203', '6230035', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '上野町', 'ウエノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市本宮町', '26', '26203', '6230036', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '本宮町', 'ホングウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市並松町', '26', '26203', '6230037', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '並松町', 'ナンマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市延町', '26', '26203', '6230041', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '延町', 'ノブチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市岡町', '26', '26203', '6230042', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '岡町', 'オカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市上延町', '26', '26203', '6230043', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '上延町', 'ウワノブチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市安場町', '26', '26203', '6230044', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '安場町', 'ヤスバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市高津町', '26', '26203', '6230045', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '高津町', 'タカツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市大島町', '26', '26203', '6230046', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '大島町', 'オオシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市井倉新町', '26', '26203', '6230051', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '井倉新町', 'イノクラシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市幸通', '26', '26203', '6230052', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '幸通', 'サイワイドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市宮代町', '26', '26203', '6230053', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '宮代町', 'ミヤシロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市井倉町', '26', '26203', '6230054', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '井倉町', 'イノクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市天神町', '26', '26203', '6230061', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '天神町', 'テンジンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市相生町', '26', '26203', '6230062', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '相生町', 'アイオイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市広小路', '26', '26203', '6230063', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '広小路', 'ヒロコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市中ノ町', '26', '26203', '6230064', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '中ノ町', 'ナカノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市西新町', '26', '26203', '6230065', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '西新町', 'ニシシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市駅前通', '26', '26203', '6230066', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '駅前通', 'エキマエドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市於与岐町', '26', '26203', '6230101', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '於与岐町', 'オヨギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市上杉町', '26', '26203', '6230102', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '上杉町', 'ウエスギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市梅迫町', '26', '26203', '6230103', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '梅迫町', 'ウメザコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市安国寺町', '26', '26203', '6230104', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '安国寺町', 'アンコクジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市中山町', '26', '26203', '6230105', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '中山町', 'ナカヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市高槻町', '26', '26203', '6230106', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '高槻町', 'タカツキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市八代町', '26', '26203', '6230107', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '八代町', 'ヤシロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市黒谷町', '26', '26203', '6230108', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '黒谷町', 'クロタニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市七百石町', '26', '26203', '6230111', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '七百石町', 'シチヒャクコクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市上八田町', '26', '26203', '6230112', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '上八田町', 'カミヤタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市中筋町', '26', '26203', '6230113', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '中筋町', 'ナカスジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市岡安町', '26', '26203', '6230114', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '岡安町', 'オカヤスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市渕垣町', '26', '26203', '6230115', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '渕垣町', 'フチガキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市下八田町', '26', '26203', '6230116', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '下八田町', 'シモヤタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市とよさか町', '26', '26203', '6230117', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', 'とよさか町', 'トヨサカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市位田町', '26', '26203', '6230221', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '位田町', 'イデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市栗町', '26', '26203', '6230222', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '栗町', 'クリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市豊里町', '26', '26203', '6230223', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '豊里町', 'トヨサトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市石原町', '26', '26203', '6230224', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '石原町', 'イシワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市小貝町', '26', '26203', '6230225', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '小貝町', 'オガイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市私市町', '26', '26203', '6230226', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '私市町', 'キサイチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市大畠町', '26', '26203', '6230231', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '大畠町', 'オオバタケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市舘町', '26', '26203', '6230232', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '舘町', 'タチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市今田町', '26', '26203', '6230233', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '今田町', 'イマダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市小西町', '26', '26203', '6230234', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '小西町', 'コニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市鍛治屋町', '26', '26203', '6230235', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '鍛治屋町', 'カジヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市小畑町', '26', '26203', '6230236', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '小畑町', 'オバタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市内久井町', '26', '26203', '6230341', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '内久井町', 'ウチグイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市金河内町', '26', '26203', '6230342', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '金河内町', 'カネゴチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市志賀郷町', '26', '26203', '6230343', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '志賀郷町', 'シガサトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市西方町', '26', '26203', '6230344', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '西方町', 'ニシガタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市仁和町', '26', '26203', '6230345', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '仁和町', 'ニワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市坊口町', '26', '26203', '6230346', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '坊口町', 'ボウグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市篠田町', '26', '26203', '6230351', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '篠田町', 'シノダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市向田町', '26', '26203', '6230352', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '向田町', 'ムコウダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市別所町', '26', '26203', '6230353', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '別所町', 'ベッシヨチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市白道路町', '26', '26203', '6230361', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '白道路町', 'ハソウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市物部町', '26', '26203', '6230362', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '物部町', 'モノベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市新庄町', '26', '26203', '6230363', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '新庄町', 'シンジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市西坂町', '26', '26203', '6230364', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '西坂町', 'ニシザカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市睦合町', '26', '26203', '6231121', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '睦合町', 'ムツアイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市八津合町', '26', '26203', '6231122', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '八津合町', 'ヤツアイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市五津合町', '26', '26203', '6231123', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '五津合町', 'イツアイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市五泉町', '26', '26203', '6231124', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '五泉町', 'イイズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市睦寄町', '26', '26203', '6231131', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '睦寄町', 'ムツヨリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市故屋岡町', '26', '26203', '6231132', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '故屋岡町', 'コヤオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市光野町', '26', '26203', '6231133', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '光野町', 'ミツノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市老富町', '26', '26203', '6231134', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '老富町', 'オイトミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市大川', '26', '26202', '6240101', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '大川', 'オオカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市志高', '26', '26202', '6240102', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '志高', 'シダカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市久田美', '26', '26202', '6240103', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '久田美', 'クタミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市長谷', '26', '26202', '6240111', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '長谷', 'ナガタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市上漆原', '26', '26202', '6240112', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '上漆原', 'カミウルシバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市下漆原', '26', '26202', '6240113', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '下漆原', 'シモウルシバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市下見谷', '26', '26202', '6240114', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '下見谷', 'シモミダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市河原', '26', '26202', '6240115', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '河原', 'コウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市富室', '26', '26202', '6240116', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '富室', 'フムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市岡田由里', '26', '26202', '6240117', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '岡田由里', 'オカダユリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市西方寺', '26', '26202', '6240118', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '西方寺', 'サイホウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市滝ケ宇呂', '26', '26202', '6240121', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '滝ケ宇呂', 'タキガウロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市地頭', '26', '26202', '6240122', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '地頭', 'ジトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市大俣', '26', '26202', '6240123', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '大俣', 'オオマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市桑飼下', '26', '26202', '6240124', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '桑飼下', 'クワガイシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市桑飼上', '26', '26202', '6240125', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '桑飼上', 'クワガイカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市寺田', '26', '26202', '6240801', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '寺田', 'テラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市上根', '26', '26202', '6240802', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '上根', 'ウエネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市白滝', '26', '26202', '6240803', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '白滝', 'シラタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市岸谷', '26', '26202', '6240804', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '岸谷', 'キシダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市別所', '26', '26202', '6240805', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '別所', 'ベッシヨ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市布敷', '26', '26202', '6240806', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '布敷', 'ヌノシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市池ノ内下', '26', '26202', '6240811', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '池ノ内下', 'イケノウチシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市堀', '26', '26202', '6240812', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '堀', 'ホリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市今田', '26', '26202', '6240813', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '今田', 'イマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市万願寺', '26', '26202', '6240814', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '万願寺', 'マンガンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市境谷', '26', '26202', '6240815', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '境谷', 'サカイダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市伊佐津', '26', '26202', '6240816', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '伊佐津', 'イサヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市公文名', '26', '26202', '6240821', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '公文名', 'クモンナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市七日市', '26', '26202', '6240822', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '七日市', 'ナヌカイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市京田', '26', '26202', '6240823', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '京田', 'キョウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市真倉', '26', '26202', '6240824', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '真倉', 'マグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市十倉', '26', '26202', '6240825', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '十倉', 'トクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市京田新町', '26', '26202', '6240826', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '京田新町', 'キョウダシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市女布', '26', '26202', '6240831', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '女布', 'ニョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市高野台', '26', '26202', '6240832', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '高野台', 'タカノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市野村寺', '26', '26202', '6240833', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '野村寺', 'ノムラジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市城屋', '26', '26202', '6240834', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '城屋', 'ジョウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市高野由里', '26', '26202', '6240835', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '高野由里', 'タカノユリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市女布北町', '26', '26202', '6240836', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '女布北町', 'ニョウキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市引土', '26', '26202', '6240841', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '引土', 'ヒキツチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市朝代', '26', '26202', '6240842', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '朝代', 'アサシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市引土新', '26', '26202', '6240843', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '引土新', 'ヒキツチシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市大内野町', '26', '26202', '6240851', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '大内野町', 'オオウチノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市大内', '26', '26202', '6240852', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '大内', 'オオウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市南田辺', '26', '26202', '6240853', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '南田辺', 'ミナミタナベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市円満寺', '26', '26202', '6240854', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '円満寺', 'エンマンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市北田辺', '26', '26202', '6240855', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '北田辺', 'キタタナベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市清美が丘', '26', '26202', '6240901', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '清美が丘', 'キヨミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市清道', '26', '26202', '6240902', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '清道', 'キヨミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市天台', '26', '26202', '6240903', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '天台', 'テンダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市昭和台', '26', '26202', '6240904', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '昭和台', 'ショウワダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市福来', '26', '26202', '6240905', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '福来', 'フキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市倉谷', '26', '26202', '6240906', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '倉谷', 'クラタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市福来問屋町', '26', '26202', '6240907', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '福来問屋町', 'フキトンヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市清道新町', '26', '26202', '6240908', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '清道新町', 'キヨミチシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市天台新町', '26', '26202', '6240909', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '天台新町', 'テンダイシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市上安東町', '26', '26202', '6240911', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '上安東町', 'ウエヤスヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市上安', '26', '26202', '6240912', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '上安', 'ウエヤス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市上安久', '26', '26202', '6240913', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '上安久', 'カミアグ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市下安久', '26', '26202', '6240914', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '下安久', 'シモアグ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市東吉原', '26', '26202', '6240921', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '東吉原', 'ヒガシヨシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市西吉原', '26', '26202', '6240922', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '西吉原', 'ニシヨシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市魚屋', '26', '26202', '6240923', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '魚屋', 'ウオヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市職人', '26', '26202', '6240924', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '職人', 'ショクニン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市丹波', '26', '26202', '6240925', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '丹波', 'タンバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市本', '26', '26202', '6240926', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '本', 'ホン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市平野屋', '26', '26202', '6240927', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '平野屋', 'ヒラノヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市竹屋', '26', '26202', '6240928', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '竹屋', 'タケヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市寺内', '26', '26202', '6240929', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '寺内', 'ジナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市松陰', '26', '26202', '6240931', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '松陰', 'マツカゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市宮津口', '26', '26202', '6240932', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '宮津口', 'ミヤヅグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市新', '26', '26202', '6240933', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '新', 'シン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市堀上', '26', '26202', '6240934', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '堀上', 'ホリカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市京口', '26', '26202', '6240935', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '京口', 'キョウグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市紺屋', '26', '26202', '6240936', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '紺屋', 'コンヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市西', '26', '26202', '6240937', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '西', 'ニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市白杉', '26', '26202', '6240941', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '白杉', 'シラスギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市青井', '26', '26202', '6240942', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '青井', 'アオイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市吉田', '26', '26202', '6240943', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '吉田', 'ヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市大君', '26', '26202', '6240944', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '大君', 'オオキミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市喜多', '26', '26202', '6240945', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '喜多', 'キタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市下福井', '26', '26202', '6240946', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '下福井', 'シモフクイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市上福井', '26', '26202', '6240951', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '上福井', 'カミフクイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市三日市', '26', '26202', '6240952', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '三日市', 'ミッカイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市八戸地', '26', '26202', '6240953', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '八戸地', 'ハトチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市八田', '26', '26202', '6240954', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '八田', 'ハッタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市丸田', '26', '26202', '6240955', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '丸田', 'マルタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市和江', '26', '26202', '6240956', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '和江', 'ワエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市西神崎', '26', '26202', '6240961', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '西神崎', 'ニシカンザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市東神崎', '26', '26202', '6240962', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '東神崎', 'ヒガシカンザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市油江', '26', '26202', '6240963', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '油江', 'ユゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市蒲江', '26', '26202', '6240964', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '蒲江', 'カマヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市水間', '26', '26202', '6240965', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '水間', 'ミズマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市中山', '26', '26202', '6240966', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '中山', 'ナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市下東', '26', '26202', '6240967', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '下東', 'シモヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市上東', '26', '26202', '6240968', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '上東', 'カミヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市', '26', '26202', '6250000', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('72447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市杉山', '26', '26202', '6250001', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '杉山', 'スギヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市登尾', '26', '26202', '6250002', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '登尾', 'ノボリオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市吉野', '26', '26202', '6250003', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '吉野', 'ヨシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市朝来西町', '26', '26202', '6250004', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '朝来西町', 'アセクニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市朝来中', '26', '26202', '6250005', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '朝来中', 'アセクナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市大波上', '26', '26202', '6250006', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '大波上', 'オオバカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市大波下', '26', '26202', '6250007', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '大波下', 'オオバシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市松尾', '26', '26202', '6250010', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '松尾', 'マツオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市吉坂', '26', '26202', '6250011', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '吉坂', 'キチサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市白屋町', '26', '26202', '6250012', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '白屋町', 'シロヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市鹿原西町', '26', '26202', '6250013', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '鹿原西町', 'カハラニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市鹿原', '26', '26202', '6250014', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '鹿原', 'カハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市岡安', '26', '26202', '6250015', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '岡安', 'オカヤス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市白屋', '26', '26202', '6250016', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '白屋', 'シロヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市小倉', '26', '26202', '6250020', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '小倉', 'オグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市安岡', '26', '26202', '6250021', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '安岡', 'ヤスオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市安岡町', '26', '26202', '6250022', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '安岡町', 'ヤスオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市田中', '26', '26202', '6250023', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '田中', 'タナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市田中町', '26', '26202', '6250024', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '田中町', 'タナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市市場', '26', '26202', '6250025', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '市場', 'イチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市泉源寺', '26', '26202', '6250026', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '泉源寺', 'センゲンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市田園町', '26', '26202', '6250027', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '田園町', 'デンエンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市愛宕上町', '26', '26202', '6250030', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '愛宕上町', 'アタゴカミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市愛宕中町', '26', '26202', '6250031', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '愛宕中町', 'アタゴナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市愛宕下町', '26', '26202', '6250032', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '愛宕下町', 'アタゴシモマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市愛宕浜町', '26', '26202', '6250033', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '愛宕浜町', 'アタゴハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市竜宮町', '26', '26202', '6250034', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '竜宮町', 'リュウグウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市溝尻', '26', '26202', '6250035', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '溝尻', 'ミゾシリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市浜', '26', '26202', '6250036', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '浜', 'ハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市矢之助町', '26', '26202', '6250040', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '矢之助町', 'ヤノスケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市溝尻中町', '26', '26202', '6250041', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '溝尻中町', 'ミゾシリナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市溝尻町', '26', '26202', '6250042', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '溝尻町', 'ミゾシリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市梅ケ谷', '26', '26202', '6250043', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '梅ケ谷', 'ウメガタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市堂奥', '26', '26202', '6250044', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '堂奥', 'ドウノオク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市多門院', '26', '26202', '6250045', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '多門院', 'タモンイン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市北浜町', '26', '26202', '6250050', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '北浜町', 'キタハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市行永東町', '26', '26202', '6250051', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '行永東町', 'ユキナガヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市行永', '26', '26202', '6250052', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '行永', 'ユキナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市金屋町', '26', '26202', '6250053', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '金屋町', 'カナヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市七条中町', '26', '26202', '6250054', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '七条中町', 'シチジョウナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市倉梯中町', '26', '26202', '6250055', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '倉梯中町', 'クラハシナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市倉梯町', '26', '26202', '6250056', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '倉梯町', 'クラハシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市南浜町', '26', '26202', '6250057', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '南浜町', 'ミナミハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市行永桜通り', '26', '26202', '6250058', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '行永桜通り', 'ユキナガサクラドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市桃山町', '26', '26202', '6250060', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '桃山町', 'モモヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市森町', '26', '26202', '6250061', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '森町', 'モリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市森', '26', '26202', '6250062', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '森', 'モリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市丸山町', '26', '26202', '6250063', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '丸山町', 'マルヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市丸山西町', '26', '26202', '6250064', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '丸山西町', 'マルヤマニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市丸山中町', '26', '26202', '6250065', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '丸山中町', 'マルヤマナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市丸山口町', '26', '26202', '6250066', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '丸山口町', 'マルヤマグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市森本町', '26', '26202', '6250067', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '森本町', 'モリホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市八反田北町', '26', '26202', '6250070', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '八反田北町', 'ハッタンダキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市常新町', '26', '26202', '6250071', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '常新町', 'ツネシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市常', '26', '26202', '6250072', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '常', 'ツネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市木ノ下', '26', '26202', '6250073', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '木ノ下', 'キノシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市与保呂', '26', '26202', '6250074', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '与保呂', 'ヨホロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市京月東町', '26', '26202', '6250075', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '京月東町', 'キョウゲツヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市京月町', '26', '26202', '6250076', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '京月町', 'キョウゲツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市亀岩町', '26', '26202', '6250077', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '亀岩町', 'カメイワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市八反田南町', '26', '26202', '6250078', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '八反田南町', 'ハッタンダミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市北吸', '26', '26202', '6250080', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '北吸', 'キタスイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市三宅', '26', '26202', '6250081', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '三宅', 'ミヤケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市つつじケ丘', '26', '26202', '6250082', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', 'つつじケ丘', 'ツツジガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市余部上', '26', '26202', '6250083', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '余部上', 'アマルベカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市白浜台', '26', '26202', '6250084', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '白浜台', 'シラハマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市和田', '26', '26202', '6250085', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '和田', 'ワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市長浜', '26', '26202', '6250086', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '長浜', 'ナガハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市余部下', '26', '26202', '6250087', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '余部下', 'アマルベシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市中田町', '26', '26202', '6250131', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '中田町', 'ナカダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市中田', '26', '26202', '6250132', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '中田', 'ナカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市平', '26', '26202', '6250133', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '平', 'タイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市佐波賀', '26', '26202', '6250134', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '佐波賀', 'サバカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市千歳', '26', '26202', '6250135', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '千歳', 'チトセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市大丹生', '26', '26202', '6250136', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '大丹生', 'オオニュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市瀬崎', '26', '26202', '6250137', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '瀬崎', 'セザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市河辺中', '26', '26202', '6250141', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '河辺中', 'カワベナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市西屋', '26', '26202', '6250142', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '西屋', 'ニシヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市室牛', '26', '26202', '6250143', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '室牛', 'ムロジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市河辺由里', '26', '26202', '6250144', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '河辺由里', 'カワベユリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市観音寺', '26', '26202', '6250145', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '観音寺', 'カンノンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市河辺原', '26', '26202', '6250146', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '河辺原', 'カワベハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市栃尾', '26', '26202', '6250147', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '栃尾', 'トチオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市赤野', '26', '26202', '6250151', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '赤野', 'アカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市多祢寺', '26', '26202', '6250152', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '多祢寺', 'タネジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市三浜', '26', '26202', '6250153', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '三浜', 'ミハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市小橋', '26', '26202', '6250154', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '小橋', 'オバセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市野原', '26', '26202', '6250155', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '野原', 'ノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市成生', '26', '26202', '6250156', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '成生', 'ナリウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市田井', '26', '26202', '6250157', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '田井', 'タイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府舞鶴市大山', '26', '26202', '6250158', '京都府', 'キョウトフ', '舞鶴市', 'マイヅルシ', '大山', 'オオヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宮津市', '26', '26205', '6260000', '京都府', 'キョウトフ', '宮津市', 'ミヤヅシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('72546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宮津市文珠', '26', '26205', '6260001', '京都府', 'キョウトフ', '宮津市', 'ミヤヅシ', '文珠', 'モンジュ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宮津市杉末', '26', '26205', '6260002', '京都府', 'キョウトフ', '宮津市', 'ミヤヅシ', '杉末', 'スギノスエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宮津市漁師', '26', '26205', '6260003', '京都府', 'キョウトフ', '宮津市', 'ミヤヅシ', '漁師', 'リョウシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宮津市川向', '26', '26205', '6260004', '京都府', 'キョウトフ', '宮津市', 'ミヤヅシ', '川向', 'カワムカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宮津市宮町', '26', '26205', '6260005', '京都府', 'キョウトフ', '宮津市', 'ミヤヅシ', '宮町', 'ミヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宮津市蛭子', '26', '26205', '6260006', '京都府', 'キョウトフ', '宮津市', 'ミヤヅシ', '蛭子', 'エビス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宮津市池ノ谷', '26', '26205', '6260007', '京都府', 'キョウトフ', '宮津市', 'ミヤヅシ', '池ノ谷', 'イケノタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宮津市万年', '26', '26205', '6260008', '京都府', 'キョウトフ', '宮津市', 'ミヤヅシ', '万年', 'マンネン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宮津市白柏', '26', '26205', '6260011', '京都府', 'キョウトフ', '宮津市', 'ミヤヅシ', '白柏', 'シラカセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宮津市浜町', '26', '26205', '6260012', '京都府', 'キョウトフ', '宮津市', 'ミヤヅシ', '浜町', 'ハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宮津市住吉', '26', '26205', '6260013', '京都府', 'キョウトフ', '宮津市', 'ミヤヅシ', '住吉', 'スミヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宮津市河原', '26', '26205', '6260014', '京都府', 'キョウトフ', '宮津市', 'ミヤヅシ', '河原', 'カワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宮津市魚屋', '26', '26205', '6260015', '京都府', 'キョウトフ', '宮津市', 'ミヤヅシ', '魚屋', 'ウオヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宮津市新浜', '26', '26205', '6260016', '京都府', 'キョウトフ', '宮津市', 'ミヤヅシ', '新浜', 'シンハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宮津市島崎', '26', '26205', '6260017', '京都府', 'キョウトフ', '宮津市', 'ミヤヅシ', '島崎', 'シマサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宮津市本町', '26', '26205', '6260018', '京都府', 'キョウトフ', '宮津市', 'ミヤヅシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宮津市万年新地', '26', '26205', '6260019', '京都府', 'キョウトフ', '宮津市', 'ミヤヅシ', '万年新地', 'マンネンシンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宮津市猟師', '26', '26205', '6260020', '京都府', 'キョウトフ', '宮津市', 'ミヤヅシ', '猟師', 'リョウシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宮津市小川', '26', '26205', '6260021', '京都府', 'キョウトフ', '宮津市', 'ミヤヅシ', '小川', 'オガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宮津市万町', '26', '26205', '6260022', '京都府', 'キョウトフ', '宮津市', 'ミヤヅシ', '万町', 'ヨロズマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宮津市宮本', '26', '26205', '6260023', '京都府', 'キョウトフ', '宮津市', 'ミヤヅシ', '宮本', 'ミヤモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宮津市柳縄手', '26', '26205', '6260024', '京都府', 'キョウトフ', '宮津市', 'ミヤヅシ', '柳縄手', 'ヤナギナワテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宮津市木ノ部', '26', '26205', '6260025', '京都府', 'キョウトフ', '宮津市', 'ミヤヅシ', '木ノ部', 'キノベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宮津市京口町', '26', '26205', '6260026', '京都府', 'キョウトフ', '宮津市', 'ミヤヅシ', '京口町', 'キョウグチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宮津市京街道', '26', '26205', '6260027', '京都府', 'キョウトフ', '宮津市', 'ミヤヅシ', '京街道', 'キョウカイドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宮津市大久保', '26', '26205', '6260028', '京都府', 'キョウトフ', '宮津市', 'ミヤヅシ', '大久保', 'オオクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宮津市金屋谷', '26', '26205', '6260029', '京都府', 'キョウトフ', '宮津市', 'ミヤヅシ', '金屋谷', 'カナヤダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宮津市京口', '26', '26205', '6260031', '京都府', 'キョウトフ', '宮津市', 'ミヤヅシ', '京口', 'キョウグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宮津市松原', '26', '26205', '6260032', '京都府', 'キョウトフ', '宮津市', 'ミヤヅシ', '松原', 'マツバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宮津市宮村', '26', '26205', '6260033', '京都府', 'キョウトフ', '宮津市', 'ミヤヅシ', '宮村', 'ミヤムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宮津市滝馬', '26', '26205', '6260034', '京都府', 'キョウトフ', '宮津市', 'ミヤヅシ', '滝馬', 'タキバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宮津市喜多', '26', '26205', '6260035', '京都府', 'キョウトフ', '宮津市', 'ミヤヅシ', '喜多', 'キタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宮津市今福', '26', '26205', '6260036', '京都府', 'キョウトフ', '宮津市', 'ミヤヅシ', '今福', 'イマフク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宮津市小田', '26', '26205', '6260037', '京都府', 'キョウトフ', '宮津市', 'ミヤヅシ', '小田', 'オダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宮津市鶴賀', '26', '26205', '6260041', '京都府', 'キョウトフ', '宮津市', 'ミヤヅシ', '鶴賀', 'ツルガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宮津市安智', '26', '26205', '6260042', '京都府', 'キョウトフ', '宮津市', 'ミヤヅシ', '安智', 'アンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宮津市惣', '26', '26205', '6260043', '京都府', 'キョウトフ', '宮津市', 'ミヤヅシ', '惣', 'ソウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宮津市吉原', '26', '26205', '6260044', '京都府', 'キョウトフ', '宮津市', 'ミヤヅシ', '吉原', 'ヨシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宮津市馬場先', '26', '26205', '6260045', '京都府', 'キョウトフ', '宮津市', 'ミヤヅシ', '馬場先', 'ババサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宮津市中ノ丁', '26', '26205', '6260046', '京都府', 'キョウトフ', '宮津市', 'ミヤヅシ', '中ノ丁', 'ナカノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宮津市外側', '26', '26205', '6260047', '京都府', 'キョウトフ', '宮津市', 'ミヤヅシ', '外側', 'ソトガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宮津市島陰', '26', '26205', '6260051', '京都府', 'キョウトフ', '宮津市', 'ミヤヅシ', '島陰', 'シマカゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宮津市小田宿野', '26', '26205', '6260052', '京都府', 'キョウトフ', '宮津市', 'ミヤヅシ', '小田宿野', 'オダシュクノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宮津市中津', '26', '26205', '6260053', '京都府', 'キョウトフ', '宮津市', 'ミヤヅシ', '中津', 'ナカツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宮津市銀丘', '26', '26205', '6260054', '京都府', 'キョウトフ', '宮津市', 'ミヤヅシ', '銀丘', 'ギンガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宮津市鏡ケ浦', '26', '26205', '6260055', '京都府', 'キョウトフ', '宮津市', 'ミヤヅシ', '鏡ケ浦', 'カガミガウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宮津市波路', '26', '26205', '6260061', '京都府', 'キョウトフ', '宮津市', 'ミヤヅシ', '波路', 'ハジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宮津市山中', '26', '26205', '6260062', '京都府', 'キョウトフ', '宮津市', 'ミヤヅシ', '山中', 'ヤマナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宮津市皆原', '26', '26205', '6260063', '京都府', 'キョウトフ', '宮津市', 'ミヤヅシ', '皆原', 'カイバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宮津市波路町', '26', '26205', '6260064', '京都府', 'キョウトフ', '宮津市', 'ミヤヅシ', '波路町', 'ハジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宮津市獅子崎', '26', '26205', '6260065', '京都府', 'キョウトフ', '宮津市', 'ミヤヅシ', '獅子崎', 'シシザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宮津市獅子', '26', '26205', '6260066', '京都府', 'キョウトフ', '宮津市', 'ミヤヅシ', '獅子', 'チシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宮津市矢原', '26', '26205', '6260067', '京都府', 'キョウトフ', '宮津市', 'ミヤヅシ', '矢原', 'ヤワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宮津市田井', '26', '26205', '6260068', '京都府', 'キョウトフ', '宮津市', 'ミヤヅシ', '田井', 'タイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宮津市由良', '26', '26205', '6260071', '京都府', 'キョウトフ', '宮津市', 'ミヤヅシ', '由良', 'ユラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宮津市石浦', '26', '26205', '6260072', '京都府', 'キョウトフ', '宮津市', 'ミヤヅシ', '石浦', 'イシウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宮津市新宮', '26', '26205', '6260073', '京都府', 'キョウトフ', '宮津市', 'ミヤヅシ', '新宮', 'シングウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宮津市上司', '26', '26205', '6260074', '京都府', 'キョウトフ', '宮津市', 'ミヤヅシ', '上司', 'ジョウシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宮津市小寺', '26', '26205', '6260075', '京都府', 'キョウトフ', '宮津市', 'ミヤヅシ', '小寺', 'コデラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宮津市中村', '26', '26205', '6260076', '京都府', 'キョウトフ', '宮津市', 'ミヤヅシ', '中村', 'ナカムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宮津市脇', '26', '26205', '6260077', '京都府', 'キョウトフ', '宮津市', 'ミヤヅシ', '脇', 'ワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宮津市田原', '26', '26205', '6260201', '京都府', 'キョウトフ', '宮津市', 'ミヤヅシ', '田原', 'タワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宮津市大島', '26', '26205', '6260202', '京都府', 'キョウトフ', '宮津市', 'ミヤヅシ', '大島', 'オオシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宮津市岩ケ鼻', '26', '26205', '6260203', '京都府', 'キョウトフ', '宮津市', 'ミヤヅシ', '岩ケ鼻', 'イワガハナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宮津市長江', '26', '26205', '6260204', '京都府', 'キョウトフ', '宮津市', 'ミヤヅシ', '長江', 'ナガエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宮津市外垣', '26', '26205', '6260205', '京都府', 'キョウトフ', '宮津市', 'ミヤヅシ', '外垣', 'トノガキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宮津市日ケ谷', '26', '26205', '6260206', '京都府', 'キョウトフ', '宮津市', 'ミヤヅシ', '日ケ谷', 'ヒガタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宮津市里波見', '26', '26205', '6260211', '京都府', 'キョウトフ', '宮津市', 'ミヤヅシ', '里波見', 'サトハミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宮津市中波見', '26', '26205', '6260212', '京都府', 'キョウトフ', '宮津市', 'ミヤヅシ', '中波見', 'ナカハミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宮津市奥波見', '26', '26205', '6260213', '京都府', 'キョウトフ', '宮津市', 'ミヤヅシ', '奥波見', 'オクハミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宮津市木子', '26', '26205', '6260221', '京都府', 'キョウトフ', '宮津市', 'ミヤヅシ', '木子', 'キゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宮津市東野', '26', '26205', '6260222', '京都府', 'キョウトフ', '宮津市', 'ミヤヅシ', '東野', 'ヒガシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宮津市松尾', '26', '26205', '6260223', '京都府', 'キョウトフ', '宮津市', 'ミヤヅシ', '松尾', 'マツオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宮津市下世屋', '26', '26205', '6260224', '京都府', 'キョウトフ', '宮津市', 'ミヤヅシ', '下世屋', 'シモセヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宮津市日置', '26', '26205', '6260225', '京都府', 'キョウトフ', '宮津市', 'ミヤヅシ', '日置', 'ヒオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宮津市畑', '26', '26205', '6260226', '京都府', 'キョウトフ', '宮津市', 'ミヤヅシ', '畑', 'ハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宮津市上世屋', '26', '26205', '6260227', '京都府', 'キョウトフ', '宮津市', 'ミヤヅシ', '上世屋', 'カミセヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府与謝郡伊根町', '26', '26463', '6260400', '京都府', 'キョウトフ', '与謝郡伊根町', 'ヨサグンイネチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('72624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府与謝郡伊根町蒲入', '26', '26463', '6260401', '京都府', 'キョウトフ', '与謝郡伊根町', 'ヨサグンイネチョウ', '蒲入', 'カマニュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府与謝郡伊根町長延', '26', '26463', '6260402', '京都府', 'キョウトフ', '与謝郡伊根町', 'ヨサグンイネチョウ', '長延', 'チョウエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府与謝郡伊根町本庄浜', '26', '26463', '6260403', '京都府', 'キョウトフ', '与謝郡伊根町', 'ヨサグンイネチョウ', '本庄浜', 'ホンジョウハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府与謝郡伊根町本庄宇治', '26', '26463', '6260404', '京都府', 'キョウトフ', '与謝郡伊根町', 'ヨサグンイネチョウ', '本庄宇治', 'ホンジョウウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府与謝郡伊根町本庄上', '26', '26463', '6260405', '京都府', 'キョウトフ', '与謝郡伊根町', 'ヨサグンイネチョウ', '本庄上', 'ホンジョウアゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府与謝郡伊根町野室', '26', '26463', '6260411', '京都府', 'キョウトフ', '与謝郡伊根町', 'ヨサグンイネチョウ', '野室', 'ノムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府与謝郡伊根町津母', '26', '26463', '6260412', '京都府', 'キョウトフ', '与謝郡伊根町', 'ヨサグンイネチョウ', '津母', 'ツモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府与謝郡伊根町泊', '26', '26463', '6260413', '京都府', 'キョウトフ', '与謝郡伊根町', 'ヨサグンイネチョウ', '泊', 'トマリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府与謝郡伊根町六万部', '26', '26463', '6260414', '京都府', 'キョウトフ', '与謝郡伊根町', 'ヨサグンイネチョウ', '六万部', 'ロクマンブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府与謝郡伊根町井室', '26', '26463', '6260415', '京都府', 'キョウトフ', '与謝郡伊根町', 'ヨサグンイネチョウ', '井室', 'イムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府与謝郡伊根町畑谷', '26', '26463', '6260416', '京都府', 'キョウトフ', '与謝郡伊根町', 'ヨサグンイネチョウ', '畑谷', 'ハタダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府与謝郡伊根町峠', '26', '26463', '6260417', '京都府', 'キョウトフ', '与謝郡伊根町', 'ヨサグンイネチョウ', '峠', 'トウゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府与謝郡伊根町新井', '26', '26463', '6260421', '京都府', 'キョウトフ', '与謝郡伊根町', 'ヨサグンイネチョウ', '新井', 'ニイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府与謝郡伊根町大原', '26', '26463', '6260422', '京都府', 'キョウトフ', '与謝郡伊根町', 'ヨサグンイネチョウ', '大原', 'オオハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府与謝郡伊根町平田', '26', '26463', '6260423', '京都府', 'キョウトフ', '与謝郡伊根町', 'ヨサグンイネチョウ', '平田', 'ヒラタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府与謝郡伊根町亀島', '26', '26463', '6260424', '京都府', 'キョウトフ', '与謝郡伊根町', 'ヨサグンイネチョウ', '亀島', 'カメシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府与謝郡伊根町日出', '26', '26463', '6260425', '京都府', 'キョウトフ', '与謝郡伊根町', 'ヨサグンイネチョウ', '日出', 'ヒデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府与謝郡伊根町菅野', '26', '26463', '6260431', '京都府', 'キョウトフ', '与謝郡伊根町', 'ヨサグンイネチョウ', '菅野', 'スガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府与謝郡伊根町本坂', '26', '26463', '6260432', '京都府', 'キョウトフ', '与謝郡伊根町', 'ヨサグンイネチョウ', '本坂', 'ホンザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府与謝郡伊根町野村', '26', '26463', '6260433', '京都府', 'キョウトフ', '与謝郡伊根町', 'ヨサグンイネチョウ', '野村', 'ノムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市', '26', '26212', '6270000', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('72649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市峰山町橋木', '26', '26212', '6270001', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '峰山町橋木', 'ミネヤマチョウハシギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市峰山町矢田', '26', '26212', '6270002', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '峰山町矢田', 'ミネヤマチョウヤタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市峰山町内記', '26', '26212', '6270003', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '峰山町内記', 'ミネヤマチョウナイキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市峰山町荒山', '26', '26212', '6270004', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '峰山町荒山', 'ミネヤマチョウアラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市峰山町新町', '26', '26212', '6270005', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '峰山町新町', 'ミネヤマチョウシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市峰山町赤坂', '26', '26212', '6270006', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '峰山町赤坂', 'ミネヤマチョウアカサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市峰山町石丸', '26', '26212', '6270007', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '峰山町石丸', 'ミネヤマチョウイシマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市峰山町丹波', '26', '26212', '6270011', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '峰山町丹波', 'ミネヤマチョウタンバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市峰山町杉谷', '26', '26212', '6270012', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '峰山町杉谷', 'ミネヤマチョウスギタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市峰山町不断', '26', '26212', '6270013', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '峰山町不断', 'ミネヤマチョウフダン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市峰山町四軒', '26', '26212', '6270014', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '峰山町四軒', 'ミネヤマチョウシケン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市峰山町吉原', '26', '26212', '6270021', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '峰山町吉原', 'ミネヤマチョウヨシワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市峰山町上', '26', '26212', '6270022', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '峰山町上', 'ミネヤマチョウカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市峰山町織元', '26', '26212', '6270023', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '峰山町織元', 'ミネヤマチョウオリモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市峰山町室', '26', '26212', '6270024', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '峰山町室', 'ミネヤマチョウムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市峰山町堺', '26', '26212', '6270025', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '峰山町堺', 'ミネヤマチョウサカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市峰山町古殿', '26', '26212', '6270026', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '峰山町古殿', 'ミネヤマチョウフルドノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市峰山町安', '26', '26212', '6270027', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '峰山町安', 'ミネヤマチョウヤス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市峰山町呉服', '26', '26212', '6270031', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '峰山町呉服', 'ミネヤマチョウゴフク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市峰山町浪花', '26', '26212', '6270032', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '峰山町浪花', 'ミネヤマチョウナニワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市峰山町白銀', '26', '26212', '6270033', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '峰山町白銀', 'ミネヤマチョウシラガネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市峰山町泉', '26', '26212', '6270034', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '峰山町泉', 'ミネヤマチョウイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市峰山町光明寺', '26', '26212', '6270035', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '峰山町光明寺', 'ミネヤマチョウコウミョウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市峰山町御旅', '26', '26212', '6270036', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '峰山町御旅', 'ミネヤマチョウオタビ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市峰山町千歳', '26', '26212', '6270037', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '峰山町千歳', 'ミネヤマチョウチトセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市峰山町富貴屋', '26', '26212', '6270038', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '峰山町富貴屋', 'ミネヤマチョウフキヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市峰山町菅', '26', '26212', '6270041', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '峰山町菅', 'ミネヤマチョウスゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市峰山町長岡', '26', '26212', '6270042', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '峰山町長岡', 'ミネヤマチョウナガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市峰山町新治', '26', '26212', '6270043', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '峰山町新治', 'ミネヤマチョウニンバリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市峰山町小西', '26', '26212', '6270044', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '峰山町小西', 'ミネヤマチョウコニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市峰山町西山', '26', '26212', '6270045', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '峰山町西山', 'ミネヤマチョウニシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市峰山町二箇', '26', '26212', '6270051', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '峰山町二箇', 'ミネヤマチョウニカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市峰山町五箇', '26', '26212', '6270052', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '峰山町五箇', 'ミネヤマチョウゴカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市峰山町鱒留', '26', '26212', '6270053', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '峰山町鱒留', 'ミネヤマチョウマスドメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市峰山町久次', '26', '26212', '6270054', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '峰山町久次', 'ミネヤマチョウヒサツギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市弥栄町野中', '26', '26212', '6270101', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '弥栄町野中', 'ヤサカチョウノナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市弥栄町須川', '26', '26212', '6270102', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '弥栄町須川', 'ヤサカチョウスガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市弥栄町溝谷', '26', '26212', '6270111', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '弥栄町溝谷', 'ヤサカチョウミゾタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市弥栄町等楽寺', '26', '26212', '6270112', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '弥栄町等楽寺', 'ヤサカチョウトウラクジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市弥栄町堤', '26', '26212', '6270121', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '弥栄町堤', 'ヤサカチョウツツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市弥栄町芋野', '26', '26212', '6270122', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '弥栄町芋野', 'ヤサカチョウイモノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市弥栄町吉沢', '26', '26212', '6270123', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '弥栄町吉沢', 'ヤサカチョウヨシサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市弥栄町和田野', '26', '26212', '6270131', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '弥栄町和田野', 'ヤサカチョウワダノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市弥栄町木橋', '26', '26212', '6270132', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '弥栄町木橋', 'ヤサカチョウキバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市弥栄町鳥取', '26', '26212', '6270133', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '弥栄町鳥取', 'ヤサカチョウトットリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市弥栄町小田', '26', '26212', '6270141', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '弥栄町小田', 'ヤサカチョウコダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市弥栄町黒部', '26', '26212', '6270142', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '弥栄町黒部', 'ヤサカチョウクロベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市弥栄町船木', '26', '26212', '6270143', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '弥栄町船木', 'ヤサカチョウフナキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市弥栄町井辺', '26', '26212', '6270144', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '弥栄町井辺', 'ヤサカチョウイノベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市弥栄町国久', '26', '26212', '6270145', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '弥栄町国久', 'ヤサカチョウクニヒサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市丹後町間人', '26', '26212', '6270201', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '丹後町間人', 'タンゴチョウタイザ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市丹後町砂方', '26', '26212', '6270202', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '丹後町砂方', 'タンゴチョウスナガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市丹後町大山', '26', '26212', '6270211', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '丹後町大山', 'タンゴチョウオオヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市丹後町三宅', '26', '26212', '6270212', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '丹後町三宅', 'タンゴチョウミヤケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市丹後町吉永', '26', '26212', '6270213', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '丹後町吉永', 'タンゴチョウヨシナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市丹後町是安', '26', '26212', '6270214', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '丹後町是安', 'タンゴチョウコレヤス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市丹後町成願寺', '26', '26212', '6270215', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '丹後町成願寺', 'タンゴチョウジョウガンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市丹後町徳光', '26', '26212', '6270216', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '丹後町徳光', 'タンゴチョウトクミツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市丹後町竹野', '26', '26212', '6270221', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '丹後町竹野', 'タンゴチョウタカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市丹後町筆石', '26', '26212', '6270222', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '丹後町筆石', 'タンゴチョウフデシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市丹後町矢畑', '26', '26212', '6270223', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '丹後町矢畑', 'タンゴチョウヤバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市丹後町岩木', '26', '26212', '6270224', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '丹後町岩木', 'タンゴチョウイワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市丹後町願興寺', '26', '26212', '6270225', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '丹後町願興寺', 'タンゴチョウガンゴウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市丹後町牧ノ谷', '26', '26212', '6270226', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '丹後町牧ノ谷', 'タンゴチョウマキノタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市丹後町家ノ谷', '26', '26212', '6270227', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '丹後町家ノ谷', 'タンゴチョウイエノタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市丹後町宮', '26', '26212', '6270228', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '丹後町宮', 'タンゴチョウミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市丹後町乗原', '26', '26212', '6270231', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '丹後町乗原', 'タンゴチョウノンバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市丹後町此代', '26', '26212', '6270232', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '丹後町此代', 'タンゴチョウコノシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市丹後町平', '26', '26212', '6270233', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '丹後町平', 'タンゴチョウヘイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市丹後町中野', '26', '26212', '6270234', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '丹後町中野', 'タンゴチョウナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市丹後町井上', '26', '26212', '6270235', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '丹後町井上', 'タンゴチョウイノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市丹後町畑', '26', '26212', '6270236', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '丹後町畑', 'タンゴチョウハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市丹後町井谷', '26', '26212', '6270237', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '丹後町井谷', 'タンゴチョウイダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市丹後町鞍内', '26', '26212', '6270238', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '丹後町鞍内', 'タンゴチョウクラウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市丹後町遠下', '26', '26212', '6270239', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '丹後町遠下', 'タンゴチョウオンゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市丹後町上野', '26', '26212', '6270241', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '丹後町上野', 'タンゴチョウウエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市丹後町久僧', '26', '26212', '6270242', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '丹後町久僧', 'タンゴチョウキュウソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市丹後町中浜', '26', '26212', '6270243', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '丹後町中浜', 'タンゴチョウナカハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市丹後町尾和', '26', '26212', '6270244', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '丹後町尾和', 'タンゴチョウオワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市丹後町袖志', '26', '26212', '6270245', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '丹後町袖志', 'タンゴチョウソデシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市丹後町谷内', '26', '26212', '6270246', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '丹後町谷内', 'タンゴチョウタニウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市丹後町上山', '26', '26212', '6270247', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '丹後町上山', 'タンゴチョウウエヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市丹後町碇', '26', '26212', '6270248', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '丹後町碇', 'タンゴチョウイカリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市丹後町三山', '26', '26212', '6270249', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '丹後町三山', 'タンゴチョウミヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市八木町船枝', '26', '26213', '6290101', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '八木町船枝', 'ヤギチョウフナエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市八木町室橋', '26', '26213', '6290102', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '八木町室橋', 'ヤギチョウムロハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市八木町諸畑', '26', '26213', '6290103', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '八木町諸畑', 'ヤギチョウモロハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市八木町日置', '26', '26213', '6290104', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '八木町日置', 'ヤギチョウヒオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市八木町野条', '26', '26213', '6290111', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '八木町野条', 'ヤギチョウノジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市八木町池上', '26', '26213', '6290112', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '八木町池上', 'ヤギチョウイケガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市八木町刑部', '26', '26213', '6290113', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '八木町刑部', 'ヤギチョウオサベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市八木町北廣瀬', '26', '26213', '6290114', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '八木町北廣瀬', 'ヤギチョウキタヒロセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市八木町山室', '26', '26213', '6290115', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '八木町山室', 'ヤギチョウヤマムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市八木町氷所', '26', '26213', '6290121', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '八木町氷所', 'ヤギチョウヒドコロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市八木町青戸', '26', '26213', '6290122', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '八木町青戸', 'ヤギチョウアオト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市八木町北屋賀', '26', '26213', '6290131', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '八木町北屋賀', 'ヤギチョウキタヤガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市八木町屋賀', '26', '26213', '6290132', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '八木町屋賀', 'ヤギチョウヤガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市八木町観音寺', '26', '26213', '6290133', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '八木町観音寺', 'ヤギチョウカンオンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市八木町西田', '26', '26213', '6290134', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '八木町西田', 'ヤギチョウニシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市八木町八木', '26', '26213', '6290141', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '八木町八木', 'ヤギチョウヤギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市八木町南廣瀬', '26', '26213', '6290151', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '八木町南廣瀬', 'ヤギチョウミナミヒロセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市八木町大藪', '26', '26213', '6290152', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '八木町大藪', 'ヤギチョウオオヤブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市八木町八木嶋', '26', '26213', '6290153', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '八木町八木嶋', 'ヤギチョウヤギノシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市八木町柴山', '26', '26213', '6290154', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '八木町柴山', 'ヤギチョウシバヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市八木町美里', '26', '26213', '6290161', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '八木町美里', 'ヤギチョウミサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市八木町鳥羽', '26', '26213', '6290162', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '八木町鳥羽', 'ヤギチョウトバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市八木町玉ノ井', '26', '26213', '6290163', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '八木町玉ノ井', 'ヤギチョウタマノイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市八木町池ノ内', '26', '26213', '6290164', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '八木町池ノ内', 'ヤギチョウイケノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市八木町木原', '26', '26213', '6290165', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '八木町木原', 'ヤギチョウキワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市八木町室河原', '26', '26213', '6290166', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '八木町室河原', 'ヤギチョウムロガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市八木町神吉', '26', '26213', '6290271', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '八木町神吉', 'ヤギチョウカミヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市日吉町保野田', '26', '26213', '6290301', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '日吉町保野田', 'ヒヨシチョウホノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市日吉町志和賀', '26', '26213', '6290302', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '日吉町志和賀', 'ヒヨシチョウシワガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市日吉町胡麻', '26', '26213', '6290311', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '日吉町胡麻', 'ヒヨシチョウゴマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市日吉町上胡麻', '26', '26213', '6290312', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '日吉町上胡麻', 'ヒヨシチョウカミゴマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市日吉町畑郷', '26', '26213', '6290313', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '日吉町畑郷', 'ヒヨシチョウハタゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市日吉町佐々江', '26', '26213', '6290321', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '日吉町佐々江', 'ヒヨシチョウササエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市日吉町四ツ谷', '26', '26213', '6290322', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '日吉町四ツ谷', 'ヒヨシチョウヨツヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市日吉町田原', '26', '26213', '6290323', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '日吉町田原', 'ヒヨシチョウタワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市日吉町生畑', '26', '26213', '6290331', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '日吉町生畑', 'ヒヨシチョウキハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市日吉町木住', '26', '26213', '6290332', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '日吉町木住', 'ヒヨシチョウコズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市日吉町中世木', '26', '26213', '6290333', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '日吉町中世木', 'ヒヨシチョウナカセキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市日吉町天若', '26', '26213', '6290334', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '日吉町天若', 'ヒヨシチョウアマワカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市日吉町中', '26', '26213', '6290335', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '日吉町中', 'ヒヨシチョウナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府南丹市日吉町殿田', '26', '26213', '6290341', '京都府', 'キョウトフ', '南丹市', 'ナンタンシ', '日吉町殿田', 'ヒヨシチョウトノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府船井郡京丹波町仏主', '26', '26407', '6291101', '京都府', 'キョウトフ', '船井郡京丹波町', 'フナイグンキョウタンバチョウ', '仏主', 'ホドス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府船井郡京丹波町上乙見', '26', '26407', '6291102', '京都府', 'キョウトフ', '船井郡京丹波町', 'フナイグンキョウタンバチョウ', '上乙見', 'カミオトミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府船井郡京丹波町下乙見', '26', '26407', '6291103', '京都府', 'キョウトフ', '船井郡京丹波町', 'フナイグンキョウタンバチョウ', '下乙見', 'シモオトミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府船井郡京丹波町篠原', '26', '26407', '6291104', '京都府', 'キョウトフ', '船井郡京丹波町', 'フナイグンキョウタンバチョウ', '篠原', 'シノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府船井郡京丹波町下粟野', '26', '26407', '6291105', '京都府', 'キョウトフ', '船井郡京丹波町', 'フナイグンキョウタンバチョウ', '下粟野', 'シモアワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府船井郡京丹波町細谷', '26', '26407', '6291106', '京都府', 'キョウトフ', '船井郡京丹波町', 'フナイグンキョウタンバチョウ', '細谷', 'ホソタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府船井郡京丹波町西河内', '26', '26407', '6291107', '京都府', 'キョウトフ', '船井郡京丹波町', 'フナイグンキョウタンバチョウ', '西河内', 'ニシカワウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府船井郡京丹波町上粟野', '26', '26407', '6291108', '京都府', 'キョウトフ', '船井郡京丹波町', 'フナイグンキョウタンバチョウ', '上粟野', 'カミアワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府船井郡京丹波町大迫', '26', '26407', '6291111', '京都府', 'キョウトフ', '船井郡京丹波町', 'フナイグンキョウタンバチョウ', '大迫', 'オオサコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府船井郡京丹波町塩谷', '26', '26407', '6291112', '京都府', 'キョウトフ', '船井郡京丹波町', 'フナイグンキョウタンバチョウ', '塩谷', 'シオタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府船井郡京丹波町長瀬', '26', '26407', '6291113', '京都府', 'キョウトフ', '船井郡京丹波町', 'フナイグンキョウタンバチョウ', '長瀬', 'ナガセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府船井郡京丹波町升谷', '26', '26407', '6291114', '京都府', 'キョウトフ', '船井郡京丹波町', 'フナイグンキョウタンバチョウ', '升谷', 'マスタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府船井郡京丹波町中山', '26', '26407', '6291115', '京都府', 'キョウトフ', '船井郡京丹波町', 'フナイグンキョウタンバチョウ', '中山', 'ナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府船井郡京丹波町市場', '26', '26407', '6291116', '京都府', 'キョウトフ', '船井郡京丹波町', 'フナイグンキョウタンバチョウ', '市場', 'イチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府船井郡京丹波町大倉', '26', '26407', '6291117', '京都府', 'キョウトフ', '船井郡京丹波町', 'フナイグンキョウタンバチョウ', '大倉', 'オオクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府船井郡京丹波町本庄', '26', '26407', '6291121', '京都府', 'キョウトフ', '船井郡京丹波町', 'フナイグンキョウタンバチョウ', '本庄', 'ホンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府船井郡京丹波町小畑', '26', '26407', '6291122', '京都府', 'キョウトフ', '船井郡京丹波町', 'フナイグンキョウタンバチョウ', '小畑', 'オバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府船井郡京丹波町坂原', '26', '26407', '6291131', '京都府', 'キョウトフ', '船井郡京丹波町', 'フナイグンキョウタンバチョウ', '坂原', 'サカバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府船井郡京丹波町中', '26', '26407', '6291132', '京都府', 'キョウトフ', '船井郡京丹波町', 'フナイグンキョウタンバチョウ', '中', 'ナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府船井郡京丹波町角', '26', '26407', '6291133', '京都府', 'キョウトフ', '船井郡京丹波町', 'フナイグンキョウタンバチョウ', '角', 'カド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府船井郡京丹波町広瀬', '26', '26407', '6291134', '京都府', 'キョウトフ', '船井郡京丹波町', 'フナイグンキョウタンバチョウ', '広瀬', 'ヒロセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府船井郡京丹波町才原', '26', '26407', '6291135', '京都府', 'キョウトフ', '船井郡京丹波町', 'フナイグンキョウタンバチョウ', '才原', 'サイバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府船井郡京丹波町安栖里', '26', '26407', '6291141', '京都府', 'キョウトフ', '船井郡京丹波町', 'フナイグンキョウタンバチョウ', '安栖里', 'アセリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府船井郡京丹波町稲次', '26', '26407', '6291142', '京都府', 'キョウトフ', '船井郡京丹波町', 'フナイグンキョウタンバチョウ', '稲次', 'イナツギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府船井郡京丹波町出野', '26', '26407', '6291143', '京都府', 'キョウトフ', '船井郡京丹波町', 'フナイグンキョウタンバチョウ', '出野', 'イデノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府船井郡京丹波町広野', '26', '26407', '6291144', '京都府', 'キョウトフ', '船井郡京丹波町', 'フナイグンキョウタンバチョウ', '広野', 'ヒロノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府船井郡京丹波町大簾', '26', '26407', '6291145', '京都府', 'キョウトフ', '船井郡京丹波町', 'フナイグンキョウタンバチョウ', '大簾', 'オオミス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市井根町', '26', '26203', '6291241', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '井根町', 'イネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市十倉名畑町', '26', '26203', '6291242', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '十倉名畑町', 'トクラナバタケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市十倉向町', '26', '26203', '6291243', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '十倉向町', 'トクラムカイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市十倉中町', '26', '26203', '6291244', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '十倉中町', 'トクラナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市十倉志茂町', '26', '26203', '6291245', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '十倉志茂町', 'トクラシモチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市忠町', '26', '26203', '6291251', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '忠町', 'タダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市佃町', '26', '26203', '6291252', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '佃町', 'ツクダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市武吉町', '26', '26203', '6291253', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '武吉町', 'タケヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市釜輪町', '26', '26203', '6291254', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '釜輪町', 'カマノワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市戸奈瀬町', '26', '26203', '6291255', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '戸奈瀬町', 'トナセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市広瀬町', '26', '26203', '6291256', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '広瀬町', 'ヒロセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市橋上町', '26', '26203', '6291257', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '橋上町', 'ハシカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市旭町', '26', '26203', '6291261', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '旭町', 'アサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市東山町', '26', '26203', '6291262', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '東山町', 'ヒガシヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市鷹栖町', '26', '26203', '6291263', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '鷹栖町', 'タカノスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市西原町', '26', '26203', '6291264', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '西原町', 'ニシバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市上原町', '26', '26203', '6291271', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '上原町', 'カンバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市下替地町', '26', '26203', '6291272', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '下替地町', 'シタノカチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市下原町', '26', '26203', '6291273', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '下原町', 'シモバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府綾部市和木町', '26', '26203', '6291274', '京都府', 'キョウトフ', '綾部市', 'アヤベシ', '和木町', 'ワギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市夜久野町畑', '26', '26201', '6291301', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '夜久野町畑', 'ヤクノチョウハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市夜久野町今西中', '26', '26201', '6291302', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '夜久野町今西中', 'ヤクノチョウイマニシナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市夜久野町井田', '26', '26201', '6291303', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '夜久野町井田', 'ヤクノチョウイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市夜久野町額田', '26', '26201', '6291304', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '夜久野町額田', 'ヤクノチョウヌカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市夜久野町千原', '26', '26201', '6291305', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '夜久野町千原', 'ヤクノチョウチハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市夜久野町日置', '26', '26201', '6291311', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '夜久野町日置', 'ヤクノチョウヘキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市夜久野町末', '26', '26201', '6291312', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '夜久野町末', 'ヤクノチョウスエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市夜久野町高内', '26', '26201', '6291313', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '夜久野町高内', 'ヤクノチョウタカウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市夜久野町小倉', '26', '26201', '6291314', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '夜久野町小倉', 'ヤクノチョウオグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市夜久野町大油子', '26', '26201', '6291315', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '夜久野町大油子', 'ヤクノチョウオユゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市夜久野町直見', '26', '26201', '6291321', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '夜久野町直見', 'ヤクノチョウナオミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市夜久野町平野', '26', '26201', '6291322', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '夜久野町平野', 'ヤクノチョウヒラノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府福知山市夜久野町板生', '26', '26201', '6291323', '京都府', 'キョウトフ', '福知山市', 'フクチヤマシ', '夜久野町板生', 'ヤクノチョウイトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府与謝郡与謝野町', '26', '26465', '6292200', '京都府', 'キョウトフ', '与謝郡与謝野町', 'ヨサグンヨサノチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('72885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宮津市小松', '26', '26205', '6292231', '京都府', 'キョウトフ', '宮津市', 'ミヤヅシ', '小松', 'コマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宮津市中野', '26', '26205', '6292232', '京都府', 'キョウトフ', '宮津市', 'ミヤヅシ', '中野', 'ナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宮津市溝尻', '26', '26205', '6292233', '京都府', 'キョウトフ', '宮津市', 'ミヤヅシ', '溝尻', 'ミゾシリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宮津市国分', '26', '26205', '6292234', '京都府', 'キョウトフ', '宮津市', 'ミヤヅシ', '国分', 'コクブン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宮津市成相寺', '26', '26205', '6292241', '京都府', 'キョウトフ', '宮津市', 'ミヤヅシ', '成相寺', 'ナリアイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宮津市大垣', '26', '26205', '6292242', '京都府', 'キョウトフ', '宮津市', 'ミヤヅシ', '大垣', 'オオガキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宮津市難波野', '26', '26205', '6292243', '京都府', 'キョウトフ', '宮津市', 'ミヤヅシ', '難波野', 'ナンバノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宮津市江尻', '26', '26205', '6292244', '京都府', 'キョウトフ', '宮津市', 'ミヤヅシ', '江尻', 'エジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府宮津市須津', '26', '26205', '6292251', '京都府', 'キョウトフ', '宮津市', 'ミヤヅシ', '須津', 'スヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府与謝郡与謝野町男山', '26', '26465', '6292261', '京都府', 'キョウトフ', '与謝郡与謝野町', 'ヨサグンヨサノチョウ', '男山', 'オトコヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府与謝郡与謝野町岩滝', '26', '26465', '6292262', '京都府', 'キョウトフ', '与謝郡与謝野町', 'ヨサグンヨサノチョウ', '岩滝', 'イワタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府与謝郡与謝野町弓木', '26', '26465', '6292263', '京都府', 'キョウトフ', '与謝郡与謝野町', 'ヨサグンヨサノチョウ', '弓木', 'ユミキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府与謝郡与謝野町上山田', '26', '26465', '6292301', '京都府', 'キョウトフ', '与謝郡与謝野町', 'ヨサグンヨサノチョウ', '上山田', 'カミヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府与謝郡与謝野町下山田', '26', '26465', '6292302', '京都府', 'キョウトフ', '与謝郡与謝野町', 'ヨサグンヨサノチョウ', '下山田', 'シモヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府与謝郡与謝野町石川', '26', '26465', '6292303', '京都府', 'キョウトフ', '与謝郡与謝野町', 'ヨサグンヨサノチョウ', '石川', 'イシカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府与謝郡与謝野町幾地', '26', '26465', '6292311', '京都府', 'キョウトフ', '与謝郡与謝野町', 'ヨサグンヨサノチョウ', '幾地', 'イクジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府与謝郡与謝野町四辻', '26', '26465', '6292312', '京都府', 'キョウトフ', '与謝郡与謝野町', 'ヨサグンヨサノチョウ', '四辻', 'ヨツツジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府与謝郡与謝野町三河内', '26', '26465', '6292313', '京都府', 'キョウトフ', '与謝郡与謝野町', 'ヨサグンヨサノチョウ', '三河内', 'ミゴウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府与謝郡与謝野町岩屋', '26', '26465', '6292314', '京都府', 'キョウトフ', '与謝郡与謝野町', 'ヨサグンヨサノチョウ', '岩屋', 'イワヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府与謝郡与謝野町加悦奥', '26', '26465', '6292401', '京都府', 'キョウトフ', '与謝郡与謝野町', 'ヨサグンヨサノチョウ', '加悦奥', 'カヤオク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府与謝郡与謝野町算所', '26', '26465', '6292402', '京都府', 'キョウトフ', '与謝郡与謝野町', 'ヨサグンヨサノチョウ', '算所', 'サンジョ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府与謝郡与謝野町加悦', '26', '26465', '6292403', '京都府', 'キョウトフ', '与謝郡与謝野町', 'ヨサグンヨサノチョウ', '加悦', 'カヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府与謝郡与謝野町後野', '26', '26465', '6292404', '京都府', 'キョウトフ', '与謝郡与謝野町', 'ヨサグンヨサノチョウ', '後野', 'ウシロノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府与謝郡与謝野町明石', '26', '26465', '6292411', '京都府', 'キョウトフ', '与謝郡与謝野町', 'ヨサグンヨサノチョウ', '明石', 'アケシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府与謝郡与謝野町香河', '26', '26465', '6292412', '京都府', 'キョウトフ', '与謝郡与謝野町', 'ヨサグンヨサノチョウ', '香河', 'カゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府与謝郡与謝野町温江', '26', '26465', '6292413', '京都府', 'キョウトフ', '与謝郡与謝野町', 'ヨサグンヨサノチョウ', '温江', 'アツエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府与謝郡与謝野町金屋', '26', '26465', '6292421', '京都府', 'キョウトフ', '与謝郡与謝野町', 'ヨサグンヨサノチョウ', '金屋', 'カナヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府与謝郡与謝野町滝', '26', '26465', '6292422', '京都府', 'キョウトフ', '与謝郡与謝野町', 'ヨサグンヨサノチョウ', '滝', 'タキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府与謝郡与謝野町与謝', '26', '26465', '6292423', '京都府', 'キョウトフ', '与謝郡与謝野町', 'ヨサグンヨサノチョウ', '与謝', 'ヨザ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市大宮町口大野', '26', '26212', '6292501', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '大宮町口大野', 'オオミヤチョウクチオオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市大宮町河辺', '26', '26212', '6292502', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '大宮町河辺', 'オオミヤチョウコウベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市大宮町周枳', '26', '26212', '6292503', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '大宮町周枳', 'オオミヤチョウスキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市大宮町善王寺', '26', '26212', '6292504', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '大宮町善王寺', 'オオミヤチョウゼンノウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市大宮町久住', '26', '26212', '6292511', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '大宮町久住', 'オオミヤチョウクスミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市大宮町五十河', '26', '26212', '6292512', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '大宮町五十河', 'オオミヤチョウイカガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市大宮町延利', '26', '26212', '6292513', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '大宮町延利', 'オオミヤチョウノブトシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市大宮町明田', '26', '26212', '6292514', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '大宮町明田', 'オオミヤチョウアケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市大宮町新宮', '26', '26212', '6292515', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '大宮町新宮', 'オオミヤチョウシングウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市大宮町森本', '26', '26212', '6292521', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '大宮町森本', 'オオミヤチョウモリモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市大宮町三重', '26', '26212', '6292522', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '大宮町三重', 'オオミヤチョウミエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市大宮町三坂', '26', '26212', '6292523', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '大宮町三坂', 'オオミヤチョウミサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市大宮町奥大野', '26', '26212', '6292531', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '大宮町奥大野', 'オオミヤチョウオクオオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市大宮町谷内', '26', '26212', '6292532', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '大宮町谷内', 'オオミヤチョウタニウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市大宮町上常吉', '26', '26212', '6292533', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '大宮町上常吉', 'オオミヤチョウカミツネヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市大宮町下常吉', '26', '26212', '6292534', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '大宮町下常吉', 'オオミヤチョウシモツネヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市網野町網野', '26', '26212', '6293101', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '網野町網野', 'アミノチョウアミノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市網野町下岡', '26', '26212', '6293102', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '網野町下岡', 'アミノチョウシモオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市網野町磯', '26', '26212', '6293103', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '網野町磯', 'アミノチョウイソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市網野町浅茂川', '26', '26212', '6293104', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '網野町浅茂川', 'アミノチョウアサモガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市網野町三津', '26', '26212', '6293111', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '網野町三津', 'アミノチョウミツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市網野町掛津', '26', '26212', '6293112', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '網野町掛津', 'アミノチョウカケヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市網野町小浜', '26', '26212', '6293113', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '網野町小浜', 'アミノチョウコバマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市網野町島津', '26', '26212', '6293121', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '網野町島津', 'アミノチョウシマヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市網野町仲禅寺', '26', '26212', '6293122', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '網野町仲禅寺', 'アミノチョウチュウゼンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市網野町高橋', '26', '26212', '6293131', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '網野町高橋', 'アミノチョウタカハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市網野町公庄', '26', '26212', '6293132', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '網野町公庄', 'アミノチョウグジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市網野町郷', '26', '26212', '6293133', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '網野町郷', 'アミノチョウゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市網野町生野内', '26', '26212', '6293134', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '網野町生野内', 'アミノチョウイクノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市網野町切畑', '26', '26212', '6293135', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '網野町切畑', 'アミノチョウキリハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市網野町新庄', '26', '26212', '6293136', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '網野町新庄', 'アミノチョウシンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市網野町木津', '26', '26212', '6293241', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '網野町木津', 'アミノチョウキツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市網野町日和田', '26', '26212', '6293242', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '網野町日和田', 'アミノチョウヒワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市網野町溝野', '26', '26212', '6293243', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '網野町溝野', 'アミノチョウミゾノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市網野町俵野', '26', '26212', '6293244', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '網野町俵野', 'アミノチョウタワラノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市網野町浜詰', '26', '26212', '6293245', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '網野町浜詰', 'アミノチョウハマヅメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市網野町塩江', '26', '26212', '6293246', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '網野町塩江', 'アミノチョウシオエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市久美浜町十楽', '26', '26212', '6293401', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '久美浜町十楽', 'クミハマチョウジュウラク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市久美浜町仲町', '26', '26212', '6293402', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '久美浜町仲町', 'クミハマチョウナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市久美浜町向町', '26', '26212', '6293403', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '久美浜町向町', 'クミハマチョウムコウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市久美浜町土居', '26', '26212', '6293404', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '久美浜町土居', 'クミハマチョウドイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市久美浜町栄町', '26', '26212', '6293405', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '久美浜町栄町', 'クミハマチョウサカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市久美浜町東本町', '26', '26212', '6293406', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '久美浜町東本町', 'クミハマチョウヒガシホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市久美浜町新橋', '26', '26212', '6293407', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '久美浜町新橋', 'クミハマチョウシンバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市久美浜町新町', '26', '26212', '6293408', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '久美浜町新町', 'クミハマチョウシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市久美浜町西本町', '26', '26212', '6293409', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '久美浜町西本町', 'クミハマチョウニシホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市久美浜町', '26', '26212', '6293410', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '久美浜町', 'クミハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市久美浜町甲坂', '26', '26212', '6293411', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '久美浜町甲坂', 'クミハマチョウコウサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市久美浜町栃谷', '26', '26212', '6293411', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '久美浜町栃谷', 'クミハマチョウトチダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市久美浜町奥三谷', '26', '26212', '6293412', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '久美浜町奥三谷', 'クミハマチョウオクミタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市久美浜町口三谷', '26', '26212', '6293412', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '久美浜町口三谷', 'クミハマチョウクチミタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市久美浜町三谷', '26', '26212', '6293412', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '久美浜町三谷', 'クミハマチョウミタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市久美浜町口馬地', '26', '26212', '6293413', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '久美浜町口馬地', 'クミハマチョウクチマジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市久美浜町奥馬地', '26', '26212', '6293414', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '久美浜町奥馬地', 'クミハマチョウオクマジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市久美浜町河梨', '26', '26212', '6293415', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '久美浜町河梨', 'クミハマチョウコウナシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市久美浜町神谷', '26', '26212', '6293416', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '久美浜町神谷', 'クミハマチョウカンダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市久美浜町葛野', '26', '26212', '6293421', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '久美浜町葛野', 'クミハマチョウカヅラノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市久美浜町河内', '26', '26212', '6293422', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '久美浜町河内', 'クミハマチョウカッチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市久美浜町箱石', '26', '26212', '6293422', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '久美浜町箱石', 'クミハマチョウハコイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市久美浜町湊宮', '26', '26212', '6293422', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '久美浜町湊宮', 'クミハマチョウミナトミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市久美浜町大向', '26', '26212', '6293423', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '久美浜町大向', 'クミハマチョウオオムカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市久美浜町旭', '26', '26212', '6293424', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '久美浜町旭', 'クミハマチョウアサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市久美浜町蒲井', '26', '26212', '6293424', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '久美浜町蒲井', 'クミハマチョウカマイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市久美浜町鹿野', '26', '26212', '6293431', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '久美浜町鹿野', 'クミハマチョウカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市久美浜町平田', '26', '26212', '6293432', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '久美浜町平田', 'クミハマチョウヒラタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市久美浜町三分', '26', '26212', '6293433', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '久美浜町三分', 'クミハマチョウサンブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市久美浜町三原', '26', '26212', '6293434', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '久美浜町三原', 'クミハマチョウミハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市久美浜町壱分', '26', '26212', '6293435', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '久美浜町壱分', 'クミハマチョウイチブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市久美浜町大井', '26', '26212', '6293436', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '久美浜町大井', 'クミハマチョウオオイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市久美浜町関', '26', '26212', '6293437', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '久美浜町関', 'クミハマチョウセキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市久美浜町浦明', '26', '26212', '6293438', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '久美浜町浦明', 'クミハマチョウウラケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市久美浜町長柄', '26', '26212', '6293438', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '久美浜町長柄', 'クミハマチョウナガラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市久美浜町神崎', '26', '26212', '6293441', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '久美浜町神崎', 'クミハマチョウカンザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市久美浜町甲山', '26', '26212', '6293442', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '久美浜町甲山', 'クミハマチョウコウヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市久美浜町海士', '26', '26212', '6293443', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '久美浜町海士', 'クミハマチョウアマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市久美浜町西橋爪', '26', '26212', '6293444', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '久美浜町西橋爪', 'クミハマチョウニシハシヅメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市久美浜町橋爪', '26', '26212', '6293444', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '久美浜町橋爪', 'クミハマチョウハシヅメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市久美浜町島', '26', '26212', '6293445', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '久美浜町島', 'クミハマチョウシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市久美浜町品田', '26', '26212', '6293446', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '久美浜町品田', 'クミハマチョウホンデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市久美浜町友重', '26', '26212', '6293447', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '久美浜町友重', 'クミハマチョウトモシゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市久美浜町坂井', '26', '26212', '6293448', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '久美浜町坂井', 'クミハマチョウサカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市久美浜町油池', '26', '26212', '6293449', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '久美浜町油池', 'クミハマチョウユイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市久美浜町永留', '26', '26212', '6293551', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '久美浜町永留', 'クミハマチョウナガドメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市久美浜町女布', '26', '26212', '6293552', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '久美浜町女布', 'クミハマチョウニョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('72999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市久美浜町長野', '26', '26212', '6293553', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '久美浜町長野', 'クミハマチョウナガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市久美浜町坂谷', '26', '26212', '6293554', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '久美浜町坂谷', 'クミハマチョウサカダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市久美浜町円頓寺', '26', '26212', '6293555', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '久美浜町円頓寺', 'クミハマチョウエンドンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市久美浜町郷', '26', '26212', '6293556', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '久美浜町郷', 'クミハマチョウゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市久美浜町竹藤', '26', '26212', '6293557', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '久美浜町竹藤', 'クミハマチョウタケフジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市久美浜町丸山', '26', '26212', '6293558', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '久美浜町丸山', 'クミハマチョウマルヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市久美浜町谷', '26', '26212', '6293559', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '久美浜町谷', 'クミハマチョウタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市久美浜町野中', '26', '26212', '6293561', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '久美浜町野中', 'クミハマチョウノナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市久美浜町佐野', '26', '26212', '6293562', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '久美浜町佐野', 'クミハマチョウサノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市久美浜町二俣', '26', '26212', '6293563', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '久美浜町二俣', 'クミハマチョウフタマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市久美浜町尉ケ畑', '26', '26212', '6293564', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '久美浜町尉ケ畑', 'クミハマチョウジョウガハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市久美浜町小桑', '26', '26212', '6293565', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '久美浜町小桑', 'クミハマチョウコグワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市久美浜町安養寺', '26', '26212', '6293566', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '久美浜町安養寺', 'クミハマチョウアンヨウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市久美浜町新庄', '26', '26212', '6293570', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '久美浜町新庄', 'クミハマチョウシンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市久美浜町芦原', '26', '26212', '6293571', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '久美浜町芦原', 'クミハマチョウアシワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市久美浜町新谷', '26', '26212', '6293572', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '久美浜町新谷', 'クミハマチョウニイダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市久美浜町出角', '26', '26212', '6293573', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '久美浜町出角', 'クミハマチョウイズスミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市久美浜町市場', '26', '26212', '6293574', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '久美浜町市場', 'クミハマチョウイチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市久美浜町金谷', '26', '26212', '6293575', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '久美浜町金谷', 'クミハマチョウカナヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市久美浜町市野々', '26', '26212', '6293576', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '久美浜町市野々', 'クミハマチョウイチノノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市久美浜町布袋野', '26', '26212', '6293577', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '久美浜町布袋野', 'クミハマチョウホタイノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市久美浜町畑', '26', '26212', '6293578', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '久美浜町畑', 'クミハマチョウハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '京都府京丹後市久美浜町須田', '26', '26212', '6293579', '京都府', 'キョウトフ', '京丹後市', 'キョウタンゴシ', '久美浜町須田', 'クミハマチョウスダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市西区', '01', '01107', '0630000', '北海道', 'ホッカイドウ', '札幌市西区', 'サッポロシニシク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('73023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市', '29', '29201', '6300000', '奈良県', 'ナラケン', '奈良市', 'ナラシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('73024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県山辺郡山添村', '29', '29322', '6300000', '奈良県', 'ナラケン', '山辺郡山添村', 'ヤマベグンヤマゾエムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('73025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市西区山の手1条', '01', '01107', '0630001', '北海道', 'ホッカイドウ', '札幌市西区', 'サッポロシニシク', '山の手1条', 'ヤマノテ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市西区山の手2条', '01', '01107', '0630002', '北海道', 'ホッカイドウ', '札幌市西区', 'サッポロシニシク', '山の手2条', 'ヤマノテ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市西区山の手3条', '01', '01107', '0630003', '北海道', 'ホッカイドウ', '札幌市西区', 'サッポロシニシク', '山の手3条', 'ヤマノテ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市西区山の手4条', '01', '01107', '0630004', '北海道', 'ホッカイドウ', '札幌市西区', 'サッポロシニシク', '山の手4条', 'ヤマノテ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市西区山の手5条', '01', '01107', '0630005', '北海道', 'ホッカイドウ', '札幌市西区', 'サッポロシニシク', '山の手5条', 'ヤマノテ05ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市西区山の手6条', '01', '01107', '0630006', '北海道', 'ホッカイドウ', '札幌市西区', 'サッポロシニシク', '山の手6条', 'ヤマノテ06ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市西区山の手7条', '01', '01107', '0630007', '北海道', 'ホッカイドウ', '札幌市西区', 'サッポロシニシク', '山の手7条', 'ヤマノテ07ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市西区山の手', '01', '01107', '0630009', '北海道', 'ホッカイドウ', '札幌市西区', 'サッポロシニシク', '山の手', 'ヤマノテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒市高山町', '29', '29209', '6300101', '奈良県', 'ナラケン', '生駒市', 'イコマシ', '高山町', 'タカヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市西区小別沢', '01', '01107', '0630011', '北海道', 'ホッカイドウ', '札幌市西区', 'サッポロシニシク', '小別沢', 'コベツザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒市鹿ノ台北', '29', '29209', '6300111', '奈良県', 'ナラケン', '生駒市', 'イコマシ', '鹿ノ台北', 'シカノダイキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒市鹿ノ台東', '29', '29209', '6300112', '奈良県', 'ナラケン', '生駒市', 'イコマシ', '鹿ノ台東', 'シカノダイヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒市鹿ノ台南', '29', '29209', '6300113', '奈良県', 'ナラケン', '生駒市', 'イコマシ', '鹿ノ台南', 'シカノダイミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒市鹿ノ台西', '29', '29209', '6300114', '奈良県', 'ナラケン', '生駒市', 'イコマシ', '鹿ノ台西', 'シカノダイニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒市鹿畑町', '29', '29209', '6300115', '奈良県', 'ナラケン', '生駒市', 'イコマシ', '鹿畑町', 'シカハタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒市美鹿の台', '29', '29209', '6300116', '奈良県', 'ナラケン', '生駒市', 'イコマシ', '美鹿の台', 'ミカノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市西区福井', '01', '01107', '0630012', '北海道', 'ホッカイドウ', '札幌市西区', 'サッポロシニシク', '福井', 'フクイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒市北大和', '29', '29209', '6300121', '奈良県', 'ナラケン', '生駒市', 'イコマシ', '北大和', 'キタヤマト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒市真弓', '29', '29209', '6300122', '奈良県', 'ナラケン', '生駒市', 'イコマシ', '真弓', 'マユミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒市真弓南', '29', '29209', '6300123', '奈良県', 'ナラケン', '生駒市', 'イコマシ', '真弓南', 'マユミミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒市上町', '29', '29209', '6300131', '奈良県', 'ナラケン', '生駒市', 'イコマシ', '上町', 'カミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒市あすか台', '29', '29209', '6300132', '奈良県', 'ナラケン', '生駒市', 'イコマシ', 'あすか台', 'アスカダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒市あすか野南', '29', '29209', '6300133', '奈良県', 'ナラケン', '生駒市', 'イコマシ', 'あすか野南', 'アスカノミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒市あすか野北', '29', '29209', '6300134', '奈良県', 'ナラケン', '生駒市', 'イコマシ', 'あすか野北', 'アスカノキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒市南田原町', '29', '29209', '6300135', '奈良県', 'ナラケン', '生駒市', 'イコマシ', '南田原町', 'ミナミタワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒市白庭台', '29', '29209', '6300136', '奈良県', 'ナラケン', '生駒市', 'イコマシ', '白庭台', 'シラニワダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒市西白庭台', '29', '29209', '6300137', '奈良県', 'ナラケン', '生駒市', 'イコマシ', '西白庭台', 'ニシシラニワダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒市ひかりが丘', '29', '29209', '6300141', '奈良県', 'ナラケン', '生駒市', 'イコマシ', 'ひかりが丘', 'ヒカリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒市北田原町', '29', '29209', '6300142', '奈良県', 'ナラケン', '生駒市', 'イコマシ', '北田原町', 'キタタハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒市', '29', '29209', '6300200', '奈良県', 'ナラケン', '生駒市', 'イコマシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('73056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒市小明町', '29', '29209', '6300201', '奈良県', 'ナラケン', '生駒市', 'イコマシ', '小明町', 'コウミョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒市生駒台南', '29', '29209', '6300202', '奈良県', 'ナラケン', '生駒市', 'イコマシ', '生駒台南', 'イコマダイミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒市生駒台北', '29', '29209', '6300203', '奈良県', 'ナラケン', '生駒市', 'イコマシ', '生駒台北', 'イコマダイキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市西区平和1条', '01', '01107', '0630021', '北海道', 'ホッカイドウ', '札幌市西区', 'サッポロシニシク', '平和1条', 'ヘイワ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒市桜ケ丘', '29', '29209', '6300211', '奈良県', 'ナラケン', '生駒市', 'イコマシ', '桜ケ丘', 'サクラガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒市辻町', '29', '29209', '6300212', '奈良県', 'ナラケン', '生駒市', 'イコマシ', '辻町', 'ツジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒市東生駒', '29', '29209', '6300213', '奈良県', 'ナラケン', '生駒市', 'イコマシ', '東生駒', 'ヒガシイコマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒市東生駒月見町', '29', '29209', '6300214', '奈良県', 'ナラケン', '生駒市', 'イコマシ', '東生駒月見町', 'ヒガシイコマツキミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒市東菜畑', '29', '29209', '6300215', '奈良県', 'ナラケン', '生駒市', 'イコマシ', '東菜畑', 'ヒガシナバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市西区平和2条', '01', '01107', '0630022', '北海道', 'ホッカイドウ', '札幌市西区', 'サッポロシニシク', '平和2条', 'ヘイワ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒市さつき台', '29', '29209', '6300221', '奈良県', 'ナラケン', '生駒市', 'イコマシ', 'さつき台', 'サツキダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒市壱分町', '29', '29209', '6300222', '奈良県', 'ナラケン', '生駒市', 'イコマシ', '壱分町', 'イチブチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒市小瀬町', '29', '29209', '6300223', '奈良県', 'ナラケン', '生駒市', 'イコマシ', '小瀬町', 'オゼチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒市萩の台', '29', '29209', '6300224', '奈良県', 'ナラケン', '生駒市', 'イコマシ', '萩の台', 'ハギノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒市東山町', '29', '29209', '6300225', '奈良県', 'ナラケン', '生駒市', 'イコマシ', '東山町', 'ヒガシヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒市小平尾町', '29', '29209', '6300226', '奈良県', 'ナラケン', '生駒市', 'イコマシ', '小平尾町', 'コビラオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒市乙田町', '29', '29209', '6300227', '奈良県', 'ナラケン', '生駒市', 'イコマシ', '乙田町', 'オトダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒市南山手台', '29', '29209', '6300228', '奈良県', 'ナラケン', '生駒市', 'イコマシ', '南山手台', 'ミナミヤマテダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市西区平和3条', '01', '01107', '0630023', '北海道', 'ホッカイドウ', '札幌市西区', 'サッポロシニシク', '平和3条', 'ヘイワ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒市菜畑町', '29', '29209', '6300231', '奈良県', 'ナラケン', '生駒市', 'イコマシ', '菜畑町', 'ナバタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒市小倉寺町', '29', '29209', '6300232', '奈良県', 'ナラケン', '生駒市', 'イコマシ', '小倉寺町', 'オグラジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒市有里町', '29', '29209', '6300233', '奈良県', 'ナラケン', '生駒市', 'イコマシ', '有里町', 'アリサトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒市萩原町', '29', '29209', '6300234', '奈良県', 'ナラケン', '生駒市', 'イコマシ', '萩原町', 'ハギハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒市藤尾町', '29', '29209', '6300235', '奈良県', 'ナラケン', '生駒市', 'イコマシ', '藤尾町', 'フジオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒市西畑町', '29', '29209', '6300236', '奈良県', 'ナラケン', '生駒市', 'イコマシ', '西畑町', 'ニシハタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒市鬼取町', '29', '29209', '6300237', '奈良県', 'ナラケン', '生駒市', 'イコマシ', '鬼取町', 'オニトリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒市大門町', '29', '29209', '6300238', '奈良県', 'ナラケン', '生駒市', 'イコマシ', '大門町', 'ダイモンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒市青山台', '29', '29209', '6300239', '奈良県', 'ナラケン', '生駒市', 'イコマシ', '青山台', 'アオヤマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒市松美台', '29', '29209', '6300241', '奈良県', 'ナラケン', '生駒市', 'イコマシ', '松美台', 'マツミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒市新生駒台', '29', '29209', '6300242', '奈良県', 'ナラケン', '生駒市', 'イコマシ', '新生駒台', 'シンイコマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒市俵口町', '29', '29209', '6300243', '奈良県', 'ナラケン', '生駒市', 'イコマシ', '俵口町', 'タワラグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒市東松ケ丘', '29', '29209', '6300244', '奈良県', 'ナラケン', '生駒市', 'イコマシ', '東松ケ丘', 'ヒガシマツガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒市北新町', '29', '29209', '6300245', '奈良県', 'ナラケン', '生駒市', 'イコマシ', '北新町', 'キタシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒市西松ケ丘', '29', '29209', '6300246', '奈良県', 'ナラケン', '生駒市', 'イコマシ', '西松ケ丘', 'ニシマツガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒市光陽台', '29', '29209', '6300247', '奈良県', 'ナラケン', '生駒市', 'イコマシ', '光陽台', 'コウヨウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒市喜里が丘', '29', '29209', '6300248', '奈良県', 'ナラケン', '生駒市', 'イコマシ', '喜里が丘', 'キリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒市谷田町', '29', '29209', '6300251', '奈良県', 'ナラケン', '生駒市', 'イコマシ', '谷田町', 'タニダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒市山崎町', '29', '29209', '6300252', '奈良県', 'ナラケン', '生駒市', 'イコマシ', '山崎町', 'ヤマサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒市新旭ケ丘', '29', '29209', '6300253', '奈良県', 'ナラケン', '生駒市', 'イコマシ', '新旭ケ丘', 'シンアサヒガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒市東旭ケ丘', '29', '29209', '6300254', '奈良県', 'ナラケン', '生駒市', 'イコマシ', '東旭ケ丘', 'ヒガシアサヒガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒市山崎新町', '29', '29209', '6300255', '奈良県', 'ナラケン', '生駒市', 'イコマシ', '山崎新町', 'ヤマサキシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒市本町', '29', '29209', '6300256', '奈良県', 'ナラケン', '生駒市', 'イコマシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒市元町', '29', '29209', '6300257', '奈良県', 'ナラケン', '生駒市', 'イコマシ', '元町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒市東新町', '29', '29209', '6300258', '奈良県', 'ナラケン', '生駒市', 'イコマシ', '東新町', 'ヒガシシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒市西旭ケ丘', '29', '29209', '6300261', '奈良県', 'ナラケン', '生駒市', 'イコマシ', '西旭ケ丘', 'ニシアサヒガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒市緑ケ丘', '29', '29209', '6300262', '奈良県', 'ナラケン', '生駒市', 'イコマシ', '緑ケ丘', 'ミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒市中菜畑', '29', '29209', '6300263', '奈良県', 'ナラケン', '生駒市', 'イコマシ', '中菜畑', 'ナカナバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒市西菜畑町', '29', '29209', '6300264', '奈良県', 'ナラケン', '生駒市', 'イコマシ', '西菜畑町', 'ニシナバタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒市軽井沢町', '29', '29209', '6300265', '奈良県', 'ナラケン', '生駒市', 'イコマシ', '軽井沢町', 'カルイザワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒市門前町', '29', '29209', '6300266', '奈良県', 'ナラケン', '生駒市', 'イコマシ', '門前町', 'モンゼンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒市仲之町', '29', '29209', '6300267', '奈良県', 'ナラケン', '生駒市', 'イコマシ', '仲之町', 'ナカノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市上石切町2丁目', '27', '27227', '6300271', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '上石切町', 'カミイシキリチョウ', null, null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('73108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大阪府東大阪市山手町', '27', '27227', '6300272', '大阪府', 'オオサカフ', '東大阪市', 'ヒガシオオサカシ', '山手町', 'ヤマテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市西区平和', '01', '01107', '0630029', '北海道', 'ホッカイドウ', '札幌市西区', 'サッポロシニシク', '平和', 'ヘイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市西区西野1条', '01', '01107', '0630031', '北海道', 'ホッカイドウ', '札幌市西区', 'サッポロシニシク', '西野1条', 'ニシノ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市西区西野2条', '01', '01107', '0630032', '北海道', 'ホッカイドウ', '札幌市西区', 'サッポロシニシク', '西野2条', 'ニシノ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市西区西野3条', '01', '01107', '0630033', '北海道', 'ホッカイドウ', '札幌市西区', 'サッポロシニシク', '西野3条', 'ニシノ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市西区西野4条', '01', '01107', '0630034', '北海道', 'ホッカイドウ', '札幌市西区', 'サッポロシニシク', '西野4条', 'ニシノ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市西区西野5条', '01', '01107', '0630035', '北海道', 'ホッカイドウ', '札幌市西区', 'サッポロシニシク', '西野5条', 'ニシノ05ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市西区西野6条', '01', '01107', '0630036', '北海道', 'ホッカイドウ', '札幌市西区', 'サッポロシニシク', '西野6条', 'ニシノ06ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市西区西野7条', '01', '01107', '0630037', '北海道', 'ホッカイドウ', '札幌市西区', 'サッポロシニシク', '西野7条', 'ニシノ07ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市西区西野8条', '01', '01107', '0630038', '北海道', 'ホッカイドウ', '札幌市西区', 'サッポロシニシク', '西野8条', 'ニシノ08ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市西区西野9条', '01', '01107', '0630039', '北海道', 'ホッカイドウ', '札幌市西区', 'サッポロシニシク', '西野9条', 'ニシノ09ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市西区西野10条', '01', '01107', '0630040', '北海道', 'ホッカイドウ', '札幌市西区', 'サッポロシニシク', '西野10条', 'ニシノ10ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市西区西野11条', '01', '01107', '0630041', '北海道', 'ホッカイドウ', '札幌市西区', 'サッポロシニシク', '西野11条', 'ニシノ11ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市西区西野12条', '01', '01107', '0630042', '北海道', 'ホッカイドウ', '札幌市西区', 'サッポロシニシク', '西野12条', 'ニシノ12ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市西区西野13条', '01', '01107', '0630043', '北海道', 'ホッカイドウ', '札幌市西区', 'サッポロシニシク', '西野13条', 'ニシノ13ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市西区西野14条', '01', '01107', '0630044', '北海道', 'ホッカイドウ', '札幌市西区', 'サッポロシニシク', '西野14条', 'ニシノ14ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市西区西野', '01', '01107', '0630049', '北海道', 'ホッカイドウ', '札幌市西区', 'サッポロシニシク', '西野', 'ニシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市西区宮の沢1条', '01', '01107', '0630051', '北海道', 'ホッカイドウ', '札幌市西区', 'サッポロシニシク', '宮の沢1条', 'ミヤノサワ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市西区宮の沢2条', '01', '01107', '0630052', '北海道', 'ホッカイドウ', '札幌市西区', 'サッポロシニシク', '宮の沢2条', 'ミヤノサワ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市西区宮の沢3条', '01', '01107', '0630053', '北海道', 'ホッカイドウ', '札幌市西区', 'サッポロシニシク', '宮の沢3条', 'ミヤノサワ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市西区宮の沢4条', '01', '01107', '0630054', '北海道', 'ホッカイドウ', '札幌市西区', 'サッポロシニシク', '宮の沢4条', 'ミヤノサワ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市西区宮の沢', '01', '01107', '0630059', '北海道', 'ホッカイドウ', '札幌市西区', 'サッポロシニシク', '宮の沢', 'ミヤノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市西区西町北', '01', '01107', '0630061', '北海道', 'ホッカイドウ', '札幌市西区', 'サッポロシニシク', '西町北', 'ニシマチキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市西区西町南', '01', '01107', '0630062', '北海道', 'ホッカイドウ', '札幌市西区', 'サッポロシニシク', '西町南', 'ニシマチミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市広岡町', '29', '29201', '6301101', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '広岡町', 'ヒロオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市下狭川町', '29', '29201', '6301102', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '下狭川町', 'シモサガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市狭川東町', '29', '29201', '6301103', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '狭川東町', 'サガワヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市狭川両町', '29', '29201', '6301104', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '狭川両町', 'サガワリョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市西狭川町', '29', '29201', '6301105', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '西狭川町', 'ニシサガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市須川町', '29', '29201', '6301111', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '須川町', 'スガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市南庄町', '29', '29201', '6301112', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '南庄町', 'ミナミショウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市北村町', '29', '29201', '6301113', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '北村町', 'キタムラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市園田町', '29', '29201', '6301121', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '園田町', 'ソノダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市平清水町', '29', '29201', '6301122', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '平清水町', 'ヒラシミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市生琉里町', '29', '29201', '6301123', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '生琉里町', 'フルサトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市中ノ川町', '29', '29201', '6301124', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '中ノ川町', 'ナカノカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市東鳴川町', '29', '29201', '6301125', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '東鳴川町', 'ヒガシナルカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市法用町', '29', '29201', '6301126', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '法用町', 'ホウヨウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市柳生下町', '29', '29201', '6301231', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '柳生下町', 'ヤギュウシモチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市興ケ原町', '29', '29201', '6301232', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '興ケ原町', 'オクガハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市邑地町', '29', '29201', '6301233', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '邑地町', 'オオジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市北野山町', '29', '29201', '6301234', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '北野山町', 'キタノヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市丹生町', '29', '29201', '6301235', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '丹生町', 'ニュウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市大保町', '29', '29201', '6301236', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '大保町', 'オオボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市柳生町', '29', '29201', '6301237', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '柳生町', 'ヤギュウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市阪原町', '29', '29201', '6301241', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '阪原町', 'サカハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市大柳生町', '29', '29201', '6301242', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '大柳生町', 'オオヤギュウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市大平尾町', '29', '29201', '6301243', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '大平尾町', 'オビラオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市忍辱山町', '29', '29201', '6301244', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '忍辱山町', 'ニンニクセンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市大慈仙町', '29', '29201', '6301245', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '大慈仙町', 'ダイジセンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市水間町', '29', '29201', '6302151', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '水間町', 'ミマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市杣ノ川町', '29', '29201', '6302152', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '杣ノ川町', 'ソマノカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市別所町', '29', '29201', '6302153', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '別所町', 'ベッシヨチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市大野町', '29', '29201', '6302161', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '大野町', 'オオノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市中貫町', '29', '29201', '6302162', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '中貫町', 'ナカヅラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市中之庄町', '29', '29201', '6302163', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '中之庄町', 'ナカノショウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市南田原町', '29', '29201', '6302164', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '南田原町', 'ミナミタワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市長谷町', '29', '29201', '6302165', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '長谷町', 'ナガタニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市矢田原町', '29', '29201', '6302166', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '矢田原町', 'ヤダワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市田原春日野町', '29', '29201', '6302167', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '田原春日野町', 'タワラカスガノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市菩提山町', '29', '29201', '6302168', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '菩提山町', 'ボダイセンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市誓多林町', '29', '29201', '6302171', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '誓多林町', 'セタリンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市沓掛町', '29', '29201', '6302172', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '沓掛町', 'クツカケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市日笠町', '29', '29201', '6302173', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '日笠町', 'ヒガサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市横田町', '29', '29201', '6302174', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '横田町', 'ヨコタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市茗荷町', '29', '29201', '6302175', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '茗荷町', 'ミョウガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市和田町', '29', '29201', '6302176', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '和田町', 'ワダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市此瀬町', '29', '29201', '6302177', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '此瀬町', 'コノセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市須山町', '29', '29201', '6302178', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '須山町', 'スヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県山辺郡山添村峰寺', '29', '29322', '6302201', '奈良県', 'ナラケン', '山辺郡山添村', 'ヤマベグンヤマゾエムラ', '峰寺', 'ミネデラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県山辺郡山添村的野', '29', '29322', '6302202', '奈良県', 'ナラケン', '山辺郡山添村', 'ヤマベグンヤマゾエムラ', '的野', 'マトノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県山辺郡山添村松尾', '29', '29322', '6302203', '奈良県', 'ナラケン', '山辺郡山添村', 'ヤマベグンヤマゾエムラ', '松尾', 'マツオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県山辺郡山添村室津', '29', '29322', '6302204', '奈良県', 'ナラケン', '山辺郡山添村', 'ヤマベグンヤマゾエムラ', '室津', 'ムロヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県山辺郡山添村桐山', '29', '29322', '6302205', '奈良県', 'ナラケン', '山辺郡山添村', 'ヤマベグンヤマゾエムラ', '桐山', 'キリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県山辺郡山添村北野', '29', '29322', '6302211', '奈良県', 'ナラケン', '山辺郡山添村', 'ヤマベグンヤマゾエムラ', '北野', 'キタノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県山辺郡山添村大塩', '29', '29322', '6302212', '奈良県', 'ナラケン', '山辺郡山添村', 'ヤマベグンヤマゾエムラ', '大塩', 'オオシオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県山辺郡山添村箕輪', '29', '29322', '6302221', '奈良県', 'ナラケン', '山辺郡山添村', 'ヤマベグンヤマゾエムラ', '箕輪', 'ミノワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県山辺郡山添村堂前', '29', '29322', '6302222', '奈良県', 'ナラケン', '山辺郡山添村', 'ヤマベグンヤマゾエムラ', '堂前', 'ドウマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県山辺郡山添村三ケ谷', '29', '29322', '6302223', '奈良県', 'ナラケン', '山辺郡山添村', 'ヤマベグンヤマゾエムラ', '三ケ谷', 'ミカダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県山辺郡山添村助命', '29', '29322', '6302224', '奈良県', 'ナラケン', '山辺郡山添村', 'ヤマベグンヤマゾエムラ', '助命', 'ゼミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県山辺郡山添村伏拝', '29', '29322', '6302225', '奈良県', 'ナラケン', '山辺郡山添村', 'ヤマベグンヤマゾエムラ', '伏拝', 'フシオガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県山辺郡山添村勝原', '29', '29322', '6302231', '奈良県', 'ナラケン', '山辺郡山添村', 'ヤマベグンヤマゾエムラ', '勝原', 'カツハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県山辺郡山添村岩屋', '29', '29322', '6302232', '奈良県', 'ナラケン', '山辺郡山添村', 'ヤマベグンヤマゾエムラ', '岩屋', 'イワヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県山辺郡山添村毛原', '29', '29322', '6302233', '奈良県', 'ナラケン', '山辺郡山添村', 'ヤマベグンヤマゾエムラ', '毛原', 'ケハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県山辺郡山添村切幡', '29', '29322', '6302234', '奈良県', 'ナラケン', '山辺郡山添村', 'ヤマベグンヤマゾエムラ', '切幡', 'キリハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市月ケ瀬石打', '29', '29201', '6302301', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '月ケ瀬石打', 'ツキガセイシウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市月ケ瀬尾山', '29', '29201', '6302302', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '月ケ瀬尾山', 'ツキガセオヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市月ケ瀬長引', '29', '29201', '6302303', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '月ケ瀬長引', 'ツキガセナガヒキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市月ケ瀬嵩', '29', '29201', '6302304', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '月ケ瀬嵩', 'ツキガセダケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市月ケ瀬月瀬', '29', '29201', '6302305', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '月ケ瀬月瀬', 'ツキガセツキセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市月ケ瀬桃香野', '29', '29201', '6302306', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '月ケ瀬桃香野', 'ツキガセモモガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県山辺郡山添村遅瀬', '29', '29322', '6302341', '奈良県', 'ナラケン', '山辺郡山添村', 'ヤマベグンヤマゾエムラ', '遅瀬', 'オソセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県山辺郡山添村広代', '29', '29322', '6302342', '奈良県', 'ナラケン', '山辺郡山添村', 'ヤマベグンヤマゾエムラ', '広代', 'ヒロダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県山辺郡山添村春日', '29', '29322', '6302343', '奈良県', 'ナラケン', '山辺郡山添村', 'ヤマベグンヤマゾエムラ', '春日', 'カスガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県山辺郡山添村大西', '29', '29322', '6302344', '奈良県', 'ナラケン', '山辺郡山添村', 'ヤマベグンヤマゾエムラ', '大西', 'オオニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県山辺郡山添村菅生', '29', '29322', '6302345', '奈良県', 'ナラケン', '山辺郡山添村', 'ヤマベグンヤマゾエムラ', '菅生', 'スゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県山辺郡山添村西波多', '29', '29322', '6302346', '奈良県', 'ナラケン', '山辺郡山添村', 'ヤマベグンヤマゾエムラ', '西波多', 'ニシハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県山辺郡山添村中峰山', '29', '29322', '6302351', '奈良県', 'ナラケン', '山辺郡山添村', 'ヤマベグンヤマゾエムラ', '中峰山', 'チュウムザン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県山辺郡山添村中之庄', '29', '29322', '6302352', '奈良県', 'ナラケン', '山辺郡山添村', 'ヤマベグンヤマゾエムラ', '中之庄', 'ナカノショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県山辺郡山添村吉田', '29', '29322', '6302353', '奈良県', 'ナラケン', '山辺郡山添村', 'ヤマベグンヤマゾエムラ', '吉田', 'ヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県山辺郡山添村広瀬', '29', '29322', '6302354', '奈良県', 'ナラケン', '山辺郡山添村', 'ヤマベグンヤマゾエムラ', '広瀬', 'ヒロセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県山辺郡山添村鵜山', '29', '29322', '6302355', '奈良県', 'ナラケン', '山辺郡山添村', 'ヤマベグンヤマゾエムラ', '鵜山', 'ウヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県山辺郡山添村片平', '29', '29322', '6302356', '奈良県', 'ナラケン', '山辺郡山添村', 'ヤマベグンヤマゾエムラ', '片平', 'カタヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県山辺郡山添村葛尾', '29', '29322', '6302357', '奈良県', 'ナラケン', '山辺郡山添村', 'ヤマベグンヤマゾエムラ', '葛尾', 'クズオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市法華寺町', '29', '29201', '6308001', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '法華寺町', 'ホッケジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市二条町', '29', '29201', '6308002', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '二条町', 'ニジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市佐紀町', '29', '29201', '6308003', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '佐紀町', 'サキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市西区二十41条', '01', '01107', '0630801', '北海道', 'ホッカイドウ', '札幌市西区', 'サッポロシニシク', '二十41条', 'ニジュウヨンケン01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市北新町', '29', '29201', '6308011', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '北新町', 'キタシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市二条大路南', '29', '29201', '6308012', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '二条大路南', 'ニジョウオオジミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市三条大路', '29', '29201', '6308013', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '三条大路', 'サンジョウオオジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市四条大路', '29', '29201', '6308014', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '四条大路', 'シジョウオオジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市四条大路南町', '29', '29201', '6308015', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '四条大路南町', 'シジョウオオジミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市南新町', '29', '29201', '6308016', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '南新町', 'ミナミシンチョウ', '（－チョウ）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('73226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市西区二十42条', '01', '01107', '0630802', '北海道', 'ホッカイドウ', '札幌市西区', 'サッポロシニシク', '二十42条', 'ニジュウヨンケン02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市尼辻町', '29', '29201', '6308021', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '尼辻町', 'アマガツジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市尼辻南町', '29', '29201', '6308022', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '尼辻南町', 'アマガツジミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市尼辻西町', '29', '29201', '6308023', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '尼辻西町', 'アマガツジニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市尼辻中町', '29', '29201', '6308024', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '尼辻中町', 'アマガツジナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市尼辻北町', '29', '29201', '6308025', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '尼辻北町', 'アマガツジキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市西区二十43条', '01', '01107', '0630803', '北海道', 'ホッカイドウ', '札幌市西区', 'サッポロシニシク', '二十43条', 'ニジュウヨンケン03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市柏木町', '29', '29201', '6308031', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '柏木町', 'カシワギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市五条町', '29', '29201', '6308032', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '五条町', 'ゴジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市五条', '29', '29201', '6308033', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '五条', 'ゴジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市五条西', '29', '29201', '6308034', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '五条西', 'ゴジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市赤膚町', '29', '29201', '6308035', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '赤膚町', 'アカハダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市五条畑', '29', '29201', '6308036', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '五条畑', 'ゴジョウバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市中町', '29', '29201', '6308037', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '中町', 'ナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市西区二十44条', '01', '01107', '0630804', '北海道', 'ホッカイドウ', '札幌市西区', 'サッポロシニシク', '二十44条', 'ニジュウヨンケン04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市六条町', '29', '29201', '6308041', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '六条町', 'ロクジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市西ノ京町', '29', '29201', '6308042', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '西ノ京町', 'ニシノキョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市六条', '29', '29201', '6308043', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '六条', 'ロクジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市六条西', '29', '29201', '6308044', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '六条西', 'ロクジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市六条緑町', '29', '29201', '6308045', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '六条緑町', 'ロクジョウミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市七条町', '29', '29201', '6308051', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '七条町', 'シチジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市七条東町', '29', '29201', '6308052', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '七条東町', 'シチジョウヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市七条', '29', '29201', '6308053', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '七条', 'シチジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市七条西町', '29', '29201', '6308054', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '七条西町', 'シチジョウニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市青山', '29', '29201', '6308101', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '青山', 'アオヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市般若寺町', '29', '29201', '6308102', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '般若寺町', 'ハンニャジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市興善院町', '29', '29201', '6308103', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '興善院町', 'コウゼンインチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市奈良阪町', '29', '29201', '6308104', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '奈良阪町', 'ナラザカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市佐保台', '29', '29201', '6308105', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '佐保台', 'サホダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市佐保台西町', '29', '29201', '6308106', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '佐保台西町', 'サホダイニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市奈保町', '29', '29201', '6308107', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '奈保町', 'ナホチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市法蓮佐保山', '29', '29201', '6308108', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '法蓮佐保山', 'ホウレンサホヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市西区琴似1条', '01', '01107', '0630811', '北海道', 'ホッカイドウ', '札幌市西区', 'サッポロシニシク', '琴似1条', 'コトニ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市半田開町', '29', '29201', '6308111', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '半田開町', 'ハンダビラキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市多門町', '29', '29201', '6308112', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '多門町', 'タモンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市法蓮町', '29', '29201', '6308113', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '法蓮町', 'ホウレンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市芝辻町', '29', '29201', '6308114', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '芝辻町', 'シバツジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市大宮町', '29', '29201', '6308115', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '大宮町', 'オオミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市西区琴似2条', '01', '01107', '0630812', '北海道', 'ホッカイドウ', '札幌市西区', 'サッポロシニシク', '琴似2条', 'コトニ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市三条宮前町', '29', '29201', '6308121', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '三条宮前町', 'サンジョウミヤマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市三条本町', '29', '29201', '6308122', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '三条本町', 'サンジョウホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市三条大宮町', '29', '29201', '6308123', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '三条大宮町', 'サンジョウオオミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市三条桧町', '29', '29201', '6308124', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '三条桧町', 'サンジョウヒノキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市三条川西町', '29', '29201', '6308125', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '三条川西町', 'サンジョウカワニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市三条栄町', '29', '29201', '6308126', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '三条栄町', 'サンジョウサカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市三条添川町', '29', '29201', '6308127', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '三条添川町', 'サンジョウソエガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市西区琴似3条', '01', '01107', '0630813', '北海道', 'ホッカイドウ', '札幌市西区', 'サッポロシニシク', '琴似3条', 'コトニ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市大森町', '29', '29201', '6308131', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '大森町', 'オオモリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市大森西町', '29', '29201', '6308132', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '大森西町', 'オオモリニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市大安寺', '29', '29201', '6308133', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '大安寺', 'ダイアンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市大安寺町', '29', '29201', '6308134', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '大安寺町', 'ダイアンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市大安寺西', '29', '29201', '6308135', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '大安寺西', 'ダイアンジニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市恋の窪', '29', '29201', '6308136', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '恋の窪', 'コイノクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市恋の窪東町', '29', '29201', '6308137', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '恋の窪東町', 'コイノクボヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市西区琴似4条', '01', '01107', '0630814', '北海道', 'ホッカイドウ', '札幌市西区', 'サッポロシニシク', '琴似4条', 'コトニ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市南京終町', '29', '29201', '6308141', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '南京終町', 'ミナミキョウバテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市肘塚町', '29', '29201', '6308142', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '肘塚町', 'カイノヅカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市桂木町', '29', '29201', '6308143', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '桂木町', 'カツラギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市東九条町', '29', '29201', '6308144', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '東九条町', 'トウクジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市八条', '29', '29201', '6308145', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '八条', 'ハチジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市八条町', '29', '29201', '6308146', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '八条町', 'ハチジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市中ノ川町', '29', '29201', '6308201', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '中ノ川町', 'ナカノカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市川上町', '29', '29201', '6308202', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '川上町', 'カワカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市東之阪町', '29', '29201', '6308203', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '東之阪町', 'ヒガシノサカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市北御門町', '29', '29201', '6308204', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '北御門町', 'キタミカドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市今在家町', '29', '29201', '6308205', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '今在家町', 'イマザイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市手貝町', '29', '29201', '6308206', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '手貝町', 'テガイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市今小路町', '29', '29201', '6308207', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '今小路町', 'イマコウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市水門町', '29', '29201', '6308208', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '水門町', 'スイモンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市西区発寒1条', '01', '01107', '0630821', '北海道', 'ホッカイドウ', '札幌市西区', 'サッポロシニシク', '発寒1条', 'ハッサム01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市雑司町', '29', '29201', '6308211', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '雑司町', 'ゾウシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市春日野町', '29', '29201', '6308212', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '春日野町', 'カスガノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市登大路町', '29', '29201', '6308213', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '登大路町', 'ノボリオオジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市東向北町', '29', '29201', '6308214', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '東向北町', 'ヒガシムキキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市東向中町', '29', '29201', '6308215', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '東向中町', 'ヒガシムキナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市東向南町', '29', '29201', '6308216', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '東向南町', 'ヒガシムキミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市橋本町', '29', '29201', '6308217', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '橋本町', 'ハシモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市樽井町', '29', '29201', '6308218', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '樽井町', 'タルイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市西区発寒2条', '01', '01107', '0630822', '北海道', 'ホッカイドウ', '札幌市西区', 'サッポロシニシク', '発寒2条', 'ハッサム02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市元林院町', '29', '29201', '6308221', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '元林院町', 'ガンリインチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市餅飯殿町', '29', '29201', '6308222', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '餅飯殿町', 'モチイドノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市角振新屋町', '29', '29201', '6308223', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '角振新屋町', 'ツノフリシンヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市角振町', '29', '29201', '6308224', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '角振町', 'ツノフリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市西御門町', '29', '29201', '6308225', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '西御門町', 'ニシミカドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市小西町', '29', '29201', '6308226', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '小西町', 'コニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市林小路町', '29', '29201', '6308227', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '林小路町', 'ハヤシコウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市上三条町', '29', '29201', '6308228', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '上三条町', 'カミサンジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市西区発寒3条', '01', '01107', '0630823', '北海道', 'ホッカイドウ', '札幌市西区', 'サッポロシニシク', '発寒3条', 'ハッサム03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市本子守町', '29', '29201', '6308231', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '本子守町', 'ホンコモリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市北向町', '29', '29201', '6308232', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '北向町', 'キタムキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市小川町', '29', '29201', '6308233', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '小川町', 'オガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市寺町', '29', '29201', '6308234', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '寺町', 'テラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市奥子守町', '29', '29201', '6308235', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '奥子守町', 'オクコモリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市下三条町', '29', '29201', '6308236', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '下三条町', 'シモサンジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市中筋町', '29', '29201', '6308237', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '中筋町', 'ナカスジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市高天市町', '29', '29201', '6308238', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '高天市町', 'タカマイチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市西区発寒4条', '01', '01107', '0630824', '北海道', 'ホッカイドウ', '札幌市西区', 'サッポロシニシク', '発寒4条', 'ハッサム04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市高天町', '29', '29201', '6308241', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '高天町', 'タカマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市漢国町', '29', '29201', '6308242', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '漢国町', 'カンゴクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市今辻子町', '29', '29201', '6308243', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '今辻子町', 'イマヅシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市三条町', '29', '29201', '6308244', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '三条町', 'サンジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市西之阪町', '29', '29201', '6308245', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '西之阪町', 'ニシノサカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市油阪地方町', '29', '29201', '6308246', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '油阪地方町', 'アブラサカジカタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市油阪町', '29', '29201', '6308247', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '油阪町', 'アブラサカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市西新在家町', '29', '29201', '6308248', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '西新在家町', 'ニシシンザイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市西区発寒5条', '01', '01107', '0630825', '北海道', 'ホッカイドウ', '札幌市西区', 'サッポロシニシク', '発寒5条', 'ハッサム05ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市西新在家号所町', '29', '29201', '6308251', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '西新在家号所町', 'ニシシンザイケゴウショチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市北小路町', '29', '29201', '6308252', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '北小路町', 'キタコウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市内侍原町', '29', '29201', '6308253', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '内侍原町', 'ナシハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市菖蒲池町', '29', '29201', '6308254', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '菖蒲池町', 'ショウブイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市阪新屋町', '29', '29201', '6308255', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '阪新屋町', 'サカノシンヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市奥芝町', '29', '29201', '6308256', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '奥芝町', 'オクシバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市畑中町', '29', '29201', '6308257', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '畑中町', 'ハタケナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市船橋町', '29', '29201', '6308258', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '船橋町', 'フナハシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市西区発寒6条', '01', '01107', '0630826', '北海道', 'ホッカイドウ', '札幌市西区', 'サッポロシニシク', '発寒6条', 'ハッサム06ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市北市町', '29', '29201', '6308261', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '北市町', 'キタイチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市北袋町', '29', '29201', '6308262', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '北袋町', 'キタフクロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市北魚屋西町', '29', '29201', '6308263', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '北魚屋西町', 'キタウオヤニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市鍋屋町', '29', '29201', '6308264', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '鍋屋町', 'ナベヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市宿院町', '29', '29201', '6308265', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '宿院町', 'シュクインチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市花芝町', '29', '29201', '6308266', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '花芝町', 'ハナシバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市大豆山突抜町', '29', '29201', '6308267', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '大豆山突抜町', 'マメヤマツキヌケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市大豆山町', '29', '29201', '6308268', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '大豆山町', 'マメヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市西区発寒7条', '01', '01107', '0630827', '北海道', 'ホッカイドウ', '札幌市西区', 'サッポロシニシク', '発寒7条', 'ハッサム07ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市坊屋敷町', '29', '29201', '6308271', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '坊屋敷町', 'ボウヤシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市東新在家町', '29', '29201', '6308272', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '東新在家町', 'ヒガシシンザイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市押上町', '29', '29201', '6308273', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '押上町', 'オシアゲチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市北半田東町', '29', '29201', '6308274', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '北半田東町', 'キタハンダヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市北半田中町', '29', '29201', '6308275', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '北半田中町', 'キタハンダナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市北半田西町', '29', '29201', '6308276', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '北半田西町', 'キタハンダニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市南半田東町', '29', '29201', '6308277', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '南半田東町', 'ミナミハンダヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市西区発寒8条', '01', '01107', '0630828', '北海道', 'ホッカイドウ', '札幌市西区', 'サッポロシニシク', '発寒8条', 'ハッサム08ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市南半田中町', '29', '29201', '6308281', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '南半田中町', 'ミナミハンダナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市南半田西町', '29', '29201', '6308282', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '南半田西町', 'ミナミハンダニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市油留木町', '29', '29201', '6308283', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '油留木町', 'ユルギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市半田横町', '29', '29201', '6308284', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '半田横町', 'ハンダヨコマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市北魚屋東町', '29', '29201', '6308285', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '北魚屋東町', 'キタウオヤヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市東包永町', '29', '29201', '6308286', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '東包永町', 'ヒガシカネナガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市西包永町', '29', '29201', '6308287', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '西包永町', 'ニシカネナガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市東笹鉾町', '29', '29201', '6308288', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '東笹鉾町', 'ヒガシササボコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市西区発寒9条', '01', '01107', '0630829', '北海道', 'ホッカイドウ', '札幌市西区', 'サッポロシニシク', '発寒9条', 'ハッサム09ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市西笹鉾町', '29', '29201', '6308291', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '西笹鉾町', 'ニシササボコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市中御門町', '29', '29201', '6308292', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '中御門町', 'ナカミカドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市川久保町', '29', '29201', '6308293', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '川久保町', 'カワクボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市押小路町', '29', '29201', '6308294', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '押小路町', 'オシコウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市半田突抜町', '29', '29201', '6308295', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '半田突抜町', 'ハンダツキヌケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市後藤町', '29', '29201', '6308296', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '後藤町', 'ゴトウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市北川端町', '29', '29201', '6308297', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '北川端町', 'キタカワバタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市西区発寒10条', '01', '01107', '0630830', '北海道', 'ホッカイドウ', '札幌市西区', 'サッポロシニシク', '発寒10条', 'ハッサム10ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市高畑町', '29', '29201', '6308301', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '高畑町', 'タカバタケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市白毫寺町', '29', '29201', '6308302', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '白毫寺町', 'ビャクゴウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市南紀寺町', '29', '29201', '6308303', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '南紀寺町', 'ミナミキデラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市南肘塚町', '29', '29201', '6308304', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '南肘塚町', 'ミナミカイノヅカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市東紀寺町', '29', '29201', '6308305', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '東紀寺町', 'ヒガシキデラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市紀寺町', '29', '29201', '6308306', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '紀寺町', 'キデラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市西紀寺町', '29', '29201', '6308307', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '西紀寺町', 'ニシキデラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市西区発寒11条', '01', '01107', '0630831', '北海道', 'ホッカイドウ', '札幌市西区', 'サッポロシニシク', '発寒11条', 'ハッサム11ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市十輪院畑町', '29', '29201', '6308311', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '十輪院畑町', 'ジュウリインハタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市十輪院町', '29', '29201', '6308312', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '十輪院町', 'ジュウリインチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市川之上町', '29', '29201', '6308313', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '川之上町', 'カワノカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市川之上突抜町', '29', '29201', '6308314', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '川之上突抜町', 'カワノカミツキヌケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市中辻町', '29', '29201', '6308315', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '中辻町', 'ナカツジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市築地之内町', '29', '29201', '6308316', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '築地之内町', 'ツジノウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市井上町', '29', '29201', '6308317', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '井上町', 'イノウエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市納院町', '29', '29201', '6308318', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '納院町', 'ノウインチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市西区発寒12条', '01', '01107', '0630832', '北海道', 'ホッカイドウ', '札幌市西区', 'サッポロシニシク', '発寒12条', 'ハッサム12ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市薬師堂町', '29', '29201', '6308321', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '薬師堂町', 'ヤクシドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市北京終町', '29', '29201', '6308322', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '北京終町', 'キタキョウバテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市京終地方東側町', '29', '29201', '6308323', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '京終地方東側町', 'キョウバテジカタヒガシガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市京終地方西側町', '29', '29201', '6308324', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '京終地方西側町', 'キョウバテジカタニシガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市西木辻町', '29', '29201', '6308325', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '西木辻町', 'ニシキツジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市瓦堂町', '29', '29201', '6308326', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '瓦堂町', 'カワラドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市東木辻町', '29', '29201', '6308327', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '東木辻町', 'ヒガシキツジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市花園町', '29', '29201', '6308328', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '花園町', 'ハナゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市西区発寒13条', '01', '01107', '0630833', '北海道', 'ホッカイドウ', '札幌市西区', 'サッポロシニシク', '発寒13条', 'ハッサム13ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市三棟町', '29', '29201', '6308331', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '三棟町', 'ミツムネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市元興寺町', '29', '29201', '6308332', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '元興寺町', 'ガンゴウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市中新屋町', '29', '29201', '6308333', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '中新屋町', 'ナカノシンヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市西新屋町', '29', '29201', '6308334', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '西新屋町', 'ニシノシンヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市鳴川町', '29', '29201', '6308335', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '鳴川町', 'ナルカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市高御門町', '29', '29201', '6308336', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '高御門町', 'タカミカドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市脇戸町', '29', '29201', '6308337', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '脇戸町', 'ワキドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市陰陽町', '29', '29201', '6308338', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '陰陽町', 'インヨウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市西区発寒14条', '01', '01107', '0630834', '北海道', 'ホッカイドウ', '札幌市西区', 'サッポロシニシク', '発寒14条', 'ハッサム14ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市南城戸町', '29', '29201', '6308341', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '南城戸町', 'ミナミジョウドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市南袋町', '29', '29201', '6308342', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '南袋町', 'ミナミフクロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市椿井町', '29', '29201', '6308343', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '椿井町', 'ツバイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市東城戸町', '29', '29201', '6308344', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '東城戸町', 'ヒガシジョウドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市西城戸町', '29', '29201', '6308345', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '西城戸町', 'ニシジョウドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市阿字万字町', '29', '29201', '6308346', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '阿字万字町', 'アゼマメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市南中町', '29', '29201', '6308347', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '南中町', 'ミナミナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市小太郎町', '29', '29201', '6308348', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '小太郎町', 'コタロウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市西区発寒15条', '01', '01107', '0630835', '北海道', 'ホッカイドウ', '札幌市西区', 'サッポロシニシク', '発寒15条', 'ハッサム15ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市南風呂町', '29', '29201', '6308351', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '南風呂町', 'ミナミフロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市北風呂町', '29', '29201', '6308352', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '北風呂町', 'キタフロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市柳町', '29', '29201', '6308353', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '柳町', 'ヤナギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市馬場町', '29', '29201', '6308354', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '馬場町', 'ババチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市南魚屋町', '29', '29201', '6308355', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '南魚屋町', 'ミナミウオヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市南新町', '29', '29201', '6308356', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '南新町', 'ミナミシンマチ', '（－マチ）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('73425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市杉ケ町', '29', '29201', '6308357', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '杉ケ町', 'スルガマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市西区発寒16条', '01', '01107', '0630836', '北海道', 'ホッカイドウ', '札幌市西区', 'サッポロシニシク', '発寒16条', 'ハッサム16ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市池之町', '29', '29201', '6308361', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '池之町', 'イケノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市東寺林町', '29', '29201', '6308362', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '東寺林町', 'ヒガシテラバヤシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市勝南院町', '29', '29201', '6308363', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '勝南院町', 'ショウナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市北室町', '29', '29201', '6308364', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '北室町', 'キタムロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市下御門町', '29', '29201', '6308365', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '下御門町', 'シモミカドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市西区発寒17条', '01', '01107', '0630837', '北海道', 'ホッカイドウ', '札幌市西区', 'サッポロシニシク', '発寒17条', 'ハッサム17ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市光明院町', '29', '29201', '6308371', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '光明院町', 'コウミョウインチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市西寺林町', '29', '29201', '6308372', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '西寺林町', 'ニシテラバヤシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市南市町', '29', '29201', '6308373', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '南市町', 'ミナミイチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市今御門町', '29', '29201', '6308374', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '今御門町', 'イマミカドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市福智院町', '29', '29201', '6308381', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '福智院町', 'フクチインチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市公納堂町', '29', '29201', '6308382', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '公納堂町', 'クノウドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市毘沙門町', '29', '29201', '6308383', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '毘沙門町', 'ビシャモンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市芝新屋町', '29', '29201', '6308384', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '芝新屋町', 'シバノシンヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市芝突抜町', '29', '29201', '6308385', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '芝突抜町', 'シバツキヌケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市鵲町', '29', '29201', '6308391', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '鵲町', 'カササギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市中院町', '29', '29201', '6308392', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '中院町', 'チュウインチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市鶴福院町', '29', '29201', '6308393', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '鶴福院町', 'ツルフクインチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市不審ケ辻子町', '29', '29201', '6308394', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '不審ケ辻子町', 'フシンガヅシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市中畑町', '29', '29201', '6308401', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '中畑町', 'ナカハタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市米谷町', '29', '29201', '6308402', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '米谷町', 'マイタニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市興隆寺町', '29', '29201', '6308403', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '興隆寺町', 'コウリュウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市南椿尾町', '29', '29201', '6308404', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '南椿尾町', 'ミナミツバオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市北椿尾町', '29', '29201', '6308405', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '北椿尾町', 'キタツバオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市西区81条西', '01', '01107', '0630841', '北海道', 'ホッカイドウ', '札幌市西区', 'サッポロシニシク', '81条西', 'ハチケン01ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市高樋町', '29', '29201', '6308411', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '高樋町', 'タカヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市虚空蔵町', '29', '29201', '6308412', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '虚空蔵町', 'コクゾウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市菩提山町', '29', '29201', '6308413', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '菩提山町', 'ボダイセンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市鉢伏町', '29', '29201', '6308414', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '鉢伏町', 'ハチブセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市西区82条西', '01', '01107', '0630842', '北海道', 'ホッカイドウ', '札幌市西区', 'サッポロシニシク', '82条西', 'ハチケン02ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市藤原町', '29', '29201', '6308421', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '藤原町', 'フジワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市横井', '29', '29201', '6308422', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '横井', 'ヨコイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市横井町', '29', '29201', '6308422', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '横井町', 'ヨコイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市出屋敷町', '29', '29201', '6308423', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '出屋敷町', 'デヤシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市古市町', '29', '29201', '6308424', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '古市町', 'フルイチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市鹿野園町', '29', '29201', '6308425', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '鹿野園町', 'ロクヤオンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市西区83条西', '01', '01107', '0630843', '北海道', 'ホッカイドウ', '札幌市西区', 'サッポロシニシク', '83条西', 'ハチケン03ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市窪之庄町', '29', '29201', '6308431', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '窪之庄町', 'クボノショウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市田中町', '29', '29201', '6308432', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '田中町', 'タナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市柴屋町', '29', '29201', '6308433', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '柴屋町', 'シバヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市山町', '29', '29201', '6308434', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '山町', 'ヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市八島町', '29', '29201', '6308435', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '八島町', 'ヤシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市西区84条西', '01', '01107', '0630844', '北海道', 'ホッカイドウ', '札幌市西区', 'サッポロシニシク', '84条西', 'ハチケン04ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市神殿町', '29', '29201', '6308441', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '神殿町', 'コドノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市北永井町', '29', '29201', '6308442', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '北永井町', 'キタナガイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市南永井町', '29', '29201', '6308443', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '南永井町', 'ミナミナガイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市今市町', '29', '29201', '6308444', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '今市町', 'イマイチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市池田町', '29', '29201', '6308445', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '池田町', 'イケダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市西区85条西', '01', '01107', '0630845', '北海道', 'ホッカイドウ', '札幌市西区', 'サッポロシニシク', '85条西', 'ハチケン05ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市北之庄町', '29', '29201', '6308451', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '北之庄町', 'キタノショウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市北之庄西町', '29', '29201', '6308452', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '北之庄西町', 'キタノショウニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市西九条町', '29', '29201', '6308453', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '西九条町', 'サイクジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市杏町', '29', '29201', '6308454', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '杏町', 'カラモモチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市西区86条西', '01', '01107', '0630846', '北海道', 'ホッカイドウ', '札幌市西区', 'サッポロシニシク', '86条西', 'ハチケン06ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市西区87条西', '01', '01107', '0630847', '北海道', 'ホッカイドウ', '札幌市西区', 'サッポロシニシク', '87条西', 'ハチケン07ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市西区88条西', '01', '01107', '0630848', '北海道', 'ホッカイドウ', '札幌市西区', 'サッポロシニシク', '88条西', 'ハチケン08ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市西区89条西', '01', '01107', '0630849', '北海道', 'ホッカイドウ', '札幌市西区', 'サッポロシニシク', '89条西', 'ハチケン09ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市西区10条西', '01', '01107', '0630850', '北海道', 'ホッカイドウ', '札幌市西区', 'サッポロシニシク', '10条西', 'ハチケン10ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市西区81条東', '01', '01107', '0630861', '北海道', 'ホッカイドウ', '札幌市西区', 'サッポロシニシク', '81条東', 'ハチケン01ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市西区82条東', '01', '01107', '0630862', '北海道', 'ホッカイドウ', '札幌市西区', 'サッポロシニシク', '82条東', 'ハチケン02ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市西区83条東', '01', '01107', '0630863', '北海道', 'ホッカイドウ', '札幌市西区', 'サッポロシニシク', '83条東', 'ハチケン03ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市西区84条東', '01', '01107', '0630864', '北海道', 'ホッカイドウ', '札幌市西区', 'サッポロシニシク', '84条東', 'ハチケン04ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市西区85条東', '01', '01107', '0630865', '北海道', 'ホッカイドウ', '札幌市西区', 'サッポロシニシク', '85条東', 'ハチケン05ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市西区86条東', '01', '01107', '0630866', '北海道', 'ホッカイドウ', '札幌市西区', 'サッポロシニシク', '86条東', 'ハチケン06ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市西区87条東', '01', '01107', '0630867', '北海道', 'ホッカイドウ', '札幌市西区', 'サッポロシニシク', '87条東', 'ハチケン07ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市西区88条東', '01', '01107', '0630868', '北海道', 'ホッカイドウ', '札幌市西区', 'サッポロシニシク', '88条東', 'ハチケン08ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市西区89条東', '01', '01107', '0630869', '北海道', 'ホッカイドウ', '札幌市西区', 'サッポロシニシク', '89条東', 'ハチケン09ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市西区10条東', '01', '01107', '0630870', '北海道', 'ホッカイドウ', '札幌市西区', 'サッポロシニシク', '10条東', 'ハチケン10ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市北登美ケ丘', '29', '29201', '6310001', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '北登美ケ丘', 'キタトミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市東登美ケ丘', '29', '29201', '6310002', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '東登美ケ丘', 'ヒガシトミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市中登美ケ丘', '29', '29201', '6310003', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '中登美ケ丘', 'ナカトミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市登美ケ丘', '29', '29201', '6310004', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '登美ケ丘', 'トミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市大渕町', '29', '29201', '6310005', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '大渕町', 'オオブチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市西登美ケ丘', '29', '29201', '6310006', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '西登美ケ丘', 'ニシトミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市松陽台', '29', '29201', '6310007', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '松陽台', 'ショウヨウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市二名町', '29', '29201', '6310008', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '二名町', 'ニミョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市押熊町', '29', '29201', '6310011', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '押熊町', 'オシクマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市中山町', '29', '29201', '6310012', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '中山町', 'ナカヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市中山町西', '29', '29201', '6310013', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '中山町西', 'ナカヤマチョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市朝日町', '29', '29201', '6310014', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '朝日町', 'アサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市学園朝日元町', '29', '29201', '6310015', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '学園朝日元町', 'ガクエンアサヒモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市学園朝日町', '29', '29201', '6310016', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '学園朝日町', 'ガクエンアサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市鶴舞東町', '29', '29201', '6310021', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '鶴舞東町', 'ツルマイヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市鶴舞西町', '29', '29201', '6310022', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '鶴舞西町', 'ツルマイニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市南登美ケ丘', '29', '29201', '6310023', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '南登美ケ丘', 'ミナミトミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市百楽園', '29', '29201', '6310024', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '百楽園', 'ヒャクラクエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市学園新田町', '29', '29201', '6310025', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '学園新田町', 'ガクエンシンデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市学園緑ケ丘', '29', '29201', '6310026', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '学園緑ケ丘', 'ガクエンミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市学園赤松町', '29', '29201', '6310027', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '学園赤松町', 'ガクエンアカマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市敷島町', '29', '29201', '6310031', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '敷島町', 'シキシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市あやめ池北', '29', '29201', '6310032', '奈良県', 'ナラケン', '奈良市', 'ナラシ', 'あやめ池北', 'アヤメイケキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市あやめ池南', '29', '29201', '6310033', '奈良県', 'ナラケン', '奈良市', 'ナラシ', 'あやめ池南', 'アヤメイケミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市学園南', '29', '29201', '6310034', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '学園南', 'ガクエンミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市学園中', '29', '29201', '6310035', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '学園中', 'ガクエンナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市学園北', '29', '29201', '6310036', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '学園北', 'ガクエンキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市学園大和町', '29', '29201', '6310041', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '学園大和町', 'ガクエンダイワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市大倭町', '29', '29201', '6310042', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '大倭町', 'オオヤマトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市菅野台', '29', '29201', '6310043', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '菅野台', 'スガノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市藤ノ木台', '29', '29201', '6310044', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '藤ノ木台', 'フジノキダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市千代ケ丘', '29', '29201', '6310045', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '千代ケ丘', 'チヨガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市西千代ケ丘', '29', '29201', '6310046', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '西千代ケ丘', 'ニシチヨガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市富雄泉ケ丘', '29', '29201', '6310051', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '富雄泉ケ丘', 'トミオイズミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市中町', '29', '29201', '6310052', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '中町', 'ナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市青垣台', '29', '29201', '6310053', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '青垣台', 'アオガキダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市石木町', '29', '29201', '6310054', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '石木町', 'イシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市大和田町', '29', '29201', '6310055', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '大和田町', 'オオワダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市丸山', '29', '29201', '6310056', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '丸山', 'マルヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市三碓', '29', '29201', '6310061', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '三碓', 'ミツガラス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市三碓町', '29', '29201', '6310061', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '三碓町', 'ミツガラスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市帝塚山', '29', '29201', '6310062', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '帝塚山', 'テヅカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市帝塚山中町', '29', '29201', '6310063', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '帝塚山中町', 'テヅカヤマナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市帝塚山南', '29', '29201', '6310064', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '帝塚山南', 'テヅカヤマミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市鳥見町', '29', '29201', '6310065', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '鳥見町', 'トリミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市帝塚山西', '29', '29201', '6310066', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '帝塚山西', 'テヅカヤマニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市二名平野', '29', '29201', '6310071', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '二名平野', 'ニミョウヒラノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市二名', '29', '29201', '6310072', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '二名', 'ニミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市二名東町', '29', '29201', '6310073', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '二名東町', 'ニミョウヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市三松', '29', '29201', '6310074', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '三松', 'ミマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市三松ケ丘', '29', '29201', '6310075', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '三松ケ丘', 'ミマツガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市富雄北', '29', '29201', '6310076', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '富雄北', 'トミオキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市富雄川西', '29', '29201', '6310077', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '富雄川西', 'トミオカワニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市富雄元町', '29', '29201', '6310078', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '富雄元町', 'トミオモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市左京', '29', '29201', '6310801', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '左京', 'サキョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市歌姫町', '29', '29201', '6310802', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '歌姫町', 'ウタヒメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市山陵町', '29', '29201', '6310803', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '山陵町', 'ミササギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市神功', '29', '29201', '6310804', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '神功', 'ジングウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市右京', '29', '29201', '6310805', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '右京', 'ウキョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市朱雀', '29', '29201', '6310806', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '朱雀', 'スザク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市秋篠町', '29', '29201', '6310811', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '秋篠町', 'アキシノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市秋篠早月町', '29', '29201', '6310812', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '秋篠早月町', 'アキシノサツキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市秋篠新町', '29', '29201', '6310813', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '秋篠新町', 'アキシノシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市秋篠三和町', '29', '29201', '6310814', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '秋篠三和町', 'アキシノサンワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市西大寺新町', '29', '29201', '6310815', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '西大寺新町', 'サイダイジシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市西大寺本町', '29', '29201', '6310816', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '西大寺本町', 'サイダイジホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市西大寺北町', '29', '29201', '6310817', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '西大寺北町', 'サイダイジキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市西大寺赤田町', '29', '29201', '6310818', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '西大寺赤田町', 'サイダイジアコダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市西大寺東町', '29', '29201', '6310821', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '西大寺東町', 'サイダイジヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市西大寺栄町', '29', '29201', '6310822', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '西大寺栄町', 'サイダイジサカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市西大寺国見町', '29', '29201', '6310823', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '西大寺国見町', 'サイダイジクニミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市西大寺南町', '29', '29201', '6310824', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '西大寺南町', 'サイダイジミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市西大寺芝町', '29', '29201', '6310825', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '西大寺芝町', 'サイダイジシバマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市西大寺町', '29', '29201', '6310826', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '西大寺町', 'サイダイジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市西大寺小坊町', '29', '29201', '6310827', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '西大寺小坊町', 'サイダイジコボウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市横領町', '29', '29201', '6310828', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '横領町', 'ヨコリョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市西大寺宝ケ丘', '29', '29201', '6310831', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '西大寺宝ケ丘', 'サイダイジタカラガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市西大寺新田町', '29', '29201', '6310832', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '西大寺新田町', 'サイダイジシンデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市西大寺野神町', '29', '29201', '6310833', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '西大寺野神町', 'サイダイジノガミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市西大寺新池町', '29', '29201', '6310834', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '西大寺新池町', 'サイダイジシンイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市西大寺高塚町', '29', '29201', '6310835', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '西大寺高塚町', 'サイダイジタカツカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市西大寺竜王町', '29', '29201', '6310836', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '西大寺竜王町', 'サイダイジリュウオウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市若葉台', '29', '29201', '6310837', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '若葉台', 'ワカバダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市青野町', '29', '29201', '6310841', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '青野町', 'アオノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市菅原町', '29', '29201', '6310842', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '菅原町', 'スガハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市疋田町', '29', '29201', '6310843', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '疋田町', 'ヒキダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市宝来町', '29', '29201', '6310844', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '宝来町', 'ホウライチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市宝来', '29', '29201', '6310845', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '宝来', 'ホウライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市平松', '29', '29201', '6310846', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '平松', 'ヒラマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県天理市', '29', '29204', '6320000', '奈良県', 'ナラケン', '天理市', 'テンリシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('73639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県天理市中之庄町', '29', '29204', '6320001', '奈良県', 'ナラケン', '天理市', 'テンリシ', '中之庄町', 'ナカノショウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県天理市和爾町', '29', '29204', '6320002', '奈良県', 'ナラケン', '天理市', 'テンリシ', '和爾町', 'ワニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県天理市岩屋町', '29', '29204', '6320003', '奈良県', 'ナラケン', '天理市', 'テンリシ', '岩屋町', 'イワヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県天理市櫟本町', '29', '29204', '6320004', '奈良県', 'ナラケン', '天理市', 'テンリシ', '櫟本町', 'イチノモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県天理市楢町', '29', '29204', '6320005', '奈良県', 'ナラケン', '天理市', 'テンリシ', '楢町', 'ナラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県天理市蔵之庄町', '29', '29204', '6320006', '奈良県', 'ナラケン', '天理市', 'テンリシ', '蔵之庄町', 'クラノショウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県天理市森本町', '29', '29204', '6320007', '奈良県', 'ナラケン', '天理市', 'テンリシ', '森本町', 'モリモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県天理市石上町', '29', '29204', '6320011', '奈良県', 'ナラケン', '天理市', 'テンリシ', '石上町', 'イソノカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県天理市豊田町', '29', '29204', '6320012', '奈良県', 'ナラケン', '天理市', 'テンリシ', '豊田町', 'トヨダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県天理市豊井町', '29', '29204', '6320013', '奈良県', 'ナラケン', '天理市', 'テンリシ', '豊井町', 'トヨイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県天理市布留町', '29', '29204', '6320014', '奈良県', 'ナラケン', '天理市', 'テンリシ', '布留町', 'フルチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県天理市三島町', '29', '29204', '6320015', '奈良県', 'ナラケン', '天理市', 'テンリシ', '三島町', 'ミシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県天理市川原城町', '29', '29204', '6320016', '奈良県', 'ナラケン', '天理市', 'テンリシ', '川原城町', 'カワハラジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県天理市田部町', '29', '29204', '6320017', '奈良県', 'ナラケン', '天理市', 'テンリシ', '田部町', 'タベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県天理市別所町', '29', '29204', '6320018', '奈良県', 'ナラケン', '天理市', 'テンリシ', '別所町', 'ベッショチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県天理市滝本町', '29', '29204', '6320021', '奈良県', 'ナラケン', '天理市', 'テンリシ', '滝本町', 'タキモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県天理市苣原町', '29', '29204', '6320022', '奈良県', 'ナラケン', '天理市', 'テンリシ', '苣原町', 'チシャワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県天理市下仁興町', '29', '29204', '6320023', '奈良県', 'ナラケン', '天理市', 'テンリシ', '下仁興町', 'シモニゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県天理市上仁興町', '29', '29204', '6320024', '奈良県', 'ナラケン', '天理市', 'テンリシ', '上仁興町', 'カミニゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県天理市藤井町', '29', '29204', '6320025', '奈良県', 'ナラケン', '天理市', 'テンリシ', '藤井町', 'フジイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県天理市内馬場町', '29', '29204', '6320031', '奈良県', 'ナラケン', '天理市', 'テンリシ', '内馬場町', 'ウチババチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県天理市杣之内町', '29', '29204', '6320032', '奈良県', 'ナラケン', '天理市', 'テンリシ', '杣之内町', 'ソマノウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県天理市勾田町', '29', '29204', '6320033', '奈良県', 'ナラケン', '天理市', 'テンリシ', '勾田町', 'マガタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県天理市丹波市町', '29', '29204', '6320034', '奈良県', 'ナラケン', '天理市', 'テンリシ', '丹波市町', 'タンバイチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県天理市守目堂町', '29', '29204', '6320035', '奈良県', 'ナラケン', '天理市', 'テンリシ', '守目堂町', 'モリメドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県天理市御経野町', '29', '29204', '6320036', '奈良県', 'ナラケン', '天理市', 'テンリシ', '御経野町', 'ゴキョウノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県天理市竹之内町', '29', '29204', '6320041', '奈良県', 'ナラケン', '天理市', 'テンリシ', '竹之内町', 'タケノウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県天理市萱生町', '29', '29204', '6320042', '奈良県', 'ナラケン', '天理市', 'テンリシ', '萱生町', 'カヨウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県天理市佐保庄町', '29', '29204', '6320043', '奈良県', 'ナラケン', '天理市', 'テンリシ', '佐保庄町', 'サホノショウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県天理市兵庫町', '29', '29204', '6320044', '奈良県', 'ナラケン', '天理市', 'テンリシ', '兵庫町', 'ヒョウゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県天理市福知堂町', '29', '29204', '6320045', '奈良県', 'ナラケン', '天理市', 'テンリシ', '福知堂町', 'フクチドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県天理市三昧田町', '29', '29204', '6320046', '奈良県', 'ナラケン', '天理市', 'テンリシ', '三昧田町', 'サンマイデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県天理市乙木町', '29', '29204', '6320047', '奈良県', 'ナラケン', '天理市', 'テンリシ', '乙木町', 'オトギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県天理市園原町', '29', '29204', '6320048', '奈良県', 'ナラケン', '天理市', 'テンリシ', '園原町', 'ソノハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県天理市中山町', '29', '29204', '6320051', '奈良県', 'ナラケン', '天理市', 'テンリシ', '中山町', 'ナカヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県天理市柳本町', '29', '29204', '6320052', '奈良県', 'ナラケン', '天理市', 'テンリシ', '柳本町', 'ヤナギモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県天理市渋谷町', '29', '29204', '6320053', '奈良県', 'ナラケン', '天理市', 'テンリシ', '渋谷町', 'シブタニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県天理市檜垣町', '29', '29204', '6320054', '奈良県', 'ナラケン', '天理市', 'テンリシ', '檜垣町', 'ヒガイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県天理市遠田町', '29', '29204', '6320055', '奈良県', 'ナラケン', '天理市', 'テンリシ', '遠田町', 'トオダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県天理市岸田町', '29', '29204', '6320056', '奈良県', 'ナラケン', '天理市', 'テンリシ', '岸田町', 'キシダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県天理市新泉町', '29', '29204', '6320057', '奈良県', 'ナラケン', '天理市', 'テンリシ', '新泉町', 'ニイズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県天理市成願寺町', '29', '29204', '6320058', '奈良県', 'ナラケン', '天理市', 'テンリシ', '成願寺町', 'ジョウガンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県天理市永原町', '29', '29204', '6320061', '奈良県', 'ナラケン', '天理市', 'テンリシ', '永原町', 'ナガハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県天理市長柄町', '29', '29204', '6320062', '奈良県', 'ナラケン', '天理市', 'テンリシ', '長柄町', 'ナガラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県天理市西長柄町', '29', '29204', '6320063', '奈良県', 'ナラケン', '天理市', 'テンリシ', '西長柄町', 'ニシナガラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県天理市海知町', '29', '29204', '6320064', '奈良県', 'ナラケン', '天理市', 'テンリシ', '海知町', 'カイチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県天理市武蔵町', '29', '29204', '6320065', '奈良県', 'ナラケン', '天理市', 'テンリシ', '武蔵町', 'ムサシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県天理市備前町', '29', '29204', '6320066', '奈良県', 'ナラケン', '天理市', 'テンリシ', '備前町', 'ビゼンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県天理市吉田町', '29', '29204', '6320067', '奈良県', 'ナラケン', '天理市', 'テンリシ', '吉田町', 'ヨシダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県天理市合場町', '29', '29204', '6320068', '奈良県', 'ナラケン', '天理市', 'テンリシ', '合場町', 'アイバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県天理市九条町', '29', '29204', '6320069', '奈良県', 'ナラケン', '天理市', 'テンリシ', '九条町', 'クジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県天理市田井庄町', '29', '29204', '6320071', '奈良県', 'ナラケン', '天理市', 'テンリシ', '田井庄町', 'タイノショウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県天理市富堂町', '29', '29204', '6320072', '奈良県', 'ナラケン', '天理市', 'テンリシ', '富堂町', 'トミドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県天理市田町', '29', '29204', '6320073', '奈良県', 'ナラケン', '天理市', 'テンリシ', '田町', 'タチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県天理市東井戸堂町', '29', '29204', '6320074', '奈良県', 'ナラケン', '天理市', 'テンリシ', '東井戸堂町', 'ヒガシイドウドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県天理市西井戸堂町', '29', '29204', '6320075', '奈良県', 'ナラケン', '天理市', 'テンリシ', '西井戸堂町', 'ニシイドウドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県天理市岩室町', '29', '29204', '6320076', '奈良県', 'ナラケン', '天理市', 'テンリシ', '岩室町', 'イワムロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県天理市平等坊町', '29', '29204', '6320077', '奈良県', 'ナラケン', '天理市', 'テンリシ', '平等坊町', 'ビョウドウボウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県天理市杉本町', '29', '29204', '6320078', '奈良県', 'ナラケン', '天理市', 'テンリシ', '杉本町', 'スギモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県天理市二階堂上ノ庄町', '29', '29204', '6320081', '奈良県', 'ナラケン', '天理市', 'テンリシ', '二階堂上ノ庄町', 'ニカイドウカミノショウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県天理市荒蒔町', '29', '29204', '6320082', '奈良県', 'ナラケン', '天理市', 'テンリシ', '荒蒔町', 'アラマキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県天理市稲葉町', '29', '29204', '6320083', '奈良県', 'ナラケン', '天理市', 'テンリシ', '稲葉町', 'イナバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県天理市嘉幡町', '29', '29204', '6320084', '奈良県', 'ナラケン', '天理市', 'テンリシ', '嘉幡町', 'カバタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県天理市小島町', '29', '29204', '6320085', '奈良県', 'ナラケン', '天理市', 'テンリシ', '小島町', 'コジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県天理市庵治町', '29', '29204', '6320086', '奈良県', 'ナラケン', '天理市', 'テンリシ', '庵治町', 'オウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県天理市二階堂南菅田町', '29', '29204', '6320087', '奈良県', 'ナラケン', '天理市', 'テンリシ', '二階堂南菅田町', 'ニカイドウミナミスガタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県天理市二階堂北菅田町', '29', '29204', '6320088', '奈良県', 'ナラケン', '天理市', 'テンリシ', '二階堂北菅田町', 'ニカイドウキタスガタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県天理市上総町', '29', '29204', '6320091', '奈良県', 'ナラケン', '天理市', 'テンリシ', '上総町', 'カンサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県天理市小田中町', '29', '29204', '6320092', '奈良県', 'ナラケン', '天理市', 'テンリシ', '小田中町', 'コダナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県天理市指柳町', '29', '29204', '6320093', '奈良県', 'ナラケン', '天理市', 'テンリシ', '指柳町', 'サシヤナギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県天理市前栽町', '29', '29204', '6320094', '奈良県', 'ナラケン', '天理市', 'テンリシ', '前栽町', 'センザイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県天理市喜殿町', '29', '29204', '6320095', '奈良県', 'ナラケン', '天理市', 'テンリシ', '喜殿町', 'キドノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県天理市小路町', '29', '29204', '6320096', '奈良県', 'ナラケン', '天理市', 'テンリシ', '小路町', 'ショウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県天理市中町', '29', '29204', '6320097', '奈良県', 'ナラケン', '天理市', 'テンリシ', '中町', 'ナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県天理市南六条町', '29', '29204', '6320098', '奈良県', 'ナラケン', '天理市', 'テンリシ', '南六条町', 'ミナミロクジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市下深川町', '29', '29201', '6320101', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '下深川町', 'シモフカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市上深川町', '29', '29201', '6320102', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '上深川町', 'カミフカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市荻町', '29', '29201', '6320103', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '荻町', 'オオギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市小倉町', '29', '29201', '6320111', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '小倉町', 'オグラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市針ケ別所町', '29', '29201', '6320112', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '針ケ別所町', 'ハリガベッショチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市都祁馬場町', '29', '29201', '6320113', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '都祁馬場町', 'ツゲババチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県天理市山田町', '29', '29204', '6320121', '奈良県', 'ナラケン', '天理市', 'テンリシ', '山田町', 'ヤマダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県天理市福住町', '29', '29204', '6320122', '奈良県', 'ナラケン', '天理市', 'テンリシ', '福住町', 'フクスミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県天理市長滝町', '29', '29204', '6320123', '奈良県', 'ナラケン', '天理市', 'テンリシ', '長滝町', 'ナガタキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市室生区下笠間', '29', '29212', '6320201', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '室生区下笠間', 'ムロウクシモカサマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市室生区上笠間', '29', '29212', '6320202', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '室生区上笠間', 'ムロウクカミカサマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市室生区深野', '29', '29212', '6320203', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '室生区深野', 'ムロウクフカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市室生区小原', '29', '29212', '6320204', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '室生区小原', 'ムロウクオハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市室生区染田', '29', '29212', '6320205', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '室生区染田', 'ムロウクソメダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市室生区多田', '29', '29212', '6320206', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '室生区多田', 'ムロウクタダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市室生区無山', '29', '29212', '6320207', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '室生区無山', 'ムロウクムヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市都祁白石町', '29', '29201', '6320221', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '都祁白石町', 'ツゲシライシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市都祁吐山町', '29', '29201', '6320231', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '都祁吐山町', 'ツゲハヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市都祁こぶしが丘', '29', '29201', '6320232', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '都祁こぶしが丘', 'ツゲコブシガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市都祁南之庄町', '29', '29201', '6320241', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '都祁南之庄町', 'ツゲミナミノショウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市都祁相河町', '29', '29201', '6320242', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '都祁相河町', 'ツゲソウゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市都祁小山戸町', '29', '29201', '6320243', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '都祁小山戸町', 'ツゲオヤマトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市来迎寺町', '29', '29201', '6320244', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '来迎寺町', 'ライコウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市藺生町', '29', '29201', '6320245', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '藺生町', 'イウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市都祁友田町', '29', '29201', '6320246', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '都祁友田町', 'ツゲトモダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市都祁甲岡町', '29', '29201', '6320247', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '都祁甲岡町', 'ツゲコウカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県奈良市針町', '29', '29201', '6320251', '奈良県', 'ナラケン', '奈良市', 'ナラシ', '針町', 'ハリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県桜井市', '29', '29206', '6330000', '奈良県', 'ナラケン', '桜井市', 'サクライシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('73756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県桜井市三輪', '29', '29206', '6330001', '奈良県', 'ナラケン', '桜井市', 'サクライシ', '三輪', 'ミワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県桜井市金屋', '29', '29206', '6330002', '奈良県', 'ナラケン', '桜井市', 'サクライシ', '金屋', 'カナヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県桜井市朝倉台東', '29', '29206', '6330003', '奈良県', 'ナラケン', '桜井市', 'サクライシ', '朝倉台東', 'アサクラダイヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県桜井市朝倉台西', '29', '29206', '6330004', '奈良県', 'ナラケン', '桜井市', 'サクライシ', '朝倉台西', 'アサクラダイニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県桜井市忍阪', '29', '29206', '6330005', '奈良県', 'ナラケン', '桜井市', 'サクライシ', '忍阪', 'オッサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県桜井市赤尾', '29', '29206', '6330006', '奈良県', 'ナラケン', '桜井市', 'サクライシ', '赤尾', 'アカオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県桜井市外山', '29', '29206', '6330007', '奈良県', 'ナラケン', '桜井市', 'サクライシ', '外山', 'トビ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県桜井市黒崎', '29', '29206', '6330011', '奈良県', 'ナラケン', '桜井市', 'サクライシ', '黒崎', 'クロザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県桜井市狛', '29', '29206', '6330012', '奈良県', 'ナラケン', '桜井市', 'サクライシ', '狛', 'コマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県桜井市岩坂', '29', '29206', '6330013', '奈良県', 'ナラケン', '桜井市', 'サクライシ', '岩坂', 'イワサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県桜井市粟原', '29', '29206', '6330014', '奈良県', 'ナラケン', '桜井市', 'サクライシ', '粟原', 'オオバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県桜井市下り尾', '29', '29206', '6330015', '奈良県', 'ナラケン', '桜井市', 'サクライシ', '下り尾', 'サガリオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県桜井市竜谷', '29', '29206', '6330016', '奈良県', 'ナラケン', '桜井市', 'サクライシ', '竜谷', 'リュウタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県桜井市慈恩寺', '29', '29206', '6330017', '奈良県', 'ナラケン', '桜井市', 'サクライシ', '慈恩寺', 'ジオンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県桜井市脇本', '29', '29206', '6330018', '奈良県', 'ナラケン', '桜井市', 'サクライシ', '脇本', 'ワキモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県桜井市倉橋', '29', '29206', '6330021', '奈良県', 'ナラケン', '桜井市', 'サクライシ', '倉橋', 'クラハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県桜井市北音羽', '29', '29206', '6330022', '奈良県', 'ナラケン', '桜井市', 'サクライシ', '北音羽', 'キタオトワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県桜井市南音羽', '29', '29206', '6330023', '奈良県', 'ナラケン', '桜井市', 'サクライシ', '南音羽', 'ミナミオトワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県桜井市針道', '29', '29206', '6330024', '奈良県', 'ナラケン', '桜井市', 'サクライシ', '針道', 'ハリミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県桜井市八井内', '29', '29206', '6330025', '奈良県', 'ナラケン', '桜井市', 'サクライシ', '八井内', 'ヤイナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県桜井市飯盛塚', '29', '29206', '6330026', '奈良県', 'ナラケン', '桜井市', 'サクライシ', '飯盛塚', 'イイモリヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県桜井市鹿路', '29', '29206', '6330027', '奈良県', 'ナラケン', '桜井市', 'サクライシ', '鹿路', 'ロクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県桜井市百市', '29', '29206', '6330028', '奈良県', 'ナラケン', '桜井市', 'サクライシ', '百市', 'モモノイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県桜井市下居', '29', '29206', '6330031', '奈良県', 'ナラケン', '桜井市', 'サクライシ', '下居', 'オリイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県桜井市多武峰', '29', '29206', '6330032', '奈良県', 'ナラケン', '桜井市', 'サクライシ', '多武峰', 'トウノミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県桜井市西口', '29', '29206', '6330033', '奈良県', 'ナラケン', '桜井市', 'サクライシ', '西口', 'ニシグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県桜井市北山', '29', '29206', '6330034', '奈良県', 'ナラケン', '桜井市', 'サクライシ', '北山', 'キタヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県桜井市今井谷', '29', '29206', '6330035', '奈良県', 'ナラケン', '桜井市', 'サクライシ', '今井谷', 'イマイダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県桜井市横柿', '29', '29206', '6330036', '奈良県', 'ナラケン', '桜井市', 'サクライシ', '横柿', 'ヨコガキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県桜井市上之宮', '29', '29206', '6330041', '奈良県', 'ナラケン', '桜井市', 'サクライシ', '上之宮', 'ウエノミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県桜井市下', '29', '29206', '6330042', '奈良県', 'ナラケン', '桜井市', 'サクライシ', '下', 'シモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県桜井市高田', '29', '29206', '6330043', '奈良県', 'ナラケン', '桜井市', 'サクライシ', '高田', 'タカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県桜井市高家', '29', '29206', '6330044', '奈良県', 'ナラケン', '桜井市', 'サクライシ', '高家', 'タイエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県桜井市山田', '29', '29206', '6330045', '奈良県', 'ナラケン', '桜井市', 'サクライシ', '山田', 'ヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県桜井市池之内', '29', '29206', '6330046', '奈良県', 'ナラケン', '桜井市', 'サクライシ', '池之内', 'イケノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県桜井市橋本', '29', '29206', '6330047', '奈良県', 'ナラケン', '桜井市', 'サクライシ', '橋本', 'ハシモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県桜井市生田', '29', '29206', '6330048', '奈良県', 'ナラケン', '桜井市', 'サクライシ', '生田', 'オイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県桜井市河西', '29', '29206', '6330051', '奈良県', 'ナラケン', '桜井市', 'サクライシ', '河西', 'カワニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県桜井市浅古', '29', '29206', '6330052', '奈良県', 'ナラケン', '桜井市', 'サクライシ', '浅古', 'アサゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県桜井市谷', '29', '29206', '6330053', '奈良県', 'ナラケン', '桜井市', 'サクライシ', '谷', 'タニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県桜井市阿部', '29', '29206', '6330054', '奈良県', 'ナラケン', '桜井市', 'サクライシ', '阿部', 'アベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県桜井市安倍木材団地', '29', '29206', '6330055', '奈良県', 'ナラケン', '桜井市', 'サクライシ', '安倍木材団地', 'アベモクザイダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県桜井市上之庄', '29', '29206', '6330061', '奈良県', 'ナラケン', '桜井市', 'サクライシ', '上之庄', 'カミノショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県桜井市粟殿', '29', '29206', '6330062', '奈良県', 'ナラケン', '桜井市', 'サクライシ', '粟殿', 'オオドノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県桜井市川合', '29', '29206', '6330063', '奈良県', 'ナラケン', '桜井市', 'サクライシ', '川合', 'カワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県桜井市戒重', '29', '29206', '6330064', '奈良県', 'ナラケン', '桜井市', 'サクライシ', '戒重', 'カイジュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県桜井市吉備', '29', '29206', '6330065', '奈良県', 'ナラケン', '桜井市', 'サクライシ', '吉備', 'キビ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県桜井市西之宮', '29', '29206', '6330066', '奈良県', 'ナラケン', '桜井市', 'サクライシ', '西之宮', 'ニシノミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県桜井市大福', '29', '29206', '6330067', '奈良県', 'ナラケン', '桜井市', 'サクライシ', '大福', 'ダイフク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県桜井市東新堂', '29', '29206', '6330068', '奈良県', 'ナラケン', '桜井市', 'サクライシ', '東新堂', 'ヒガシシンドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県桜井市穴師', '29', '29206', '6330071', '奈良県', 'ナラケン', '桜井市', 'サクライシ', '穴師', 'アナシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県桜井市箸中', '29', '29206', '6330072', '奈良県', 'ナラケン', '桜井市', 'サクライシ', '箸中', 'ハシナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県桜井市茅原', '29', '29206', '6330073', '奈良県', 'ナラケン', '桜井市', 'サクライシ', '茅原', 'チワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県桜井市芝', '29', '29206', '6330074', '奈良県', 'ナラケン', '桜井市', 'サクライシ', '芝', 'シバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県桜井市新屋敷', '29', '29206', '6330075', '奈良県', 'ナラケン', '桜井市', 'サクライシ', '新屋敷', 'シンヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県桜井市大泉', '29', '29206', '6330076', '奈良県', 'ナラケン', '桜井市', 'サクライシ', '大泉', 'オイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県桜井市大西', '29', '29206', '6330077', '奈良県', 'ナラケン', '桜井市', 'サクライシ', '大西', 'オオニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県桜井市豊前', '29', '29206', '6330078', '奈良県', 'ナラケン', '桜井市', 'サクライシ', '豊前', 'ブンゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県桜井市豊田', '29', '29206', '6330079', '奈良県', 'ナラケン', '桜井市', 'サクライシ', '豊田', 'トヨダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県桜井市草川', '29', '29206', '6330081', '奈良県', 'ナラケン', '桜井市', 'サクライシ', '草川', 'クサカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県桜井市巻野内', '29', '29206', '6330082', '奈良県', 'ナラケン', '桜井市', 'サクライシ', '巻野内', 'マキノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県桜井市辻', '29', '29206', '6330083', '奈良県', 'ナラケン', '桜井市', 'サクライシ', '辻', 'ツジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県桜井市太田', '29', '29206', '6330084', '奈良県', 'ナラケン', '桜井市', 'サクライシ', '太田', 'オオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県桜井市東田', '29', '29206', '6330085', '奈良県', 'ナラケン', '桜井市', 'サクライシ', '東田', 'ヒガシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県桜井市江包', '29', '29206', '6330086', '奈良県', 'ナラケン', '桜井市', 'サクライシ', '江包', 'エツツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県桜井市大豆越', '29', '29206', '6330087', '奈良県', 'ナラケン', '桜井市', 'サクライシ', '大豆越', 'マメゴシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県桜井市桜井', '29', '29206', '6330091', '奈良県', 'ナラケン', '桜井市', 'サクライシ', '桜井', 'サクライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県桜井市小夫', '29', '29206', '6330101', '奈良県', 'ナラケン', '桜井市', 'サクライシ', '小夫', 'オオブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県桜井市三谷', '29', '29206', '6330102', '奈良県', 'ナラケン', '桜井市', 'サクライシ', '三谷', 'ミタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県桜井市小夫嵩方', '29', '29206', '6330103', '奈良県', 'ナラケン', '桜井市', 'サクライシ', '小夫嵩方', 'オオブダケホウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県桜井市芹井', '29', '29206', '6330104', '奈良県', 'ナラケン', '桜井市', 'サクライシ', '芹井', 'セリイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県桜井市白木', '29', '29206', '6330105', '奈良県', 'ナラケン', '桜井市', 'サクライシ', '白木', 'シラキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県桜井市萱森', '29', '29206', '6330106', '奈良県', 'ナラケン', '桜井市', 'サクライシ', '萱森', 'カヤモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県桜井市中谷', '29', '29206', '6330107', '奈良県', 'ナラケン', '桜井市', 'サクライシ', '中谷', 'ナカタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県桜井市滝倉', '29', '29206', '6330108', '奈良県', 'ナラケン', '桜井市', 'サクライシ', '滝倉', 'タキノクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県桜井市吉隠', '29', '29206', '6330111', '奈良県', 'ナラケン', '桜井市', 'サクライシ', '吉隠', 'ヨナバリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県桜井市初瀬', '29', '29206', '6330112', '奈良県', 'ナラケン', '桜井市', 'サクライシ', '初瀬', 'ハセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県桜井市白河', '29', '29206', '6330121', '奈良県', 'ナラケン', '桜井市', 'サクライシ', '白河', 'シラガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県桜井市出雲', '29', '29206', '6330122', '奈良県', 'ナラケン', '桜井市', 'サクライシ', '出雲', 'イズモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県桜井市修理枝', '29', '29206', '6330131', '奈良県', 'ナラケン', '桜井市', 'サクライシ', '修理枝', 'シュリエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県桜井市和田', '29', '29206', '6330132', '奈良県', 'ナラケン', '桜井市', 'サクライシ', '和田', 'ワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県桜井市笠', '29', '29206', '6330133', '奈良県', 'ナラケン', '桜井市', 'サクライシ', '笠', 'カサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市', '29', '29212', '6330200', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('73839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市榛原区戒場', '29', '29212', '6330201', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '榛原区戒場', 'ハイバラクカイバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市榛原区山辺三', '29', '29212', '6330202', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '榛原区山辺三', 'ハイバラクヤマベサン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市榛原区長峯', '29', '29212', '6330203', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '榛原区長峯', 'ハイバラクナガミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市榛原区福地', '29', '29212', '6330204', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '榛原区福地', 'ハイバラクフクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市榛原区天満台東', '29', '29212', '6330205', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '榛原区天満台東', 'ハイバラクテンマダイヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市榛原区天満台西', '29', '29212', '6330206', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '榛原区天満台西', 'ハイバラクテンマダイニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市榛原区赤瀬', '29', '29212', '6330207', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '榛原区赤瀬', 'ハイバラクアカゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市榛原区額井', '29', '29212', '6330208', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '榛原区額井', 'ハイバラクヌカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市榛原区荷阪', '29', '29212', '6330211', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '榛原区荷阪', 'ハイバラクニザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市榛原区高井', '29', '29212', '6330212', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '榛原区高井', 'ハイバラクタカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市榛原区赤埴', '29', '29212', '6330213', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '榛原区赤埴', 'ハイバラクアカバネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市榛原区諸木野', '29', '29212', '6330214', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '榛原区諸木野', 'ハイバラクモロキノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市榛原区内牧', '29', '29212', '6330215', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '榛原区内牧', 'ハイバラクウチマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市榛原区八滝', '29', '29212', '6330216', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '榛原区八滝', 'ハイバラクヤタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市榛原区自明', '29', '29212', '6330217', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '榛原区自明', 'ハイバラクジミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市榛原区檜牧', '29', '29212', '6330218', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '榛原区檜牧', 'ハイバラクヒノマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市榛原区萩乃里', '29', '29212', '6330221', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '榛原区萩乃里', 'ハイバラクハギノサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市榛原区上井足', '29', '29212', '6330222', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '榛原区上井足', 'ハイバラクカミイダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市榛原区石田', '29', '29212', '6330223', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '榛原区石田', 'ハイバラクイシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市榛原区山路', '29', '29212', '6330224', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '榛原区山路', 'ハイバラクヤマジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市榛原区大貝', '29', '29212', '6330225', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '榛原区大貝', 'ハイバラクオオガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市榛原区澤', '29', '29212', '6330226', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '榛原区澤', 'ハイバラクサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市榛原区三宮寺', '29', '29212', '6330227', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '榛原区三宮寺', 'ハイバラクサングウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市榛原区栗谷', '29', '29212', '6330228', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '榛原区栗谷', 'ハイバラククリダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市榛原区足立', '29', '29212', '6330231', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '榛原区足立', 'ハイバラクアダチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市榛原区池上', '29', '29212', '6330232', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '榛原区池上', 'ハイバラクイケガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市榛原区福西', '29', '29212', '6330233', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '榛原区福西', 'ハイバラクフクニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市榛原区高塚', '29', '29212', '6330234', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '榛原区高塚', 'ハイバラクタカツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市榛原区比布', '29', '29212', '6330235', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '榛原区比布', 'ハイバラクヒフ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市榛原区母里', '29', '29212', '6330236', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '榛原区母里', 'ハイバラクモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市榛原区下井足', '29', '29212', '6330241', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '榛原区下井足', 'ハイバラクシモイダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市榛原区篠楽', '29', '29212', '6330242', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '榛原区篠楽', 'ハイバラクササガク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市榛原区雨師', '29', '29212', '6330243', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '榛原区雨師', 'ハイバラクアメシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市榛原区安田', '29', '29212', '6330244', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '榛原区安田', 'ハイバラクヤスダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市榛原区笠間', '29', '29212', '6330245', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '榛原区笠間', 'ハイバラクカサマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市榛原区柳', '29', '29212', '6330246', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '榛原区柳', 'ハイバラクヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市榛原区ひのき坂', '29', '29212', '6330251', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '榛原区ひのき坂', 'ハイバラクヒノキザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市榛原区桜が丘', '29', '29212', '6330252', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '榛原区桜が丘', 'ハイバラクサクラガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市榛原区萩原', '29', '29212', '6330253', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '榛原区萩原', 'ハイバラクハギハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市榛原区高萩台', '29', '29212', '6330254', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '榛原区高萩台', 'ハイバラクタカハギダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市榛原区角柄', '29', '29212', '6330255', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '榛原区角柄', 'ハイバラクツノガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市榛原区あかね台', '29', '29212', '6330256', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '榛原区あかね台', 'ハイバラクアカネダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市榛原区榛見が丘', '29', '29212', '6330257', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '榛原区榛見が丘', 'ハイバラクハルミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市室生区龍口', '29', '29212', '6330311', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '室生区龍口', 'ムロウクリュウグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市室生区西谷', '29', '29212', '6330312', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '室生区西谷', 'ムロウクニシタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市室生区瀧谷', '29', '29212', '6330313', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '室生区瀧谷', 'ムロウクタキダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市室生区砥取', '29', '29212', '6330314', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '室生区砥取', 'ムロウクトトリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市室生区大野', '29', '29212', '6330315', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '室生区大野', 'ムロウクオオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市室生区向渕', '29', '29212', '6330316', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '室生区向渕', 'ムロウクムコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市室生区三本松', '29', '29212', '6330317', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '室生区三本松', 'ムロウクサンボンマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市室生区室生', '29', '29212', '6330421', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '室生区室生', 'ムロウクムロウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市室生区下田口', '29', '29212', '6330422', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '室生区下田口', 'ムロウクシモタグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市室生区田口元角川', '29', '29212', '6330423', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '室生区田口元角川', 'ムロウクタグチモトツノガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市室生区田口元上田口', '29', '29212', '6330424', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '室生区田口元上田口', 'ムロウクタグチモトカミタグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市室生区黒岩', '29', '29212', '6330425', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '室生区黒岩', 'ムロウククロイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀郡曽爾村', '29', '29385', '6331200', '奈良県', 'ナラケン', '宇陀郡曽爾村', 'ウダグンソニムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('73899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀郡曽爾村伊賀見', '29', '29385', '6331201', '奈良県', 'ナラケン', '宇陀郡曽爾村', 'ウダグンソニムラ', '伊賀見', 'イガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀郡曽爾村太良路', '29', '29385', '6331202', '奈良県', 'ナラケン', '宇陀郡曽爾村', 'ウダグンソニムラ', '太良路', 'タロジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀郡曽爾村葛', '29', '29385', '6331203', '奈良県', 'ナラケン', '宇陀郡曽爾村', 'ウダグンソニムラ', '葛', 'カズラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀郡曽爾村塩井', '29', '29385', '6331211', '奈良県', 'ナラケン', '宇陀郡曽爾村', 'ウダグンソニムラ', '塩井', 'シオイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀郡曽爾村今井', '29', '29385', '6331212', '奈良県', 'ナラケン', '宇陀郡曽爾村', 'ウダグンソニムラ', '今井', 'イマイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀郡曽爾村小長尾', '29', '29385', '6331213', '奈良県', 'ナラケン', '宇陀郡曽爾村', 'ウダグンソニムラ', '小長尾', 'コナガオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀郡曽爾村長野', '29', '29385', '6331214', '奈良県', 'ナラケン', '宇陀郡曽爾村', 'ウダグンソニムラ', '長野', 'ナガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀郡曽爾村掛', '29', '29385', '6331215', '奈良県', 'ナラケン', '宇陀郡曽爾村', 'ウダグンソニムラ', '掛', 'カケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀郡曽爾村山粕', '29', '29385', '6331216', '奈良県', 'ナラケン', '宇陀郡曽爾村', 'ウダグンソニムラ', '山粕', 'ヤマガス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀郡御杖村', '29', '29386', '6331300', '奈良県', 'ナラケン', '宇陀郡御杖村', 'ウダグンミツエムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('73909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀郡御杖村神末', '29', '29386', '6331301', '奈良県', 'ナラケン', '宇陀郡御杖村', 'ウダグンミツエムラ', '神末', 'コウズエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀郡御杖村菅野', '29', '29386', '6331302', '奈良県', 'ナラケン', '宇陀郡御杖村', 'ウダグンミツエムラ', '菅野', 'スガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀郡御杖村土屋原', '29', '29386', '6331303', '奈良県', 'ナラケン', '宇陀郡御杖村', 'ウダグンミツエムラ', '土屋原', 'ツチヤハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀郡御杖村桃俣', '29', '29386', '6331304', '奈良県', 'ナラケン', '宇陀郡御杖村', 'ウダグンミツエムラ', '桃俣', 'モモノマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市大宇陀区五津', '29', '29212', '6332101', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '大宇陀区五津', 'オオウダクイツツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市大宇陀区平尾', '29', '29212', '6332102', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '大宇陀区平尾', 'オオウダクヒラオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市大宇陀区野依', '29', '29212', '6332103', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '大宇陀区野依', 'オオウダクノヨリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市大宇陀区口今井', '29', '29212', '6332104', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '大宇陀区口今井', 'オオウダククチイマイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市大宇陀区麻生田', '29', '29212', '6332105', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '大宇陀区麻生田', 'オオウダクアソダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市大宇陀区馬取柿', '29', '29212', '6332106', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '大宇陀区馬取柿', 'オオウダクマトリガキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市大宇陀区嬉河原', '29', '29212', '6332107', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '大宇陀区嬉河原', 'オオウダクウレシガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市大宇陀区半阪', '29', '29212', '6332108', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '大宇陀区半阪', 'オオウダクハンサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市大宇陀区内原', '29', '29212', '6332111', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '大宇陀区内原', 'オオウダクウチワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市大宇陀区小附', '29', '29212', '6332112', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '大宇陀区小附', 'オオウダクコウツケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市大宇陀区下竹', '29', '29212', '6332113', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '大宇陀区下竹', 'オオウダクシモタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市大宇陀区春日', '29', '29212', '6332114', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '大宇陀区春日', 'オオウダクカスガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市大宇陀区西山', '29', '29212', '6332115', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '大宇陀区西山', 'オオウダクニシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市大宇陀区岩室', '29', '29212', '6332116', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '大宇陀区岩室', 'オオウダクイワムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市大宇陀区芝生', '29', '29212', '6332117', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '大宇陀区芝生', 'オオウダクシボウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市大宇陀区塚脇', '29', '29212', '6332121', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '大宇陀区塚脇', 'オオウダクツカワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市大宇陀区調子', '29', '29212', '6332122', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '大宇陀区調子', 'オオウダクチョウシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市大宇陀区藤井', '29', '29212', '6332123', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '大宇陀区藤井', 'オオウダクフジイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市大宇陀区才ケ辻', '29', '29212', '6332124', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '大宇陀区才ケ辻', 'オオウダクサイガツジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市大宇陀区守道', '29', '29212', '6332125', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '大宇陀区守道', 'オオウダクモチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市大宇陀区岩清水', '29', '29212', '6332126', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '大宇陀区岩清水', 'オオウダクイワシミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市大宇陀区和田', '29', '29212', '6332131', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '大宇陀区和田', 'オオウダクワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市大宇陀区下品', '29', '29212', '6332132', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '大宇陀区下品', 'オオウダクシモシナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市大宇陀区上品', '29', '29212', '6332133', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '大宇陀区上品', 'オオウダクカミシナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市大宇陀区小和田', '29', '29212', '6332134', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '大宇陀区小和田', 'オオウダクコワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市大宇陀区東平尾', '29', '29212', '6332135', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '大宇陀区東平尾', 'オオウダクヒガシヒラオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市大宇陀区大熊', '29', '29212', '6332136', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '大宇陀区大熊', 'オオウダクオオクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市大宇陀区下片岡', '29', '29212', '6332137', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '大宇陀区下片岡', 'オオウダクシモカタオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市大宇陀区白鳥居', '29', '29212', '6332138', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '大宇陀区白鳥居', 'オオウダクシラトリイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市大宇陀区山口', '29', '29212', '6332139', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '大宇陀区山口', 'オオウダクヤマグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市大宇陀区上片岡', '29', '29212', '6332141', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '大宇陀区上片岡', 'オオウダクカミカタオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市大宇陀区田原', '29', '29212', '6332142', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '大宇陀区田原', 'オオウダクタワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市大宇陀区牧', '29', '29212', '6332143', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '大宇陀区牧', 'オオウダクマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市大宇陀区栗野', '29', '29212', '6332144', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '大宇陀区栗野', 'オオウダククリノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市大宇陀区大東', '29', '29212', '6332151', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '大宇陀区大東', 'オオウダクダイトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市大宇陀区関戸', '29', '29212', '6332152', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '大宇陀区関戸', 'オオウダクセキド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市大宇陀区下宮奥', '29', '29212', '6332153', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '大宇陀区下宮奥', 'オオウダクシモミヤノオク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市大宇陀区宮奥', '29', '29212', '6332154', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '大宇陀区宮奥', 'オオウダクミヤノオク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市大宇陀区黒木', '29', '29212', '6332155', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '大宇陀区黒木', 'オオウダククロギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市大宇陀区本郷', '29', '29212', '6332156', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '大宇陀区本郷', 'オオウダクホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市大宇陀区上新', '29', '29212', '6332161', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '大宇陀区上新', 'オオウダクカミシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市大宇陀区出新', '29', '29212', '6332162', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '大宇陀区出新', 'オオウダクイデシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市大宇陀区万六', '29', '29212', '6332163', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '大宇陀区万六', 'オオウダクマンロク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市大宇陀区拾生', '29', '29212', '6332164', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '大宇陀区拾生', 'オオウダクヒロウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市大宇陀区中庄', '29', '29212', '6332165', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '大宇陀区中庄', 'オオウダクナカノショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市大宇陀区迫間', '29', '29212', '6332166', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '大宇陀区迫間', 'オオウダクハサマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市大宇陀区下茶', '29', '29212', '6332170', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '大宇陀区下茶', 'オオウダクシモチャ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市大宇陀区上茶', '29', '29212', '6332171', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '大宇陀区上茶', 'オオウダクカミチャ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市大宇陀区上本', '29', '29212', '6332172', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '大宇陀区上本', 'オオウダクカミホン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市大宇陀区上中', '29', '29212', '6332173', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '大宇陀区上中', 'オオウダクカミナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市大宇陀区上', '29', '29212', '6332174', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '大宇陀区上', 'オオウダクカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市大宇陀区中新', '29', '29212', '6332175', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '大宇陀区中新', 'オオウダクナカシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市大宇陀区小出口', '29', '29212', '6332176', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '大宇陀区小出口', 'オオウダクコイデグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市大宇陀区下出口', '29', '29212', '6332177', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '大宇陀区下出口', 'オオウダクシモデグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市大宇陀区下中', '29', '29212', '6332178', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '大宇陀区下中', 'オオウダクシモナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市大宇陀区下本', '29', '29212', '6332179', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '大宇陀区下本', 'オオウダクシモホン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市菟田野区平井', '29', '29212', '6332201', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '菟田野区平井', 'ウタノクヒライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市菟田野区大神', '29', '29212', '6332202', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '菟田野区大神', 'ウタノクオオガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市菟田野区見田', '29', '29212', '6332203', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '菟田野区見田', 'ウタノクミタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市菟田野区大沢', '29', '29212', '6332204', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '菟田野区大沢', 'ウタノクオオサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市菟田野区別所', '29', '29212', '6332205', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '菟田野区別所', 'ウタノクベッシヨ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市菟田野区入谷', '29', '29212', '6332211', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '菟田野区入谷', 'ウタノクニュウダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市菟田野区下芳野', '29', '29212', '6332212', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '菟田野区下芳野', 'ウタノクシモホウノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市菟田野区上芳野', '29', '29212', '6332213', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '菟田野区上芳野', 'ウタノクカミホウノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市菟田野区岩端', '29', '29212', '6332214', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '菟田野区岩端', 'ウタノクイワハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市菟田野区東郷', '29', '29212', '6332215', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '菟田野区東郷', 'ウタノクトウゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市菟田野区松井', '29', '29212', '6332221', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '菟田野区松井', 'ウタノクマツイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市菟田野区駒帰', '29', '29212', '6332222', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '菟田野区駒帰', 'ウタノクコマガエリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市菟田野区宇賀志', '29', '29212', '6332223', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '菟田野区宇賀志', 'ウタノクウカシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市菟田野区佐倉', '29', '29212', '6332224', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '菟田野区佐倉', 'ウタノクサクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市菟田野区稲戸', '29', '29212', '6332225', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '菟田野区稲戸', 'ウタノクイナド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市菟田野区古市場', '29', '29212', '6332226', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '菟田野区古市場', 'ウタノクフルイチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県宇陀市菟田野区岩崎', '29', '29212', '6332227', '奈良県', 'ナラケン', '宇陀市', 'ウダシ', '菟田野区岩崎', 'ウタノクイワサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡東吉野村滝野', '29', '29453', '6332301', '奈良県', 'ナラケン', '吉野郡東吉野村', 'ヨシノグンヒガシヨシノムラ', '滝野', 'タキノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡東吉野村谷尻', '29', '29453', '6332302', '奈良県', 'ナラケン', '吉野郡東吉野村', 'ヨシノグンヒガシヨシノムラ', '谷尻', 'タニジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡東吉野村平野', '29', '29453', '6332303', '奈良県', 'ナラケン', '吉野郡東吉野村', 'ヨシノグンヒガシヨシノムラ', '平野', 'ヒラノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡東吉野村杉谷', '29', '29453', '6332304', '奈良県', 'ナラケン', '吉野郡東吉野村', 'ヨシノグンヒガシヨシノムラ', '杉谷', 'スギタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡東吉野村木津', '29', '29453', '6332311', '奈良県', 'ナラケン', '吉野郡東吉野村', 'ヨシノグンヒガシヨシノムラ', '木津', 'コツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡東吉野村伊豆尾', '29', '29453', '6332312', '奈良県', 'ナラケン', '吉野郡東吉野村', 'ヨシノグンヒガシヨシノムラ', '伊豆尾', 'イズオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡東吉野村日裏', '29', '29453', '6332313', '奈良県', 'ナラケン', '吉野郡東吉野村', 'ヨシノグンヒガシヨシノムラ', '日裏', 'ヒウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡東吉野村萩原', '29', '29453', '6332314', '奈良県', 'ナラケン', '吉野郡東吉野村', 'ヨシノグンヒガシヨシノムラ', '萩原', 'ハギワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡東吉野村', '29', '29453', '6332400', '奈良県', 'ナラケン', '吉野郡東吉野村', 'ヨシノグンヒガシヨシノムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('73996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡東吉野村小川', '29', '29453', '6332421', '奈良県', 'ナラケン', '吉野郡東吉野村', 'ヨシノグンヒガシヨシノムラ', '小川', 'オガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡東吉野村鷲家', '29', '29453', '6332422', '奈良県', 'ナラケン', '吉野郡東吉野村', 'ヨシノグンヒガシヨシノムラ', '鷲家', 'ワシカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡東吉野村小栗栖', '29', '29453', '6332423', '奈良県', 'ナラケン', '吉野郡東吉野村', 'ヨシノグンヒガシヨシノムラ', '小栗栖', 'コグリス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('73999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡東吉野村中黒', '29', '29453', '6332424', '奈良県', 'ナラケン', '吉野郡東吉野村', 'ヨシノグンヒガシヨシノムラ', '中黒', 'ナカグロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡東吉野村小', '29', '29453', '6332431', '奈良県', 'ナラケン', '吉野郡東吉野村', 'ヨシノグンヒガシヨシノムラ', '小', 'オムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡東吉野村木津川', '29', '29453', '6332432', '奈良県', 'ナラケン', '吉野郡東吉野村', 'ヨシノグンヒガシヨシノムラ', '木津川', 'コツガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡東吉野村三尾', '29', '29453', '6332433', '奈良県', 'ナラケン', '吉野郡東吉野村', 'ヨシノグンヒガシヨシノムラ', '三尾', 'ミオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡東吉野村狭戸', '29', '29453', '6332441', '奈良県', 'ナラケン', '吉野郡東吉野村', 'ヨシノグンヒガシヨシノムラ', '狭戸', 'セバト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡東吉野村大豆生', '29', '29453', '6332442', '奈良県', 'ナラケン', '吉野郡東吉野村', 'ヨシノグンヒガシヨシノムラ', '大豆生', 'マメオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡東吉野村麦谷', '29', '29453', '6332443', '奈良県', 'ナラケン', '吉野郡東吉野村', 'ヨシノグンヒガシヨシノムラ', '麦谷', 'ムギタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡東吉野村大又', '29', '29453', '6332444', '奈良県', 'ナラケン', '吉野郡東吉野村', 'ヨシノグンヒガシヨシノムラ', '大又', 'オオマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県橿原市', '29', '29205', '6340000', '奈良県', 'ナラケン', '橿原市', 'カシハラシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('74013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県橿原市太田市町', '29', '29205', '6340001', '奈良県', 'ナラケン', '橿原市', 'カシハラシ', '太田市町', 'オダイチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県橿原市東竹田町', '29', '29205', '6340002', '奈良県', 'ナラケン', '橿原市', 'カシハラシ', '東竹田町', 'ヒガシタケダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県橿原市常盤町', '29', '29205', '6340003', '奈良県', 'ナラケン', '橿原市', 'カシハラシ', '常盤町', 'トキワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県橿原市木原町', '29', '29205', '6340004', '奈良県', 'ナラケン', '橿原市', 'カシハラシ', '木原町', 'キハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県橿原市北八木町', '29', '29205', '6340005', '奈良県', 'ナラケン', '橿原市', 'カシハラシ', '北八木町', 'キタヤギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県橿原市新賀町', '29', '29205', '6340006', '奈良県', 'ナラケン', '橿原市', 'カシハラシ', '新賀町', 'シンガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県橿原市葛本町', '29', '29205', '6340007', '奈良県', 'ナラケン', '橿原市', 'カシハラシ', '葛本町', 'クズモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県橿原市十市町', '29', '29205', '6340008', '奈良県', 'ナラケン', '橿原市', 'カシハラシ', '十市町', 'トオイチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県橿原市中町', '29', '29205', '6340009', '奈良県', 'ナラケン', '橿原市', 'カシハラシ', '中町', 'ナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県橿原市出垣内町', '29', '29205', '6340011', '奈良県', 'ナラケン', '橿原市', 'カシハラシ', '出垣内町', 'デガイトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県橿原市膳夫町', '29', '29205', '6340012', '奈良県', 'ナラケン', '橿原市', 'カシハラシ', '膳夫町', 'カシワテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県橿原市出合町', '29', '29205', '6340013', '奈良県', 'ナラケン', '橿原市', 'カシハラシ', '出合町', 'デアイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県橿原市石原田町', '29', '29205', '6340014', '奈良県', 'ナラケン', '橿原市', 'カシハラシ', '石原田町', 'イシハラダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県橿原市東池尻町', '29', '29205', '6340021', '奈良県', 'ナラケン', '橿原市', 'カシハラシ', '東池尻町', 'ヒガシイケジリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県橿原市南浦町', '29', '29205', '6340022', '奈良県', 'ナラケン', '橿原市', 'カシハラシ', '南浦町', 'ミナミウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県橿原市戒外町', '29', '29205', '6340023', '奈良県', 'ナラケン', '橿原市', 'カシハラシ', '戒外町', 'カイゲチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県橿原市南山町', '29', '29205', '6340024', '奈良県', 'ナラケン', '橿原市', 'カシハラシ', '南山町', 'ミナミヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県橿原市木之本町', '29', '29205', '6340025', '奈良県', 'ナラケン', '橿原市', 'カシハラシ', '木之本町', 'キノモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県橿原市別所町', '29', '29205', '6340026', '奈良県', 'ナラケン', '橿原市', 'カシハラシ', '別所町', 'ベッシヨチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県橿原市高殿町', '29', '29205', '6340027', '奈良県', 'ナラケン', '橿原市', 'カシハラシ', '高殿町', 'タカドノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県橿原市法花寺町', '29', '29205', '6340028', '奈良県', 'ナラケン', '橿原市', 'カシハラシ', '法花寺町', 'ホッケイジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県橿原市下八釣町', '29', '29205', '6340029', '奈良県', 'ナラケン', '橿原市', 'カシハラシ', '下八釣町', 'シモヤツリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県橿原市上飛騨町', '29', '29205', '6340031', '奈良県', 'ナラケン', '橿原市', 'カシハラシ', '上飛騨町', 'カミヒダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県橿原市田中町', '29', '29205', '6340032', '奈良県', 'ナラケン', '橿原市', 'カシハラシ', '田中町', 'タナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県橿原市城殿町', '29', '29205', '6340033', '奈良県', 'ナラケン', '橿原市', 'カシハラシ', '城殿町', 'キドノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県橿原市飛騨町', '29', '29205', '6340034', '奈良県', 'ナラケン', '橿原市', 'カシハラシ', '飛騨町', 'ヒダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県橿原市和田町', '29', '29205', '6340041', '奈良県', 'ナラケン', '橿原市', 'カシハラシ', '和田町', 'ワダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県橿原市菖蒲町', '29', '29205', '6340042', '奈良県', 'ナラケン', '橿原市', 'カシハラシ', '菖蒲町', 'ショウブチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県橿原市五条野町', '29', '29205', '6340043', '奈良県', 'ナラケン', '橿原市', 'カシハラシ', '五条野町', 'ゴジョウノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県橿原市大軽町', '29', '29205', '6340044', '奈良県', 'ナラケン', '橿原市', 'カシハラシ', '大軽町', 'オオガルチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県橿原市石川町', '29', '29205', '6340045', '奈良県', 'ナラケン', '橿原市', 'カシハラシ', '石川町', 'イシカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県橿原市栄和町', '29', '29205', '6340046', '奈良県', 'ナラケン', '橿原市', 'カシハラシ', '栄和町', 'エイワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県橿原市白橿町', '29', '29205', '6340051', '奈良県', 'ナラケン', '橿原市', 'カシハラシ', '白橿町', 'シラカシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県橿原市南妙法寺町', '29', '29205', '6340052', '奈良県', 'ナラケン', '橿原市', 'カシハラシ', '南妙法寺町', 'ミナミミョウホウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県橿原市大久保町', '29', '29205', '6340061', '奈良県', 'ナラケン', '橿原市', 'カシハラシ', '大久保町', 'オオクボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県橿原市御坊町', '29', '29205', '6340062', '奈良県', 'ナラケン', '橿原市', 'カシハラシ', '御坊町', 'ゴボウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県橿原市久米町', '29', '29205', '6340063', '奈良県', 'ナラケン', '橿原市', 'カシハラシ', '久米町', 'クメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県橿原市見瀬町', '29', '29205', '6340064', '奈良県', 'ナラケン', '橿原市', 'カシハラシ', '見瀬町', 'ミセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県橿原市畝傍町', '29', '29205', '6340065', '奈良県', 'ナラケン', '橿原市', 'カシハラシ', '畝傍町', 'ウネビチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県橿原市山之坊町', '29', '29205', '6340071', '奈良県', 'ナラケン', '橿原市', 'カシハラシ', '山之坊町', 'ヤマノボウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県橿原市醍醐町', '29', '29205', '6340072', '奈良県', 'ナラケン', '橿原市', 'カシハラシ', '醍醐町', 'ダイゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県橿原市縄手町', '29', '29205', '6340073', '奈良県', 'ナラケン', '橿原市', 'カシハラシ', '縄手町', 'ナワテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県橿原市四分町', '29', '29205', '6340074', '奈良県', 'ナラケン', '橿原市', 'カシハラシ', '四分町', 'シブチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県橿原市小房町', '29', '29205', '6340075', '奈良県', 'ナラケン', '橿原市', 'カシハラシ', '小房町', 'オウサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県橿原市兵部町', '29', '29205', '6340076', '奈良県', 'ナラケン', '橿原市', 'カシハラシ', '兵部町', 'ヒョウブチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県橿原市南八木町', '29', '29205', '6340077', '奈良県', 'ナラケン', '橿原市', 'カシハラシ', '南八木町', 'ミナミヤギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県橿原市八木町', '29', '29205', '6340078', '奈良県', 'ナラケン', '橿原市', 'カシハラシ', '八木町', 'ヤギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県高市郡明日香村', '29', '29402', '6340100', '奈良県', 'ナラケン', '高市郡明日香村', 'タカイチグンアスカムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('74061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県高市郡明日香村小山', '29', '29402', '6340101', '奈良県', 'ナラケン', '高市郡明日香村', 'タカイチグンアスカムラ', '小山', 'コヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県高市郡明日香村奥山', '29', '29402', '6340102', '奈良県', 'ナラケン', '高市郡明日香村', 'タカイチグンアスカムラ', '奥山', 'オクヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県高市郡明日香村飛鳥', '29', '29402', '6340103', '奈良県', 'ナラケン', '高市郡明日香村', 'タカイチグンアスカムラ', '飛鳥', 'アスカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県高市郡明日香村八釣', '29', '29402', '6340104', '奈良県', 'ナラケン', '高市郡明日香村', 'タカイチグンアスカムラ', '八釣', 'ヤツリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県高市郡明日香村東山', '29', '29402', '6340105', '奈良県', 'ナラケン', '高市郡明日香村', 'タカイチグンアスカムラ', '東山', 'ヒガシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県高市郡明日香村小原', '29', '29402', '6340106', '奈良県', 'ナラケン', '高市郡明日香村', 'タカイチグンアスカムラ', '小原', 'オオハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県高市郡明日香村豊浦', '29', '29402', '6340107', '奈良県', 'ナラケン', '高市郡明日香村', 'タカイチグンアスカムラ', '豊浦', 'トヨウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県高市郡明日香村雷', '29', '29402', '6340108', '奈良県', 'ナラケン', '高市郡明日香村', 'タカイチグンアスカムラ', '雷', 'イカツチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県高市郡明日香村岡', '29', '29402', '6340111', '奈良県', 'ナラケン', '高市郡明日香村', 'タカイチグンアスカムラ', '岡', 'オカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県高市郡明日香村島庄', '29', '29402', '6340112', '奈良県', 'ナラケン', '高市郡明日香村', 'タカイチグンアスカムラ', '島庄', 'シマショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県高市郡明日香村上居', '29', '29402', '6340113', '奈良県', 'ナラケン', '高市郡明日香村', 'タカイチグンアスカムラ', '上居', 'ジョウゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県高市郡明日香村細川', '29', '29402', '6340114', '奈良県', 'ナラケン', '高市郡明日香村', 'タカイチグンアスカムラ', '細川', 'ホソカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県高市郡明日香村上', '29', '29402', '6340115', '奈良県', 'ナラケン', '高市郡明日香村', 'タカイチグンアスカムラ', '上', 'カムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県高市郡明日香村尾曽', '29', '29402', '6340116', '奈良県', 'ナラケン', '高市郡明日香村', 'タカイチグンアスカムラ', '尾曽', 'オオソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県高市郡明日香村冬野', '29', '29402', '6340117', '奈良県', 'ナラケン', '高市郡明日香村', 'タカイチグンアスカムラ', '冬野', 'フユノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県高市郡明日香村畑', '29', '29402', '6340118', '奈良県', 'ナラケン', '高市郡明日香村', 'タカイチグンアスカムラ', '畑', 'ハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県高市郡明日香村祝戸', '29', '29402', '6340121', '奈良県', 'ナラケン', '高市郡明日香村', 'タカイチグンアスカムラ', '祝戸', 'イワイド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県高市郡明日香村阪田', '29', '29402', '6340122', '奈良県', 'ナラケン', '高市郡明日香村', 'タカイチグンアスカムラ', '阪田', 'サカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県高市郡明日香村稲渕', '29', '29402', '6340123', '奈良県', 'ナラケン', '高市郡明日香村', 'タカイチグンアスカムラ', '稲渕', 'イナブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県高市郡明日香村栢森', '29', '29402', '6340124', '奈良県', 'ナラケン', '高市郡明日香村', 'タカイチグンアスカムラ', '栢森', 'カヤモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県高市郡明日香村入谷', '29', '29402', '6340125', '奈良県', 'ナラケン', '高市郡明日香村', 'タカイチグンアスカムラ', '入谷', 'ニュウダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県高市郡明日香村御園', '29', '29402', '6340131', '奈良県', 'ナラケン', '高市郡明日香村', 'タカイチグンアスカムラ', '御園', 'ミソノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県高市郡明日香村栗原', '29', '29402', '6340132', '奈良県', 'ナラケン', '高市郡明日香村', 'タカイチグンアスカムラ', '栗原', 'クリハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県高市郡明日香村大根田', '29', '29402', '6340133', '奈良県', 'ナラケン', '高市郡明日香村', 'タカイチグンアスカムラ', '大根田', 'オオネダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県高市郡明日香村阿部山', '29', '29402', '6340134', '奈良県', 'ナラケン', '高市郡明日香村', 'タカイチグンアスカムラ', '阿部山', 'アベヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県高市郡明日香村檜前', '29', '29402', '6340135', '奈良県', 'ナラケン', '高市郡明日香村', 'タカイチグンアスカムラ', '檜前', 'ヒノクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県高市郡明日香村地ノ窪', '29', '29402', '6340136', '奈良県', 'ナラケン', '高市郡明日香村', 'タカイチグンアスカムラ', '地ノ窪', 'ジノクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県高市郡明日香村真弓', '29', '29402', '6340137', '奈良県', 'ナラケン', '高市郡明日香村', 'タカイチグンアスカムラ', '真弓', 'マユミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県高市郡明日香村越', '29', '29402', '6340138', '奈良県', 'ナラケン', '高市郡明日香村', 'タカイチグンアスカムラ', '越', 'コシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県高市郡明日香村川原', '29', '29402', '6340141', '奈良県', 'ナラケン', '高市郡明日香村', 'タカイチグンアスカムラ', '川原', 'カワハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県高市郡明日香村橘', '29', '29402', '6340142', '奈良県', 'ナラケン', '高市郡明日香村', 'タカイチグンアスカムラ', '橘', 'タチバナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県高市郡明日香村立部', '29', '29402', '6340143', '奈良県', 'ナラケン', '高市郡明日香村', 'タカイチグンアスカムラ', '立部', 'タチベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県高市郡明日香村平田', '29', '29402', '6340144', '奈良県', 'ナラケン', '高市郡明日香村', 'タカイチグンアスカムラ', '平田', 'ヒラタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県高市郡明日香村野口', '29', '29402', '6340145', '奈良県', 'ナラケン', '高市郡明日香村', 'タカイチグンアスカムラ', '野口', 'ノグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県橿原市西新堂町', '29', '29205', '6340801', '奈良県', 'ナラケン', '橿原市', 'カシハラシ', '西新堂町', 'ニシシンドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県橿原市新口町', '29', '29205', '6340802', '奈良県', 'ナラケン', '橿原市', 'カシハラシ', '新口町', 'ニノクチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県橿原市上品寺町', '29', '29205', '6340803', '奈良県', 'ナラケン', '橿原市', 'カシハラシ', '上品寺町', 'ジョウボンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県橿原市内膳町', '29', '29205', '6340804', '奈良県', 'ナラケン', '橿原市', 'カシハラシ', '内膳町', 'ナイゼンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県橿原市地黄町', '29', '29205', '6340805', '奈良県', 'ナラケン', '橿原市', 'カシハラシ', '地黄町', 'ジオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県橿原市小綱町', '29', '29205', '6340811', '奈良県', 'ナラケン', '橿原市', 'カシハラシ', '小綱町', 'ショウコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県橿原市今井町', '29', '29205', '6340812', '奈良県', 'ナラケン', '橿原市', 'カシハラシ', '今井町', 'イマイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県橿原市四条町', '29', '29205', '6340813', '奈良県', 'ナラケン', '橿原市', 'カシハラシ', '四条町', 'シジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県橿原市山本町', '29', '29205', '6340814', '奈良県', 'ナラケン', '橿原市', 'カシハラシ', '山本町', 'ヤマモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県橿原市大谷町', '29', '29205', '6340815', '奈良県', 'ナラケン', '橿原市', 'カシハラシ', '大谷町', 'オオタニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県橿原市慈明寺町', '29', '29205', '6340816', '奈良県', 'ナラケン', '橿原市', 'カシハラシ', '慈明寺町', 'ジミョウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県橿原市寺田町', '29', '29205', '6340817', '奈良県', 'ナラケン', '橿原市', 'カシハラシ', '寺田町', 'テラダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県橿原市西池尻町', '29', '29205', '6340821', '奈良県', 'ナラケン', '橿原市', 'カシハラシ', '西池尻町', 'ニシイケジリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県橿原市鳥屋町', '29', '29205', '6340822', '奈良県', 'ナラケン', '橿原市', 'カシハラシ', '鳥屋町', 'トリヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県橿原市北越智町', '29', '29205', '6340823', '奈良県', 'ナラケン', '橿原市', 'カシハラシ', '北越智町', 'キタオチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県橿原市一町', '29', '29205', '6340824', '奈良県', 'ナラケン', '橿原市', 'カシハラシ', '一町', 'カズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県橿原市観音寺町', '29', '29205', '6340825', '奈良県', 'ナラケン', '橿原市', 'カシハラシ', '観音寺町', 'カンノンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県橿原市川西町', '29', '29205', '6340826', '奈良県', 'ナラケン', '橿原市', 'カシハラシ', '川西町', 'カワニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県橿原市光陽町', '29', '29205', '6340827', '奈良県', 'ナラケン', '橿原市', 'カシハラシ', '光陽町', 'コウヨウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県橿原市古川町', '29', '29205', '6340828', '奈良県', 'ナラケン', '橿原市', 'カシハラシ', '古川町', 'フルカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県橿原市吉田町', '29', '29205', '6340829', '奈良県', 'ナラケン', '橿原市', 'カシハラシ', '吉田町', 'ヨシダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県橿原市曽我町', '29', '29205', '6340831', '奈良県', 'ナラケン', '橿原市', 'カシハラシ', '曽我町', 'ソガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県橿原市五井町', '29', '29205', '6340832', '奈良県', 'ナラケン', '橿原市', 'カシハラシ', '五井町', 'ゴイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県橿原市忌部町', '29', '29205', '6340833', '奈良県', 'ナラケン', '橿原市', 'カシハラシ', '忌部町', 'インベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県橿原市雲梯町', '29', '29205', '6340834', '奈良県', 'ナラケン', '橿原市', 'カシハラシ', '雲梯町', 'ウナテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県橿原市東坊城町', '29', '29205', '6340835', '奈良県', 'ナラケン', '橿原市', 'カシハラシ', '東坊城町', 'ヒガシボウジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県橿原市新堂町', '29', '29205', '6340836', '奈良県', 'ナラケン', '橿原市', 'カシハラシ', '新堂町', 'シンドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県橿原市曲川町', '29', '29205', '6340837', '奈良県', 'ナラケン', '橿原市', 'カシハラシ', '曲川町', 'マガリカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県橿原市大垣町', '29', '29205', '6340841', '奈良県', 'ナラケン', '橿原市', 'カシハラシ', '大垣町', 'オオガキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県橿原市豊田町', '29', '29205', '6340842', '奈良県', 'ナラケン', '橿原市', 'カシハラシ', '豊田町', 'トヨダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県橿原市北妙法寺町', '29', '29205', '6340843', '奈良県', 'ナラケン', '橿原市', 'カシハラシ', '北妙法寺町', 'キタミョウホウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県橿原市土橋町', '29', '29205', '6340844', '奈良県', 'ナラケン', '橿原市', 'カシハラシ', '土橋町', 'ツチハシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県橿原市中曽司町', '29', '29205', '6340845', '奈良県', 'ナラケン', '橿原市', 'カシハラシ', '中曽司町', 'ナカゾシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県橿原市小槻町', '29', '29205', '6340846', '奈良県', 'ナラケン', '橿原市', 'カシハラシ', '小槻町', 'オウヅクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県橿原市飯高町', '29', '29205', '6340847', '奈良県', 'ナラケン', '橿原市', 'カシハラシ', '飯高町', 'ヒダカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和高田市', '29', '29202', '6350000', '奈良県', 'ナラケン', '大和高田市', 'ヤマトタカダシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('74150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県北葛城郡広陵町', '29', '29426', '6350000', '奈良県', 'ナラケン', '北葛城郡広陵町', 'キタカツラギグンコウリョウチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('74151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和高田市松塚', '29', '29202', '6350001', '奈良県', 'ナラケン', '大和高田市', 'ヤマトタカダシ', '松塚', 'マツヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和高田市土庫', '29', '29202', '6350002', '奈良県', 'ナラケン', '大和高田市', 'ヤマトタカダシ', '土庫', 'ドンゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和高田市土庫', '29', '29202', '6350003', '奈良県', 'ナラケン', '大和高田市', 'ヤマトタカダシ', '土庫', 'ドンゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和高田市藤森', '29', '29202', '6350004', '奈良県', 'ナラケン', '大和高田市', 'ヤマトタカダシ', '藤森', 'フジノモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和高田市材木町', '29', '29202', '6350011', '奈良県', 'ナラケン', '大和高田市', 'ヤマトタカダシ', '材木町', 'ザイモクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和高田市曙町', '29', '29202', '6350012', '奈良県', 'ナラケン', '大和高田市', 'ヤマトタカダシ', '曙町', 'アケボノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和高田市昭和町', '29', '29202', '6350013', '奈良県', 'ナラケン', '大和高田市', 'ヤマトタカダシ', '昭和町', 'ショウワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和高田市三和町', '29', '29202', '6350014', '奈良県', 'ナラケン', '大和高田市', 'ヤマトタカダシ', '三和町', 'サンワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和高田市幸町', '29', '29202', '6350015', '奈良県', 'ナラケン', '大和高田市', 'ヤマトタカダシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和高田市大東町', '29', '29202', '6350016', '奈良県', 'ナラケン', '大和高田市', 'ヤマトタカダシ', '大東町', 'オオヒガシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和高田市東雲町', '29', '29202', '6350017', '奈良県', 'ナラケン', '大和高田市', 'ヤマトタカダシ', '東雲町', 'シノノメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和高田市池尻', '29', '29202', '6350021', '奈良県', 'ナラケン', '大和高田市', 'ヤマトタカダシ', '池尻', 'イケジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和高田市高田', '29', '29202', '6350022', '奈良県', 'ナラケン', '大和高田市', 'ヤマトタカダシ', '高田', 'タカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和高田市日之出町', '29', '29202', '6350022', '奈良県', 'ナラケン', '大和高田市', 'ヤマトタカダシ', '日之出町', 'ヒノデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和高田市日之出東本町', '29', '29202', '6350023', '奈良県', 'ナラケン', '大和高田市', 'ヤマトタカダシ', '日之出東本町', 'ヒノデヒガシホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和高田市日之出西本町', '29', '29202', '6350024', '奈良県', 'ナラケン', '大和高田市', 'ヤマトタカダシ', '日之出西本町', 'ヒノデニシホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和高田市神楽', '29', '29202', '6350025', '奈良県', 'ナラケン', '大和高田市', 'ヤマトタカダシ', '神楽', 'ジンラク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和高田市神楽', '29', '29202', '6350026', '奈良県', 'ナラケン', '大和高田市', 'ヤマトタカダシ', '神楽', 'ジンラク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和高田市今里', '29', '29202', '6350031', '奈良県', 'ナラケン', '大和高田市', 'ヤマトタカダシ', '今里', 'イマザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和高田市今里町', '29', '29202', '6350031', '奈良県', 'ナラケン', '大和高田市', 'ヤマトタカダシ', '今里町', 'イマザトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和高田市今里川合方', '29', '29202', '6350032', '奈良県', 'ナラケン', '大和高田市', 'ヤマトタカダシ', '今里川合方', 'イマザトカワイホウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和高田市南今里町', '29', '29202', '6350033', '奈良県', 'ナラケン', '大和高田市', 'ヤマトタカダシ', '南今里町', 'ミナミイマザトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和高田市東三倉堂町', '29', '29202', '6350034', '奈良県', 'ナラケン', '大和高田市', 'ヤマトタカダシ', '東三倉堂町', 'ヒガシミクラドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和高田市旭南町', '29', '29202', '6350035', '奈良県', 'ナラケン', '大和高田市', 'ヤマトタカダシ', '旭南町', 'アサヒミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和高田市旭北町', '29', '29202', '6350036', '奈良県', 'ナラケン', '大和高田市', 'ヤマトタカダシ', '旭北町', 'アサヒキタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和高田市中今里町', '29', '29202', '6350037', '奈良県', 'ナラケン', '大和高田市', 'ヤマトタカダシ', '中今里町', 'ナカイマザトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和高田市田井', '29', '29202', '6350041', '奈良県', 'ナラケン', '大和高田市', 'ヤマトタカダシ', '田井', 'タイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和高田市勝目', '29', '29202', '6350042', '奈良県', 'ナラケン', '大和高田市', 'ヤマトタカダシ', '勝目', 'カジメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和高田市出', '29', '29202', '6350043', '奈良県', 'ナラケン', '大和高田市', 'ヤマトタカダシ', '出', 'イデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和高田市蔵之宮町', '29', '29202', '6350044', '奈良県', 'ナラケン', '大和高田市', 'ヤマトタカダシ', '蔵之宮町', 'クラノミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和高田市中三倉堂', '29', '29202', '6350045', '奈良県', 'ナラケン', '大和高田市', 'ヤマトタカダシ', '中三倉堂', 'ナカミクラドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和高田市西三倉堂', '29', '29202', '6350046', '奈良県', 'ナラケン', '大和高田市', 'ヤマトタカダシ', '西三倉堂', 'ニシミクラドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和高田市田井新町', '29', '29202', '6350047', '奈良県', 'ナラケン', '大和高田市', 'ヤマトタカダシ', '田井新町', 'タイシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和高田市根成柿', '29', '29202', '6350051', '奈良県', 'ナラケン', '大和高田市', 'ヤマトタカダシ', '根成柿', 'ネナリガキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和高田市奥田', '29', '29202', '6350052', '奈良県', 'ナラケン', '大和高田市', 'ヤマトタカダシ', '奥田', 'オクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和高田市秋吉', '29', '29202', '6350053', '奈良県', 'ナラケン', '大和高田市', 'ヤマトタカダシ', '秋吉', 'アキヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和高田市曽大根', '29', '29202', '6350054', '奈良県', 'ナラケン', '大和高田市', 'ヤマトタカダシ', '曽大根', 'ソオネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和高田市曽大根', '29', '29202', '6350055', '奈良県', 'ナラケン', '大和高田市', 'ヤマトタカダシ', '曽大根', 'ソオネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和高田市甘田町', '29', '29202', '6350056', '奈良県', 'ナラケン', '大和高田市', 'ヤマトタカダシ', '甘田町', 'カンダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和高田市南陽町', '29', '29202', '6350057', '奈良県', 'ナラケン', '大和高田市', 'ヤマトタカダシ', '南陽町', 'ナンヨウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和高田市西坊城', '29', '29202', '6350058', '奈良県', 'ナラケン', '大和高田市', 'ヤマトタカダシ', '西坊城', 'ニシボウジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和高田市吉井', '29', '29202', '6350059', '奈良県', 'ナラケン', '大和高田市', 'ヤマトタカダシ', '吉井', 'ヨシイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和高田市礒野東町', '29', '29202', '6350061', '奈良県', 'ナラケン', '大和高田市', 'ヤマトタカダシ', '礒野東町', 'イソノヒガシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和高田市礒野南町', '29', '29202', '6350062', '奈良県', 'ナラケン', '大和高田市', 'ヤマトタカダシ', '礒野南町', 'イソノミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和高田市礒野新町', '29', '29202', '6350063', '奈良県', 'ナラケン', '大和高田市', 'ヤマトタカダシ', '礒野新町', 'イソノシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和高田市栄町', '29', '29202', '6350064', '奈良県', 'ナラケン', '大和高田市', 'ヤマトタカダシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和高田市東中', '29', '29202', '6350065', '奈良県', 'ナラケン', '大和高田市', 'ヤマトタカダシ', '東中', 'ヒガシナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和高田市東中', '29', '29202', '6350066', '奈良県', 'ナラケン', '大和高田市', 'ヤマトタカダシ', '東中', 'ヒガシナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和高田市春日町', '29', '29202', '6350067', '奈良県', 'ナラケン', '大和高田市', 'ヤマトタカダシ', '春日町', 'カスガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和高田市築山', '29', '29202', '6350071', '奈良県', 'ナラケン', '大和高田市', 'ヤマトタカダシ', '築山', 'ツキヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和高田市有井', '29', '29202', '6350072', '奈良県', 'ナラケン', '大和高田市', 'ヤマトタカダシ', '有井', 'アリイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和高田市岡崎', '29', '29202', '6350073', '奈良県', 'ナラケン', '大和高田市', 'ヤマトタカダシ', '岡崎', 'オカザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和高田市市場', '29', '29202', '6350074', '奈良県', 'ナラケン', '大和高田市', 'ヤマトタカダシ', '市場', 'イチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和高田市野口', '29', '29202', '6350075', '奈良県', 'ナラケン', '大和高田市', 'ヤマトタカダシ', '野口', 'ノグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和高田市大谷', '29', '29202', '6350076', '奈良県', 'ナラケン', '大和高田市', 'ヤマトタカダシ', '大谷', 'オオタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和高田市池田', '29', '29202', '6350077', '奈良県', 'ナラケン', '大和高田市', 'ヤマトタカダシ', '池田', 'イケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和高田市高砂町', '29', '29202', '6350081', '奈良県', 'ナラケン', '大和高田市', 'ヤマトタカダシ', '高砂町', 'タカサゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和高田市本郷町', '29', '29202', '6350082', '奈良県', 'ナラケン', '大和高田市', 'ヤマトタカダシ', '本郷町', 'ホンゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和高田市永和町', '29', '29202', '6350083', '奈良県', 'ナラケン', '大和高田市', 'ヤマトタカダシ', '永和町', 'エイワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和高田市北片塩町', '29', '29202', '6350084', '奈良県', 'ナラケン', '大和高田市', 'ヤマトタカダシ', '北片塩町', 'キタカタシオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和高田市片塩町', '29', '29202', '6350085', '奈良県', 'ナラケン', '大和高田市', 'ヤマトタカダシ', '片塩町', 'カタシオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和高田市南本町', '29', '29202', '6350086', '奈良県', 'ナラケン', '大和高田市', 'ヤマトタカダシ', '南本町', 'ミナミホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和高田市内本町', '29', '29202', '6350087', '奈良県', 'ナラケン', '大和高田市', 'ヤマトタカダシ', '内本町', 'ウチホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和高田市大中東町', '29', '29202', '6350091', '奈良県', 'ナラケン', '大和高田市', 'ヤマトタカダシ', '大中東町', 'オオナカヒガシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和高田市大中南町', '29', '29202', '6350092', '奈良県', 'ナラケン', '大和高田市', 'ヤマトタカダシ', '大中南町', 'オオナカミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和高田市礒野', '29', '29202', '6350093', '奈良県', 'ナラケン', '大和高田市', 'ヤマトタカダシ', '礒野', 'イソノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和高田市礒野町', '29', '29202', '6350093', '奈良県', 'ナラケン', '大和高田市', 'ヤマトタカダシ', '礒野町', 'イソノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和高田市礒野北町', '29', '29202', '6350094', '奈良県', 'ナラケン', '大和高田市', 'ヤマトタカダシ', '礒野北町', 'イソノキタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和高田市大中', '29', '29202', '6350095', '奈良県', 'ナラケン', '大和高田市', 'ヤマトタカダシ', '大中', 'オオナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和高田市西町', '29', '29202', '6350096', '奈良県', 'ナラケン', '大和高田市', 'ヤマトタカダシ', '西町', 'ニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和高田市北本町', '29', '29202', '6350097', '奈良県', 'ナラケン', '大和高田市', 'ヤマトタカダシ', '北本町', 'キタホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県高市郡高取町', '29', '29401', '6350100', '奈良県', 'ナラケン', '高市郡高取町', 'タカイチグンタカトリチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('74223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県高市郡高取町高取', '29', '29401', '6350101', '奈良県', 'ナラケン', '高市郡高取町', 'タカイチグンタカトリチョウ', '高取', 'タカトリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県高市郡高取町壺阪', '29', '29401', '6350102', '奈良県', 'ナラケン', '高市郡高取町', 'タカイチグンタカトリチョウ', '壺阪', 'ツボサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県高市郡高取町清水谷', '29', '29401', '6350103', '奈良県', 'ナラケン', '高市郡高取町', 'タカイチグンタカトリチョウ', '清水谷', 'シミズタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県高市郡高取町上子島', '29', '29401', '6350104', '奈良県', 'ナラケン', '高市郡高取町', 'タカイチグンタカトリチョウ', '上子島', 'カミコシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県高市郡高取町松山', '29', '29401', '6350111', '奈良県', 'ナラケン', '高市郡高取町', 'タカイチグンタカトリチョウ', '松山', 'マツヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県高市郡高取町藤井', '29', '29401', '6350112', '奈良県', 'ナラケン', '高市郡高取町', 'タカイチグンタカトリチョウ', '藤井', 'フジイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県高市郡高取町羽内', '29', '29401', '6350113', '奈良県', 'ナラケン', '高市郡高取町', 'タカイチグンタカトリチョウ', '羽内', 'ホウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県高市郡高取町丹生谷', '29', '29401', '6350121', '奈良県', 'ナラケン', '高市郡高取町', 'タカイチグンタカトリチョウ', '丹生谷', 'ニウダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県高市郡高取町谷田', '29', '29401', '6350122', '奈良県', 'ナラケン', '高市郡高取町', 'タカイチグンタカトリチョウ', '谷田', 'ヤタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県高市郡高取町市尾', '29', '29401', '6350123', '奈良県', 'ナラケン', '高市郡高取町', 'タカイチグンタカトリチョウ', '市尾', 'イチオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県高市郡高取町佐田', '29', '29401', '6350131', '奈良県', 'ナラケン', '高市郡高取町', 'タカイチグンタカトリチョウ', '佐田', 'サダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県高市郡高取町森', '29', '29401', '6350132', '奈良県', 'ナラケン', '高市郡高取町', 'タカイチグンタカトリチョウ', '森', 'モリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県高市郡高取町吉備', '29', '29401', '6350133', '奈良県', 'ナラケン', '高市郡高取町', 'タカイチグンタカトリチョウ', '吉備', 'キビ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県高市郡高取町薩摩', '29', '29401', '6350134', '奈良県', 'ナラケン', '高市郡高取町', 'タカイチグンタカトリチョウ', '薩摩', 'サツマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県高市郡高取町田井庄', '29', '29401', '6350135', '奈良県', 'ナラケン', '高市郡高取町', 'タカイチグンタカトリチョウ', '田井庄', 'タイノショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県高市郡高取町兵庫', '29', '29401', '6350136', '奈良県', 'ナラケン', '高市郡高取町', 'タカイチグンタカトリチョウ', '兵庫', 'ヒョウゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県高市郡高取町与楽', '29', '29401', '6350141', '奈良県', 'ナラケン', '高市郡高取町', 'タカイチグンタカトリチョウ', '与楽', 'ヨウラク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県高市郡高取町寺崎', '29', '29401', '6350142', '奈良県', 'ナラケン', '高市郡高取町', 'タカイチグンタカトリチョウ', '寺崎', 'テラサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県高市郡高取町車木', '29', '29401', '6350143', '奈良県', 'ナラケン', '高市郡高取町', 'タカイチグンタカトリチョウ', '車木', 'クルマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県高市郡高取町越智', '29', '29401', '6350144', '奈良県', 'ナラケン', '高市郡高取町', 'タカイチグンタカトリチョウ', '越智', 'オチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県高市郡高取町下子島', '29', '29401', '6350151', '奈良県', 'ナラケン', '高市郡高取町', 'タカイチグンタカトリチョウ', '下子島', 'シモコシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県高市郡高取町上土佐', '29', '29401', '6350152', '奈良県', 'ナラケン', '高市郡高取町', 'タカイチグンタカトリチョウ', '上土佐', 'カミトサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県高市郡高取町下土佐', '29', '29401', '6350153', '奈良県', 'ナラケン', '高市郡高取町', 'タカイチグンタカトリチョウ', '下土佐', 'シモトサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県高市郡高取町観覚寺', '29', '29401', '6350154', '奈良県', 'ナラケン', '高市郡高取町', 'タカイチグンタカトリチョウ', '観覚寺', 'カンガクジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県北葛城郡広陵町大場', '29', '29426', '6350801', '奈良県', 'ナラケン', '北葛城郡広陵町', 'キタカツラギグンコウリョウチョウ', '大場', 'オオバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県北葛城郡広陵町的場', '29', '29426', '6350802', '奈良県', 'ナラケン', '北葛城郡広陵町', 'キタカツラギグンコウリョウチョウ', '的場', 'マトバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県北葛城郡広陵町大野', '29', '29426', '6350803', '奈良県', 'ナラケン', '北葛城郡広陵町', 'キタカツラギグンコウリョウチョウ', '大野', 'オオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県北葛城郡広陵町沢', '29', '29426', '6350804', '奈良県', 'ナラケン', '北葛城郡広陵町', 'キタカツラギグンコウリョウチョウ', '沢', 'サワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県北葛城郡広陵町萱野', '29', '29426', '6350805', '奈良県', 'ナラケン', '北葛城郡広陵町', 'キタカツラギグンコウリョウチョウ', '萱野', 'カヤノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県北葛城郡広陵町弁財天', '29', '29426', '6350811', '奈良県', 'ナラケン', '北葛城郡広陵町', 'キタカツラギグンコウリョウチョウ', '弁財天', 'ベザイテン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県北葛城郡広陵町広瀬', '29', '29426', '6350812', '奈良県', 'ナラケン', '北葛城郡広陵町', 'キタカツラギグンコウリョウチョウ', '広瀬', 'ヒロセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県北葛城郡広陵町百済', '29', '29426', '6350813', '奈良県', 'ナラケン', '北葛城郡広陵町', 'キタカツラギグンコウリョウチョウ', '百済', 'クダラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県北葛城郡広陵町南郷', '29', '29426', '6350814', '奈良県', 'ナラケン', '北葛城郡広陵町', 'キタカツラギグンコウリョウチョウ', '南郷', 'ナンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県北葛城郡広陵町古寺', '29', '29426', '6350815', '奈良県', 'ナラケン', '北葛城郡広陵町', 'キタカツラギグンコウリョウチョウ', '古寺', 'コデラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県北葛城郡広陵町中', '29', '29426', '6350816', '奈良県', 'ナラケン', '北葛城郡広陵町', 'キタカツラギグンコウリョウチョウ', '中', 'ナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県北葛城郡広陵町寺戸', '29', '29426', '6350817', '奈良県', 'ナラケン', '北葛城郡広陵町', 'キタカツラギグンコウリョウチョウ', '寺戸', 'テラド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県北葛城郡広陵町南', '29', '29426', '6350818', '奈良県', 'ナラケン', '北葛城郡広陵町', 'キタカツラギグンコウリョウチョウ', '南', 'ミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県北葛城郡広陵町笠', '29', '29426', '6350821', '奈良県', 'ナラケン', '北葛城郡広陵町', 'キタカツラギグンコウリョウチョウ', '笠', 'カサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県北葛城郡広陵町平尾', '29', '29426', '6350822', '奈良県', 'ナラケン', '北葛城郡広陵町', 'キタカツラギグンコウリョウチョウ', '平尾', 'ヒラオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県北葛城郡広陵町三吉', '29', '29426', '6350823', '奈良県', 'ナラケン', '北葛城郡広陵町', 'キタカツラギグンコウリョウチョウ', '三吉', 'ミツヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県北葛城郡広陵町疋相', '29', '29426', '6350824', '奈良県', 'ナラケン', '北葛城郡広陵町', 'キタカツラギグンコウリョウチョウ', '疋相', 'ヒキソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県北葛城郡広陵町安部', '29', '29426', '6350825', '奈良県', 'ナラケン', '北葛城郡広陵町', 'キタカツラギグンコウリョウチョウ', '安部', 'アベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県北葛城郡広陵町馬見北', '29', '29426', '6350831', '奈良県', 'ナラケン', '北葛城郡広陵町', 'キタカツラギグンコウリョウチョウ', '馬見北', 'ウマミキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県北葛城郡広陵町馬見中', '29', '29426', '6350832', '奈良県', 'ナラケン', '北葛城郡広陵町', 'キタカツラギグンコウリョウチョウ', '馬見中', 'ウマミナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県北葛城郡広陵町馬見南', '29', '29426', '6350833', '奈良県', 'ナラケン', '北葛城郡広陵町', 'キタカツラギグンコウリョウチョウ', '馬見南', 'ウマミミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県北葛城郡広陵町大塚', '29', '29426', '6350834', '奈良県', 'ナラケン', '北葛城郡広陵町', 'キタカツラギグンコウリョウチョウ', '大塚', 'オオツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県北葛城郡広陵町みささぎ台', '29', '29426', '6350835', '奈良県', 'ナラケン', '北葛城郡広陵町', 'キタカツラギグンコウリョウチョウ', 'みささぎ台', 'ミササギダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒郡平群町', '29', '29342', '6360000', '奈良県', 'ナラケン', '生駒郡平群町', 'イコマグンヘグリチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('74282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒郡三郷町', '29', '29343', '6360000', '奈良県', 'ナラケン', '生駒郡三郷町', 'イコマグンサンゴウチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('74283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県北葛城郡王寺町', '29', '29425', '6360000', '奈良県', 'ナラケン', '北葛城郡王寺町', 'キタカツラギグンオウジチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('74284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県北葛城郡河合町', '29', '29427', '6360000', '奈良県', 'ナラケン', '北葛城郡河合町', 'キタカツラギグンカワイチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('74285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県北葛城郡王寺町舟戸', '29', '29425', '6360001', '奈良県', 'ナラケン', '北葛城郡王寺町', 'キタカツラギグンオウジチョウ', '舟戸', 'フナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県北葛城郡王寺町王寺', '29', '29425', '6360002', '奈良県', 'ナラケン', '北葛城郡王寺町', 'キタカツラギグンオウジチョウ', '王寺', 'オウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県北葛城郡王寺町久度', '29', '29425', '6360003', '奈良県', 'ナラケン', '北葛城郡王寺町', 'キタカツラギグンオウジチョウ', '久度', 'クド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県北葛城郡王寺町葛下', '29', '29425', '6360011', '奈良県', 'ナラケン', '北葛城郡王寺町', 'キタカツラギグンオウジチョウ', '葛下', 'カツシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県北葛城郡王寺町本町', '29', '29425', '6360012', '奈良県', 'ナラケン', '北葛城郡王寺町', 'キタカツラギグンオウジチョウ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県北葛城郡王寺町元町', '29', '29425', '6360013', '奈良県', 'ナラケン', '北葛城郡王寺町', 'キタカツラギグンオウジチョウ', '元町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県北葛城郡王寺町藤井', '29', '29425', '6360014', '奈良県', 'ナラケン', '北葛城郡王寺町', 'キタカツラギグンオウジチョウ', '藤井', 'フジイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県北葛城郡王寺町畠田', '29', '29425', '6360021', '奈良県', 'ナラケン', '北葛城郡王寺町', 'キタカツラギグンオウジチョウ', '畠田', 'ハタケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県北葛城郡王寺町明神', '29', '29425', '6360022', '奈良県', 'ナラケン', '北葛城郡王寺町', 'キタカツラギグンオウジチョウ', '明神', 'ミョウジン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県北葛城郡王寺町太子', '29', '29425', '6360023', '奈良県', 'ナラケン', '北葛城郡王寺町', 'キタカツラギグンオウジチョウ', '太子', 'タイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県北葛城郡河合町川合', '29', '29427', '6360051', '奈良県', 'ナラケン', '北葛城郡河合町', 'キタカツラギグンカワイチョウ', '川合', 'カワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県北葛城郡河合町長楽', '29', '29427', '6360052', '奈良県', 'ナラケン', '北葛城郡河合町', 'キタカツラギグンカワイチョウ', '長楽', 'チョウラク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県北葛城郡河合町池部', '29', '29427', '6360053', '奈良県', 'ナラケン', '北葛城郡河合町', 'キタカツラギグンカワイチョウ', '池部', 'イケベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県北葛城郡河合町穴闇', '29', '29427', '6360054', '奈良県', 'ナラケン', '北葛城郡河合町', 'キタカツラギグンカワイチョウ', '穴闇', 'ナグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県北葛城郡河合町西穴闇', '29', '29427', '6360055', '奈良県', 'ナラケン', '北葛城郡河合町', 'キタカツラギグンカワイチョウ', '西穴闇', 'ニシナグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県北葛城郡河合町西山台', '29', '29427', '6360056', '奈良県', 'ナラケン', '北葛城郡河合町', 'キタカツラギグンカワイチョウ', '西山台', 'ニシヤマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県北葛城郡河合町山坊', '29', '29427', '6360061', '奈良県', 'ナラケン', '北葛城郡河合町', 'キタカツラギグンカワイチョウ', '山坊', 'ヤマノボウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県北葛城郡河合町佐味田', '29', '29427', '6360062', '奈良県', 'ナラケン', '北葛城郡河合町', 'キタカツラギグンカワイチョウ', '佐味田', 'サミタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県北葛城郡河合町久美ケ丘', '29', '29427', '6360063', '奈良県', 'ナラケン', '北葛城郡河合町', 'キタカツラギグンカワイチョウ', '久美ケ丘', 'クミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県北葛城郡河合町高塚台', '29', '29427', '6360071', '奈良県', 'ナラケン', '北葛城郡河合町', 'キタカツラギグンカワイチョウ', '高塚台', 'タカツカダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県北葛城郡河合町中山台', '29', '29427', '6360072', '奈良県', 'ナラケン', '北葛城郡河合町', 'キタカツラギグンカワイチョウ', '中山台', 'ナカヤマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県北葛城郡河合町広瀬台', '29', '29427', '6360073', '奈良県', 'ナラケン', '北葛城郡河合町', 'キタカツラギグンカワイチョウ', '広瀬台', 'ヒロセダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県北葛城郡河合町星和台', '29', '29427', '6360081', '奈良県', 'ナラケン', '北葛城郡河合町', 'キタカツラギグンカワイチョウ', '星和台', 'セイワダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県北葛城郡河合町薬井', '29', '29427', '6360082', '奈良県', 'ナラケン', '北葛城郡河合町', 'キタカツラギグンカワイチョウ', '薬井', 'クスリイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県北葛城郡河合町泉台', '29', '29427', '6360091', '奈良県', 'ナラケン', '北葛城郡河合町', 'キタカツラギグンカワイチョウ', '泉台', 'イズミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県北葛城郡河合町城内', '29', '29427', '6360092', '奈良県', 'ナラケン', '北葛城郡河合町', 'キタカツラギグンカワイチョウ', '城内', 'ジョウナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県北葛城郡河合町大輪田', '29', '29427', '6360093', '奈良県', 'ナラケン', '北葛城郡河合町', 'キタカツラギグンカワイチョウ', '大輪田', 'オオワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒郡斑鳩町', '29', '29344', '6360100', '奈良県', 'ナラケン', '生駒郡斑鳩町', 'イコマグンイカルガチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('74313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒郡斑鳩町三井', '29', '29344', '6360101', '奈良県', 'ナラケン', '生駒郡斑鳩町', 'イコマグンイカルガチョウ', '三井', 'ミイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒郡斑鳩町岡本', '29', '29344', '6360102', '奈良県', 'ナラケン', '生駒郡斑鳩町', 'イコマグンイカルガチョウ', '岡本', 'オカモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒郡斑鳩町幸前', '29', '29344', '6360103', '奈良県', 'ナラケン', '生駒郡斑鳩町', 'イコマグンイカルガチョウ', '幸前', 'コウゼン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒郡斑鳩町高安', '29', '29344', '6360104', '奈良県', 'ナラケン', '生駒郡斑鳩町', 'イコマグンイカルガチョウ', '高安', 'タカヤス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒郡斑鳩町東福寺', '29', '29344', '6360105', '奈良県', 'ナラケン', '生駒郡斑鳩町', 'イコマグンイカルガチョウ', '東福寺', 'トウフクジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒郡斑鳩町高安西', '29', '29344', '6360106', '奈良県', 'ナラケン', '生駒郡斑鳩町', 'イコマグンイカルガチョウ', '高安西', 'タカヤスニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒郡斑鳩町法隆寺北', '29', '29344', '6360111', '奈良県', 'ナラケン', '生駒郡斑鳩町', 'イコマグンイカルガチョウ', '法隆寺北', 'ホウリュウジキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒郡斑鳩町法隆寺東', '29', '29344', '6360112', '奈良県', 'ナラケン', '生駒郡斑鳩町', 'イコマグンイカルガチョウ', '法隆寺東', 'ホウリュウジヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒郡斑鳩町法隆寺南', '29', '29344', '6360113', '奈良県', 'ナラケン', '生駒郡斑鳩町', 'イコマグンイカルガチョウ', '法隆寺南', 'ホウリュウジミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒郡斑鳩町法隆寺西', '29', '29344', '6360114', '奈良県', 'ナラケン', '生駒郡斑鳩町', 'イコマグンイカルガチョウ', '法隆寺西', 'ホウリュウジニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒郡斑鳩町法隆寺山内', '29', '29344', '6360115', '奈良県', 'ナラケン', '生駒郡斑鳩町', 'イコマグンイカルガチョウ', '法隆寺山内', 'ホウリュウジサンナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒郡斑鳩町法隆寺', '29', '29344', '6360116', '奈良県', 'ナラケン', '生駒郡斑鳩町', 'イコマグンイカルガチョウ', '法隆寺', 'ホウリュウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒郡斑鳩町興留東', '29', '29344', '6360121', '奈良県', 'ナラケン', '生駒郡斑鳩町', 'イコマグンイカルガチョウ', '興留東', 'オキドメヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒郡斑鳩町阿波', '29', '29344', '6360122', '奈良県', 'ナラケン', '生駒郡斑鳩町', 'イコマグンイカルガチョウ', '阿波', 'アワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒郡斑鳩町興留', '29', '29344', '6360123', '奈良県', 'ナラケン', '生駒郡斑鳩町', 'イコマグンイカルガチョウ', '興留', 'オキドメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒郡斑鳩町五百井', '29', '29344', '6360124', '奈良県', 'ナラケン', '生駒郡斑鳩町', 'イコマグンイカルガチョウ', '五百井', 'イオイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒郡斑鳩町服部', '29', '29344', '6360131', '奈良県', 'ナラケン', '生駒郡斑鳩町', 'イコマグンイカルガチョウ', '服部', 'ハットリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒郡斑鳩町目安', '29', '29344', '6360132', '奈良県', 'ナラケン', '生駒郡斑鳩町', 'イコマグンイカルガチョウ', '目安', 'メヤス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒郡斑鳩町目安北', '29', '29344', '6360133', '奈良県', 'ナラケン', '生駒郡斑鳩町', 'イコマグンイカルガチョウ', '目安北', 'メヤスキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒郡斑鳩町稲葉車瀬', '29', '29344', '6360141', '奈良県', 'ナラケン', '生駒郡斑鳩町', 'イコマグンイカルガチョウ', '稲葉車瀬', 'イナバクルマセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒郡斑鳩町小吉田', '29', '29344', '6360142', '奈良県', 'ナラケン', '生駒郡斑鳩町', 'イコマグンイカルガチョウ', '小吉田', 'コヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒郡斑鳩町神南', '29', '29344', '6360143', '奈良県', 'ナラケン', '生駒郡斑鳩町', 'イコマグンイカルガチョウ', '神南', 'ジンナン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒郡斑鳩町稲葉西', '29', '29344', '6360144', '奈良県', 'ナラケン', '生駒郡斑鳩町', 'イコマグンイカルガチョウ', '稲葉西', 'イナバニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒郡斑鳩町龍田北', '29', '29344', '6360151', '奈良県', 'ナラケン', '生駒郡斑鳩町', 'イコマグンイカルガチョウ', '龍田北', 'タツタキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒郡斑鳩町龍田', '29', '29344', '6360152', '奈良県', 'ナラケン', '生駒郡斑鳩町', 'イコマグンイカルガチョウ', '龍田', 'タツタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒郡斑鳩町龍田南', '29', '29344', '6360153', '奈良県', 'ナラケン', '生駒郡斑鳩町', 'イコマグンイカルガチョウ', '龍田南', 'タツタミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒郡斑鳩町龍田西', '29', '29344', '6360154', '奈良県', 'ナラケン', '生駒郡斑鳩町', 'イコマグンイカルガチョウ', '龍田西', 'タツタニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県磯城郡川西町下永', '29', '29361', '6360201', '奈良県', 'ナラケン', '磯城郡川西町', 'シキグンカワニシチョウ', '下永', 'シモナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県磯城郡川西町結崎', '29', '29361', '6360202', '奈良県', 'ナラケン', '磯城郡川西町', 'シキグンカワニシチョウ', '結崎', 'ユウザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県磯城郡川西町梅戸', '29', '29361', '6360203', '奈良県', 'ナラケン', '磯城郡川西町', 'シキグンカワニシチョウ', '梅戸', 'ウメド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県磯城郡川西町唐院', '29', '29361', '6360204', '奈良県', 'ナラケン', '磯城郡川西町', 'シキグンカワニシチョウ', '唐院', 'トウイン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県磯城郡川西町保田', '29', '29361', '6360205', '奈良県', 'ナラケン', '磯城郡川西町', 'シキグンカワニシチョウ', '保田', 'ホタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県磯城郡川西町吐田', '29', '29361', '6360206', '奈良県', 'ナラケン', '磯城郡川西町', 'シキグンカワニシチョウ', '吐田', 'ハンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県磯城郡三宅町三河', '29', '29362', '6360211', '奈良県', 'ナラケン', '磯城郡三宅町', 'シキグンミヤケチョウ', '三河', 'ミカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県磯城郡三宅町石見', '29', '29362', '6360212', '奈良県', 'ナラケン', '磯城郡三宅町', 'シキグンミヤケチョウ', '石見', 'イワミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県磯城郡三宅町伴堂', '29', '29362', '6360213', '奈良県', 'ナラケン', '磯城郡三宅町', 'シキグンミヤケチョウ', '伴堂', 'トモンドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県磯城郡三宅町但馬', '29', '29362', '6360214', '奈良県', 'ナラケン', '磯城郡三宅町', 'シキグンミヤケチョウ', '但馬', 'タジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県磯城郡三宅町上但馬', '29', '29362', '6360215', '奈良県', 'ナラケン', '磯城郡三宅町', 'シキグンミヤケチョウ', '上但馬', 'カミタジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県磯城郡三宅町小柳', '29', '29362', '6360216', '奈良県', 'ナラケン', '磯城郡三宅町', 'シキグンミヤケチョウ', '小柳', 'オヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県磯城郡三宅町屏風', '29', '29362', '6360217', '奈良県', 'ナラケン', '磯城郡三宅町', 'シキグンミヤケチョウ', '屏風', 'ビョウブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県磯城郡田原本町八田', '29', '29363', '6360221', '奈良県', 'ナラケン', '磯城郡田原本町', 'シキグンタワラモトチョウ', '八田', 'ハッタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県磯城郡田原本町法貴寺', '29', '29363', '6360222', '奈良県', 'ナラケン', '磯城郡田原本町', 'シキグンタワラモトチョウ', '法貴寺', 'ホウキジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県磯城郡田原本町鍵', '29', '29363', '6360223', '奈良県', 'ナラケン', '磯城郡田原本町', 'シキグンタワラモトチョウ', '鍵', 'カギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県磯城郡田原本町今里', '29', '29363', '6360224', '奈良県', 'ナラケン', '磯城郡田原本町', 'シキグンタワラモトチョウ', '今里', 'イマザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県磯城郡田原本町西代', '29', '29363', '6360225', '奈良県', 'ナラケン', '磯城郡田原本町', 'シキグンタワラモトチョウ', '西代', 'ニシンダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県磯城郡田原本町唐古', '29', '29363', '6360226', '奈良県', 'ナラケン', '磯城郡田原本町', 'シキグンタワラモトチョウ', '唐古', 'カラコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県磯城郡田原本町為川北方', '29', '29363', '6360231', '奈良県', 'ナラケン', '磯城郡田原本町', 'シキグンタワラモトチョウ', '為川北方', 'タメガワホッポウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県磯城郡田原本町金沢', '29', '29363', '6360232', '奈良県', 'ナラケン', '磯城郡田原本町', 'シキグンタワラモトチョウ', '金沢', 'カナザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県磯城郡田原本町為川南方', '29', '29363', '6360233', '奈良県', 'ナラケン', '磯城郡田原本町', 'シキグンタワラモトチョウ', '為川南方', 'タメガワナンポウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県磯城郡田原本町蔵堂', '29', '29363', '6360234', '奈良県', 'ナラケン', '磯城郡田原本町', 'シキグンタワラモトチョウ', '蔵堂', 'クラドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県磯城郡田原本町東井上', '29', '29363', '6360235', '奈良県', 'ナラケン', '磯城郡田原本町', 'シキグンタワラモトチョウ', '東井上', 'ヒガシイネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県磯城郡田原本町西井上', '29', '29363', '6360236', '奈良県', 'ナラケン', '磯城郡田原本町', 'シキグンタワラモトチョウ', '西井上', 'ニシイネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県磯城郡田原本町小阪', '29', '29363', '6360237', '奈良県', 'ナラケン', '磯城郡田原本町', 'シキグンタワラモトチョウ', '小阪', 'コサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県磯城郡田原本町平田', '29', '29363', '6360241', '奈良県', 'ナラケン', '磯城郡田原本町', 'シキグンタワラモトチョウ', '平田', 'ヒラタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県磯城郡田原本町大木', '29', '29363', '6360242', '奈良県', 'ナラケン', '磯城郡田原本町', 'シキグンタワラモトチョウ', '大木', 'オオギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県磯城郡田原本町伊与戸', '29', '29363', '6360243', '奈良県', 'ナラケン', '磯城郡田原本町', 'シキグンタワラモトチョウ', '伊与戸', 'イヨド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県磯城郡田原本町笠形', '29', '29363', '6360244', '奈良県', 'ナラケン', '磯城郡田原本町', 'シキグンタワラモトチョウ', '笠形', 'カサガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県磯城郡田原本町味間', '29', '29363', '6360245', '奈良県', 'ナラケン', '磯城郡田原本町', 'シキグンタワラモトチョウ', '味間', 'アジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県磯城郡田原本町千代', '29', '29363', '6360246', '奈良県', 'ナラケン', '磯城郡田原本町', 'シキグンタワラモトチョウ', '千代', 'チシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県磯城郡田原本町阪手', '29', '29363', '6360247', '奈良県', 'ナラケン', '磯城郡田原本町', 'シキグンタワラモトチョウ', '阪手', 'サカテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県磯城郡田原本町大安寺', '29', '29363', '6360248', '奈良県', 'ナラケン', '磯城郡田原本町', 'シキグンタワラモトチョウ', '大安寺', 'ダイアンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県磯城郡川西町', '29', '29361', '6360300', '奈良県', 'ナラケン', '磯城郡川西町', 'シキグンカワニシチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('74383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県磯城郡三宅町', '29', '29362', '6360300', '奈良県', 'ナラケン', '磯城郡三宅町', 'シキグンミヤケチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('74384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県磯城郡田原本町', '29', '29363', '6360300', '奈良県', 'ナラケン', '磯城郡田原本町', 'シキグンタワラモトチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('74385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県磯城郡田原本町黒田', '29', '29363', '6360301', '奈良県', 'ナラケン', '磯城郡田原本町', 'シキグンタワラモトチョウ', '黒田', 'クロダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県磯城郡田原本町宮古', '29', '29363', '6360302', '奈良県', 'ナラケン', '磯城郡田原本町', 'シキグンタワラモトチョウ', '宮古', 'ミヤコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県磯城郡田原本町保津', '29', '29363', '6360303', '奈良県', 'ナラケン', '磯城郡田原本町', 'シキグンタワラモトチョウ', '保津', 'ホツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県磯城郡田原本町十六面', '29', '29363', '6360304', '奈良県', 'ナラケン', '磯城郡田原本町', 'シキグンタワラモトチョウ', '十六面', 'ジュウロクセン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県磯城郡田原本町平野', '29', '29363', '6360305', '奈良県', 'ナラケン', '磯城郡田原本町', 'シキグンタワラモトチョウ', '平野', 'ヒラノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県磯城郡田原本町西竹田', '29', '29363', '6360306', '奈良県', 'ナラケン', '磯城郡田原本町', 'シキグンタワラモトチョウ', '西竹田', 'ニシタケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県磯城郡田原本町富本', '29', '29363', '6360307', '奈良県', 'ナラケン', '磯城郡田原本町', 'シキグンタワラモトチョウ', '富本', 'トンモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県磯城郡田原本町八尾', '29', '29363', '6360311', '奈良県', 'ナラケン', '磯城郡田原本町', 'シキグンタワラモトチョウ', '八尾', 'ヤオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県磯城郡田原本町新町', '29', '29363', '6360312', '奈良県', 'ナラケン', '磯城郡田原本町', 'シキグンタワラモトチョウ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県磯城郡田原本町旭町', '29', '29363', '6360313', '奈良県', 'ナラケン', '磯城郡田原本町', 'シキグンタワラモトチョウ', '旭町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県磯城郡田原本町戎通', '29', '29363', '6360314', '奈良県', 'ナラケン', '磯城郡田原本町', 'シキグンタワラモトチョウ', '戎通', 'エビスドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県磯城郡田原本町幸町', '29', '29363', '6360315', '奈良県', 'ナラケン', '磯城郡田原本町', 'シキグンタワラモトチョウ', '幸町', 'サイワイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県磯城郡田原本町室町', '29', '29363', '6360316', '奈良県', 'ナラケン', '磯城郡田原本町', 'シキグンタワラモトチョウ', '室町', 'ムロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県磯城郡田原本町殿町', '29', '29363', '6360317', '奈良県', 'ナラケン', '磯城郡田原本町', 'シキグンタワラモトチョウ', '殿町', 'トノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県磯城郡田原本町八幡町', '29', '29363', '6360321', '奈良県', 'ナラケン', '磯城郡田原本町', 'シキグンタワラモトチョウ', '八幡町', 'ヤハタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県磯城郡田原本町郭内', '29', '29363', '6360322', '奈良県', 'ナラケン', '磯城郡田原本町', 'シキグンタワラモトチョウ', '郭内', 'カクナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県磯城郡田原本町根太口', '29', '29363', '6360323', '奈良県', 'ナラケン', '磯城郡田原本町', 'シキグンタワラモトチョウ', '根太口', 'ネブトグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県磯城郡田原本町三輪町', '29', '29363', '6360324', '奈良県', 'ナラケン', '磯城郡田原本町', 'シキグンタワラモトチョウ', '三輪町', 'ミワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県磯城郡田原本町南町', '29', '29363', '6360325', '奈良県', 'ナラケン', '磯城郡田原本町', 'シキグンタワラモトチョウ', '南町', 'ミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県磯城郡田原本町新地', '29', '29363', '6360326', '奈良県', 'ナラケン', '磯城郡田原本町', 'シキグンタワラモトチョウ', '新地', 'シンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県磯城郡田原本町堺町', '29', '29363', '6360327', '奈良県', 'ナラケン', '磯城郡田原本町', 'シキグンタワラモトチョウ', '堺町', 'サカイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県磯城郡田原本町材木町', '29', '29363', '6360328', '奈良県', 'ナラケン', '磯城郡田原本町', 'シキグンタワラモトチョウ', '材木町', 'ザイモクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県磯城郡田原本町味間町', '29', '29363', '6360329', '奈良県', 'ナラケン', '磯城郡田原本町', 'シキグンタワラモトチョウ', '味間町', 'アジママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県磯城郡田原本町魚町', '29', '29363', '6360331', '奈良県', 'ナラケン', '磯城郡田原本町', 'シキグンタワラモトチョウ', '魚町', 'ウオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県磯城郡田原本町市町', '29', '29363', '6360332', '奈良県', 'ナラケン', '磯城郡田原本町', 'シキグンタワラモトチョウ', '市町', 'イチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県磯城郡田原本町祗園町', '29', '29363', '6360333', '奈良県', 'ナラケン', '磯城郡田原本町', 'シキグンタワラモトチョウ', '祗園町', 'ギオンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県磯城郡田原本町本町', '29', '29363', '6360334', '奈良県', 'ナラケン', '磯城郡田原本町', 'シキグンタワラモトチョウ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県磯城郡田原本町大門東', '29', '29363', '6360335', '奈良県', 'ナラケン', '磯城郡田原本町', 'シキグンタワラモトチョウ', '大門東', 'ダイモンヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県磯城郡田原本町大門中', '29', '29363', '6360336', '奈良県', 'ナラケン', '磯城郡田原本町', 'シキグンタワラモトチョウ', '大門中', 'ダイモンナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県磯城郡田原本町大門西', '29', '29363', '6360337', '奈良県', 'ナラケン', '磯城郡田原本町', 'シキグンタワラモトチョウ', '大門西', 'ダイモンニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県磯城郡田原本町茶町', '29', '29363', '6360338', '奈良県', 'ナラケン', '磯城郡田原本町', 'シキグンタワラモトチョウ', '茶町', 'チャマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県磯城郡田原本町小室', '29', '29363', '6360339', '奈良県', 'ナラケン', '磯城郡田原本町', 'シキグンタワラモトチョウ', '小室', 'コムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県磯城郡田原本町薬王寺', '29', '29363', '6360341', '奈良県', 'ナラケン', '磯城郡田原本町', 'シキグンタワラモトチョウ', '薬王寺', 'ヤクオウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県磯城郡田原本町三笠', '29', '29363', '6360342', '奈良県', 'ナラケン', '磯城郡田原本町', 'シキグンタワラモトチョウ', '三笠', 'ミカサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県磯城郡田原本町秦庄', '29', '29363', '6360343', '奈良県', 'ナラケン', '磯城郡田原本町', 'シキグンタワラモトチョウ', '秦庄', 'ハタノショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県磯城郡田原本町宮森', '29', '29363', '6360344', '奈良県', 'ナラケン', '磯城郡田原本町', 'シキグンタワラモトチョウ', '宮森', 'ミヤノモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県磯城郡田原本町多', '29', '29363', '6360345', '奈良県', 'ナラケン', '磯城郡田原本町', 'シキグンタワラモトチョウ', '多', 'オオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県磯城郡田原本町矢部', '29', '29363', '6360346', '奈良県', 'ナラケン', '磯城郡田原本町', 'シキグンタワラモトチョウ', '矢部', 'ヤベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県磯城郡田原本町新木', '29', '29363', '6360347', '奈良県', 'ナラケン', '磯城郡田原本町', 'シキグンタワラモトチョウ', '新木', 'ニキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県磯城郡田原本町松本', '29', '29363', '6360351', '奈良県', 'ナラケン', '磯城郡田原本町', 'シキグンタワラモトチョウ', '松本', 'マツモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県磯城郡田原本町金剛寺', '29', '29363', '6360352', '奈良県', 'ナラケン', '磯城郡田原本町', 'シキグンタワラモトチョウ', '金剛寺', 'コンゴウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県磯城郡田原本町大網', '29', '29363', '6360353', '奈良県', 'ナラケン', '磯城郡田原本町', 'シキグンタワラモトチョウ', '大網', 'オオアミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県磯城郡田原本町満田', '29', '29363', '6360354', '奈良県', 'ナラケン', '磯城郡田原本町', 'シキグンタワラモトチョウ', '満田', 'マンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県磯城郡田原本町佐味', '29', '29363', '6360355', '奈良県', 'ナラケン', '磯城郡田原本町', 'シキグンタワラモトチョウ', '佐味', 'サミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒郡三郷町夕陽ケ丘', '29', '29343', '6360801', '奈良県', 'ナラケン', '生駒郡三郷町', 'イコマグンサンゴウチョウ', '夕陽ケ丘', 'ユウヒガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒郡三郷町三室', '29', '29343', '6360802', '奈良県', 'ナラケン', '生駒郡三郷町', 'イコマグンサンゴウチョウ', '三室', 'ミムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒郡三郷町東信貴ケ丘', '29', '29343', '6360803', '奈良県', 'ナラケン', '生駒郡三郷町', 'イコマグンサンゴウチョウ', '東信貴ケ丘', 'ヒガシシギガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒郡三郷町美松ケ丘西', '29', '29343', '6360804', '奈良県', 'ナラケン', '生駒郡三郷町', 'イコマグンサンゴウチョウ', '美松ケ丘西', 'ミマツガオカニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒郡三郷町美松ケ丘東', '29', '29343', '6360805', '奈良県', 'ナラケン', '生駒郡三郷町', 'イコマグンサンゴウチョウ', '美松ケ丘東', 'ミマツガオカヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒郡三郷町勢野東', '29', '29343', '6360811', '奈良県', 'ナラケン', '生駒郡三郷町', 'イコマグンサンゴウチョウ', '勢野東', 'セヤヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒郡三郷町勢野西', '29', '29343', '6360812', '奈良県', 'ナラケン', '生駒郡三郷町', 'イコマグンサンゴウチョウ', '勢野西', 'セヤニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒郡三郷町信貴ケ丘', '29', '29343', '6360813', '奈良県', 'ナラケン', '生駒郡三郷町', 'イコマグンサンゴウチョウ', '信貴ケ丘', 'シギガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒郡三郷町勢野', '29', '29343', '6360814', '奈良県', 'ナラケン', '生駒郡三郷町', 'イコマグンサンゴウチョウ', '勢野', 'セヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒郡三郷町勢野北', '29', '29343', '6360815', '奈良県', 'ナラケン', '生駒郡三郷町', 'イコマグンサンゴウチョウ', '勢野北', 'セヤキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒郡三郷町立野北', '29', '29343', '6360821', '奈良県', 'ナラケン', '生駒郡三郷町', 'イコマグンサンゴウチョウ', '立野北', 'タツノキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒郡三郷町立野南', '29', '29343', '6360822', '奈良県', 'ナラケン', '生駒郡三郷町', 'イコマグンサンゴウチョウ', '立野南', 'タツノミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒郡三郷町立野', '29', '29343', '6360823', '奈良県', 'ナラケン', '生駒郡三郷町', 'イコマグンサンゴウチョウ', '立野', 'タツノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒郡三郷町城山台', '29', '29343', '6360824', '奈良県', 'ナラケン', '生駒郡三郷町', 'イコマグンサンゴウチョウ', '城山台', 'シロヤマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒郡三郷町信貴山東', '29', '29343', '6360831', '奈良県', 'ナラケン', '生駒郡三郷町', 'イコマグンサンゴウチョウ', '信貴山東', 'シギサンヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒郡三郷町信貴山西', '29', '29343', '6360832', '奈良県', 'ナラケン', '生駒郡三郷町', 'イコマグンサンゴウチョウ', '信貴山西', 'シギサンニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒郡三郷町信貴南畑', '29', '29343', '6360833', '奈良県', 'ナラケン', '生駒郡三郷町', 'イコマグンサンゴウチョウ', '信貴南畑', 'シギミナミハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒郡三郷町南畑', '29', '29343', '6360834', '奈良県', 'ナラケン', '生駒郡三郷町', 'イコマグンサンゴウチョウ', '南畑', 'ミナミハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒郡平群町椣原', '29', '29342', '6360901', '奈良県', 'ナラケン', '生駒郡平群町', 'イコマグンヘグリチョウ', '椣原', 'シデハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒郡平群町白石畑', '29', '29342', '6360902', '奈良県', 'ナラケン', '生駒郡平群町', 'イコマグンヘグリチョウ', '白石畑', 'シライシバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒郡平群町平等寺', '29', '29342', '6360903', '奈良県', 'ナラケン', '生駒郡平群町', 'イコマグンヘグリチョウ', '平等寺', 'ビョウドウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒郡平群町三里', '29', '29342', '6360904', '奈良県', 'ナラケン', '生駒郡平群町', 'イコマグンヘグリチョウ', '三里', 'ミサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒郡平群町上庄', '29', '29342', '6360905', '奈良県', 'ナラケン', '生駒郡平群町', 'イコマグンヘグリチョウ', '上庄', 'カミショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒郡平群町菊美台', '29', '29342', '6360906', '奈良県', 'ナラケン', '生駒郡平群町', 'イコマグンヘグリチョウ', '菊美台', 'キクミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒郡平群町椿井', '29', '29342', '6360911', '奈良県', 'ナラケン', '生駒郡平群町', 'イコマグンヘグリチョウ', '椿井', 'ツバイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒郡平群町竜田川', '29', '29342', '6360912', '奈良県', 'ナラケン', '生駒郡平群町', 'イコマグンヘグリチョウ', '竜田川', 'タツタガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒郡平群町北信貴ケ丘', '29', '29342', '6360913', '奈良県', 'ナラケン', '生駒郡平群町', 'イコマグンヘグリチョウ', '北信貴ケ丘', 'キタシギガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒郡平群町西宮', '29', '29342', '6360914', '奈良県', 'ナラケン', '生駒郡平群町', 'イコマグンヘグリチョウ', '西宮', 'ニシノミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒郡平群町春日丘', '29', '29342', '6360915', '奈良県', 'ナラケン', '生駒郡平群町', 'イコマグンヘグリチョウ', '春日丘', 'カスガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒郡平群町若井', '29', '29342', '6360916', '奈良県', 'ナラケン', '生駒郡平群町', 'イコマグンヘグリチョウ', '若井', 'ワカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒郡平群町椹原', '29', '29342', '6360921', '奈良県', 'ナラケン', '生駒郡平群町', 'イコマグンヘグリチョウ', '椹原', 'フシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒郡平群町信貴畑', '29', '29342', '6360922', '奈良県', 'ナラケン', '生駒郡平群町', 'イコマグンヘグリチョウ', '信貴畑', 'シギハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒郡平群町信貴山', '29', '29342', '6360923', '奈良県', 'ナラケン', '生駒郡平群町', 'イコマグンヘグリチョウ', '信貴山', 'シギサン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒郡平群町久安寺', '29', '29342', '6360924', '奈良県', 'ナラケン', '生駒郡平群町', 'イコマグンヘグリチョウ', '久安寺', 'キュウアンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒郡平群町越木塚', '29', '29342', '6360925', '奈良県', 'ナラケン', '生駒郡平群町', 'イコマグンヘグリチョウ', '越木塚', 'コシキヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒郡平群町梨本', '29', '29342', '6360931', '奈良県', 'ナラケン', '生駒郡平群町', 'イコマグンヘグリチョウ', '梨本', 'ナシモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒郡平群町吉新', '29', '29342', '6360932', '奈良県', 'ナラケン', '生駒郡平群町', 'イコマグンヘグリチョウ', '吉新', 'ヨシシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒郡平群町下垣内', '29', '29342', '6360933', '奈良県', 'ナラケン', '生駒郡平群町', 'イコマグンヘグリチョウ', '下垣内', 'シモガイト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒郡平群町初香台', '29', '29342', '6360934', '奈良県', 'ナラケン', '生駒郡平群町', 'イコマグンヘグリチョウ', '初香台', 'ハツカダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒郡平群町光ケ丘', '29', '29342', '6360935', '奈良県', 'ナラケン', '生駒郡平群町', 'イコマグンヘグリチョウ', '光ケ丘', 'ヒカリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒郡平群町福貴', '29', '29342', '6360936', '奈良県', 'ナラケン', '生駒郡平群町', 'イコマグンヘグリチョウ', '福貴', 'フキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒郡平群町福貴畑', '29', '29342', '6360937', '奈良県', 'ナラケン', '生駒郡平群町', 'イコマグンヘグリチョウ', '福貴畑', 'フキハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒郡平群町若葉台', '29', '29342', '6360938', '奈良県', 'ナラケン', '生駒郡平群町', 'イコマグンヘグリチョウ', '若葉台', 'ワカバダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒郡平群町緑ケ丘', '29', '29342', '6360941', '奈良県', 'ナラケン', '生駒郡平群町', 'イコマグンヘグリチョウ', '緑ケ丘', 'ミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒郡平群町西向', '29', '29342', '6360942', '奈良県', 'ナラケン', '生駒郡平群町', 'イコマグンヘグリチョウ', '西向', 'ニシムカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒郡平群町椿台', '29', '29342', '6360943', '奈良県', 'ナラケン', '生駒郡平群町', 'イコマグンヘグリチョウ', '椿台', 'ツバキダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒郡平群町櫟原', '29', '29342', '6360944', '奈良県', 'ナラケン', '生駒郡平群町', 'イコマグンヘグリチョウ', '櫟原', 'イチハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒郡平群町鳴川', '29', '29342', '6360945', '奈良県', 'ナラケン', '生駒郡平群町', 'イコマグンヘグリチョウ', '鳴川', 'ナルカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市', '29', '29207', '6370000', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('74488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市西河内町', '29', '29207', '6370001', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '西河内町', 'ニシカワチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市三在町', '29', '29207', '6370002', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '三在町', 'サンザイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市宇野町', '29', '29207', '6370003', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '宇野町', 'ウノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市今井', '29', '29207', '6370004', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '今井', 'イマイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市今井町', '29', '29207', '6370004', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '今井町', 'イマイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市須恵', '29', '29207', '6370005', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '須恵', 'スエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市岡口', '29', '29207', '6370006', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '岡口', 'オカグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市出屋敷町', '29', '29207', '6370011', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '出屋敷町', 'デヤシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市小山町', '29', '29207', '6370012', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '小山町', 'コヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市居伝町', '29', '29207', '6370013', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '居伝町', 'イデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市住川町', '29', '29207', '6370014', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '住川町', 'スガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市大野新田町', '29', '29207', '6370015', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '大野新田町', 'オオノシンデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市近内町', '29', '29207', '6370016', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '近内町', 'チカウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市西久留野町', '29', '29207', '6370017', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '西久留野町', 'ニシクルノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市久留野町', '29', '29207', '6370018', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '久留野町', 'クルノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市小和町', '29', '29207', '6370019', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '小和町', 'オワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市西阿田町', '29', '29207', '6370020', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '西阿田町', 'ニシアダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市東阿田町', '29', '29207', '6370021', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '東阿田町', 'ヒガシアダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市八田町', '29', '29207', '6370022', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '八田町', 'ハッタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市南阿田町', '29', '29207', '6370023', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '南阿田町', 'ミナミアダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市滝町', '29', '29207', '6370024', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '滝町', 'タキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市車谷町', '29', '29207', '6370025', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '車谷町', 'クルマダニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市湯谷市塚町', '29', '29207', '6370026', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '湯谷市塚町', 'ユタニイチヅカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市島野町', '29', '29207', '6370027', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '島野町', 'シマノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市原町', '29', '29207', '6370028', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '原町', 'ハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市山田町', '29', '29207', '6370029', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '山田町', 'ヤマダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市小島町', '29', '29207', '6370031', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '小島町', 'コジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市六倉町', '29', '29207', '6370032', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '六倉町', 'ムツクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市牧町', '29', '29207', '6370033', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '牧町', 'マキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市野原町', '29', '29207', '6370034', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '野原町', 'ノハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市霊安寺町', '29', '29207', '6370035', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '霊安寺町', 'リョウアンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市野原西', '29', '29207', '6370036', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '野原西', 'ノハラニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市野原中', '29', '29207', '6370037', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '野原中', 'ノハラナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市野原東', '29', '29207', '6370038', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '野原東', 'ノハラヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市本町', '29', '29207', '6370041', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市五條', '29', '29207', '6370042', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '五條', 'ゴジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市新町', '29', '29207', '6370043', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市御山町', '29', '29207', '6370051', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '御山町', 'ミヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市丹原町', '29', '29207', '6370052', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '丹原町', 'タンバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市生子町', '29', '29207', '6370053', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '生子町', 'オブスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市樫辻町', '29', '29207', '6370054', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '樫辻町', 'カシツジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市大津町', '29', '29207', '6370060', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '大津町', 'オオツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市中町', '29', '29207', '6370061', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '中町', 'ナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市黒駒町', '29', '29207', '6370062', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '黒駒町', 'クロコマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市大野町', '29', '29207', '6370063', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '大野町', 'オオノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市山陰町', '29', '29207', '6370064', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '山陰町', 'ヤマカゲチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市阪合部新田町', '29', '29207', '6370065', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '阪合部新田町', 'サカアイベシンデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市大深町', '29', '29207', '6370066', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '大深町', 'オオフカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市田殿町', '29', '29207', '6370067', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '田殿町', 'タドノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市火打町', '29', '29207', '6370068', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '火打町', 'ヒウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市表野町', '29', '29207', '6370069', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '表野町', 'ヒョウノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市二見', '29', '29207', '6370071', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '二見', 'フタミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市犬飼町', '29', '29207', '6370072', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '犬飼町', 'イヌカイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市上野町', '29', '29207', '6370073', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '上野町', 'コウズケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市相谷町', '29', '29207', '6370074', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '相谷町', 'アイタニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市畑田町', '29', '29207', '6370075', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '畑田町', 'ハタケダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市木ノ原町', '29', '29207', '6370076', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '木ノ原町', 'キノハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市大沢町', '29', '29207', '6370077', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '大沢町', 'オオザワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市なつみ台', '29', '29207', '6370078', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', 'なつみ台', 'ナツミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市上之町', '29', '29207', '6370081', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '上之町', 'カミノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市中之町', '29', '29207', '6370082', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '中之町', 'ナカノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市下之町', '29', '29207', '6370083', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '下之町', 'シモノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市釜窪町', '29', '29207', '6370084', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '釜窪町', 'カマノクボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市北山町', '29', '29207', '6370091', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '北山町', 'キタヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市岡町', '29', '29207', '6370092', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '岡町', 'オカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市田園', '29', '29207', '6370093', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '田園', 'デンエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市西吉野町大日川', '29', '29207', '6370101', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '西吉野町大日川', 'ニシヨシノチョウオビカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市西吉野町黒淵', '29', '29207', '6370102', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '西吉野町黒淵', 'ニシヨシノチョウクロブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市西吉野町向加名生', '29', '29207', '6370103', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '西吉野町向加名生', 'ニシヨシノチョウムカイアノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市西吉野町屋那瀬', '29', '29207', '6370104', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '西吉野町屋那瀬', 'ニシヨシノチョウヤナセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市西吉野町湯塩', '29', '29207', '6370105', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '西吉野町湯塩', 'ニシヨシノチョウユシオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市西吉野町江出', '29', '29207', '6370111', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '西吉野町江出', 'ニシヨシノチョウエズル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市西吉野町老野', '29', '29207', '6370112', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '西吉野町老野', 'ニシヨシノチョウオイノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市西吉野町神野', '29', '29207', '6370113', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '西吉野町神野', 'ニシヨシノチョウコウノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市西吉野町滝', '29', '29207', '6370114', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '西吉野町滝', 'ニシヨシノチョウタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市西吉野町北曽木', '29', '29207', '6370115', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '西吉野町北曽木', 'ニシヨシノチョウホクソギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市西吉野町和田', '29', '29207', '6370116', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '西吉野町和田', 'ニシヨシノチョウワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市西吉野町永谷', '29', '29207', '6370221', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '西吉野町永谷', 'ニシヨシノチョウエイタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市西吉野町立川渡', '29', '29207', '6370222', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '西吉野町立川渡', 'ニシヨシノチョウタテカワド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市西吉野町本谷', '29', '29207', '6370223', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '西吉野町本谷', 'ニシヨシノチョウモトダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市西吉野町茄子原', '29', '29207', '6370224', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '西吉野町茄子原', 'ニシヨシノチョウナスハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市西吉野町川股', '29', '29207', '6370225', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '西吉野町川股', 'ニシヨシノチョウカワマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市西吉野町西日裏', '29', '29207', '6370226', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '西吉野町西日裏', 'ニシヨシノチョウニシヒウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市西吉野町勢井', '29', '29207', '6370227', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '西吉野町勢井', 'ニシヨシノチョウセイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市西吉野町城戸', '29', '29207', '6370230', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '西吉野町城戸', 'ニシヨシノチョウジョウド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市西吉野町川岸', '29', '29207', '6370231', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '西吉野町川岸', 'ニシヨシノチョウカワギシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市西吉野町津越', '29', '29207', '6370232', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '西吉野町津越', 'ニシヨシノチョウツゴシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市西吉野町桧川迫', '29', '29207', '6370233', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '西吉野町桧川迫', 'ニシヨシノチョウヒカワセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市西吉野町大峯', '29', '29207', '6370234', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '西吉野町大峯', 'ニシヨシノチョウオオミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市西吉野町平雄', '29', '29207', '6370235', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '西吉野町平雄', 'ニシヨシノチョウヒラオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市西吉野町阪巻', '29', '29207', '6370236', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '西吉野町阪巻', 'ニシヨシノチョウサカマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市西吉野町宗川野', '29', '29207', '6370237', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '西吉野町宗川野', 'ニシヨシノチョウムネガワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市西吉野町西野', '29', '29207', '6370238', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '西吉野町西野', 'ニシヨシノチョウニシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市西吉野町陰地', '29', '29207', '6370239', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '西吉野町陰地', 'ニシヨシノチョウオンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市大塔町篠原', '29', '29207', '6370401', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '大塔町篠原', 'オオトウチョウシノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市大塔町惣谷', '29', '29207', '6370402', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '大塔町惣谷', 'オオトウチョウソウタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市大塔町中井傍示', '29', '29207', '6370403', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '大塔町中井傍示', 'オオトウチョウナカイホウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市大塔町中峯', '29', '29207', '6370404', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '大塔町中峯', 'オオトウチョウナカミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市大塔町宇井', '29', '29207', '6370405', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '大塔町宇井', 'オオトウチョウウイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市大塔町清水', '29', '29207', '6370406', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '大塔町清水', 'オオトウチョウシミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市大塔町閉君', '29', '29207', '6370407', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '大塔町閉君', 'オオトウチョウトジキミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市大塔町辻堂', '29', '29207', '6370408', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '大塔町辻堂', 'オオトウチョウツジドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市大塔町殿野', '29', '29207', '6370409', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '大塔町殿野', 'オオトウチョウトノノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市大塔町堂平', '29', '29207', '6370411', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '大塔町堂平', 'オオトウチョウドウヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市大塔町飛養曽', '29', '29207', '6370412', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '大塔町飛養曽', 'オオトウチョウヒヨソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市大塔町引土', '29', '29207', '6370413', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '大塔町引土', 'オオトウチョウヒキツチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市大塔町猿谷', '29', '29207', '6370414', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '大塔町猿谷', 'オオトウチョウサルタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市大塔町中原', '29', '29207', '6370415', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '大塔町中原', 'オオトウチョウナカバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市大塔町小代', '29', '29207', '6370416', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '大塔町小代', 'オオトウチョウコダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市大塔町阪本', '29', '29207', '6370417', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '大塔町阪本', 'オオトウチョウサカモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市大塔町簾', '29', '29207', '6370419', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '大塔町簾', 'オオトウチョウスダレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡野迫川村今井', '29', '29447', '6370421', '奈良県', 'ナラケン', '吉野郡野迫川村', 'ヨシノグンノセガワムラ', '今井', 'イマイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡野迫川村平川', '29', '29447', '6370422', '奈良県', 'ナラケン', '吉野郡野迫川村', 'ヨシノグンノセガワムラ', '平川', 'ヒラカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡野迫川村柞原', '29', '29447', '6370423', '奈良県', 'ナラケン', '吉野郡野迫川村', 'ヨシノグンノセガワムラ', '柞原', 'ホソハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡野迫川村中', '29', '29447', '6370424', '奈良県', 'ナラケン', '吉野郡野迫川村', 'ヨシノグンノセガワムラ', '中', 'ナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡野迫川村上', '29', '29447', '6370425', '奈良県', 'ナラケン', '吉野郡野迫川村', 'ヨシノグンノセガワムラ', '上', 'カミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡十津川村沼田原', '29', '29449', '6371101', '奈良県', 'ナラケン', '吉野郡十津川村', 'ヨシノグントツカワムラ', '沼田原', 'ヌタノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡十津川村旭', '29', '29449', '6371102', '奈良県', 'ナラケン', '吉野郡十津川村', 'ヨシノグントツカワムラ', '旭', 'アサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡十津川村上野地', '29', '29449', '6371103', '奈良県', 'ナラケン', '吉野郡十津川村', 'ヨシノグントツカワムラ', '上野地', 'ウエノジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡十津川村高津', '29', '29449', '6371104', '奈良県', 'ナラケン', '吉野郡十津川村', 'ヨシノグントツカワムラ', '高津', 'タコウツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡十津川村林', '29', '29449', '6371105', '奈良県', 'ナラケン', '吉野郡十津川村', 'ヨシノグントツカワムラ', '林', 'ハヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡十津川村谷瀬', '29', '29449', '6371106', '奈良県', 'ナラケン', '吉野郡十津川村', 'ヨシノグントツカワムラ', '谷瀬', 'タニゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡十津川村宇宮原', '29', '29449', '6371107', '奈良県', 'ナラケン', '吉野郡十津川村', 'ヨシノグントツカワムラ', '宇宮原', 'ウグハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡十津川村長殿', '29', '29449', '6371108', '奈良県', 'ナラケン', '吉野郡十津川村', 'ヨシノグントツカワムラ', '長殿', 'ナガトノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡十津川村滝川', '29', '29449', '6371211', '奈良県', 'ナラケン', '吉野郡十津川村', 'ヨシノグントツカワムラ', '滝川', 'タキガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡十津川村内原', '29', '29449', '6371212', '奈良県', 'ナラケン', '吉野郡十津川村', 'ヨシノグントツカワムラ', '内原', 'ナイバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡十津川村野尻', '29', '29449', '6371213', '奈良県', 'ナラケン', '吉野郡十津川村', 'ヨシノグントツカワムラ', '野尻', 'ノジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡十津川村山崎', '29', '29449', '6371214', '奈良県', 'ナラケン', '吉野郡十津川村', 'ヨシノグントツカワムラ', '山崎', 'ヤマサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡十津川村池穴', '29', '29449', '6371215', '奈良県', 'ナラケン', '吉野郡十津川村', 'ヨシノグントツカワムラ', '池穴', 'イケアナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡十津川村川津', '29', '29449', '6371216', '奈良県', 'ナラケン', '吉野郡十津川村', 'ヨシノグントツカワムラ', '川津', 'カワツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡十津川村風屋', '29', '29449', '6371217', '奈良県', 'ナラケン', '吉野郡十津川村', 'ヨシノグントツカワムラ', '風屋', 'カゼヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡十津川村内野', '29', '29449', '6371221', '奈良県', 'ナラケン', '吉野郡十津川村', 'ヨシノグントツカワムラ', '内野', 'ウチノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡十津川村山天', '29', '29449', '6371222', '奈良県', 'ナラケン', '吉野郡十津川村', 'ヨシノグントツカワムラ', '山天', 'ヤマテン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡十津川村三浦', '29', '29449', '6371223', '奈良県', 'ナラケン', '吉野郡十津川村', 'ヨシノグントツカワムラ', '三浦', 'ミウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡十津川村五百瀬', '29', '29449', '6371224', '奈良県', 'ナラケン', '吉野郡十津川村', 'ヨシノグントツカワムラ', '五百瀬', 'イモゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡十津川村杉清', '29', '29449', '6371225', '奈良県', 'ナラケン', '吉野郡十津川村', 'ヨシノグントツカワムラ', '杉清', 'スギセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡十津川村大野', '29', '29449', '6371331', '奈良県', 'ナラケン', '吉野郡十津川村', 'ヨシノグントツカワムラ', '大野', 'オオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡十津川村武蔵', '29', '29449', '6371332', '奈良県', 'ナラケン', '吉野郡十津川村', 'ヨシノグントツカワムラ', '武蔵', 'ムサシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡十津川村小原', '29', '29449', '6371333', '奈良県', 'ナラケン', '吉野郡十津川村', 'ヨシノグントツカワムラ', '小原', 'オハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡十津川村小森', '29', '29449', '6371334', '奈良県', 'ナラケン', '吉野郡十津川村', 'ヨシノグントツカワムラ', '小森', 'コモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡十津川村湯之原', '29', '29449', '6371335', '奈良県', 'ナラケン', '吉野郡十津川村', 'ヨシノグントツカワムラ', '湯之原', 'ユノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡十津川村小井', '29', '29449', '6371336', '奈良県', 'ナラケン', '吉野郡十津川村', 'ヨシノグントツカワムラ', '小井', 'コイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡十津川村小川', '29', '29449', '6371441', '奈良県', 'ナラケン', '吉野郡十津川村', 'ヨシノグントツカワムラ', '小川', 'オガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡十津川村高滝', '29', '29449', '6371442', '奈良県', 'ナラケン', '吉野郡十津川村', 'ヨシノグントツカワムラ', '高滝', 'タカタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡十津川村折立', '29', '29449', '6371443', '奈良県', 'ナラケン', '吉野郡十津川村', 'ヨシノグントツカワムラ', '折立', 'オリタチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡十津川村山手谷', '29', '29449', '6371444', '奈良県', 'ナラケン', '吉野郡十津川村', 'ヨシノグントツカワムラ', '山手谷', 'ヤマテダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡十津川村込之上', '29', '29449', '6371445', '奈良県', 'ナラケン', '吉野郡十津川村', 'ヨシノグントツカワムラ', '込之上', 'コミノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡十津川村樫原', '29', '29449', '6371446', '奈良県', 'ナラケン', '吉野郡十津川村', 'ヨシノグントツカワムラ', '樫原', 'カシワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡十津川村', '29', '29449', '6371500', '奈良県', 'ナラケン', '吉野郡十津川村', 'ヨシノグントツカワムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('74637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡十津川村那知合', '29', '29449', '6371551', '奈良県', 'ナラケン', '吉野郡十津川村', 'ヨシノグントツカワムラ', '那知合', 'ナチアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡十津川村谷垣内', '29', '29449', '6371552', '奈良県', 'ナラケン', '吉野郡十津川村', 'ヨシノグントツカワムラ', '谷垣内', 'タニガイト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡十津川村山手', '29', '29449', '6371553', '奈良県', 'ナラケン', '吉野郡十津川村', 'ヨシノグントツカワムラ', '山手', 'ヤマテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡十津川村平谷', '29', '29449', '6371554', '奈良県', 'ナラケン', '吉野郡十津川村', 'ヨシノグントツカワムラ', '平谷', 'ヒラタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡十津川村猿飼', '29', '29449', '6371555', '奈良県', 'ナラケン', '吉野郡十津川村', 'ヨシノグントツカワムラ', '猿飼', 'サルカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡十津川村桑畑', '29', '29449', '6371556', '奈良県', 'ナラケン', '吉野郡十津川村', 'ヨシノグントツカワムラ', '桑畑', 'クワハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡十津川村七色', '29', '29449', '6371557', '奈良県', 'ナラケン', '吉野郡十津川村', 'ヨシノグントツカワムラ', '七色', 'ナナイロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡十津川村出谷', '29', '29449', '6371558', '奈良県', 'ナラケン', '吉野郡十津川村', 'ヨシノグントツカワムラ', '出谷', 'デタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡十津川村上湯川', '29', '29449', '6371559', '奈良県', 'ナラケン', '吉野郡十津川村', 'ヨシノグントツカワムラ', '上湯川', 'カミユカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡十津川村重里', '29', '29449', '6371661', '奈良県', 'ナラケン', '吉野郡十津川村', 'ヨシノグントツカワムラ', '重里', 'シゲサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡十津川村永井', '29', '29449', '6371662', '奈良県', 'ナラケン', '吉野郡十津川村', 'ヨシノグントツカワムラ', '永井', 'ナガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡十津川村玉垣内', '29', '29449', '6371663', '奈良県', 'ナラケン', '吉野郡十津川村', 'ヨシノグントツカワムラ', '玉垣内', 'タマガイト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡十津川村今西', '29', '29449', '6371664', '奈良県', 'ナラケン', '吉野郡十津川村', 'ヨシノグントツカワムラ', '今西', 'イマニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡十津川村西中', '29', '29449', '6371665', '奈良県', 'ナラケン', '吉野郡十津川村', 'ヨシノグントツカワムラ', '西中', 'ニシナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡十津川村小山手', '29', '29449', '6371666', '奈良県', 'ナラケン', '吉野郡十津川村', 'ヨシノグントツカワムラ', '小山手', 'コヤマテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡十津川村小坪瀬', '29', '29449', '6371667', '奈良県', 'ナラケン', '吉野郡十津川村', 'ヨシノグントツカワムラ', '小坪瀬', 'コツボセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡十津川村迫西川', '29', '29449', '6371668', '奈良県', 'ナラケン', '吉野郡十津川村', 'ヨシノグントツカワムラ', '迫西川', 'セニシガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡大淀町', '29', '29442', '6380000', '奈良県', 'ナラケン', '吉野郡大淀町', 'ヨシノグンオオヨドチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('74657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡下市町', '29', '29443', '6380000', '奈良県', 'ナラケン', '吉野郡下市町', 'ヨシノグンシモイチチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('74658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡下市町阿知賀', '29', '29443', '6380001', '奈良県', 'ナラケン', '吉野郡下市町', 'ヨシノグンシモイチチョウ', '阿知賀', 'アチガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡下市町小路', '29', '29443', '6380002', '奈良県', 'ナラケン', '吉野郡下市町', 'ヨシノグンシモイチチョウ', '小路', 'ショウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡下市町善城', '29', '29443', '6380003', '奈良県', 'ナラケン', '吉野郡下市町', 'ヨシノグンシモイチチョウ', '善城', 'ゼンギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡下市町よ邑', '29', '29443', '6380011', '奈良県', 'ナラケン', '吉野郡下市町', 'ヨシノグンシモイチチョウ', 'よ邑', 'ヨムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡下市町岩森', '29', '29443', '6380012', '奈良県', 'ナラケン', '吉野郡下市町', 'ヨシノグンシモイチチョウ', '岩森', 'イワモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡下市町立石', '29', '29443', '6380013', '奈良県', 'ナラケン', '吉野郡下市町', 'ヨシノグンシモイチチョウ', '立石', 'タテイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡下市町才谷', '29', '29443', '6380014', '奈良県', 'ナラケン', '吉野郡下市町', 'ヨシノグンシモイチチョウ', '才谷', 'サイタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡下市町広橋', '29', '29443', '6380015', '奈良県', 'ナラケン', '吉野郡下市町', 'ヨシノグンシモイチチョウ', '広橋', 'ヒロハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡下市町長谷', '29', '29443', '6380021', '奈良県', 'ナラケン', '吉野郡下市町', 'ヨシノグンシモイチチョウ', '長谷', 'ナガタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡下市町丹生', '29', '29443', '6380022', '奈良県', 'ナラケン', '吉野郡下市町', 'ヨシノグンシモイチチョウ', '丹生', 'ニウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡下市町黒木', '29', '29443', '6380023', '奈良県', 'ナラケン', '吉野郡下市町', 'ヨシノグンシモイチチョウ', '黒木', 'クロギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡下市町貝原', '29', '29443', '6380024', '奈良県', 'ナラケン', '吉野郡下市町', 'ヨシノグンシモイチチョウ', '貝原', 'カイバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡下市町谷', '29', '29443', '6380025', '奈良県', 'ナラケン', '吉野郡下市町', 'ヨシノグンシモイチチョウ', '谷', 'タニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡下市町西山', '29', '29443', '6380026', '奈良県', 'ナラケン', '吉野郡下市町', 'ヨシノグンシモイチチョウ', '西山', 'ニシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡下市町栃本', '29', '29443', '6380031', '奈良県', 'ナラケン', '吉野郡下市町', 'ヨシノグンシモイチチョウ', '栃本', 'トチモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡下市町原谷', '29', '29443', '6380032', '奈良県', 'ナラケン', '吉野郡下市町', 'ヨシノグンシモイチチョウ', '原谷', 'ハラダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡下市町梨子堂', '29', '29443', '6380033', '奈良県', 'ナラケン', '吉野郡下市町', 'ヨシノグンシモイチチョウ', '梨子堂', 'ナシドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡下市町平原', '29', '29443', '6380034', '奈良県', 'ナラケン', '吉野郡下市町', 'ヨシノグンシモイチチョウ', '平原', 'ヘイバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡下市町栃原', '29', '29443', '6380035', '奈良県', 'ナラケン', '吉野郡下市町', 'ヨシノグンシモイチチョウ', '栃原', 'トチハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡下市町下市', '29', '29443', '6380041', '奈良県', 'ナラケン', '吉野郡下市町', 'ヨシノグンシモイチチョウ', '下市', 'シモイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡下市町栄町', '29', '29443', '6380042', '奈良県', 'ナラケン', '吉野郡下市町', 'ヨシノグンシモイチチョウ', '栄町', 'サカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡下市町大峯', '29', '29443', '6380043', '奈良県', 'ナラケン', '吉野郡下市町', 'ヨシノグンシモイチチョウ', '大峯', 'オオミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡下市町田中', '29', '29443', '6380044', '奈良県', 'ナラケン', '吉野郡下市町', 'ヨシノグンシモイチチョウ', '田中', 'タナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡下市町新住', '29', '29443', '6380045', '奈良県', 'ナラケン', '吉野郡下市町', 'ヨシノグンシモイチチョウ', '新住', 'アタラスミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡黒滝村', '29', '29444', '6380200', '奈良県', 'ナラケン', '吉野郡黒滝村', 'ヨシノグンクロタキムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('74683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡黒滝村槇尾', '29', '29444', '6380201', '奈良県', 'ナラケン', '吉野郡黒滝村', 'ヨシノグンクロタキムラ', '槇尾', 'マキオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡黒滝村脇川', '29', '29444', '6380202', '奈良県', 'ナラケン', '吉野郡黒滝村', 'ヨシノグンクロタキムラ', '脇川', 'ワキガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡黒滝村鳥住', '29', '29444', '6380203', '奈良県', 'ナラケン', '吉野郡黒滝村', 'ヨシノグンクロタキムラ', '鳥住', 'トリスミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡黒滝村赤滝', '29', '29444', '6380211', '奈良県', 'ナラケン', '吉野郡黒滝村', 'ヨシノグンクロタキムラ', '赤滝', 'アカタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡黒滝村中戸', '29', '29444', '6380221', '奈良県', 'ナラケン', '吉野郡黒滝村', 'ヨシノグンクロタキムラ', '中戸', 'ナカト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡黒滝村笠木', '29', '29444', '6380231', '奈良県', 'ナラケン', '吉野郡黒滝村', 'ヨシノグンクロタキムラ', '笠木', 'カサギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡黒滝村桂原', '29', '29444', '6380232', '奈良県', 'ナラケン', '吉野郡黒滝村', 'ヨシノグンクロタキムラ', '桂原', 'カツラハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡黒滝村長瀬', '29', '29444', '6380233', '奈良県', 'ナラケン', '吉野郡黒滝村', 'ヨシノグンクロタキムラ', '長瀬', 'ナガセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡黒滝村粟飯谷', '29', '29444', '6380241', '奈良県', 'ナラケン', '吉野郡黒滝村', 'ヨシノグンクロタキムラ', '粟飯谷', 'アワイダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡黒滝村御吉野', '29', '29444', '6380242', '奈良県', 'ナラケン', '吉野郡黒滝村', 'ヨシノグンクロタキムラ', '御吉野', 'ミヨシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡黒滝村堂原', '29', '29444', '6380243', '奈良県', 'ナラケン', '吉野郡黒滝村', 'ヨシノグンクロタキムラ', '堂原', 'ドウバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡黒滝村寺戸', '29', '29444', '6380251', '奈良県', 'ナラケン', '吉野郡黒滝村', 'ヨシノグンクロタキムラ', '寺戸', 'テラド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡天川村', '29', '29446', '6380300', '奈良県', 'ナラケン', '吉野郡天川村', 'ヨシノグンテンカワムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('74697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡天川村川合', '29', '29446', '6380301', '奈良県', 'ナラケン', '吉野郡天川村', 'ヨシノグンテンカワムラ', '川合', 'カワアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡天川村中越', '29', '29446', '6380302', '奈良県', 'ナラケン', '吉野郡天川村', 'ヨシノグンテンカワムラ', '中越', 'ナカゴシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡天川村北角', '29', '29446', '6380303', '奈良県', 'ナラケン', '吉野郡天川村', 'ヨシノグンテンカワムラ', '北角', 'キトズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡天川村南角', '29', '29446', '6380304', '奈良県', 'ナラケン', '吉野郡天川村', 'ヨシノグンテンカワムラ', '南角', 'ミノズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡天川村沢谷', '29', '29446', '6380305', '奈良県', 'ナラケン', '吉野郡天川村', 'ヨシノグンテンカワムラ', '沢谷', 'サワタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡天川村沖金', '29', '29446', '6380311', '奈良県', 'ナラケン', '吉野郡天川村', 'ヨシノグンテンカワムラ', '沖金', 'オキガネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡天川村中谷', '29', '29446', '6380312', '奈良県', 'ナラケン', '吉野郡天川村', 'ヨシノグンテンカワムラ', '中谷', 'ナカタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡天川村北小原', '29', '29446', '6380313', '奈良県', 'ナラケン', '吉野郡天川村', 'ヨシノグンテンカワムラ', '北小原', 'キタコバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡天川村五色', '29', '29446', '6380314', '奈良県', 'ナラケン', '吉野郡天川村', 'ヨシノグンテンカワムラ', '五色', 'ゴシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡天川村沢原', '29', '29446', '6380315', '奈良県', 'ナラケン', '吉野郡天川村', 'ヨシノグンテンカワムラ', '沢原', 'サワバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡天川村坪内', '29', '29446', '6380321', '奈良県', 'ナラケン', '吉野郡天川村', 'ヨシノグンテンカワムラ', '坪内', 'ツボノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡天川村南日裏', '29', '29446', '6380322', '奈良県', 'ナラケン', '吉野郡天川村', 'ヨシノグンテンカワムラ', '南日裏', 'ミナミヒウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡天川村洞川', '29', '29446', '6380431', '奈良県', 'ナラケン', '吉野郡天川村', 'ヨシノグンテンカワムラ', '洞川', 'ドロガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡天川村九尾', '29', '29446', '6380541', '奈良県', 'ナラケン', '吉野郡天川村', 'ヨシノグンテンカワムラ', '九尾', 'ツヅラオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡天川村栃尾', '29', '29446', '6380542', '奈良県', 'ナラケン', '吉野郡天川村', 'ヨシノグンテンカワムラ', '栃尾', 'トチオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡天川村和田', '29', '29446', '6380543', '奈良県', 'ナラケン', '吉野郡天川村', 'ヨシノグンテンカワムラ', '和田', 'ワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡天川村籠山', '29', '29446', '6380551', '奈良県', 'ナラケン', '吉野郡天川村', 'ヨシノグンテンカワムラ', '籠山', 'コモリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡天川村庵住', '29', '29446', '6380552', '奈良県', 'ナラケン', '吉野郡天川村', 'ヨシノグンテンカワムラ', '庵住', 'イオスミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡天川村山西', '29', '29446', '6380553', '奈良県', 'ナラケン', '吉野郡天川村', 'ヨシノグンテンカワムラ', '山西', 'ヤマニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡天川村広瀬', '29', '29446', '6380561', '奈良県', 'ナラケン', '吉野郡天川村', 'ヨシノグンテンカワムラ', '広瀬', 'ヒロセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡天川村滝尾', '29', '29446', '6380562', '奈良県', 'ナラケン', '吉野郡天川村', 'ヨシノグンテンカワムラ', '滝尾', 'タキオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡天川村塩野', '29', '29446', '6380563', '奈良県', 'ナラケン', '吉野郡天川村', 'ヨシノグンテンカワムラ', '塩野', 'シオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡天川村塩谷', '29', '29446', '6380564', '奈良県', 'ナラケン', '吉野郡天川村', 'ヨシノグンテンカワムラ', '塩谷', 'シオタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市西吉野町百谷', '29', '29207', '6380641', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '西吉野町百谷', 'ニシヨシノチョウモモダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市西吉野町平沼田', '29', '29207', '6380642', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '西吉野町平沼田', 'ニシヨシノチョウヒラヌマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市西吉野町赤松', '29', '29207', '6380643', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '西吉野町赤松', 'ニシヨシノチョウアカマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市西吉野町湯川', '29', '29207', '6380644', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '西吉野町湯川', 'ニシヨシノチョウユカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市西吉野町唐戸', '29', '29207', '6380651', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '西吉野町唐戸', 'ニシヨシノチョウカラト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市西吉野町尼ケ生', '29', '29207', '6380652', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '西吉野町尼ケ生', 'ニシヨシノチョウアマガショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市西吉野町十日市', '29', '29207', '6380653', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '西吉野町十日市', 'ニシヨシノチョウトオカイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市西吉野町南山', '29', '29207', '6380654', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '西吉野町南山', 'ニシヨシノチョウミナミヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市西吉野町小古田', '29', '29207', '6380655', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '西吉野町小古田', 'ニシヨシノチョウオブルタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市西吉野町鹿場', '29', '29207', '6380656', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '西吉野町鹿場', 'ニシヨシノチョウシシバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市西吉野町八ツ川', '29', '29207', '6380657', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '西吉野町八ツ川', 'ニシヨシノチョウヤツカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市西吉野町西新子', '29', '29207', '6380661', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '西吉野町西新子', 'ニシヨシノチョウニシアタラシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市西吉野町夜中', '29', '29207', '6380662', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '西吉野町夜中', 'ニシヨシノチョウヨナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県五條市西吉野町奥谷', '29', '29207', '6380663', '奈良県', 'ナラケン', '五條市', 'ゴジョウシ', '西吉野町奥谷', 'ニシヨシノチョウオクダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡大淀町芦原', '29', '29442', '6380801', '奈良県', 'ナラケン', '吉野郡大淀町', 'ヨシノグンオオヨドチョウ', '芦原', 'アシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡大淀町畑屋', '29', '29442', '6380802', '奈良県', 'ナラケン', '吉野郡大淀町', 'ヨシノグンオオヨドチョウ', '畑屋', 'ハタヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡大淀町越部', '29', '29442', '6380803', '奈良県', 'ナラケン', '吉野郡大淀町', 'ヨシノグンオオヨドチョウ', '越部', 'コシベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡大淀町土田', '29', '29442', '6380811', '奈良県', 'ナラケン', '吉野郡大淀町', 'ヨシノグンオオヨドチョウ', '土田', 'ツチダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡大淀町桧垣本', '29', '29442', '6380812', '奈良県', 'ナラケン', '吉野郡大淀町', 'ヨシノグンオオヨドチョウ', '桧垣本', 'ヒガイモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡大淀町下渕', '29', '29442', '6380821', '奈良県', 'ナラケン', '吉野郡大淀町', 'ヨシノグンオオヨドチョウ', '下渕', 'シモブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡大淀町佐名伝', '29', '29442', '6380831', '奈良県', 'ナラケン', '吉野郡大淀町', 'ヨシノグンオオヨドチョウ', '佐名伝', 'サナテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡大淀町薬水', '29', '29442', '6380832', '奈良県', 'ナラケン', '吉野郡大淀町', 'ヨシノグンオオヨドチョウ', '薬水', 'クスリミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡大淀町福神', '29', '29442', '6380833', '奈良県', 'ナラケン', '吉野郡大淀町', 'ヨシノグンオオヨドチョウ', '福神', 'フクガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡大淀町今木', '29', '29442', '6380841', '奈良県', 'ナラケン', '吉野郡大淀町', 'ヨシノグンオオヨドチョウ', '今木', 'イマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡大淀町大岩', '29', '29442', '6380842', '奈良県', 'ナラケン', '吉野郡大淀町', 'ヨシノグンオオヨドチョウ', '大岩', 'オオイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡大淀町鉾立', '29', '29442', '6380843', '奈良県', 'ナラケン', '吉野郡大淀町', 'ヨシノグンオオヨドチョウ', '鉾立', 'ホコタテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡大淀町岩壺', '29', '29442', '6380851', '奈良県', 'ナラケン', '吉野郡大淀町', 'ヨシノグンオオヨドチョウ', '岩壺', 'イワツボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡大淀町持尾', '29', '29442', '6380852', '奈良県', 'ナラケン', '吉野郡大淀町', 'ヨシノグンオオヨドチョウ', '持尾', 'モチオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡大淀町矢走', '29', '29442', '6380853', '奈良県', 'ナラケン', '吉野郡大淀町', 'ヨシノグンオオヨドチョウ', '矢走', 'ヤバセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県香芝市', '29', '29210', '6390200', '奈良県', 'ナラケン', '香芝市', 'カシバシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('74767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県北葛城郡上牧町', '29', '29424', '6390200', '奈良県', 'ナラケン', '北葛城郡上牧町', 'キタカツラギグンカンマキチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('74768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県北葛城郡上牧町片岡台', '29', '29424', '6390201', '奈良県', 'ナラケン', '北葛城郡上牧町', 'キタカツラギグンカンマキチョウ', '片岡台', 'カタオカダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県北葛城郡上牧町桜ケ丘', '29', '29424', '6390202', '奈良県', 'ナラケン', '北葛城郡上牧町', 'キタカツラギグンカンマキチョウ', '桜ケ丘', 'サクラガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県北葛城郡上牧町友が丘', '29', '29424', '6390203', '奈良県', 'ナラケン', '北葛城郡上牧町', 'キタカツラギグンカンマキチョウ', '友が丘', 'トモガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県北葛城郡上牧町緑ケ丘', '29', '29424', '6390204', '奈良県', 'ナラケン', '北葛城郡上牧町', 'キタカツラギグンカンマキチョウ', '緑ケ丘', 'ミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県北葛城郡上牧町下牧', '29', '29424', '6390205', '奈良県', 'ナラケン', '北葛城郡上牧町', 'キタカツラギグンカンマキチョウ', '下牧', 'シモマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県北葛城郡上牧町滝川台', '29', '29424', '6390211', '奈良県', 'ナラケン', '北葛城郡上牧町', 'キタカツラギグンカンマキチョウ', '滝川台', 'タキガワダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県北葛城郡上牧町服部台', '29', '29424', '6390212', '奈良県', 'ナラケン', '北葛城郡上牧町', 'キタカツラギグンカンマキチョウ', '服部台', 'ハットリダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県北葛城郡上牧町米山台', '29', '29424', '6390213', '奈良県', 'ナラケン', '北葛城郡上牧町', 'キタカツラギグンカンマキチョウ', '米山台', 'ヨネヤマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県北葛城郡上牧町上牧', '29', '29424', '6390214', '奈良県', 'ナラケン', '北葛城郡上牧町', 'キタカツラギグンカンマキチョウ', '上牧', 'カンマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県北葛城郡上牧町葛城台', '29', '29424', '6390215', '奈良県', 'ナラケン', '北葛城郡上牧町', 'キタカツラギグンカンマキチョウ', '葛城台', 'カツラギダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県北葛城郡上牧町松里園', '29', '29424', '6390216', '奈良県', 'ナラケン', '北葛城郡上牧町', 'キタカツラギグンカンマキチョウ', '松里園', 'ショウリエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県北葛城郡上牧町中筋出作', '29', '29424', '6390217', '奈良県', 'ナラケン', '北葛城郡上牧町', 'キタカツラギグンカンマキチョウ', '中筋出作', 'ナカスジシュツサク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県香芝市五ケ所', '29', '29210', '6390221', '奈良県', 'ナラケン', '香芝市', 'カシバシ', '五ケ所', 'ゴカショ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県香芝市西真美', '29', '29210', '6390222', '奈良県', 'ナラケン', '香芝市', 'カシバシ', '西真美', 'ニシマミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県香芝市真美ケ丘', '29', '29210', '6390223', '奈良県', 'ナラケン', '香芝市', 'カシバシ', '真美ケ丘', 'マミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県香芝市別所', '29', '29210', '6390224', '奈良県', 'ナラケン', '香芝市', 'カシバシ', '別所', 'ベッシヨ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県香芝市瓦口', '29', '29210', '6390225', '奈良県', 'ナラケン', '香芝市', 'カシバシ', '瓦口', 'カワラグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県香芝市五位堂', '29', '29210', '6390226', '奈良県', 'ナラケン', '香芝市', 'カシバシ', '五位堂', 'ゴイドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県香芝市鎌田', '29', '29210', '6390227', '奈良県', 'ナラケン', '香芝市', 'カシバシ', '鎌田', 'カマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県香芝市下田西', '29', '29210', '6390231', '奈良県', 'ナラケン', '香芝市', 'カシバシ', '下田西', 'シモダニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県香芝市下田東', '29', '29210', '6390232', '奈良県', 'ナラケン', '香芝市', 'カシバシ', '下田東', 'シモダヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県香芝市下田', '29', '29210', '6390233', '奈良県', 'ナラケン', '香芝市', 'カシバシ', '下田', 'シモダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県香芝市狐井', '29', '29210', '6390234', '奈良県', 'ナラケン', '香芝市', 'カシバシ', '狐井', 'キツイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県香芝市良福寺', '29', '29210', '6390235', '奈良県', 'ナラケン', '香芝市', 'カシバシ', '良福寺', 'リョウフクジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県香芝市磯壁', '29', '29210', '6390236', '奈良県', 'ナラケン', '香芝市', 'カシバシ', '磯壁', 'イソカベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県香芝市高', '29', '29210', '6390241', '奈良県', 'ナラケン', '香芝市', 'カシバシ', '高', 'タカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県香芝市北今市', '29', '29210', '6390242', '奈良県', 'ナラケン', '香芝市', 'カシバシ', '北今市', 'キタイマイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県香芝市藤山', '29', '29210', '6390243', '奈良県', 'ナラケン', '香芝市', 'カシバシ', '藤山', 'フジヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県香芝市本町', '29', '29210', '6390244', '奈良県', 'ナラケン', '香芝市', 'カシバシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県香芝市畑', '29', '29210', '6390245', '奈良県', 'ナラケン', '香芝市', 'カシバシ', '畑', 'ハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県香芝市逢坂', '29', '29210', '6390251', '奈良県', 'ナラケン', '香芝市', 'カシバシ', '逢坂', 'オウサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県香芝市穴虫', '29', '29210', '6390252', '奈良県', 'ナラケン', '香芝市', 'カシバシ', '穴虫', 'アナムシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県香芝市田尻', '29', '29210', '6390253', '奈良県', 'ナラケン', '香芝市', 'カシバシ', '田尻', 'タジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県香芝市関屋北', '29', '29210', '6390254', '奈良県', 'ナラケン', '香芝市', 'カシバシ', '関屋北', 'セキヤキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県香芝市関屋', '29', '29210', '6390255', '奈良県', 'ナラケン', '香芝市', 'カシバシ', '関屋', 'セキヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県香芝市高山台', '29', '29210', '6390256', '奈良県', 'ナラケン', '香芝市', 'カシバシ', '高山台', 'タカヤマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県香芝市尼寺', '29', '29210', '6390261', '奈良県', 'ナラケン', '香芝市', 'カシバシ', '尼寺', 'ニンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県香芝市白鳳台', '29', '29210', '6390262', '奈良県', 'ナラケン', '香芝市', 'カシバシ', '白鳳台', 'ハクホウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県香芝市平野', '29', '29210', '6390263', '奈良県', 'ナラケン', '香芝市', 'カシバシ', '平野', 'ヒラノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県香芝市今泉', '29', '29210', '6390264', '奈良県', 'ナラケン', '香芝市', 'カシバシ', '今泉', 'イマイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県香芝市上中', '29', '29210', '6390265', '奈良県', 'ナラケン', '香芝市', 'カシバシ', '上中', 'カミナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県香芝市旭ケ丘', '29', '29210', '6390266', '奈良県', 'ナラケン', '香芝市', 'カシバシ', '旭ケ丘', 'アサヒガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県葛城市加守', '29', '29211', '6390271', '奈良県', 'ナラケン', '葛城市', 'カツラギシ', '加守', 'カモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県葛城市新在家', '29', '29211', '6390272', '奈良県', 'ナラケン', '葛城市', 'カツラギシ', '新在家', 'シンザイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県葛城市染野', '29', '29211', '6390273', '奈良県', 'ナラケン', '葛城市', 'カツラギシ', '染野', 'ソメノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県葛城市今在家', '29', '29211', '6390274', '奈良県', 'ナラケン', '葛城市', 'カツラギシ', '今在家', 'イマザイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県葛城市勝根', '29', '29211', '6390275', '奈良県', 'ナラケン', '葛城市', 'カツラギシ', '勝根', 'カツネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県葛城市當麻', '29', '29211', '6390276', '奈良県', 'ナラケン', '葛城市', 'カツラギシ', '當麻', 'タイマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市九条町', '29', '29203', '6391001', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '九条町', 'クジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市九条平野町', '29', '29203', '6391002', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '九条平野町', 'クジョウヒラノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市代官町', '29', '29203', '6391003', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '代官町', 'ダイカンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市城北町', '29', '29203', '6391004', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '城北町', 'ジョウホクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市植槻町', '29', '29203', '6391005', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '植槻町', 'ウエツキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市天理町', '29', '29203', '6391006', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '天理町', 'テンリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市南郡山町', '29', '29203', '6391007', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '南郡山町', 'ミナミコオリヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市城の台町', '29', '29203', '6391008', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '城の台町', 'シロノダイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市城内町', '29', '29203', '6391011', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '城内町', 'ジョウナイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市城見町', '29', '29203', '6391012', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '城見町', 'シロミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市朝日町', '29', '29203', '6391013', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '朝日町', 'アサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市西岡町', '29', '29203', '6391014', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '西岡町', 'ニシオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市箕山町', '29', '29203', '6391015', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '箕山町', 'ミノヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市城南町', '29', '29203', '6391016', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '城南町', 'ジョウナンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市藤原町', '29', '29203', '6391017', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '藤原町', 'フジワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市冠山町', '29', '29203', '6391018', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '冠山町', 'カンザンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市永慶寺町', '29', '29203', '6391019', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '永慶寺町', 'エイケイジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市新木町', '29', '29203', '6391021', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '新木町', 'ニキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市豊浦町', '29', '29203', '6391022', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '豊浦町', 'トヨウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市小南町', '29', '29203', '6391023', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '小南町', 'コミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市南井町', '29', '29203', '6391024', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '南井町', 'ミナミイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市北西町', '29', '29203', '6391025', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '北西町', 'キタニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市小林町', '29', '29203', '6391026', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '小林町', 'コバヤシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市池之内町', '29', '29203', '6391027', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '池之内町', 'イケノウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市田中町', '29', '29203', '6391028', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '田中町', 'タナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市今国府町', '29', '29203', '6391031', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '今国府町', 'イマゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市池沢町', '29', '29203', '6391032', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '池沢町', 'イケザワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市昭和町', '29', '29203', '6391033', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '昭和町', 'ショウワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市柏木町', '29', '29203', '6391034', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '柏木町', 'カシワギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市額田部南町', '29', '29203', '6391035', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '額田部南町', 'ヌカタベミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市額田部寺町', '29', '29203', '6391036', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '額田部寺町', 'ヌカタベテラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市額田部北町', '29', '29203', '6391037', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '額田部北町', 'ヌカタベキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市西町', '29', '29203', '6391038', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '西町', 'ニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市椎木町', '29', '29203', '6391039', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '椎木町', 'シギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市満願寺町', '29', '29203', '6391041', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '満願寺町', 'マンガンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市小泉町', '29', '29203', '6391042', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '小泉町', 'コイズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市西田中町', '29', '29203', '6391043', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '西田中町', 'ニシタナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市小泉町東', '29', '29203', '6391044', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '小泉町東', 'コイズミチョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市小林町西', '29', '29203', '6391045', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '小林町西', 'コバヤシチョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市城町', '29', '29203', '6391051', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '城町', 'ジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市外川町', '29', '29203', '6391052', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '外川町', 'トガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市千日町', '29', '29203', '6391053', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '千日町', 'センニチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市新町', '29', '29203', '6391054', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市矢田山町', '29', '29203', '6391055', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '矢田山町', 'ヤタヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市泉原町', '29', '29203', '6391056', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '泉原町', 'イズミハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市山田町', '29', '29203', '6391057', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '山田町', 'ヤマダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市矢田町', '29', '29203', '6391058', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '矢田町', 'ヤタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒郡安堵町東安堵', '29', '29345', '6391061', '奈良県', 'ナラケン', '生駒郡安堵町', 'イコマグンアンドチョウ', '東安堵', 'ヒガシアンド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒郡安堵町岡崎', '29', '29345', '6391062', '奈良県', 'ナラケン', '生駒郡安堵町', 'イコマグンアンドチョウ', '岡崎', 'オカサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒郡安堵町かしの木台', '29', '29345', '6391063', '奈良県', 'ナラケン', '生駒郡安堵町', 'イコマグンアンドチョウ', 'かしの木台', 'カシノキダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒郡安堵町窪田', '29', '29345', '6391064', '奈良県', 'ナラケン', '生駒郡安堵町', 'イコマグンアンドチョウ', '窪田', 'クボタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒郡安堵町笠目', '29', '29345', '6391065', '奈良県', 'ナラケン', '生駒郡安堵町', 'イコマグンアンドチョウ', '笠目', 'カサメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒郡安堵町西安堵', '29', '29345', '6391066', '奈良県', 'ナラケン', '生駒郡安堵町', 'イコマグンアンドチョウ', '西安堵', 'ニシアンド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市', '29', '29203', '6391100', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('74880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県生駒郡安堵町', '29', '29345', '6391100', '奈良県', 'ナラケン', '生駒郡安堵町', 'イコマグンアンドチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('74881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市下三橋町', '29', '29203', '6391101', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '下三橋町', 'シモミツハシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市上三橋町', '29', '29203', '6391102', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '上三橋町', 'カミミツハシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市美濃庄町', '29', '29203', '6391103', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '美濃庄町', 'ミノショウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市井戸野町', '29', '29203', '6391104', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '井戸野町', 'イドノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市番匠田中町', '29', '29203', '6391105', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '番匠田中町', 'バンジョウタナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市大江町', '29', '29203', '6391106', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '大江町', 'オオエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市若槻町', '29', '29203', '6391107', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '若槻町', 'ワカツキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市稗田町', '29', '29203', '6391108', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '稗田町', 'ヒエダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市石川町', '29', '29203', '6391111', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '石川町', 'イシカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市白土町', '29', '29203', '6391112', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '白土町', 'シラツチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市櫟枝町', '29', '29203', '6391113', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '櫟枝町', 'イチエダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市新庄町', '29', '29203', '6391114', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '新庄町', 'シンジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市横田町', '29', '29203', '6391115', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '横田町', 'ヨコタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市伊豆七条町', '29', '29203', '6391116', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '伊豆七条町', 'イズシチジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市番条町', '29', '29203', '6391117', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '番条町', 'バンジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市中城町', '29', '29203', '6391118', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '中城町', 'ナカジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市発志院町', '29', '29203', '6391119', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '発志院町', 'ハツシインチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市杉町', '29', '29203', '6391121', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '杉町', 'スギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市丹後庄町', '29', '29203', '6391122', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '丹後庄町', 'タンゴノショウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市筒井町', '29', '29203', '6391123', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '筒井町', 'ツツイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市馬司町', '29', '29203', '6391124', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '馬司町', 'マツカサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市八条町', '29', '29203', '6391125', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '八条町', 'ハチジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市宮堂町', '29', '29203', '6391126', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '宮堂町', 'ミヤドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市長安寺町', '29', '29203', '6391127', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '長安寺町', 'チョウアンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市野垣内町', '29', '29203', '6391131', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '野垣内町', 'ノガイトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市高田町', '29', '29203', '6391132', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '高田町', 'タカダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市高田口町', '29', '29203', '6391133', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '高田口町', 'タカダグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市柳町', '29', '29203', '6391134', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '柳', 'ヤナギ', null, null, '町', 'マチ');
INSERT INTO `ms_addresses` VALUES ('74909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市天井町', '29', '29203', '6391135', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '天井町', 'テンジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市本庄町', '29', '29203', '6391136', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '本庄町', 'ホンジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市東岡町', '29', '29203', '6391137', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '東岡町', 'ヒガシオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市大宮町', '29', '29203', '6391138', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '大宮町', 'オオミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市材木町', '29', '29203', '6391141', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '材木町', 'ザイモクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市矢田町通', '29', '29203', '6391142', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '矢田町通', 'ヤタマチドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市新紺屋町', '29', '29203', '6391143', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '新紺屋町', 'シンコンヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市洞泉寺町', '29', '29203', '6391144', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '洞泉寺町', 'トウセンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市南大工町', '29', '29203', '6391145', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '南大工町', 'ミナミダイクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市北大工町', '29', '29203', '6391146', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '北大工町', 'キタダイクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市車町', '29', '29203', '6391147', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '車町', 'クルママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市紺屋町', '29', '29203', '6391148', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '紺屋町', 'コンヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市豆腐町', '29', '29203', '6391149', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '豆腐町', 'トウフマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市雑穀町', '29', '29203', '6391150', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '雑穀町', 'ザコクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市本町', '29', '29203', '6391151', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市茶町', '29', '29203', '6391152', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '茶町', 'チャマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市西野垣内町', '29', '29203', '6391153', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '西野垣内町', 'ニシノガイトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市綿町', '29', '29203', '6391154', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '綿町', 'ワタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市今井町', '29', '29203', '6391155', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '今井町', 'イマイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市堺町', '29', '29203', '6391156', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '堺町', 'サカイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市新中町', '29', '29203', '6391157', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '新中町', 'シンナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市藺町', '29', '29203', '6391158', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '藺町', 'イノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市奈良町', '29', '29203', '6391159', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '奈良町', 'ナラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市北郡山町', '29', '29203', '6391160', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '北郡山町', 'キタコオリヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市観音寺町', '29', '29203', '6391161', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '観音寺町', 'カンノンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市東奈良口町', '29', '29203', '6391162', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '東奈良口町', 'ヒガシナラグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市西奈良口町', '29', '29203', '6391163', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '西奈良口町', 'ニシナラグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市西観音寺町', '29', '29203', '6391164', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '西観音寺町', 'ニシカンノンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市北鍛冶町', '29', '29203', '6391165', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '北鍛冶町', 'キタカジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市中鍛冶町', '29', '29203', '6391166', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '中鍛冶町', 'ナカカジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市南鍛冶町', '29', '29203', '6391167', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '南鍛冶町', 'ミナミカジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市魚町', '29', '29203', '6391168', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '魚町', 'ウオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県大和郡山市塩町', '29', '29203', '6391169', '奈良県', 'ナラケン', '大和郡山市', 'ヤマトコオリヤマシ', '塩町', 'シオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県葛城市', '29', '29211', '6392100', '奈良県', 'ナラケン', '葛城市', 'カツラギシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('74950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県葛城市疋田', '29', '29211', '6392101', '奈良県', 'ナラケン', '葛城市', 'カツラギシ', '疋田', 'ヒキダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県葛城市東室', '29', '29211', '6392102', '奈良県', 'ナラケン', '葛城市', 'カツラギシ', '東室', 'ヒガシムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県葛城市西室', '29', '29211', '6392103', '奈良県', 'ナラケン', '葛城市', 'カツラギシ', '西室', 'ニシムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県葛城市柿本', '29', '29211', '6392111', '奈良県', 'ナラケン', '葛城市', 'カツラギシ', '柿本', 'カキノモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県葛城市笛堂', '29', '29211', '6392112', '奈良県', 'ナラケン', '葛城市', 'カツラギシ', '笛堂', 'フエドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県葛城市北花内', '29', '29211', '6392113', '奈良県', 'ナラケン', '葛城市', 'カツラギシ', '北花内', 'キタハナウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県葛城市新村', '29', '29211', '6392121', '奈良県', 'ナラケン', '葛城市', 'カツラギシ', '新村', 'シムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県葛城市薑', '29', '29211', '6392122', '奈良県', 'ナラケン', '葛城市', 'カツラギシ', '薑', 'ハジカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県葛城市忍海', '29', '29211', '6392123', '奈良県', 'ナラケン', '葛城市', 'カツラギシ', '忍海', 'オシミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県葛城市南新町', '29', '29211', '6392123', '奈良県', 'ナラケン', '葛城市', 'カツラギシ', '南新町', 'ミナミシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県葛城市脇田', '29', '29211', '6392124', '奈良県', 'ナラケン', '葛城市', 'カツラギシ', '脇田', 'ワキダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県葛城市西辻', '29', '29211', '6392125', '奈良県', 'ナラケン', '葛城市', 'カツラギシ', '西辻', 'ニシツジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県葛城市南花内', '29', '29211', '6392126', '奈良県', 'ナラケン', '葛城市', 'カツラギシ', '南花内', 'ミナミハナウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県葛城市新町', '29', '29211', '6392127', '奈良県', 'ナラケン', '葛城市', 'カツラギシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県葛城市林堂', '29', '29211', '6392131', '奈良県', 'ナラケン', '葛城市', 'カツラギシ', '林堂', 'ハヤシドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県葛城市笛吹', '29', '29211', '6392132', '奈良県', 'ナラケン', '葛城市', 'カツラギシ', '笛吹', 'フエフキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県葛城市梅室', '29', '29211', '6392133', '奈良県', 'ナラケン', '葛城市', 'カツラギシ', '梅室', 'ウメムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県葛城市山口', '29', '29211', '6392134', '奈良県', 'ナラケン', '葛城市', 'カツラギシ', '山口', 'ヤマグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県葛城市寺口', '29', '29211', '6392135', '奈良県', 'ナラケン', '葛城市', 'カツラギシ', '寺口', 'テラグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県葛城市平岡', '29', '29211', '6392136', '奈良県', 'ナラケン', '葛城市', 'カツラギシ', '平岡', 'ヒラオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県葛城市南藤井', '29', '29211', '6392137', '奈良県', 'ナラケン', '葛城市', 'カツラギシ', '南藤井', 'ミナミフジイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県葛城市山田', '29', '29211', '6392138', '奈良県', 'ナラケン', '葛城市', 'カツラギシ', '山田', 'ヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県葛城市弁之庄', '29', '29211', '6392141', '奈良県', 'ナラケン', '葛城市', 'カツラギシ', '弁之庄', 'ベンノショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県葛城市北道穂', '29', '29211', '6392142', '奈良県', 'ナラケン', '葛城市', 'カツラギシ', '北道穂', 'キタミツボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県葛城市南道穂', '29', '29211', '6392143', '奈良県', 'ナラケン', '葛城市', 'カツラギシ', '南道穂', 'ミナミミツボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県葛城市葛木', '29', '29211', '6392144', '奈良県', 'ナラケン', '葛城市', 'カツラギシ', '葛木', 'カツラギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県葛城市大屋', '29', '29211', '6392145', '奈良県', 'ナラケン', '葛城市', 'カツラギシ', '大屋', 'オオヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県葛城市中戸', '29', '29211', '6392146', '奈良県', 'ナラケン', '葛城市', 'カツラギシ', '中戸', 'ナカト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県葛城市新庄', '29', '29211', '6392147', '奈良県', 'ナラケン', '葛城市', 'カツラギシ', '新庄', 'シンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県葛城市南今市', '29', '29211', '6392151', '奈良県', 'ナラケン', '葛城市', 'カツラギシ', '南今市', 'ミナミイマイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県葛城市大畑', '29', '29211', '6392152', '奈良県', 'ナラケン', '葛城市', 'カツラギシ', '大畑', 'オバタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県葛城市太田', '29', '29211', '6392153', '奈良県', 'ナラケン', '葛城市', 'カツラギシ', '太田', 'オオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県葛城市兵家', '29', '29211', '6392154', '奈良県', 'ナラケン', '葛城市', 'カツラギシ', '兵家', 'ヒョウゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県葛城市竹内', '29', '29211', '6392155', '奈良県', 'ナラケン', '葛城市', 'カツラギシ', '竹内', 'タケノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県葛城市木戸', '29', '29211', '6392161', '奈良県', 'ナラケン', '葛城市', 'カツラギシ', '木戸', 'キド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県葛城市尺土', '29', '29211', '6392162', '奈良県', 'ナラケン', '葛城市', 'カツラギシ', '尺土', 'シャクド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県葛城市八川', '29', '29211', '6392163', '奈良県', 'ナラケン', '葛城市', 'カツラギシ', '八川', 'ハチガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県葛城市長尾', '29', '29211', '6392164', '奈良県', 'ナラケン', '葛城市', 'カツラギシ', '長尾', 'ナガオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県御所市', '29', '29208', '6392200', '奈良県', 'ナラケン', '御所市', 'ゴセシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('74992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県御所市柳原', '29', '29208', '6392201', '奈良県', 'ナラケン', '御所市', 'ゴセシ', '柳原', 'ヤナギハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県御所市出屋敷', '29', '29208', '6392202', '奈良県', 'ナラケン', '御所市', 'ゴセシ', '出屋敷', 'デヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県御所市北十三', '29', '29208', '6392203', '奈良県', 'ナラケン', '御所市', 'ゴセシ', '北十三', 'キタジュウソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県御所市南十三', '29', '29208', '6392204', '奈良県', 'ナラケン', '御所市', 'ゴセシ', '南十三', 'ミナミジュウソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県御所市東辻', '29', '29208', '6392205', '奈良県', 'ナラケン', '御所市', 'ゴセシ', '東辻', 'ヒガシツジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県御所市竹田', '29', '29208', '6392206', '奈良県', 'ナラケン', '御所市', 'ゴセシ', '竹田', 'タケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県御所市今城', '29', '29208', '6392207', '奈良県', 'ナラケン', '御所市', 'ゴセシ', '今城', 'イマンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('74999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県御所市国鉄御所駅前通り', '29', '29208', '6392211', '奈良県', 'ナラケン', '御所市', 'ゴセシ', '国鉄御所駅前通り', 'コクテツゴセエキマエドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県御所市中央通り', '29', '29208', '6392212', '奈良県', 'ナラケン', '御所市', 'ゴセシ', '中央通り', 'チュウオウドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県御所市神宮町', '29', '29208', '6392213', '奈良県', 'ナラケン', '御所市', 'ゴセシ', '神宮町', 'シングウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県御所市御堂魚棚町', '29', '29208', '6392214', '奈良県', 'ナラケン', '御所市', 'ゴセシ', '御堂魚棚町', 'ミドウウオタナマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県御所市西町', '29', '29208', '6392215', '奈良県', 'ナラケン', '御所市', 'ゴセシ', '西町', 'ニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県御所市御国通り', '29', '29208', '6392216', '奈良県', 'ナラケン', '御所市', 'ゴセシ', '御国通り', 'ミクニドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県御所市新地町', '29', '29208', '6392217', '奈良県', 'ナラケン', '御所市', 'ゴセシ', '新地町', 'シンチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県御所市栄町', '29', '29208', '6392221', '奈良県', 'ナラケン', '御所市', 'ゴセシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県御所市六軒町', '29', '29208', '6392222', '奈良県', 'ナラケン', '御所市', 'ゴセシ', '六軒町', 'ロッケンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県御所市本町', '29', '29208', '6392223', '奈良県', 'ナラケン', '御所市', 'ゴセシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県御所市西柏町', '29', '29208', '6392224', '奈良県', 'ナラケン', '御所市', 'ゴセシ', '西柏町', 'サイカシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県御所市中本町', '29', '29208', '6392225', '奈良県', 'ナラケン', '御所市', 'ゴセシ', '中本町', 'ナカホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県御所市南中町', '29', '29208', '6392226', '奈良県', 'ナラケン', '御所市', 'ゴセシ', '南中町', 'ミナミナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県御所市東久保町', '29', '29208', '6392227', '奈良県', 'ナラケン', '御所市', 'ゴセシ', '東久保町', 'ヒガシクボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県御所市西久保本町', '29', '29208', '6392228', '奈良県', 'ナラケン', '御所市', 'ゴセシ', '西久保本町', 'ニシクボホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県御所市鴨口町', '29', '29208', '6392229', '奈良県', 'ナラケン', '御所市', 'ゴセシ', '鴨口町', 'カモグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県御所市柿ケ坪町', '29', '29208', '6392231', '奈良県', 'ナラケン', '御所市', 'ゴセシ', '柿ケ坪町', 'カキガツボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県御所市御門町', '29', '29208', '6392232', '奈良県', 'ナラケン', '御所市', 'ゴセシ', '御門町', 'ミカドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県御所市都町', '29', '29208', '6392233', '奈良県', 'ナラケン', '御所市', 'ゴセシ', '都町', 'ミヤコマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県御所市柳町', '29', '29208', '6392234', '奈良県', 'ナラケン', '御所市', 'ゴセシ', '柳町', 'ヤナギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県御所市寺内町', '29', '29208', '6392235', '奈良県', 'ナラケン', '御所市', 'ゴセシ', '寺内町', 'ジナイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県御所市代官町', '29', '29208', '6392236', '奈良県', 'ナラケン', '御所市', 'ゴセシ', '代官町', 'ダイカンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県御所市豊年橋通り', '29', '29208', '6392237', '奈良県', 'ナラケン', '御所市', 'ゴセシ', '豊年橋通り', 'ホウネンバシドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県御所市大橋通り', '29', '29208', '6392238', '奈良県', 'ナラケン', '御所市', 'ゴセシ', '大橋通り', 'オオハシドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県御所市旭町', '29', '29208', '6392239', '奈良県', 'ナラケン', '御所市', 'ゴセシ', '旭町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県御所市茅原', '29', '29208', '6392241', '奈良県', 'ナラケン', '御所市', 'ゴセシ', '茅原', 'チハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県御所市本馬', '29', '29208', '6392242', '奈良県', 'ナラケン', '御所市', 'ゴセシ', '本馬', 'ホンマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県御所市東寺田', '29', '29208', '6392243', '奈良県', 'ナラケン', '御所市', 'ゴセシ', '東寺田', 'ヒガシテラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県御所市柏原', '29', '29208', '6392244', '奈良県', 'ナラケン', '御所市', 'ゴセシ', '柏原', 'カシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県御所市今住', '29', '29208', '6392245', '奈良県', 'ナラケン', '御所市', 'ゴセシ', '今住', 'イマズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県御所市原谷', '29', '29208', '6392246', '奈良県', 'ナラケン', '御所市', 'ゴセシ', '原谷', 'ハラダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県御所市玉手', '29', '29208', '6392247', '奈良県', 'ナラケン', '御所市', 'ゴセシ', '玉手', 'タマデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県御所市緑町', '29', '29208', '6392248', '奈良県', 'ナラケン', '御所市', 'ゴセシ', '緑町', 'ミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県御所市戸毛', '29', '29208', '6392251', '奈良県', 'ナラケン', '御所市', 'ゴセシ', '戸毛', 'トウゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県御所市樋野', '29', '29208', '6392252', '奈良県', 'ナラケン', '御所市', 'ゴセシ', '樋野', 'ヒノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県御所市奉膳', '29', '29208', '6392253', '奈良県', 'ナラケン', '御所市', 'ゴセシ', '奉膳', 'ブンゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県御所市古瀬', '29', '29208', '6392254', '奈良県', 'ナラケン', '御所市', 'ゴセシ', '古瀬', 'コセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県御所市朝町', '29', '29208', '6392255', '奈良県', 'ナラケン', '御所市', 'ゴセシ', '朝町', 'アサマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県御所市栗阪', '29', '29208', '6392256', '奈良県', 'ナラケン', '御所市', 'ゴセシ', '栗阪', 'クリサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県御所市小殿', '29', '29208', '6392257', '奈良県', 'ナラケン', '御所市', 'ゴセシ', '小殿', 'オドノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県御所市稲宿', '29', '29208', '6392258', '奈良県', 'ナラケン', '御所市', 'ゴセシ', '稲宿', 'イナイド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県御所市城山台', '29', '29208', '6392261', '奈良県', 'ナラケン', '御所市', 'ゴセシ', '城山台', 'シロヤマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県御所市東持田', '29', '29208', '6392262', '奈良県', 'ナラケン', '御所市', 'ゴセシ', '東持田', 'ヒガシモッタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県御所市持田', '29', '29208', '6392262', '奈良県', 'ナラケン', '御所市', 'ゴセシ', '持田', 'モッタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県御所市鳥井戸', '29', '29208', '6392263', '奈良県', 'ナラケン', '御所市', 'ゴセシ', '鳥井戸', 'トリイド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県御所市五百家', '29', '29208', '6392264', '奈良県', 'ナラケン', '御所市', 'ゴセシ', '五百家', 'イウカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県御所市新田', '29', '29208', '6392265', '奈良県', 'ナラケン', '御所市', 'ゴセシ', '新田', 'シンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県御所市重阪', '29', '29208', '6392266', '奈良県', 'ナラケン', '御所市', 'ゴセシ', '重阪', 'ヘイサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県御所市内谷', '29', '29208', '6392267', '奈良県', 'ナラケン', '御所市', 'ゴセシ', '内谷', 'ウチタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県御所市船路', '29', '29208', '6392268', '奈良県', 'ナラケン', '御所市', 'ゴセシ', '船路', 'フナジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県御所市宮前町', '29', '29208', '6392271', '奈良県', 'ナラケン', '御所市', 'ゴセシ', '宮前町', 'ミヤマエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県御所市蛇穴', '29', '29208', '6392272', '奈良県', 'ナラケン', '御所市', 'ゴセシ', '蛇穴', 'サラギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県御所市池之内', '29', '29208', '6392273', '奈良県', 'ナラケン', '御所市', 'ゴセシ', '池之内', 'イケノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県御所市冨田', '29', '29208', '6392274', '奈良県', 'ナラケン', '御所市', 'ゴセシ', '冨田', 'トミタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県御所市出走', '29', '29208', '6392275', '奈良県', 'ナラケン', '御所市', 'ゴセシ', '出走', 'デハシリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県御所市條', '29', '29208', '6392276', '奈良県', 'ナラケン', '御所市', 'ゴセシ', '條', 'ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県御所市室', '29', '29208', '6392277', '奈良県', 'ナラケン', '御所市', 'ゴセシ', '室', 'ムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県御所市緑ケ丘', '29', '29208', '6392278', '奈良県', 'ナラケン', '御所市', 'ゴセシ', '緑ケ丘', 'ミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県御所市今出', '29', '29208', '6392279', '奈良県', 'ナラケン', '御所市', 'ゴセシ', '今出', 'イマデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県御所市元町', '29', '29208', '6392301', '奈良県', 'ナラケン', '御所市', 'ゴセシ', '元町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県御所市東松本', '29', '29208', '6392302', '奈良県', 'ナラケン', '御所市', 'ゴセシ', '東松本', 'ヒガシマツモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県御所市末広町', '29', '29208', '6392303', '奈良県', 'ナラケン', '御所市', 'ゴセシ', '末広町', 'スエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県御所市大広町', '29', '29208', '6392304', '奈良県', 'ナラケン', '御所市', 'ゴセシ', '大広町', 'オオヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県御所市柳田町', '29', '29208', '6392305', '奈良県', 'ナラケン', '御所市', 'ゴセシ', '柳田町', 'ヤナギダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県御所市三室', '29', '29208', '6392306', '奈良県', 'ナラケン', '御所市', 'ゴセシ', '三室', 'ミムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県御所市小林', '29', '29208', '6392311', '奈良県', 'ナラケン', '御所市', 'ゴセシ', '小林', 'コバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県御所市櫛羅', '29', '29208', '6392312', '奈良県', 'ナラケン', '御所市', 'ゴセシ', '櫛羅', 'クジラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県御所市楢原', '29', '29208', '6392313', '奈良県', 'ナラケン', '御所市', 'ゴセシ', '楢原', 'ナラバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県御所市幸町', '29', '29208', '6392314', '奈良県', 'ナラケン', '御所市', 'ゴセシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県御所市宮戸', '29', '29208', '6392315', '奈良県', 'ナラケン', '御所市', 'ゴセシ', '宮戸', 'ミヤド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県御所市西寺田', '29', '29208', '6392316', '奈良県', 'ナラケン', '御所市', 'ゴセシ', '西寺田', 'ニシテラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県御所市豊田', '29', '29208', '6392317', '奈良県', 'ナラケン', '御所市', 'ゴセシ', '豊田', 'トヨダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県御所市森脇', '29', '29208', '6392318', '奈良県', 'ナラケン', '御所市', 'ゴセシ', '森脇', 'モリワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県御所市名柄', '29', '29208', '6392321', '奈良県', 'ナラケン', '御所市', 'ゴセシ', '名柄', 'ナガラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県御所市東名柄', '29', '29208', '6392322', '奈良県', 'ナラケン', '御所市', 'ゴセシ', '東名柄', 'ヒガシナガラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県御所市多田', '29', '29208', '6392323', '奈良県', 'ナラケン', '御所市', 'ゴセシ', '多田', 'オイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県御所市下茶屋', '29', '29208', '6392324', '奈良県', 'ナラケン', '御所市', 'ゴセシ', '下茶屋', 'シモノチャヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県御所市佐田', '29', '29208', '6392325', '奈良県', 'ナラケン', '御所市', 'ゴセシ', '佐田', 'サダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県御所市井戸', '29', '29208', '6392326', '奈良県', 'ナラケン', '御所市', 'ゴセシ', '井戸', 'イド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県御所市増', '29', '29208', '6392327', '奈良県', 'ナラケン', '御所市', 'ゴセシ', '増', 'マシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県御所市関屋', '29', '29208', '6392328', '奈良県', 'ナラケン', '御所市', 'ゴセシ', '関屋', 'セキヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県御所市南郷', '29', '29208', '6392331', '奈良県', 'ナラケン', '御所市', 'ゴセシ', '南郷', 'ナンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県御所市西持田', '29', '29208', '6392332', '奈良県', 'ナラケン', '御所市', 'ゴセシ', '西持田', 'ニシモッタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県御所市林', '29', '29208', '6392333', '奈良県', 'ナラケン', '御所市', 'ゴセシ', '林', 'ハヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県御所市北窪', '29', '29208', '6392334', '奈良県', 'ナラケン', '御所市', 'ゴセシ', '北窪', 'キタクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県御所市西北窪', '29', '29208', '6392335', '奈良県', 'ナラケン', '御所市', 'ゴセシ', '西北窪', 'ニシキタクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県御所市高天', '29', '29208', '6392336', '奈良県', 'ナラケン', '御所市', 'ゴセシ', '高天', 'タカマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県御所市極楽寺', '29', '29208', '6392337', '奈良県', 'ナラケン', '御所市', 'ゴセシ', '極楽寺', 'ゴクラクジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県御所市朝妻', '29', '29208', '6392341', '奈良県', 'ナラケン', '御所市', 'ゴセシ', '朝妻', 'アサヅマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県御所市僧堂', '29', '29208', '6392342', '奈良県', 'ナラケン', '御所市', 'ゴセシ', '僧堂', 'ソウドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県御所市鴨神', '29', '29208', '6392343', '奈良県', 'ナラケン', '御所市', 'ゴセシ', '鴨神', 'カモガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県御所市東佐味', '29', '29208', '6392344', '奈良県', 'ナラケン', '御所市', 'ゴセシ', '東佐味', 'ヒガシサビ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県御所市西佐味', '29', '29208', '6392345', '奈良県', 'ナラケン', '御所市', 'ゴセシ', '西佐味', 'ニシサビ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県御所市伏見', '29', '29208', '6392346', '奈良県', 'ナラケン', '御所市', 'ゴセシ', '伏見', 'フシミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡吉野町', '29', '29441', '6393100', '奈良県', 'ナラケン', '吉野郡吉野町', 'ヨシノグンヨシノチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('75097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡吉野町山口', '29', '29441', '6393101', '奈良県', 'ナラケン', '吉野郡吉野町', 'ヨシノグンヨシノチョウ', '山口', 'ヤマグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡吉野町河原屋', '29', '29441', '6393102', '奈良県', 'ナラケン', '吉野郡吉野町', 'ヨシノグンヨシノチョウ', '河原屋', 'カワハラヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡吉野町津風呂', '29', '29441', '6393102', '奈良県', 'ナラケン', '吉野郡吉野町', 'ヨシノグンヨシノチョウ', '津風呂', 'ツブロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡吉野町平尾', '29', '29441', '6393103', '奈良県', 'ナラケン', '吉野郡吉野町', 'ヨシノグンヨシノチョウ', '平尾', 'ヒラオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡吉野町峰寺', '29', '29441', '6393104', '奈良県', 'ナラケン', '吉野郡吉野町', 'ヨシノグンヨシノチョウ', '峰寺', 'ミネデラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡吉野町千股', '29', '29441', '6393105', '奈良県', 'ナラケン', '吉野郡吉野町', 'ヨシノグンヨシノチョウ', '千股', 'チマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡吉野町志賀', '29', '29441', '6393106', '奈良県', 'ナラケン', '吉野郡吉野町', 'ヨシノグンヨシノチョウ', '志賀', 'シガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡吉野町滝畑', '29', '29441', '6393106', '奈良県', 'ナラケン', '吉野郡吉野町', 'ヨシノグンヨシノチョウ', '滝畑', 'タキハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡吉野町佐々羅', '29', '29441', '6393107', '奈良県', 'ナラケン', '吉野郡吉野町', 'ヨシノグンヨシノチョウ', '佐々羅', 'ササラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡吉野町西谷', '29', '29441', '6393108', '奈良県', 'ナラケン', '吉野郡吉野町', 'ヨシノグンヨシノチョウ', '西谷', 'ニシタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡吉野町三津', '29', '29441', '6393108', '奈良県', 'ナラケン', '吉野郡吉野町', 'ヨシノグンヨシノチョウ', '三津', 'ミヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡吉野町上市', '29', '29441', '6393111', '奈良県', 'ナラケン', '吉野郡吉野町', 'ヨシノグンヨシノチョウ', '上市', 'カミイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡吉野町立野', '29', '29441', '6393112', '奈良県', 'ナラケン', '吉野郡吉野町', 'ヨシノグンヨシノチョウ', '立野', 'タチノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡吉野町飯貝', '29', '29441', '6393113', '奈良県', 'ナラケン', '吉野郡吉野町', 'ヨシノグンヨシノチョウ', '飯貝', 'イイガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡吉野町丹治', '29', '29441', '6393114', '奈良県', 'ナラケン', '吉野郡吉野町', 'ヨシノグンヨシノチョウ', '丹治', 'タンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡吉野町吉野山', '29', '29441', '6393115', '奈良県', 'ナラケン', '吉野郡吉野町', 'ヨシノグンヨシノチョウ', '吉野山', 'ヨシノヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡吉野町六田', '29', '29441', '6393116', '奈良県', 'ナラケン', '吉野郡吉野町', 'ヨシノグンヨシノチョウ', '六田', 'ムダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡吉野町左曽', '29', '29441', '6393117', '奈良県', 'ナラケン', '吉野郡吉野町', 'ヨシノグンヨシノチョウ', '左曽', 'サソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡吉野町橋屋', '29', '29441', '6393118', '奈良県', 'ナラケン', '吉野郡吉野町', 'ヨシノグンヨシノチョウ', '橋屋', 'ハシヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡大淀町西増', '29', '29442', '6393121', '奈良県', 'ナラケン', '吉野郡大淀町', 'ヨシノグンオオヨドチョウ', '西増', 'ニシマシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡大淀町中増', '29', '29442', '6393122', '奈良県', 'ナラケン', '吉野郡大淀町', 'ヨシノグンオオヨドチョウ', '中増', 'ナカマシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡大淀町増口', '29', '29442', '6393123', '奈良県', 'ナラケン', '吉野郡大淀町', 'ヨシノグンオオヨドチョウ', '増口', 'マシグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡大淀町北六田', '29', '29442', '6393124', '奈良県', 'ナラケン', '吉野郡大淀町', 'ヨシノグンオオヨドチョウ', '北六田', 'キタムダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡大淀町北野', '29', '29442', '6393125', '奈良県', 'ナラケン', '吉野郡大淀町', 'ヨシノグンオオヨドチョウ', '北野', 'キタノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡大淀町新野', '29', '29442', '6393126', '奈良県', 'ナラケン', '吉野郡大淀町', 'ヨシノグンオオヨドチョウ', '新野', 'ニノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡大淀町馬佐', '29', '29442', '6393127', '奈良県', 'ナラケン', '吉野郡大淀町', 'ヨシノグンオオヨドチョウ', '馬佐', 'バサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡大淀町比曽', '29', '29442', '6393128', '奈良県', 'ナラケン', '吉野郡大淀町', 'ヨシノグンオオヨドチョウ', '比曽', 'ヒソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡吉野町三茶屋', '29', '29441', '6393321', '奈良県', 'ナラケン', '吉野郡吉野町', 'ヨシノグンヨシノチョウ', '三茶屋', 'ミツチャヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡吉野町小名', '29', '29441', '6393322', '奈良県', 'ナラケン', '吉野郡吉野町', 'ヨシノグンヨシノチョウ', '小名', 'コナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡吉野町色生', '29', '29441', '6393323', '奈良県', 'ナラケン', '吉野郡吉野町', 'ヨシノグンヨシノチョウ', '色生', 'イロウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡吉野町香束', '29', '29441', '6393324', '奈良県', 'ナラケン', '吉野郡吉野町', 'ヨシノグンヨシノチョウ', '香束', 'コウソク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡吉野町柳', '29', '29441', '6393325', '奈良県', 'ナラケン', '吉野郡吉野町', 'ヨシノグンヨシノチョウ', '柳', 'ヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡吉野町入野', '29', '29441', '6393431', '奈良県', 'ナラケン', '吉野郡吉野町', 'ヨシノグンヨシノチョウ', '入野', 'シオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡吉野町窪垣内', '29', '29441', '6393432', '奈良県', 'ナラケン', '吉野郡吉野町', 'ヨシノグンヨシノチョウ', '窪垣内', 'クボガイト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡吉野町新子', '29', '29441', '6393433', '奈良県', 'ナラケン', '吉野郡吉野町', 'ヨシノグンヨシノチョウ', '新子', 'アタラシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡吉野町国栖', '29', '29441', '6393434', '奈良県', 'ナラケン', '吉野郡吉野町', 'ヨシノグンヨシノチョウ', '国栖', 'クズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡吉野町南国栖', '29', '29441', '6393435', '奈良県', 'ナラケン', '吉野郡吉野町', 'ヨシノグンヨシノチョウ', '南国栖', 'ミナミクズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡吉野町樫尾', '29', '29441', '6393436', '奈良県', 'ナラケン', '吉野郡吉野町', 'ヨシノグンヨシノチョウ', '樫尾', 'カシオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡吉野町南大野', '29', '29441', '6393437', '奈良県', 'ナラケン', '吉野郡吉野町', 'ヨシノグンヨシノチョウ', '南大野', 'ミナミオオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡吉野町矢治', '29', '29441', '6393441', '奈良県', 'ナラケン', '吉野郡吉野町', 'ヨシノグンヨシノチョウ', '矢治', 'ヤジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡吉野町喜佐谷', '29', '29441', '6393442', '奈良県', 'ナラケン', '吉野郡吉野町', 'ヨシノグンヨシノチョウ', '喜佐谷', 'キサダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡吉野町宮滝', '29', '29441', '6393443', '奈良県', 'ナラケン', '吉野郡吉野町', 'ヨシノグンヨシノチョウ', '宮滝', 'ミヤタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡吉野町御園', '29', '29441', '6393444', '奈良県', 'ナラケン', '吉野郡吉野町', 'ヨシノグンヨシノチョウ', '御園', 'ミソノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡吉野町楢井', '29', '29441', '6393445', '奈良県', 'ナラケン', '吉野郡吉野町', 'ヨシノグンヨシノチョウ', '楢井', 'ナライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡吉野町菜摘', '29', '29441', '6393446', '奈良県', 'ナラケン', '吉野郡吉野町', 'ヨシノグンヨシノチョウ', '菜摘', 'ナツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡川上村', '29', '29452', '6393500', '奈良県', 'ナラケン', '吉野郡川上村', 'ヨシノグンカワカミムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('75144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡川上村東川', '29', '29452', '6393541', '奈良県', 'ナラケン', '吉野郡川上村', 'ヨシノグンカワカミムラ', '東川', 'ウノガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡川上村西河', '29', '29452', '6393542', '奈良県', 'ナラケン', '吉野郡川上村', 'ヨシノグンカワカミムラ', '西河', 'ニシガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡川上村大滝', '29', '29452', '6393543', '奈良県', 'ナラケン', '吉野郡川上村', 'ヨシノグンカワカミムラ', '大滝', 'オオタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡川上村寺尾', '29', '29452', '6393551', '奈良県', 'ナラケン', '吉野郡川上村', 'ヨシノグンカワカミムラ', '寺尾', 'テラオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡川上村北塩谷', '29', '29452', '6393552', '奈良県', 'ナラケン', '吉野郡川上村', 'ヨシノグンカワカミムラ', '北塩谷', 'キタシオダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡川上村迫', '29', '29452', '6393553', '奈良県', 'ナラケン', '吉野郡川上村', 'ヨシノグンカワカミムラ', '迫', 'サコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡川上村高原', '29', '29452', '6393554', '奈良県', 'ナラケン', '吉野郡川上村', 'ヨシノグンカワカミムラ', '高原', 'タカハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡川上村白屋', '29', '29452', '6393555', '奈良県', 'ナラケン', '吉野郡川上村', 'ヨシノグンカワカミムラ', '白屋', 'シラヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡川上村高原土場', '29', '29452', '6393556', '奈良県', 'ナラケン', '吉野郡川上村', 'ヨシノグンカワカミムラ', '高原土場', 'タカハラドバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡川上村人知', '29', '29452', '6393557', '奈良県', 'ナラケン', '吉野郡川上村', 'ヨシノグンカワカミムラ', '人知', 'ヒトジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡川上村井戸', '29', '29452', '6393558', '奈良県', 'ナラケン', '吉野郡川上村', 'ヨシノグンカワカミムラ', '井戸', 'イド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡川上村柏木', '29', '29452', '6393601', '奈良県', 'ナラケン', '吉野郡川上村', 'ヨシノグンカワカミムラ', '柏木', 'カシワギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡川上村上多古', '29', '29452', '6393602', '奈良県', 'ナラケン', '吉野郡川上村', 'ヨシノグンカワカミムラ', '上多古', 'コウダコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡川上村北和田', '29', '29452', '6393603', '奈良県', 'ナラケン', '吉野郡川上村', 'ヨシノグンカワカミムラ', '北和田', 'キタワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡川上村上谷', '29', '29452', '6393604', '奈良県', 'ナラケン', '吉野郡川上村', 'ヨシノグンカワカミムラ', '上谷', 'コウダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡川上村入之波', '29', '29452', '6393611', '奈良県', 'ナラケン', '吉野郡川上村', 'ヨシノグンカワカミムラ', '入之波', 'シオノハ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡川上村大迫', '29', '29452', '6393612', '奈良県', 'ナラケン', '吉野郡川上村', 'ヨシノグンカワカミムラ', '大迫', 'オオサコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡川上村伯母谷', '29', '29452', '6393613', '奈良県', 'ナラケン', '吉野郡川上村', 'ヨシノグンカワカミムラ', '伯母谷', 'オバタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡川上村下多古', '29', '29452', '6393621', '奈良県', 'ナラケン', '吉野郡川上村', 'ヨシノグンカワカミムラ', '下多古', 'シモタコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡川上村井戸ネジ畑', '29', '29452', '6393622', '奈良県', 'ナラケン', '吉野郡川上村', 'ヨシノグンカワカミムラ', '井戸', 'イド', null, null, 'ネジ畑', 'ネジバタ');
INSERT INTO `ms_addresses` VALUES ('75165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡川上村武木', '29', '29452', '6393622', '奈良県', 'ナラケン', '吉野郡川上村', 'ヨシノグンカワカミムラ', '武木', 'タキギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡川上村井光', '29', '29452', '6393623', '奈良県', 'ナラケン', '吉野郡川上村', 'ヨシノグンカワカミムラ', '井光', 'イカリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡川上村白川渡', '29', '29452', '6393631', '奈良県', 'ナラケン', '吉野郡川上村', 'ヨシノグンカワカミムラ', '白川渡', 'シラカワド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡川上村枌尾', '29', '29452', '6393632', '奈良県', 'ナラケン', '吉野郡川上村', 'ヨシノグンカワカミムラ', '枌尾', 'ソギオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡川上村中奥', '29', '29452', '6393633', '奈良県', 'ナラケン', '吉野郡川上村', 'ヨシノグンカワカミムラ', '中奥', 'ナカオク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡川上村瀬戸', '29', '29452', '6393634', '奈良県', 'ナラケン', '吉野郡川上村', 'ヨシノグンカワカミムラ', '瀬戸', 'セト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡川上村神之谷', '29', '29452', '6393635', '奈良県', 'ナラケン', '吉野郡川上村', 'ヨシノグンカワカミムラ', '神之谷', 'コウノタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡上北山村', '29', '29451', '6393700', '奈良県', 'ナラケン', '吉野郡上北山村', 'ヨシノグンカミキタヤマムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('75173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡上北山村河合', '29', '29451', '6393701', '奈良県', 'ナラケン', '吉野郡上北山村', 'ヨシノグンカミキタヤマムラ', '河合', 'カワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡上北山村小橡', '29', '29451', '6393702', '奈良県', 'ナラケン', '吉野郡上北山村', 'ヨシノグンカミキタヤマムラ', '小橡', 'コトチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡上北山村白川', '29', '29451', '6393703', '奈良県', 'ナラケン', '吉野郡上北山村', 'ヨシノグンカミキタヤマムラ', '白川', 'シラカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡上北山村西原', '29', '29451', '6393704', '奈良県', 'ナラケン', '吉野郡上北山村', 'ヨシノグンカミキタヤマムラ', '西原', 'ニシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡上北山村東ノ川', '29', '29451', '6393705', '奈良県', 'ナラケン', '吉野郡上北山村', 'ヨシノグンカミキタヤマムラ', '東ノ川', 'ヒガシノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡下北山村', '29', '29450', '6393800', '奈良県', 'ナラケン', '吉野郡下北山村', 'ヨシノグンシモキタヤマムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('75179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡下北山村佐田', '29', '29450', '6393801', '奈良県', 'ナラケン', '吉野郡下北山村', 'ヨシノグンシモキタヤマムラ', '佐田', 'サダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡下北山村浦向', '29', '29450', '6393802', '奈良県', 'ナラケン', '吉野郡下北山村', 'ヨシノグンシモキタヤマムラ', '浦向', 'ウラムカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡下北山村寺垣内', '29', '29450', '6393803', '奈良県', 'ナラケン', '吉野郡下北山村', 'ヨシノグンシモキタヤマムラ', '寺垣内', 'テラガイト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡下北山村池峰', '29', '29450', '6393804', '奈良県', 'ナラケン', '吉野郡下北山村', 'ヨシノグンシモキタヤマムラ', '池峰', 'イケミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡下北山村上池原', '29', '29450', '6393805', '奈良県', 'ナラケン', '吉野郡下北山村', 'ヨシノグンシモキタヤマムラ', '上池原', 'カミイケハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡下北山村下池原', '29', '29450', '6393806', '奈良県', 'ナラケン', '吉野郡下北山村', 'ヨシノグンシモキタヤマムラ', '下池原', 'シモイケハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡下北山村下桑原', '29', '29450', '6393807', '奈良県', 'ナラケン', '吉野郡下北山村', 'ヨシノグンシモキタヤマムラ', '下桑原', 'シモクワハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡下北山村上桑原', '29', '29450', '6393808', '奈良県', 'ナラケン', '吉野郡下北山村', 'ヨシノグンシモキタヤマムラ', '上桑原', 'カミクワハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡下北山村前鬼', '29', '29450', '6393809', '奈良県', 'ナラケン', '吉野郡下北山村', 'ヨシノグンシモキタヤマムラ', '前鬼', 'ゼンキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市', '30', '30201', '6400000', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('75189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市大川', '30', '30201', '6400101', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '大川', 'オオカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市深山', '30', '30201', '6400102', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '深山', 'ミヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市加太', '30', '30201', '6400103', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '加太', 'カダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市日野', '30', '30201', '6400111', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '日野', 'ヒノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市西庄', '30', '30201', '6400112', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '西庄', 'ニシノショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市本脇', '30', '30201', '6400113', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '本脇', 'モトワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市磯の浦', '30', '30201', '6400114', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '磯の浦', 'イソノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市つつじが丘', '30', '30201', '6400115', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', 'つつじが丘', 'ツツジガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市木枕', '30', '30201', '6400301', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '木枕', 'コマクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市永山', '30', '30201', '6400302', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '永山', 'ナガヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市山東中', '30', '30201', '6400303', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '山東中', 'サンドウナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市平尾', '30', '30201', '6400304', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '平尾', 'ヒラオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市明王寺', '30', '30201', '6400305', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '明王寺', 'ミョウオウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市塩ノ谷', '30', '30201', '6400306', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '塩ノ谷', 'シオノタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市矢田', '30', '30201', '6400307', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '矢田', 'ヤタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市黒岩', '30', '30201', '6400311', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '黒岩', 'クロイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市黒谷', '30', '30201', '6400312', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '黒谷', 'クロダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市境原', '30', '30201', '6400313', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '境原', 'サカイバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市頭陀寺', '30', '30201', '6400314', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '頭陀寺', 'ズダジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市南畑', '30', '30201', '6400315', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '南畑', 'ミナミバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市大河内', '30', '30201', '6400316', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '大河内', 'オオカワチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市薬勝寺', '30', '30201', '6400321', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '薬勝寺', 'ヤクショウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市仁井辺', '30', '30201', '6400322', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '仁井辺', 'ニイベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市小瀬田', '30', '30201', '6400323', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '小瀬田', 'コゼタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市本渡', '30', '30201', '6400324', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '本渡', 'モトワタリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市吉原', '30', '30201', '6400331', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '吉原', 'ヨシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市冬野', '30', '30201', '6400332', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '冬野', 'フユノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市広原', '30', '30201', '6400333', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '広原', 'ヒロハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市相坂', '30', '30201', '6400341', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '相坂', 'ソウザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市松原', '30', '30201', '6400342', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '松原', 'マツバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市江南', '30', '30201', '6400343', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '江南', 'エナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市朝日', '30', '30201', '6400344', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '朝日', 'アサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市桑山', '30', '30201', '6400345', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '桑山', 'クワヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市吉礼', '30', '30201', '6400351', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '吉礼', 'キレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市井戸', '30', '30201', '6400352', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '井戸', 'イド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市馬場', '30', '30201', '6400353', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '馬場', 'ババ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市伊太祈曽', '30', '30201', '6400361', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '伊太祈曽', 'イダキソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市奥須佐', '30', '30201', '6400362', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '奥須佐', 'オクズサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市吉里', '30', '30201', '6400363', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '吉里', 'ヨシザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市口須佐', '30', '30201', '6400364', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '口須佐', 'クチズサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市貴志川町丸栖', '30', '30208', '6400401', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '貴志川町丸栖', 'キシガワチョウマルス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市貴志川町北山', '30', '30208', '6400402', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '貴志川町北山', 'キシガワチョウキタヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市貴志川町尼寺', '30', '30208', '6400403', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '貴志川町尼寺', 'キシガワチョウアマテラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市貴志川町鳥居', '30', '30208', '6400404', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '貴志川町鳥居', 'キシガワチョウトリイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市貴志川町岸宮', '30', '30208', '6400405', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '貴志川町岸宮', 'キシガワチョウキシミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市貴志川町西山', '30', '30208', '6400406', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '貴志川町西山', 'キシガワチョウニシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市貴志川町前田', '30', '30208', '6400411', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '貴志川町前田', 'キシガワチョウマエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市貴志川町上野山', '30', '30208', '6400412', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '貴志川町上野山', 'キシガワチョウウエノヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市貴志川町神戸', '30', '30208', '6400413', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '貴志川町神戸', 'キシガワチョウコウド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市貴志川町国主', '30', '30208', '6400414', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '貴志川町国主', 'キシガワチョウクニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市貴志川町長原', '30', '30208', '6400415', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '貴志川町長原', 'キシガワチョウナガハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市貴志川町長山', '30', '30208', '6400416', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '貴志川町長山', 'キシガワチョウナガヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市貴志川町北', '30', '30208', '6400421', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '貴志川町北', 'キシガワチョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市貴志川町岸小野', '30', '30208', '6400422', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '貴志川町岸小野', 'キシガワチョウキシオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市貴志川町高尾', '30', '30208', '6400423', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '貴志川町高尾', 'キシガワチョウタカオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市貴志川町井ノ口', '30', '30208', '6400424', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '貴志川町井ノ口', 'キシガワチョウイノクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海南市七山', '30', '30202', '6400441', '和歌山県', 'ワカヤマケン', '海南市', 'カイナンシ', '七山', 'ナナヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海南市原野', '30', '30202', '6400442', '和歌山県', 'ワカヤマケン', '海南市', 'カイナンシ', '原野', 'ハラノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海南市下津野', '30', '30202', '6400443', '和歌山県', 'ワカヤマケン', '海南市', 'カイナンシ', '下津野', 'シモツノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海南市高津', '30', '30202', '6400451', '和歌山県', 'ワカヤマケン', '海南市', 'カイナンシ', '高津', 'タカヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海南市孟子', '30', '30202', '6400452', '和歌山県', 'ワカヤマケン', '海南市', 'カイナンシ', '孟子', 'モウコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海南市野尻', '30', '30202', '6400453', '和歌山県', 'ワカヤマケン', '海南市', 'カイナンシ', '野尻', 'ノジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海南市別院', '30', '30202', '6400454', '和歌山県', 'ワカヤマケン', '海南市', 'カイナンシ', '別院', 'ベツイン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海草郡紀美野町', '30', '30304', '6401100', '和歌山県', 'ワカヤマケン', '海草郡紀美野町', 'カイソウグンキミノチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('75254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海草郡紀美野町長谷', '30', '30304', '6401101', '和歌山県', 'ワカヤマケン', '海草郡紀美野町', 'カイソウグンキミノチョウ', '長谷', 'ナガタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海草郡紀美野町柴目', '30', '30304', '6401102', '和歌山県', 'ワカヤマケン', '海草郡紀美野町', 'カイソウグンキミノチョウ', '柴目', 'シバメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海草郡紀美野町吉野', '30', '30304', '6401103', '和歌山県', 'ワカヤマケン', '海草郡紀美野町', 'カイソウグンキミノチョウ', '吉野', 'ヨシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海草郡紀美野町福井', '30', '30304', '6401111', '和歌山県', 'ワカヤマケン', '海草郡紀美野町', 'カイソウグンキミノチョウ', '福井', 'フクイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海草郡紀美野町坂本', '30', '30304', '6401112', '和歌山県', 'ワカヤマケン', '海草郡紀美野町', 'カイソウグンキミノチョウ', '坂本', 'サカモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海草郡紀美野町梅本', '30', '30304', '6401113', '和歌山県', 'ワカヤマケン', '海草郡紀美野町', 'カイソウグンキミノチョウ', '梅本', 'ウメモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海草郡紀美野町中田', '30', '30304', '6401114', '和歌山県', 'ワカヤマケン', '海草郡紀美野町', 'カイソウグンキミノチョウ', '中田', 'ナカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海草郡紀美野町奥佐々', '30', '30304', '6401115', '和歌山県', 'ワカヤマケン', '海草郡紀美野町', 'カイソウグンキミノチョウ', '奥佐々', 'オクササ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海草郡紀美野町下佐々', '30', '30304', '6401121', '和歌山県', 'ワカヤマケン', '海草郡紀美野町', 'カイソウグンキミノチョウ', '下佐々', 'シモササ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海草郡紀美野町動木', '30', '30304', '6401131', '和歌山県', 'ワカヤマケン', '海草郡紀美野町', 'カイソウグンキミノチョウ', '動木', 'トドロキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海草郡紀美野町小畑', '30', '30304', '6401141', '和歌山県', 'ワカヤマケン', '海草郡紀美野町', 'カイソウグンキミノチョウ', '小畑', 'ショウバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海南市野上新', '30', '30202', '6401161', '和歌山県', 'ワカヤマケン', '海南市', 'カイナンシ', '野上新', 'ノカミシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海南市上谷', '30', '30202', '6401162', '和歌山県', 'ワカヤマケン', '海南市', 'カイナンシ', '上谷', 'カミダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海南市赤沼', '30', '30202', '6401163', '和歌山県', 'ワカヤマケン', '海南市', 'カイナンシ', '赤沼', 'アカヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海南市海老谷', '30', '30202', '6401164', '和歌山県', 'ワカヤマケン', '海南市', 'カイナンシ', '海老谷', 'エビタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海南市ひや水', '30', '30202', '6401165', '和歌山県', 'ワカヤマケン', '海南市', 'カイナンシ', 'ひや水', 'ヒヤミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海南市次ケ谷', '30', '30202', '6401166', '和歌山県', 'ワカヤマケン', '海南市', 'カイナンシ', '次ケ谷', 'ツゲダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海南市九品寺', '30', '30202', '6401167', '和歌山県', 'ワカヤマケン', '海南市', 'カイナンシ', '九品寺', 'クホンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海南市野上中', '30', '30202', '6401171', '和歌山県', 'ワカヤマケン', '海南市', 'カイナンシ', '野上中', 'ノカミナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海南市溝ノ口', '30', '30202', '6401172', '和歌山県', 'ワカヤマケン', '海南市', 'カイナンシ', '溝ノ口', 'ミゾノクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海南市椋木', '30', '30202', '6401173', '和歌山県', 'ワカヤマケン', '海南市', 'カイナンシ', '椋木', 'ムクノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海南市木津', '30', '30202', '6401174', '和歌山県', 'ワカヤマケン', '海南市', 'カイナンシ', '木津', 'キヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海南市沖野々', '30', '30202', '6401175', '和歌山県', 'ワカヤマケン', '海南市', 'カイナンシ', '沖野々', 'オキノノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海草郡紀美野町北野', '30', '30304', '6401201', '和歌山県', 'ワカヤマケン', '海草郡紀美野町', 'カイソウグンキミノチョウ', '北野', 'キタノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海草郡紀美野町初生谷', '30', '30304', '6401202', '和歌山県', 'ワカヤマケン', '海草郡紀美野町', 'カイソウグンキミノチョウ', '初生谷', 'ウイタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海草郡紀美野町花野原', '30', '30304', '6401203', '和歌山県', 'ワカヤマケン', '海草郡紀美野町', 'カイソウグンキミノチョウ', '花野原', 'ハナノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海草郡紀美野町蓑津呂', '30', '30304', '6401204', '和歌山県', 'ワカヤマケン', '海草郡紀美野町', 'カイソウグンキミノチョウ', '蓑津呂', 'ミノツロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海草郡紀美野町真国宮', '30', '30304', '6401205', '和歌山県', 'ワカヤマケン', '海草郡紀美野町', 'カイソウグンキミノチョウ', '真国宮', 'マクニミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海草郡紀美野町蓑垣内', '30', '30304', '6401206', '和歌山県', 'ワカヤマケン', '海草郡紀美野町', 'カイソウグンキミノチョウ', '蓑垣内', 'ミノガイト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海草郡紀美野町井堰', '30', '30304', '6401207', '和歌山県', 'ワカヤマケン', '海草郡紀美野町', 'カイソウグンキミノチョウ', '井堰', 'イセキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海草郡紀美野町桂瀬', '30', '30304', '6401211', '和歌山県', 'ワカヤマケン', '海草郡紀美野町', 'カイソウグンキミノチョウ', '桂瀬', 'カツラセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海草郡紀美野町高畑', '30', '30304', '6401212', '和歌山県', 'ワカヤマケン', '海草郡紀美野町', 'カイソウグンキミノチョウ', '高畑', 'タカハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海草郡紀美野町赤木', '30', '30304', '6401213', '和歌山県', 'ワカヤマケン', '海草郡紀美野町', 'カイソウグンキミノチョウ', '赤木', 'アカギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海草郡紀美野町明添', '30', '30304', '6401214', '和歌山県', 'ワカヤマケン', '海草郡紀美野町', 'カイソウグンキミノチョウ', '明添', 'ミョウゾエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海草郡紀美野町鎌滝', '30', '30304', '6401215', '和歌山県', 'ワカヤマケン', '海草郡紀美野町', 'カイソウグンキミノチョウ', '鎌滝', 'カマタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海草郡紀美野町三尾川', '30', '30304', '6401221', '和歌山県', 'ワカヤマケン', '海草郡紀美野町', 'カイソウグンキミノチョウ', '三尾川', 'ミオガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海草郡紀美野町大角', '30', '30304', '6401222', '和歌山県', 'ワカヤマケン', '海草郡紀美野町', 'カイソウグンキミノチョウ', '大角', 'オオスミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海草郡紀美野町津川', '30', '30304', '6401223', '和歌山県', 'ワカヤマケン', '海草郡紀美野町', 'カイソウグンキミノチョウ', '津川', 'ツガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海草郡紀美野町上ケ井', '30', '30304', '6401231', '和歌山県', 'ワカヤマケン', '海草郡紀美野町', 'カイソウグンキミノチョウ', '上ケ井', 'アゲイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海草郡紀美野町箕六', '30', '30304', '6401232', '和歌山県', 'ワカヤマケン', '海草郡紀美野町', 'カイソウグンキミノチョウ', '箕六', 'ミロク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海草郡紀美野町南畑', '30', '30304', '6401233', '和歌山県', 'ワカヤマケン', '海草郡紀美野町', 'カイソウグンキミノチョウ', '南畑', 'ミナミバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海草郡紀美野町安井', '30', '30304', '6401234', '和歌山県', 'ワカヤマケン', '海草郡紀美野町', 'カイソウグンキミノチョウ', '安井', 'ヤスイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海草郡紀美野町野中', '30', '30304', '6401235', '和歌山県', 'ワカヤマケン', '海草郡紀美野町', 'カイソウグンキミノチョウ', '野中', 'ノナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海草郡紀美野町永谷', '30', '30304', '6401241', '和歌山県', 'ワカヤマケン', '海草郡紀美野町', 'カイソウグンキミノチョウ', '永谷', 'ナガタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海草郡紀美野町樋下', '30', '30304', '6401242', '和歌山県', 'ワカヤマケン', '海草郡紀美野町', 'カイソウグンキミノチョウ', '樋下', 'ヒノシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海草郡紀美野町神野市場', '30', '30304', '6401243', '和歌山県', 'ワカヤマケン', '海草郡紀美野町', 'カイソウグンキミノチョウ', '神野市場', 'コウノイチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海草郡紀美野町福田', '30', '30304', '6401244', '和歌山県', 'ワカヤマケン', '海草郡紀美野町', 'カイソウグンキミノチョウ', '福田', 'フクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海草郡紀美野町国木原', '30', '30304', '6401251', '和歌山県', 'ワカヤマケン', '海草郡紀美野町', 'カイソウグンキミノチョウ', '国木原', 'クニギハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海草郡紀美野町西野', '30', '30304', '6401252', '和歌山県', 'ワカヤマケン', '海草郡紀美野町', 'カイソウグンキミノチョウ', '西野', 'ニシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海草郡紀美野町東野', '30', '30304', '6401253', '和歌山県', 'ワカヤマケン', '海草郡紀美野町', 'カイソウグンキミノチョウ', '東野', 'ヒガシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海草郡紀美野町松瀬', '30', '30304', '6401254', '和歌山県', 'ワカヤマケン', '海草郡紀美野町', 'カイソウグンキミノチョウ', '松瀬', 'マツセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海草郡紀美野町釜滝', '30', '30304', '6401255', '和歌山県', 'ワカヤマケン', '海草郡紀美野町', 'カイソウグンキミノチョウ', '釜滝', 'カマタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市桃山町峯', '30', '30208', '6401331', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '桃山町峯', 'モモヤマチョウミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市桃山町中畑', '30', '30208', '6401332', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '桃山町中畑', 'モモヤマチョウナカハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市桃山町垣内', '30', '30208', '6401333', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '桃山町垣内', 'モモヤマチョウカイト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海草郡紀美野町勝谷', '30', '30304', '6401351', '和歌山県', 'ワカヤマケン', '海草郡紀美野町', 'カイソウグンキミノチョウ', '勝谷', 'カチヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海草郡紀美野町谷', '30', '30304', '6401352', '和歌山県', 'ワカヤマケン', '海草郡紀美野町', 'カイソウグンキミノチョウ', '谷', 'タニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海草郡紀美野町円明寺', '30', '30304', '6401353', '和歌山県', 'ワカヤマケン', '海草郡紀美野町', 'カイソウグンキミノチョウ', '円明寺', 'エンミョウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海草郡紀美野町四郷', '30', '30304', '6401354', '和歌山県', 'ワカヤマケン', '海草郡紀美野町', 'カイソウグンキミノチョウ', '四郷', 'ヨゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海草郡紀美野町中', '30', '30304', '6401361', '和歌山県', 'ワカヤマケン', '海草郡紀美野町', 'カイソウグンキミノチョウ', '中', 'ナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海草郡紀美野町滝ノ川', '30', '30304', '6401362', '和歌山県', 'ワカヤマケン', '海草郡紀美野町', 'カイソウグンキミノチョウ', '滝ノ川', 'タキノガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海草郡紀美野町田', '30', '30304', '6401363', '和歌山県', 'ワカヤマケン', '海草郡紀美野町', 'カイソウグンキミノチョウ', '田', 'タ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海草郡紀美野町菅沢', '30', '30304', '6401364', '和歌山県', 'ワカヤマケン', '海草郡紀美野町', 'カイソウグンキミノチョウ', '菅沢', 'スゲザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海草郡紀美野町今西', '30', '30304', '6401365', '和歌山県', 'ワカヤマケン', '海草郡紀美野町', 'カイソウグンキミノチョウ', '今西', 'イマニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海草郡紀美野町松ケ峰', '30', '30304', '6401366', '和歌山県', 'ワカヤマケン', '海草郡紀美野町', 'カイソウグンキミノチョウ', '松ケ峰', 'マツガミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海草郡紀美野町長谷宮', '30', '30304', '6401471', '和歌山県', 'ワカヤマケン', '海草郡紀美野町', 'カイソウグンキミノチョウ', '長谷宮', 'ハセミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海草郡紀美野町毛原上', '30', '30304', '6401472', '和歌山県', 'ワカヤマケン', '海草郡紀美野町', 'カイソウグンキミノチョウ', '毛原上', 'ケバラカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海草郡紀美野町毛原宮', '30', '30304', '6401473', '和歌山県', 'ワカヤマケン', '海草郡紀美野町', 'カイソウグンキミノチョウ', '毛原宮', 'ケバラミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海草郡紀美野町毛原中', '30', '30304', '6401474', '和歌山県', 'ワカヤマケン', '海草郡紀美野町', 'カイソウグンキミノチョウ', '毛原中', 'ケバラナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海草郡紀美野町小西', '30', '30304', '6401475', '和歌山県', 'ワカヤマケン', '海草郡紀美野町', 'カイソウグンキミノチョウ', '小西', 'コニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海草郡紀美野町毛原下', '30', '30304', '6401476', '和歌山県', 'ワカヤマケン', '海草郡紀美野町', 'カイソウグンキミノチョウ', '毛原下', 'ケバラシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県伊都郡かつらぎ町新城', '30', '30341', '6401481', '和歌山県', 'ワカヤマケン', '伊都郡かつらぎ町', 'イトグンカツラギチョウ', '新城', 'シンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市北新七軒丁', '30', '30201', '6408001', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '北新七軒丁', 'キタシンシチケンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市北新', '30', '30201', '6408002', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '北新', 'キタシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市北新博労町', '30', '30201', '6408003', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '北新博労町', 'キタシンバクロウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市東旅籠町', '30', '30201', '6408004', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '東旅籠町', 'ヒガシハタゴマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市元寺町南ノ丁', '30', '30201', '6408005', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '元寺町南ノ丁', 'モトデラマチミナミノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市元寺町東ノ丁', '30', '30201', '6408006', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '元寺町東ノ丁', 'モトデラマチヒガシノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市元寺町西ノ丁', '30', '30201', '6408007', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '元寺町西ノ丁', 'モトデラマチニシノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市元寺町北ノ丁', '30', '30201', '6408008', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '元寺町北ノ丁', 'モトデラマチキタノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市鍋屋町', '30', '30201', '6408009', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '鍋屋町', 'ナベヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南1条西20丁目', '01', '01101', '0640801', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南1条西', 'ミナミ01ジョウニシ', null, null, '20丁目', '20チョウメ');
INSERT INTO `ms_addresses` VALUES ('75338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南1条西21丁目', '01', '01101', '0640801', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南1条西', 'ミナミ01ジョウニシ', null, null, '21丁目', '21チョウメ');
INSERT INTO `ms_addresses` VALUES ('75339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南1条西22丁目', '01', '01101', '0640801', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南1条西', 'ミナミ01ジョウニシ', null, null, '22丁目', '22チョウメ');
INSERT INTO `ms_addresses` VALUES ('75340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南1条西23丁目', '01', '01101', '0640801', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南1条西', 'ミナミ01ジョウニシ', null, null, '23丁目', '23チョウメ');
INSERT INTO `ms_addresses` VALUES ('75341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南1条西24丁目', '01', '01101', '0640801', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南1条西', 'ミナミ01ジョウニシ', null, null, '24丁目', '24チョウメ');
INSERT INTO `ms_addresses` VALUES ('75342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南1条西25丁目', '01', '01101', '0640801', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南1条西', 'ミナミ01ジョウニシ', null, null, '25丁目', '25チョウメ');
INSERT INTO `ms_addresses` VALUES ('75343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南1条西26丁目', '01', '01101', '0640801', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南1条西', 'ミナミ01ジョウニシ', null, null, '26丁目', '26チョウメ');
INSERT INTO `ms_addresses` VALUES ('75344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南1条西27丁目', '01', '01101', '0640801', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南1条西', 'ミナミ01ジョウニシ', null, null, '27丁目', '27チョウメ');
INSERT INTO `ms_addresses` VALUES ('75345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南1条西28丁目', '01', '01101', '0640801', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南1条西', 'ミナミ01ジョウニシ', null, null, '28丁目', '28チョウメ');
INSERT INTO `ms_addresses` VALUES ('75346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市北新元金屋丁', '30', '30201', '6408011', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '北新元金屋丁', 'キタシンモトカナヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市北新金屋丁', '30', '30201', '6408012', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '北新金屋丁', 'キタシンカナヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市東仲間町', '30', '30201', '6408013', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '東仲間町', 'ヒガシチュウゲンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市西仲間町', '30', '30201', '6408014', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '西仲間町', 'ニシチュウゲンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市北新桶屋町', '30', '30201', '6408015', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '北新桶屋町', 'キタシンオケヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市北新中ノ丁', '30', '30201', '6408016', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '北新中ノ丁', 'キタシンナカノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市北新戎ノ丁', '30', '30201', '6408017', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '北新戎ノ丁', 'キタシンエビスノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南2条西20丁目', '01', '01101', '0640802', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南2条西', 'ミナミ02ジョウニシ', null, null, '20丁目', '20チョウメ');
INSERT INTO `ms_addresses` VALUES ('75354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市北桶屋町', '30', '30201', '6408020', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '北桶屋町', 'キタオケヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南2条西21丁目', '01', '01101', '0640802', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南2条西', 'ミナミ02ジョウニシ', null, null, '21丁目', '21チョウメ');
INSERT INTO `ms_addresses` VALUES ('75356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南2条西22丁目', '01', '01101', '0640802', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南2条西', 'ミナミ02ジョウニシ', null, null, '22丁目', '22チョウメ');
INSERT INTO `ms_addresses` VALUES ('75357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南2条西23丁目', '01', '01101', '0640802', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南2条西', 'ミナミ02ジョウニシ', null, null, '23丁目', '23チョウメ');
INSERT INTO `ms_addresses` VALUES ('75358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南2条西24丁目', '01', '01101', '0640802', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南2条西', 'ミナミ02ジョウニシ', null, null, '24丁目', '24チョウメ');
INSERT INTO `ms_addresses` VALUES ('75359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南2条西25丁目', '01', '01101', '0640802', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南2条西', 'ミナミ02ジョウニシ', null, null, '25丁目', '25チョウメ');
INSERT INTO `ms_addresses` VALUES ('75360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南2条西26丁目', '01', '01101', '0640802', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南2条西', 'ミナミ02ジョウニシ', null, null, '26丁目', '26チョウメ');
INSERT INTO `ms_addresses` VALUES ('75361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南2条西27丁目', '01', '01101', '0640802', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南2条西', 'ミナミ02ジョウニシ', null, null, '27丁目', '27チョウメ');
INSERT INTO `ms_addresses` VALUES ('75362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南2条西28丁目', '01', '01101', '0640802', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南2条西', 'ミナミ02ジョウニシ', null, null, '28丁目', '28チョウメ');
INSERT INTO `ms_addresses` VALUES ('75363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市西旅籠町', '30', '30201', '6408021', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '西旅籠町', 'ニシハタゴマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市住吉町', '30', '30201', '6408022', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '住吉町', 'スミヨシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市中ノ店北ノ丁', '30', '30201', '6408023', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '中ノ店北ノ丁', 'ナカノタナキタノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市元寺町', '30', '30201', '6408024', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '元寺町', 'モトデラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市中ノ店中ノ丁', '30', '30201', '6408025', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '中ノ店中ノ丁', 'ナカノタナナカノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市中ノ店南ノ丁', '30', '30201', '6408026', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '中ノ店南ノ丁', 'ナカノタナミナミノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市米屋町', '30', '30201', '6408027', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '米屋町', 'コメヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市匠町', '30', '30201', '6408028', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '匠町', 'タクミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市南桶屋町', '30', '30201', '6408029', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '南桶屋町', 'ミナミオケヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南3条西20丁目', '01', '01101', '0640803', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南3条西', 'ミナミ03ジョウニシ', null, null, '20丁目', '20チョウメ');
INSERT INTO `ms_addresses` VALUES ('75373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南3条西21丁目', '01', '01101', '0640803', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南3条西', 'ミナミ03ジョウニシ', null, null, '21丁目', '21チョウメ');
INSERT INTO `ms_addresses` VALUES ('75374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南3条西22丁目', '01', '01101', '0640803', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南3条西', 'ミナミ03ジョウニシ', null, null, '22丁目', '22チョウメ');
INSERT INTO `ms_addresses` VALUES ('75375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南3条西23丁目', '01', '01101', '0640803', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南3条西', 'ミナミ03ジョウニシ', null, null, '23丁目', '23チョウメ');
INSERT INTO `ms_addresses` VALUES ('75376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南3条西24丁目', '01', '01101', '0640803', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南3条西', 'ミナミ03ジョウニシ', null, null, '24丁目', '24チョウメ');
INSERT INTO `ms_addresses` VALUES ('75377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南3条西25丁目', '01', '01101', '0640803', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南3条西', 'ミナミ03ジョウニシ', null, null, '25丁目', '25チョウメ');
INSERT INTO `ms_addresses` VALUES ('75378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南3条西26丁目', '01', '01101', '0640803', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南3条西', 'ミナミ03ジョウニシ', null, null, '26丁目', '26チョウメ');
INSERT INTO `ms_addresses` VALUES ('75379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南3条西27丁目', '01', '01101', '0640803', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南3条西', 'ミナミ03ジョウニシ', null, null, '27丁目', '27チョウメ');
INSERT INTO `ms_addresses` VALUES ('75380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南3条西28丁目', '01', '01101', '0640803', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南3条西', 'ミナミ03ジョウニシ', null, null, '28丁目', '28チョウメ');
INSERT INTO `ms_addresses` VALUES ('75381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市北大工町', '30', '30201', '6408031', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '北大工町', 'キタダイクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市南大工町', '30', '30201', '6408032', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '南大工町', 'ミナミダイクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市本町', '30', '30201', '6408033', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市駿河町', '30', '30201', '6408034', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '駿河町', 'スルガマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市万町', '30', '30201', '6408035', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '万町', 'ヨロズマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市東鍛冶屋町', '30', '30201', '6408036', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '東鍛冶屋町', 'ヒガシカジヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市西大工町', '30', '30201', '6408037', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '西大工町', 'ニシダイクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市北町', '30', '30201', '6408038', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '北町', 'キタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市宇治袋町', '30', '30201', '6408039', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '宇治袋町', 'ウジフクロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南4条西', '01', '01101', '0640804', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南4条西', 'ミナミ04ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市専光寺門前丁', '30', '30201', '6408041', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '専光寺門前丁', 'センコウジモンゼンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市西ノ店', '30', '30201', '6408042', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '西ノ店', 'ニシノタナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市福町', '30', '30201', '6408043', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '福町', 'フクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市板屋町', '30', '30201', '6408044', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '板屋町', 'イタヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市卜半町', '30', '30201', '6408045', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '卜半町', 'ボクハンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市西鍛冶屋町', '30', '30201', '6408046', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '西鍛冶屋町', 'ニシカジヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市鷺ノ森南ノ丁', '30', '30201', '6408047', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '鷺ノ森南ノ丁', 'サギノモリミナミノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南5条西', '01', '01101', '0640805', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南5条西', 'ミナミ05ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市鷺ノ森東ノ丁', '30', '30201', '6408051', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '鷺ノ森東ノ丁', 'サギノモリヒガシノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市鷺ノ森堂前丁', '30', '30201', '6408052', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '鷺ノ森堂前丁', 'サギノモリドウマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市鷺ノ森', '30', '30201', '6408053', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '鷺ノ森', 'サギノモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市鷺ノ森片町', '30', '30201', '6408054', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '鷺ノ森片町', 'サギノモリカタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市九家ノ丁', '30', '30201', '6408055', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '九家ノ丁', 'クケノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市鷺ノ森西ノ丁', '30', '30201', '6408056', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '鷺ノ森西ノ丁', 'サギノモリニシノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市鷺ノ森新道', '30', '30201', '6408057', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '鷺ノ森新道', 'サギノモリシンミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市鷺ノ森中ノ丁', '30', '30201', '6408058', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '鷺ノ森中ノ丁', 'サギノモリナカノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市鷺ノ森明神丁', '30', '30201', '6408059', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '鷺ノ森明神丁', 'サギノモリミョウジンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南6条西', '01', '01101', '0640806', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南6条西', 'ミナミ06ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市四筋目', '30', '30201', '6408060', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '四筋目', 'ヨスジメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市畳屋町', '30', '30201', '6408061', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '畳屋町', 'タタミヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市北釘貫丁', '30', '30201', '6408062', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '北釘貫丁', 'キタクギヌキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市西釘貫丁', '30', '30201', '6408063', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '西釘貫丁', 'ニシクギヌキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市東釘貫丁', '30', '30201', '6408064', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '東釘貫丁', 'ヒガシクギヌキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市山吹丁', '30', '30201', '6408065', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '山吹丁', 'ヤマブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市東布経丁', '30', '30201', '6408066', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '東布経丁', 'ヒガシヌノエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市一筋目', '30', '30201', '6408067', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '一筋目', 'ヒトスジメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市二筋目', '30', '30201', '6408068', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '二筋目', 'フタスジメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市三筋目', '30', '30201', '6408069', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '三筋目', 'ミスジメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南7条西', '01', '01101', '0640807', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南7条西', 'ミナミ07ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市宇治薮下', '30', '30201', '6408071', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '宇治薮下', 'ウジヤブシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市宇治家裏', '30', '30201', '6408072', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '宇治家裏', 'ウジヤウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市嘉家作丁', '30', '30201', '6408073', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '嘉家作丁', 'カケヅクリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市新魚町', '30', '30201', '6408074', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '新魚町', 'シンギョマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市源蔵馬場', '30', '30201', '6408075', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '源蔵馬場', 'ゲンゾウババ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市五筋目', '30', '30201', '6408076', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '五筋目', 'イツスジメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市六筋目', '30', '30201', '6408077', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '六筋目', 'ムスジメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市宇治鉄砲場', '30', '30201', '6408078', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '宇治鉄砲場', 'ウジテッポウバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南8条西', '01', '01101', '0640808', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南8条西', 'ミナミ08ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南9条西', '01', '01101', '0640809', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南9条西', 'ミナミ09ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南10条西', '01', '01101', '0640810', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南10条西', 'ミナミ10ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市新雑賀町', '30', '30201', '6408101', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '新雑賀町', 'シンサイカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市南雑賀町', '30', '30201', '6408102', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '南雑賀町', 'ミナミサイカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市北休賀町', '30', '30201', '6408103', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '北休賀町', 'キタキュウカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市南休賀町', '30', '30201', '6408104', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '南休賀町', 'ミナミキュウカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市三木町南ノ丁', '30', '30201', '6408105', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '三木町南ノ丁', 'ミキマチミナミノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市三木町中ノ丁', '30', '30201', '6408106', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '三木町中ノ丁', 'ミキマチナカノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市三木町堀詰', '30', '30201', '6408107', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '三木町堀詰', 'ミキマチホリヅメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市雑賀町', '30', '30201', '6408108', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '雑賀町', 'サイカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南11条西', '01', '01101', '0640811', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南11条西', 'ミナミ11ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市新通', '30', '30201', '6408111', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '新通', 'シントオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市南材木丁', '30', '30201', '6408112', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '南材木丁', 'ミナミザイモクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市広瀬通丁', '30', '30201', '6408113', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '広瀬通丁', 'ヒロセトオリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市船場町', '30', '30201', '6408114', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '船場町', 'センバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市東紺屋町', '30', '30201', '6408115', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '東紺屋町', 'ヒガシコンヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市西紺屋町', '30', '30201', '6408116', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '西紺屋町', 'ニシコンヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市南細工町', '30', '30201', '6408117', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '南細工町', 'ミナミサイクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市北細工町', '30', '30201', '6408118', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '北細工町', 'キタサイクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市和歌町', '30', '30201', '6408119', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '和歌町', 'ワカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市雑賀道', '30', '30201', '6408121', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '雑賀道', 'サイカミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市汐見町', '30', '30201', '6408122', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '汐見町', 'シオミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市三沢町', '30', '30201', '6408123', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '三沢町', 'ミサワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市雄松町', '30', '30201', '6408124', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '雄松町', 'オマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市島崎町', '30', '30201', '6408125', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '島崎町', 'シマザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市南片原', '30', '30201', '6408126', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '南片原', 'ミナミカタハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市元町奉行丁', '30', '30201', '6408127', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '元町奉行丁', 'モトマチブギョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市広瀬中ノ丁', '30', '30201', '6408128', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '広瀬中ノ丁', 'ヒロセナカノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市弁財天丁', '30', '30201', '6408131', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '弁財天丁', 'ベザイテンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市山蔭丁', '30', '30201', '6408132', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '山蔭丁', 'ヤマカゲチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市谷町', '30', '30201', '6408133', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '谷町', 'タニマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市芦辺丁', '30', '30201', '6408134', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '芦辺丁', 'アシベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市鷹匠町', '30', '30201', '6408135', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '鷹匠町', 'タカジョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市堀止東', '30', '30201', '6408136', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '堀止東', 'ホリドメヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市吹上', '30', '30201', '6408137', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '吹上', 'フキアゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市薮ノ丁', '30', '30201', '6408138', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '薮ノ丁', 'ヤブノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市片岡町', '30', '30201', '6408139', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '片岡町', 'カタオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市五番丁', '30', '30201', '6408141', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '五番丁', 'ゴバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市三番丁', '30', '30201', '6408142', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '三番丁', 'サンバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市二番丁', '30', '30201', '6408143', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '二番丁', 'ニバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市四番丁', '30', '30201', '6408144', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '四番丁', 'ヨンバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市岡山丁', '30', '30201', '6408145', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '岡山丁', 'オカヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市一番丁', '30', '30201', '6408146', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '一番丁', 'イチバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市十三番丁', '30', '30201', '6408150', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '十三番丁', 'ジュウサンバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市屋形町', '30', '30201', '6408151', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '屋形町', 'ヤカタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市十番丁', '30', '30201', '6408152', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '十番丁', 'ジュウバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市三木町台所町', '30', '30201', '6408153', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '三木町台所町', 'ミキマチダイドコロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市六番丁', '30', '30201', '6408154', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '六番丁', 'ロクバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市九番丁', '30', '30201', '6408155', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '九番丁', 'キュウバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市七番丁', '30', '30201', '6408156', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '七番丁', 'シチバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市八番丁', '30', '30201', '6408157', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '八番丁', 'ハチバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市十二番丁', '30', '30201', '6408158', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '十二番丁', 'ジュウニバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市十一番丁', '30', '30201', '6408159', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '十一番丁', 'ジュウイチバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区大通西20丁目', '01', '01101', '0640820', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '大通西', 'オオドオリニシ', null, null, '20丁目', '20チョウメ');
INSERT INTO `ms_addresses` VALUES ('75483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区大通西21丁目', '01', '01101', '0640820', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '大通西', 'オオドオリニシ', null, null, '21丁目', '21チョウメ');
INSERT INTO `ms_addresses` VALUES ('75484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区大通西22丁目', '01', '01101', '0640820', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '大通西', 'オオドオリニシ', null, null, '22丁目', '22チョウメ');
INSERT INTO `ms_addresses` VALUES ('75485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区大通西23丁目', '01', '01101', '0640820', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '大通西', 'オオドオリニシ', null, null, '23丁目', '23チョウメ');
INSERT INTO `ms_addresses` VALUES ('75486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区大通西24丁目', '01', '01101', '0640820', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '大通西', 'オオドオリニシ', null, null, '24丁目', '24チョウメ');
INSERT INTO `ms_addresses` VALUES ('75487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区大通西25丁目', '01', '01101', '0640820', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '大通西', 'オオドオリニシ', null, null, '25丁目', '25チョウメ');
INSERT INTO `ms_addresses` VALUES ('75488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区大通西26丁目', '01', '01101', '0640820', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '大通西', 'オオドオリニシ', null, null, '26丁目', '26チョウメ');
INSERT INTO `ms_addresses` VALUES ('75489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区大通西27丁目', '01', '01101', '0640820', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '大通西', 'オオドオリニシ', null, null, '27丁目', '27チョウメ');
INSERT INTO `ms_addresses` VALUES ('75490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区大通西28丁目', '01', '01101', '0640820', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '大通西', 'オオドオリニシ', null, null, '28丁目', '28チョウメ');
INSERT INTO `ms_addresses` VALUES ('75491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市石橋丁', '30', '30201', '6408201', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '石橋丁', 'イシバシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市屏風丁', '30', '30201', '6408202', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '屏風丁', 'ビョウブチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市東蔵前丁', '30', '30201', '6408203', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '東蔵前丁', 'ヒガシクラマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市伝法橋南ノ丁', '30', '30201', '6408204', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '伝法橋南ノ丁', 'デンポウバシミナミノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市西蔵前丁', '30', '30201', '6408205', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '西蔵前丁', 'ニシクラマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市徳田木丁', '30', '30201', '6408206', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '徳田木丁', 'トクダギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北1条西20丁目', '01', '01101', '0640821', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北1条西', 'キタ01ジョウニシ', null, null, '20丁目', '20チョウメ');
INSERT INTO `ms_addresses` VALUES ('75498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北1条西21丁目', '01', '01101', '0640821', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北1条西', 'キタ01ジョウニシ', null, null, '21丁目', '21チョウメ');
INSERT INTO `ms_addresses` VALUES ('75499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北1条西22丁目', '01', '01101', '0640821', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北1条西', 'キタ01ジョウニシ', null, null, '22丁目', '22チョウメ');
INSERT INTO `ms_addresses` VALUES ('75500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北1条西23丁目', '01', '01101', '0640821', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北1条西', 'キタ01ジョウニシ', null, null, '23丁目', '23チョウメ');
INSERT INTO `ms_addresses` VALUES ('75501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北1条西24丁目', '01', '01101', '0640821', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北1条西', 'キタ01ジョウニシ', null, null, '24丁目', '24チョウメ');
INSERT INTO `ms_addresses` VALUES ('75502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北1条西25丁目', '01', '01101', '0640821', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北1条西', 'キタ01ジョウニシ', null, null, '25丁目', '25チョウメ');
INSERT INTO `ms_addresses` VALUES ('75503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北1条西26丁目', '01', '01101', '0640821', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北1条西', 'キタ01ジョウニシ', null, null, '26丁目', '26チョウメ');
INSERT INTO `ms_addresses` VALUES ('75504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北1条西27丁目', '01', '01101', '0640821', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北1条西', 'キタ01ジョウニシ', null, null, '27丁目', '27チョウメ');
INSERT INTO `ms_addresses` VALUES ('75505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北1条西28丁目', '01', '01101', '0640821', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北1条西', 'キタ01ジョウニシ', null, null, '28丁目', '28チョウメ');
INSERT INTO `ms_addresses` VALUES ('75506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市西布経丁', '30', '30201', '6408211', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '西布経丁', 'ニシヌノエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市杉ノ馬場', '30', '30201', '6408212', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '杉ノ馬場', 'スギノババ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市舟大工町', '30', '30201', '6408213', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '舟大工町', 'フナダイクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市寄合町', '30', '30201', '6408214', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '寄合町', 'ヨリアイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市橋丁', '30', '30201', '6408215', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '橋丁', 'ハシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市元博労町', '30', '30201', '6408216', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '元博労町', 'モトバクロウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北2条西20丁目', '01', '01101', '0640822', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北2条西', 'キタ02ジョウニシ', null, null, '20丁目', '20チョウメ');
INSERT INTO `ms_addresses` VALUES ('75513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市下町', '30', '30201', '6408220', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '下町', 'ゲノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北2条西21丁目', '01', '01101', '0640822', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北2条西', 'キタ02ジョウニシ', null, null, '21丁目', '21チョウメ');
INSERT INTO `ms_addresses` VALUES ('75515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北2条西22丁目', '01', '01101', '0640822', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北2条西', 'キタ02ジョウニシ', null, null, '22丁目', '22チョウメ');
INSERT INTO `ms_addresses` VALUES ('75516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北2条西23丁目', '01', '01101', '0640822', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北2条西', 'キタ02ジョウニシ', null, null, '23丁目', '23チョウメ');
INSERT INTO `ms_addresses` VALUES ('75517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北2条西24丁目', '01', '01101', '0640822', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北2条西', 'キタ02ジョウニシ', null, null, '24丁目', '24チョウメ');
INSERT INTO `ms_addresses` VALUES ('75518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北2条西25丁目', '01', '01101', '0640822', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北2条西', 'キタ02ジョウニシ', null, null, '25丁目', '25チョウメ');
INSERT INTO `ms_addresses` VALUES ('75519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北2条西26丁目', '01', '01101', '0640822', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北2条西', 'キタ02ジョウニシ', null, null, '26丁目', '26チョウメ');
INSERT INTO `ms_addresses` VALUES ('75520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北2条西27丁目', '01', '01101', '0640822', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北2条西', 'キタ02ジョウニシ', null, null, '27丁目', '27チョウメ');
INSERT INTO `ms_addresses` VALUES ('75521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北2条西28丁目', '01', '01101', '0640822', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北2条西', 'キタ02ジョウニシ', null, null, '28丁目', '28チョウメ');
INSERT INTO `ms_addresses` VALUES ('75522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市湊紺屋町', '30', '30201', '6408221', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '湊紺屋町', 'ミナトコンヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市湊本町', '30', '30201', '6408222', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '湊本町', 'ミナトホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市湊北町', '30', '30201', '6408223', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '湊北町', 'ミナトキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市小野町', '30', '30201', '6408224', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '小野町', 'オノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市久保丁', '30', '30201', '6408225', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '久保丁', 'クボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市小人町', '30', '30201', '6408226', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '小人町', 'コビトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市西汀丁', '30', '30201', '6408227', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '西汀丁', 'ニシミギワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市小人町南ノ丁', '30', '30201', '6408228', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '小人町南ノ丁', 'コビトマチミナミノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市道場町', '30', '30201', '6408229', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '道場町', 'ドウジョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北3条西20丁目', '01', '01101', '0640823', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北3条西', 'キタ03ジョウニシ', null, null, '20丁目', '20チョウメ');
INSERT INTO `ms_addresses` VALUES ('75532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市男野芝丁', '30', '30201', '6408230', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '男野芝丁', 'オノシバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北3条西21丁目', '01', '01101', '0640823', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北3条西', 'キタ03ジョウニシ', null, null, '21丁目', '21チョウメ');
INSERT INTO `ms_addresses` VALUES ('75534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北3条西22丁目', '01', '01101', '0640823', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北3条西', 'キタ03ジョウニシ', null, null, '22丁目', '22チョウメ');
INSERT INTO `ms_addresses` VALUES ('75535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北3条西23丁目', '01', '01101', '0640823', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北3条西', 'キタ03ジョウニシ', null, null, '23丁目', '23チョウメ');
INSERT INTO `ms_addresses` VALUES ('75536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北3条西24丁目', '01', '01101', '0640823', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北3条西', 'キタ03ジョウニシ', null, null, '24丁目', '24チョウメ');
INSERT INTO `ms_addresses` VALUES ('75537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北3条西25丁目', '01', '01101', '0640823', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北3条西', 'キタ03ジョウニシ', null, null, '25丁目', '25チョウメ');
INSERT INTO `ms_addresses` VALUES ('75538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北3条西26丁目', '01', '01101', '0640823', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北3条西', 'キタ03ジョウニシ', null, null, '26丁目', '26チョウメ');
INSERT INTO `ms_addresses` VALUES ('75539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北3条西27丁目', '01', '01101', '0640823', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北3条西', 'キタ03ジョウニシ', null, null, '27丁目', '27チョウメ');
INSERT INTO `ms_addresses` VALUES ('75540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北3条西28丁目', '01', '01101', '0640823', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北3条西', 'キタ03ジョウニシ', null, null, '28丁目', '28チョウメ');
INSERT INTO `ms_addresses` VALUES ('75541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北3条西29丁目', '01', '01101', '0640823', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北3条西', 'キタ03ジョウニシ', null, null, '29丁目', '29チョウメ');
INSERT INTO `ms_addresses` VALUES ('75542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北3条西30丁目', '01', '01101', '0640823', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北3条西', 'キタ03ジョウニシ', null, null, '30丁目', '30チョウメ');
INSERT INTO `ms_addresses` VALUES ('75543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市北汀丁', '30', '30201', '6408231', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '北汀丁', 'キタミギワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市南汀丁', '30', '30201', '6408232', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '南汀丁', 'ミナミミギワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市北坂ノ上丁', '30', '30201', '6408233', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '北坂ノ上丁', 'キタサカノウエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市西坂ノ上丁', '30', '30201', '6408234', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '西坂ノ上丁', 'ニシサカノウエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市東長町', '30', '30201', '6408235', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '東長町', 'ヒガシナガマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市七曲り', '30', '30201', '6408236', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '七曲り', 'ナナマガリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市材木丁', '30', '30201', '6408237', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '材木丁', 'ザイモクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市網屋町', '30', '30201', '6408238', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '網屋町', 'アミヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市上町', '30', '30201', '6408239', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '上町', 'ウワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北4条西20丁目', '01', '01101', '0640824', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北4条西', 'キタ04ジョウニシ', null, null, '20丁目', '20チョウメ');
INSERT INTO `ms_addresses` VALUES ('75553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北4条西21丁目', '01', '01101', '0640824', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北4条西', 'キタ04ジョウニシ', null, null, '21丁目', '21チョウメ');
INSERT INTO `ms_addresses` VALUES ('75554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北4条西22丁目', '01', '01101', '0640824', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北4条西', 'キタ04ジョウニシ', null, null, '22丁目', '22チョウメ');
INSERT INTO `ms_addresses` VALUES ('75555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北4条西23丁目', '01', '01101', '0640824', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北4条西', 'キタ04ジョウニシ', null, null, '23丁目', '23チョウメ');
INSERT INTO `ms_addresses` VALUES ('75556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北4条西24丁目', '01', '01101', '0640824', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北4条西', 'キタ04ジョウニシ', null, null, '24丁目', '24チョウメ');
INSERT INTO `ms_addresses` VALUES ('75557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北4条西25丁目', '01', '01101', '0640824', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北4条西', 'キタ04ジョウニシ', null, null, '25丁目', '25チョウメ');
INSERT INTO `ms_addresses` VALUES ('75558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北4条西26丁目', '01', '01101', '0640824', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北4条西', 'キタ04ジョウニシ', null, null, '26丁目', '26チョウメ');
INSERT INTO `ms_addresses` VALUES ('75559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北4条西27丁目', '01', '01101', '0640824', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北4条西', 'キタ04ジョウニシ', null, null, '27丁目', '27チョウメ');
INSERT INTO `ms_addresses` VALUES ('75560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北4条西28丁目', '01', '01101', '0640824', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北4条西', 'キタ04ジョウニシ', null, null, '28丁目', '28チョウメ');
INSERT INTO `ms_addresses` VALUES ('75561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北4条西29丁目', '01', '01101', '0640824', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北4条西', 'キタ04ジョウニシ', null, null, '29丁目', '29チョウメ');
INSERT INTO `ms_addresses` VALUES ('75562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北4条西30丁目', '01', '01101', '0640824', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北4条西', 'キタ04ジョウニシ', null, null, '30丁目', '30チョウメ');
INSERT INTO `ms_addresses` VALUES ('75563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市雑賀屋町東ノ丁', '30', '30201', '6408241', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '雑賀屋町東ノ丁', 'サイカヤマチヒガシノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市上野町', '30', '30201', '6408242', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '上野町', 'ウエノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市徒町', '30', '30201', '6408243', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '徒町', 'カチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市久右衛門丁', '30', '30201', '6408244', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '久右衛門丁', 'キュウエモンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市有田屋町南ノ丁', '30', '30201', '6408245', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '有田屋町南ノ丁', 'アリダヤマチミナミノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市有田屋町西ノ丁', '30', '30201', '6408246', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '有田屋町西ノ丁', 'アリダヤマチニシノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市東坂ノ上丁', '30', '30201', '6408247', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '東坂ノ上丁', 'ヒガシサカノウエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市有田屋町', '30', '30201', '6408248', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '有田屋町', 'アリダヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市雑賀屋町', '30', '30201', '6408249', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '雑賀屋町', 'サイカヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北5条西25丁目', '01', '01101', '0640825', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北5条西', 'キタ05ジョウニシ', null, null, '25丁目', '25チョウメ');
INSERT INTO `ms_addresses` VALUES ('75573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北5条西26丁目', '01', '01101', '0640825', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北5条西', 'キタ05ジョウニシ', null, null, '26丁目', '26チョウメ');
INSERT INTO `ms_addresses` VALUES ('75574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北5条西27丁目', '01', '01101', '0640825', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北5条西', 'キタ05ジョウニシ', null, null, '27丁目', '27チョウメ');
INSERT INTO `ms_addresses` VALUES ('75575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北5条西28丁目', '01', '01101', '0640825', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北5条西', 'キタ05ジョウニシ', null, null, '28丁目', '28チョウメ');
INSERT INTO `ms_addresses` VALUES ('75576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北5条西29丁目', '01', '01101', '0640825', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北5条西', 'キタ05ジョウニシ', null, null, '29丁目', '29チョウメ');
INSERT INTO `ms_addresses` VALUES ('75577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市南中間町', '30', '30201', '6408251', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '南中間町', 'ミナミチュウゲンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市北田辺丁', '30', '30201', '6408252', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '北田辺丁', 'キタタナベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市北相生丁', '30', '30201', '6408253', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '北相生丁', 'キタアイオイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市南田辺丁', '30', '30201', '6408254', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '南田辺丁', 'ミナミタナベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市舟津町', '30', '30201', '6408255', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '舟津町', 'フナヅチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市土佐町', '30', '30201', '6408256', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '土佐町', 'トサマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北6条西26丁目', '01', '01101', '0640826', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北6条西', 'キタ06ジョウニシ', null, null, '26丁目', '26チョウメ');
INSERT INTO `ms_addresses` VALUES ('75584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北6条西27丁目', '01', '01101', '0640826', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北6条西', 'キタ06ジョウニシ', null, null, '27丁目', '27チョウメ');
INSERT INTO `ms_addresses` VALUES ('75585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区北6条西28丁目', '01', '01101', '0640826', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '北6条西', 'キタ06ジョウニシ', null, null, '28丁目', '28チョウメ');
INSERT INTO `ms_addresses` VALUES ('75586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市真砂丁', '30', '30201', '6408261', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '真砂丁', 'マサゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市湊通丁北', '30', '30201', '6408262', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '湊通丁北', 'ミナトトオリチョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市茶屋ノ丁', '30', '30201', '6408263', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '茶屋ノ丁', 'チャヤノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市湊桶屋町', '30', '30201', '6408264', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '湊桶屋町', 'ミナトオケヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市小松原', '30', '30201', '6408265', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '小松原', 'コマツバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市東長町中ノ丁', '30', '30201', '6408266', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '東長町中ノ丁', 'ヒガシナガマチナカノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市芝ノ丁', '30', '30201', '6408267', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '芝ノ丁', 'シバノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市広道', '30', '30201', '6408268', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '広道', 'ヒロミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市小松原通', '30', '30201', '6408269', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '小松原通', 'コマツバラドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市尾崎丁', '30', '30201', '6408271', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '尾崎丁', 'オザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市砂山南', '30', '30201', '6408272', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '砂山南', 'スナヤマミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市葵町', '30', '30201', '6408273', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '葵町', 'アオイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市金龍寺丁', '30', '30201', '6408274', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '金龍寺丁', 'キンリュウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市南相生丁', '30', '30201', '6408275', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '南相生丁', 'ミナミアイオイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市作事丁', '30', '30201', '6408276', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '作事丁', 'サクジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市湊通丁南', '30', '30201', '6408281', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '湊通丁南', 'ミナトトオリチョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市出口甲賀丁', '30', '30201', '6408282', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '出口甲賀丁', 'デグチコウガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市出口中ノ丁', '30', '30201', '6408283', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '出口中ノ丁', 'デグチナカノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市出口端ノ丁', '30', '30201', '6408284', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '出口端ノ丁', 'デグチハシノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市出口新端ノ丁', '30', '30201', '6408285', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '出口新端ノ丁', 'デグチシンハシノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市湊御殿', '30', '30201', '6408286', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '湊御殿', 'ミナトゴテン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市築港', '30', '30201', '6408287', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '築港', 'チッコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市加納町', '30', '30201', '6408288', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '加納町', 'カノウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市西長町', '30', '30201', '6408290', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '西長町', 'ニシナガマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市北甚五兵衛丁', '30', '30201', '6408291', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '北甚五兵衛丁', 'キタジンゴベエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市南甚五兵衛丁', '30', '30201', '6408292', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '南甚五兵衛丁', 'ミナミジンゴベエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市駕町', '30', '30201', '6408293', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '駕町', 'カゴマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市北中間町', '30', '30201', '6408294', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '北中間町', 'キタチュウゲンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市南牛町', '30', '30201', '6408295', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '南牛町', 'ミナミウシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市北土佐丁', '30', '30201', '6408296', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '北土佐丁', 'キタトサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市西河岸町', '30', '30201', '6408297', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '西河岸町', 'ニシカワギシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市植松丁', '30', '30201', '6408298', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '植松丁', 'ウエマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市北牛町', '30', '30201', '6408299', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '北牛町', 'キタウシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市岩橋', '30', '30201', '6408301', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '岩橋', 'イワセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市井辺', '30', '30201', '6408302', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '井辺', 'インベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市鳴神', '30', '30201', '6408303', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '鳴神', 'ナルカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市松島', '30', '30201', '6408304', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '松島', 'マツシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市栗栖', '30', '30201', '6408305', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '栗栖', 'クルス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市出島', '30', '30201', '6408306', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '出島', 'デジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市寺内', '30', '30201', '6408311', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '寺内', 'テラウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市森小手穂', '30', '30201', '6408312', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '森小手穂', 'モリオテボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市西', '30', '30201', '6408313', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '西', 'ニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市神前', '30', '30201', '6408314', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '神前', 'コウザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市津秦', '30', '30201', '6408315', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '津秦', 'ツハダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市有家', '30', '30201', '6408316', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '有家', 'アリエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市北出島', '30', '30201', '6408317', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '北出島', 'キタデジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市南出島', '30', '30201', '6408318', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '南出島', 'ミナミデジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市手平', '30', '30201', '6408319', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '手平', 'テビラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市手平出島', '30', '30201', '6408320', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '手平出島', 'テビラデジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市出水', '30', '30201', '6408321', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '出水', 'デミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市秋月', '30', '30201', '6408322', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '秋月', 'アキヅキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市太田', '30', '30201', '6408323', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '太田', 'オオダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市吹屋町', '30', '30201', '6408324', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '吹屋町', 'フキヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市新生町', '30', '30201', '6408325', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '新生町', 'シンセイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市新留丁', '30', '30201', '6408326', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '新留丁', 'ニントメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市橋向丁', '30', '30201', '6408327', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '橋向丁', 'ハシムカイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市木広町', '30', '30201', '6408328', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '木広町', 'キヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市田中町', '30', '30201', '6408329', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '田中町', 'タナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市美園町', '30', '30201', '6408331', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '美園町', 'ミソノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市楠右衛門小路', '30', '30201', '6408332', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '楠右衛門小路', 'クスエモンショウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市蔵小路', '30', '30201', '6408333', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '蔵小路', 'クラショウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市茶屋町', '30', '30201', '6408334', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '茶屋町', 'チャヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市餌差町', '30', '30201', '6408335', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '餌差町', 'エサシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市柳丁', '30', '30201', '6408336', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '柳丁', 'ヤナギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市毛革屋丁', '30', '30201', '6408337', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '毛革屋丁', 'ケガワヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市黒田', '30', '30201', '6408341', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '黒田', 'クロダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市友田町', '30', '30201', '6408342', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '友田町', 'トモダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市吉田', '30', '30201', '6408343', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '吉田', 'ヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市納定', '30', '30201', '6408344', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '納定', 'ノウジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市新在家', '30', '30201', '6408345', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '新在家', 'シンザイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市北ノ新地分銅丁', '30', '30201', '6408350', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '北ノ新地分銅丁', 'キタノシンチフンドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市新内', '30', '30201', '6408351', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '新内', 'アロチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市北ノ新地裏田町', '30', '30201', '6408352', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '北ノ新地裏田町', 'キタノシンチウラタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市北ノ新地榎丁', '30', '30201', '6408353', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '北ノ新地榎丁', 'キタノシンチエノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市北ノ新地東ノ丁', '30', '30201', '6408354', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '北ノ新地東ノ丁', 'キタノシンチヒガシノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市北ノ新地', '30', '30201', '6408355', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '北ノ新地', 'キタノシンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市北ノ新地上六軒丁', '30', '30201', '6408356', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '北ノ新地上六軒丁', 'キタノシンチカミロッケンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市北ノ新地中六軒丁', '30', '30201', '6408357', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '北ノ新地中六軒丁', 'キタノシンチナカロッケンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市北ノ新地下六軒丁', '30', '30201', '6408358', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '北ノ新地下六軒丁', 'キタノシンチシモロッケンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市北ノ新地田町', '30', '30201', '6408359', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '北ノ新地田町', 'キタノシンチタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市岡円福院東ノ丁', '30', '30201', '6408361', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '岡円福院東ノ丁', 'オカエンプクインヒガシノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市岡織屋小路', '30', '30201', '6408362', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '岡織屋小路', 'オカオリヤショウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市岡南ノ丁', '30', '30201', '6408363', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '岡南ノ丁', 'オカミナミノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市岡円福院西ノ丁', '30', '30201', '6408364', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '岡円福院西ノ丁', 'オカエンプクインニシノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市岡北ノ丁', '30', '30201', '6408365', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '岡北ノ丁', 'オカキタノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市新八百屋丁', '30', '30201', '6408371', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '新八百屋丁', 'シンヤオヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市新大工町', '30', '30201', '6408372', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '新大工町', 'シンダイクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市木挽丁', '30', '30201', '6408373', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '木挽丁', 'コビキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市数寄屋丁', '30', '30201', '6408374', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '数寄屋丁', 'スキヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市坊主丁', '30', '30201', '6408375', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '坊主丁', 'ボウズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市新中通', '30', '30201', '6408376', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '新中通', 'シンナカドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市新堺丁', '30', '30201', '6408377', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '新堺丁', 'シンサカイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市鈴丸丁', '30', '30201', '6408378', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '鈴丸丁', 'スズマルチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市畑屋敷東ノ丁', '30', '30201', '6408381', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '畑屋敷東ノ丁', 'ハタヤシキヒガシノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市畑屋敷榎丁', '30', '30201', '6408382', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '畑屋敷榎丁', 'ハタヤシキエノキノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市畑屋敷円福院東ノ丁', '30', '30201', '6408383', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '畑屋敷円福院東ノ丁', 'ハタヤシキエンプクインヒガシノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市畑屋敷葛屋丁', '30', '30201', '6408384', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '畑屋敷葛屋丁', 'ハタヤシキクズヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市畑屋敷円福院西ノ丁', '30', '30201', '6408385', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '畑屋敷円福院西ノ丁', 'ハタヤシキエンプクインニシノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市畑屋敷雁木丁', '30', '30201', '6408386', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '畑屋敷雁木丁', 'ハタヤシキガンギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市畑屋敷袋町', '30', '30201', '6408387', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '畑屋敷袋町', 'ハタヤシキフクロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市有本', '30', '30201', '6408390', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '有本', 'アリモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市加納', '30', '30201', '6408391', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '加納', 'カノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市中之島', '30', '30201', '6408392', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '中之島', 'ナカノシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市畑屋敷端ノ丁', '30', '30201', '6408393', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '畑屋敷端ノ丁', 'ハタヤシキハシノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市畑屋敷千体仏丁', '30', '30201', '6408394', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '畑屋敷千体仏丁', 'ハタヤシキセンタイブツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市畑屋敷中ノ丁', '30', '30201', '6408395', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '畑屋敷中ノ丁', 'ハタヤシキナカノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市畑屋敷西ノ丁', '30', '30201', '6408396', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '畑屋敷西ノ丁', 'ハタヤシキニシノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市畑屋敷新道丁', '30', '30201', '6408397', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '畑屋敷新道丁', 'ハタヤシキシンミチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市畑屋敷松ケ枝丁', '30', '30201', '6408398', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '畑屋敷松ケ枝丁', 'ハタヤシキマツガエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市畑屋敷兵庫ノ丁', '30', '30201', '6408399', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '畑屋敷兵庫ノ丁', 'ハタヤシキヒョウゴノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市福島', '30', '30201', '6408401', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '福島', 'フクシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市野崎', '30', '30201', '6408402', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '野崎', 'ノザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市北島', '30', '30201', '6408403', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '北島', 'キタジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市湊', '30', '30201', '6408404', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '湊', 'ミナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市梶取', '30', '30201', '6408411', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '梶取', 'カンドリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市狐島', '30', '30201', '6408412', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '狐島', 'キツネジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市島橋東ノ丁', '30', '30201', '6408413', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '島橋東ノ丁', 'シマバシヒガシノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市島橋西ノ丁', '30', '30201', '6408414', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '島橋西ノ丁', 'シマバシニシノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市島橋南ノ丁', '30', '30201', '6408415', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '島橋南ノ丁', 'シマバシミナミノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市島橋北ノ丁', '30', '30201', '6408416', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '島橋北ノ丁', 'シマバシキタノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市松江', '30', '30201', '6408421', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '松江', 'マツエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市松江東', '30', '30201', '6408422', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '松江東', 'マツエヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市松江中', '30', '30201', '6408423', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '松江中', 'マツエナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市松江西', '30', '30201', '6408424', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '松江西', 'マツエニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市松江北', '30', '30201', '6408425', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '松江北', 'マツエキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市向', '30', '30201', '6408431', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '向', 'ムカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市土入', '30', '30201', '6408432', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '土入', 'ドウニュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市中野', '30', '30201', '6408433', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '中野', 'ナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市榎原', '30', '30201', '6408434', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '榎原', 'エノキハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市古屋', '30', '30201', '6408435', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '古屋', 'コヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市栄谷', '30', '30201', '6408441', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '栄谷', 'サカエダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市平井', '30', '30201', '6408442', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '平井', 'ヒライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市延時', '30', '30201', '6408443', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '延時', 'ノブトキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市次郎丸', '30', '30201', '6408444', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '次郎丸', 'ジロマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市中', '30', '30201', '6408451', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '中', 'ナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市梅原', '30', '30201', '6408452', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '梅原', 'ウメハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市木ノ本', '30', '30201', '6408453', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '木ノ本', 'キノモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市船所', '30', '30201', '6408461', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '船所', 'フナドコロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市粟', '30', '30201', '6408462', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '粟', 'アワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市楠見中', '30', '30201', '6408463', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '楠見中', 'クスミナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市市小路', '30', '30201', '6408464', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '市小路', 'イチショウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市善明寺', '30', '30201', '6408471', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '善明寺', 'ゼンミョウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市大谷', '30', '30201', '6408472', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '大谷', 'オオタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市直川', '30', '30201', '6408481', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '直川', 'ノウガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市六十谷', '30', '30201', '6408482', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '六十谷', 'ムソタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市園部', '30', '30201', '6408483', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '園部', 'ソノベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南12条西', '01', '01101', '0640912', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南12条西', 'ミナミ12ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南13条西', '01', '01101', '0640913', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南13条西', 'ミナミ13ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南14条西', '01', '01101', '0640914', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南14条西', 'ミナミ14ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南15条西', '01', '01101', '0640915', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南15条西', 'ミナミ15ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南16条西', '01', '01101', '0640916', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南16条西', 'ミナミ16ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南17条西', '01', '01101', '0640917', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南17条西', 'ミナミ17ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南18条西', '01', '01101', '0640918', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南18条西', 'ミナミ18ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南19条西', '01', '01101', '0640919', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南19条西', 'ミナミ19ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南20条西', '01', '01101', '0640920', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南20条西', 'ミナミ20ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南21条西', '01', '01101', '0640921', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南21条西', 'ミナミ21ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南22条西', '01', '01101', '0640922', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南22条西', 'ミナミ22ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南23条西', '01', '01101', '0640923', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南23条西', 'ミナミ23ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南24条西', '01', '01101', '0640924', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南24条西', 'ミナミ24ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南25条西', '01', '01101', '0640925', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南25条西', 'ミナミ25ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南26条西', '01', '01101', '0640926', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南26条西', 'ミナミ26ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南27条西', '01', '01101', '0640927', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南27条西', 'ミナミ27ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南28条西', '01', '01101', '0640928', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南28条西', 'ミナミ28ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南29条西', '01', '01101', '0640929', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南29条西', 'ミナミ29ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区南30条西', '01', '01101', '0640930', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '南30条西', 'ミナミ30ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区中島公園', '01', '01101', '0640931', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '中島公園', 'ナカジマコウエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区旭ケ丘', '01', '01101', '0640941', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '旭ケ丘', 'アサヒガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区伏見', '01', '01101', '0640942', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '伏見', 'フシミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区界川', '01', '01101', '0640943', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '界川', 'サカイガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区円山西町', '01', '01101', '0640944', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '円山西町', 'マルヤマニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区盤渓', '01', '01101', '0640945', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '盤渓', 'バンケイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区双子山', '01', '01101', '0640946', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '双子山', 'フタゴヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区宮の森1条', '01', '01101', '0640951', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '宮の森1条', 'ミヤノモリ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区宮の森2条', '01', '01101', '0640952', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '宮の森2条', 'ミヤノモリ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区宮の森3条', '01', '01101', '0640953', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '宮の森3条', 'ミヤノモリ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区宮の森4条', '01', '01101', '0640954', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '宮の森4条', 'ミヤノモリ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区宮の森', '01', '01101', '0640958', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '宮の森', 'ミヤノモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市中央区宮ケ丘', '01', '01101', '0640959', '北海道', 'ホッカイドウ', '札幌市中央区', 'サッポロシチュウオウク', '宮ケ丘', 'ミヤガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市杭ノ瀬', '30', '30201', '6410001', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '杭ノ瀬', 'クイノセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市新中島', '30', '30201', '6410002', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '新中島', 'シンナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市坂田', '30', '30201', '6410003', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '坂田', 'サカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市和田', '30', '30201', '6410004', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '和田', 'ワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市田尻', '30', '30201', '6410005', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '田尻', 'タジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市中島', '30', '30201', '6410006', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '中島', 'ナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市小雑賀', '30', '30201', '6410007', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '小雑賀', 'コザイカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市北中島', '30', '30201', '6410008', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '北中島', 'キタナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市三葛', '30', '30201', '6410011', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '三葛', 'ミカズラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市紀三井寺', '30', '30201', '6410012', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '紀三井寺', 'キミイデラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市内原', '30', '30201', '6410013', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '内原', 'ウチハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市毛見', '30', '30201', '6410014', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '毛見', 'ケミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市布引', '30', '30201', '6410015', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '布引', 'ヌノヒキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市和歌浦東', '30', '30201', '6410021', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '和歌浦東', 'ワカウラヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市和歌浦南', '30', '30201', '6410022', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '和歌浦南', 'ワカウラミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市新和歌浦', '30', '30201', '6410023', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '新和歌浦', 'シンワカウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市和歌浦西', '30', '30201', '6410024', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '和歌浦西', 'ワカウラニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市和歌浦中', '30', '30201', '6410025', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '和歌浦中', 'ワカウラナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市西小二里', '30', '30201', '6410031', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '西小二里', 'ニシコニリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市東小二里町', '30', '30201', '6410032', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '東小二里町', 'ヒガシコニリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市松ケ丘', '30', '30201', '6410033', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '松ケ丘', 'マツガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市新高町', '30', '30201', '6410034', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '新高町', 'ニイタカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市関戸', '30', '30201', '6410035', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '関戸', 'セキド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市西浜', '30', '30201', '6410036', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '西浜', 'ニシハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市堀止南ノ丁', '30', '30201', '6410041', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '堀止南ノ丁', 'ホリドメミナミノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市新堀東', '30', '30201', '6410042', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '新堀東', 'シンボリヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市宇須', '30', '30201', '6410043', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '宇須', 'ウズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市今福', '30', '30201', '6410044', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '今福', 'イマブク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市堀止西', '30', '30201', '6410045', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '堀止西', 'ホリドメニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市西高松', '30', '30201', '6410051', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '西高松', 'ニシタカマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市東高松', '30', '30201', '6410052', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '東高松', 'ヒガシタカマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市打越町', '30', '30201', '6410053', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '打越町', 'ウチコシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市塩屋', '30', '30201', '6410054', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '塩屋', 'シオヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市和歌川町', '30', '30201', '6410055', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '和歌川町', 'ワカガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市秋葉町', '30', '30201', '6410056', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '秋葉町', 'アキバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市田野', '30', '30201', '6410061', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '田野', 'タノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市雑賀崎', '30', '30201', '6410062', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '雑賀崎', 'サイカザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海南市', '30', '30202', '6420000', '和歌山県', 'ワカヤマケン', '海南市', 'カイナンシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('75867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海南市船尾', '30', '30202', '6420001', '和歌山県', 'ワカヤマケン', '海南市', 'カイナンシ', '船尾', 'フノオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海南市日方', '30', '30202', '6420002', '和歌山県', 'ワカヤマケン', '海南市', 'カイナンシ', '日方', 'ヒカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海南市山崎町', '30', '30202', '6420003', '和歌山県', 'ワカヤマケン', '海南市', 'カイナンシ', '山崎町', 'ヤマサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海南市馬場町', '30', '30202', '6420004', '和歌山県', 'ワカヤマケン', '海南市', 'カイナンシ', '馬場町', 'ババチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海南市黒江', '30', '30202', '6420011', '和歌山県', 'ワカヤマケン', '海南市', 'カイナンシ', '黒江', 'クロエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海南市岡田', '30', '30202', '6420012', '和歌山県', 'ワカヤマケン', '海南市', 'カイナンシ', '岡田', 'オカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海南市多田', '30', '30202', '6420013', '和歌山県', 'ワカヤマケン', '海南市', 'カイナンシ', '多田', 'オオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海南市小野田', '30', '30202', '6420014', '和歌山県', 'ワカヤマケン', '海南市', 'カイナンシ', '小野田', 'オノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海南市且来', '30', '30202', '6420015', '和歌山県', 'ワカヤマケン', '海南市', 'カイナンシ', '且来', 'アッソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海南市北赤坂', '30', '30202', '6420016', '和歌山県', 'ワカヤマケン', '海南市', 'カイナンシ', '北赤坂', 'キタアカサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海南市南赤坂', '30', '30202', '6420017', '和歌山県', 'ワカヤマケン', '海南市', 'カイナンシ', '南赤坂', 'ミナミアカサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海南市井田', '30', '30202', '6420021', '和歌山県', 'ワカヤマケン', '海南市', 'カイナンシ', '井田', 'イダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海南市大野中', '30', '30202', '6420022', '和歌山県', 'ワカヤマケン', '海南市', 'カイナンシ', '大野中', 'オオノナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海南市重根', '30', '30202', '6420023', '和歌山県', 'ワカヤマケン', '海南市', 'カイナンシ', '重根', 'シコネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海南市阪井', '30', '30202', '6420024', '和歌山県', 'ワカヤマケン', '海南市', 'カイナンシ', '阪井', 'サカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海南市東畑', '30', '30202', '6420025', '和歌山県', 'ワカヤマケン', '海南市', 'カイナンシ', '東畑', 'ヒガシバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海南市別所', '30', '30202', '6420026', '和歌山県', 'ワカヤマケン', '海南市', 'カイナンシ', '別所', 'ベッシヨ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海南市扱沢', '30', '30202', '6420027', '和歌山県', 'ワカヤマケン', '海南市', 'カイナンシ', '扱沢', 'グミザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海南市幡川', '30', '30202', '6420028', '和歌山県', 'ワカヤマケン', '海南市', 'カイナンシ', '幡川', 'ハタガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海南市山田', '30', '30202', '6420029', '和歌山県', 'ワカヤマケン', '海南市', 'カイナンシ', '山田', 'ヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海南市築地', '30', '30202', '6420031', '和歌山県', 'ワカヤマケン', '海南市', 'カイナンシ', '築地', 'ツキジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海南市名高', '30', '30202', '6420032', '和歌山県', 'ワカヤマケン', '海南市', 'カイナンシ', '名高', 'ナタカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海南市鳥居', '30', '30202', '6420033', '和歌山県', 'ワカヤマケン', '海南市', 'カイナンシ', '鳥居', 'トリイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海南市藤白', '30', '30202', '6420034', '和歌山県', 'ワカヤマケン', '海南市', 'カイナンシ', '藤白', 'フジシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海南市冷水', '30', '30202', '6420035', '和歌山県', 'ワカヤマケン', '海南市', 'カイナンシ', '冷水', 'シミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡湯浅町', '30', '30361', '6430000', '和歌山県', 'ワカヤマケン', '有田郡湯浅町', 'アリダグンユアサチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('75894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡広川町', '30', '30362', '6430000', '和歌山県', 'ワカヤマケン', '有田郡広川町', 'アリダグンヒロガワチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('75895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡有田川町', '30', '30366', '6430000', '和歌山県', 'ワカヤマケン', '有田郡有田川町', 'アリダグンアリダガワチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('75896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡湯浅町山田', '30', '30361', '6430001', '和歌山県', 'ワカヤマケン', '有田郡湯浅町', 'アリダグンユアサチョウ', '山田', 'ヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡湯浅町青木', '30', '30361', '6430002', '和歌山県', 'ワカヤマケン', '有田郡湯浅町', 'アリダグンユアサチョウ', '青木', 'アオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡湯浅町別所', '30', '30361', '6430003', '和歌山県', 'ワカヤマケン', '有田郡湯浅町', 'アリダグンユアサチョウ', '別所', 'ベッシヨ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡湯浅町湯浅', '30', '30361', '6430004', '和歌山県', 'ワカヤマケン', '有田郡湯浅町', 'アリダグンユアサチョウ', '湯浅', 'ユアサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡湯浅町栖原', '30', '30361', '6430005', '和歌山県', 'ワカヤマケン', '有田郡湯浅町', 'アリダグンユアサチョウ', '栖原', 'スハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡湯浅町田', '30', '30361', '6430006', '和歌山県', 'ワカヤマケン', '有田郡湯浅町', 'アリダグンユアサチョウ', '田', 'タ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡湯浅町吉川', '30', '30361', '6430007', '和歌山県', 'ワカヤマケン', '有田郡湯浅町', 'アリダグンユアサチョウ', '吉川', 'ヨシカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡有田川町下津野', '30', '30366', '6430021', '和歌山県', 'ワカヤマケン', '有田郡有田川町', 'アリダグンアリダガワチョウ', '下津野', 'シモツノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡有田川町奥', '30', '30366', '6430022', '和歌山県', 'ワカヤマケン', '有田郡有田川町', 'アリダグンアリダガワチョウ', '奥', 'オキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡有田川町熊井', '30', '30366', '6430023', '和歌山県', 'ワカヤマケン', '有田郡有田川町', 'アリダグンアリダガワチョウ', '熊井', 'クマイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡有田川町水尻', '30', '30366', '6430024', '和歌山県', 'ワカヤマケン', '有田郡有田川町', 'アリダグンアリダガワチョウ', '水尻', 'ミズシリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡有田川町土生', '30', '30366', '6430025', '和歌山県', 'ワカヤマケン', '有田郡有田川町', 'アリダグンアリダガワチョウ', '土生', 'ハブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡有田川町植野', '30', '30366', '6430026', '和歌山県', 'ワカヤマケン', '有田郡有田川町', 'アリダグンアリダガワチョウ', '植野', 'ウエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡有田川町野田', '30', '30366', '6430031', '和歌山県', 'ワカヤマケン', '有田郡有田川町', 'アリダグンアリダガワチョウ', '野田', 'ノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡有田川町天満', '30', '30366', '6430032', '和歌山県', 'ワカヤマケン', '有田郡有田川町', 'アリダグンアリダガワチョウ', '天満', 'テンマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡有田川町明王寺', '30', '30366', '6430033', '和歌山県', 'ワカヤマケン', '有田郡有田川町', 'アリダグンアリダガワチョウ', '明王寺', 'ミョウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡有田川町小島', '30', '30366', '6430034', '和歌山県', 'ワカヤマケン', '有田郡有田川町', 'アリダグンアリダガワチョウ', '小島', 'オシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡広川町下津木', '30', '30362', '6430051', '和歌山県', 'ワカヤマケン', '有田郡広川町', 'アリダグンヒロガワチョウ', '下津木', 'シモツギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡広川町上津木', '30', '30362', '6430052', '和歌山県', 'ワカヤマケン', '有田郡広川町', 'アリダグンヒロガワチョウ', '上津木', 'カミツギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡広川町河瀬', '30', '30362', '6430053', '和歌山県', 'ワカヤマケン', '有田郡広川町', 'アリダグンヒロガワチョウ', '河瀬', 'ゴノセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡広川町前田', '30', '30362', '6430054', '和歌山県', 'ワカヤマケン', '有田郡広川町', 'アリダグンヒロガワチョウ', '前田', 'マエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡広川町井関', '30', '30362', '6430055', '和歌山県', 'ワカヤマケン', '有田郡広川町', 'アリダグンヒロガワチョウ', '井関', 'イセキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡広川町柳瀬', '30', '30362', '6430061', '和歌山県', 'ワカヤマケン', '有田郡広川町', 'アリダグンヒロガワチョウ', '柳瀬', 'ヤナセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡広川町殿', '30', '30362', '6430062', '和歌山県', 'ワカヤマケン', '有田郡広川町', 'アリダグンヒロガワチョウ', '殿', 'トノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡広川町南金屋', '30', '30362', '6430063', '和歌山県', 'ワカヤマケン', '有田郡広川町', 'アリダグンヒロガワチョウ', '南金屋', 'ミナミカナヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡広川町上中野', '30', '30362', '6430064', '和歌山県', 'ワカヤマケン', '有田郡広川町', 'アリダグンヒロガワチョウ', '上中野', 'カミナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡広川町東中', '30', '30362', '6430065', '和歌山県', 'ワカヤマケン', '有田郡広川町', 'アリダグンヒロガワチョウ', '東中', 'ヒガシナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡広川町名島', '30', '30362', '6430066', '和歌山県', 'ワカヤマケン', '有田郡広川町', 'アリダグンヒロガワチョウ', '名島', 'ナシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡広川町広', '30', '30362', '6430071', '和歌山県', 'ワカヤマケン', '有田郡広川町', 'アリダグンヒロガワチョウ', '広', 'ヒロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡広川町山本', '30', '30362', '6430072', '和歌山県', 'ワカヤマケン', '有田郡広川町', 'アリダグンヒロガワチョウ', '山本', 'ヤマモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡広川町唐尾', '30', '30362', '6430073', '和歌山県', 'ワカヤマケン', '有田郡広川町', 'アリダグンヒロガワチョウ', '唐尾', 'カロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡広川町西広', '30', '30362', '6430074', '和歌山県', 'ワカヤマケン', '有田郡広川町', 'アリダグンヒロガワチョウ', '西広', 'ニシヒロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡広川町和田', '30', '30362', '6430075', '和歌山県', 'ワカヤマケン', '有田郡広川町', 'アリダグンヒロガワチョウ', '和田', 'ワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡有田川町彦ケ瀬', '30', '30366', '6430121', '和歌山県', 'ワカヤマケン', '有田郡有田川町', 'アリダグンアリダガワチョウ', '彦ケ瀬', 'ヒコガセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡有田川町瀬井', '30', '30366', '6430122', '和歌山県', 'ワカヤマケン', '有田郡有田川町', 'アリダグンアリダガワチョウ', '瀬井', 'セイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡有田川町中', '30', '30366', '6430123', '和歌山県', 'ワカヤマケン', '有田郡有田川町', 'アリダグンアリダガワチョウ', '中', 'ナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡有田川町中峯', '30', '30366', '6430124', '和歌山県', 'ワカヤマケン', '有田郡有田川町', 'アリダグンアリダガワチョウ', '中峯', 'ナカミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡有田川町沼田', '30', '30366', '6430125', '和歌山県', 'ワカヤマケン', '有田郡有田川町', 'アリダグンアリダガワチョウ', '沼田', 'ヌタダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡有田川町本堂', '30', '30366', '6430126', '和歌山県', 'ワカヤマケン', '有田郡有田川町', 'アリダグンアリダガワチョウ', '本堂', 'ホンドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡有田川町有原', '30', '30366', '6430127', '和歌山県', 'ワカヤマケン', '有田郡有田川町', 'アリダグンアリダガワチョウ', '有原', 'アリハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡有田川町西ケ峯', '30', '30366', '6430128', '和歌山県', 'ワカヤマケン', '有田郡有田川町', 'アリダグンアリダガワチョウ', '西ケ峯', 'ニシガミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡有田川町畦田', '30', '30366', '6430129', '和歌山県', 'ワカヤマケン', '有田郡有田川町', 'アリダグンアリダガワチョウ', '畦田', 'アゼタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡有田川町生石', '30', '30366', '6430131', '和歌山県', 'ワカヤマケン', '有田郡有田川町', 'アリダグンアリダガワチョウ', '生石', 'オイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡有田川町小原', '30', '30366', '6430132', '和歌山県', 'ワカヤマケン', '有田郡有田川町', 'アリダグンアリダガワチョウ', '小原', 'オハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡有田川町尾上', '30', '30366', '6430133', '和歌山県', 'ワカヤマケン', '有田郡有田川町', 'アリダグンアリダガワチョウ', '尾上', 'オノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡有田川町大薗', '30', '30366', '6430134', '和歌山県', 'ワカヤマケン', '有田郡有田川町', 'アリダグンアリダガワチョウ', '大薗', 'オオソノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡有田川町大西', '30', '30366', '6430135', '和歌山県', 'ワカヤマケン', '有田郡有田川町', 'アリダグンアリダガワチョウ', '大西', 'オオニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡有田川町青田', '30', '30366', '6430136', '和歌山県', 'ワカヤマケン', '有田郡有田川町', 'アリダグンアリダガワチョウ', '青田', 'アオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡有田川町延坂', '30', '30366', '6430137', '和歌山県', 'ワカヤマケン', '有田郡有田川町', 'アリダグンアリダガワチョウ', '延坂', 'ノブサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡有田川町伏羊', '30', '30366', '6430141', '和歌山県', 'ワカヤマケン', '有田郡有田川町', 'アリダグンアリダガワチョウ', '伏羊', 'ブヨウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡有田川町小川', '30', '30366', '6430142', '和歌山県', 'ワカヤマケン', '有田郡有田川町', 'アリダグンアリダガワチョウ', '小川', 'オガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡有田川町中野', '30', '30366', '6430143', '和歌山県', 'ワカヤマケン', '有田郡有田川町', 'アリダグンアリダガワチョウ', '中野', 'ナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡有田川町市場', '30', '30366', '6430144', '和歌山県', 'ワカヤマケン', '有田郡有田川町', 'アリダグンアリダガワチョウ', '市場', 'イチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡有田川町長谷川', '30', '30366', '6430151', '和歌山県', 'ワカヤマケン', '有田郡有田川町', 'アリダグンアリダガワチョウ', '長谷川', 'ハセガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡有田川町金屋', '30', '30366', '6430152', '和歌山県', 'ワカヤマケン', '有田郡有田川町', 'アリダグンアリダガワチョウ', '金屋', 'カナヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡有田川町中井原', '30', '30366', '6430153', '和歌山県', 'ワカヤマケン', '有田郡有田川町', 'アリダグンアリダガワチョウ', '中井原', 'ナカイバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡有田川町歓喜寺', '30', '30366', '6430161', '和歌山県', 'ワカヤマケン', '有田郡有田川町', 'アリダグンアリダガワチョウ', '歓喜寺', 'カンギジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡有田川町松原', '30', '30366', '6430162', '和歌山県', 'ワカヤマケン', '有田郡有田川町', 'アリダグンアリダガワチョウ', '松原', 'マツバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡有田川町修理川', '30', '30366', '6430163', '和歌山県', 'ワカヤマケン', '有田郡有田川町', 'アリダグンアリダガワチョウ', '修理川', 'スリガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡有田川町宇井苔', '30', '30366', '6430164', '和歌山県', 'ワカヤマケン', '有田郡有田川町', 'アリダグンアリダガワチョウ', '宇井苔', 'ウイゴケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡有田川町糸川', '30', '30366', '6430165', '和歌山県', 'ワカヤマケン', '有田郡有田川町', 'アリダグンアリダガワチョウ', '糸川', 'イトガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡有田川町吉原', '30', '30366', '6430166', '和歌山県', 'ワカヤマケン', '有田郡有田川町', 'アリダグンアリダガワチョウ', '吉原', 'ヨシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡有田川町上六川', '30', '30366', '6430171', '和歌山県', 'ワカヤマケン', '有田郡有田川町', 'アリダグンアリダガワチョウ', '上六川', 'カミムツガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡有田川町黒松', '30', '30366', '6430172', '和歌山県', 'ワカヤマケン', '有田郡有田川町', 'アリダグンアリダガワチョウ', '黒松', 'クロマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡有田川町下六川', '30', '30366', '6430173', '和歌山県', 'ワカヤマケン', '有田郡有田川町', 'アリダグンアリダガワチョウ', '下六川', 'シモムツガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡有田川町糸野', '30', '30366', '6430174', '和歌山県', 'ワカヤマケン', '有田郡有田川町', 'アリダグンアリダガワチョウ', '糸野', 'イトノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡有田川町丹生', '30', '30366', '6430175', '和歌山県', 'ワカヤマケン', '有田郡有田川町', 'アリダグンアリダガワチョウ', '丹生', 'ニウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡有田川町釜中', '30', '30366', '6430176', '和歌山県', 'ワカヤマケン', '有田郡有田川町', 'アリダグンアリダガワチョウ', '釜中', 'カマナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡有田川町谷', '30', '30366', '6430311', '和歌山県', 'ワカヤマケン', '有田郡有田川町', 'アリダグンアリダガワチョウ', '谷', 'タニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡有田川町岩野河', '30', '30366', '6430312', '和歌山県', 'ワカヤマケン', '有田郡有田川町', 'アリダグンアリダガワチョウ', '岩野河', 'イワノガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡有田川町川口', '30', '30366', '6430313', '和歌山県', 'ワカヤマケン', '有田郡有田川町', 'アリダグンアリダガワチョウ', '川口', 'カワグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡有田川町立石', '30', '30366', '6430314', '和歌山県', 'ワカヤマケン', '有田郡有田川町', 'アリダグンアリダガワチョウ', '立石', 'タテイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡有田川町三瀬川', '30', '30366', '6430361', '和歌山県', 'ワカヤマケン', '有田郡有田川町', 'アリダグンアリダガワチョウ', '三瀬川', 'ミセガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡有田川町北野川', '30', '30366', '6430362', '和歌山県', 'ワカヤマケン', '有田郡有田川町', 'アリダグンアリダガワチョウ', '北野川', 'キタノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡有田川町二沢', '30', '30366', '6430363', '和歌山県', 'ワカヤマケン', '有田郡有田川町', 'アリダグンアリダガワチョウ', '二沢', 'ニサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡有田川町川合', '30', '30366', '6430364', '和歌山県', 'ワカヤマケン', '有田郡有田川町', 'アリダグンアリダガワチョウ', '川合', 'カワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡有田川町中原', '30', '30366', '6430365', '和歌山県', 'ワカヤマケン', '有田郡有田川町', 'アリダグンアリダガワチョウ', '中原', 'ナカハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡有田川町粟生', '30', '30366', '6430366', '和歌山県', 'ワカヤマケン', '有田郡有田川町', 'アリダグンアリダガワチョウ', '粟生', 'アオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡有田川町三田', '30', '30366', '6430511', '和歌山県', 'ワカヤマケン', '有田郡有田川町', 'アリダグンアリダガワチョウ', '三田', 'ミタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡有田川町宮川', '30', '30366', '6430512', '和歌山県', 'ワカヤマケン', '有田郡有田川町', 'アリダグンアリダガワチョウ', '宮川', 'ミヤガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡有田川町大蔵', '30', '30366', '6430513', '和歌山県', 'ワカヤマケン', '有田郡有田川町', 'アリダグンアリダガワチョウ', '大蔵', 'オオゾウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡有田川町久野原', '30', '30366', '6430514', '和歌山県', 'ワカヤマケン', '有田郡有田川町', 'アリダグンアリダガワチョウ', '久野原', 'クノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡有田川町室川', '30', '30366', '6430515', '和歌山県', 'ワカヤマケン', '有田郡有田川町', 'アリダグンアリダガワチョウ', '室川', 'ムロガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡有田川町清水', '30', '30366', '6430521', '和歌山県', 'ワカヤマケン', '有田郡有田川町', 'アリダグンアリダガワチョウ', '清水', 'シミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡有田川町下湯川', '30', '30366', '6430522', '和歌山県', 'ワカヤマケン', '有田郡有田川町', 'アリダグンアリダガワチョウ', '下湯川', 'シモユカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡有田川町楠本', '30', '30366', '6430531', '和歌山県', 'ワカヤマケン', '有田郡有田川町', 'アリダグンアリダガワチョウ', '楠本', 'クスモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡有田川町沼', '30', '30366', '6430532', '和歌山県', 'ワカヤマケン', '有田郡有田川町', 'アリダグンアリダガワチョウ', '沼', 'ヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡有田川町遠井', '30', '30366', '6430533', '和歌山県', 'ワカヤマケン', '有田郡有田川町', 'アリダグンアリダガワチョウ', '遠井', 'トイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡有田川町東大谷', '30', '30366', '6430541', '和歌山県', 'ワカヤマケン', '有田郡有田川町', 'アリダグンアリダガワチョウ', '東大谷', 'ヒガシオオダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡有田川町二川', '30', '30366', '6430542', '和歌山県', 'ワカヤマケン', '有田郡有田川町', 'アリダグンアリダガワチョウ', '二川', 'フタガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡有田川町日物川', '30', '30366', '6430543', '和歌山県', 'ワカヤマケン', '有田郡有田川町', 'アリダグンアリダガワチョウ', '日物川', 'ヒモノガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡有田川町境川', '30', '30366', '6430544', '和歌山県', 'ワカヤマケン', '有田郡有田川町', 'アリダグンアリダガワチョウ', '境川', 'サカイガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡有田川町上湯川', '30', '30366', '6430551', '和歌山県', 'ワカヤマケン', '有田郡有田川町', 'アリダグンアリダガワチョウ', '上湯川', 'カミユカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡有田川町押手', '30', '30366', '6430601', '和歌山県', 'ワカヤマケン', '有田郡有田川町', 'アリダグンアリダガワチョウ', '押手', 'オシテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡有田川町杉野原', '30', '30366', '6430602', '和歌山県', 'ワカヤマケン', '有田郡有田川町', 'アリダグンアリダガワチョウ', '杉野原', 'スギノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡有田川町板尾', '30', '30366', '6430603', '和歌山県', 'ワカヤマケン', '有田郡有田川町', 'アリダグンアリダガワチョウ', '板尾', 'イタオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡有田川町井谷', '30', '30366', '6430604', '和歌山県', 'ワカヤマケン', '有田郡有田川町', 'アリダグンアリダガワチョウ', '井谷', 'イダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡有田川町沼谷', '30', '30366', '6430605', '和歌山県', 'ワカヤマケン', '有田郡有田川町', 'アリダグンアリダガワチョウ', '沼谷', 'ヌマタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県伊都郡かつらぎ町花園梁瀬', '30', '30341', '6430611', '和歌山県', 'ワカヤマケン', '伊都郡かつらぎ町', 'イトグンカツラギチョウ', '花園梁瀬', 'ハナゾノヤナセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県伊都郡かつらぎ町花園北寺', '30', '30341', '6430612', '和歌山県', 'ワカヤマケン', '伊都郡かつらぎ町', 'イトグンカツラギチョウ', '花園北寺', 'ハナゾノキタデラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県伊都郡かつらぎ町花園池ノ窪', '30', '30341', '6430613', '和歌山県', 'ワカヤマケン', '伊都郡かつらぎ町', 'イトグンカツラギチョウ', '花園池ノ窪', 'ハナゾノイケノクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県伊都郡かつらぎ町花園新子', '30', '30341', '6430614', '和歌山県', 'ワカヤマケン', '伊都郡かつらぎ町', 'イトグンカツラギチョウ', '花園新子', 'ハナゾノアタラシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡有田川町徳田', '30', '30366', '6430801', '和歌山県', 'ワカヤマケン', '有田郡有田川町', 'アリダグンアリダガワチョウ', '徳田', 'トクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('75999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡有田川町吉見', '30', '30366', '6430802', '和歌山県', 'ワカヤマケン', '有田郡有田川町', 'アリダグンアリダガワチョウ', '吉見', 'ヨシミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡有田川町東丹生図', '30', '30366', '6430803', '和歌山県', 'ワカヤマケン', '有田郡有田川町', 'アリダグンアリダガワチョウ', '東丹生図', 'ヒガシニュウノズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡有田川町庄', '30', '30366', '6430811', '和歌山県', 'ワカヤマケン', '有田郡有田川町', 'アリダグンアリダガワチョウ', '庄', 'ショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡有田川町垣倉', '30', '30366', '6430812', '和歌山県', 'ワカヤマケン', '有田郡有田川町', 'アリダグンアリダガワチョウ', '垣倉', 'カイグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡有田川町西丹生図', '30', '30366', '6430813', '和歌山県', 'ワカヤマケン', '有田郡有田川町', 'アリダグンアリダガワチョウ', '西丹生図', 'ニシニュウノズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡有田川町長谷', '30', '30366', '6430841', '和歌山県', 'ワカヤマケン', '有田郡有田川町', 'アリダグンアリダガワチョウ', '長谷', 'ナガタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡有田川町船坂', '30', '30366', '6430842', '和歌山県', 'ワカヤマケン', '有田郡有田川町', 'アリダグンアリダガワチョウ', '船坂', 'フナサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡有田川町賢', '30', '30366', '6430843', '和歌山県', 'ワカヤマケン', '有田郡有田川町', 'アリダグンアリダガワチョウ', '賢', 'カシコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡有田川町井口', '30', '30366', '6430844', '和歌山県', 'ワカヤマケン', '有田郡有田川町', 'アリダグンアリダガワチョウ', '井口', 'イノクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡有田川町大谷', '30', '30366', '6430845', '和歌山県', 'ワカヤマケン', '有田郡有田川町', 'アリダグンアリダガワチョウ', '大谷', 'オオタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡有田川町田口', '30', '30366', '6430846', '和歌山県', 'ワカヤマケン', '有田郡有田川町', 'アリダグンアリダガワチョウ', '田口', 'タグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡有田川町大賀畑', '30', '30366', '6430847', '和歌山県', 'ワカヤマケン', '有田郡有田川町', 'アリダグンアリダガワチョウ', '大賀畑', 'オオカハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡有田川町田角', '30', '30366', '6430848', '和歌山県', 'ワカヤマケン', '有田郡有田川町', 'アリダグンアリダガワチョウ', '田角', 'タズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡有田川町出', '30', '30366', '6430851', '和歌山県', 'ワカヤマケン', '有田郡有田川町', 'アリダグンアリダガワチョウ', '出', 'イデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡有田川町尾中', '30', '30366', '6430852', '和歌山県', 'ワカヤマケン', '有田郡有田川町', 'アリダグンアリダガワチョウ', '尾中', 'オナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡有田川町角', '30', '30366', '6430853', '和歌山県', 'ワカヤマケン', '有田郡有田川町', 'アリダグンアリダガワチョウ', '角', 'スミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡有田川町長田', '30', '30366', '6430854', '和歌山県', 'ワカヤマケン', '有田郡有田川町', 'アリダグンアリダガワチョウ', '長田', 'ナガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田郡有田川町上中島', '30', '30366', '6430855', '和歌山県', 'ワカヤマケン', '有田郡有田川町', 'アリダグンアリダガワチョウ', '上中島', 'カミナカシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県御坊市', '30', '30205', '6440000', '和歌山県', 'ワカヤマケン', '御坊市', 'ゴボウシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('76018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡美浜町', '30', '30381', '6440000', '和歌山県', 'ワカヤマケン', '日高郡美浜町', 'ヒダカグンミハマチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('76019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県御坊市御坊', '30', '30205', '6440001', '和歌山県', 'ワカヤマケン', '御坊市', 'ゴボウシ', '御坊', 'ゴボウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県御坊市薗', '30', '30205', '6440002', '和歌山県', 'ワカヤマケン', '御坊市', 'ゴボウシ', '薗', 'ソノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県御坊市島', '30', '30205', '6440003', '和歌山県', 'ワカヤマケン', '御坊市', 'ゴボウシ', '島', 'シマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県御坊市名屋', '30', '30205', '6440004', '和歌山県', 'ワカヤマケン', '御坊市', 'ゴボウシ', '名屋', 'ナヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県御坊市名屋町', '30', '30205', '6440005', '和歌山県', 'ワカヤマケン', '御坊市', 'ゴボウシ', '名屋町', 'ナヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県御坊市湯川町財部', '30', '30205', '6440011', '和歌山県', 'ワカヤマケン', '御坊市', 'ゴボウシ', '湯川町財部', 'ユカワチョウタカラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県御坊市湯川町小松原', '30', '30205', '6440012', '和歌山県', 'ワカヤマケン', '御坊市', 'ゴボウシ', '湯川町小松原', 'ユカワチョウコマツバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県御坊市湯川町丸山', '30', '30205', '6440013', '和歌山県', 'ワカヤマケン', '御坊市', 'ゴボウシ', '湯川町丸山', 'ユカワチョウマルヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県御坊市湯川町富安', '30', '30205', '6440014', '和歌山県', 'ワカヤマケン', '御坊市', 'ゴボウシ', '湯川町富安', 'ユカワチョウトミヤス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県御坊市荊木', '30', '30205', '6440015', '和歌山県', 'ワカヤマケン', '御坊市', 'ゴボウシ', '荊木', 'イバラキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県御坊市名田町楠井', '30', '30205', '6440021', '和歌山県', 'ワカヤマケン', '御坊市', 'ゴボウシ', '名田町楠井', 'ナダチョウクスイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県御坊市名田町上野', '30', '30205', '6440022', '和歌山県', 'ワカヤマケン', '御坊市', 'ゴボウシ', '名田町上野', 'ナダチョウウエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県御坊市名田町野島', '30', '30205', '6440023', '和歌山県', 'ワカヤマケン', '御坊市', 'ゴボウシ', '名田町野島', 'ナダチョウノシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県御坊市塩屋町南塩屋', '30', '30205', '6440024', '和歌山県', 'ワカヤマケン', '御坊市', 'ゴボウシ', '塩屋町南塩屋', 'シオヤチョウミナミシオヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県御坊市塩屋町北塩屋', '30', '30205', '6440025', '和歌山県', 'ワカヤマケン', '御坊市', 'ゴボウシ', '塩屋町北塩屋', 'シオヤチョウキタシオヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県御坊市野口', '30', '30205', '6440031', '和歌山県', 'ワカヤマケン', '御坊市', 'ゴボウシ', '野口', 'ノグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県御坊市岩内', '30', '30205', '6440032', '和歌山県', 'ワカヤマケン', '御坊市', 'ゴボウシ', '岩内', 'イワウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県御坊市熊野', '30', '30205', '6440033', '和歌山県', 'ワカヤマケン', '御坊市', 'ゴボウシ', '熊野', 'イヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県御坊市明神川', '30', '30205', '6440034', '和歌山県', 'ワカヤマケン', '御坊市', 'ゴボウシ', '明神川', 'ミョウジンガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡美浜町田井', '30', '30381', '6440041', '和歌山県', 'ワカヤマケン', '日高郡美浜町', 'ヒダカグンミハマチョウ', '田井', 'タイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡美浜町浜ノ瀬', '30', '30381', '6440042', '和歌山県', 'ワカヤマケン', '日高郡美浜町', 'ヒダカグンミハマチョウ', '浜ノ瀬', 'ハマノセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡美浜町吉原', '30', '30381', '6440043', '和歌山県', 'ワカヤマケン', '日高郡美浜町', 'ヒダカグンミハマチョウ', '吉原', 'ヨシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡美浜町和田', '30', '30381', '6440044', '和歌山県', 'ワカヤマケン', '日高郡美浜町', 'ヒダカグンミハマチョウ', '和田', 'ワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡美浜町三尾', '30', '30381', '6440045', '和歌山県', 'ワカヤマケン', '日高郡美浜町', 'ヒダカグンミハマチョウ', '三尾', 'ミオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡印南町川又', '30', '30390', '6440201', '和歌山県', 'ワカヤマケン', '日高郡印南町', 'ヒダカグンイナミチョウ', '川又', 'カワマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡印南町上洞', '30', '30390', '6440202', '和歌山県', 'ワカヤマケン', '日高郡印南町', 'ヒダカグンイナミチョウ', '上洞', 'カボラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡印南町高串', '30', '30390', '6440211', '和歌山県', 'ワカヤマケン', '日高郡印南町', 'ヒダカグンイナミチョウ', '高串', 'タカクシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡印南町田ノ垣内', '30', '30390', '6440212', '和歌山県', 'ワカヤマケン', '日高郡印南町', 'ヒダカグンイナミチョウ', '田ノ垣内', 'タノカイト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡印南町西神ノ川', '30', '30390', '6440213', '和歌山県', 'ワカヤマケン', '日高郡印南町', 'ヒダカグンイナミチョウ', '西神ノ川', 'ニシコウノガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡印南町小原', '30', '30390', '6440214', '和歌山県', 'ワカヤマケン', '日高郡印南町', 'ヒダカグンイナミチョウ', '小原', 'コバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡印南町皆瀬川', '30', '30390', '6440215', '和歌山県', 'ワカヤマケン', '日高郡印南町', 'ヒダカグンイナミチョウ', '皆瀬川', 'カイゼガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡印南町崎ノ原', '30', '30390', '6440216', '和歌山県', 'ワカヤマケン', '日高郡印南町', 'ヒダカグンイナミチョウ', '崎ノ原', 'サキノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡印南町丹生', '30', '30390', '6440217', '和歌山県', 'ワカヤマケン', '日高郡印南町', 'ヒダカグンイナミチョウ', '丹生', 'ニュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡印南町松原', '30', '30390', '6440218', '和歌山県', 'ワカヤマケン', '日高郡印南町', 'ヒダカグンイナミチョウ', '松原', 'マツバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡日高川町藤野川', '30', '30392', '6441101', '和歌山県', 'ワカヤマケン', '日高郡日高川町', 'ヒダカグンヒダカガワチョウ', '藤野川', 'トウノガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡日高川町船津', '30', '30392', '6441111', '和歌山県', 'ワカヤマケン', '日高郡日高川町', 'ヒダカグンヒダカガワチョウ', '船津', 'フナツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡日高川町西原', '30', '30392', '6441121', '和歌山県', 'ワカヤマケン', '日高郡日高川町', 'ヒダカグンヒダカガワチョウ', '西原', 'ニシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡日高川町高津尾', '30', '30392', '6441122', '和歌山県', 'ワカヤマケン', '日高郡日高川町', 'ヒダカグンヒダカガワチョウ', '高津尾', 'タカツオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡日高川町高津尾川', '30', '30392', '6441123', '和歌山県', 'ワカヤマケン', '日高郡日高川町', 'ヒダカグンヒダカガワチョウ', '高津尾川', 'タカツオガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡日高川町三十井川', '30', '30392', '6441131', '和歌山県', 'ワカヤマケン', '日高郡日高川町', 'ヒダカグンヒダカガワチョウ', '三十井川', 'ミソイガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡日高川町姉子', '30', '30392', '6441132', '和歌山県', 'ワカヤマケン', '日高郡日高川町', 'ヒダカグンヒダカガワチョウ', '姉子', 'アネコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡日高川町原日浦', '30', '30392', '6441133', '和歌山県', 'ワカヤマケン', '日高郡日高川町', 'ヒダカグンヒダカガワチョウ', '原日浦', 'ハラビウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡日高川町三十木', '30', '30392', '6441134', '和歌山県', 'ワカヤマケン', '日高郡日高川町', 'ヒダカグンヒダカガワチョウ', '三十木', 'ミソギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡日高川町上田原', '30', '30392', '6441141', '和歌山県', 'ワカヤマケン', '日高郡日高川町', 'ヒダカグンヒダカガワチョウ', '上田原', 'カミタハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡日高川町下田原', '30', '30392', '6441142', '和歌山県', 'ワカヤマケン', '日高郡日高川町', 'ヒダカグンヒダカガワチョウ', '下田原', 'シモタハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡日高川町小釜本', '30', '30392', '6441143', '和歌山県', 'ワカヤマケン', '日高郡日高川町', 'ヒダカグンヒダカガワチョウ', '小釜本', 'コカモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡日高川町田尻', '30', '30392', '6441151', '和歌山県', 'ワカヤマケン', '日高郡日高川町', 'ヒダカグンヒダカガワチョウ', '田尻', 'タジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡日高川町三佐', '30', '30392', '6441152', '和歌山県', 'ワカヤマケン', '日高郡日高川町', 'ヒダカグンヒダカガワチョウ', '三佐', 'ミザ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡日高川町坂野川', '30', '30392', '6441161', '和歌山県', 'ワカヤマケン', '日高郡日高川町', 'ヒダカグンヒダカガワチョウ', '坂野川', 'サカノガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡日高川町老星', '30', '30392', '6441162', '和歌山県', 'ワカヤマケン', '日高郡日高川町', 'ヒダカグンヒダカガワチョウ', '老星', 'オイボシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡日高川町大又', '30', '30392', '6441163', '和歌山県', 'ワカヤマケン', '日高郡日高川町', 'ヒダカグンヒダカガワチョウ', '大又', 'オオマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡日高川町佐井', '30', '30392', '6441164', '和歌山県', 'ワカヤマケン', '日高郡日高川町', 'ヒダカグンヒダカガワチョウ', '佐井', 'サイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡日高川町川原河', '30', '30392', '6441201', '和歌山県', 'ワカヤマケン', '日高郡日高川町', 'ヒダカグンヒダカガワチョウ', '川原河', 'カワハラゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡日高川町弥谷', '30', '30392', '6441211', '和歌山県', 'ワカヤマケン', '日高郡日高川町', 'ヒダカグンヒダカガワチョウ', '弥谷', 'イヤダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡日高川町皆瀬', '30', '30392', '6441212', '和歌山県', 'ワカヤマケン', '日高郡日高川町', 'ヒダカグンヒダカガワチョウ', '皆瀬', 'カイゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡日高川町愛川', '30', '30392', '6441213', '和歌山県', 'ワカヤマケン', '日高郡日高川町', 'ヒダカグンヒダカガワチョウ', '愛川', 'アタイガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡日高川町上初湯川', '30', '30392', '6441214', '和歌山県', 'ワカヤマケン', '日高郡日高川町', 'ヒダカグンヒダカガワチョウ', '上初湯川', 'カミウブユガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡日高川町寒川', '30', '30392', '6441221', '和歌山県', 'ワカヤマケン', '日高郡日高川町', 'ヒダカグンヒダカガワチョウ', '寒川', 'ソウガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡日高川町串本', '30', '30392', '6441222', '和歌山県', 'ワカヤマケン', '日高郡日高川町', 'ヒダカグンヒダカガワチョウ', '串本', 'クシモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡日高川町初湯川', '30', '30392', '6441231', '和歌山県', 'ワカヤマケン', '日高郡日高川町', 'ヒダカグンヒダカガワチョウ', '初湯川', 'ウブユガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡日高川町滝頭', '30', '30392', '6441241', '和歌山県', 'ワカヤマケン', '日高郡日高川町', 'ヒダカグンヒダカガワチョウ', '滝頭', 'タキガシラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡日高川町熊野川', '30', '30392', '6441242', '和歌山県', 'ワカヤマケン', '日高郡日高川町', 'ヒダカグンヒダカガワチョウ', '熊野川', 'クマノガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡日高川町浅間', '30', '30392', '6441243', '和歌山県', 'ワカヤマケン', '日高郡日高川町', 'ヒダカグンヒダカガワチョウ', '浅間', 'アサマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡日高川町上越方', '30', '30392', '6441244', '和歌山県', 'ワカヤマケン', '日高郡日高川町', 'ヒダカグンヒダカガワチョウ', '上越方', 'カミコシカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡みなべ町', '30', '30391', '6450000', '和歌山県', 'ワカヤマケン', '日高郡みなべ町', 'ヒダカグンミナベチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('76087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡みなべ町東吉田', '30', '30391', '6450001', '和歌山県', 'ワカヤマケン', '日高郡みなべ町', 'ヒダカグンミナベチョウ', '東吉田', 'ヒガシヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡みなべ町芝', '30', '30391', '6450002', '和歌山県', 'ワカヤマケン', '日高郡みなべ町', 'ヒダカグンミナベチョウ', '芝', 'シバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡みなべ町堺', '30', '30391', '6450003', '和歌山県', 'ワカヤマケン', '日高郡みなべ町', 'ヒダカグンミナベチョウ', '堺', 'サカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡みなべ町埴田', '30', '30391', '6450004', '和歌山県', 'ワカヤマケン', '日高郡みなべ町', 'ヒダカグンミナベチョウ', '埴田', 'ハネタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡みなべ町南道', '30', '30391', '6450005', '和歌山県', 'ワカヤマケン', '日高郡みなべ町', 'ヒダカグンミナベチョウ', '南道', 'ミナミドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡みなべ町北道', '30', '30391', '6450006', '和歌山県', 'ワカヤマケン', '日高郡みなべ町', 'ヒダカグンミナベチョウ', '北道', 'キタドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡みなべ町気佐藤', '30', '30391', '6450011', '和歌山県', 'ワカヤマケン', '日高郡みなべ町', 'ヒダカグンミナベチョウ', '気佐藤', 'キサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡みなべ町山内', '30', '30391', '6450012', '和歌山県', 'ワカヤマケン', '日高郡みなべ町', 'ヒダカグンミナベチョウ', '山内', 'ヤマウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡みなべ町東岩代', '30', '30391', '6450013', '和歌山県', 'ワカヤマケン', '日高郡みなべ町', 'ヒダカグンミナベチョウ', '東岩代', 'ヒガシイワシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡みなべ町西岩代', '30', '30391', '6450014', '和歌山県', 'ワカヤマケン', '日高郡みなべ町', 'ヒダカグンミナベチョウ', '西岩代', 'ニシイワシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡みなべ町東本庄', '30', '30391', '6450021', '和歌山県', 'ワカヤマケン', '日高郡みなべ町', 'ヒダカグンミナベチョウ', '東本庄', 'ヒガシホンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡みなべ町晩稲', '30', '30391', '6450022', '和歌山県', 'ワカヤマケン', '日高郡みなべ町', 'ヒダカグンミナベチョウ', '晩稲', 'オシネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡みなべ町熊岡', '30', '30391', '6450023', '和歌山県', 'ワカヤマケン', '日高郡みなべ町', 'ヒダカグンミナベチョウ', '熊岡', 'クマオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡みなべ町徳蔵', '30', '30391', '6450024', '和歌山県', 'ワカヤマケン', '日高郡みなべ町', 'ヒダカグンミナベチョウ', '徳蔵', 'トクゾウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡みなべ町筋', '30', '30391', '6450025', '和歌山県', 'ワカヤマケン', '日高郡みなべ町', 'ヒダカグンミナベチョウ', '筋', 'スジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡みなべ町谷口', '30', '30391', '6450026', '和歌山県', 'ワカヤマケン', '日高郡みなべ町', 'ヒダカグンミナベチョウ', '谷口', 'タニグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡みなべ町西本庄', '30', '30391', '6450027', '和歌山県', 'ワカヤマケン', '日高郡みなべ町', 'ヒダカグンミナベチョウ', '西本庄', 'ニシホンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡みなべ町熊瀬川', '30', '30391', '6450028', '和歌山県', 'ワカヤマケン', '日高郡みなべ町', 'ヒダカグンミナベチョウ', '熊瀬川', 'クマセガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡みなべ町清川', '30', '30391', '6450201', '和歌山県', 'ワカヤマケン', '日高郡みなべ町', 'ヒダカグンミナベチョウ', '清川', 'キヨカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡みなべ町東神野川', '30', '30391', '6450202', '和歌山県', 'ワカヤマケン', '日高郡みなべ町', 'ヒダカグンミナベチョウ', '東神野川', 'ヒガシコウノガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡みなべ町島之瀬', '30', '30391', '6450203', '和歌山県', 'ワカヤマケン', '日高郡みなべ町', 'ヒダカグンミナベチョウ', '島之瀬', 'シマノセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡みなべ町広野', '30', '30391', '6450204', '和歌山県', 'ワカヤマケン', '日高郡みなべ町', 'ヒダカグンミナベチョウ', '広野', 'ヒロノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡みなべ町滝', '30', '30391', '6450205', '和歌山県', 'ワカヤマケン', '日高郡みなべ町', 'ヒダカグンミナベチョウ', '滝', 'タキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡みなべ町土井', '30', '30391', '6450206', '和歌山県', 'ワカヤマケン', '日高郡みなべ町', 'ヒダカグンミナベチョウ', '土井', 'ドイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡みなべ町高野', '30', '30391', '6450207', '和歌山県', 'ワカヤマケン', '日高郡みなべ町', 'ヒダカグンミナベチョウ', '高野', 'タカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡みなべ町市井川', '30', '30391', '6450208', '和歌山県', 'ワカヤマケン', '日高郡みなべ町', 'ヒダカグンミナベチョウ', '市井川', 'イチイガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市龍神村福井', '30', '30206', '6450301', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '龍神村福井', 'リュウジンムラフクイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市龍神村甲斐ノ川', '30', '30206', '6450302', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '龍神村甲斐ノ川', 'リュウジンムラカイノガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市龍神村小家', '30', '30206', '6450303', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '龍神村小家', 'リュウジンムラオイエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市龍神村宮代', '30', '30206', '6450411', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '龍神村宮代', 'リュウジンムラミヤシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市龍神村丹生ノ川', '30', '30206', '6450412', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '龍神村丹生ノ川', 'リュウジンムラニュウノガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市龍神村殿原', '30', '30206', '6450413', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '龍神村殿原', 'リュウジンムラトノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市龍神村東', '30', '30206', '6450414', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '龍神村東', 'リュウジンムラヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市龍神村西', '30', '30206', '6450415', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '龍神村西', 'リュウジンムラニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市龍神村安井', '30', '30206', '6450416', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '龍神村安井', 'リュウジンムラヤスイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市龍神村柳瀬', '30', '30206', '6450417', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '龍神村柳瀬', 'リュウジンムラヤナセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市龍神村小又川', '30', '30206', '6450521', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '龍神村小又川', 'リュウジンムラコマタガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市龍神村三ツ又', '30', '30206', '6450522', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '龍神村三ツ又', 'リュウジンムラミツマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市龍神村広井原', '30', '30206', '6450523', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '龍神村広井原', 'リュウジンムラヒロイハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市龍神村湯ノ又', '30', '30206', '6450524', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '龍神村湯ノ又', 'リュウジンムラユノマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市龍神村龍神', '30', '30206', '6450525', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '龍神村龍神', 'リュウジンムラリュウジン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡日高川町寒川小川', '30', '30392', '6450551', '和歌山県', 'ワカヤマケン', '日高郡日高川町', 'ヒダカグンヒダカガワチョウ', '寒川', 'ソウガワ', null, null, '小川', 'オガワ');
INSERT INTO `ms_addresses` VALUES ('76130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市', '30', '30206', '6460000', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('76131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市上秋津', '30', '30206', '6460001', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '上秋津', 'カミアキヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市上万呂', '30', '30206', '6460002', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '上万呂', 'カミマロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市中万呂', '30', '30206', '6460003', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '中万呂', 'ナカマロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市下万呂', '30', '30206', '6460004', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '下万呂', 'シモマロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市秋津町', '30', '30206', '6460005', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '秋津町', 'アキヅチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市新庄町', '30', '30206', '6460011', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '新庄町', 'シンジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市神島台', '30', '30206', '6460012', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '神島台', 'カシマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市南新万', '30', '30206', '6460013', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '南新万', 'ミナミシンマン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市新万', '30', '30206', '6460014', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '新万', 'シンマン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市たきない町', '30', '30206', '6460015', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', 'たきない町', 'タキナイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市あけぼの', '30', '30206', '6460021', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', 'あけぼの', 'アケボノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市東山', '30', '30206', '6460022', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '東山', 'ヒガシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市文里', '30', '30206', '6460023', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '文里', 'モリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市学園', '30', '30206', '6460024', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '学園', 'ガクエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市神子浜', '30', '30206', '6460025', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '神子浜', 'ミコノハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市宝来町', '30', '30206', '6460026', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '宝来町', 'ホウライチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市朝日ケ丘', '30', '30206', '6460027', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '朝日ケ丘', 'アサヒガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市湊', '30', '30206', '6460031', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '湊', 'ミナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市下屋敷町', '30', '30206', '6460032', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '下屋敷町', 'シモヤシキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市新屋敷町', '30', '30206', '6460033', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '新屋敷町', 'シンヤシキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市扇ケ浜', '30', '30206', '6460034', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '扇ケ浜', 'オウギガハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市中屋敷町', '30', '30206', '6460035', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '中屋敷町', 'ナカヤシキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市上屋敷', '30', '30206', '6460036', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '上屋敷', 'カミヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市磯間', '30', '30206', '6460037', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '磯間', 'イソマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市末広町', '30', '30206', '6460038', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '末広町', 'スエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市北新町', '30', '30206', '6460041', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '北新町', 'キタシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市南新町', '30', '30206', '6460042', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '南新町', 'ミナミシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市今福町', '30', '30206', '6460043', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '今福町', 'イマフクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市福路町', '30', '30206', '6460044', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '福路町', 'フクロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市片町', '30', '30206', '6460045', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '片町', 'カタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市本町', '30', '30206', '6460046', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市紺屋町', '30', '30206', '6460047', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '紺屋町', 'コンヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市栄町', '30', '30206', '6460048', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市天神崎', '30', '30206', '6460050', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '天神崎', 'テンジンザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市稲成町', '30', '30206', '6460051', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '稲成町', 'イナリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市むつみ', '30', '30206', '6460052', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', 'むつみ', 'ムツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市元町', '30', '30206', '6460053', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '元町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市江川', '30', '30206', '6460054', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '江川', 'エガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市芳養町', '30', '30206', '6460056', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '芳養町', 'ハヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市中芳養', '30', '30206', '6460057', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '中芳養', 'ナカハヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市目良', '30', '30206', '6460058', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '目良', 'メラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市古尾', '30', '30206', '6460059', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '古尾', 'フルオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市上の山', '30', '30206', '6460061', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '上の山', 'ウエノヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市明洋', '30', '30206', '6460062', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '明洋', 'メイヨウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市芳養松原', '30', '30206', '6460063', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '芳養松原', 'ハヤマツバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市上芳養', '30', '30206', '6460101', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '上芳養', 'カミハヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市秋津川', '30', '30206', '6460102', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '秋津川', 'アキヅガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市伏菟野', '30', '30206', '6460211', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '伏菟野', 'フドノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市上野', '30', '30206', '6460212', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '上野', 'ウエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市長野', '30', '30206', '6460213', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '長野', 'ナガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市上三栖', '30', '30206', '6460214', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '上三栖', 'カミミス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市中三栖', '30', '30206', '6460215', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '中三栖', 'ナカミス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市下三栖', '30', '30206', '6460216', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '下三栖', 'シモミス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市城山台', '30', '30206', '6460217', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '城山台', 'シロヤマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県西牟婁郡白浜町市鹿野', '30', '30401', '6460301', '和歌山県', 'ワカヤマケン', '西牟婁郡白浜町', 'ニシムログンシラハマチョウ', '市鹿野', 'イチカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県西牟婁郡白浜町上露', '30', '30401', '6460302', '和歌山県', 'ワカヤマケン', '西牟婁郡白浜町', 'ニシムログンシラハマチョウ', '上露', 'コウヅユ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県西牟婁郡白浜町大瀬', '30', '30401', '6460303', '和歌山県', 'ワカヤマケン', '西牟婁郡白浜町', 'ニシムログンシラハマチョウ', '大瀬', 'オオセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県西牟婁郡白浜町竹垣内', '30', '30401', '6460304', '和歌山県', 'ワカヤマケン', '西牟婁郡白浜町', 'ニシムログンシラハマチョウ', '竹垣内', 'タケガイト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県西牟婁郡白浜町北谷', '30', '30401', '6460305', '和歌山県', 'ワカヤマケン', '西牟婁郡白浜町', 'ニシムログンシラハマチョウ', '北谷', 'キタダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県西牟婁郡白浜町小房', '30', '30401', '6460311', '和歌山県', 'ワカヤマケン', '西牟婁郡白浜町', 'ニシムログンシラハマチョウ', '小房', 'オブサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県西牟婁郡白浜町大', '30', '30401', '6460312', '和歌山県', 'ワカヤマケン', '西牟婁郡白浜町', 'ニシムログンシラハマチョウ', '大', 'オオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県西牟婁郡白浜町玉伝', '30', '30401', '6460313', '和歌山県', 'ワカヤマケン', '西牟婁郡白浜町', 'ニシムログンシラハマチョウ', '玉伝', 'タマデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県西牟婁郡白浜町里谷', '30', '30401', '6460314', '和歌山県', 'ワカヤマケン', '西牟婁郡白浜町', 'ニシムログンシラハマチョウ', '里谷', 'サトダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市鮎川', '30', '30206', '6461101', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '鮎川', 'アユカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県西牟婁郡上富田町市ノ瀬', '30', '30404', '6461111', '和歌山県', 'ワカヤマケン', '西牟婁郡上富田町', 'ニシムログンカミトンダチョウ', '市ノ瀬', 'イチノセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県西牟婁郡上富田町下鮎川', '30', '30404', '6461112', '和歌山県', 'ワカヤマケン', '西牟婁郡上富田町', 'ニシムログンカミトンダチョウ', '下鮎川', 'シモアユカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市和田', '30', '30206', '6461211', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '和田', 'ワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市下川上', '30', '30206', '6461212', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '下川上', 'シモガワカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市下川下', '30', '30206', '6461213', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '下川下', 'シモガワシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市平瀬', '30', '30206', '6461214', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '平瀬', 'ヒラセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市熊野', '30', '30206', '6461321', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '熊野', 'イヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市面川', '30', '30206', '6461322', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '面川', 'メンガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市向山', '30', '30206', '6461323', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '向山', 'ムカイヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市竹ノ平', '30', '30206', '6461324', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '竹ノ平', 'タケノタイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市小谷', '30', '30206', '6461325', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '小谷', 'コダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市深谷', '30', '30206', '6461326', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '深谷', 'フカタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市木守', '30', '30206', '6461331', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '木守', 'コモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市五味', '30', '30206', '6461332', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '五味', 'ゴミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市東伏菟野', '30', '30206', '6461333', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '東伏菟野', 'ヒガシフドノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市九川', '30', '30206', '6461334', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '九川', 'クガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市串', '30', '30206', '6461335', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '串', 'クシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市谷野口', '30', '30206', '6461336', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '谷野口', 'タニノクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市下露', '30', '30206', '6461337', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '下露', 'シモツユ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市合川', '30', '30206', '6461338', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '合川', 'ゴウガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市長瀬', '30', '30206', '6461339', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '長瀬', 'ナガセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市中辺路町野中', '30', '30206', '6461401', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '中辺路町野中', 'ナカヘチチョウノナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市中辺路町近露', '30', '30206', '6461402', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '中辺路町近露', 'ナカヘチチョウチカツユ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市中辺路町大内川', '30', '30206', '6461411', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '中辺路町大内川', 'ナカヘチチョウオオウチガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市中辺路町石船', '30', '30206', '6461412', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '中辺路町石船', 'ナカヘチチョウイシブリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市中辺路町北郡', '30', '30206', '6461413', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '中辺路町北郡', 'ナカヘチチョウホクソギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市中辺路町西谷', '30', '30206', '6461414', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '中辺路町西谷', 'ナカヘチチョウニシダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市中辺路町真砂', '30', '30206', '6461415', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '中辺路町真砂', 'ナカヘチチョウマナゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市中辺路町高原', '30', '30206', '6461416', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '中辺路町高原', 'ナカヘチチョウタカハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市中辺路町川合', '30', '30206', '6461417', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '中辺路町川合', 'ナカヘチチョウカワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市中辺路町栗栖川', '30', '30206', '6461421', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '中辺路町栗栖川', 'ナカヘチチョウクリスガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市中辺路町小松原', '30', '30206', '6461431', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '中辺路町小松原', 'ナカヘチチョウコマツバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市中辺路町福定', '30', '30206', '6461432', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '中辺路町福定', 'ナカヘチチョウフクサダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市中辺路町大川', '30', '30206', '6461433', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '中辺路町大川', 'ナカヘチチョウオオカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市中辺路町温川', '30', '30206', '6461434', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '中辺路町温川', 'ナカヘチチョウヌルミガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市中辺路町小皆', '30', '30206', '6461435', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '中辺路町小皆', 'ナカヘチチョウコカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市中辺路町熊野川', '30', '30206', '6461436', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '中辺路町熊野川', 'ナカヘチチョウクマノガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市中辺路町沢', '30', '30206', '6461437', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '中辺路町沢', 'ナカヘチチョウサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市中辺路町水上', '30', '30206', '6461438', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '中辺路町水上', 'ナカヘチチョウミズカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市中辺路町内井川', '30', '30206', '6461439', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '中辺路町内井川', 'ナカヘチチョウウチイガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県新宮市', '30', '30207', '6470000', '和歌山県', 'ワカヤマケン', '新宮市', 'シングウシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('76250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県新宮市相筋', '30', '30207', '6470001', '和歌山県', 'ワカヤマケン', '新宮市', 'シングウシ', '相筋', 'アイスジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県新宮市船町', '30', '30207', '6470002', '和歌山県', 'ワカヤマケン', '新宮市', 'シングウシ', '船町', 'フナマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県新宮市上本町', '30', '30207', '6470003', '和歌山県', 'ワカヤマケン', '新宮市', 'シングウシ', '上本町', 'カミホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県新宮市大橋通', '30', '30207', '6470004', '和歌山県', 'ワカヤマケン', '新宮市', 'シングウシ', '大橋通', 'オオハシドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県新宮市元鍛治町', '30', '30207', '6470005', '和歌山県', 'ワカヤマケン', '新宮市', 'シングウシ', '元鍛治町', 'モトカジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県新宮市薬師町', '30', '30207', '6470006', '和歌山県', 'ワカヤマケン', '新宮市', 'シングウシ', '薬師町', 'ヤクシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県新宮市別当屋敷町', '30', '30207', '6470007', '和歌山県', 'ワカヤマケン', '新宮市', 'シングウシ', '別当屋敷町', 'ベットウヤシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県新宮市馬町', '30', '30207', '6470008', '和歌山県', 'ワカヤマケン', '新宮市', 'シングウシ', '馬町', 'ウママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県新宮市下本町', '30', '30207', '6470011', '和歌山県', 'ワカヤマケン', '新宮市', 'シングウシ', '下本町', 'シモホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県新宮市伊佐田町', '30', '30207', '6470012', '和歌山県', 'ワカヤマケン', '新宮市', 'シングウシ', '伊佐田町', 'イサダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県新宮市春日', '30', '30207', '6470013', '和歌山県', 'ワカヤマケン', '新宮市', 'シングウシ', '春日', 'カスガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県新宮市浮島', '30', '30207', '6470014', '和歌山県', 'ワカヤマケン', '新宮市', 'シングウシ', '浮島', 'ウキジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県新宮市千穂', '30', '30207', '6470015', '和歌山県', 'ワカヤマケン', '新宮市', 'シングウシ', '千穂', 'チホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県新宮市谷王子町', '30', '30207', '6470016', '和歌山県', 'ワカヤマケン', '新宮市', 'シングウシ', '谷王子町', 'タニオウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県新宮市横町', '30', '30207', '6470017', '和歌山県', 'ワカヤマケン', '新宮市', 'シングウシ', '横町', 'ヨコマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県新宮市仲之町', '30', '30207', '6470018', '和歌山県', 'ワカヤマケン', '新宮市', 'シングウシ', '仲之町', 'ナカノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県新宮市新町', '30', '30207', '6470019', '和歌山県', 'ワカヤマケン', '新宮市', 'シングウシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県新宮市徐福', '30', '30207', '6470020', '和歌山県', 'ワカヤマケン', '新宮市', 'シングウシ', '徐福', 'ジョフク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県新宮市池田', '30', '30207', '6470021', '和歌山県', 'ワカヤマケン', '新宮市', 'シングウシ', '池田', 'イケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県新宮市阿須賀', '30', '30207', '6470022', '和歌山県', 'ワカヤマケン', '新宮市', 'シングウシ', '阿須賀', 'アスカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県新宮市蓬莱', '30', '30207', '6470023', '和歌山県', 'ワカヤマケン', '新宮市', 'シングウシ', '蓬莱', 'ホウライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県新宮市熊野地', '30', '30207', '6470024', '和歌山県', 'ワカヤマケン', '新宮市', 'シングウシ', '熊野地', 'クマノジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県新宮市あけぼの', '30', '30207', '6470025', '和歌山県', 'ワカヤマケン', '新宮市', 'シングウシ', 'あけぼの', 'アケボノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県新宮市田鶴原町', '30', '30207', '6470031', '和歌山県', 'ワカヤマケン', '新宮市', 'シングウシ', '田鶴原町', 'タズハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県新宮市王子町', '30', '30207', '6470032', '和歌山県', 'ワカヤマケン', '新宮市', 'シングウシ', '王子町', 'オウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県新宮市清水元', '30', '30207', '6470033', '和歌山県', 'ワカヤマケン', '新宮市', 'シングウシ', '清水元', 'シミズモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県新宮市丸山', '30', '30207', '6470034', '和歌山県', 'ワカヤマケン', '新宮市', 'シングウシ', '丸山', 'マルヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県新宮市野田', '30', '30207', '6470041', '和歌山県', 'ワカヤマケン', '新宮市', 'シングウシ', '野田', 'ノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県新宮市下田', '30', '30207', '6470042', '和歌山県', 'ワカヤマケン', '新宮市', 'シングウシ', '下田', 'シモダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県新宮市緑ケ丘', '30', '30207', '6470043', '和歌山県', 'ワカヤマケン', '新宮市', 'シングウシ', '緑ケ丘', 'ミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県新宮市神倉', '30', '30207', '6470044', '和歌山県', 'ワカヤマケン', '新宮市', 'シングウシ', '神倉', 'カミクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県新宮市井の沢', '30', '30207', '6470045', '和歌山県', 'ワカヤマケン', '新宮市', 'シングウシ', '井の沢', 'イノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県新宮市磐盾', '30', '30207', '6470051', '和歌山県', 'ワカヤマケン', '新宮市', 'シングウシ', '磐盾', 'イワタテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県新宮市橋本', '30', '30207', '6470052', '和歌山県', 'ワカヤマケン', '新宮市', 'シングウシ', '橋本', 'ハシモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県新宮市五新', '30', '30207', '6470053', '和歌山県', 'ワカヤマケン', '新宮市', 'シングウシ', '五新', 'ゴシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県新宮市南檜杖', '30', '30207', '6470054', '和歌山県', 'ワカヤマケン', '新宮市', 'シングウシ', '南檜杖', 'ミナミヒヅエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県新宮市三輪崎', '30', '30207', '6470061', '和歌山県', 'ワカヤマケン', '新宮市', 'シングウシ', '三輪崎', 'ミワサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県新宮市佐野', '30', '30207', '6470071', '和歌山県', 'ワカヤマケン', '新宮市', 'シングウシ', '佐野', 'サノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県新宮市蜂伏', '30', '30207', '6470072', '和歌山県', 'ワカヤマケン', '新宮市', 'シングウシ', '蜂伏', 'ハチブセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県新宮市木ノ川', '30', '30207', '6470073', '和歌山県', 'ワカヤマケン', '新宮市', 'シングウシ', '木ノ川', 'キノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県新宮市新宮', '30', '30207', '6470081', '和歌山県', 'ワカヤマケン', '新宮市', 'シングウシ', '新宮', 'シングウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県新宮市高田', '30', '30207', '6471101', '和歌山県', 'ワカヤマケン', '新宮市', 'シングウシ', '高田', 'タカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県新宮市相賀', '30', '30207', '6471102', '和歌山県', 'ワカヤマケン', '新宮市', 'シングウシ', '相賀', 'オウガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県新宮市南檜杖土ノ河', '30', '30207', '6471103', '和歌山県', 'ワカヤマケン', '新宮市', 'シングウシ', '南檜杖', 'ミナミヒヅエ', null, null, '土ノ河', 'ツチノコ');
INSERT INTO `ms_addresses` VALUES ('76294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県新宮市熊野川町上長井', '30', '30207', '6471201', '和歌山県', 'ワカヤマケン', '新宮市', 'シングウシ', '熊野川町上長井', 'クマノガワチョウカミナガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県新宮市熊野川町東', '30', '30207', '6471202', '和歌山県', 'ワカヤマケン', '新宮市', 'シングウシ', '熊野川町東', 'クマノガワチョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県新宮市熊野川町大山', '30', '30207', '6471203', '和歌山県', 'ワカヤマケン', '新宮市', 'シングウシ', '熊野川町大山', 'クマノガワチョウオオヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県新宮市熊野川町鎌塚', '30', '30207', '6471204', '和歌山県', 'ワカヤマケン', '新宮市', 'シングウシ', '熊野川町鎌塚', 'クマノガワチョウカマヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県新宮市熊野川町滝本', '30', '30207', '6471205', '和歌山県', 'ワカヤマケン', '新宮市', 'シングウシ', '熊野川町滝本', 'クマノガワチョウタキモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県新宮市熊野川町西', '30', '30207', '6471206', '和歌山県', 'ワカヤマケン', '新宮市', 'シングウシ', '熊野川町西', 'クマノガワチョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県新宮市熊野川町畝畑', '30', '30207', '6471207', '和歌山県', 'ワカヤマケン', '新宮市', 'シングウシ', '熊野川町畝畑', 'クマノガワチョウウネハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県新宮市熊野川町日足', '30', '30207', '6471211', '和歌山県', 'ワカヤマケン', '新宮市', 'シングウシ', '熊野川町日足', 'クマノガワチョウヒタリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県新宮市熊野川町田長', '30', '30207', '6471212', '和歌山県', 'ワカヤマケン', '新宮市', 'シングウシ', '熊野川町田長', 'クマノガワチョウタナゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県新宮市熊野川町能城山本', '30', '30207', '6471213', '和歌山県', 'ワカヤマケン', '新宮市', 'シングウシ', '熊野川町能城山本', 'クマノガワチョウノキヤマモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県新宮市熊野川町赤木', '30', '30207', '6471214', '和歌山県', 'ワカヤマケン', '新宮市', 'シングウシ', '熊野川町赤木', 'クマノガワチョウアカギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県新宮市熊野川町椋井', '30', '30207', '6471215', '和歌山県', 'ワカヤマケン', '新宮市', 'シングウシ', '熊野川町椋井', 'クマノガワチョウムクノイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県新宮市熊野川町相須', '30', '30207', '6471216', '和歌山県', 'ワカヤマケン', '新宮市', 'シングウシ', '熊野川町相須', 'クマノガワチョウアイス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県新宮市熊野川町西敷屋', '30', '30207', '6471221', '和歌山県', 'ワカヤマケン', '新宮市', 'シングウシ', '熊野川町西敷屋', 'クマノガワチョウニシシキヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県新宮市熊野川町東敷屋', '30', '30207', '6471222', '和歌山県', 'ワカヤマケン', '新宮市', 'シングウシ', '熊野川町東敷屋', 'クマノガワチョウヒガシシキヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県新宮市熊野川町篠尾', '30', '30207', '6471223', '和歌山県', 'ワカヤマケン', '新宮市', 'シングウシ', '熊野川町篠尾', 'クマノガワチョウササビ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県新宮市熊野川町玉置口', '30', '30207', '6471231', '和歌山県', 'ワカヤマケン', '新宮市', 'シングウシ', '熊野川町玉置口', 'クマノガワチョウタマキグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県新宮市熊野川町嶋津', '30', '30207', '6471232', '和歌山県', 'ワカヤマケン', '新宮市', 'シングウシ', '熊野川町嶋津', 'クマノガワチョウシマヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県新宮市熊野川町九重', '30', '30207', '6471233', '和歌山県', 'ワカヤマケン', '新宮市', 'シングウシ', '熊野川町九重', 'クマノガワチョウクジュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県新宮市熊野川町四滝', '30', '30207', '6471234', '和歌山県', 'ワカヤマケン', '新宮市', 'シングウシ', '熊野川町四滝', 'クマノガワチョウシタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県新宮市熊野川町宮井', '30', '30207', '6471235', '和歌山県', 'ワカヤマケン', '新宮市', 'シングウシ', '熊野川町宮井', 'クマノガワチョウミヤイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡十津川村竹筒', '29', '29449', '6471271', '奈良県', 'ナラケン', '吉野郡十津川村', 'ヨシノグントツカワムラ', '竹筒', 'タケトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県熊野市紀和町花井', '24', '24212', '6471321', '三重県', 'ミエケン', '熊野市', 'クマノシ', '紀和町花井', 'キワチョウケイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県熊野市紀和町小船', '24', '24212', '6471322', '三重県', 'ミエケン', '熊野市', 'クマノシ', '紀和町小船', 'キワチョウコブネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県熊野市紀和町楊枝川', '24', '24212', '6471323', '三重県', 'ミエケン', '熊野市', 'クマノシ', '紀和町楊枝川', 'キワチョウヨウジガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県熊野市紀和町和気', '24', '24212', '6471324', '三重県', 'ミエケン', '熊野市', 'クマノシ', '紀和町和気', 'キワチョウワケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '三重県熊野市紀和町楊枝', '24', '24212', '6471325', '三重県', 'ミエケン', '熊野市', 'クマノシ', '紀和町楊枝', 'キワチョウヨウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡十津川村神下', '29', '29449', '6471581', '奈良県', 'ナラケン', '吉野郡十津川村', 'ヨシノグントツカワムラ', '神下', 'コウカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡十津川村玉置川', '29', '29449', '6471582', '奈良県', 'ナラケン', '吉野郡十津川村', 'ヨシノグントツカワムラ', '玉置川', 'タマイガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡十津川村東中', '29', '29449', '6471583', '奈良県', 'ナラケン', '吉野郡十津川村', 'ヨシノグントツカワムラ', '東中', 'ヒガシナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡十津川村上葛川', '29', '29449', '6471584', '奈良県', 'ナラケン', '吉野郡十津川村', 'ヨシノグントツカワムラ', '上葛川', 'カミクズガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡北山村', '30', '30427', '6471600', '和歌山県', 'ワカヤマケン', '東牟婁郡北山村', 'ヒガシムログンキタヤマムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('76327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡北山村七色', '30', '30427', '6471601', '和歌山県', 'ワカヤマケン', '東牟婁郡北山村', 'ヒガシムログンキタヤマムラ', '七色', 'ナナイロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡北山村竹原', '30', '30427', '6471602', '和歌山県', 'ワカヤマケン', '東牟婁郡北山村', 'ヒガシムログンキタヤマムラ', '竹原', 'タケハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡北山村大沼', '30', '30427', '6471603', '和歌山県', 'ワカヤマケン', '東牟婁郡北山村', 'ヒガシムログンキタヤマムラ', '大沼', 'オオヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡北山村下尾井', '30', '30427', '6471604', '和歌山県', 'ワカヤマケン', '東牟婁郡北山村', 'ヒガシムログンキタヤマムラ', '下尾井', 'シモオイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡北山村小松', '30', '30427', '6471605', '和歌山県', 'ワカヤマケン', '東牟婁郡北山村', 'ヒガシムログンキタヤマムラ', '小松', 'コマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市本宮町小津荷', '30', '30206', '6471701', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '本宮町小津荷', 'ホングウチョウコツガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市本宮町大津荷', '30', '30206', '6471702', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '本宮町大津荷', 'ホングウチョウオオツガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市本宮町請川', '30', '30206', '6471703', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '本宮町請川', 'ホングウチョウウケガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市本宮町耳打', '30', '30206', '6471704', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '本宮町耳打', 'ホングウチョウミミウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市本宮町高山', '30', '30206', '6471705', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '本宮町高山', 'ホングウチョウタカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市本宮町皆瀬川', '30', '30206', '6471711', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '本宮町皆瀬川', 'ホングウチョウミナセガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市本宮町田代', '30', '30206', '6471712', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '本宮町田代', 'ホングウチョウタシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市本宮町簑尾谷', '30', '30206', '6471713', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '本宮町簑尾谷', 'ホングウチョウミノオダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市本宮町静川', '30', '30206', '6471714', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '本宮町静川', 'ホングウチョウシズカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市本宮町東和田', '30', '30206', '6471715', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '本宮町東和田', 'ホングウチョウヒガシワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市本宮町上大野', '30', '30206', '6471716', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '本宮町上大野', 'ホングウチョウカミオオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市本宮町川湯', '30', '30206', '6471717', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '本宮町川湯', 'ホングウチョウカワユ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市本宮町檜葉', '30', '30206', '6471721', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '本宮町檜葉', 'ホングウチョウヒバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市本宮町小々森', '30', '30206', '6471722', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '本宮町小々森', 'ホングウチョウコゴモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市本宮町皆地', '30', '30206', '6471723', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '本宮町皆地', 'ホングウチョウミナチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市本宮町野竹', '30', '30206', '6471724', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '本宮町野竹', 'ホングウチョウノダケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市本宮町大瀬', '30', '30206', '6471725', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '本宮町大瀬', 'ホングウチョウオオゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市本宮町武住', '30', '30206', '6471726', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '本宮町武住', 'ホングウチョウブジュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市本宮町本宮', '30', '30206', '6471731', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '本宮町本宮', 'ホングウチョウホングウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市本宮町湯峰', '30', '30206', '6471732', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '本宮町湯峰', 'ホングウチョウユノミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市本宮町渡瀬', '30', '30206', '6471733', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '本宮町渡瀬', 'ホングウチョウワタゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市本宮町下湯川', '30', '30206', '6471734', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '本宮町下湯川', 'ホングウチョウシモユカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市本宮町曲川', '30', '30206', '6471735', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '本宮町曲川', 'ホングウチョウマガリカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市本宮町久保野', '30', '30206', '6471736', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '本宮町久保野', 'ホングウチョウクボノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市本宮町大居', '30', '30206', '6471741', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '本宮町大居', 'ホングウチョウオオイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市本宮町一本松', '30', '30206', '6471742', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '本宮町一本松', 'ホングウチョウイッポンマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市本宮町伏拝', '30', '30206', '6471743', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '本宮町伏拝', 'ホングウチョウフシオガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市本宮町三越', '30', '30206', '6471744', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '本宮町三越', 'ホングウチョウミコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市本宮町上切原', '30', '30206', '6471751', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '本宮町上切原', 'ホングウチョウカミキリバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市本宮町切畑', '30', '30206', '6471752', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '本宮町切畑', 'ホングウチョウキリハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県田辺市本宮町土河屋', '30', '30206', '6471753', '和歌山県', 'ワカヤマケン', '田辺市', 'タナベシ', '本宮町土河屋', 'ホングウチョウツチゴヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県橋本市', '30', '30203', '6480000', '和歌山県', 'ワカヤマケン', '橋本市', 'ハシモトシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('76366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県橋本市杉尾', '30', '30203', '6480001', '和歌山県', 'ワカヤマケン', '橋本市', 'ハシモトシ', '杉尾', 'スギオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県橋本市隅田町平野', '30', '30203', '6480002', '和歌山県', 'ワカヤマケン', '橋本市', 'ハシモトシ', '隅田町平野', 'スダチョウヒラノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県橋本市隅田町山内', '30', '30203', '6480003', '和歌山県', 'ワカヤマケン', '橋本市', 'ハシモトシ', '隅田町山内', 'スダチョウヤマウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県橋本市隅田町霜草', '30', '30203', '6480004', '和歌山県', 'ワカヤマケン', '橋本市', 'ハシモトシ', '隅田町霜草', 'スダチョウシモクサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県橋本市小峰台', '30', '30203', '6480005', '和歌山県', 'ワカヤマケン', '橋本市', 'ハシモトシ', '小峰台', 'オミネダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県橋本市境原', '30', '30203', '6480006', '和歌山県', 'ワカヤマケン', '橋本市', 'ハシモトシ', '境原', 'サカイバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県橋本市隅田町真土', '30', '30203', '6480011', '和歌山県', 'ワカヤマケン', '橋本市', 'ハシモトシ', '隅田町真土', 'スダチョウマツチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県橋本市隅田町芋生', '30', '30203', '6480012', '和歌山県', 'ワカヤマケン', '橋本市', 'ハシモトシ', '隅田町芋生', 'スダチョウイモウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県橋本市隅田町中下', '30', '30203', '6480013', '和歌山県', 'ワカヤマケン', '橋本市', 'ハシモトシ', '隅田町中下', 'スダチョウチュウゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県橋本市隅田町上兵庫', '30', '30203', '6480014', '和歌山県', 'ワカヤマケン', '橋本市', 'ハシモトシ', '隅田町上兵庫', 'スダチョウカミヒョウゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県橋本市隅田町河瀬', '30', '30203', '6480015', '和歌山県', 'ワカヤマケン', '橋本市', 'ハシモトシ', '隅田町河瀬', 'スダチョウコウゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県橋本市隅田町下兵庫', '30', '30203', '6480016', '和歌山県', 'ワカヤマケン', '橋本市', 'ハシモトシ', '隅田町下兵庫', 'スダチョウシモヒョウゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県橋本市隅田町中島', '30', '30203', '6480017', '和歌山県', 'ワカヤマケン', '橋本市', 'ハシモトシ', '隅田町中島', 'スダチョウナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県橋本市隅田町垂井', '30', '30203', '6480018', '和歌山県', 'ワカヤマケン', '橋本市', 'ハシモトシ', '隅田町垂井', 'スダチョウタルイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県橋本市あやの台', '30', '30203', '6480019', '和歌山県', 'ワカヤマケン', '橋本市', 'ハシモトシ', 'あやの台', 'アヤノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県橋本市恋野', '30', '30203', '6480021', '和歌山県', 'ワカヤマケン', '橋本市', 'ハシモトシ', '恋野', 'コイノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県橋本市赤塚', '30', '30203', '6480022', '和歌山県', 'ワカヤマケン', '橋本市', 'ハシモトシ', '赤塚', 'アカツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県橋本市中道', '30', '30203', '6480023', '和歌山県', 'ワカヤマケン', '橋本市', 'ハシモトシ', '中道', 'ナカドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県橋本市上田', '30', '30203', '6480024', '和歌山県', 'ワカヤマケン', '橋本市', 'ハシモトシ', '上田', 'ウエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県橋本市向副', '30', '30203', '6480025', '和歌山県', 'ワカヤマケン', '橋本市', 'ハシモトシ', '向副', 'ムカソイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県橋本市只野', '30', '30203', '6480031', '和歌山県', 'ワカヤマケン', '橋本市', 'ハシモトシ', '只野', 'タダノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県橋本市谷奥深', '30', '30203', '6480032', '和歌山県', 'ワカヤマケン', '橋本市', 'ハシモトシ', '谷奥深', 'タニオブカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県橋本市北宿', '30', '30203', '6480033', '和歌山県', 'ワカヤマケン', '橋本市', 'ハシモトシ', '北宿', 'キタヤドリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県橋本市南宿', '30', '30203', '6480034', '和歌山県', 'ワカヤマケン', '橋本市', 'ハシモトシ', '南宿', 'ミナミヤドリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県橋本市彦谷', '30', '30203', '6480035', '和歌山県', 'ワカヤマケン', '橋本市', 'ハシモトシ', '彦谷', 'ヒコタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県橋本市横座', '30', '30203', '6480036', '和歌山県', 'ワカヤマケン', '橋本市', 'ハシモトシ', '横座', 'ヨコザ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県橋本市賢堂', '30', '30203', '6480037', '和歌山県', 'ワカヤマケン', '橋本市', 'ハシモトシ', '賢堂', 'カシコドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県橋本市須河', '30', '30203', '6480038', '和歌山県', 'ワカヤマケン', '橋本市', 'ハシモトシ', '須河', 'スゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県橋本市清水', '30', '30203', '6480041', '和歌山県', 'ワカヤマケン', '橋本市', 'ハシモトシ', '清水', 'シミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県橋本市西畑', '30', '30203', '6480042', '和歌山県', 'ワカヤマケン', '橋本市', 'ハシモトシ', '西畑', 'ニシバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県橋本市学文路', '30', '30203', '6480043', '和歌山県', 'ワカヤマケン', '橋本市', 'ハシモトシ', '学文路', 'カムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県橋本市南馬場', '30', '30203', '6480044', '和歌山県', 'ワカヤマケン', '橋本市', 'ハシモトシ', '南馬場', 'ミナミババ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県橋本市細川', '30', '30203', '6480051', '和歌山県', 'ワカヤマケン', '橋本市', 'ハシモトシ', '細川', 'ホソカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県橋本市紀見', '30', '30203', '6480052', '和歌山県', 'ワカヤマケン', '橋本市', 'ハシモトシ', '紀見', 'キミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県橋本市しらさぎ台', '30', '30203', '6480053', '和歌山県', 'ワカヤマケン', '橋本市', 'ハシモトシ', 'しらさぎ台', 'シラサギダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県橋本市城山台', '30', '30203', '6480054', '和歌山県', 'ワカヤマケン', '橋本市', 'ハシモトシ', '城山台', 'シロヤマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県橋本市北馬場', '30', '30203', '6480061', '和歌山県', 'ワカヤマケン', '橋本市', 'ハシモトシ', '北馬場', 'キタババ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県橋本市妻', '30', '30203', '6480062', '和歌山県', 'ワカヤマケン', '橋本市', 'ハシモトシ', '妻', 'ツマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県橋本市原田', '30', '30203', '6480063', '和歌山県', 'ワカヤマケン', '橋本市', 'ハシモトシ', '原田', 'ハラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県橋本市橋本', '30', '30203', '6480064', '和歌山県', 'ワカヤマケン', '橋本市', 'ハシモトシ', '橋本', 'ハシモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県橋本市古佐田', '30', '30203', '6480065', '和歌山県', 'ワカヤマケン', '橋本市', 'ハシモトシ', '古佐田', 'コサダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県橋本市胡麻生', '30', '30203', '6480066', '和歌山県', 'ワカヤマケン', '橋本市', 'ハシモトシ', '胡麻生', 'ゴモウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県橋本市小原田', '30', '30203', '6480071', '和歌山県', 'ワカヤマケン', '橋本市', 'ハシモトシ', '小原田', 'オハラタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県橋本市東家', '30', '30203', '6480072', '和歌山県', 'ワカヤマケン', '橋本市', 'ハシモトシ', '東家', 'トウゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県橋本市市脇', '30', '30203', '6480073', '和歌山県', 'ワカヤマケン', '橋本市', 'ハシモトシ', '市脇', 'イチワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県橋本市野', '30', '30203', '6480074', '和歌山県', 'ワカヤマケン', '橋本市', 'ハシモトシ', '野', 'ノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県橋本市さつき台', '30', '30203', '6480075', '和歌山県', 'ワカヤマケン', '橋本市', 'ハシモトシ', 'さつき台', 'サツキダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県橋本市山田', '30', '30203', '6480081', '和歌山県', 'ワカヤマケン', '橋本市', 'ハシモトシ', '山田', 'ヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県橋本市菖蒲谷', '30', '30203', '6480082', '和歌山県', 'ワカヤマケン', '橋本市', 'ハシモトシ', '菖蒲谷', 'ショウブタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県橋本市出塔', '30', '30203', '6480083', '和歌山県', 'ワカヤマケン', '橋本市', 'ハシモトシ', '出塔', 'デトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県橋本市柏原', '30', '30203', '6480084', '和歌山県', 'ワカヤマケン', '橋本市', 'ハシモトシ', '柏原', 'カセバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県橋本市岸上', '30', '30203', '6480085', '和歌山県', 'ワカヤマケン', '橋本市', 'ハシモトシ', '岸上', 'キシガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県橋本市神野々', '30', '30203', '6480086', '和歌山県', 'ワカヤマケン', '橋本市', 'ハシモトシ', '神野々', 'コノノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県橋本市吉原', '30', '30203', '6480087', '和歌山県', 'ワカヤマケン', '橋本市', 'ハシモトシ', '吉原', 'ヨシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県橋本市みゆき台', '30', '30203', '6480088', '和歌山県', 'ワカヤマケン', '橋本市', 'ハシモトシ', 'みゆき台', 'ミユキダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県橋本市柱本', '30', '30203', '6480091', '和歌山県', 'ワカヤマケン', '橋本市', 'ハシモトシ', '柱本', 'ハシラモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県橋本市紀見ケ丘', '30', '30203', '6480092', '和歌山県', 'ワカヤマケン', '橋本市', 'ハシモトシ', '紀見ケ丘', 'キミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県橋本市慶賀野', '30', '30203', '6480093', '和歌山県', 'ワカヤマケン', '橋本市', 'ハシモトシ', '慶賀野', 'ケガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県橋本市三石台', '30', '30203', '6480094', '和歌山県', 'ワカヤマケン', '橋本市', 'ハシモトシ', '三石台', 'ミツイシダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県橋本市橋谷', '30', '30203', '6480095', '和歌山県', 'ワカヤマケン', '橋本市', 'ハシモトシ', '橋谷', 'ハシタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県橋本市御幸辻', '30', '30203', '6480096', '和歌山県', 'ワカヤマケン', '橋本市', 'ハシモトシ', '御幸辻', 'ミユキツジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県橋本市柿の木坂', '30', '30203', '6480097', '和歌山県', 'ワカヤマケン', '橋本市', 'ハシモトシ', '柿の木坂', 'カキノキザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県橋本市矢倉脇', '30', '30203', '6480098', '和歌山県', 'ワカヤマケン', '橋本市', 'ハシモトシ', '矢倉脇', 'ヤグラワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県橋本市光陽台', '30', '30203', '6480099', '和歌山県', 'ワカヤマケン', '橋本市', 'ハシモトシ', '光陽台', 'コウヨウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県伊都郡九度山町', '30', '30343', '6480100', '和歌山県', 'ワカヤマケン', '伊都郡九度山町', 'イトグンクドヤマチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('76431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県伊都郡九度山町九度山', '30', '30343', '6480101', '和歌山県', 'ワカヤマケン', '伊都郡九度山町', 'イトグンクドヤマチョウ', '九度山', 'クドヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県伊都郡九度山町河根', '30', '30343', '6480111', '和歌山県', 'ワカヤマケン', '伊都郡九度山町', 'イトグンクドヤマチョウ', '河根', 'カネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県伊都郡九度山町丹生川', '30', '30343', '6480121', '和歌山県', 'ワカヤマケン', '伊都郡九度山町', 'イトグンクドヤマチョウ', '丹生川', 'ニュウカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県伊都郡九度山町市平', '30', '30343', '6480131', '和歌山県', 'ワカヤマケン', '伊都郡九度山町', 'イトグンクドヤマチョウ', '市平', 'イチタイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県伊都郡九度山町北又', '30', '30343', '6480132', '和歌山県', 'ワカヤマケン', '伊都郡九度山町', 'イトグンクドヤマチョウ', '北又', 'キタマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県伊都郡九度山町東郷', '30', '30343', '6480133', '和歌山県', 'ワカヤマケン', '伊都郡九度山町', 'イトグンクドヤマチョウ', '東郷', 'ヒガシゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県伊都郡九度山町椎出', '30', '30343', '6480141', '和歌山県', 'ワカヤマケン', '伊都郡九度山町', 'イトグンクドヤマチョウ', '椎出', 'シイデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県伊都郡九度山町笠木', '30', '30343', '6480142', '和歌山県', 'ワカヤマケン', '伊都郡九度山町', 'イトグンクドヤマチョウ', '笠木', 'カサギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県伊都郡九度山町上古沢', '30', '30343', '6480143', '和歌山県', 'ワカヤマケン', '伊都郡九度山町', 'イトグンクドヤマチョウ', '上古沢', 'カミコサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県伊都郡九度山町中古沢', '30', '30343', '6480144', '和歌山県', 'ワカヤマケン', '伊都郡九度山町', 'イトグンクドヤマチョウ', '中古沢', 'ナカコサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県伊都郡九度山町下古沢', '30', '30343', '6480145', '和歌山県', 'ワカヤマケン', '伊都郡九度山町', 'イトグンクドヤマチョウ', '下古沢', 'シモコサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県伊都郡九度山町慈尊院', '30', '30343', '6480151', '和歌山県', 'ワカヤマケン', '伊都郡九度山町', 'イトグンクドヤマチョウ', '慈尊院', 'ジソンイン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県伊都郡九度山町入郷', '30', '30343', '6480161', '和歌山県', 'ワカヤマケン', '伊都郡九度山町', 'イトグンクドヤマチョウ', '入郷', 'ニュウゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県伊都郡高野町西郷', '30', '30344', '6480171', '和歌山県', 'ワカヤマケン', '伊都郡高野町', 'イトグンコウヤチョウ', '西郷', 'ニシゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県伊都郡高野町', '30', '30344', '6480200', '和歌山県', 'ワカヤマケン', '伊都郡高野町', 'イトグンコウヤチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('76447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県伊都郡かつらぎ町花園久木', '30', '30341', '6480201', '和歌山県', 'ワカヤマケン', '伊都郡かつらぎ町', 'イトグンカツラギチョウ', '花園久木', 'ハナゾノクキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県伊都郡かつらぎ町花園中南', '30', '30341', '6480202', '和歌山県', 'ワカヤマケン', '伊都郡かつらぎ町', 'イトグンカツラギチョウ', '花園中南', 'ハナゾノナカミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県伊都郡高野町高野山', '30', '30344', '6480211', '和歌山県', 'ワカヤマケン', '伊都郡高野町', 'イトグンコウヤチョウ', '高野山', 'コウヤサン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県伊都郡高野町西ケ峰', '30', '30344', '6480221', '和歌山県', 'ワカヤマケン', '伊都郡高野町', 'イトグンコウヤチョウ', '西ケ峰', 'ニシガミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県伊都郡高野町南', '30', '30344', '6480222', '和歌山県', 'ワカヤマケン', '伊都郡高野町', 'イトグンコウヤチョウ', '南', 'ミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県伊都郡高野町林', '30', '30344', '6480223', '和歌山県', 'ワカヤマケン', '伊都郡高野町', 'イトグンコウヤチョウ', '林', 'ハヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県伊都郡高野町平原', '30', '30344', '6480224', '和歌山県', 'ワカヤマケン', '伊都郡高野町', 'イトグンコウヤチョウ', '平原', 'ヒラハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県伊都郡高野町杖ケ薮', '30', '30344', '6480225', '和歌山県', 'ワカヤマケン', '伊都郡高野町', 'イトグンコウヤチョウ', '杖ケ薮', 'ツエガヤブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県伊都郡高野町東又', '30', '30344', '6480226', '和歌山県', 'ワカヤマケン', '伊都郡高野町', 'イトグンコウヤチョウ', '東又', 'ヒガシマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県伊都郡高野町樫原', '30', '30344', '6480227', '和歌山県', 'ワカヤマケン', '伊都郡高野町', 'イトグンコウヤチョウ', '樫原', 'カシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県伊都郡高野町大滝', '30', '30344', '6480231', '和歌山県', 'ワカヤマケン', '伊都郡高野町', 'イトグンコウヤチョウ', '大滝', 'オオタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県伊都郡高野町相ノ浦', '30', '30344', '6480241', '和歌山県', 'ワカヤマケン', '伊都郡高野町', 'イトグンコウヤチョウ', '相ノ浦', 'アイノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県伊都郡高野町湯川', '30', '30344', '6480251', '和歌山県', 'ワカヤマケン', '伊都郡高野町', 'イトグンコウヤチョウ', '湯川', 'ユカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県伊都郡高野町西郷神谷', '30', '30344', '6480261', '和歌山県', 'ワカヤマケン', '伊都郡高野町', 'イトグンコウヤチョウ', '西郷', 'ニシゴウ', null, null, '神谷', 'カミヤ');
INSERT INTO `ms_addresses` VALUES ('76461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県伊都郡高野町細川', '30', '30344', '6480262', '和歌山県', 'ワカヤマケン', '伊都郡高野町', 'イトグンコウヤチョウ', '細川', 'ホソカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県伊都郡高野町花坂', '30', '30344', '6480263', '和歌山県', 'ワカヤマケン', '伊都郡高野町', 'イトグンコウヤチョウ', '花坂', 'ハナサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡野迫川村', '29', '29447', '6480300', '奈良県', 'ナラケン', '吉野郡野迫川村', 'ヨシノグンノセガワムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('76481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡野迫川村池津川', '29', '29447', '6480301', '奈良県', 'ナラケン', '吉野郡野迫川村', 'ヨシノグンノセガワムラ', '池津川', 'イケツカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡野迫川村紫園', '29', '29447', '6480302', '奈良県', 'ナラケン', '吉野郡野迫川村', 'ヨシノグンノセガワムラ', '紫園', 'シオン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡野迫川村中津川', '29', '29447', '6480303', '奈良県', 'ナラケン', '吉野郡野迫川村', 'ヨシノグンノセガワムラ', '中津川', 'ナカツガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡野迫川村立里', '29', '29447', '6480304', '奈良県', 'ナラケン', '吉野郡野迫川村', 'ヨシノグンノセガワムラ', '立里', 'タテリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡野迫川村北股', '29', '29447', '6480305', '奈良県', 'ナラケン', '吉野郡野迫川村', 'ヨシノグンノセガワムラ', '北股', 'キタマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡野迫川村平', '29', '29447', '6480306', '奈良県', 'ナラケン', '吉野郡野迫川村', 'ヨシノグンノセガワムラ', '平', 'タイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡野迫川村北今西', '29', '29447', '6480307', '奈良県', 'ナラケン', '吉野郡野迫川村', 'ヨシノグンノセガワムラ', '北今西', 'キタイマニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡野迫川村桧股', '29', '29447', '6480308', '奈良県', 'ナラケン', '吉野郡野迫川村', 'ヨシノグンノセガワムラ', '桧股', 'ヒノキマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '奈良県吉野郡野迫川村弓手原', '29', '29447', '6480309', '奈良県', 'ナラケン', '吉野郡野迫川村', 'ヨシノグンノセガワムラ', '弓手原', 'ユミテハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県伊都郡高野町西富貴', '30', '30344', '6480401', '和歌山県', 'ワカヤマケン', '伊都郡高野町', 'イトグンコウヤチョウ', '西富貴', 'ニシフキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県伊都郡高野町東富貴', '30', '30344', '6480402', '和歌山県', 'ワカヤマケン', '伊都郡高野町', 'イトグンコウヤチョウ', '東富貴', 'ヒガシフキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県伊都郡高野町上筒香', '30', '30344', '6480403', '和歌山県', 'ワカヤマケン', '伊都郡高野町', 'イトグンコウヤチョウ', '上筒香', 'カミツツガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県伊都郡高野町中筒香', '30', '30344', '6480404', '和歌山県', 'ワカヤマケン', '伊都郡高野町', 'イトグンコウヤチョウ', '中筒香', 'ナカツツガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県伊都郡高野町下筒香', '30', '30344', '6480405', '和歌山県', 'ワカヤマケン', '伊都郡高野町', 'イトグンコウヤチョウ', '下筒香', 'シモツツガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海南市下津町下津', '30', '30202', '6490101', '和歌山県', 'ワカヤマケン', '海南市', 'カイナンシ', '下津町下津', 'シモツチョウシモツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海南市下津町方', '30', '30202', '6490111', '和歌山県', 'ワカヤマケン', '海南市', 'カイナンシ', '下津町方', 'シモツチョウカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海南市下津町大崎', '30', '30202', '6490112', '和歌山県', 'ワカヤマケン', '海南市', 'カイナンシ', '下津町大崎', 'シモツチョウオオサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海南市下津町丸田', '30', '30202', '6490121', '和歌山県', 'ワカヤマケン', '海南市', 'カイナンシ', '下津町丸田', 'シモツチョウマルダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海南市下津町黒田', '30', '30202', '6490122', '和歌山県', 'ワカヤマケン', '海南市', 'カイナンシ', '下津町黒田', 'シモツチョウクロダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海南市下津町丁', '30', '30202', '6490123', '和歌山県', 'ワカヤマケン', '海南市', 'カイナンシ', '下津町丁', 'シモツチョウヨロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海南市下津町塩津', '30', '30202', '6490131', '和歌山県', 'ワカヤマケン', '海南市', 'カイナンシ', '下津町塩津', 'シモツチョウシオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海南市下津町梅田', '30', '30202', '6490132', '和歌山県', 'ワカヤマケン', '海南市', 'カイナンシ', '下津町梅田', 'シモツチョウウメダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海南市下津町下', '30', '30202', '6490133', '和歌山県', 'ワカヤマケン', '海南市', 'カイナンシ', '下津町下', 'シモツチョウシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海南市下津町小南', '30', '30202', '6490141', '和歌山県', 'ワカヤマケン', '海南市', 'カイナンシ', '下津町小南', 'シモツチョウコミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海南市下津町中', '30', '30202', '6490142', '和歌山県', 'ワカヤマケン', '海南市', 'カイナンシ', '下津町中', 'シモツチョウナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海南市下津町小松原', '30', '30202', '6490143', '和歌山県', 'ワカヤマケン', '海南市', 'カイナンシ', '下津町小松原', 'シモツチョウコマツバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海南市下津町橘本', '30', '30202', '6490144', '和歌山県', 'ワカヤマケン', '海南市', 'カイナンシ', '下津町橘本', 'シモツチョウキツモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海南市下津町市坪', '30', '30202', '6490145', '和歌山県', 'ワカヤマケン', '海南市', 'カイナンシ', '下津町市坪', 'シモツチョウイチツボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海南市下津町沓掛', '30', '30202', '6490146', '和歌山県', 'ワカヤマケン', '海南市', 'カイナンシ', '下津町沓掛', 'シモツチョウクツカケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海南市下津町青枝', '30', '30202', '6490147', '和歌山県', 'ワカヤマケン', '海南市', 'カイナンシ', '下津町青枝', 'シモツチョウアオシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海南市下津町曽根田', '30', '30202', '6490151', '和歌山県', 'ワカヤマケン', '海南市', 'カイナンシ', '下津町曽根田', 'シモツチョウソネダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海南市下津町引尾', '30', '30202', '6490152', '和歌山県', 'ワカヤマケン', '海南市', 'カイナンシ', '下津町引尾', 'シモツチョウヒキオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海南市下津町興', '30', '30202', '6490153', '和歌山県', 'ワカヤマケン', '海南市', 'カイナンシ', '下津町興', 'シモツチョウオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海南市下津町笠畑', '30', '30202', '6490154', '和歌山県', 'ワカヤマケン', '海南市', 'カイナンシ', '下津町笠畑', 'シモツチョウカサバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海南市下津町大窪', '30', '30202', '6490155', '和歌山県', 'ワカヤマケン', '海南市', 'カイナンシ', '下津町大窪', 'シモツチョウオオクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海南市下津町百垣内', '30', '30202', '6490156', '和歌山県', 'ワカヤマケン', '海南市', 'カイナンシ', '下津町百垣内', 'シモツチョウモモガイト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海南市下津町小畑', '30', '30202', '6490161', '和歌山県', 'ワカヤマケン', '海南市', 'カイナンシ', '下津町小畑', 'シモツチョウコバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海南市下津町小原', '30', '30202', '6490162', '和歌山県', 'ワカヤマケン', '海南市', 'カイナンシ', '下津町小原', 'シモツチョウオバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海南市下津町鰈川', '30', '30202', '6490163', '和歌山県', 'ワカヤマケン', '海南市', 'カイナンシ', '下津町鰈川', 'シモツチョウカレガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県海南市下津町上', '30', '30202', '6490164', '和歌山県', 'ワカヤマケン', '海南市', 'カイナンシ', '下津町上', 'シモツチョウカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田市', '30', '30204', '6490300', '和歌山県', 'ワカヤマケン', '有田市', 'アリダシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('76610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田市下中島', '30', '30204', '6490301', '和歌山県', 'ワカヤマケン', '有田市', 'アリダシ', '下中島', 'シモナカシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田市山田原', '30', '30204', '6490302', '和歌山県', 'ワカヤマケン', '有田市', 'アリダシ', '山田原', 'ヤマダハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田市新堂', '30', '30204', '6490303', '和歌山県', 'ワカヤマケン', '有田市', 'アリダシ', '新堂', 'シンドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田市箕島', '30', '30204', '6490304', '和歌山県', 'ワカヤマケン', '有田市', 'アリダシ', '箕島', 'ミノシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田市港町', '30', '30204', '6490305', '和歌山県', 'ワカヤマケン', '有田市', 'アリダシ', '港町', 'ミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田市初島町浜', '30', '30204', '6490306', '和歌山県', 'ワカヤマケン', '有田市', 'アリダシ', '初島町浜', 'ハツシマチョウハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田市初島町里', '30', '30204', '6490307', '和歌山県', 'ワカヤマケン', '有田市', 'アリダシ', '初島町里', 'ハツシマチョウサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田市辻堂', '30', '30204', '6490311', '和歌山県', 'ワカヤマケン', '有田市', 'アリダシ', '辻堂', 'ツジドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田市星尾', '30', '30204', '6490312', '和歌山県', 'ワカヤマケン', '有田市', 'アリダシ', '星尾', 'ホシオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田市千田', '30', '30204', '6490313', '和歌山県', 'ワカヤマケン', '有田市', 'アリダシ', '千田', 'チダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田市野', '30', '30204', '6490314', '和歌山県', 'ワカヤマケン', '有田市', 'アリダシ', '野', 'ノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田市山地', '30', '30204', '6490315', '和歌山県', 'ワカヤマケン', '有田市', 'アリダシ', '山地', 'ヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田市宮崎町', '30', '30204', '6490316', '和歌山県', 'ワカヤマケン', '有田市', 'アリダシ', '宮崎町', 'ミヤザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田市古江見', '30', '30204', '6490317', '和歌山県', 'ワカヤマケン', '有田市', 'アリダシ', '古江見', 'コエミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田市糸我町中番', '30', '30204', '6490421', '和歌山県', 'ワカヤマケン', '有田市', 'アリダシ', '糸我町中番', 'イトガチョウナカバン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田市糸我町西', '30', '30204', '6490422', '和歌山県', 'ワカヤマケン', '有田市', 'アリダシ', '糸我町西', 'イトガチョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田市宮原町畑', '30', '30204', '6490431', '和歌山県', 'ワカヤマケン', '有田市', 'アリダシ', '宮原町畑', 'ミヤハラチョウハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田市宮原町東', '30', '30204', '6490432', '和歌山県', 'ワカヤマケン', '有田市', 'アリダシ', '宮原町東', 'ミヤハラチョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田市宮原町須谷', '30', '30204', '6490433', '和歌山県', 'ワカヤマケン', '有田市', 'アリダシ', '宮原町須谷', 'ミヤハラチョウスガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田市宮原町新町', '30', '30204', '6490434', '和歌山県', 'ワカヤマケン', '有田市', 'アリダシ', '宮原町新町', 'ミヤハラチョウシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田市宮原町滝川原', '30', '30204', '6490435', '和歌山県', 'ワカヤマケン', '有田市', 'アリダシ', '宮原町滝川原', 'ミヤハラチョウタキガハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田市宮原町道', '30', '30204', '6490436', '和歌山県', 'ワカヤマケン', '有田市', 'アリダシ', '宮原町道', 'ミヤハラチョウドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県有田市宮原町滝', '30', '30204', '6490437', '和歌山県', 'ワカヤマケン', '有田市', 'アリダシ', '宮原町滝', 'ミヤハラチョウタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡由良町', '30', '30383', '6491100', '和歌山県', 'ワカヤマケン', '日高郡由良町', 'ヒダカグンユラチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('76634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡由良町畑', '30', '30383', '6491101', '和歌山県', 'ワカヤマケン', '日高郡由良町', 'ヒダカグンユラチョウ', '畑', 'ハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡由良町中', '30', '30383', '6491102', '和歌山県', 'ワカヤマケン', '日高郡由良町', 'ヒダカグンユラチョウ', '中', 'ナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡由良町門前', '30', '30383', '6491103', '和歌山県', 'ワカヤマケン', '日高郡由良町', 'ヒダカグンユラチョウ', '門前', 'モンゼン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡由良町江ノ駒', '30', '30383', '6491104', '和歌山県', 'ワカヤマケン', '日高郡由良町', 'ヒダカグンユラチョウ', '江ノ駒', 'エノコマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡由良町里', '30', '30383', '6491111', '和歌山県', 'ワカヤマケン', '日高郡由良町', 'ヒダカグンユラチョウ', '里', 'サト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡由良町網代', '30', '30383', '6491112', '和歌山県', 'ワカヤマケン', '日高郡由良町', 'ヒダカグンユラチョウ', '網代', 'アジロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡由良町阿戸', '30', '30383', '6491113', '和歌山県', 'ワカヤマケン', '日高郡由良町', 'ヒダカグンユラチョウ', '阿戸', 'アト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡由良町吹井', '30', '30383', '6491121', '和歌山県', 'ワカヤマケン', '日高郡由良町', 'ヒダカグンユラチョウ', '吹井', 'フケイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡由良町神谷', '30', '30383', '6491122', '和歌山県', 'ワカヤマケン', '日高郡由良町', 'ヒダカグンユラチョウ', '神谷', 'カミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡由良町大引', '30', '30383', '6491123', '和歌山県', 'ワカヤマケン', '日高郡由良町', 'ヒダカグンユラチョウ', '大引', 'オオビキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡由良町小引', '30', '30383', '6491131', '和歌山県', 'ワカヤマケン', '日高郡由良町', 'ヒダカグンユラチョウ', '小引', 'コビキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡由良町衣奈', '30', '30383', '6491132', '和歌山県', 'ワカヤマケン', '日高郡由良町', 'ヒダカグンユラチョウ', '衣奈', 'エナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡由良町三尾川', '30', '30383', '6491133', '和歌山県', 'ワカヤマケン', '日高郡由良町', 'ヒダカグンユラチョウ', '三尾川', 'ミオガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡由良町戸津井', '30', '30383', '6491134', '和歌山県', 'ワカヤマケン', '日高郡由良町', 'ヒダカグンユラチョウ', '戸津井', 'トツイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡日高町', '30', '30382', '6491200', '和歌山県', 'ワカヤマケン', '日高郡日高町', 'ヒダカグンヒダカチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('76649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡日高町原谷', '30', '30382', '6491201', '和歌山県', 'ワカヤマケン', '日高郡日高町', 'ヒダカグンヒダカチョウ', '原谷', 'ハラダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡日高町萩原', '30', '30382', '6491202', '和歌山県', 'ワカヤマケン', '日高郡日高町', 'ヒダカグンヒダカチョウ', '萩原', 'ハギワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡日高町池田', '30', '30382', '6491203', '和歌山県', 'ワカヤマケン', '日高郡日高町', 'ヒダカグンヒダカチョウ', '池田', 'イケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡日高町荊木', '30', '30382', '6491211', '和歌山県', 'ワカヤマケン', '日高郡日高町', 'ヒダカグンヒダカチョウ', '荊木', 'イバラキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡日高町小中', '30', '30382', '6491212', '和歌山県', 'ワカヤマケン', '日高郡日高町', 'ヒダカグンヒダカチョウ', '小中', 'オナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡日高町高家', '30', '30382', '6491213', '和歌山県', 'ワカヤマケン', '日高郡日高町', 'ヒダカグンヒダカチョウ', '高家', 'タイエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡日高町志賀', '30', '30382', '6491221', '和歌山県', 'ワカヤマケン', '日高郡日高町', 'ヒダカグンヒダカチョウ', '志賀', 'シガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡日高町小池', '30', '30382', '6491222', '和歌山県', 'ワカヤマケン', '日高郡日高町', 'ヒダカグンヒダカチョウ', '小池', 'オイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡日高町小浦', '30', '30382', '6491223', '和歌山県', 'ワカヤマケン', '日高郡日高町', 'ヒダカグンヒダカチョウ', '小浦', 'オウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡日高町津久野', '30', '30382', '6491224', '和歌山県', 'ワカヤマケン', '日高郡日高町', 'ヒダカグンヒダカチョウ', '津久野', 'ツクノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡日高町方杭', '30', '30382', '6491225', '和歌山県', 'ワカヤマケン', '日高郡日高町', 'ヒダカグンヒダカチョウ', '方杭', 'カタクイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡日高町小坂', '30', '30382', '6491231', '和歌山県', 'ワカヤマケン', '日高郡日高町', 'ヒダカグンヒダカチョウ', '小坂', 'オサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡日高町阿尾', '30', '30382', '6491232', '和歌山県', 'ワカヤマケン', '日高郡日高町', 'ヒダカグンヒダカチョウ', '阿尾', 'アオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡日高町産湯', '30', '30382', '6491233', '和歌山県', 'ワカヤマケン', '日高郡日高町', 'ヒダカグンヒダカチョウ', '産湯', 'ウブユ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡日高町比井', '30', '30382', '6491234', '和歌山県', 'ワカヤマケン', '日高郡日高町', 'ヒダカグンヒダカチョウ', '比井', 'ヒイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡日高川町', '30', '30392', '6491300', '和歌山県', 'ワカヤマケン', '日高郡日高川町', 'ヒダカグンヒダカガワチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('76665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡日高川町平川', '30', '30392', '6491311', '和歌山県', 'ワカヤマケン', '日高郡日高川町', 'ヒダカグンヒダカガワチョウ', '平川', 'ヒュウガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡日高川町三百瀬', '30', '30392', '6491312', '和歌山県', 'ワカヤマケン', '日高郡日高川町', 'ヒダカグンヒダカガワチョウ', '三百瀬', 'ミヨセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡日高川町伊藤川', '30', '30392', '6491313', '和歌山県', 'ワカヤマケン', '日高郡日高川町', 'ヒダカグンヒダカガワチョウ', '伊藤川', 'イトゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡日高川町早藤', '30', '30392', '6491314', '和歌山県', 'ワカヤマケン', '日高郡日高川町', 'ヒダカグンヒダカガワチョウ', '早藤', 'ハイクズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡日高川町玄子', '30', '30392', '6491315', '和歌山県', 'ワカヤマケン', '日高郡日高川町', 'ヒダカグンヒダカガワチョウ', '玄子', 'ゲンゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡日高川町蛇尾', '30', '30392', '6491316', '和歌山県', 'ワカヤマケン', '日高郡日高川町', 'ヒダカグンヒダカガワチョウ', '蛇尾', 'ヘビオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡日高川町入野', '30', '30392', '6491321', '和歌山県', 'ワカヤマケン', '日高郡日高川町', 'ヒダカグンヒダカガワチョウ', '入野', 'ニュウノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡日高川町若野', '30', '30392', '6491322', '和歌山県', 'ワカヤマケン', '日高郡日高川町', 'ヒダカグンヒダカガワチョウ', '若野', 'ワカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡日高川町小熊', '30', '30392', '6491323', '和歌山県', 'ワカヤマケン', '日高郡日高川町', 'ヒダカグンヒダカガワチョウ', '小熊', 'コグマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡日高川町土生', '30', '30392', '6491324', '和歌山県', 'ワカヤマケン', '日高郡日高川町', 'ヒダカグンヒダカガワチョウ', '土生', 'ハブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡日高川町中津川', '30', '30392', '6491325', '和歌山県', 'ワカヤマケン', '日高郡日高川町', 'ヒダカグンヒダカガワチョウ', '中津川', 'ナカツカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡日高川町鐘巻', '30', '30392', '6491331', '和歌山県', 'ワカヤマケン', '日高郡日高川町', 'ヒダカグンヒダカガワチョウ', '鐘巻', 'カネマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡日高川町千津川', '30', '30392', '6491332', '和歌山県', 'ワカヤマケン', '日高郡日高川町', 'ヒダカグンヒダカガワチョウ', '千津川', 'センヅガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県御坊市藤田町藤井', '30', '30205', '6491341', '和歌山県', 'ワカヤマケン', '御坊市', 'ゴボウシ', '藤田町藤井', 'フジタチョウフジイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県御坊市藤田町吉田', '30', '30205', '6491342', '和歌山県', 'ワカヤマケン', '御坊市', 'ゴボウシ', '藤田町吉田', 'フジタチョウヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡日高川町山野', '30', '30392', '6491441', '和歌山県', 'ワカヤマケン', '日高郡日高川町', 'ヒダカグンヒダカガワチョウ', '山野', 'サンヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡日高川町江川', '30', '30392', '6491442', '和歌山県', 'ワカヤマケン', '日高郡日高川町', 'ヒダカグンヒダカガワチョウ', '江川', 'エカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡日高川町和佐', '30', '30392', '6491443', '和歌山県', 'ワカヤマケン', '日高郡日高川町', 'ヒダカグンヒダカガワチョウ', '和佐', 'ワサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡日高川町松瀬', '30', '30392', '6491444', '和歌山県', 'ワカヤマケン', '日高郡日高川町', 'ヒダカグンヒダカガワチョウ', '松瀬', 'マツセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡印南町', '30', '30390', '6491500', '和歌山県', 'ワカヤマケン', '日高郡印南町', 'ヒダカグンイナミチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('76685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡印南町美里', '30', '30390', '6491521', '和歌山県', 'ワカヤマケン', '日高郡印南町', 'ヒダカグンイナミチョウ', '美里', 'ミサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡印南町古井', '30', '30390', '6491522', '和歌山県', 'ワカヤマケン', '日高郡印南町', 'ヒダカグンイナミチョウ', '古井', 'フルイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡印南町樮川', '30', '30390', '6491523', '和歌山県', 'ワカヤマケン', '日高郡印南町', 'ヒダカグンイナミチョウ', '樮川', 'ホクソガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡印南町羽六', '30', '30390', '6491524', '和歌山県', 'ワカヤマケン', '日高郡印南町', 'ヒダカグンイナミチョウ', '羽六', 'ハロク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡印南町古屋', '30', '30390', '6491525', '和歌山県', 'ワカヤマケン', '日高郡印南町', 'ヒダカグンイナミチョウ', '古屋', 'フルヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡印南町宮ノ前', '30', '30390', '6491526', '和歌山県', 'ワカヤマケン', '日高郡印南町', 'ヒダカグンイナミチョウ', '宮ノ前', 'ミヤノマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡印南町島田', '30', '30390', '6491527', '和歌山県', 'ワカヤマケン', '日高郡印南町', 'ヒダカグンイナミチョウ', '島田', 'シマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡印南町西ノ地', '30', '30390', '6491528', '和歌山県', 'ワカヤマケン', '日高郡印南町', 'ヒダカグンイナミチョウ', '西ノ地', 'ニシノジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡印南町立石', '30', '30390', '6491531', '和歌山県', 'ワカヤマケン', '日高郡印南町', 'ヒダカグンイナミチョウ', '立石', 'タテイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡印南町印南原', '30', '30390', '6491532', '和歌山県', 'ワカヤマケン', '日高郡印南町', 'ヒダカグンイナミチョウ', '印南原', 'イナンバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡印南町山口', '30', '30390', '6491533', '和歌山県', 'ワカヤマケン', '日高郡印南町', 'ヒダカグンイナミチョウ', '山口', 'ヤマグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡印南町印南', '30', '30390', '6491534', '和歌山県', 'ワカヤマケン', '日高郡印南町', 'ヒダカグンイナミチョウ', '印南', 'イナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡印南町津井', '30', '30390', '6491535', '和歌山県', 'ワカヤマケン', '日高郡印南町', 'ヒダカグンイナミチョウ', '津井', 'ツイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡印南町南谷', '30', '30390', '6491536', '和歌山県', 'ワカヤマケン', '日高郡印南町', 'ヒダカグンイナミチョウ', '南谷', 'ミナミダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県日高郡印南町明神川', '30', '30390', '6491537', '和歌山県', 'ワカヤマケン', '日高郡印南町', 'ヒダカグンイナミチョウ', '明神川', 'ミョウジンガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県西牟婁郡上富田町', '30', '30404', '6492100', '和歌山県', 'ワカヤマケン', '西牟婁郡上富田町', 'ニシムログンカミトンダチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('76701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県西牟婁郡上富田町岡', '30', '30404', '6492101', '和歌山県', 'ワカヤマケン', '西牟婁郡上富田町', 'ニシムログンカミトンダチョウ', '岡', 'オカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県西牟婁郡上富田町岩田', '30', '30404', '6492102', '和歌山県', 'ワカヤマケン', '西牟婁郡上富田町', 'ニシムログンカミトンダチョウ', '岩田', 'イワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県西牟婁郡上富田町生馬', '30', '30404', '6492103', '和歌山県', 'ワカヤマケン', '西牟婁郡上富田町', 'ニシムログンカミトンダチョウ', '生馬', 'イクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県西牟婁郡上富田町岩崎', '30', '30404', '6492104', '和歌山県', 'ワカヤマケン', '西牟婁郡上富田町', 'ニシムログンカミトンダチョウ', '岩崎', 'イワサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県西牟婁郡上富田町朝来', '30', '30404', '6492105', '和歌山県', 'ワカヤマケン', '西牟婁郡上富田町', 'ニシムログンカミトンダチョウ', '朝来', 'アッソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県西牟婁郡上富田町南紀の台', '30', '30404', '6492106', '和歌山県', 'ワカヤマケン', '西牟婁郡上富田町', 'ニシムログンカミトンダチョウ', '南紀の台', 'ナンキノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県西牟婁郡白浜町', '30', '30401', '6492200', '和歌山県', 'ワカヤマケン', '西牟婁郡白浜町', 'ニシムログンシラハマチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('76712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県西牟婁郡白浜町堅田', '30', '30401', '6492201', '和歌山県', 'ワカヤマケン', '西牟婁郡白浜町', 'ニシムログンシラハマチョウ', '堅田', 'カタタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県西牟婁郡白浜町', '30', '30401', '6492211', '和歌山県', 'ワカヤマケン', '西牟婁郡白浜町', 'ニシムログンシラハマチョウ', null, '　', '（直番地）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('76714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県西牟婁郡白浜町保呂', '30', '30401', '6492321', '和歌山県', 'ワカヤマケン', '西牟婁郡白浜町', 'ニシムログンシラハマチョウ', '保呂', 'ホロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県西牟婁郡白浜町内ノ川', '30', '30401', '6492322', '和歌山県', 'ワカヤマケン', '西牟婁郡白浜町', 'ニシムログンシラハマチョウ', '内ノ川', 'ウチノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県西牟婁郡白浜町庄川', '30', '30401', '6492323', '和歌山県', 'ワカヤマケン', '西牟婁郡白浜町', 'ニシムログンシラハマチョウ', '庄川', 'シャガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県西牟婁郡白浜町十九渕', '30', '30401', '6492324', '和歌山県', 'ワカヤマケン', '西牟婁郡白浜町', 'ニシムログンシラハマチョウ', '十九渕', 'ツヅラフチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県西牟婁郡白浜町富田', '30', '30401', '6492325', '和歌山県', 'ワカヤマケン', '西牟婁郡白浜町', 'ニシムログンシラハマチョウ', '富田', 'トンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県西牟婁郡白浜町椿', '30', '30401', '6492326', '和歌山県', 'ワカヤマケン', '西牟婁郡白浜町', 'ニシムログンシラハマチョウ', '椿', 'ツバキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県西牟婁郡白浜町平', '30', '30401', '6492331', '和歌山県', 'ワカヤマケン', '西牟婁郡白浜町', 'ニシムログンシラハマチョウ', '平', 'タイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県西牟婁郡白浜町栄', '30', '30401', '6492332', '和歌山県', 'ワカヤマケン', '西牟婁郡白浜町', 'ニシムログンシラハマチョウ', '栄', 'サカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県西牟婁郡白浜町中', '30', '30401', '6492333', '和歌山県', 'ワカヤマケン', '西牟婁郡白浜町', 'ニシムログンシラハマチョウ', '中', 'ナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県西牟婁郡白浜町才野', '30', '30401', '6492334', '和歌山県', 'ワカヤマケン', '西牟婁郡白浜町', 'ニシムログンシラハマチョウ', '才野', 'サイノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県西牟婁郡白浜町日置', '30', '30401', '6492511', '和歌山県', 'ワカヤマケン', '西牟婁郡白浜町', 'ニシムログンシラハマチョウ', '日置', 'ヒキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県西牟婁郡白浜町大古', '30', '30401', '6492521', '和歌山県', 'ワカヤマケン', '西牟婁郡白浜町', 'ニシムログンシラハマチョウ', '大古', 'オオフル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県西牟婁郡白浜町矢田', '30', '30401', '6492522', '和歌山県', 'ワカヤマケン', '西牟婁郡白浜町', 'ニシムログンシラハマチョウ', '矢田', 'ヤタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県西牟婁郡白浜町田野井', '30', '30401', '6492523', '和歌山県', 'ワカヤマケン', '西牟婁郡白浜町', 'ニシムログンシラハマチョウ', '田野井', 'タノイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県西牟婁郡白浜町安宅', '30', '30401', '6492524', '和歌山県', 'ワカヤマケン', '西牟婁郡白浜町', 'ニシムログンシラハマチョウ', '安宅', 'アタギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県西牟婁郡白浜町塩野', '30', '30401', '6492525', '和歌山県', 'ワカヤマケン', '西牟婁郡白浜町', 'ニシムログンシラハマチョウ', '塩野', 'シオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県西牟婁郡白浜町口ケ谷', '30', '30401', '6492531', '和歌山県', 'ワカヤマケン', '西牟婁郡白浜町', 'ニシムログンシラハマチョウ', '口ケ谷', 'クチガタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県西牟婁郡白浜町安居', '30', '30401', '6492532', '和歌山県', 'ワカヤマケン', '西牟婁郡白浜町', 'ニシムログンシラハマチョウ', '安居', 'アゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県西牟婁郡白浜町中嶋', '30', '30401', '6492533', '和歌山県', 'ワカヤマケン', '西牟婁郡白浜町', 'ニシムログンシラハマチョウ', '中嶋', 'ナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県西牟婁郡白浜町寺山', '30', '30401', '6492534', '和歌山県', 'ワカヤマケン', '西牟婁郡白浜町', 'ニシムログンシラハマチョウ', '寺山', 'テラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県西牟婁郡白浜町向平', '30', '30401', '6492535', '和歌山県', 'ワカヤマケン', '西牟婁郡白浜町', 'ニシムログンシラハマチョウ', '向平', 'ムカイダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県西牟婁郡白浜町久木', '30', '30401', '6492536', '和歌山県', 'ワカヤマケン', '西牟婁郡白浜町', 'ニシムログンシラハマチョウ', '久木', 'ヒサギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県西牟婁郡白浜町宇津木', '30', '30401', '6492537', '和歌山県', 'ワカヤマケン', '西牟婁郡白浜町', 'ニシムログンシラハマチョウ', '宇津木', 'ウツギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県西牟婁郡白浜町小川', '30', '30401', '6492538', '和歌山県', 'ワカヤマケン', '西牟婁郡白浜町', 'ニシムログンシラハマチョウ', '小川', 'コガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県西牟婁郡白浜町城', '30', '30401', '6492539', '和歌山県', 'ワカヤマケン', '西牟婁郡白浜町', 'ニシムログンシラハマチョウ', '城', 'ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県西牟婁郡すさみ町', '30', '30406', '6492600', '和歌山県', 'ワカヤマケン', '西牟婁郡すさみ町', 'ニシムログンスサミチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('76740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県西牟婁郡すさみ町小附', '30', '30406', '6492601', '和歌山県', 'ワカヤマケン', '西牟婁郡すさみ町', 'ニシムログンスサミチョウ', '小附', 'コツキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県西牟婁郡すさみ町大附', '30', '30406', '6492602', '和歌山県', 'ワカヤマケン', '西牟婁郡すさみ町', 'ニシムログンスサミチョウ', '大附', 'オオツキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県西牟婁郡すさみ町小河内', '30', '30406', '6492603', '和歌山県', 'ワカヤマケン', '西牟婁郡すさみ町', 'ニシムログンスサミチョウ', '小河内', 'オカウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県西牟婁郡すさみ町矢野口', '30', '30406', '6492604', '和歌山県', 'ワカヤマケン', '西牟婁郡すさみ町', 'ニシムログンスサミチョウ', '矢野口', 'ヤノクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県西牟婁郡すさみ町和深川', '30', '30406', '6492611', '和歌山県', 'ワカヤマケン', '西牟婁郡すさみ町', 'ニシムログンスサミチョウ', '和深川', 'ワブカガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県西牟婁郡すさみ町口和深', '30', '30406', '6492612', '和歌山県', 'ワカヤマケン', '西牟婁郡すさみ町', 'ニシムログンスサミチョウ', '口和深', 'クチワブカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県西牟婁郡すさみ町周参見', '30', '30406', '6492621', '和歌山県', 'ワカヤマケン', '西牟婁郡すさみ町', 'ニシムログンスサミチョウ', '周参見', 'スサミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県西牟婁郡すさみ町太間川', '30', '30406', '6492631', '和歌山県', 'ワカヤマケン', '西牟婁郡すさみ町', 'ニシムログンスサミチョウ', '太間川', 'タイマガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県西牟婁郡すさみ町見老津', '30', '30406', '6493141', '和歌山県', 'ワカヤマケン', '西牟婁郡すさみ町', 'ニシムログンスサミチョウ', '見老津', 'ミロヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県西牟婁郡すさみ町江住', '30', '30406', '6493142', '和歌山県', 'ワカヤマケン', '西牟婁郡すさみ町', 'ニシムログンスサミチョウ', '江住', 'エスミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県西牟婁郡すさみ町里野', '30', '30406', '6493143', '和歌山県', 'ワカヤマケン', '西牟婁郡すさみ町', 'ニシムログンスサミチョウ', '里野', 'サトノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県西牟婁郡すさみ町大鎌', '30', '30406', '6493151', '和歌山県', 'ワカヤマケン', '西牟婁郡すさみ町', 'ニシムログンスサミチョウ', '大鎌', 'オオガマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県西牟婁郡すさみ町防己', '30', '30406', '6493152', '和歌山県', 'ワカヤマケン', '西牟婁郡すさみ町', 'ニシムログンスサミチョウ', '防己', 'ツヅラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県西牟婁郡すさみ町大谷', '30', '30406', '6493153', '和歌山県', 'ワカヤマケン', '西牟婁郡すさみ町', 'ニシムログンスサミチョウ', '大谷', 'オオタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県西牟婁郡すさみ町佐本中', '30', '30406', '6493161', '和歌山県', 'ワカヤマケン', '西牟婁郡すさみ町', 'ニシムログンスサミチョウ', '佐本中', 'サモトナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県西牟婁郡すさみ町佐本追川', '30', '30406', '6493162', '和歌山県', 'ワカヤマケン', '西牟婁郡すさみ町', 'ニシムログンスサミチョウ', '佐本追川', 'サモトオイガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県西牟婁郡すさみ町佐本西栗垣内', '30', '30406', '6493163', '和歌山県', 'ワカヤマケン', '西牟婁郡すさみ町', 'ニシムログンスサミチョウ', '佐本西栗垣内', 'サモトニシクリガイト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県西牟婁郡すさみ町佐本東栗垣内', '30', '30406', '6493164', '和歌山県', 'ワカヤマケン', '西牟婁郡すさみ町', 'ニシムログンスサミチョウ', '佐本東栗垣内', 'サモトヒガシクリガイト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県西牟婁郡すさみ町佐本中野', '30', '30406', '6493165', '和歌山県', 'ワカヤマケン', '西牟婁郡すさみ町', 'ニシムログンスサミチョウ', '佐本中野', 'サモトナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県西牟婁郡すさみ町佐本西野川', '30', '30406', '6493166', '和歌山県', 'ワカヤマケン', '西牟婁郡すさみ町', 'ニシムログンスサミチョウ', '佐本西野川', 'サモトニシノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県西牟婁郡すさみ町佐本平野', '30', '30406', '6493167', '和歌山県', 'ワカヤマケン', '西牟婁郡すさみ町', 'ニシムログンスサミチョウ', '佐本平野', 'サモトヒラノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県西牟婁郡すさみ町佐本根倉', '30', '30406', '6493168', '和歌山県', 'ワカヤマケン', '西牟婁郡すさみ町', 'ニシムログンスサミチョウ', '佐本根倉', 'サモトネクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県西牟婁郡すさみ町佐本深谷', '30', '30406', '6493169', '和歌山県', 'ワカヤマケン', '西牟婁郡すさみ町', 'ニシムログンスサミチョウ', '佐本深谷', 'サモトフカタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡串本町', '30', '30428', '6493500', '和歌山県', 'ワカヤマケン', '東牟婁郡串本町', 'ヒガシムログンクシモトチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('76764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡串本町出雲', '30', '30428', '6493501', '和歌山県', 'ワカヤマケン', '東牟婁郡串本町', 'ヒガシムログンクシモトチョウ', '出雲', 'イツモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡串本町潮岬', '30', '30428', '6493502', '和歌山県', 'ワカヤマケン', '東牟婁郡串本町', 'ヒガシムログンクシモトチョウ', '潮岬', 'シオノミサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡串本町串本', '30', '30428', '6493503', '和歌山県', 'ワカヤマケン', '東牟婁郡串本町', 'ヒガシムログンクシモトチョウ', '串本', 'クシモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡串本町サンゴ台', '30', '30428', '6493510', '和歌山県', 'ワカヤマケン', '東牟婁郡串本町', 'ヒガシムログンクシモトチョウ', 'サンゴ台', 'サンゴダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡串本町鬮野川', '30', '30428', '6493511', '和歌山県', 'ワカヤマケン', '東牟婁郡串本町', 'ヒガシムログンクシモトチョウ', '鬮野川', 'クジノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡串本町二色', '30', '30428', '6493512', '和歌山県', 'ワカヤマケン', '東牟婁郡串本町', 'ヒガシムログンクシモトチョウ', '二色', 'ニシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡串本町高富', '30', '30428', '6493513', '和歌山県', 'ワカヤマケン', '東牟婁郡串本町', 'ヒガシムログンクシモトチョウ', '高富', 'タカトミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡串本町有田', '30', '30428', '6493514', '和歌山県', 'ワカヤマケン', '東牟婁郡串本町', 'ヒガシムログンクシモトチョウ', '有田', 'アリダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡串本町田並', '30', '30428', '6493515', '和歌山県', 'ワカヤマケン', '東牟婁郡串本町', 'ヒガシムログンクシモトチョウ', '田並', 'タナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡串本町田並上', '30', '30428', '6493516', '和歌山県', 'ワカヤマケン', '東牟婁郡串本町', 'ヒガシムログンクシモトチョウ', '田並上', 'タナミカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡串本町吐生', '30', '30428', '6493517', '和歌山県', 'ワカヤマケン', '東牟婁郡串本町', 'ヒガシムログンクシモトチョウ', '吐生', 'ハブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡串本町有田上', '30', '30428', '6493518', '和歌山県', 'ワカヤマケン', '東牟婁郡串本町', 'ヒガシムログンクシモトチョウ', '有田上', 'アリダカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡串本町江田', '30', '30428', '6493521', '和歌山県', 'ワカヤマケン', '東牟婁郡串本町', 'ヒガシムログンクシモトチョウ', '江田', 'エダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡串本町田子', '30', '30428', '6493522', '和歌山県', 'ワカヤマケン', '東牟婁郡串本町', 'ヒガシムログンクシモトチョウ', '田子', 'タコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡串本町和深', '30', '30428', '6493523', '和歌山県', 'ワカヤマケン', '東牟婁郡串本町', 'ヒガシムログンクシモトチョウ', '和深', 'ワブカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡串本町里川', '30', '30428', '6493524', '和歌山県', 'ワカヤマケン', '東牟婁郡串本町', 'ヒガシムログンクシモトチョウ', '里川', 'サトガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡串本町樫野', '30', '30428', '6493631', '和歌山県', 'ワカヤマケン', '東牟婁郡串本町', 'ヒガシムログンクシモトチョウ', '樫野', 'カシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡串本町須江', '30', '30428', '6493632', '和歌山県', 'ワカヤマケン', '東牟婁郡串本町', 'ヒガシムログンクシモトチョウ', '須江', 'スエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡串本町大島', '30', '30428', '6493633', '和歌山県', 'ワカヤマケン', '東牟婁郡串本町', 'ヒガシムログンクシモトチョウ', '大島', 'オオシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡古座川町', '30', '30424', '6494100', '和歌山県', 'ワカヤマケン', '東牟婁郡古座川町', 'ヒガシムログンコザガワチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('76785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡古座川町樫山', '30', '30424', '6494101', '和歌山県', 'ワカヤマケン', '東牟婁郡古座川町', 'ヒガシムログンコザガワチョウ', '樫山', 'カシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡古座川町楠', '30', '30424', '6494102', '和歌山県', 'ワカヤマケン', '東牟婁郡古座川町', 'ヒガシムログンコザガワチョウ', '楠', 'クス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡古座川町池野山', '30', '30424', '6494103', '和歌山県', 'ワカヤマケン', '東牟婁郡古座川町', 'ヒガシムログンコザガワチョウ', '池野山', 'イケノヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡古座川町高池', '30', '30424', '6494104', '和歌山県', 'ワカヤマケン', '東牟婁郡古座川町', 'ヒガシムログンコザガワチョウ', '高池', 'タカイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡古座川町宇津木', '30', '30424', '6494105', '和歌山県', 'ワカヤマケン', '東牟婁郡古座川町', 'ヒガシムログンコザガワチョウ', '宇津木', 'ウツギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡古座川町月野瀬', '30', '30424', '6494106', '和歌山県', 'ワカヤマケン', '東牟婁郡古座川町', 'ヒガシムログンコザガワチョウ', '月野瀬', 'ツキノセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡串本町上田原', '30', '30428', '6494111', '和歌山県', 'ワカヤマケン', '東牟婁郡串本町', 'ヒガシムログンクシモトチョウ', '上田原', 'カミタワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡串本町田原', '30', '30428', '6494112', '和歌山県', 'ワカヤマケン', '東牟婁郡串本町', 'ヒガシムログンクシモトチョウ', '田原', 'タワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡串本町津荷', '30', '30428', '6494113', '和歌山県', 'ワカヤマケン', '東牟婁郡串本町', 'ヒガシムログンクシモトチョウ', '津荷', 'ツガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡串本町上野山', '30', '30428', '6494114', '和歌山県', 'ワカヤマケン', '東牟婁郡串本町', 'ヒガシムログンクシモトチョウ', '上野山', 'ウエノヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡串本町古座', '30', '30428', '6494115', '和歌山県', 'ワカヤマケン', '東牟婁郡串本町', 'ヒガシムログンクシモトチョウ', '古座', 'コザ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡串本町中湊', '30', '30428', '6494116', '和歌山県', 'ワカヤマケン', '東牟婁郡串本町', 'ヒガシムログンクシモトチョウ', '中湊', 'ナカミナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡串本町佐部', '30', '30428', '6494117', '和歌山県', 'ワカヤマケン', '東牟婁郡串本町', 'ヒガシムログンクシモトチョウ', '佐部', 'サベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡串本町古田', '30', '30428', '6494121', '和歌山県', 'ワカヤマケン', '東牟婁郡串本町', 'ヒガシムログンクシモトチョウ', '古田', 'フルタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡串本町西向', '30', '30428', '6494122', '和歌山県', 'ワカヤマケン', '東牟婁郡串本町', 'ヒガシムログンクシモトチョウ', '西向', 'ニシムカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡串本町神野川', '30', '30428', '6494123', '和歌山県', 'ワカヤマケン', '東牟婁郡串本町', 'ヒガシムログンクシモトチョウ', '神野川', 'コノガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡串本町伊串', '30', '30428', '6494124', '和歌山県', 'ワカヤマケン', '東牟婁郡串本町', 'ヒガシムログンクシモトチョウ', '伊串', 'イクシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡串本町姫', '30', '30428', '6494125', '和歌山県', 'ワカヤマケン', '東牟婁郡串本町', 'ヒガシムログンクシモトチョウ', '姫', 'ヒメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡串本町姫川', '30', '30428', '6494126', '和歌山県', 'ワカヤマケン', '東牟婁郡串本町', 'ヒガシムログンクシモトチョウ', '姫川', 'ヒメガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡古座川町小森川', '30', '30424', '6494211', '和歌山県', 'ワカヤマケン', '東牟婁郡古座川町', 'ヒガシムログンコザガワチョウ', '小森川', 'コモリガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡古座川町田川', '30', '30424', '6494212', '和歌山県', 'ワカヤマケン', '東牟婁郡古座川町', 'ヒガシムログンコザガワチョウ', '田川', 'タガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡古座川町西赤木', '30', '30424', '6494213', '和歌山県', 'ワカヤマケン', '東牟婁郡古座川町', 'ヒガシムログンコザガワチョウ', '西赤木', 'ニシアカギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡古座川町宇筒井', '30', '30424', '6494214', '和歌山県', 'ワカヤマケン', '東牟婁郡古座川町', 'ヒガシムログンコザガワチョウ', '宇筒井', 'ウヅツイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡古座川町大桑', '30', '30424', '6494215', '和歌山県', 'ワカヤマケン', '東牟婁郡古座川町', 'ヒガシムログンコザガワチョウ', '大桑', 'オオグワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡古座川町小川', '30', '30424', '6494216', '和歌山県', 'ワカヤマケン', '東牟婁郡古座川町', 'ヒガシムログンコザガワチョウ', '小川', 'コガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡古座川町山手', '30', '30424', '6494217', '和歌山県', 'ワカヤマケン', '東牟婁郡古座川町', 'ヒガシムログンコザガワチョウ', '山手', 'ヤマテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡古座川町中崎', '30', '30424', '6494221', '和歌山県', 'ワカヤマケン', '東牟婁郡古座川町', 'ヒガシムログンコザガワチョウ', '中崎', 'ナカザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡古座川町直見', '30', '30424', '6494222', '和歌山県', 'ワカヤマケン', '東牟婁郡古座川町', 'ヒガシムログンコザガワチョウ', '直見', 'ヌクミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡古座川町川口', '30', '30424', '6494223', '和歌山県', 'ワカヤマケン', '東牟婁郡古座川町', 'ヒガシムログンコザガワチョウ', '川口', 'カワグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡古座川町高瀬', '30', '30424', '6494224', '和歌山県', 'ワカヤマケン', '東牟婁郡古座川町', 'ヒガシムログンコザガワチョウ', '高瀬', 'タカセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡古座川町潤野', '30', '30424', '6494225', '和歌山県', 'ワカヤマケン', '東牟婁郡古座川町', 'ヒガシムログンコザガワチョウ', '潤野', 'ウルノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡古座川町明神', '30', '30424', '6494226', '和歌山県', 'ワカヤマケン', '東牟婁郡古座川町', 'ヒガシムログンコザガワチョウ', '明神', 'ミョウジン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡古座川町大柳', '30', '30424', '6494227', '和歌山県', 'ワカヤマケン', '東牟婁郡古座川町', 'ヒガシムログンコザガワチョウ', '大柳', 'オオヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡古座川町鶴川', '30', '30424', '6494231', '和歌山県', 'ワカヤマケン', '東牟婁郡古座川町', 'ヒガシムログンコザガワチョウ', '鶴川', 'ツルガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡古座川町一雨', '30', '30424', '6494232', '和歌山県', 'ワカヤマケン', '東牟婁郡古座川町', 'ヒガシムログンコザガワチョウ', '一雨', 'イチブリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡古座川町立合', '30', '30424', '6494233', '和歌山県', 'ワカヤマケン', '東牟婁郡古座川町', 'ヒガシムログンコザガワチョウ', '立合', 'タチアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡古座川町峰', '30', '30424', '6494234', '和歌山県', 'ワカヤマケン', '東牟婁郡古座川町', 'ヒガシムログンコザガワチョウ', '峰', 'ミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡古座川町相瀬', '30', '30424', '6494235', '和歌山県', 'ワカヤマケン', '東牟婁郡古座川町', 'ヒガシムログンコザガワチョウ', '相瀬', 'アイセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡古座川町立合川', '30', '30424', '6494236', '和歌山県', 'ワカヤマケン', '東牟婁郡古座川町', 'ヒガシムログンコザガワチョウ', '立合川', 'タチアイガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡古座川町添野川', '30', '30424', '6494441', '和歌山県', 'ワカヤマケン', '東牟婁郡古座川町', 'ヒガシムログンコザガワチョウ', '添野川', 'ソイノガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡古座川町佐田', '30', '30424', '6494442', '和歌山県', 'ワカヤマケン', '東牟婁郡古座川町', 'ヒガシムログンコザガワチョウ', '佐田', 'サダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡古座川町真砂', '30', '30424', '6494443', '和歌山県', 'ワカヤマケン', '東牟婁郡古座川町', 'ヒガシムログンコザガワチョウ', '真砂', 'マナゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡古座川町長追', '30', '30424', '6494444', '和歌山県', 'ワカヤマケン', '東牟婁郡古座川町', 'ヒガシムログンコザガワチョウ', '長追', 'ナガオイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡古座川町大川', '30', '30424', '6494451', '和歌山県', 'ワカヤマケン', '東牟婁郡古座川町', 'ヒガシムログンコザガワチョウ', '大川', 'オオカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡古座川町蔵土', '30', '30424', '6494452', '和歌山県', 'ワカヤマケン', '東牟婁郡古座川町', 'ヒガシムログンコザガワチョウ', '蔵土', 'クロズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡古座川町洞尾', '30', '30424', '6494453', '和歌山県', 'ワカヤマケン', '東牟婁郡古座川町', 'ヒガシムログンコザガワチョウ', '洞尾', 'ウツオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡古座川町南平', '30', '30424', '6494454', '和歌山県', 'ワカヤマケン', '東牟婁郡古座川町', 'ヒガシムログンコザガワチョウ', '南平', 'ナベラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡古座川町三尾川', '30', '30424', '6494455', '和歌山県', 'ワカヤマケン', '東牟婁郡古座川町', 'ヒガシムログンコザガワチョウ', '三尾川', 'ミトガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡古座川町西川', '30', '30424', '6494561', '和歌山県', 'ワカヤマケン', '東牟婁郡古座川町', 'ヒガシムログンコザガワチョウ', '西川', 'ニシカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡古座川町下露', '30', '30424', '6494562', '和歌山県', 'ワカヤマケン', '東牟婁郡古座川町', 'ヒガシムログンコザガワチョウ', '下露', 'シモツユ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡古座川町平井', '30', '30424', '6494563', '和歌山県', 'ワカヤマケン', '東牟婁郡古座川町', 'ヒガシムログンコザガワチョウ', '平井', 'ヒライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡古座川町松根', '30', '30424', '6494564', '和歌山県', 'ワカヤマケン', '東牟婁郡古座川町', 'ヒガシムログンコザガワチョウ', '松根', 'マツネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡古座川町成川', '30', '30424', '6494565', '和歌山県', 'ワカヤマケン', '東牟婁郡古座川町', 'ヒガシムログンコザガワチョウ', '成川', 'ナルカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡太地町', '30', '30422', '6495100', '和歌山県', 'ワカヤマケン', '東牟婁郡太地町', 'ヒガシムログンタイジチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('76840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡那智勝浦町西中野川', '30', '30421', '6495131', '和歌山県', 'ワカヤマケン', '東牟婁郡那智勝浦町', 'ヒガシムログンナチカツウラチョウ', '西中野川', 'ニシナカノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡那智勝浦町中ノ川', '30', '30421', '6495132', '和歌山県', 'ワカヤマケン', '東牟婁郡那智勝浦町', 'ヒガシムログンナチカツウラチョウ', '中ノ川', 'ナカノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡那智勝浦町井鹿', '30', '30421', '6495133', '和歌山県', 'ワカヤマケン', '東牟婁郡那智勝浦町', 'ヒガシムログンナチカツウラチョウ', '井鹿', 'イジシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡那智勝浦町南大居', '30', '30421', '6495134', '和歌山県', 'ワカヤマケン', '東牟婁郡那智勝浦町', 'ヒガシムログンナチカツウラチョウ', '南大居', 'ミナミオオイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡那智勝浦町高遠井', '30', '30421', '6495135', '和歌山県', 'ワカヤマケン', '東牟婁郡那智勝浦町', 'ヒガシムログンナチカツウラチョウ', '高遠井', 'コウドオイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡那智勝浦町長井', '30', '30421', '6495136', '和歌山県', 'ワカヤマケン', '東牟婁郡那智勝浦町', 'ヒガシムログンナチカツウラチョウ', '長井', 'ナガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡那智勝浦町小匠', '30', '30421', '6495137', '和歌山県', 'ワカヤマケン', '東牟婁郡那智勝浦町', 'ヒガシムログンナチカツウラチョウ', '小匠', 'コダクミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡那智勝浦町市屋', '30', '30421', '6495141', '和歌山県', 'ワカヤマケン', '東牟婁郡那智勝浦町', 'ヒガシムログンナチカツウラチョウ', '市屋', 'イチヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡那智勝浦町下里', '30', '30421', '6495142', '和歌山県', 'ワカヤマケン', '東牟婁郡那智勝浦町', 'ヒガシムログンナチカツウラチョウ', '下里', 'シモサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡那智勝浦町八尺鏡野', '30', '30421', '6495143', '和歌山県', 'ワカヤマケン', '東牟婁郡那智勝浦町', 'ヒガシムログンナチカツウラチョウ', '八尺鏡野', 'ヤタガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡那智勝浦町粉白', '30', '30421', '6495144', '和歌山県', 'ワカヤマケン', '東牟婁郡那智勝浦町', 'ヒガシムログンナチカツウラチョウ', '粉白', 'コノシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡那智勝浦町浦神', '30', '30421', '6495145', '和歌山県', 'ワカヤマケン', '東牟婁郡那智勝浦町', 'ヒガシムログンナチカツウラチョウ', '浦神', 'ウラガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡那智勝浦町中里', '30', '30421', '6495146', '和歌山県', 'ワカヤマケン', '東牟婁郡那智勝浦町', 'ヒガシムログンナチカツウラチョウ', '中里', 'ナカサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡那智勝浦町庄', '30', '30421', '6495147', '和歌山県', 'ワカヤマケン', '東牟婁郡那智勝浦町', 'ヒガシムログンナチカツウラチョウ', '庄', 'ショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡那智勝浦町下和田', '30', '30421', '6495148', '和歌山県', 'ワカヤマケン', '東牟婁郡那智勝浦町', 'ヒガシムログンナチカツウラチョウ', '下和田', 'シモワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡太地町太地', '30', '30422', '6495171', '和歌山県', 'ワカヤマケン', '東牟婁郡太地町', 'ヒガシムログンタイジチョウ', '太地', 'タイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡太地町森浦', '30', '30422', '6495172', '和歌山県', 'ワカヤマケン', '東牟婁郡太地町', 'ヒガシムログンタイジチョウ', '森浦', 'モリウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡那智勝浦町', '30', '30421', '6495300', '和歌山県', 'ワカヤマケン', '東牟婁郡那智勝浦町', 'ヒガシムログンナチカツウラチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('76858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡那智勝浦町那智山', '30', '30421', '6495301', '和歌山県', 'ワカヤマケン', '東牟婁郡那智勝浦町', 'ヒガシムログンナチカツウラチョウ', '那智山', 'ナチサン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡那智勝浦町市野々', '30', '30421', '6495302', '和歌山県', 'ワカヤマケン', '東牟婁郡那智勝浦町', 'ヒガシムログンナチカツウラチョウ', '市野々', 'イチノノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡那智勝浦町井関', '30', '30421', '6495303', '和歌山県', 'ワカヤマケン', '東牟婁郡那智勝浦町', 'ヒガシムログンナチカツウラチョウ', '井関', 'イセキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡那智勝浦町川関', '30', '30421', '6495304', '和歌山県', 'ワカヤマケン', '東牟婁郡那智勝浦町', 'ヒガシムログンナチカツウラチョウ', '川関', 'カワセキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡那智勝浦町高津気', '30', '30421', '6495311', '和歌山県', 'ワカヤマケン', '東牟婁郡那智勝浦町', 'ヒガシムログンナチカツウラチョウ', '高津気', 'コウヅケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡那智勝浦町宇久井', '30', '30421', '6495312', '和歌山県', 'ワカヤマケン', '東牟婁郡那智勝浦町', 'ヒガシムログンナチカツウラチョウ', '宇久井', 'ウグイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡那智勝浦町狗子ノ川', '30', '30421', '6495313', '和歌山県', 'ワカヤマケン', '東牟婁郡那智勝浦町', 'ヒガシムログンナチカツウラチョウ', '狗子ノ川', 'クジノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡那智勝浦町浜ノ宮', '30', '30421', '6495314', '和歌山県', 'ワカヤマケン', '東牟婁郡那智勝浦町', 'ヒガシムログンナチカツウラチョウ', '浜ノ宮', 'ハマノミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡那智勝浦町天満', '30', '30421', '6495331', '和歌山県', 'ワカヤマケン', '東牟婁郡那智勝浦町', 'ヒガシムログンナチカツウラチョウ', '天満', 'テンマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡那智勝浦町朝日', '30', '30421', '6495332', '和歌山県', 'ワカヤマケン', '東牟婁郡那智勝浦町', 'ヒガシムログンナチカツウラチョウ', '朝日', 'アサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡那智勝浦町北浜', '30', '30421', '6495333', '和歌山県', 'ワカヤマケン', '東牟婁郡那智勝浦町', 'ヒガシムログンナチカツウラチョウ', '北浜', 'キタハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡那智勝浦町勝浦', '30', '30421', '6495334', '和歌山県', 'ワカヤマケン', '東牟婁郡那智勝浦町', 'ヒガシムログンナチカツウラチョウ', '勝浦', 'カツウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡那智勝浦町築地', '30', '30421', '6495335', '和歌山県', 'ワカヤマケン', '東牟婁郡那智勝浦町', 'ヒガシムログンナチカツウラチョウ', '築地', 'ツキジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡那智勝浦町湯川', '30', '30421', '6495336', '和歌山県', 'ワカヤマケン', '東牟婁郡那智勝浦町', 'ヒガシムログンナチカツウラチョウ', '湯川', 'ユカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡那智勝浦町橋ノ川', '30', '30421', '6495337', '和歌山県', 'ワカヤマケン', '東牟婁郡那智勝浦町', 'ヒガシムログンナチカツウラチョウ', '橋ノ川', 'ハシノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡那智勝浦町二河', '30', '30421', '6495338', '和歌山県', 'ワカヤマケン', '東牟婁郡那智勝浦町', 'ヒガシムログンナチカツウラチョウ', '二河', 'ニコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡那智勝浦町市屋', '30', '30421', '6495339', '和歌山県', 'ワカヤマケン', '東牟婁郡那智勝浦町', 'ヒガシムログンナチカツウラチョウ', '市屋', 'イチヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡那智勝浦町市屋大浦', '30', '30421', '6495339', '和歌山県', 'ワカヤマケン', '東牟婁郡那智勝浦町', 'ヒガシムログンナチカツウラチョウ', '市屋', 'イチヤ', null, null, '大浦', 'オオウラ');
INSERT INTO `ms_addresses` VALUES ('76876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡太地町太地', '30', '30422', '6495371', '和歌山県', 'ワカヤマケン', '東牟婁郡太地町', 'ヒガシムログンタイジチョウ', '太地', 'タイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡那智勝浦町口色川', '30', '30421', '6495451', '和歌山県', 'ワカヤマケン', '東牟婁郡那智勝浦町', 'ヒガシムログンナチカツウラチョウ', '口色川', 'クチイロカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡那智勝浦町小阪', '30', '30421', '6495452', '和歌山県', 'ワカヤマケン', '東牟婁郡那智勝浦町', 'ヒガシムログンナチカツウラチョウ', '小阪', 'コサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡那智勝浦町南平野', '30', '30421', '6495453', '和歌山県', 'ワカヤマケン', '東牟婁郡那智勝浦町', 'ヒガシムログンナチカツウラチョウ', '南平野', 'ミナミヒラノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡那智勝浦町熊瀬川', '30', '30421', '6495454', '和歌山県', 'ワカヤマケン', '東牟婁郡那智勝浦町', 'ヒガシムログンナチカツウラチョウ', '熊瀬川', 'クマセガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡那智勝浦町大野', '30', '30421', '6495461', '和歌山県', 'ワカヤマケン', '東牟婁郡那智勝浦町', 'ヒガシムログンナチカツウラチョウ', '大野', 'オオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡那智勝浦町田垣内', '30', '30421', '6495462', '和歌山県', 'ワカヤマケン', '東牟婁郡那智勝浦町', 'ヒガシムログンナチカツウラチョウ', '田垣内', 'タガイト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡那智勝浦町高野', '30', '30421', '6495463', '和歌山県', 'ワカヤマケン', '東牟婁郡那智勝浦町', 'ヒガシムログンナチカツウラチョウ', '高野', 'タカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡那智勝浦町直柱', '30', '30421', '6495464', '和歌山県', 'ワカヤマケン', '東牟婁郡那智勝浦町', 'ヒガシムログンナチカツウラチョウ', '直柱', 'ヒタハシラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡那智勝浦町坂足', '30', '30421', '6495465', '和歌山県', 'ワカヤマケン', '東牟婁郡那智勝浦町', 'ヒガシムログンナチカツウラチョウ', '坂足', 'サカアシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県東牟婁郡那智勝浦町樫原', '30', '30421', '6495466', '和歌山県', 'ワカヤマケン', '東牟婁郡那智勝浦町', 'ヒガシムログンナチカツウラチョウ', '樫原', 'カシワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市桃山町善田', '30', '30208', '6496101', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '桃山町善田', 'モモヤマチョウゼンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市桃山町黒川', '30', '30208', '6496102', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '桃山町黒川', 'モモヤマチョウクロカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市桃山町野田原', '30', '30208', '6496103', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '桃山町野田原', 'モモヤマチョウノタハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市桃山町脇谷', '30', '30208', '6496104', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '桃山町脇谷', 'モモヤマチョウワキダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市桃山町大原', '30', '30208', '6496105', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '桃山町大原', 'モモヤマチョウオオバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市桃山町最上', '30', '30208', '6496111', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '桃山町最上', 'モモヤマチョウモガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市桃山町調月', '30', '30208', '6496112', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '桃山町調月', 'モモヤマチョウツカツキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市桃山町段新田', '30', '30208', '6496121', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '桃山町段新田', 'モモヤマチョウダンシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市桃山町元', '30', '30208', '6496122', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '桃山町元', 'モモヤマチョウモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市桃山町神田', '30', '30208', '6496123', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '桃山町神田', 'モモヤマチョウコウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市桃山町市場', '30', '30208', '6496124', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '桃山町市場', 'モモヤマチョウイチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市桃山町段', '30', '30208', '6496125', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '桃山町段', 'モモヤマチョウダン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市高野', '30', '30208', '6496161', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '高野', 'タカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市竹房', '30', '30208', '6496162', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '竹房', 'タケブサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県岩出市', '30', '30209', '6496200', '和歌山県', 'ワカヤマケン', '岩出市', 'イワデシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('76903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県岩出市押川', '30', '30209', '6496201', '和歌山県', 'ワカヤマケン', '岩出市', 'イワデシ', '押川', 'オシガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県岩出市根来', '30', '30209', '6496202', '和歌山県', 'ワカヤマケン', '岩出市', 'イワデシ', '根来', 'ネゴロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県岩出市桜台', '30', '30209', '6496203', '和歌山県', 'ワカヤマケン', '岩出市', 'イワデシ', '桜台', 'サクラダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県岩出市今中', '30', '30209', '6496204', '和歌山県', 'ワカヤマケン', '岩出市', 'イワデシ', '今中', 'イマナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県岩出市森', '30', '30209', '6496205', '和歌山県', 'ワカヤマケン', '岩出市', 'イワデシ', '森', 'モリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県岩出市堀口', '30', '30209', '6496206', '和歌山県', 'ワカヤマケン', '岩出市', 'イワデシ', '堀口', 'ホリグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県岩出市尼ケ辻', '30', '30209', '6496207', '和歌山県', 'ワカヤマケン', '岩出市', 'イワデシ', '尼ケ辻', 'アマガツジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県岩出市今畑', '30', '30209', '6496208', '和歌山県', 'ワカヤマケン', '岩出市', 'イワデシ', '今畑', 'イマハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県岩出市東坂本', '30', '30209', '6496211', '和歌山県', 'ワカヤマケン', '岩出市', 'イワデシ', '東坂本', 'ヒガシサカモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県岩出市新田広芝', '30', '30209', '6496212', '和歌山県', 'ワカヤマケン', '岩出市', 'イワデシ', '新田広芝', 'シンデンヒロシバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県岩出市西国分', '30', '30209', '6496213', '和歌山県', 'ワカヤマケン', '岩出市', 'イワデシ', '西国分', 'ニシコクブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県岩出市水栖', '30', '30209', '6496214', '和歌山県', 'ワカヤマケン', '岩出市', 'イワデシ', '水栖', 'ミズス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県岩出市中迫', '30', '30209', '6496215', '和歌山県', 'ワカヤマケン', '岩出市', 'イワデシ', '中迫', 'ナカブサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県岩出市野上野', '30', '30209', '6496216', '和歌山県', 'ワカヤマケン', '岩出市', 'イワデシ', '野上野', 'ノジョノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県岩出市山田', '30', '30209', '6496217', '和歌山県', 'ワカヤマケン', '岩出市', 'イワデシ', '山田', 'ヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県岩出市南大池', '30', '30209', '6496218', '和歌山県', 'ワカヤマケン', '岩出市', 'イワデシ', '南大池', 'ミナミオイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県岩出市北大池', '30', '30209', '6496219', '和歌山県', 'ワカヤマケン', '岩出市', 'イワデシ', '北大池', 'キタオイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県岩出市溝川', '30', '30209', '6496221', '和歌山県', 'ワカヤマケン', '岩出市', 'イワデシ', '溝川', 'ミゾカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県岩出市岡田', '30', '30209', '6496222', '和歌山県', 'ワカヤマケン', '岩出市', 'イワデシ', '岡田', 'オカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県岩出市高塚', '30', '30209', '6496223', '和歌山県', 'ワカヤマケン', '岩出市', 'イワデシ', '高塚', 'タカツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県岩出市山崎', '30', '30209', '6496224', '和歌山県', 'ワカヤマケン', '岩出市', 'イワデシ', '山崎', 'ヤマサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県岩出市船戸', '30', '30209', '6496225', '和歌山県', 'ワカヤマケン', '岩出市', 'イワデシ', '船戸', 'フナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県岩出市宮', '30', '30209', '6496226', '和歌山県', 'ワカヤマケン', '岩出市', 'イワデシ', '宮', 'ミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県岩出市清水', '30', '30209', '6496227', '和歌山県', 'ワカヤマケン', '岩出市', 'イワデシ', '清水', 'シミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県岩出市大町', '30', '30209', '6496228', '和歌山県', 'ワカヤマケン', '岩出市', 'イワデシ', '大町', 'オオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県岩出市川尻', '30', '30209', '6496231', '和歌山県', 'ワカヤマケン', '岩出市', 'イワデシ', '川尻', 'カワシリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県岩出市荊本', '30', '30209', '6496232', '和歌山県', 'ワカヤマケン', '岩出市', 'イワデシ', '荊本', 'イバラモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県岩出市備前', '30', '30209', '6496233', '和歌山県', 'ワカヤマケン', '岩出市', 'イワデシ', '備前', 'ビゼン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県岩出市高瀬', '30', '30209', '6496234', '和歌山県', 'ワカヤマケン', '岩出市', 'イワデシ', '高瀬', 'タカセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県岩出市西野', '30', '30209', '6496235', '和歌山県', 'ワカヤマケン', '岩出市', 'イワデシ', '西野', 'ニシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県岩出市曽屋', '30', '30209', '6496236', '和歌山県', 'ワカヤマケン', '岩出市', 'イワデシ', '曽屋', 'ソウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県岩出市波分', '30', '30209', '6496241', '和歌山県', 'ワカヤマケン', '岩出市', 'イワデシ', '波分', 'ハブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県岩出市赤垣内', '30', '30209', '6496242', '和歌山県', 'ワカヤマケン', '岩出市', 'イワデシ', '赤垣内', 'アカガイト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県岩出市金屋', '30', '30209', '6496243', '和歌山県', 'ワカヤマケン', '岩出市', 'イワデシ', '金屋', 'カナヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県岩出市畑毛', '30', '30209', '6496244', '和歌山県', 'ワカヤマケン', '岩出市', 'イワデシ', '畑毛', 'ハタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県岩出市中島', '30', '30209', '6496245', '和歌山県', 'ワカヤマケン', '岩出市', 'イワデシ', '中島', 'ナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県岩出市吉田', '30', '30209', '6496246', '和歌山県', 'ワカヤマケン', '岩出市', 'イワデシ', '吉田', 'ヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県岩出市中黒', '30', '30209', '6496248', '和歌山県', 'ワカヤマケン', '岩出市', 'イワデシ', '中黒', 'ナカクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県岩出市湯窪', '30', '30209', '6496248', '和歌山県', 'ワカヤマケン', '岩出市', 'イワデシ', '湯窪', 'ユクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県岩出市境谷', '30', '30209', '6496251', '和歌山県', 'ワカヤマケン', '岩出市', 'イワデシ', '境谷', 'サカイダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県岩出市安上', '30', '30209', '6496252', '和歌山県', 'ワカヤマケン', '岩出市', 'イワデシ', '安上', 'アンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県岩出市紀泉台', '30', '30209', '6496253', '和歌山県', 'ワカヤマケン', '岩出市', 'イワデシ', '紀泉台', 'キセンダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県岩出市原', '30', '30209', '6496254', '和歌山県', 'ワカヤマケン', '岩出市', 'イワデシ', '原', 'ハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県岩出市西安上', '30', '30209', '6496255', '和歌山県', 'ワカヤマケン', '岩出市', 'イワデシ', '西安上', 'ニシアンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県岩出市金池', '30', '30209', '6496256', '和歌山県', 'ワカヤマケン', '岩出市', 'イワデシ', '金池', 'カナイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県岩出市相谷', '30', '30209', '6496257', '和歌山県', 'ワカヤマケン', '岩出市', 'イワデシ', '相谷', 'アイダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県岩出市山', '30', '30209', '6496258', '和歌山県', 'ワカヤマケン', '岩出市', 'イワデシ', '山', 'ヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市小倉', '30', '30201', '6496261', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '小倉', 'オグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市上三毛', '30', '30201', '6496262', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '上三毛', 'カミミケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市下三毛', '30', '30201', '6496263', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '下三毛', 'シモミケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市新庄', '30', '30201', '6496264', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '新庄', 'シンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市満屋', '30', '30201', '6496271', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '満屋', 'ミツヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市大垣内', '30', '30201', '6496272', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '大垣内', 'オオガイト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市東田中', '30', '30201', '6496273', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '東田中', 'ヒガシタナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市金谷', '30', '30201', '6496274', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '金谷', 'カナヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市吐前', '30', '30201', '6496275', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '吐前', 'ハンザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市滝畑', '30', '30201', '6496301', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '滝畑', 'タキハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市湯屋谷', '30', '30201', '6496302', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '湯屋谷', 'ユヤダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市平岡', '30', '30201', '6496303', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '平岡', 'ヒラオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市中筋日延', '30', '30201', '6496304', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '中筋日延', 'ナカスジヒノベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市谷', '30', '30201', '6496305', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '谷', 'タニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市上黒谷', '30', '30201', '6496306', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '上黒谷', 'カミクロダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市北別所', '30', '30201', '6496307', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '北別所', 'キタベッシヨ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市落合', '30', '30201', '6496308', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '落合', 'オチアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市里', '30', '30201', '6496311', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '里', 'サト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市川辺', '30', '30201', '6496312', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '川辺', 'カワナベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市楠本', '30', '30201', '6496313', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '楠本', 'クスモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市島', '30', '30201', '6496314', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '島', 'シマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市神波', '30', '30201', '6496315', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '神波', 'コウナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市上野', '30', '30201', '6496316', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '上野', 'ウエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市山口西', '30', '30201', '6496317', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '山口西', 'ヤマグチニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市藤田', '30', '30201', '6496318', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '藤田', 'フジタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市布施屋', '30', '30201', '6496321', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '布施屋', 'ホシヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市和佐関戸', '30', '30201', '6496322', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '和佐関戸', 'ワサセキド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市井ノ口', '30', '30201', '6496323', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '井ノ口', 'イノクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市祢宜', '30', '30201', '6496324', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '祢宜', 'ネギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市下和佐', '30', '30201', '6496325', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '下和佐', 'シモワサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市和佐中', '30', '30201', '6496326', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '和佐中', 'ワサナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市北野', '30', '30201', '6496331', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '北野', 'キタノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市宇田森', '30', '30201', '6496332', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '宇田森', 'ウダモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市永穂', '30', '30201', '6496333', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '永穂', 'ナンゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市北', '30', '30201', '6496334', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '北', 'キタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市西田井', '30', '30201', '6496335', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '西田井', 'ニシタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市小豆島', '30', '30201', '6496336', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '小豆島', 'アズシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市田屋', '30', '30201', '6496337', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '田屋', 'タヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市府中', '30', '30201', '6496338', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '府中', 'フチュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県和歌山市弘西', '30', '30201', '6496339', '和歌山県', 'ワカヤマケン', '和歌山市', 'ワカヤマシ', '弘西', 'ヒロニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市', '30', '30208', '6496400', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('76992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市重行', '30', '30208', '6496401', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '重行', 'シゲキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市北勢田', '30', '30208', '6496402', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '北勢田', 'キタセイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市南勢田', '30', '30208', '6496403', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '南勢田', 'ミナミセイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市赤尾', '30', '30208', '6496404', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '赤尾', 'アカオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市東大井', '30', '30208', '6496405', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '東大井', 'ヒガシオオイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市北大井', '30', '30208', '6496406', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '北大井', 'キタオオイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市池田新', '30', '30208', '6496407', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '池田新', 'イケダシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('76999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市広野', '30', '30208', '6496411', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '広野', 'ヒロノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市黒土', '30', '30208', '6496412', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '黒土', 'クロツチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市竹房', '30', '30208', '6496413', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '竹房', 'タケブサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市打田', '30', '30208', '6496414', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '打田', 'ウチタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市窪', '30', '30208', '6496415', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '窪', 'クボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市上野', '30', '30208', '6496416', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '上野', 'ウエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市西大井', '30', '30208', '6496417', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '西大井', 'ニシオオイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市久留壁', '30', '30208', '6496418', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '久留壁', 'クルベキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市田中馬場', '30', '30208', '6496421', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '田中馬場', 'タナカババ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市花野', '30', '30208', '6496422', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '花野', 'ケヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市尾崎', '30', '30208', '6496423', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '尾崎', 'オザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市畑野上', '30', '30208', '6496424', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '畑野上', 'ハタノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市中井阪', '30', '30208', '6496425', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '中井阪', 'ナカイサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市下井阪', '30', '30208', '6496426', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '下井阪', 'シモイサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市西井阪', '30', '30208', '6496427', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '西井阪', 'ニシイサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市東国分', '30', '30208', '6496428', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '東国分', 'ヒガシコクブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市南中', '30', '30208', '6496431', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '南中', 'ミナミナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市古和田', '30', '30208', '6496432', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '古和田', 'フルワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市西三谷', '30', '30208', '6496433', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '西三谷', 'ニシミタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市中三谷', '30', '30208', '6496434', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '中三谷', 'ナカミタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市東三谷', '30', '30208', '6496435', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '東三谷', 'ヒガシミタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市東山田', '30', '30208', '6496441', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '東山田', 'ヒガシヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市神領', '30', '30208', '6496442', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '神領', 'ジンリョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市北中', '30', '30208', '6496443', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '北中', 'キタナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市登尾', '30', '30208', '6496444', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '登尾', 'ノボリオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市豊田', '30', '30208', '6496445', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '豊田', 'トヨダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市枇杷谷', '30', '30208', '6496446', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '枇杷谷', 'ビワダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市西山田', '30', '30208', '6496447', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '西山田', 'ニシヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市神通', '30', '30208', '6496451', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '神通', 'ジンヅウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市中畑', '30', '30208', '6496452', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '中畑', 'ナカハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市北志野', '30', '30208', '6496501', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '北志野', 'キタシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市北長田', '30', '30208', '6496502', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '北長田', 'キタナガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市長田中', '30', '30208', '6496503', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '長田中', 'ナガタナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市南志野', '30', '30208', '6496504', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '南志野', 'ミナミシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市猪垣', '30', '30208', '6496511', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '猪垣', 'イノカケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市東毛', '30', '30208', '6496512', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '東毛', 'トウゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市中津川', '30', '30208', '6496513', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '中津川', 'ナカツガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市藤井', '30', '30208', '6496514', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '藤井', 'フジイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市馬宿', '30', '30208', '6496521', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '馬宿', 'ウマヤド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市上丹生谷', '30', '30208', '6496522', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '上丹生谷', 'カミニュウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市下丹生谷', '30', '30208', '6496523', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '下丹生谷', 'シモニュウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市西川原', '30', '30208', '6496524', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '西川原', 'ニシカワハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市野上', '30', '30208', '6496525', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '野上', 'ノガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市東川原', '30', '30208', '6496526', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '東川原', 'ヒガシカワハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市粉河', '30', '30208', '6496531', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '粉河', 'コカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市中山', '30', '30208', '6496532', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '中山', 'ナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市井田', '30', '30208', '6496541', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '井田', 'イダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市東野', '30', '30208', '6496542', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '東野', 'ヒガシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市上田井', '30', '30208', '6496551', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '上田井', 'コウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市嶋', '30', '30208', '6496552', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '嶋', 'シマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市深田', '30', '30208', '6496553', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '深田', 'フケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市別所', '30', '30208', '6496554', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '別所', 'ベッシヨ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市松井', '30', '30208', '6496555', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '松井', 'マツイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市荒見', '30', '30208', '6496561', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '荒見', 'アラミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市遠方', '30', '30208', '6496562', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '遠方', 'オチカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市風市', '30', '30208', '6496563', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '風市', 'カザシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市勝神', '30', '30208', '6496564', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '勝神', 'カスカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市杉原', '30', '30208', '6496565', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '杉原', 'スイバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市上鞆渕', '30', '30208', '6496571', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '上鞆渕', 'カミトモブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市下鞆渕', '30', '30208', '6496572', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '下鞆渕', 'シモトモブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市中鞆渕', '30', '30208', '6496573', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '中鞆渕', 'ナカトモブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市名手上', '30', '30208', '6496601', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '名手上', 'ナテカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市平野', '30', '30208', '6496602', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '平野', 'ヒラノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市名手下', '30', '30208', '6496603', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '名手下', 'ナテシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市西野山', '30', '30208', '6496604', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '西野山', 'ニシノヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市江川中', '30', '30208', '6496605', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '江川中', 'エカワナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市切畑', '30', '30208', '6496606', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '切畑', 'キリハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市穴伏', '30', '30208', '6496611', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '穴伏', 'アナブシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市北涌', '30', '30208', '6496612', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '北涌', 'キタワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市横谷', '30', '30208', '6496613', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '横谷', 'ヨコダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市赤沼田', '30', '30208', '6496614', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '赤沼田', 'アカンタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市麻生津中', '30', '30208', '6496615', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '麻生津中', 'オウヅナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市西脇', '30', '30208', '6496616', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '西脇', 'ニシワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市名手西野', '30', '30208', '6496621', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '名手西野', 'ナテニシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市後田', '30', '30208', '6496622', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '後田', 'シレダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市藤崎', '30', '30208', '6496623', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '藤崎', 'フジサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市王子', '30', '30208', '6496624', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '王子', 'オウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県紀の川市名手市場', '30', '30208', '6496631', '和歌山県', 'ワカヤマケン', '紀の川市', 'キノカワシ', '名手市場', 'ナテイチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県伊都郡かつらぎ町', '30', '30341', '6497100', '和歌山県', 'ワカヤマケン', '伊都郡かつらぎ町', 'イトグンカツラギチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('77085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県伊都郡かつらぎ町東谷', '30', '30341', '6497101', '和歌山県', 'ワカヤマケン', '伊都郡かつらぎ町', 'イトグンカツラギチョウ', '東谷', 'ヒガシタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県伊都郡かつらぎ町滝', '30', '30341', '6497102', '和歌山県', 'ワカヤマケン', '伊都郡かつらぎ町', 'イトグンカツラギチョウ', '滝', 'タキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県伊都郡かつらぎ町広口', '30', '30341', '6497103', '和歌山県', 'ワカヤマケン', '伊都郡かつらぎ町', 'イトグンカツラギチョウ', '広口', 'ヒロクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県伊都郡かつらぎ町平', '30', '30341', '6497104', '和歌山県', 'ワカヤマケン', '伊都郡かつらぎ町', 'イトグンカツラギチョウ', '平', 'タイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県伊都郡かつらぎ町大畑', '30', '30341', '6497111', '和歌山県', 'ワカヤマケン', '伊都郡かつらぎ町', 'イトグンカツラギチョウ', '大畑', 'オオハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県伊都郡かつらぎ町中飯降', '30', '30341', '6497112', '和歌山県', 'ワカヤマケン', '伊都郡かつらぎ町', 'イトグンカツラギチョウ', '中飯降', 'ナカイブリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県伊都郡かつらぎ町妙寺', '30', '30341', '6497113', '和歌山県', 'ワカヤマケン', '伊都郡かつらぎ町', 'イトグンカツラギチョウ', '妙寺', 'ミョウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県伊都郡かつらぎ町西飯降', '30', '30341', '6497114', '和歌山県', 'ワカヤマケン', '伊都郡かつらぎ町', 'イトグンカツラギチョウ', '西飯降', 'ニシイブリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県伊都郡かつらぎ町短野', '30', '30341', '6497115', '和歌山県', 'ワカヤマケン', '伊都郡かつらぎ町', 'イトグンカツラギチョウ', '短野', 'ミジカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県伊都郡かつらぎ町丁ノ町', '30', '30341', '6497121', '和歌山県', 'ワカヤマケン', '伊都郡かつらぎ町', 'イトグンカツラギチョウ', '丁ノ町', 'チョウノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県伊都郡かつらぎ町新田', '30', '30341', '6497122', '和歌山県', 'ワカヤマケン', '伊都郡かつらぎ町', 'イトグンカツラギチョウ', '新田', 'シンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県伊都郡かつらぎ町柏木', '30', '30341', '6497123', '和歌山県', 'ワカヤマケン', '伊都郡かつらぎ町', 'イトグンカツラギチョウ', '柏木', 'カシワギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県伊都郡かつらぎ町山崎', '30', '30341', '6497131', '和歌山県', 'ワカヤマケン', '伊都郡かつらぎ町', 'イトグンカツラギチョウ', '山崎', 'ヤマサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県伊都郡かつらぎ町教良寺', '30', '30341', '6497132', '和歌山県', 'ワカヤマケン', '伊都郡かつらぎ町', 'イトグンカツラギチョウ', '教良寺', 'キョウラジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県伊都郡かつらぎ町三谷', '30', '30341', '6497133', '和歌山県', 'ワカヤマケン', '伊都郡かつらぎ町', 'イトグンカツラギチョウ', '三谷', 'ミタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県伊都郡かつらぎ町宮本', '30', '30341', '6497134', '和歌山県', 'ワカヤマケン', '伊都郡かつらぎ町', 'イトグンカツラギチョウ', '宮本', 'ミヤモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県伊都郡かつらぎ町平沼田', '30', '30341', '6497135', '和歌山県', 'ワカヤマケン', '伊都郡かつらぎ町', 'イトグンカツラギチョウ', '平沼田', 'ヒランタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県伊都郡かつらぎ町寺尾', '30', '30341', '6497136', '和歌山県', 'ワカヤマケン', '伊都郡かつらぎ町', 'イトグンカツラギチョウ', '寺尾', 'テラオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県伊都郡かつらぎ町兄井', '30', '30341', '6497137', '和歌山県', 'ワカヤマケン', '伊都郡かつらぎ町', 'イトグンカツラギチョウ', '兄井', 'アニイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県伊都郡かつらぎ町上天野', '30', '30341', '6497141', '和歌山県', 'ワカヤマケン', '伊都郡かつらぎ町', 'イトグンカツラギチョウ', '上天野', 'カミアマノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県伊都郡かつらぎ町下天野', '30', '30341', '6497142', '和歌山県', 'ワカヤマケン', '伊都郡かつらぎ町', 'イトグンカツラギチョウ', '下天野', 'シモアマノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県伊都郡かつらぎ町神田', '30', '30341', '6497143', '和歌山県', 'ワカヤマケン', '伊都郡かつらぎ町', 'イトグンカツラギチョウ', '神田', 'コウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県伊都郡かつらぎ町志賀', '30', '30341', '6497144', '和歌山県', 'ワカヤマケン', '伊都郡かつらぎ町', 'イトグンカツラギチョウ', '志賀', 'シガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県伊都郡かつらぎ町日高', '30', '30341', '6497145', '和歌山県', 'ワカヤマケン', '伊都郡かつらぎ町', 'イトグンカツラギチョウ', '日高', 'ヒダカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県伊都郡かつらぎ町星山', '30', '30341', '6497146', '和歌山県', 'ワカヤマケン', '伊都郡かつらぎ町', 'イトグンカツラギチョウ', '星山', 'ホシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県伊都郡かつらぎ町東渋田', '30', '30341', '6497151', '和歌山県', 'ワカヤマケン', '伊都郡かつらぎ町', 'イトグンカツラギチョウ', '東渋田', 'ヒガシシブタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県伊都郡かつらぎ町星川', '30', '30341', '6497152', '和歌山県', 'ワカヤマケン', '伊都郡かつらぎ町', 'イトグンカツラギチョウ', '星川', 'ホシカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県伊都郡かつらぎ町御所', '30', '30341', '6497153', '和歌山県', 'ワカヤマケン', '伊都郡かつらぎ町', 'イトグンカツラギチョウ', '御所', 'ゴセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県伊都郡かつらぎ町西渋田', '30', '30341', '6497154', '和歌山県', 'ワカヤマケン', '伊都郡かつらぎ町', 'イトグンカツラギチョウ', '西渋田', 'ニシシブタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県伊都郡かつらぎ町島', '30', '30341', '6497155', '和歌山県', 'ワカヤマケン', '伊都郡かつらぎ町', 'イトグンカツラギチョウ', '島', 'シマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県伊都郡かつらぎ町笠田東', '30', '30341', '6497161', '和歌山県', 'ワカヤマケン', '伊都郡かつらぎ町', 'イトグンカツラギチョウ', '笠田東', 'カセダヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県伊都郡かつらぎ町笠田中', '30', '30341', '6497162', '和歌山県', 'ワカヤマケン', '伊都郡かつらぎ町', 'イトグンカツラギチョウ', '笠田中', 'カセダナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県伊都郡かつらぎ町萩原', '30', '30341', '6497163', '和歌山県', 'ワカヤマケン', '伊都郡かつらぎ町', 'イトグンカツラギチョウ', '萩原', 'ハギハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県伊都郡かつらぎ町窪', '30', '30341', '6497164', '和歌山県', 'ワカヤマケン', '伊都郡かつらぎ町', 'イトグンカツラギチョウ', '窪', 'クボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県伊都郡かつらぎ町背ノ山', '30', '30341', '6497165', '和歌山県', 'ワカヤマケン', '伊都郡かつらぎ町', 'イトグンカツラギチョウ', '背ノ山', 'セノヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県伊都郡かつらぎ町高田', '30', '30341', '6497166', '和歌山県', 'ワカヤマケン', '伊都郡かつらぎ町', 'イトグンカツラギチョウ', '高田', 'タカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県伊都郡かつらぎ町移', '30', '30341', '6497167', '和歌山県', 'ワカヤマケン', '伊都郡かつらぎ町', 'イトグンカツラギチョウ', '移', 'ウツリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県伊都郡かつらぎ町大薮', '30', '30341', '6497171', '和歌山県', 'ワカヤマケン', '伊都郡かつらぎ町', 'イトグンカツラギチョウ', '大薮', 'オオヤブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県伊都郡かつらぎ町蛭子', '30', '30341', '6497172', '和歌山県', 'ワカヤマケン', '伊都郡かつらぎ町', 'イトグンカツラギチョウ', '蛭子', 'エビス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県伊都郡かつらぎ町大谷', '30', '30341', '6497173', '和歌山県', 'ワカヤマケン', '伊都郡かつらぎ町', 'イトグンカツラギチョウ', '大谷', 'オオタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県伊都郡かつらぎ町佐野', '30', '30341', '6497174', '和歌山県', 'ワカヤマケン', '伊都郡かつらぎ町', 'イトグンカツラギチョウ', '佐野', 'サヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県伊都郡かつらぎ町広浦', '30', '30341', '6497175', '和歌山県', 'ワカヤマケン', '伊都郡かつらぎ町', 'イトグンカツラギチョウ', '広浦', 'ヒロウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県橋本市高野口町応其', '30', '30203', '6497201', '和歌山県', 'ワカヤマケン', '橋本市', 'ハシモトシ', '高野口町応其', 'コウヤグチチョウオウゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県橋本市高野口町伏原', '30', '30203', '6497202', '和歌山県', 'ワカヤマケン', '橋本市', 'ハシモトシ', '高野口町伏原', 'コウヤグチチョウフシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県橋本市高野口町名古曽', '30', '30203', '6497203', '和歌山県', 'ワカヤマケン', '橋本市', 'ハシモトシ', '高野口町名古曽', 'コウヤグチチョウナゴソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県橋本市高野口町小田', '30', '30203', '6497204', '和歌山県', 'ワカヤマケン', '橋本市', 'ハシモトシ', '高野口町小田', 'コウヤグチチョウオダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県橋本市高野口町名倉', '30', '30203', '6497205', '和歌山県', 'ワカヤマケン', '橋本市', 'ハシモトシ', '高野口町名倉', 'コウヤグチチョウナグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県橋本市高野口町向島', '30', '30203', '6497206', '和歌山県', 'ワカヤマケン', '橋本市', 'ハシモトシ', '高野口町向島', 'コウヤグチチョウムコウジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県橋本市高野口町大野', '30', '30203', '6497207', '和歌山県', 'ワカヤマケン', '橋本市', 'ハシモトシ', '高野口町大野', 'コウヤグチチョウオオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県橋本市高野口町下中', '30', '30203', '6497211', '和歌山県', 'ワカヤマケン', '橋本市', 'ハシモトシ', '高野口町下中', 'コウヤグチチョウシモナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県橋本市高野口町上中', '30', '30203', '6497212', '和歌山県', 'ワカヤマケン', '橋本市', 'ハシモトシ', '高野口町上中', 'コウヤグチチョウカミナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県橋本市高野口町嵯峨谷', '30', '30203', '6497213', '和歌山県', 'ワカヤマケン', '橋本市', 'ハシモトシ', '高野口町嵯峨谷', 'コウヤグチチョウサガタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県橋本市高野口町竹尾', '30', '30203', '6497214', '和歌山県', 'ワカヤマケン', '橋本市', 'ハシモトシ', '高野口町竹尾', 'コウヤグチチョウタケオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県橋本市高野口町九重', '30', '30203', '6497215', '和歌山県', 'ワカヤマケン', '橋本市', 'ハシモトシ', '高野口町九重', 'コウヤグチチョウクジュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '和歌山県橋本市高野口町田原', '30', '30203', '6497216', '和歌山県', 'ワカヤマケン', '橋本市', 'ハシモトシ', '高野口町田原', 'コウヤグチチョウタワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区', '01', '01103', '0650000', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('77144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市中央区', '28', '28110', '6500000', '兵庫県', 'ヒョウゴケン', '神戸市中央区', 'コウベシチュウオウク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('77145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区', '28', '28111', '6500000', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('77146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市中央区加納町', '28', '28110', '6500001', '兵庫県', 'ヒョウゴケン', '神戸市中央区', 'コウベシチュウオウク', '加納町', 'カノウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市中央区北野町', '28', '28110', '6500002', '兵庫県', 'ヒョウゴケン', '神戸市中央区', 'コウベシチュウオウク', '北野町', 'キタノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市中央区山本通', '28', '28110', '6500003', '兵庫県', 'ヒョウゴケン', '神戸市中央区', 'コウベシチュウオウク', '山本通', 'ヤマモトドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市中央区中山手通', '28', '28110', '6500004', '兵庫県', 'ヒョウゴケン', '神戸市中央区', 'コウベシチュウオウク', '中山手通', 'ナカヤマテドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市中央区再度筋町', '28', '28110', '6500005', '兵庫県', 'ヒョウゴケン', '神戸市中央区', 'コウベシチュウオウク', '再度筋町', 'フタタビスジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市中央区諏訪山町', '28', '28110', '6500006', '兵庫県', 'ヒョウゴケン', '神戸市中央区', 'コウベシチュウオウク', '諏訪山町', 'スワヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市中央区神戸港地方', '28', '28110', '6500007', '兵庫県', 'ヒョウゴケン', '神戸市中央区', 'コウベシチュウオウク', '神戸港地方', 'コウベコウジカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市中央区下山手通', '28', '28110', '6500011', '兵庫県', 'ヒョウゴケン', '神戸市中央区', 'コウベシチュウオウク', '下山手通', 'シモヤマテドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市中央区北長狭通', '28', '28110', '6500012', '兵庫県', 'ヒョウゴケン', '神戸市中央区', 'コウベシチュウオウク', '北長狭通', 'キタナガサドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市中央区花隈町', '28', '28110', '6500013', '兵庫県', 'ヒョウゴケン', '神戸市中央区', 'コウベシチュウオウク', '花隈町', 'ハナクマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市中央区元町高架通', '28', '28110', '6500014', '兵庫県', 'ヒョウゴケン', '神戸市中央区', 'コウベシチュウオウク', '元町高架通', 'モトマチコウカドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市中央区多聞通', '28', '28110', '6500015', '兵庫県', 'ヒョウゴケン', '神戸市中央区', 'コウベシチュウオウク', '多聞通', 'タモンドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市中央区橘通', '28', '28110', '6500016', '兵庫県', 'ヒョウゴケン', '神戸市中央区', 'コウベシチュウオウク', '橘通', 'タチバナドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市中央区楠町', '28', '28110', '6500017', '兵庫県', 'ヒョウゴケン', '神戸市中央区', 'コウベシチュウオウク', '楠町', 'クスノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市中央区三宮町', '28', '28110', '6500021', '兵庫県', 'ヒョウゴケン', '神戸市中央区', 'コウベシチュウオウク', '三宮町', 'サンノミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市中央区元町通', '28', '28110', '6500022', '兵庫県', 'ヒョウゴケン', '神戸市中央区', 'コウベシチュウオウク', '元町通', 'モトマチドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市中央区栄町通', '28', '28110', '6500023', '兵庫県', 'ヒョウゴケン', '神戸市中央区', 'コウベシチュウオウク', '栄町通', 'サカエマチドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市中央区海岸通', '28', '28110', '6500024', '兵庫県', 'ヒョウゴケン', '神戸市中央区', 'コウベシチュウオウク', '海岸通', 'カイガンドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市中央区相生町', '28', '28110', '6500025', '兵庫県', 'ヒョウゴケン', '神戸市中央区', 'コウベシチュウオウク', '相生町', 'アイオイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市中央区古湊通', '28', '28110', '6500026', '兵庫県', 'ヒョウゴケン', '神戸市中央区', 'コウベシチュウオウク', '古湊通', 'コミナトドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市中央区中町通', '28', '28110', '6500027', '兵庫県', 'ヒョウゴケン', '神戸市中央区', 'コウベシチュウオウク', '中町通', 'ナカマチドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市中央区東町', '28', '28110', '6500031', '兵庫県', 'ヒョウゴケン', '神戸市中央区', 'コウベシチュウオウク', '東町', 'ヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市中央区伊藤町', '28', '28110', '6500032', '兵庫県', 'ヒョウゴケン', '神戸市中央区', 'コウベシチュウオウク', '伊藤町', 'イトウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市中央区江戸町', '28', '28110', '6500033', '兵庫県', 'ヒョウゴケン', '神戸市中央区', 'コウベシチュウオウク', '江戸町', 'エドマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市中央区京町', '28', '28110', '6500034', '兵庫県', 'ヒョウゴケン', '神戸市中央区', 'コウベシチュウオウク', '京町', 'キョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市中央区浪花町', '28', '28110', '6500035', '兵庫県', 'ヒョウゴケン', '神戸市中央区', 'コウベシチュウオウク', '浪花町', 'ナニワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市中央区播磨町', '28', '28110', '6500036', '兵庫県', 'ヒョウゴケン', '神戸市中央区', 'コウベシチュウオウク', '播磨町', 'ハリママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市中央区明石町', '28', '28110', '6500037', '兵庫県', 'ヒョウゴケン', '神戸市中央区', 'コウベシチュウオウク', '明石町', 'アカシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市中央区西町', '28', '28110', '6500038', '兵庫県', 'ヒョウゴケン', '神戸市中央区', 'コウベシチュウオウク', '西町', 'ニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市中央区前町', '28', '28110', '6500039', '兵庫県', 'ヒョウゴケン', '神戸市中央区', 'コウベシチュウオウク', '前町', 'マエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北4条東9丁目', '01', '01103', '0650004', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北4条東', 'キタ04ジョウヒガシ', null, null, '9丁目', '09チョウメ');
INSERT INTO `ms_addresses` VALUES ('77177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北4条東10丁目', '01', '01103', '0650004', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北4条東', 'キタ04ジョウヒガシ', null, null, '10丁目', '10チョウメ');
INSERT INTO `ms_addresses` VALUES ('77178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北4条東11丁目', '01', '01103', '0650004', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北4条東', 'キタ04ジョウヒガシ', null, null, '11丁目', '11チョウメ');
INSERT INTO `ms_addresses` VALUES ('77179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北4条東12丁目', '01', '01103', '0650004', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北4条東', 'キタ04ジョウヒガシ', null, null, '12丁目', '12チョウメ');
INSERT INTO `ms_addresses` VALUES ('77180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北4条東13丁目', '01', '01103', '0650004', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北4条東', 'キタ04ジョウヒガシ', null, null, '13丁目', '13チョウメ');
INSERT INTO `ms_addresses` VALUES ('77181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北4条東14丁目', '01', '01103', '0650004', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北4条東', 'キタ04ジョウヒガシ', null, null, '14丁目', '14チョウメ');
INSERT INTO `ms_addresses` VALUES ('77182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北4条東15丁目', '01', '01103', '0650004', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北4条東', 'キタ04ジョウヒガシ', null, null, '15丁目', '15チョウメ');
INSERT INTO `ms_addresses` VALUES ('77183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北4条東16丁目', '01', '01103', '0650004', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北4条東', 'キタ04ジョウヒガシ', null, null, '16丁目', '16チョウメ');
INSERT INTO `ms_addresses` VALUES ('77184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市中央区新港町', '28', '28110', '6500041', '兵庫県', 'ヒョウゴケン', '神戸市中央区', 'コウベシチュウオウク', '新港町', 'シンコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市中央区波止場町', '28', '28110', '6500042', '兵庫県', 'ヒョウゴケン', '神戸市中央区', 'コウベシチュウオウク', '波止場町', 'ハトバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市中央区弁天町', '28', '28110', '6500043', '兵庫県', 'ヒョウゴケン', '神戸市中央区', 'コウベシチュウオウク', '弁天町', 'ベンテンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市中央区東川崎町', '28', '28110', '6500044', '兵庫県', 'ヒョウゴケン', '神戸市中央区', 'コウベシチュウオウク', '東川崎町', 'ヒガシカワサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市中央区港島', '28', '28110', '6500045', '兵庫県', 'ヒョウゴケン', '神戸市中央区', 'コウベシチュウオウク', '港島', 'ミナトジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市中央区港島中町', '28', '28110', '6500046', '兵庫県', 'ヒョウゴケン', '神戸市中央区', 'コウベシチュウオウク', '港島中町', 'ミナトジマナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市中央区港島南町', '28', '28110', '6500047', '兵庫県', 'ヒョウゴケン', '神戸市中央区', 'コウベシチュウオウク', '港島南町', 'ミナトジマミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市中央区神戸空港', '28', '28110', '6500048', '兵庫県', 'ヒョウゴケン', '神戸市中央区', 'コウベシチュウオウク', '神戸空港', 'コウベクウコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北5条東8丁目', '01', '01103', '0650005', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北5条東', 'キタ05ジョウヒガシ', null, null, '8丁目', '08チョウメ');
INSERT INTO `ms_addresses` VALUES ('77193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北5条東9丁目', '01', '01103', '0650005', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北5条東', 'キタ05ジョウヒガシ', null, null, '9丁目', '09チョウメ');
INSERT INTO `ms_addresses` VALUES ('77194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北5条東10丁目', '01', '01103', '0650005', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北5条東', 'キタ05ジョウヒガシ', null, null, '10丁目', '10チョウメ');
INSERT INTO `ms_addresses` VALUES ('77195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北5条東11丁目', '01', '01103', '0650005', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北5条東', 'キタ05ジョウヒガシ', null, null, '11丁目', '11チョウメ');
INSERT INTO `ms_addresses` VALUES ('77196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北5条東12丁目', '01', '01103', '0650005', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北5条東', 'キタ05ジョウヒガシ', null, null, '12丁目', '12チョウメ');
INSERT INTO `ms_addresses` VALUES ('77197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北5条東13丁目', '01', '01103', '0650005', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北5条東', 'キタ05ジョウヒガシ', null, null, '13丁目', '13チョウメ');
INSERT INTO `ms_addresses` VALUES ('77198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北5条東14丁目', '01', '01103', '0650005', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北5条東', 'キタ05ジョウヒガシ', null, null, '14丁目', '14チョウメ');
INSERT INTO `ms_addresses` VALUES ('77199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北5条東15丁目', '01', '01103', '0650005', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北5条東', 'キタ05ジョウヒガシ', null, null, '15丁目', '15チョウメ');
INSERT INTO `ms_addresses` VALUES ('77200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北5条東16丁目', '01', '01103', '0650005', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北5条東', 'キタ05ジョウヒガシ', null, null, '16丁目', '16チョウメ');
INSERT INTO `ms_addresses` VALUES ('77201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北5条東17丁目', '01', '01103', '0650005', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北5条東', 'キタ05ジョウヒガシ', null, null, '17丁目', '17チョウメ');
INSERT INTO `ms_addresses` VALUES ('77202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北6条東8丁目', '01', '01103', '0650006', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北6条東', 'キタ06ジョウヒガシ', null, null, '8丁目', '08チョウメ');
INSERT INTO `ms_addresses` VALUES ('77203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北6条東9丁目', '01', '01103', '0650006', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北6条東', 'キタ06ジョウヒガシ', null, null, '9丁目', '09チョウメ');
INSERT INTO `ms_addresses` VALUES ('77204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北6条東10丁目', '01', '01103', '0650006', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北6条東', 'キタ06ジョウヒガシ', null, null, '10丁目', '10チョウメ');
INSERT INTO `ms_addresses` VALUES ('77205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北6条東11丁目', '01', '01103', '0650006', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北6条東', 'キタ06ジョウヒガシ', null, null, '11丁目', '11チョウメ');
INSERT INTO `ms_addresses` VALUES ('77206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北6条東12丁目', '01', '01103', '0650006', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北6条東', 'キタ06ジョウヒガシ', null, null, '12丁目', '12チョウメ');
INSERT INTO `ms_addresses` VALUES ('77207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北6条東13丁目', '01', '01103', '0650006', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北6条東', 'キタ06ジョウヒガシ', null, null, '13丁目', '13チョウメ');
INSERT INTO `ms_addresses` VALUES ('77208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北6条東14丁目', '01', '01103', '0650006', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北6条東', 'キタ06ジョウヒガシ', null, null, '14丁目', '14チョウメ');
INSERT INTO `ms_addresses` VALUES ('77209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北6条東15丁目', '01', '01103', '0650006', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北6条東', 'キタ06ジョウヒガシ', null, null, '15丁目', '15チョウメ');
INSERT INTO `ms_addresses` VALUES ('77210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北6条東16丁目', '01', '01103', '0650006', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北6条東', 'キタ06ジョウヒガシ', null, null, '16丁目', '16チョウメ');
INSERT INTO `ms_addresses` VALUES ('77211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北6条東17丁目', '01', '01103', '0650006', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北6条東', 'キタ06ジョウヒガシ', null, null, '17丁目', '17チョウメ');
INSERT INTO `ms_addresses` VALUES ('77212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北6条東18丁目', '01', '01103', '0650006', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北6条東', 'キタ06ジョウヒガシ', null, null, '18丁目', '18チョウメ');
INSERT INTO `ms_addresses` VALUES ('77213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北6条東19丁目', '01', '01103', '0650006', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北6条東', 'キタ06ジョウヒガシ', null, null, '19丁目', '19チョウメ');
INSERT INTO `ms_addresses` VALUES ('77214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北6条東20丁目', '01', '01103', '0650006', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北6条東', 'キタ06ジョウヒガシ', null, null, '20丁目', '20チョウメ');
INSERT INTO `ms_addresses` VALUES ('77215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北7条東8丁目', '01', '01103', '0650007', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北7条東', 'キタ07ジョウヒガシ', null, null, '8丁目', '08チョウメ');
INSERT INTO `ms_addresses` VALUES ('77216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北7条東9丁目', '01', '01103', '0650007', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北7条東', 'キタ07ジョウヒガシ', null, null, '9丁目', '09チョウメ');
INSERT INTO `ms_addresses` VALUES ('77217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北7条東10丁目', '01', '01103', '0650007', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北7条東', 'キタ07ジョウヒガシ', null, null, '10丁目', '10チョウメ');
INSERT INTO `ms_addresses` VALUES ('77218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北7条東11丁目', '01', '01103', '0650007', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北7条東', 'キタ07ジョウヒガシ', null, null, '11丁目', '11チョウメ');
INSERT INTO `ms_addresses` VALUES ('77219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北7条東12丁目', '01', '01103', '0650007', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北7条東', 'キタ07ジョウヒガシ', null, null, '12丁目', '12チョウメ');
INSERT INTO `ms_addresses` VALUES ('77220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北7条東13丁目', '01', '01103', '0650007', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北7条東', 'キタ07ジョウヒガシ', null, null, '13丁目', '13チョウメ');
INSERT INTO `ms_addresses` VALUES ('77221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北7条東14丁目', '01', '01103', '0650007', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北7条東', 'キタ07ジョウヒガシ', null, null, '14丁目', '14チョウメ');
INSERT INTO `ms_addresses` VALUES ('77222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北7条東15丁目', '01', '01103', '0650007', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北7条東', 'キタ07ジョウヒガシ', null, null, '15丁目', '15チョウメ');
INSERT INTO `ms_addresses` VALUES ('77223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北7条東16丁目', '01', '01103', '0650007', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北7条東', 'キタ07ジョウヒガシ', null, null, '16丁目', '16チョウメ');
INSERT INTO `ms_addresses` VALUES ('77224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北7条東17丁目', '01', '01103', '0650007', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北7条東', 'キタ07ジョウヒガシ', null, null, '17丁目', '17チョウメ');
INSERT INTO `ms_addresses` VALUES ('77225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北7条東18丁目', '01', '01103', '0650007', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北7条東', 'キタ07ジョウヒガシ', null, null, '18丁目', '18チョウメ');
INSERT INTO `ms_addresses` VALUES ('77226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北7条東19丁目', '01', '01103', '0650007', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北7条東', 'キタ07ジョウヒガシ', null, null, '19丁目', '19チョウメ');
INSERT INTO `ms_addresses` VALUES ('77227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北7条東20丁目', '01', '01103', '0650007', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北7条東', 'キタ07ジョウヒガシ', null, null, '20丁目', '20チョウメ');
INSERT INTO `ms_addresses` VALUES ('77228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北8条東8丁目', '01', '01103', '0650008', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北8条東', 'キタ08ジョウヒガシ', null, null, '8丁目', '08チョウメ');
INSERT INTO `ms_addresses` VALUES ('77229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北8条東9丁目', '01', '01103', '0650008', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北8条東', 'キタ08ジョウヒガシ', null, null, '9丁目', '09チョウメ');
INSERT INTO `ms_addresses` VALUES ('77230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北8条東10丁目', '01', '01103', '0650008', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北8条東', 'キタ08ジョウヒガシ', null, null, '10丁目', '10チョウメ');
INSERT INTO `ms_addresses` VALUES ('77231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北8条東11丁目', '01', '01103', '0650008', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北8条東', 'キタ08ジョウヒガシ', null, null, '11丁目', '11チョウメ');
INSERT INTO `ms_addresses` VALUES ('77232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北8条東12丁目', '01', '01103', '0650008', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北8条東', 'キタ08ジョウヒガシ', null, null, '12丁目', '12チョウメ');
INSERT INTO `ms_addresses` VALUES ('77233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北8条東13丁目', '01', '01103', '0650008', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北8条東', 'キタ08ジョウヒガシ', null, null, '13丁目', '13チョウメ');
INSERT INTO `ms_addresses` VALUES ('77234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北8条東14丁目', '01', '01103', '0650008', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北8条東', 'キタ08ジョウヒガシ', null, null, '14丁目', '14チョウメ');
INSERT INTO `ms_addresses` VALUES ('77235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北8条東15丁目', '01', '01103', '0650008', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北8条東', 'キタ08ジョウヒガシ', null, null, '15丁目', '15チョウメ');
INSERT INTO `ms_addresses` VALUES ('77236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北8条東16丁目', '01', '01103', '0650008', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北8条東', 'キタ08ジョウヒガシ', null, null, '16丁目', '16チョウメ');
INSERT INTO `ms_addresses` VALUES ('77237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北8条東17丁目', '01', '01103', '0650008', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北8条東', 'キタ08ジョウヒガシ', null, null, '17丁目', '17チョウメ');
INSERT INTO `ms_addresses` VALUES ('77238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北8条東18丁目', '01', '01103', '0650008', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北8条東', 'キタ08ジョウヒガシ', null, null, '18丁目', '18チョウメ');
INSERT INTO `ms_addresses` VALUES ('77239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北8条東19丁目', '01', '01103', '0650008', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北8条東', 'キタ08ジョウヒガシ', null, null, '19丁目', '19チョウメ');
INSERT INTO `ms_addresses` VALUES ('77240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北9条東8丁目', '01', '01103', '0650009', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北9条東', 'キタ09ジョウヒガシ', null, null, '8丁目', '08チョウメ');
INSERT INTO `ms_addresses` VALUES ('77241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北9条東9丁目', '01', '01103', '0650009', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北9条東', 'キタ09ジョウヒガシ', null, null, '9丁目', '09チョウメ');
INSERT INTO `ms_addresses` VALUES ('77242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北9条東10丁目', '01', '01103', '0650009', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北9条東', 'キタ09ジョウヒガシ', null, null, '10丁目', '10チョウメ');
INSERT INTO `ms_addresses` VALUES ('77243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北9条東11丁目', '01', '01103', '0650009', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北9条東', 'キタ09ジョウヒガシ', null, null, '11丁目', '11チョウメ');
INSERT INTO `ms_addresses` VALUES ('77244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北9条東12丁目', '01', '01103', '0650009', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北9条東', 'キタ09ジョウヒガシ', null, null, '12丁目', '12チョウメ');
INSERT INTO `ms_addresses` VALUES ('77245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北9条東13丁目', '01', '01103', '0650009', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北9条東', 'キタ09ジョウヒガシ', null, null, '13丁目', '13チョウメ');
INSERT INTO `ms_addresses` VALUES ('77246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北9条東14丁目', '01', '01103', '0650009', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北9条東', 'キタ09ジョウヒガシ', null, null, '14丁目', '14チョウメ');
INSERT INTO `ms_addresses` VALUES ('77247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北9条東15丁目', '01', '01103', '0650009', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北9条東', 'キタ09ジョウヒガシ', null, null, '15丁目', '15チョウメ');
INSERT INTO `ms_addresses` VALUES ('77248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北9条東16丁目', '01', '01103', '0650009', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北9条東', 'キタ09ジョウヒガシ', null, null, '16丁目', '16チョウメ');
INSERT INTO `ms_addresses` VALUES ('77249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北10条東', '01', '01103', '0650010', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北10条東', 'キタ10ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北11条東', '01', '01103', '0650011', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北11条東', 'キタ11ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北12条東', '01', '01103', '0650012', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北12条東', 'キタ12ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北13条東', '01', '01103', '0650013', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北13条東', 'キタ13ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北14条東', '01', '01103', '0650014', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北14条東', 'キタ14ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北15条東', '01', '01103', '0650015', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北15条東', 'キタ15ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北16条東', '01', '01103', '0650016', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北16条東', 'キタ16ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北17条東', '01', '01103', '0650017', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北17条東', 'キタ17ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北18条東', '01', '01103', '0650018', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北18条東', 'キタ18ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北19条東', '01', '01103', '0650019', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北19条東', 'キタ19ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北20条東', '01', '01103', '0650020', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北20条東', 'キタ20ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北21条東', '01', '01103', '0650021', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北21条東', 'キタ21ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北22条東', '01', '01103', '0650022', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北22条東', 'キタ22ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北23条東', '01', '01103', '0650023', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北23条東', 'キタ23ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北24条東', '01', '01103', '0650024', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北24条東', 'キタ24ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北25条東', '01', '01103', '0650025', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北25条東', 'キタ25ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北26条東', '01', '01103', '0650026', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北26条東', 'キタ26ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北27条東', '01', '01103', '0650027', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北27条東', 'キタ27ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北28条東', '01', '01103', '0650028', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北28条東', 'キタ28ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北30条東', '01', '01103', '0650030', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北30条東', 'キタ30ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北31条東', '01', '01103', '0650031', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北31条東', 'キタ31ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北32条東', '01', '01103', '0650032', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北32条東', 'キタ32ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北33条東', '01', '01103', '0650033', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北33条東', 'キタ33ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区本町1条', '01', '01103', '0650041', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '本町1条', 'ホンチョウ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区本町2条', '01', '01103', '0650042', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '本町2条', 'ホンチョウ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区苗穂町', '01', '01103', '0650043', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '苗穂町', 'ナエボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市中央区神仙寺通', '28', '28110', '6510051', '兵庫県', 'ヒョウゴケン', '神戸市中央区', 'コウベシチュウオウク', '神仙寺通', 'シンセンジドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市中央区中島通', '28', '28110', '6510052', '兵庫県', 'ヒョウゴケン', '神戸市中央区', 'コウベシチュウオウク', '中島通', 'ナカジマドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市中央区籠池通', '28', '28110', '6510053', '兵庫県', 'ヒョウゴケン', '神戸市中央区', 'コウベシチュウオウク', '籠池通', 'カゴイケドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市中央区野崎通', '28', '28110', '6510054', '兵庫県', 'ヒョウゴケン', '神戸市中央区', 'コウベシチュウオウク', '野崎通', 'ノザキドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市中央区熊内橋通', '28', '28110', '6510055', '兵庫県', 'ヒョウゴケン', '神戸市中央区', 'コウベシチュウオウク', '熊内橋通', 'クモチバシドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市中央区熊内町', '28', '28110', '6510056', '兵庫県', 'ヒョウゴケン', '神戸市中央区', 'コウベシチュウオウク', '熊内町', 'クモチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市中央区中尾町', '28', '28110', '6510057', '兵庫県', 'ヒョウゴケン', '神戸市中央区', 'コウベシチュウオウク', '中尾町', 'ナカオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市中央区葺合町', '28', '28110', '6510058', '兵庫県', 'ヒョウゴケン', '神戸市中央区', 'コウベシチュウオウク', '葺合町', 'フキアイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市中央区上筒井通', '28', '28110', '6510061', '兵庫県', 'ヒョウゴケン', '神戸市中央区', 'コウベシチュウオウク', '上筒井通', 'カミツツイドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市中央区坂口通', '28', '28110', '6510062', '兵庫県', 'ヒョウゴケン', '神戸市中央区', 'コウベシチュウオウク', '坂口通', 'サカグチドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市中央区宮本通', '28', '28110', '6510063', '兵庫県', 'ヒョウゴケン', '神戸市中央区', 'コウベシチュウオウク', '宮本通', 'ミヤモトドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市中央区大日通', '28', '28110', '6510064', '兵庫県', 'ヒョウゴケン', '神戸市中央区', 'コウベシチュウオウク', '大日通', 'ダイニチドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市中央区割塚通', '28', '28110', '6510065', '兵庫県', 'ヒョウゴケン', '神戸市中央区', 'コウベシチュウオウク', '割塚通', 'ワリヅカドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市中央区国香通', '28', '28110', '6510066', '兵庫県', 'ヒョウゴケン', '神戸市中央区', 'コウベシチュウオウク', '国香通', 'クニカドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市中央区神若通', '28', '28110', '6510067', '兵庫県', 'ヒョウゴケン', '神戸市中央区', 'コウベシチュウオウク', '神若通', 'カミワカドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市中央区旗塚通', '28', '28110', '6510068', '兵庫県', 'ヒョウゴケン', '神戸市中央区', 'コウベシチュウオウク', '旗塚通', 'ハタツカドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市中央区筒井町', '28', '28110', '6510071', '兵庫県', 'ヒョウゴケン', '神戸市中央区', 'コウベシチュウオウク', '筒井町', 'ツツイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市中央区脇浜町', '28', '28110', '6510072', '兵庫県', 'ヒョウゴケン', '神戸市中央区', 'コウベシチュウオウク', '脇浜町', 'ワキノハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市中央区脇浜海岸通', '28', '28110', '6510073', '兵庫県', 'ヒョウゴケン', '神戸市中央区', 'コウベシチュウオウク', '脇浜海岸通', 'ワキノハマカイガンドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市中央区南本町通', '28', '28110', '6510074', '兵庫県', 'ヒョウゴケン', '神戸市中央区', 'コウベシチュウオウク', '南本町通', 'ミナミホンマチドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市中央区北本町通', '28', '28110', '6510075', '兵庫県', 'ヒョウゴケン', '神戸市中央区', 'コウベシチュウオウク', '北本町通', 'キタホンマチドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市中央区吾妻通', '28', '28110', '6510076', '兵庫県', 'ヒョウゴケン', '神戸市中央区', 'コウベシチュウオウク', '吾妻通', 'アヅマドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市中央区日暮通', '28', '28110', '6510077', '兵庫県', 'ヒョウゴケン', '神戸市中央区', 'コウベシチュウオウク', '日暮通', 'ヒグレドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市中央区八雲通', '28', '28110', '6510078', '兵庫県', 'ヒョウゴケン', '神戸市中央区', 'コウベシチュウオウク', '八雲通', 'ヤグモドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市中央区東雲通', '28', '28110', '6510079', '兵庫県', 'ヒョウゴケン', '神戸市中央区', 'コウベシチュウオウク', '東雲通', 'シノノメドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市中央区真砂通', '28', '28110', '6510081', '兵庫県', 'ヒョウゴケン', '神戸市中央区', 'コウベシチュウオウク', '真砂通', 'マサゴドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市中央区小野浜町', '28', '28110', '6510082', '兵庫県', 'ヒョウゴケン', '神戸市中央区', 'コウベシチュウオウク', '小野浜町', 'オノハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市中央区浜辺通', '28', '28110', '6510083', '兵庫県', 'ヒョウゴケン', '神戸市中央区', 'コウベシチュウオウク', '浜辺通', 'ハマベドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市中央区磯辺通', '28', '28110', '6510084', '兵庫県', 'ヒョウゴケン', '神戸市中央区', 'コウベシチュウオウク', '磯辺通', 'イソベドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市中央区八幡通', '28', '28110', '6510085', '兵庫県', 'ヒョウゴケン', '神戸市中央区', 'コウベシチュウオウク', '八幡通', 'ハチマンドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市中央区磯上通', '28', '28110', '6510086', '兵庫県', 'ヒョウゴケン', '神戸市中央区', 'コウベシチュウオウク', '磯上通', 'イソガミドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市中央区御幸通', '28', '28110', '6510087', '兵庫県', 'ヒョウゴケン', '神戸市中央区', 'コウベシチュウオウク', '御幸通', 'ゴコウドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市中央区小野柄通', '28', '28110', '6510088', '兵庫県', 'ヒョウゴケン', '神戸市中央区', 'コウベシチュウオウク', '小野柄通', 'オノエドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市中央区若菜通', '28', '28110', '6510091', '兵庫県', 'ヒョウゴケン', '神戸市中央区', 'コウベシチュウオウク', '若菜通', 'ワカナドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市中央区生田町', '28', '28110', '6510092', '兵庫県', 'ヒョウゴケン', '神戸市中央区', 'コウベシチュウオウク', '生田町', 'イクタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市中央区二宮町', '28', '28110', '6510093', '兵庫県', 'ヒョウゴケン', '神戸市中央区', 'コウベシチュウオウク', '二宮町', 'ニノミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市中央区琴ノ緒町', '28', '28110', '6510094', '兵庫県', 'ヒョウゴケン', '神戸市中央区', 'コウベシチュウオウク', '琴ノ緒町', 'コトノオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市中央区旭通', '28', '28110', '6510095', '兵庫県', 'ヒョウゴケン', '神戸市中央区', 'コウベシチュウオウク', '旭通', 'アサヒドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市中央区雲井通', '28', '28110', '6510096', '兵庫県', 'ヒョウゴケン', '神戸市中央区', 'コウベシチュウオウク', '雲井通', 'クモイドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市中央区布引町', '28', '28110', '6510097', '兵庫県', 'ヒョウゴケン', '神戸市中央区', 'コウベシチュウオウク', '布引町', 'ヌノビキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区', '28', '28109', '6511100', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('77368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区山田町小部', '28', '28109', '6511101', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '山田町小部', 'ヤマダチョウオウブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区山田町下谷上大上谷', '28', '28109', '6511102', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '山田町下谷上', 'ヤマダチョウシモタニガミ', null, null, '大上谷', 'オオカミダニ');
INSERT INTO `ms_addresses` VALUES ('77370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区山田町下谷上修法ケ原', '28', '28109', '6511102', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '山田町下谷上', 'ヤマダチョウシモタニガミ', null, null, '修法ケ原', 'シュウホウガハラ');
INSERT INTO `ms_addresses` VALUES ('77371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区山田町下谷上中一里山', '28', '28109', '6511102', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '山田町下谷上', 'ヤマダチョウシモタニガミ', null, null, '中一里山', 'ナカイチリヤマ');
INSERT INTO `ms_addresses` VALUES ('77372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区山田町下谷上再度公園', '28', '28109', '6511102', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '山田町下谷上', 'ヤマダチョウシモタニガミ', null, null, '再度公園', 'フタタビコウエン');
INSERT INTO `ms_addresses` VALUES ('77373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区中里町', '28', '28109', '6511103', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '中里町', 'ナカザトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区山田町藍那', '28', '28109', '6511104', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '山田町藍那', 'ヤマダチョウアイナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区山田町小河', '28', '28109', '6511105', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '山田町小河', 'ヤマダチョウオウゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区鈴蘭台北町', '28', '28109', '6511111', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '鈴蘭台北町', 'スズランダイキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区鈴蘭台東町', '28', '28109', '6511112', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '鈴蘭台東町', 'スズランダイヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区鈴蘭台南町', '28', '28109', '6511113', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '鈴蘭台南町', 'スズランダイミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区鈴蘭台西町', '28', '28109', '6511114', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '鈴蘭台西町', 'スズランダイニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区星和台', '28', '28109', '6511121', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '星和台', 'セイワダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区君影町', '28', '28109', '6511122', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '君影町', 'キミカゲチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区ひよどり台', '28', '28109', '6511123', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', 'ひよどり台', 'ヒヨドリダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区ひよどり北町', '28', '28109', '6511124', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', 'ひよどり北町', 'ヒヨドリキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区ひよどり台南町', '28', '28109', '6511125', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', 'ひよどり台南町', 'ヒヨドリダイミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区北五葉', '28', '28109', '6511131', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '北五葉', 'キタゴヨウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区南五葉', '28', '28109', '6511132', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '南五葉', 'ミナミゴヨウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区鳴子', '28', '28109', '6511133', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '鳴子', 'ナルコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区泉台', '28', '28109', '6511141', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '泉台', 'イズミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区甲栄台', '28', '28109', '6511142', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '甲栄台', 'コウエイダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区若葉台', '28', '28109', '6511143', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '若葉台', 'ワカバダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区大脇台', '28', '28109', '6511144', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '大脇台', 'オオワキダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区惣山町', '28', '28109', '6511145', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '惣山町', 'ソウヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区杉尾台', '28', '28109', '6511146', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '杉尾台', 'スギオダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区松宮台', '28', '28109', '6511147', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '松宮台', 'マツミヤダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区西大池', '28', '28109', '6511201', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '西大池', 'ニシオオイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区花山中尾台', '28', '28109', '6511202', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '花山中尾台', 'ハナヤマナカオダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区幸陽町', '28', '28109', '6511203', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '幸陽町', 'コウヨウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区花山東町', '28', '28109', '6511204', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '花山東町', 'ハナヤマヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区花山台', '28', '28109', '6511205', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '花山台', 'ハナヤマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区大池見山台', '28', '28109', '6511206', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '大池見山台', 'オオイケミヤマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区小倉台', '28', '28109', '6511211', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '小倉台', 'オグラダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区筑紫が丘', '28', '28109', '6511212', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '筑紫が丘', 'ツクシガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区広陵町', '28', '28109', '6511213', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '広陵町', 'コウリョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区緑町', '28', '28109', '6511221', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '緑町', 'ミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区大原', '28', '28109', '6511222', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '大原', 'オオハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区桂木', '28', '28109', '6511223', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '桂木', 'カツラギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区青葉台', '28', '28109', '6511231', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '青葉台', 'アオバダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区松が枝町', '28', '28109', '6511232', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '松が枝町', 'マツガエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区日の峰', '28', '28109', '6511233', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '日の峰', 'ヒノミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区山田町大池', '28', '28109', '6511241', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '山田町大池', 'ヤマダチョウオオイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区山田町上谷上', '28', '28109', '6511242', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '山田町上谷上', 'ヤマダチョウカミタニガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区山田町下谷上', '28', '28109', '6511243', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '山田町下谷上', 'ヤマダチョウシモタニガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区谷上南町', '28', '28109', '6511244', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '谷上南町', 'タニガミミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区谷上東町', '28', '28109', '6511245', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '谷上東町', 'タニガミヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区谷上西町', '28', '28109', '6511246', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '谷上西町', 'タニガミニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区山田町与左衛門新田', '28', '28109', '6511251', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '山田町与左衛門新田', 'ヤマダチョウヨザエモンシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区山田町原野', '28', '28109', '6511252', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '山田町原野', 'ヤマダチョウハラノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区山田町中', '28', '28109', '6511253', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '山田町中', 'ヤマダチョウナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区山田町福地', '28', '28109', '6511254', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '山田町福地', 'ヤマダチョウフクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区柏尾台', '28', '28109', '6511255', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '柏尾台', 'カシオダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区山田町坂本', '28', '28109', '6511261', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '山田町坂本', 'ヤマダチョウサカモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区山田町東下', '28', '28109', '6511262', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '山田町東下', 'ヤマダチョウヒガシシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区山田町西下', '28', '28109', '6511263', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '山田町西下', 'ヤマダチョウニシシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区山田町衝原', '28', '28109', '6511264', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '山田町衝原', 'ヤマダチョウツクハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区藤原台北町', '28', '28109', '6511301', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '藤原台北町', 'フジワラダイキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区藤原台中町', '28', '28109', '6511302', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '藤原台中町', 'フジワラダイナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区藤原台南町', '28', '28109', '6511303', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '藤原台南町', 'フジワラダイミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区京地', '28', '28109', '6511304', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '京地', 'キョウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区西山', '28', '28109', '6511305', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '西山', 'ニシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区菖蒲が丘', '28', '28109', '6511306', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '菖蒲が丘', 'ショウブガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区有野町二郎', '28', '28109', '6511311', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '有野町二郎', 'アリノチョウニロウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区有野町有野', '28', '28109', '6511312', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '有野町有野', 'アリノチョウアリノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区有野中町', '28', '28109', '6511313', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '有野中町', 'アリノナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区有野台', '28', '28109', '6511321', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '有野台', 'アリノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区東有野台', '28', '28109', '6511322', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '東有野台', 'ヒガシアリノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区有野町唐櫃', '28', '28109', '6511331', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '有野町唐櫃', 'アリノチョウカラト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区唐櫃台', '28', '28109', '6511332', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '唐櫃台', 'カラトダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区東大池', '28', '28109', '6511333', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '東大池', 'ヒガシオオイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区唐櫃六甲台', '28', '28109', '6511334', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '唐櫃六甲台', 'カラトロッコウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区八多町深谷', '28', '28109', '6511341', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '八多町深谷', 'ハタチョウフカタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区八多町柳谷', '28', '28109', '6511342', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '八多町柳谷', 'ハタチョウヤナギダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区八多町附物', '28', '28109', '6511343', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '八多町附物', 'ハタチョウツクモノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区八多町屏風', '28', '28109', '6511344', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '八多町屏風', 'ハタチョウビョウブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区八多町西畑', '28', '28109', '6511345', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '八多町西畑', 'ハタチョウニシハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区八多町中', '28', '28109', '6511351', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '八多町中', 'ハタチョウナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区八多町下小名田', '28', '28109', '6511352', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '八多町下小名田', 'ハタチョウシモオナダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区八多町吉尾', '28', '28109', '6511353', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '八多町吉尾', 'ハタチョウヨシオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区八多町上小名田', '28', '28109', '6511354', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '八多町上小名田', 'ハタチョウカミオナダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区有馬町', '28', '28109', '6511401', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '有馬町', 'アリマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市山口町名来', '28', '28204', '6511411', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '山口町名来', 'ヤマグチチョウナライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市山口町下山口', '28', '28204', '6511412', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '山口町下山口', 'ヤマグチチョウシモヤマグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市北六甲台', '28', '28204', '6511413', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '北六甲台', 'キタロッコウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市山口町上山口', '28', '28204', '6511421', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '山口町上山口', 'ヤマグチチョウカミヤマグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市山口町金仙寺', '28', '28204', '6511422', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '山口町金仙寺', 'ヤマグチチョウキンセンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市山口町船坂', '28', '28204', '6511423', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '山口町船坂', 'ヤマグチチョウフナサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市山口町香花園', '28', '28204', '6511424', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '山口町香花園', 'ヤマグチチョウコウカエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市山口町阪神流通センター', '28', '28204', '6511431', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '山口町阪神流通センター', 'ヤマグチチョウハンシンリュウツウセンター', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市すみれ台', '28', '28204', '6511432', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', 'すみれ台', 'スミレダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市山口町中野', '28', '28204', '6511433', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '山口町中野', 'ヤマグチチョウナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区道場町道場', '28', '28109', '6511501', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '道場町道場', 'ドウジョウチョウドウジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区道場町塩田', '28', '28109', '6511502', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '道場町塩田', 'ドウジョウチョウシオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区道場町生野', '28', '28109', '6511503', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '道場町生野', 'ドウジョウチョウイクノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区道場町平田', '28', '28109', '6511504', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '道場町平田', 'ドウジョウチョウヒラタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区道場町日下部', '28', '28109', '6511505', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '道場町日下部', 'ドウジョウチョウクサカベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区長尾町宅原', '28', '28109', '6511511', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '長尾町宅原', 'ナガオチョウエイバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区長尾町上津', '28', '28109', '6511512', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '長尾町上津', 'ナガオチョウコウヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区鹿の子台北町', '28', '28109', '6511513', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '鹿の子台北町', 'カノコダイキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区鹿の子台南町', '28', '28109', '6511514', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '鹿の子台南町', 'カノコダイミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区上津台', '28', '28109', '6511515', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '上津台', 'コウヅダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区赤松台', '28', '28109', '6511516', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '赤松台', 'アカマツダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区大沢町市原', '28', '28109', '6511521', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '大沢町市原', 'オオゾウチョウイチハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区大沢町上大沢', '28', '28109', '6511522', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '大沢町上大沢', 'オオゾウチョウカミオオゾウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区大沢町神付', '28', '28109', '6511523', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '大沢町神付', 'オオゾウチョウカンヅケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区大沢町中大沢', '28', '28109', '6511524', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '大沢町中大沢', 'オオゾウチョウナカオオゾウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区大沢町日西原', '28', '28109', '6511525', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '大沢町日西原', 'オオゾウチョウヒサイハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区大沢町簾', '28', '28109', '6511526', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '大沢町簾', 'オオゾウチョウスダレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区淡河町北僧尾', '28', '28109', '6511601', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '淡河町北僧尾', 'オウゴチョウキタソオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区淡河町南僧尾', '28', '28109', '6511602', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '淡河町南僧尾', 'オウゴチョウミナミソオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区淡河町淡河', '28', '28109', '6511603', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '淡河町淡河', 'オウゴチョウオウゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区淡河町勝雄', '28', '28109', '6511604', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '淡河町勝雄', 'オウゴチョウカツオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区淡河町中山', '28', '28109', '6511611', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '淡河町中山', 'オウゴチョウナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区淡河町東畑', '28', '28109', '6511612', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '淡河町東畑', 'オウゴチョウヒガシバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区淡河町行原', '28', '28109', '6511613', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '淡河町行原', 'オウゴチョウギョウノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区淡河町木津', '28', '28109', '6511614', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '淡河町木津', 'オウゴチョウキヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区淡河町萩原', '28', '28109', '6511615', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '淡河町萩原', 'オウゴチョウハギワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区淡河町北畑', '28', '28109', '6511616', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '淡河町北畑', 'オウゴチョウキタバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区淡河町神影', '28', '28109', '6511621', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '淡河町神影', 'オウゴチョウミカゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区淡河町神田', '28', '28109', '6511622', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '淡河町神田', 'オウゴチョウコウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区淡河町野瀬', '28', '28109', '6511623', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '淡河町野瀬', 'オウゴチョウノセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区伊川谷町布施畑', '28', '28111', '6512101', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '伊川谷町布施畑', 'イカワダニチョウフセハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区学園東町', '28', '28111', '6512102', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '学園東町', 'ガクエンヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区学園西町', '28', '28111', '6512103', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '学園西町', 'ガクエンニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区伊川谷町長坂', '28', '28111', '6512104', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '伊川谷町長坂', 'イカワダニチョウナガサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区伊川谷町上脇', '28', '28111', '6512105', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '伊川谷町上脇', 'イカワダニチョウカミワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区伊川谷町井吹', '28', '28111', '6512106', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '伊川谷町井吹', 'イカワダニチョウイブキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区伊川谷町小寺', '28', '28111', '6512107', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '伊川谷町小寺', 'イカワダニチョウコデラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区伊川谷町前開', '28', '28111', '6512108', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '伊川谷町前開', 'イカワダニチョウゼンカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区前開南町', '28', '28111', '6512109', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '前開南町', 'ゼンカイミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区池上', '28', '28111', '6512111', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '池上', 'イケガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区大津和', '28', '28111', '6512112', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '大津和', 'オオツワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区伊川谷町有瀬', '28', '28111', '6512113', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '伊川谷町有瀬', 'イカワダニチョウアリセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区今寺', '28', '28111', '6512114', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '今寺', 'イマデラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区伊川谷町別府', '28', '28111', '6512115', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '伊川谷町別府', 'イカワダニチョウベフ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区南別府', '28', '28111', '6512116', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '南別府', 'ミナミベフ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区北別府', '28', '28111', '6512117', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '北別府', 'キタベフ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区和井取', '28', '28111', '6512120', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '和井取', 'ワイドリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区玉津町水谷', '28', '28111', '6512121', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '玉津町水谷', 'タマツチョウミタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区水谷', '28', '28111', '6512121', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '水谷', 'ミタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区玉津町高津橋', '28', '28111', '6512122', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '玉津町高津橋', 'タマツチョウコウヅバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区天王山', '28', '28111', '6512123', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '天王山', 'テンノウザン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区伊川谷町潤和', '28', '28111', '6512124', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '伊川谷町潤和', 'イカワダニチョウジュンナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区玉津町新方', '28', '28111', '6512125', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '玉津町新方', 'タマツチョウシンポウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区玉津町上池', '28', '28111', '6512126', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '玉津町上池', 'タマツチョウカミイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区玉津町西河原', '28', '28111', '6512127', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '玉津町西河原', 'タマツチョウニシガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区玉津町今津', '28', '28111', '6512128', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '玉津町今津', 'タマツチョウイマヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区白水', '28', '28111', '6512129', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '白水', 'シラミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区持子', '28', '28111', '6512131', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '持子', 'モチコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区森友', '28', '28111', '6512132', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '森友', 'モリトモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区枝吉', '28', '28111', '6512133', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '枝吉', 'エダヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区曙町', '28', '28111', '6512134', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '曙町', 'アケボノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区王塚台', '28', '28111', '6512135', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '王塚台', 'オウツカダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区中野', '28', '28111', '6512136', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '中野', 'ナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区玉津町出合', '28', '28111', '6512137', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '玉津町出合', 'タマツチョウデアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区玉津町吉田', '28', '28111', '6512138', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '玉津町吉田', 'タマツチョウヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区天が岡', '28', '28111', '6512141', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '天が岡', 'アマガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区玉津町二ツ屋', '28', '28111', '6512142', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '玉津町二ツ屋', 'タマツチョウフタツヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区二ツ屋', '28', '28111', '6512142', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '二ツ屋', 'フタツヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区玉津町丸塚', '28', '28111', '6512143', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '玉津町丸塚', 'タマツチョウマルヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区丸塚', '28', '28111', '6512143', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '丸塚', 'マルヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区小山', '28', '28111', '6512144', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '小山', 'コヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区玉津町小山', '28', '28111', '6512144', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '玉津町小山', 'タマツチョウコヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区玉津町居住', '28', '28111', '6512145', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '玉津町居住', 'タマツチョウイスミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区宮下', '28', '28111', '6512146', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '宮下', 'ミヤシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区玉津町田中', '28', '28111', '6512147', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '玉津町田中', 'タマツチョウタナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区長畑町', '28', '28111', '6512148', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '長畑町', 'ナガハタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区高雄台', '28', '28111', '6512201', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '高雄台', 'タカオダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区押部谷町西盛', '28', '28111', '6512202', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '押部谷町西盛', 'オシベダニチョウニシモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区押部谷町近江', '28', '28111', '6512203', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '押部谷町近江', 'オシベダニチョウキンコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区押部谷町高和', '28', '28111', '6512204', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '押部谷町高和', 'オシベダニチョウタカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区押部谷町養田', '28', '28111', '6512205', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '押部谷町養田', 'オシベダニチョウヨウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区押部谷町和田', '28', '28111', '6512206', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '押部谷町和田', 'オシベダニチョウワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区押部谷町細田', '28', '28111', '6512207', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '押部谷町細田', 'オシベダニチョウサイタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区押部谷町栄', '28', '28111', '6512211', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '押部谷町栄', 'オシベダニチョウサカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区押部谷町押部', '28', '28111', '6512212', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '押部谷町押部', 'オシベダニチョウオシベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区押部谷町福住', '28', '28111', '6512213', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '押部谷町福住', 'オシベダニチョウフクスミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区富士見が丘', '28', '28111', '6512214', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '富士見が丘', 'フジミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区北山台', '28', '28111', '6512215', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '北山台', 'キタヤマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区美穂が丘', '28', '28111', '6512216', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '美穂が丘', 'ミホガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区月が丘', '28', '28111', '6512217', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '月が丘', 'ツキガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区押部谷町木幡', '28', '28111', '6512221', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '押部谷町木幡', 'オシベダニチョウコバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区押部谷町木津', '28', '28111', '6512222', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '押部谷町木津', 'オシベダニチョウキヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区押部谷町木見', '28', '28111', '6512223', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '押部谷町木見', 'オシベダニチョウコウミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区秋葉台', '28', '28111', '6512224', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '秋葉台', 'アキバダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区桜が丘東町', '28', '28111', '6512225', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '桜が丘東町', 'サクラガオカヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区桜が丘中町', '28', '28111', '6512226', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '桜が丘中町', 'サクラガオカナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区桜が丘西町', '28', '28111', '6512227', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '桜が丘西町', 'サクラガオカニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区見津が丘', '28', '28111', '6512228', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '見津が丘', 'ミツガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区櫨谷町寺谷', '28', '28111', '6512231', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '櫨谷町寺谷', 'ハセタニチョウテラタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区櫨谷町友清', '28', '28111', '6512232', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '櫨谷町友清', 'ハセタニチョウトモキヨ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区櫨谷町福谷', '28', '28111', '6512233', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '櫨谷町福谷', 'ハセタニチョウフクタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区櫨谷町池谷', '28', '28111', '6512234', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '櫨谷町池谷', 'ハセタニチョウイケタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区櫨谷町長谷', '28', '28111', '6512235', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '櫨谷町長谷', 'ハセタニチョウハセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区櫨谷町栃木', '28', '28111', '6512236', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '櫨谷町栃木', 'ハセタニチョウトチノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区櫨谷町谷口', '28', '28111', '6512237', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '櫨谷町谷口', 'ハセタニチョウタニグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区櫨谷町菅野', '28', '28111', '6512238', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '櫨谷町菅野', 'ハセタニチョウスガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区櫨谷町松本', '28', '28111', '6512239', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '櫨谷町松本', 'ハセタニチョウマツモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区室谷', '28', '28111', '6512241', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '室谷', 'ムロタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区井吹台東町', '28', '28111', '6512242', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '井吹台東町', 'イブキダイヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区井吹台西町', '28', '28111', '6512243', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '井吹台西町', 'イブキダイニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区井吹台北町', '28', '28111', '6512244', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '井吹台北町', 'イブキダイキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区平野町下村', '28', '28111', '6512251', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '平野町下村', 'ヒラノチョウシモムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区平野町福中', '28', '28111', '6512252', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '平野町福中', 'ヒラノチョウフクナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区平野町向井', '28', '28111', '6512253', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '平野町向井', 'ヒラノチョウムカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区平野町芝崎', '28', '28111', '6512254', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '平野町芝崎', 'ヒラノチョウシバサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区平野町慶明', '28', '28111', '6512255', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '平野町慶明', 'ヒラノチョウケイメイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区平野町大野', '28', '28111', '6512256', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '平野町大野', 'ヒラノチョウオオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区平野町中津', '28', '28111', '6512257', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '平野町中津', 'ヒラノチョウナカツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区平野町堅田', '28', '28111', '6512261', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '平野町堅田', 'ヒラノチョウカタダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区平野町繁田', '28', '28111', '6512262', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '平野町繁田', 'ヒラノチョウシゲタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区平野町常本', '28', '28111', '6512263', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '平野町常本', 'ヒラノチョウツネモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区平野町大畑', '28', '28111', '6512264', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '平野町大畑', 'ヒラノチョウオオハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区平野町宮前', '28', '28111', '6512265', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '平野町宮前', 'ヒラノチョウミヤマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区平野町印路', '28', '28111', '6512266', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '平野町印路', 'ヒラノチョウインジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区平野町西戸田', '28', '28111', '6512267', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '平野町西戸田', 'ヒラノチョウニシトダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区平野町黒田', '28', '28111', '6512268', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '平野町黒田', 'ヒラノチョウクロダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区高塚台', '28', '28111', '6512271', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '高塚台', 'タカツカダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区狩場台', '28', '28111', '6512272', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '狩場台', 'カリバダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区糀台', '28', '28111', '6512273', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '糀台', 'コウジダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区竹の台', '28', '28111', '6512274', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '竹の台', 'タケノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区樫野台', '28', '28111', '6512275', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '樫野台', 'カシノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区春日台', '28', '28111', '6512276', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '春日台', 'カスガダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区美賀多台', '28', '28111', '6512277', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '美賀多台', 'ミカタダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区神出町勝成', '28', '28111', '6512301', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '神出町勝成', 'カンデチョウヨシナリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区神出町古神', '28', '28111', '6512302', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '神出町古神', 'カンデチョウコガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区神出町五百蔵', '28', '28111', '6512303', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '神出町五百蔵', 'カンデチョウイオロイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区神出町小束野', '28', '28111', '6512304', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '神出町小束野', 'カンデチョウコソクノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区神出町東', '28', '28111', '6512311', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '神出町東', 'カンデチョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区神出町南', '28', '28111', '6512312', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '神出町南', 'カンデチョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区神出町田井', '28', '28111', '6512313', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '神出町田井', 'カンデチョウタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区神出町宝勢', '28', '28111', '6512321', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '神出町宝勢', 'カンデチョウホウセイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区神出町広谷', '28', '28111', '6512331', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '神出町広谷', 'カンデチョウヒロタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区神出町北', '28', '28111', '6512332', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '神出町北', 'カンデチョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区神出町池田', '28', '28111', '6512333', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '神出町池田', 'カンデチョウイケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区神出町紫合', '28', '28111', '6512334', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '神出町紫合', 'カンデチョウユウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区岩岡町岩岡', '28', '28111', '6512401', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '岩岡町岩岡', 'イワオカチョウイワオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区岩岡町印路', '28', '28111', '6512402', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '岩岡町印路', 'イワオカチョウインジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区岩岡町西脇', '28', '28111', '6512403', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '岩岡町西脇', 'イワオカチョウニシワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区岩岡町古郷', '28', '28111', '6512404', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '岩岡町古郷', 'イワオカチョウフルサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区岩岡町野中', '28', '28111', '6512405', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '岩岡町野中', 'イワオカチョウノナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区上新地', '28', '28111', '6512411', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '上新地', 'カミシンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区竜が岡', '28', '28111', '6512412', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '竜が岡', 'リュウガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区福吉台', '28', '28111', '6512413', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '福吉台', 'フクヨシダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市西区大沢', '28', '28111', '6512414', '兵庫県', 'ヒョウゴケン', '神戸市西区', 'コウベシニシク', '大沢', 'オオサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市兵庫区', '28', '28105', '6520000', '兵庫県', 'ヒョウゴケン', '神戸市兵庫区', 'コウベシヒョウゴク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('77631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市兵庫区烏原町', '28', '28105', '6520001', '兵庫県', 'ヒョウゴケン', '神戸市兵庫区', 'コウベシヒョウゴク', '烏原町', 'カラスハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市兵庫区平野町', '28', '28105', '6520002', '兵庫県', 'ヒョウゴケン', '神戸市兵庫区', 'コウベシヒョウゴク', '平野町', 'ヒラノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市兵庫区梅元町', '28', '28105', '6520003', '兵庫県', 'ヒョウゴケン', '神戸市兵庫区', 'コウベシヒョウゴク', '梅元町', 'ウメモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市兵庫区楠谷町', '28', '28105', '6520004', '兵庫県', 'ヒョウゴケン', '神戸市兵庫区', 'コウベシヒョウゴク', '楠谷町', 'クスダニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市兵庫区矢部町', '28', '28105', '6520005', '兵庫県', 'ヒョウゴケン', '神戸市兵庫区', 'コウベシヒョウゴク', '矢部町', 'ヤベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市兵庫区神田町', '28', '28105', '6520006', '兵庫県', 'ヒョウゴケン', '神戸市兵庫区', 'コウベシヒョウゴク', '神田町', 'カンダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市兵庫区五宮町', '28', '28105', '6520007', '兵庫県', 'ヒョウゴケン', '神戸市兵庫区', 'コウベシヒョウゴク', '五宮町', 'ゴノミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市兵庫区上祇園町', '28', '28105', '6520008', '兵庫県', 'ヒョウゴケン', '神戸市兵庫区', 'コウベシヒョウゴク', '上祇園町', 'カミギオンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市兵庫区山王町', '28', '28105', '6520011', '兵庫県', 'ヒョウゴケン', '神戸市兵庫区', 'コウベシヒョウゴク', '山王町', 'サンノウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市兵庫区湊山町', '28', '28105', '6520012', '兵庫県', 'ヒョウゴケン', '神戸市兵庫区', 'コウベシヒョウゴク', '湊山町', 'ミナトヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市兵庫区上三条町', '28', '28105', '6520013', '兵庫県', 'ヒョウゴケン', '神戸市兵庫区', 'コウベシヒョウゴク', '上三条町', 'カミサンジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市兵庫区下三条町', '28', '28105', '6520014', '兵庫県', 'ヒョウゴケン', '神戸市兵庫区', 'コウベシヒョウゴク', '下三条町', 'シモサンジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市兵庫区下祇園町', '28', '28105', '6520015', '兵庫県', 'ヒョウゴケン', '神戸市兵庫区', 'コウベシヒョウゴク', '下祇園町', 'シモギオンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市兵庫区馬場町', '28', '28105', '6520016', '兵庫県', 'ヒョウゴケン', '神戸市兵庫区', 'コウベシヒョウゴク', '馬場町', 'ババチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市兵庫区天王町', '28', '28105', '6520021', '兵庫県', 'ヒョウゴケン', '神戸市兵庫区', 'コウベシヒョウゴク', '天王町', 'テンノウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市兵庫区千鳥町', '28', '28105', '6520022', '兵庫県', 'ヒョウゴケン', '神戸市兵庫区', 'コウベシヒョウゴク', '千鳥町', 'チドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市兵庫区都由乃町', '28', '28105', '6520023', '兵庫県', 'ヒョウゴケン', '神戸市兵庫区', 'コウベシヒョウゴク', '都由乃町', 'ツユノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市兵庫区雪御所町', '28', '28105', '6520031', '兵庫県', 'ヒョウゴケン', '神戸市兵庫区', 'コウベシヒョウゴク', '雪御所町', 'ユキノゴショチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市兵庫区荒田町', '28', '28105', '6520032', '兵庫県', 'ヒョウゴケン', '神戸市兵庫区', 'コウベシヒョウゴク', '荒田町', 'アラタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市兵庫区西上橘通', '28', '28105', '6520033', '兵庫県', 'ヒョウゴケン', '神戸市兵庫区', 'コウベシヒョウゴク', '西上橘通', 'ニシカミタチバナドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市兵庫区西橘通', '28', '28105', '6520034', '兵庫県', 'ヒョウゴケン', '神戸市兵庫区', 'コウベシヒョウゴク', '西橘通', 'ニシタチバナドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市兵庫区西多聞通', '28', '28105', '6520035', '兵庫県', 'ヒョウゴケン', '神戸市兵庫区', 'コウベシヒョウゴク', '西多聞通', 'ニシタモンドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市兵庫区福原町', '28', '28105', '6520036', '兵庫県', 'ヒョウゴケン', '神戸市兵庫区', 'コウベシヒョウゴク', '福原町', 'フクワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市兵庫区湊川町', '28', '28105', '6520041', '兵庫県', 'ヒョウゴケン', '神戸市兵庫区', 'コウベシヒョウゴク', '湊川町', 'ミナトガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市兵庫区東山町', '28', '28105', '6520042', '兵庫県', 'ヒョウゴケン', '神戸市兵庫区', 'コウベシヒョウゴク', '東山町', 'ヒガシヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市兵庫区会下山町', '28', '28105', '6520043', '兵庫県', 'ヒョウゴケン', '神戸市兵庫区', 'コウベシヒョウゴク', '会下山町', 'エゲヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市兵庫区大井通', '28', '28105', '6520044', '兵庫県', 'ヒョウゴケン', '神戸市兵庫区', 'コウベシヒョウゴク', '大井通', 'オオイドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市兵庫区松本通', '28', '28105', '6520045', '兵庫県', 'ヒョウゴケン', '神戸市兵庫区', 'コウベシヒョウゴク', '松本通', 'マツモトドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市兵庫区上沢通', '28', '28105', '6520046', '兵庫県', 'ヒョウゴケン', '神戸市兵庫区', 'コウベシヒョウゴク', '上沢通', 'カミサワドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市兵庫区下沢通', '28', '28105', '6520047', '兵庫県', 'ヒョウゴケン', '神戸市兵庫区', 'コウベシヒョウゴク', '下沢通', 'シモサワドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市兵庫区里山町', '28', '28105', '6520051', '兵庫県', 'ヒョウゴケン', '神戸市兵庫区', 'コウベシヒョウゴク', '里山町', 'サトヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市兵庫区鵯越筋', '28', '28105', '6520052', '兵庫県', 'ヒョウゴケン', '神戸市兵庫区', 'コウベシヒョウゴク', '鵯越筋', 'ヒヨドリゴエスジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市兵庫区北山町', '28', '28105', '6520053', '兵庫県', 'ヒョウゴケン', '神戸市兵庫区', 'コウベシヒョウゴク', '北山町', 'キタヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市兵庫区氷室町', '28', '28105', '6520054', '兵庫県', 'ヒョウゴケン', '神戸市兵庫区', 'コウベシヒョウゴク', '氷室町', 'ヒムロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市兵庫区小山町', '28', '28105', '6520055', '兵庫県', 'ヒョウゴケン', '神戸市兵庫区', 'コウベシヒョウゴク', '小山町', 'コヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市兵庫区滝山町', '28', '28105', '6520056', '兵庫県', 'ヒョウゴケン', '神戸市兵庫区', 'コウベシヒョウゴク', '滝山町', 'タキヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市兵庫区鵯越町', '28', '28105', '6520057', '兵庫県', 'ヒョウゴケン', '神戸市兵庫区', 'コウベシヒョウゴク', '鵯越町', 'ヒヨドリゴエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市兵庫区菊水町', '28', '28105', '6520058', '兵庫県', 'ヒョウゴケン', '神戸市兵庫区', 'コウベシヒョウゴク', '菊水町', 'キクスイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市兵庫区石井町', '28', '28105', '6520061', '兵庫県', 'ヒョウゴケン', '神戸市兵庫区', 'コウベシヒョウゴク', '石井町', 'イシイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市兵庫区大同町', '28', '28105', '6520062', '兵庫県', 'ヒョウゴケン', '神戸市兵庫区', 'コウベシヒョウゴク', '大同町', 'ダイドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市兵庫区夢野町', '28', '28105', '6520063', '兵庫県', 'ヒョウゴケン', '神戸市兵庫区', 'コウベシヒョウゴク', '夢野町', 'ユメノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市兵庫区熊野町', '28', '28105', '6520064', '兵庫県', 'ヒョウゴケン', '神戸市兵庫区', 'コウベシヒョウゴク', '熊野町', 'クマノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市兵庫区清水町', '28', '28105', '6520065', '兵庫県', 'ヒョウゴケン', '神戸市兵庫区', 'コウベシヒョウゴク', '清水町', 'シミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区山田町下谷上菊水山', '28', '28109', '6520071', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '山田町下谷上', 'ヤマダチョウシモタニガミ', null, null, '菊水山', 'キクスイヤマ');
INSERT INTO `ms_addresses` VALUES ('77675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区山田町下谷上高座川向', '28', '28109', '6520071', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '山田町下谷上', 'ヤマダチョウシモタニガミ', null, null, '高座川向', 'コウザカワムカイ');
INSERT INTO `ms_addresses` VALUES ('77676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区山田町下谷上中一里山', '28', '28109', '6520071', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '山田町下谷上', 'ヤマダチョウシモタニガミ', null, null, '中一里山', 'ナカイチリヤマ');
INSERT INTO `ms_addresses` VALUES ('77677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区山田町下谷上ひよどり越', '28', '28109', '6520071', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '山田町下谷上', 'ヤマダチョウシモタニガミ', null, null, 'ひよどり越', 'ヒヨドリゴエ');
INSERT INTO `ms_addresses` VALUES ('77678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市兵庫区中道通', '28', '28105', '6520801', '兵庫県', 'ヒョウゴケン', '神戸市兵庫区', 'コウベシヒョウゴク', '中道通', 'ナカミチドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市兵庫区水木通', '28', '28105', '6520802', '兵庫県', 'ヒョウゴケン', '神戸市兵庫区', 'コウベシヒョウゴク', '水木通', 'ミズキドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市兵庫区大開通', '28', '28105', '6520803', '兵庫県', 'ヒョウゴケン', '神戸市兵庫区', 'コウベシヒョウゴク', '大開通', 'ダイカイドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市兵庫区塚本通', '28', '28105', '6520804', '兵庫県', 'ヒョウゴケン', '神戸市兵庫区', 'コウベシヒョウゴク', '塚本通', 'ツカモトドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市兵庫区羽坂通', '28', '28105', '6520805', '兵庫県', 'ヒョウゴケン', '神戸市兵庫区', 'コウベシヒョウゴク', '羽坂通', 'ハサカドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市兵庫区西柳原町', '28', '28105', '6520806', '兵庫県', 'ヒョウゴケン', '神戸市兵庫区', 'コウベシヒョウゴク', '西柳原町', 'ニシヤナギワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市兵庫区浜崎通', '28', '28105', '6520807', '兵庫県', 'ヒョウゴケン', '神戸市兵庫区', 'コウベシヒョウゴク', '浜崎通', 'ハマサキドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市兵庫区新開地', '28', '28105', '6520811', '兵庫県', 'ヒョウゴケン', '神戸市兵庫区', 'コウベシヒョウゴク', '新開地', 'シンカイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市兵庫区湊町', '28', '28105', '6520812', '兵庫県', 'ヒョウゴケン', '神戸市兵庫区', 'コウベシヒョウゴク', '湊町', 'ミナトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市兵庫区兵庫町', '28', '28105', '6520813', '兵庫県', 'ヒョウゴケン', '神戸市兵庫区', 'コウベシヒョウゴク', '兵庫町', 'ヒョウゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市兵庫区門口町', '28', '28105', '6520814', '兵庫県', 'ヒョウゴケン', '神戸市兵庫区', 'コウベシヒョウゴク', '門口町', 'モングチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市兵庫区三川口町', '28', '28105', '6520815', '兵庫県', 'ヒョウゴケン', '神戸市兵庫区', 'コウベシヒョウゴク', '三川口町', 'ミカワグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市兵庫区永沢町', '28', '28105', '6520816', '兵庫県', 'ヒョウゴケン', '神戸市兵庫区', 'コウベシヒョウゴク', '永沢町', 'エイザワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市兵庫区佐比江町', '28', '28105', '6520821', '兵庫県', 'ヒョウゴケン', '神戸市兵庫区', 'コウベシヒョウゴク', '佐比江町', 'サビエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市兵庫区西出町', '28', '28105', '6520822', '兵庫県', 'ヒョウゴケン', '神戸市兵庫区', 'コウベシヒョウゴク', '西出町', 'ニシデマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市兵庫区東出町', '28', '28105', '6520823', '兵庫県', 'ヒョウゴケン', '神戸市兵庫区', 'コウベシヒョウゴク', '東出町', 'ヒガシデマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市兵庫区七宮町', '28', '28105', '6520831', '兵庫県', 'ヒョウゴケン', '神戸市兵庫区', 'コウベシヒョウゴク', '七宮町', 'シチノミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市兵庫区鍛冶屋町', '28', '28105', '6520832', '兵庫県', 'ヒョウゴケン', '神戸市兵庫区', 'コウベシヒョウゴク', '鍛冶屋町', 'カジヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市兵庫区島上町', '28', '28105', '6520833', '兵庫県', 'ヒョウゴケン', '神戸市兵庫区', 'コウベシヒョウゴク', '島上町', 'シマガミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市兵庫区本町', '28', '28105', '6520834', '兵庫県', 'ヒョウゴケン', '神戸市兵庫区', 'コウベシヒョウゴク', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市兵庫区西仲町', '28', '28105', '6520835', '兵庫県', 'ヒョウゴケン', '神戸市兵庫区', 'コウベシヒョウゴク', '西仲町', 'ニシナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市兵庫区神明町', '28', '28105', '6520836', '兵庫県', 'ヒョウゴケン', '神戸市兵庫区', 'コウベシヒョウゴク', '神明町', 'シンメイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市兵庫区北逆瀬川町', '28', '28105', '6520837', '兵庫県', 'ヒョウゴケン', '神戸市兵庫区', 'コウベシヒョウゴク', '北逆瀬川町', 'キタサカセガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市兵庫区南仲町', '28', '28105', '6520841', '兵庫県', 'ヒョウゴケン', '神戸市兵庫区', 'コウベシヒョウゴク', '南仲町', 'ミナミナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市兵庫区磯之町', '28', '28105', '6520842', '兵庫県', 'ヒョウゴケン', '神戸市兵庫区', 'コウベシヒョウゴク', '磯之町', 'イソノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市兵庫区船大工町', '28', '28105', '6520843', '兵庫県', 'ヒョウゴケン', '神戸市兵庫区', 'コウベシヒョウゴク', '船大工町', 'フナダイクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市兵庫区中之島', '28', '28105', '6520844', '兵庫県', 'ヒョウゴケン', '神戸市兵庫区', 'コウベシヒョウゴク', '中之島', 'ナカノシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市兵庫区築地町', '28', '28105', '6520845', '兵庫県', 'ヒョウゴケン', '神戸市兵庫区', 'コウベシヒョウゴク', '築地町', 'ツキジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市兵庫区出在家町', '28', '28105', '6520846', '兵庫県', 'ヒョウゴケン', '神戸市兵庫区', 'コウベシヒョウゴク', '出在家町', 'デザイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市兵庫区切戸町', '28', '28105', '6520847', '兵庫県', 'ヒョウゴケン', '神戸市兵庫区', 'コウベシヒョウゴク', '切戸町', 'キレトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市兵庫区材木町', '28', '28105', '6520851', '兵庫県', 'ヒョウゴケン', '神戸市兵庫区', 'コウベシヒョウゴク', '材木町', 'ザイモクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市兵庫区御崎本町', '28', '28105', '6520852', '兵庫県', 'ヒョウゴケン', '神戸市兵庫区', 'コウベシヒョウゴク', '御崎本町', 'ミサキホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市兵庫区今出在家町', '28', '28105', '6520853', '兵庫県', 'ヒョウゴケン', '神戸市兵庫区', 'コウベシヒョウゴク', '今出在家町', 'イマデザイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市兵庫区和田崎町', '28', '28105', '6520854', '兵庫県', 'ヒョウゴケン', '神戸市兵庫区', 'コウベシヒョウゴク', '和田崎町', 'ワダサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市兵庫区御崎町', '28', '28105', '6520855', '兵庫県', 'ヒョウゴケン', '神戸市兵庫区', 'コウベシヒョウゴク', '御崎町', 'ミサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市兵庫区三石通', '28', '28105', '6520861', '兵庫県', 'ヒョウゴケン', '神戸市兵庫区', 'コウベシヒョウゴク', '三石通', 'ミツイシドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市兵庫区上庄通', '28', '28105', '6520862', '兵庫県', 'ヒョウゴケン', '神戸市兵庫区', 'コウベシヒョウゴク', '上庄通', 'カミショウドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市兵庫区和田宮通', '28', '28105', '6520863', '兵庫県', 'ヒョウゴケン', '神戸市兵庫区', 'コウベシヒョウゴク', '和田宮通', 'ワダミヤドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市兵庫区笠松通', '28', '28105', '6520864', '兵庫県', 'ヒョウゴケン', '神戸市兵庫区', 'コウベシヒョウゴク', '笠松通', 'カサマツドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市兵庫区小松通', '28', '28105', '6520865', '兵庫県', 'ヒョウゴケン', '神戸市兵庫区', 'コウベシヒョウゴク', '小松通', 'コマツドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市兵庫区遠矢浜町', '28', '28105', '6520866', '兵庫県', 'ヒョウゴケン', '神戸市兵庫区', 'コウベシヒョウゴク', '遠矢浜町', 'トオヤハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市兵庫区浜山通', '28', '28105', '6520871', '兵庫県', 'ヒョウゴケン', '神戸市兵庫区', 'コウベシヒョウゴク', '浜山通', 'ハマヤマドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市兵庫区吉田町', '28', '28105', '6520872', '兵庫県', 'ヒョウゴケン', '神戸市兵庫区', 'コウベシヒョウゴク', '吉田町', 'ヨシダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市兵庫区金平町', '28', '28105', '6520873', '兵庫県', 'ヒョウゴケン', '神戸市兵庫区', 'コウベシヒョウゴク', '金平町', 'キンペイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市兵庫区高松町', '28', '28105', '6520874', '兵庫県', 'ヒョウゴケン', '神戸市兵庫区', 'コウベシヒョウゴク', '高松町', 'タカマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市兵庫区浜中町', '28', '28105', '6520875', '兵庫県', 'ヒョウゴケン', '神戸市兵庫区', 'コウベシヒョウゴク', '浜中町', 'ハマナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市兵庫区松原通', '28', '28105', '6520881', '兵庫県', 'ヒョウゴケン', '神戸市兵庫区', 'コウベシヒョウゴク', '松原通', 'マツバラドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市兵庫区芦原通', '28', '28105', '6520882', '兵庫県', 'ヒョウゴケン', '神戸市兵庫区', 'コウベシヒョウゴク', '芦原通', 'アシハラドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市兵庫区明和通', '28', '28105', '6520883', '兵庫県', 'ヒョウゴケン', '神戸市兵庫区', 'コウベシヒョウゴク', '明和通', 'メイワドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市兵庫区和田山通', '28', '28105', '6520884', '兵庫県', 'ヒョウゴケン', '神戸市兵庫区', 'コウベシヒョウゴク', '和田山通', 'ワダヤマドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市兵庫区御所通', '28', '28105', '6520885', '兵庫県', 'ヒョウゴケン', '神戸市兵庫区', 'コウベシヒョウゴク', '御所通', 'ゴショドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市兵庫区西宮内町', '28', '28105', '6520891', '兵庫県', 'ヒョウゴケン', '神戸市兵庫区', 'コウベシヒョウゴク', '西宮内町', 'ニシミヤウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市兵庫区東柳原町', '28', '28105', '6520892', '兵庫県', 'ヒョウゴケン', '神戸市兵庫区', 'コウベシヒョウゴク', '東柳原町', 'ヒガシヤナギワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市兵庫区南逆瀬川町', '28', '28105', '6520893', '兵庫県', 'ヒョウゴケン', '神戸市兵庫区', 'コウベシヒョウゴク', '南逆瀬川町', 'ミナミサカセガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市兵庫区入江通', '28', '28105', '6520894', '兵庫県', 'ヒョウゴケン', '神戸市兵庫区', 'コウベシヒョウゴク', '入江通', 'イリエドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市兵庫区小河通', '28', '28105', '6520895', '兵庫県', 'ヒョウゴケン', '神戸市兵庫区', 'コウベシヒョウゴク', '小河通', 'オガワドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市兵庫区須佐野通', '28', '28105', '6520896', '兵庫県', 'ヒョウゴケン', '神戸市兵庫区', 'コウベシヒョウゴク', '須佐野通', 'スサノドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市兵庫区駅南通', '28', '28105', '6520897', '兵庫県', 'ヒョウゴケン', '神戸市兵庫区', 'コウベシヒョウゴク', '駅南通', 'エキミナミドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市兵庫区駅前通', '28', '28105', '6520898', '兵庫県', 'ヒョウゴケン', '神戸市兵庫区', 'コウベシヒョウゴク', '駅前通', 'エキマエドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市長田区', '28', '28106', '6530000', '兵庫県', 'ヒョウゴケン', '神戸市長田区', 'コウベシナガタク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('77744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市長田区七番町', '28', '28106', '6530001', '兵庫県', 'ヒョウゴケン', '神戸市長田区', 'コウベシナガタク', '七番町', 'ナナバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市長田区六番町', '28', '28106', '6530002', '兵庫県', 'ヒョウゴケン', '神戸市長田区', 'コウベシナガタク', '六番町', 'ロクバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市長田区五番町', '28', '28106', '6530003', '兵庫県', 'ヒョウゴケン', '神戸市長田区', 'コウベシナガタク', '五番町', 'ゴバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市長田区四番町', '28', '28106', '6530004', '兵庫県', 'ヒョウゴケン', '神戸市長田区', 'コウベシナガタク', '四番町', 'ヨンバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市長田区三番町', '28', '28106', '6530011', '兵庫県', 'ヒョウゴケン', '神戸市長田区', 'コウベシナガタク', '三番町', 'サンバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市長田区二番町', '28', '28106', '6530012', '兵庫県', 'ヒョウゴケン', '神戸市長田区', 'コウベシナガタク', '二番町', 'ニバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市長田区一番町', '28', '28106', '6530013', '兵庫県', 'ヒョウゴケン', '神戸市長田区', 'コウベシナガタク', '一番町', 'イチバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市長田区御蔵通', '28', '28106', '6530014', '兵庫県', 'ヒョウゴケン', '神戸市長田区', 'コウベシナガタク', '御蔵通', 'ミクラドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市長田区菅原通', '28', '28106', '6530015', '兵庫県', 'ヒョウゴケン', '神戸市長田区', 'コウベシナガタク', '菅原通', 'スガハラドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市長田区北町', '28', '28106', '6530016', '兵庫県', 'ヒョウゴケン', '神戸市長田区', 'コウベシナガタク', '北町', 'キタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市長田区梅ケ香町', '28', '28106', '6530021', '兵庫県', 'ヒョウゴケン', '神戸市長田区', 'コウベシナガタク', '梅ケ香町', 'ウメガカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市長田区東尻池町', '28', '28106', '6530022', '兵庫県', 'ヒョウゴケン', '神戸市長田区', 'コウベシナガタク', '東尻池町', 'ヒガシシリイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市長田区東尻池新町', '28', '28106', '6530023', '兵庫県', 'ヒョウゴケン', '神戸市長田区', 'コウベシナガタク', '東尻池新町', 'ヒガシシリイケシンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市長田区浜添通', '28', '28106', '6530024', '兵庫県', 'ヒョウゴケン', '神戸市長田区', 'コウベシナガタク', '浜添通', 'ハマゾエドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市長田区真野町', '28', '28106', '6530025', '兵庫県', 'ヒョウゴケン', '神戸市長田区', 'コウベシナガタク', '真野町', 'マノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市長田区西尻池町', '28', '28106', '6530031', '兵庫県', 'ヒョウゴケン', '神戸市長田区', 'コウベシナガタク', '西尻池町', 'ニシシリイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市長田区苅藻通', '28', '28106', '6530032', '兵庫県', 'ヒョウゴケン', '神戸市長田区', 'コウベシナガタク', '苅藻通', 'カルモドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市長田区苅藻島町', '28', '28106', '6530033', '兵庫県', 'ヒョウゴケン', '神戸市長田区', 'コウベシナガタク', '苅藻島町', 'カルモジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市長田区駒栄町', '28', '28106', '6530034', '兵庫県', 'ヒョウゴケン', '神戸市長田区', 'コウベシナガタク', '駒栄町', 'コマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市長田区庄田町', '28', '28106', '6530035', '兵庫県', 'ヒョウゴケン', '神戸市長田区', 'コウベシナガタク', '庄田町', 'ショウダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市長田区腕塚町', '28', '28106', '6530036', '兵庫県', 'ヒョウゴケン', '神戸市長田区', 'コウベシナガタク', '腕塚町', 'ウデヅカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市長田区大橋町', '28', '28106', '6530037', '兵庫県', 'ヒョウゴケン', '神戸市長田区', 'コウベシナガタク', '大橋町', 'オオハシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市長田区若松町', '28', '28106', '6530038', '兵庫県', 'ヒョウゴケン', '神戸市長田区', 'コウベシナガタク', '若松町', 'ワカマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市長田区日吉町', '28', '28106', '6530039', '兵庫県', 'ヒョウゴケン', '神戸市長田区', 'コウベシナガタク', '日吉町', 'ヒヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市長田区久保町', '28', '28106', '6530041', '兵庫県', 'ヒョウゴケン', '神戸市長田区', 'コウベシナガタク', '久保町', 'クボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市長田区二葉町', '28', '28106', '6530042', '兵庫県', 'ヒョウゴケン', '神戸市長田区', 'コウベシナガタク', '二葉町', 'フタバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市長田区駒ケ林町', '28', '28106', '6530043', '兵庫県', 'ヒョウゴケン', '神戸市長田区', 'コウベシナガタク', '駒ケ林町', 'コマガバヤシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市長田区南駒栄町', '28', '28106', '6530044', '兵庫県', 'ヒョウゴケン', '神戸市長田区', 'コウベシナガタク', '南駒栄町', 'ミナミコマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市長田区駒ケ林南町', '28', '28106', '6530045', '兵庫県', 'ヒョウゴケン', '神戸市長田区', 'コウベシナガタク', '駒ケ林南町', 'コマガバヤシミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市長田区野田町', '28', '28106', '6530051', '兵庫県', 'ヒョウゴケン', '神戸市長田区', 'コウベシナガタク', '野田町', 'ノダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市長田区海運町', '28', '28106', '6530052', '兵庫県', 'ヒョウゴケン', '神戸市長田区', 'コウベシナガタク', '海運町', 'カイウンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市長田区本庄町', '28', '28106', '6530053', '兵庫県', 'ヒョウゴケン', '神戸市長田区', 'コウベシナガタク', '本庄町', 'ホンジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市長田区長楽町', '28', '28106', '6530054', '兵庫県', 'ヒョウゴケン', '神戸市長田区', 'コウベシナガタク', '長楽町', 'ナガラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市長田区浪松町', '28', '28106', '6530055', '兵庫県', 'ヒョウゴケン', '神戸市長田区', 'コウベシナガタク', '浪松町', 'ナミマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市長田区房王寺町', '28', '28106', '6530801', '兵庫県', 'ヒョウゴケン', '神戸市長田区', 'コウベシナガタク', '房王寺町', 'ボウオウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市長田区重池町', '28', '28106', '6530802', '兵庫県', 'ヒョウゴケン', '神戸市長田区', 'コウベシナガタク', '重池町', 'オモイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市長田区前原町', '28', '28106', '6530803', '兵庫県', 'ヒョウゴケン', '神戸市長田区', 'コウベシナガタク', '前原町', 'マエバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市長田区寺池町', '28', '28106', '6530804', '兵庫県', 'ヒョウゴケン', '神戸市長田区', 'コウベシナガタク', '寺池町', 'テライケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市長田区片山町', '28', '28106', '6530805', '兵庫県', 'ヒョウゴケン', '神戸市長田区', 'コウベシナガタク', '片山町', 'カタヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市長田区大丸町', '28', '28106', '6530806', '兵庫県', 'ヒョウゴケン', '神戸市長田区', 'コウベシナガタク', '大丸町', 'ダイマルチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市長田区大塚町', '28', '28106', '6530811', '兵庫県', 'ヒョウゴケン', '神戸市長田区', 'コウベシナガタク', '大塚町', 'オオツカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市長田区長田町', '28', '28106', '6530812', '兵庫県', 'ヒョウゴケン', '神戸市長田区', 'コウベシナガタク', '長田町', 'ナガタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市長田区宮川町', '28', '28106', '6530813', '兵庫県', 'ヒョウゴケン', '神戸市長田区', 'コウベシナガタク', '宮川町', 'ミヤガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市長田区池田広町', '28', '28106', '6530814', '兵庫県', 'ヒョウゴケン', '神戸市長田区', 'コウベシナガタク', '池田広町', 'イケダヒロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市長田区池田谷町', '28', '28106', '6530821', '兵庫県', 'ヒョウゴケン', '神戸市長田区', 'コウベシナガタク', '池田谷町', 'イケダタニマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市長田区池田寺町', '28', '28106', '6530822', '兵庫県', 'ヒョウゴケン', '神戸市長田区', 'コウベシナガタク', '池田寺町', 'イケダテラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市長田区池田経町', '28', '28106', '6530823', '兵庫県', 'ヒョウゴケン', '神戸市長田区', 'コウベシナガタク', '池田経町', 'イケダキョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市長田区池田上町', '28', '28106', '6530824', '兵庫県', 'ヒョウゴケン', '神戸市長田区', 'コウベシナガタク', '池田上町', 'イケダウエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市長田区池田新町', '28', '28106', '6530825', '兵庫県', 'ヒョウゴケン', '神戸市長田区', 'コウベシナガタク', '池田新町', 'イケダシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市長田区池田塩町', '28', '28106', '6530826', '兵庫県', 'ヒョウゴケン', '神戸市長田区', 'コウベシナガタク', '池田塩町', 'イケダシオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市長田区上池田', '28', '28106', '6530827', '兵庫県', 'ヒョウゴケン', '神戸市長田区', 'コウベシナガタク', '上池田', 'カミイケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市長田区蓮宮通', '28', '28106', '6530831', '兵庫県', 'ヒョウゴケン', '神戸市長田区', 'コウベシナガタク', '蓮宮通', 'ハスミヤドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市長田区御船通', '28', '28106', '6530832', '兵庫県', 'ヒョウゴケン', '神戸市長田区', 'コウベシナガタク', '御船通', 'ミフネドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市長田区大道通', '28', '28106', '6530833', '兵庫県', 'ヒョウゴケン', '神戸市長田区', 'コウベシナガタク', '大道通', 'オオミチドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市長田区川西通', '28', '28106', '6530834', '兵庫県', 'ヒョウゴケン', '神戸市長田区', 'コウベシナガタク', '川西通', 'カワニシドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市長田区細田町', '28', '28106', '6530835', '兵庫県', 'ヒョウゴケン', '神戸市長田区', 'コウベシナガタク', '細田町', 'ホソダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市長田区神楽町', '28', '28106', '6530836', '兵庫県', 'ヒョウゴケン', '神戸市長田区', 'コウベシナガタク', '神楽町', 'カグラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市長田区蓮池町', '28', '28106', '6530837', '兵庫県', 'ヒョウゴケン', '神戸市長田区', 'コウベシナガタク', '蓮池町', 'ハスイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市長田区大谷町', '28', '28106', '6530838', '兵庫県', 'ヒョウゴケン', '神戸市長田区', 'コウベシナガタク', '大谷町', 'オオタニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市長田区松野通', '28', '28106', '6530841', '兵庫県', 'ヒョウゴケン', '神戸市長田区', 'コウベシナガタク', '松野通', 'マツノドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市長田区水笠通', '28', '28106', '6530842', '兵庫県', 'ヒョウゴケン', '神戸市長田区', 'コウベシナガタク', '水笠通', 'ミズカサドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市長田区御屋敷通', '28', '28106', '6530843', '兵庫県', 'ヒョウゴケン', '神戸市長田区', 'コウベシナガタク', '御屋敷通', 'オヤシキドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市長田区西代通', '28', '28106', '6530844', '兵庫県', 'ヒョウゴケン', '神戸市長田区', 'コウベシナガタク', '西代通', 'ニシダイドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市長田区戸崎通', '28', '28106', '6530845', '兵庫県', 'ヒョウゴケン', '神戸市長田区', 'コウベシナガタク', '戸崎通', 'トザキドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市長田区五位ノ池町', '28', '28106', '6530851', '兵庫県', 'ヒョウゴケン', '神戸市長田区', 'コウベシナガタク', '五位ノ池町', 'ゴイノイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市長田区山下町', '28', '28106', '6530852', '兵庫県', 'ヒョウゴケン', '神戸市長田区', 'コウベシナガタク', '山下町', 'ヤマシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市長田区庄山町', '28', '28106', '6530853', '兵庫県', 'ヒョウゴケン', '神戸市長田区', 'コウベシナガタク', '庄山町', 'ショウヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市長田区平和台町', '28', '28106', '6530854', '兵庫県', 'ヒョウゴケン', '神戸市長田区', 'コウベシナガタク', '平和台町', 'ヘイワダイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市長田区長尾町', '28', '28106', '6530855', '兵庫県', 'ヒョウゴケン', '神戸市長田区', 'コウベシナガタク', '長尾町', 'ナガオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市長田区高取山町', '28', '28106', '6530856', '兵庫県', 'ヒョウゴケン', '神戸市長田区', 'コウベシナガタク', '高取山町', 'タカトリサンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市長田区林山町', '28', '28106', '6530861', '兵庫県', 'ヒョウゴケン', '神戸市長田区', 'コウベシナガタク', '林山町', 'ハヤシヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市長田区西山町', '28', '28106', '6530862', '兵庫県', 'ヒョウゴケン', '神戸市長田区', 'コウベシナガタク', '西山町', 'ニシヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市長田区宮丘町', '28', '28106', '6530863', '兵庫県', 'ヒョウゴケン', '神戸市長田区', 'コウベシナガタク', '宮丘町', 'ミヤオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市長田区池田惣町', '28', '28106', '6530864', '兵庫県', 'ヒョウゴケン', '神戸市長田区', 'コウベシナガタク', '池田惣町', 'イケダソウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市長田区池田宮町', '28', '28106', '6530865', '兵庫県', 'ヒョウゴケン', '神戸市長田区', 'コウベシナガタク', '池田宮町', 'イケダミヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市長田区長者町', '28', '28106', '6530866', '兵庫県', 'ヒョウゴケン', '神戸市長田区', 'コウベシナガタク', '長者町', 'チョウジャマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市長田区高東町', '28', '28106', '6530867', '兵庫県', 'ヒョウゴケン', '神戸市長田区', 'コウベシナガタク', '高東町', 'コウトウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市長田区鶯町', '28', '28106', '6530871', '兵庫県', 'ヒョウゴケン', '神戸市長田区', 'コウベシナガタク', '鶯町', 'ウグイスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市長田区大日丘町', '28', '28106', '6530872', '兵庫県', 'ヒョウゴケン', '神戸市長田区', 'コウベシナガタク', '大日丘町', 'ダイニチガオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市長田区萩乃町', '28', '28106', '6530873', '兵庫県', 'ヒョウゴケン', '神戸市長田区', 'コウベシナガタク', '萩乃町', 'ハギノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市長田区西丸山町', '28', '28106', '6530874', '兵庫県', 'ヒョウゴケン', '神戸市長田区', 'コウベシナガタク', '西丸山町', 'ニシマルヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市長田区丸山町', '28', '28106', '6530875', '兵庫県', 'ヒョウゴケン', '神戸市長田区', 'コウベシナガタク', '丸山町', 'マルヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市長田区花山町', '28', '28106', '6530876', '兵庫県', 'ヒョウゴケン', '神戸市長田区', 'コウベシナガタク', '花山町', 'ハナヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市長田区鹿松町', '28', '28106', '6530877', '兵庫県', 'ヒョウゴケン', '神戸市長田区', 'コウベシナガタク', '鹿松町', 'シカマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市長田区一里山町', '28', '28106', '6530878', '兵庫県', 'ヒョウゴケン', '神戸市長田区', 'コウベシナガタク', '一里山町', 'イチリヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市長田区雲雀ケ丘', '28', '28106', '6530879', '兵庫県', 'ヒョウゴケン', '神戸市長田区', 'コウベシナガタク', '雲雀ケ丘', 'ヒバリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市長田区滝谷町', '28', '28106', '6530881', '兵庫県', 'ヒョウゴケン', '神戸市長田区', 'コウベシナガタク', '滝谷町', 'タキタニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市長田区長田天神町', '28', '28106', '6530882', '兵庫県', 'ヒョウゴケン', '神戸市長田区', 'コウベシナガタク', '長田天神町', 'ナガタテンジンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市長田区名倉町', '28', '28106', '6530883', '兵庫県', 'ヒョウゴケン', '神戸市長田区', 'コウベシナガタク', '名倉町', 'ナグラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市長田区明泉寺町', '28', '28106', '6530884', '兵庫県', 'ヒョウゴケン', '神戸市長田区', 'コウベシナガタク', '明泉寺町', 'ミョウセンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市長田区堀切町', '28', '28106', '6530885', '兵庫県', 'ヒョウゴケン', '神戸市長田区', 'コウベシナガタク', '堀切町', 'ホリキリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市長田区東丸山町', '28', '28106', '6530886', '兵庫県', 'ヒョウゴケン', '神戸市長田区', 'コウベシナガタク', '東丸山町', 'ヒガシマルヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市長田区檜川町', '28', '28106', '6530887', '兵庫県', 'ヒョウゴケン', '神戸市長田区', 'コウベシナガタク', '檜川町', 'ヒカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市長田区源平町', '28', '28106', '6530888', '兵庫県', 'ヒョウゴケン', '神戸市長田区', 'コウベシナガタク', '源平町', 'ゲンペイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市須磨区', '28', '28107', '6540000', '兵庫県', 'ヒョウゴケン', '神戸市須磨区', 'コウベシスマク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('77841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市須磨区禅昌寺町', '28', '28107', '6540001', '兵庫県', 'ヒョウゴケン', '神戸市須磨区', 'コウベシスマク', '禅昌寺町', 'ゼンショウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市須磨区明神町', '28', '28107', '6540002', '兵庫県', 'ヒョウゴケン', '神戸市須磨区', 'コウベシスマク', '明神町', 'ミョウジンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市須磨区神撫町', '28', '28107', '6540003', '兵庫県', 'ヒョウゴケン', '神戸市須磨区', 'コウベシスマク', '神撫町', 'ジンブチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市須磨区永楽町', '28', '28107', '6540004', '兵庫県', 'ヒョウゴケン', '神戸市須磨区', 'コウベシスマク', '永楽町', 'エイラクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市須磨区川上町', '28', '28107', '6540005', '兵庫県', 'ヒョウゴケン', '神戸市須磨区', 'コウベシスマク', '川上町', 'カワカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市須磨区養老町', '28', '28107', '6540006', '兵庫県', 'ヒョウゴケン', '神戸市須磨区', 'コウベシスマク', '養老町', 'ヨウロウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市須磨区宝田町', '28', '28107', '6540007', '兵庫県', 'ヒョウゴケン', '神戸市須磨区', 'コウベシスマク', '宝田町', 'ホウデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市須磨区菊池町', '28', '28107', '6540008', '兵庫県', 'ヒョウゴケン', '神戸市須磨区', 'コウベシスマク', '菊池町', 'キクイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市須磨区板宿町', '28', '28107', '6540009', '兵庫県', 'ヒョウゴケン', '神戸市須磨区', 'コウベシスマク', '板宿町', 'イタヤドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市須磨区前池町', '28', '28107', '6540011', '兵庫県', 'ヒョウゴケン', '神戸市須磨区', 'コウベシスマク', '前池町', 'マエイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市須磨区飛松町', '28', '28107', '6540012', '兵庫県', 'ヒョウゴケン', '神戸市須磨区', 'コウベシスマク', '飛松町', 'トビマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市須磨区大手町', '28', '28107', '6540013', '兵庫県', 'ヒョウゴケン', '神戸市須磨区', 'コウベシスマク', '大手町', 'オオテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市須磨区若木町', '28', '28107', '6540014', '兵庫県', 'ヒョウゴケン', '神戸市須磨区', 'コウベシスマク', '若木町', 'ワカギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市須磨区奥山畑町', '28', '28107', '6540015', '兵庫県', 'ヒョウゴケン', '神戸市須磨区', 'コウベシスマク', '奥山畑町', 'オクヤマハタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市須磨区上細沢町', '28', '28107', '6540016', '兵庫県', 'ヒョウゴケン', '神戸市須磨区', 'コウベシスマク', '上細沢町', 'カミホソザワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市須磨区大手', '28', '28107', '6540017', '兵庫県', 'ヒョウゴケン', '神戸市須磨区', 'コウベシスマク', '大手', 'オオテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市須磨区東須磨', '28', '28107', '6540018', '兵庫県', 'ヒョウゴケン', '神戸市須磨区', 'コウベシスマク', '東須磨', 'ヒガシスマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市須磨区平田町', '28', '28107', '6540021', '兵庫県', 'ヒョウゴケン', '神戸市須磨区', 'コウベシスマク', '平田町', 'ヒラタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市須磨区大黒町', '28', '28107', '6540022', '兵庫県', 'ヒョウゴケン', '神戸市須磨区', 'コウベシスマク', '大黒町', 'ダイコクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市須磨区戎町', '28', '28107', '6540023', '兵庫県', 'ヒョウゴケン', '神戸市須磨区', 'コウベシスマク', '戎町', 'エビスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市須磨区大田町', '28', '28107', '6540024', '兵庫県', 'ヒョウゴケン', '神戸市須磨区', 'コウベシスマク', '大田町', 'オオタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市須磨区寺田町', '28', '28107', '6540025', '兵庫県', 'ヒョウゴケン', '神戸市須磨区', 'コウベシスマク', '寺田町', 'テラダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市須磨区大池町', '28', '28107', '6540026', '兵庫県', 'ヒョウゴケン', '神戸市須磨区', 'コウベシスマク', '大池町', 'オオイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市須磨区千歳町', '28', '28107', '6540027', '兵庫県', 'ヒョウゴケン', '神戸市須磨区', 'コウベシスマク', '千歳町', 'チトセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市須磨区常盤町', '28', '28107', '6540028', '兵庫県', 'ヒョウゴケン', '神戸市須磨区', 'コウベシスマク', '常盤町', 'トキワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市須磨区権現町', '28', '28107', '6540031', '兵庫県', 'ヒョウゴケン', '神戸市須磨区', 'コウベシスマク', '権現町', 'ゴンゲンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市須磨区堀池町', '28', '28107', '6540032', '兵庫県', 'ヒョウゴケン', '神戸市須磨区', 'コウベシスマク', '堀池町', 'ホリイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市須磨区東町', '28', '28107', '6540033', '兵庫県', 'ヒョウゴケン', '神戸市須磨区', 'コウベシスマク', '東町', 'ヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市須磨区戸政町', '28', '28107', '6540034', '兵庫県', 'ヒョウゴケン', '神戸市須磨区', 'コウベシスマク', '戸政町', 'トマサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市須磨区中島町', '28', '28107', '6540035', '兵庫県', 'ヒョウゴケン', '神戸市須磨区', 'コウベシスマク', '中島町', 'ナカジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市須磨区南町', '28', '28107', '6540036', '兵庫県', 'ヒョウゴケン', '神戸市須磨区', 'コウベシスマク', '南町', 'ミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市須磨区行平町', '28', '28107', '6540037', '兵庫県', 'ヒョウゴケン', '神戸市須磨区', 'コウベシスマク', '行平町', 'ユキヒラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市須磨区青葉町', '28', '28107', '6540038', '兵庫県', 'ヒョウゴケン', '神戸市須磨区', 'コウベシスマク', '青葉町', 'アオバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市須磨区鷹取町', '28', '28107', '6540039', '兵庫県', 'ヒョウゴケン', '神戸市須磨区', 'コウベシスマク', '鷹取町', 'タカトリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市須磨区古川町', '28', '28107', '6540041', '兵庫県', 'ヒョウゴケン', '神戸市須磨区', 'コウベシスマク', '古川町', 'フルカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市須磨区小寺町', '28', '28107', '6540042', '兵庫県', 'ヒョウゴケン', '神戸市須磨区', 'コウベシスマク', '小寺町', 'コデラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市須磨区外浜町', '28', '28107', '6540043', '兵庫県', 'ヒョウゴケン', '神戸市須磨区', 'コウベシスマク', '外浜町', 'ソトハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市須磨区稲葉町', '28', '28107', '6540044', '兵庫県', 'ヒョウゴケン', '神戸市須磨区', 'コウベシスマク', '稲葉町', 'イナバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市須磨区松風町', '28', '28107', '6540045', '兵庫県', 'ヒョウゴケン', '神戸市須磨区', 'コウベシスマク', '松風町', 'マツカゼチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市須磨区村雨町', '28', '28107', '6540046', '兵庫県', 'ヒョウゴケン', '神戸市須磨区', 'コウベシスマク', '村雨町', 'ムラサメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市須磨区磯馴町', '28', '28107', '6540047', '兵庫県', 'ヒョウゴケン', '神戸市須磨区', 'コウベシスマク', '磯馴町', 'イソナレチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市須磨区衣掛町', '28', '28107', '6540048', '兵庫県', 'ヒョウゴケン', '神戸市須磨区', 'コウベシスマク', '衣掛町', 'キヌガケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市須磨区若宮町', '28', '28107', '6540049', '兵庫県', 'ヒョウゴケン', '神戸市須磨区', 'コウベシスマク', '若宮町', 'ワカミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市須磨区月見山本町', '28', '28107', '6540051', '兵庫県', 'ヒョウゴケン', '神戸市須磨区', 'コウベシスマク', '月見山本町', 'ツキミヤマホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市須磨区行幸町', '28', '28107', '6540052', '兵庫県', 'ヒョウゴケン', '神戸市須磨区', 'コウベシスマク', '行幸町', 'ミユキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市須磨区天神町', '28', '28107', '6540053', '兵庫県', 'ヒョウゴケン', '神戸市須磨区', 'コウベシスマク', '天神町', 'テンジンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市須磨区須磨本町', '28', '28107', '6540054', '兵庫県', 'ヒョウゴケン', '神戸市須磨区', 'コウベシスマク', '須磨本町', 'スマホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市須磨区須磨浦通', '28', '28107', '6540055', '兵庫県', 'ヒョウゴケン', '神戸市須磨区', 'コウベシスマク', '須磨浦通', 'スマウラドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市須磨区高尾台', '28', '28107', '6540061', '兵庫県', 'ヒョウゴケン', '神戸市須磨区', 'コウベシスマク', '高尾台', 'タカオダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市須磨区水野町', '28', '28107', '6540062', '兵庫県', 'ヒョウゴケン', '神戸市須磨区', 'コウベシスマク', '水野町', 'ミズノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市須磨区月見山町', '28', '28107', '6540063', '兵庫県', 'ヒョウゴケン', '神戸市須磨区', 'コウベシスマク', '月見山町', 'ツキミヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市須磨区北町', '28', '28107', '6540064', '兵庫県', 'ヒョウゴケン', '神戸市須磨区', 'コウベシスマク', '北町', 'キタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市須磨区離宮前町', '28', '28107', '6540065', '兵庫県', 'ヒョウゴケン', '神戸市須磨区', 'コウベシスマク', '離宮前町', 'リキュウマエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市須磨区桜木町', '28', '28107', '6540066', '兵庫県', 'ヒョウゴケン', '神戸市須磨区', 'コウベシスマク', '桜木町', 'サクラギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市須磨区離宮西町', '28', '28107', '6540067', '兵庫県', 'ヒョウゴケン', '神戸市須磨区', 'コウベシスマク', '離宮西町', 'リキュウニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市須磨区西須磨', '28', '28107', '6540068', '兵庫県', 'ヒョウゴケン', '神戸市須磨区', 'コウベシスマク', '西須磨', 'ニシスマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市須磨区須磨寺町', '28', '28107', '6540071', '兵庫県', 'ヒョウゴケン', '神戸市須磨区', 'コウベシスマク', '須磨寺町', 'スマデラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市須磨区千守町', '28', '28107', '6540072', '兵庫県', 'ヒョウゴケン', '神戸市須磨区', 'コウベシスマク', '千守町', 'チモリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市須磨区関守町', '28', '28107', '6540073', '兵庫県', 'ヒョウゴケン', '神戸市須磨区', 'コウベシスマク', '関守町', 'セキモリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市須磨区高倉町', '28', '28107', '6540074', '兵庫県', 'ヒョウゴケン', '神戸市須磨区', 'コウベシスマク', '高倉町', 'タカクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市須磨区潮見台町', '28', '28107', '6540075', '兵庫県', 'ヒョウゴケン', '神戸市須磨区', 'コウベシスマク', '潮見台町', 'シオミダイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市須磨区一ノ谷町', '28', '28107', '6540076', '兵庫県', 'ヒョウゴケン', '神戸市須磨区', 'コウベシスマク', '一ノ谷町', 'イチノタニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市須磨区高倉台', '28', '28107', '6540081', '兵庫県', 'ヒョウゴケン', '神戸市須磨区', 'コウベシスマク', '高倉台', 'タカクラダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市須磨区白川', '28', '28107', '6540101', '兵庫県', 'ヒョウゴケン', '神戸市須磨区', 'コウベシスマク', '白川', 'シラカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市須磨区東白川台', '28', '28107', '6540102', '兵庫県', 'ヒョウゴケン', '神戸市須磨区', 'コウベシスマク', '東白川台', 'ヒガシシラカワダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市須磨区白川台', '28', '28107', '6540103', '兵庫県', 'ヒョウゴケン', '神戸市須磨区', 'コウベシスマク', '白川台', 'シラカワダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市須磨区車', '28', '28107', '6540111', '兵庫県', 'ヒョウゴケン', '神戸市須磨区', 'コウベシスマク', '車', 'クルマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市須磨区若草町', '28', '28107', '6540112', '兵庫県', 'ヒョウゴケン', '神戸市須磨区', 'コウベシスマク', '若草町', 'ワカクサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市須磨区緑が丘', '28', '28107', '6540113', '兵庫県', 'ヒョウゴケン', '神戸市須磨区', 'コウベシスマク', '緑が丘', 'ミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市須磨区妙法寺', '28', '28107', '6540121', '兵庫県', 'ヒョウゴケン', '神戸市須磨区', 'コウベシスマク', '妙法寺', 'ミョウホウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市須磨区道正台', '28', '28107', '6540122', '兵庫県', 'ヒョウゴケン', '神戸市須磨区', 'コウベシスマク', '道正台', 'ドウショウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市須磨区清水台', '28', '28107', '6540123', '兵庫県', 'ヒョウゴケン', '神戸市須磨区', 'コウベシスマク', '清水台', 'シミズダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市須磨区横尾', '28', '28107', '6540131', '兵庫県', 'ヒョウゴケン', '神戸市須磨区', 'コウベシスマク', '横尾', 'ヨコオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市須磨区多井畑南町', '28', '28107', '6540132', '兵庫県', 'ヒョウゴケン', '神戸市須磨区', 'コウベシスマク', '多井畑南町', 'タイノハタミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市須磨区多井畑', '28', '28107', '6540133', '兵庫県', 'ヒョウゴケン', '神戸市須磨区', 'コウベシスマク', '多井畑', 'タイノハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市須磨区多井畑東町', '28', '28107', '6540134', '兵庫県', 'ヒョウゴケン', '神戸市須磨区', 'コウベシスマク', '多井畑東町', 'タイノハタヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市須磨区竜が台', '28', '28107', '6540141', '兵庫県', 'ヒョウゴケン', '神戸市須磨区', 'コウベシスマク', '竜が台', 'リュウガダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市須磨区友が丘', '28', '28107', '6540142', '兵庫県', 'ヒョウゴケン', '神戸市須磨区', 'コウベシスマク', '友が丘', 'トモガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市須磨区菅の台', '28', '28107', '6540143', '兵庫県', 'ヒョウゴケン', '神戸市須磨区', 'コウベシスマク', '菅の台', 'スガノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市須磨区北落合', '28', '28107', '6540151', '兵庫県', 'ヒョウゴケン', '神戸市須磨区', 'コウベシスマク', '北落合', 'キタオチアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市須磨区東落合', '28', '28107', '6540152', '兵庫県', 'ヒョウゴケン', '神戸市須磨区', 'コウベシスマク', '東落合', 'ヒガシオチアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市須磨区南落合', '28', '28107', '6540153', '兵庫県', 'ヒョウゴケン', '神戸市須磨区', 'コウベシスマク', '南落合', 'ミナミオチアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市須磨区中落合', '28', '28107', '6540154', '兵庫県', 'ヒョウゴケン', '神戸市須磨区', 'コウベシスマク', '中落合', 'ナカオチアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市須磨区西落合', '28', '28107', '6540155', '兵庫県', 'ヒョウゴケン', '神戸市須磨区', 'コウベシスマク', '西落合', 'ニシオチアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市須磨区弥栄台', '28', '28107', '6540161', '兵庫県', 'ヒョウゴケン', '神戸市須磨区', 'コウベシスマク', '弥栄台', 'ヤサカダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市須磨区神の谷', '28', '28107', '6540162', '兵庫県', 'ヒョウゴケン', '神戸市須磨区', 'コウベシスマク', '神の谷', 'カミノタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市須磨区緑台', '28', '28107', '6540163', '兵庫県', 'ヒョウゴケン', '神戸市須磨区', 'コウベシスマク', '緑台', 'ミドリダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市垂水区', '28', '28108', '6550000', '兵庫県', 'ヒョウゴケン', '神戸市垂水区', 'コウベシタルミク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('77935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市垂水区多聞町', '28', '28108', '6550001', '兵庫県', 'ヒョウゴケン', '神戸市垂水区', 'コウベシタルミク', '多聞町', 'タモンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市垂水区小束山', '28', '28108', '6550002', '兵庫県', 'ヒョウゴケン', '神戸市垂水区', 'コウベシタルミク', '小束山', 'コヅカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市垂水区小束山本町', '28', '28108', '6550003', '兵庫県', 'ヒョウゴケン', '神戸市垂水区', 'コウベシタルミク', '小束山本町', 'コヅカヤマホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市垂水区学が丘', '28', '28108', '6550004', '兵庫県', 'ヒョウゴケン', '神戸市垂水区', 'コウベシタルミク', '学が丘', 'マナビガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市垂水区潮見が丘', '28', '28108', '6550005', '兵庫県', 'ヒョウゴケン', '神戸市垂水区', 'コウベシタルミク', '潮見が丘', 'シオミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市垂水区本多聞', '28', '28108', '6550006', '兵庫県', 'ヒョウゴケン', '神戸市垂水区', 'コウベシタルミク', '本多聞', 'ホンタモン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市垂水区多聞台', '28', '28108', '6550007', '兵庫県', 'ヒョウゴケン', '神戸市垂水区', 'コウベシタルミク', '多聞台', 'タモンダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市垂水区小束台', '28', '28108', '6550008', '兵庫県', 'ヒョウゴケン', '神戸市垂水区', 'コウベシタルミク', '小束台', 'コヅカダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市垂水区小束山手', '28', '28108', '6550009', '兵庫県', 'ヒョウゴケン', '神戸市垂水区', 'コウベシタルミク', '小束山手', 'コヅカヤマテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市垂水区千鳥が丘', '28', '28108', '6550011', '兵庫県', 'ヒョウゴケン', '神戸市垂水区', 'コウベシタルミク', '千鳥が丘', 'チドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市垂水区向陽', '28', '28108', '6550012', '兵庫県', 'ヒョウゴケン', '神戸市垂水区', 'コウベシタルミク', '向陽', 'コウヨウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市垂水区福田', '28', '28108', '6550013', '兵庫県', 'ヒョウゴケン', '神戸市垂水区', 'コウベシタルミク', '福田', 'フクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市垂水区大町', '28', '28108', '6550014', '兵庫県', 'ヒョウゴケン', '神戸市垂水区', 'コウベシタルミク', '大町', 'オオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市垂水区野田通', '28', '28108', '6550015', '兵庫県', 'ヒョウゴケン', '神戸市垂水区', 'コウベシタルミク', '野田通', 'ノダドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市垂水区高丸', '28', '28108', '6550016', '兵庫県', 'ヒョウゴケン', '神戸市垂水区', 'コウベシタルミク', '高丸', 'タカマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市垂水区上高丸', '28', '28108', '6550017', '兵庫県', 'ヒョウゴケン', '神戸市垂水区', 'コウベシタルミク', '上高丸', 'カミタカマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市垂水区千代が丘', '28', '28108', '6550018', '兵庫県', 'ヒョウゴケン', '神戸市垂水区', 'コウベシタルミク', '千代が丘', 'チヨガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市垂水区馬場通', '28', '28108', '6550021', '兵庫県', 'ヒョウゴケン', '神戸市垂水区', 'コウベシタルミク', '馬場通', 'ババドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市垂水区瑞穂通', '28', '28108', '6550022', '兵庫県', 'ヒョウゴケン', '神戸市垂水区', 'コウベシタルミク', '瑞穂通', 'ミズホドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市垂水区清水通', '28', '28108', '6550023', '兵庫県', 'ヒョウゴケン', '神戸市垂水区', 'コウベシタルミク', '清水通', 'シミズドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市垂水区御霊町', '28', '28108', '6550024', '兵庫県', 'ヒョウゴケン', '神戸市垂水区', 'コウベシタルミク', '御霊町', 'ゴリョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市垂水区瑞ケ丘', '28', '28108', '6550025', '兵庫県', 'ヒョウゴケン', '神戸市垂水区', 'コウベシタルミク', '瑞ケ丘', 'ミズガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市垂水区陸ノ町', '28', '28108', '6550026', '兵庫県', 'ヒョウゴケン', '神戸市垂水区', 'コウベシタルミク', '陸ノ町', 'クガノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市垂水区神田町', '28', '28108', '6550027', '兵庫県', 'ヒョウゴケン', '神戸市垂水区', 'コウベシタルミク', '神田町', 'カンダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市垂水区宮本町', '28', '28108', '6550028', '兵庫県', 'ヒョウゴケン', '神戸市垂水区', 'コウベシタルミク', '宮本町', 'ミヤモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市垂水区天ノ下町', '28', '28108', '6550029', '兵庫県', 'ヒョウゴケン', '神戸市垂水区', 'コウベシタルミク', '天ノ下町', 'テンノシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市垂水区清水が丘', '28', '28108', '6550031', '兵庫県', 'ヒョウゴケン', '神戸市垂水区', 'コウベシタルミク', '清水が丘', 'シミズガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市垂水区星が丘', '28', '28108', '6550032', '兵庫県', 'ヒョウゴケン', '神戸市垂水区', 'コウベシタルミク', '星が丘', 'ホシガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市垂水区旭が丘', '28', '28108', '6550033', '兵庫県', 'ヒョウゴケン', '神戸市垂水区', 'コウベシタルミク', '旭が丘', 'アサヒガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市垂水区仲田', '28', '28108', '6550034', '兵庫県', 'ヒョウゴケン', '神戸市垂水区', 'コウベシタルミク', '仲田', 'ナカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市垂水区五色山', '28', '28108', '6550035', '兵庫県', 'ヒョウゴケン', '神戸市垂水区', 'コウベシタルミク', '五色山', 'ゴシキヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市垂水区海岸通', '28', '28108', '6550036', '兵庫県', 'ヒョウゴケン', '神戸市垂水区', 'コウベシタルミク', '海岸通', 'カイガンドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市垂水区歌敷山', '28', '28108', '6550037', '兵庫県', 'ヒョウゴケン', '神戸市垂水区', 'コウベシタルミク', '歌敷山', 'ウタシキヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市垂水区星陵台', '28', '28108', '6550038', '兵庫県', 'ヒョウゴケン', '神戸市垂水区', 'コウベシタルミク', '星陵台', 'セイリョウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市垂水区霞ケ丘', '28', '28108', '6550039', '兵庫県', 'ヒョウゴケン', '神戸市垂水区', 'コウベシタルミク', '霞ケ丘', 'カスミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市垂水区神陵台', '28', '28108', '6550041', '兵庫県', 'ヒョウゴケン', '神戸市垂水区', 'コウベシタルミク', '神陵台', 'シンリョウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市垂水区西脇', '28', '28108', '6550042', '兵庫県', 'ヒョウゴケン', '神戸市垂水区', 'コウベシタルミク', '西脇', 'ニシワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市垂水区南多聞台', '28', '28108', '6550043', '兵庫県', 'ヒョウゴケン', '神戸市垂水区', 'コウベシタルミク', '南多聞台', 'ミナミタモンダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市垂水区舞子坂', '28', '28108', '6550044', '兵庫県', 'ヒョウゴケン', '神戸市垂水区', 'コウベシタルミク', '舞子坂', 'マイコザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市垂水区北舞子', '28', '28108', '6550045', '兵庫県', 'ヒョウゴケン', '神戸市垂水区', 'コウベシタルミク', '北舞子', 'キタマイコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市垂水区舞子台', '28', '28108', '6550046', '兵庫県', 'ヒョウゴケン', '神戸市垂水区', 'コウベシタルミク', '舞子台', 'マイコダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市垂水区東舞子町', '28', '28108', '6550047', '兵庫県', 'ヒョウゴケン', '神戸市垂水区', 'コウベシタルミク', '東舞子町', 'ヒガシマイコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市垂水区西舞子', '28', '28108', '6550048', '兵庫県', 'ヒョウゴケン', '神戸市垂水区', 'コウベシタルミク', '西舞子', 'ニシマイコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市垂水区狩口台', '28', '28108', '6550049', '兵庫県', 'ヒョウゴケン', '神戸市垂水区', 'コウベシタルミク', '狩口台', 'カリグチダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市垂水区舞多聞西', '28', '28108', '6550051', '兵庫県', 'ヒョウゴケン', '神戸市垂水区', 'コウベシタルミク', '舞多聞西', 'マイタモンニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市垂水区舞多聞東', '28', '28108', '6550052', '兵庫県', 'ヒョウゴケン', '神戸市垂水区', 'コウベシタルミク', '舞多聞東', 'マイタモンヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市垂水区神和台', '28', '28108', '6550851', '兵庫県', 'ヒョウゴケン', '神戸市垂水区', 'コウベシタルミク', '神和台', 'シンワダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市垂水区名谷町', '28', '28108', '6550852', '兵庫県', 'ヒョウゴケン', '神戸市垂水区', 'コウベシタルミク', '名谷町', 'ミョウダニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市垂水区つつじが丘', '28', '28108', '6550853', '兵庫県', 'ヒョウゴケン', '神戸市垂水区', 'コウベシタルミク', 'つつじが丘', 'ツツジガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市垂水区桃山台', '28', '28108', '6550854', '兵庫県', 'ヒョウゴケン', '神戸市垂水区', 'コウベシタルミク', '桃山台', 'モモヤマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市垂水区下畑町', '28', '28108', '6550861', '兵庫県', 'ヒョウゴケン', '神戸市垂水区', 'コウベシタルミク', '下畑町', 'シモハタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市垂水区朝谷町', '28', '28108', '6550862', '兵庫県', 'ヒョウゴケン', '神戸市垂水区', 'コウベシタルミク', '朝谷町', 'アサタニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市垂水区塩屋北町', '28', '28108', '6550863', '兵庫県', 'ヒョウゴケン', '神戸市垂水区', 'コウベシタルミク', '塩屋北町', 'シオヤキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市垂水区塩屋台', '28', '28108', '6550864', '兵庫県', 'ヒョウゴケン', '神戸市垂水区', 'コウベシタルミク', '塩屋台', 'シオヤダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市垂水区清玄町', '28', '28108', '6550865', '兵庫県', 'ヒョウゴケン', '神戸市垂水区', 'コウベシタルミク', '清玄町', 'セイゲンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市垂水区松風台', '28', '28108', '6550871', '兵庫県', 'ヒョウゴケン', '神戸市垂水区', 'コウベシタルミク', '松風台', 'ショウフウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市垂水区塩屋町', '28', '28108', '6550872', '兵庫県', 'ヒョウゴケン', '神戸市垂水区', 'コウベシタルミク', '塩屋町', 'シオヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市垂水区青山台', '28', '28108', '6550873', '兵庫県', 'ヒョウゴケン', '神戸市垂水区', 'コウベシタルミク', '青山台', 'アオヤマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市垂水区美山台', '28', '28108', '6550874', '兵庫県', 'ヒョウゴケン', '神戸市垂水区', 'コウベシタルミク', '美山台', 'ミヤマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市垂水区東垂水町', '28', '28108', '6550881', '兵庫県', 'ヒョウゴケン', '神戸市垂水区', 'コウベシタルミク', '東垂水町', 'ヒガシタルミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市垂水区乙木', '28', '28108', '6550882', '兵庫県', 'ヒョウゴケン', '神戸市垂水区', 'コウベシタルミク', '乙木', 'オトギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市垂水区王居殿', '28', '28108', '6550883', '兵庫県', 'ヒョウゴケン', '神戸市垂水区', 'コウベシタルミク', '王居殿', 'オウイデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市垂水区城が山', '28', '28108', '6550884', '兵庫県', 'ヒョウゴケン', '神戸市垂水区', 'コウベシタルミク', '城が山', 'シロガヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市垂水区泉が丘', '28', '28108', '6550885', '兵庫県', 'ヒョウゴケン', '神戸市垂水区', 'コウベシタルミク', '泉が丘', 'イズミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('77999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市垂水区東垂水', '28', '28108', '6550886', '兵庫県', 'ヒョウゴケン', '神戸市垂水区', 'コウベシタルミク', '東垂水', 'ヒガシタルミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市垂水区山手', '28', '28108', '6550891', '兵庫県', 'ヒョウゴケン', '神戸市垂水区', 'コウベシタルミク', '山手', 'ヤマテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市垂水区平磯', '28', '28108', '6550892', '兵庫県', 'ヒョウゴケン', '神戸市垂水区', 'コウベシタルミク', '平磯', 'ヒライソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市垂水区日向', '28', '28108', '6550893', '兵庫県', 'ヒョウゴケン', '神戸市垂水区', 'コウベシタルミク', '日向', 'ヒュウガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市垂水区川原', '28', '28108', '6550894', '兵庫県', 'ヒョウゴケン', '神戸市垂水区', 'コウベシタルミク', '川原', 'カワハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市垂水区坂上', '28', '28108', '6550895', '兵庫県', 'ヒョウゴケン', '神戸市垂水区', 'コウベシタルミク', '坂上', 'サカガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市垂水区中道', '28', '28108', '6550896', '兵庫県', 'ヒョウゴケン', '神戸市垂水区', 'コウベシタルミク', '中道', 'ナカミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県洲本市', '28', '28205', '6560000', '兵庫県', 'ヒョウゴケン', '洲本市', 'スモトシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('78008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県洲本市中川原町厚浜', '28', '28205', '6560001', '兵庫県', 'ヒョウゴケン', '洲本市', 'スモトシ', '中川原町厚浜', 'ナカガワラチョウアツハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県洲本市中川原町中川原', '28', '28205', '6560002', '兵庫県', 'ヒョウゴケン', '洲本市', 'スモトシ', '中川原町中川原', 'ナカガワラチョウナカガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県洲本市中川原町三木田', '28', '28205', '6560003', '兵庫県', 'ヒョウゴケン', '洲本市', 'スモトシ', '中川原町三木田', 'ナカガワラチョウミキダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県洲本市中川原町安坂', '28', '28205', '6560004', '兵庫県', 'ヒョウゴケン', '洲本市', 'スモトシ', '中川原町安坂', 'ナカガワラチョウヤスサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県洲本市中川原町市原', '28', '28205', '6560005', '兵庫県', 'ヒョウゴケン', '洲本市', 'スモトシ', '中川原町市原', 'ナカガワラチョウイチバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県洲本市中川原町二ツ石', '28', '28205', '6560006', '兵庫県', 'ヒョウゴケン', '洲本市', 'スモトシ', '中川原町二ツ石', 'ナカガワラチョウフタツイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県洲本市炬口', '28', '28205', '6560011', '兵庫県', 'ヒョウゴケン', '洲本市', 'スモトシ', '炬口', 'タケノクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県洲本市宇山', '28', '28205', '6560012', '兵庫県', 'ヒョウゴケン', '洲本市', 'スモトシ', '宇山', 'ウヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県洲本市下加茂', '28', '28205', '6560013', '兵庫県', 'ヒョウゴケン', '洲本市', 'スモトシ', '下加茂', 'シモガモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県洲本市桑間', '28', '28205', '6560014', '兵庫県', 'ヒョウゴケン', '洲本市', 'スモトシ', '桑間', 'クワマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県洲本市上加茂', '28', '28205', '6560015', '兵庫県', 'ヒョウゴケン', '洲本市', 'スモトシ', '上加茂', 'カミガモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県洲本市下内膳', '28', '28205', '6560016', '兵庫県', 'ヒョウゴケン', '洲本市', 'スモトシ', '下内膳', 'シモナイゼン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県洲本市上内膳', '28', '28205', '6560017', '兵庫県', 'ヒョウゴケン', '洲本市', 'スモトシ', '上内膳', 'カミナイゼン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県洲本市奥畑', '28', '28205', '6560018', '兵庫県', 'ヒョウゴケン', '洲本市', 'スモトシ', '奥畑', 'オクハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県洲本市塩屋', '28', '28205', '6560021', '兵庫県', 'ヒョウゴケン', '洲本市', 'スモトシ', '塩屋', 'シオヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県洲本市海岸通', '28', '28205', '6560022', '兵庫県', 'ヒョウゴケン', '洲本市', 'スモトシ', '海岸通', 'カイガンドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県洲本市小路谷', '28', '28205', '6560023', '兵庫県', 'ヒョウゴケン', '洲本市', 'スモトシ', '小路谷', 'オロダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県洲本市山手', '28', '28205', '6560024', '兵庫県', 'ヒョウゴケン', '洲本市', 'スモトシ', '山手', 'ヤマテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県洲本市本町', '28', '28205', '6560025', '兵庫県', 'ヒョウゴケン', '洲本市', 'スモトシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県洲本市栄町', '28', '28205', '6560026', '兵庫県', 'ヒョウゴケン', '洲本市', 'スモトシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県洲本市港', '28', '28205', '6560027', '兵庫県', 'ヒョウゴケン', '洲本市', 'スモトシ', '港', 'ミナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県洲本市千草', '28', '28205', '6560031', '兵庫県', 'ヒョウゴケン', '洲本市', 'スモトシ', '千草', 'チクサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県洲本市新村', '28', '28205', '6560041', '兵庫県', 'ヒョウゴケン', '洲本市', 'スモトシ', '新村', 'シンムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県洲本市池内', '28', '28205', '6560042', '兵庫県', 'ヒョウゴケン', '洲本市', 'スモトシ', '池内', 'イケウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県洲本市池田', '28', '28205', '6560043', '兵庫県', 'ヒョウゴケン', '洲本市', 'スモトシ', '池田', 'イケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県洲本市前平', '28', '28205', '6560044', '兵庫県', 'ヒョウゴケン', '洲本市', 'スモトシ', '前平', 'マエヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県洲本市木戸', '28', '28205', '6560045', '兵庫県', 'ヒョウゴケン', '洲本市', 'スモトシ', '木戸', 'キド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県洲本市金屋', '28', '28205', '6560046', '兵庫県', 'ヒョウゴケン', '洲本市', 'スモトシ', '金屋', 'カナヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県洲本市物部', '28', '28205', '6560051', '兵庫県', 'ヒョウゴケン', '洲本市', 'スモトシ', '物部', 'モノベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県洲本市津田', '28', '28205', '6560052', '兵庫県', 'ヒョウゴケン', '洲本市', 'スモトシ', '津田', 'ツダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県洲本市上物部', '28', '28205', '6560053', '兵庫県', 'ヒョウゴケン', '洲本市', 'スモトシ', '上物部', 'カミモノベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県洲本市宇原', '28', '28205', '6560054', '兵庫県', 'ヒョウゴケン', '洲本市', 'スモトシ', '宇原', 'ウハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県洲本市大野', '28', '28205', '6560055', '兵庫県', 'ヒョウゴケン', '洲本市', 'スモトシ', '大野', 'オオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県洲本市納', '28', '28205', '6560101', '兵庫県', 'ヒョウゴケン', '洲本市', 'スモトシ', '納', 'オサメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県洲本市鮎屋', '28', '28205', '6560111', '兵庫県', 'ヒョウゴケン', '洲本市', 'スモトシ', '鮎屋', 'アイヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市山添', '28', '28224', '6560121', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '山添', 'ヤマゾエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市広田広田', '28', '28224', '6560122', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '広田広田', 'ヒロタヒロタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市広田中筋', '28', '28224', '6560131', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '広田中筋', 'ヒロタナカスジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市中条広田', '28', '28224', '6560141', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '中条広田', 'チュウジョウヒロタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市中条徳原', '28', '28224', '6560142', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '中条徳原', 'チュウジョウトクハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市中条中筋', '28', '28224', '6560143', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '中条中筋', 'チュウジョウチュウキン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市倭文安住寺', '28', '28224', '6560151', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '倭文安住寺', 'シトオリアンジュウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市倭文長田', '28', '28224', '6560152', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '倭文長田', 'シトオリナガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市倭文庄田', '28', '28224', '6560153', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '倭文庄田', 'シトオリショウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市倭文神道', '28', '28224', '6560154', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '倭文神道', 'シトオリジンドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市倭文土井', '28', '28224', '6560161', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '倭文土井', 'シトオリドイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市松帆北方', '28', '28224', '6560301', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '松帆北方', 'マツホキタカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市松帆塩浜', '28', '28224', '6560302', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '松帆塩浜', 'マツホシオハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市松帆江尻', '28', '28224', '6560303', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '松帆江尻', 'マツホエジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市松帆古津路', '28', '28224', '6560304', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '松帆古津路', 'マツホコツロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市松帆北浜', '28', '28224', '6560305', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '松帆北浜', 'マツホキタハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市松帆慶野', '28', '28224', '6560306', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '松帆慶野', 'マツホケイノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市松帆檪田', '28', '28224', '6560307', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '松帆檪田', 'マツホイチダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市松帆宝明寺', '28', '28224', '6560308', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '松帆宝明寺', 'マツホホウミョウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市松帆戒旦寺', '28', '28224', '6560311', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '松帆戒旦寺', 'マツホカイダンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市松帆脇田', '28', '28224', '6560312', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '松帆脇田', 'マツホワキダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市松帆志知川', '28', '28224', '6560313', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '松帆志知川', 'マツホシチガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市松帆西路', '28', '28224', '6560314', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '松帆西路', 'マツホニシジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市松帆高屋', '28', '28224', '6560315', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '松帆高屋', 'マツホタカヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市志知', '28', '28224', '6560321', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '志知', 'シチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市志知鈩', '28', '28224', '6560322', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '志知鈩', 'シチタタラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市志知飯山寺', '28', '28224', '6560323', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '志知飯山寺', 'シチハンサンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市志知口', '28', '28224', '6560324', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '志知口', 'シチクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市志知奥', '28', '28224', '6560325', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '志知奥', 'シチオク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市志知南', '28', '28224', '6560326', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '志知南', 'シチミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市志知北', '28', '28224', '6560327', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '志知北', 'シチキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市湊里', '28', '28224', '6560331', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '湊里', 'ミナトサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市湊', '28', '28224', '6560332', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '湊', 'ミナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市津井', '28', '28224', '6560341', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '津井', 'ツイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市', '28', '28224', '6560400', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('78080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市倭文高', '28', '28224', '6560411', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '倭文高', 'シトオリコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市倭文委文', '28', '28224', '6560412', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '倭文委文', 'シトオリイブン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市倭文流', '28', '28224', '6560413', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '倭文流', 'シトオリナガレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市榎列山所', '28', '28224', '6560421', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '榎列山所', 'エナミヤマジョ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市榎列上幡多', '28', '28224', '6560422', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '榎列上幡多', 'エナミカミハダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市榎列下幡多', '28', '28224', '6560423', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '榎列下幡多', 'エナミシモハダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市榎列西川', '28', '28224', '6560424', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '榎列西川', 'エナミニシガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市榎列小榎列', '28', '28224', '6560425', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '榎列小榎列', 'エナミコエナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市榎列大榎列', '28', '28224', '6560426', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '榎列大榎列', 'エナミオオエナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市榎列松田', '28', '28224', '6560427', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '榎列松田', 'エナミマツダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市榎列掃守', '28', '28224', '6560428', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '榎列掃守', 'エナミカモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市八木野原', '28', '28224', '6560431', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '八木野原', 'ヤギノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市八木徳野', '28', '28224', '6560432', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '八木徳野', 'ヤギトクノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市八木鳥井', '28', '28224', '6560433', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '八木鳥井', 'ヤギトリイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市八木国分', '28', '28224', '6560434', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '八木国分', 'ヤギコクブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市八木立石', '28', '28224', '6560435', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '八木立石', 'ヤギタテイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市八木新庄', '28', '28224', '6560436', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '八木新庄', 'ヤギシンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市八木入田', '28', '28224', '6560441', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '八木入田', 'ヤギイリタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市八木養宜中', '28', '28224', '6560442', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '八木養宜中', 'ヤギヨウギナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市八木養宜上', '28', '28224', '6560443', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '八木養宜上', 'ヤギヨウギカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市八木大久保', '28', '28224', '6560444', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '八木大久保', 'ヤギオオクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市八木馬回', '28', '28224', '6560445', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '八木馬回', 'ヤギウママワリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市八木寺内', '28', '28224', '6560446', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '八木寺内', 'ヤギジナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市神代社家', '28', '28224', '6560451', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '神代社家', 'ジンダイシャケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市神代浦壁', '28', '28224', '6560452', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '神代浦壁', 'ジンダイウラカベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市神代黒道', '28', '28224', '6560453', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '神代黒道', 'ジンダイクロミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市神代喜来', '28', '28224', '6560454', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '神代喜来', 'ジンダイキライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市神代國衙', '28', '28224', '6560455', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '神代國衙', 'ジンダイコクガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市神代地頭方', '28', '28224', '6560456', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '神代地頭方', 'ジンダイジトホウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市神代富田', '28', '28224', '6560457', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '神代富田', 'ジンダイトミダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市市円行寺', '28', '28224', '6560461', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '市円行寺', 'イチエンギョウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市市青木', '28', '28224', '6560462', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '市青木', 'イチアオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市市十一ケ所', '28', '28224', '6560471', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '市十一ケ所', 'イチジュウイッカショ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市市善光寺', '28', '28224', '6560472', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '市善光寺', 'イチゼンコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市市小井', '28', '28224', '6560473', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '市小井', 'イチオイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市市市', '28', '28224', '6560474', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '市市', 'イチイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市市三條', '28', '28224', '6560475', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '市三條', 'イチサンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市市新', '28', '28224', '6560476', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '市新', 'イチシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市市徳長', '28', '28224', '6560477', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '市徳長', 'イチトクナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市市福永', '28', '28224', '6560478', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '市福永', 'イチフクナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市志知松本', '28', '28224', '6560481', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '志知松本', 'シチマツモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市志知難波', '28', '28224', '6560482', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '志知難波', 'シチナンバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市志知中島', '28', '28224', '6560483', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '志知中島', 'シチナカシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市志知佐礼尾', '28', '28224', '6560484', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '志知佐礼尾', 'シチサレオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市福良甲', '28', '28224', '6560501', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '福良甲', 'フクラコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市福良乙', '28', '28224', '6560502', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '福良乙', 'フクラオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市福良丙', '28', '28224', '6560503', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '福良丙', 'フクラヘイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市賀集八幡', '28', '28224', '6560511', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '賀集八幡', 'カシュウヤハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市賀集立川瀬', '28', '28224', '6560512', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '賀集立川瀬', 'カシュウタテガワセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市賀集野田', '28', '28224', '6560513', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '賀集野田', 'カシュウノタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市賀集賀集', '28', '28224', '6560514', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '賀集', 'カシュウ', null, null, '賀集', 'カシュウ');
INSERT INTO `ms_addresses` VALUES ('78132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市賀集鍛治屋', '28', '28224', '6560515', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '賀集鍛治屋', 'カシュウカジヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市賀集福井', '28', '28224', '6560516', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '賀集福井', 'カシュウフクイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市賀集内ケ原', '28', '28224', '6560517', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '賀集内ケ原', 'カシュウウチガハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市賀集生子', '28', '28224', '6560517', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '賀集生子', 'カシュウセイゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市賀集長原', '28', '28224', '6560517', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '賀集長原', 'カシュウナガハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市賀集牛内', '28', '28224', '6560518', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '賀集牛内', 'カシュウウシウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市潮美台', '28', '28224', '6560521', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '潮美台', 'シオミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市北阿万伊賀野', '28', '28224', '6560531', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '北阿万伊賀野', 'キタアマイガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市北阿万稲田南', '28', '28224', '6560532', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '北阿万稲田南', 'キタアマイナダミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市北阿万新田北', '28', '28224', '6560533', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '北阿万新田', 'キタアマシンデン', null, null, '北', 'キタ');
INSERT INTO `ms_addresses` VALUES ('78142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市北阿万新田中', '28', '28224', '6560533', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '北阿万新田', 'キタアマシンデン', null, null, '中', 'ナカ');
INSERT INTO `ms_addresses` VALUES ('78143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市北阿万筒井', '28', '28224', '6560534', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '北阿万筒井', 'キタアマツツイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市阿万上町', '28', '28224', '6560541', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '阿万上町', 'アマカミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市阿万吹上町', '28', '28224', '6560542', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '阿万吹上町', 'アマフキアゲマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市阿万塩屋町', '28', '28224', '6560543', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '阿万塩屋町', 'アマシオヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市阿万下町', '28', '28224', '6560544', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '阿万下町', 'アマシモマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市阿万西町', '28', '28224', '6560545', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '阿万西町', 'アマニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市阿万東町', '28', '28224', '6560546', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '阿万東町', 'アマヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市灘', '28', '28224', '6560551', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '灘', 'ナダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市伊加利', '28', '28224', '6560651', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '伊加利', 'イカリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市阿那賀', '28', '28224', '6560661', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '阿那賀', 'アナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市阿那賀志知川', '28', '28224', '6560662', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '阿那賀志知川', 'アナガシチガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市阿那賀西路', '28', '28224', '6560663', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '阿那賀西路', 'アナガニシジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県南あわじ市沼島', '28', '28224', '6560961', '兵庫県', 'ヒョウゴケン', '南あわじ市', 'ミナミアワジシ', '沼島', 'ヌシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県洲本市五色町都志', '28', '28205', '6561301', '兵庫県', 'ヒョウゴケン', '洲本市', 'スモトシ', '五色町都志', 'ゴシキチョウツシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県洲本市五色町都志米山', '28', '28205', '6561302', '兵庫県', 'ヒョウゴケン', '洲本市', 'スモトシ', '五色町都志米山', 'ゴシキチョウツシコメヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県洲本市五色町都志大宮', '28', '28205', '6561303', '兵庫県', 'ヒョウゴケン', '洲本市', 'スモトシ', '五色町都志大宮', 'ゴシキチョウツシオオミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県洲本市五色町都志万歳', '28', '28205', '6561304', '兵庫県', 'ヒョウゴケン', '洲本市', 'スモトシ', '五色町都志万歳', 'ゴシキチョウツシマンザイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県洲本市五色町鮎原葛尾', '28', '28205', '6561311', '兵庫県', 'ヒョウゴケン', '洲本市', 'スモトシ', '五色町鮎原葛尾', 'ゴシキチョウアイハラツヅラオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県洲本市五色町鮎原吉田', '28', '28205', '6561312', '兵庫県', 'ヒョウゴケン', '洲本市', 'スモトシ', '五色町鮎原吉田', 'ゴシキチョウアイハラヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県洲本市五色町鮎原西', '28', '28205', '6561313', '兵庫県', 'ヒョウゴケン', '洲本市', 'スモトシ', '五色町鮎原西', 'ゴシキチョウアイハラニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県洲本市五色町鮎原鮎の郷', '28', '28205', '6561314', '兵庫県', 'ヒョウゴケン', '洲本市', 'スモトシ', '五色町鮎原鮎の郷', 'ゴシキチョウアイハラアユノサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県洲本市五色町鮎原宇谷', '28', '28205', '6561315', '兵庫県', 'ヒョウゴケン', '洲本市', 'スモトシ', '五色町鮎原宇谷', 'ゴシキチョウアイハラウダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県洲本市五色町鮎原栢野', '28', '28205', '6561316', '兵庫県', 'ヒョウゴケン', '洲本市', 'スモトシ', '五色町鮎原栢野', 'ゴシキチョウアイハラカヤノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県洲本市五色町鮎原小山田', '28', '28205', '6561317', '兵庫県', 'ヒョウゴケン', '洲本市', 'スモトシ', '五色町鮎原小山田', 'ゴシキチョウアイハラコヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県洲本市五色町鮎原神陽', '28', '28205', '6561318', '兵庫県', 'ヒョウゴケン', '洲本市', 'スモトシ', '五色町鮎原神陽', 'ゴシキチョウアイハラシンヨウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県洲本市五色町鮎原中邑', '28', '28205', '6561321', '兵庫県', 'ヒョウゴケン', '洲本市', 'スモトシ', '五色町鮎原中邑', 'ゴシキチョウアイハラナカムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県洲本市五色町鮎原上', '28', '28205', '6561322', '兵庫県', 'ヒョウゴケン', '洲本市', 'スモトシ', '五色町鮎原上', 'ゴシキチョウアイハラカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県洲本市五色町鮎原塔下', '28', '28205', '6561323', '兵庫県', 'ヒョウゴケン', '洲本市', 'スモトシ', '五色町鮎原塔下', 'ゴシキチョウアイハラトウゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県洲本市五色町鮎原三野畑', '28', '28205', '6561324', '兵庫県', 'ヒョウゴケン', '洲本市', 'スモトシ', '五色町鮎原三野畑', 'ゴシキチョウアイハラミノハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県洲本市五色町鮎原南谷', '28', '28205', '6561325', '兵庫県', 'ヒョウゴケン', '洲本市', 'スモトシ', '五色町鮎原南谷', 'ゴシキチョウアイハラミナミダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県洲本市五色町鮎原下', '28', '28205', '6561326', '兵庫県', 'ヒョウゴケン', '洲本市', 'スモトシ', '五色町鮎原下', 'ゴシキチョウアイハラシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県洲本市五色町鮎原田処', '28', '28205', '6561327', '兵庫県', 'ヒョウゴケン', '洲本市', 'スモトシ', '五色町鮎原田処', 'ゴシキチョウアイハラタドコロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県洲本市五色町都志大日', '28', '28205', '6561331', '兵庫県', 'ヒョウゴケン', '洲本市', 'スモトシ', '五色町都志大日', 'ゴシキチョウツシダイニチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県洲本市五色町広石北', '28', '28205', '6561332', '兵庫県', 'ヒョウゴケン', '洲本市', 'スモトシ', '五色町広石北', 'ゴシキチョウヒロイシキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県洲本市五色町広石上', '28', '28205', '6561333', '兵庫県', 'ヒョウゴケン', '洲本市', 'スモトシ', '五色町広石上', 'ゴシキチョウヒロイシカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県洲本市五色町広石中', '28', '28205', '6561334', '兵庫県', 'ヒョウゴケン', '洲本市', 'スモトシ', '五色町広石中', 'ゴシキチョウヒロイシナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県洲本市五色町広石下', '28', '28205', '6561335', '兵庫県', 'ヒョウゴケン', '洲本市', 'スモトシ', '五色町広石下', 'ゴシキチョウヒロイシシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県洲本市五色町上堺', '28', '28205', '6561336', '兵庫県', 'ヒョウゴケン', '洲本市', 'スモトシ', '五色町上堺', 'ゴシキチョウカミサカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県洲本市五色町下堺', '28', '28205', '6561337', '兵庫県', 'ヒョウゴケン', '洲本市', 'スモトシ', '五色町下堺', 'ゴシキチョウシモサカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県洲本市五色町都志角川', '28', '28205', '6561341', '兵庫県', 'ヒョウゴケン', '洲本市', 'スモトシ', '五色町都志角川', 'ゴシキチョウツシツノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県洲本市五色町鳥飼上', '28', '28205', '6561342', '兵庫県', 'ヒョウゴケン', '洲本市', 'スモトシ', '五色町鳥飼上', 'ゴシキチョウトリカイカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県洲本市五色町鳥飼中', '28', '28205', '6561343', '兵庫県', 'ヒョウゴケン', '洲本市', 'スモトシ', '五色町鳥飼中', 'ゴシキチョウトリカイナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県洲本市五色町鳥飼浦', '28', '28205', '6561344', '兵庫県', 'ヒョウゴケン', '洲本市', 'スモトシ', '五色町鳥飼浦', 'ゴシキチョウトリカイウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県淡路市尾崎', '28', '28226', '6561501', '兵庫県', 'ヒョウゴケン', '淡路市', 'アワジシ', '尾崎', 'オサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県淡路市新村', '28', '28226', '6561502', '兵庫県', 'ヒョウゴケン', '淡路市', 'アワジシ', '新村', 'シンムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県淡路市遠田', '28', '28226', '6561503', '兵庫県', 'ヒョウゴケン', '淡路市', 'アワジシ', '遠田', 'トオダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県淡路市郡家', '28', '28226', '6561511', '兵庫県', 'ヒョウゴケン', '淡路市', 'アワジシ', '郡家', 'グンゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県淡路市北山', '28', '28226', '6561512', '兵庫県', 'ヒョウゴケン', '淡路市', 'アワジシ', '北山', 'キタヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県淡路市多賀', '28', '28226', '6561521', '兵庫県', 'ヒョウゴケン', '淡路市', 'アワジシ', '多賀', 'タガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県淡路市下河合', '28', '28226', '6561522', '兵庫県', 'ヒョウゴケン', '淡路市', 'アワジシ', '下河合', 'シモガワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県淡路市上河合', '28', '28226', '6561523', '兵庫県', 'ヒョウゴケン', '淡路市', 'アワジシ', '上河合', 'カミガワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県淡路市竹谷', '28', '28226', '6561524', '兵庫県', 'ヒョウゴケン', '淡路市', 'アワジシ', '竹谷', 'タケダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県淡路市井手', '28', '28226', '6561525', '兵庫県', 'ヒョウゴケン', '淡路市', 'アワジシ', '井手', 'イデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県淡路市中村', '28', '28226', '6561526', '兵庫県', 'ヒョウゴケン', '淡路市', 'アワジシ', '中村', 'ナカムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県淡路市江井', '28', '28226', '6561531', '兵庫県', 'ヒョウゴケン', '淡路市', 'アワジシ', '江井', 'エイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県淡路市柳沢', '28', '28226', '6561541', '兵庫県', 'ヒョウゴケン', '淡路市', 'アワジシ', '柳沢', 'ヤナギサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県淡路市高山', '28', '28226', '6561551', '兵庫県', 'ヒョウゴケン', '淡路市', 'アワジシ', '高山', 'タカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県淡路市入野', '28', '28226', '6561552', '兵庫県', 'ヒョウゴケン', '淡路市', 'アワジシ', '入野', 'イリノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県淡路市山田', '28', '28226', '6561553', '兵庫県', 'ヒョウゴケン', '淡路市', 'アワジシ', '山田', 'ヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県淡路市深草', '28', '28226', '6561554', '兵庫県', 'ヒョウゴケン', '淡路市', 'アワジシ', '深草', 'フカクサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県淡路市南', '28', '28226', '6561555', '兵庫県', 'ヒョウゴケン', '淡路市', 'アワジシ', '南', 'ミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県淡路市草香', '28', '28226', '6561556', '兵庫県', 'ヒョウゴケン', '淡路市', 'アワジシ', '草香', 'クサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県淡路市明神', '28', '28226', '6561557', '兵庫県', 'ヒョウゴケン', '淡路市', 'アワジシ', '明神', 'ミョウジン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県淡路市草香北', '28', '28226', '6561558', '兵庫県', 'ヒョウゴケン', '淡路市', 'アワジシ', '草香北', 'クサカキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県淡路市黒谷', '28', '28226', '6561601', '兵庫県', 'ヒョウゴケン', '淡路市', 'アワジシ', '黒谷', 'クロダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県淡路市育波', '28', '28226', '6561602', '兵庫県', 'ヒョウゴケン', '淡路市', 'アワジシ', '育波', 'イクハ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県淡路市生田大坪', '28', '28226', '6561603', '兵庫県', 'ヒョウゴケン', '淡路市', 'アワジシ', '生田大坪', 'イクタオオツボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県淡路市生田畑', '28', '28226', '6561604', '兵庫県', 'ヒョウゴケン', '淡路市', 'アワジシ', '生田畑', 'イクタハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県淡路市生田田尻', '28', '28226', '6561605', '兵庫県', 'ヒョウゴケン', '淡路市', 'アワジシ', '生田田尻', 'イクタタジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県淡路市室津', '28', '28226', '6561606', '兵庫県', 'ヒョウゴケン', '淡路市', 'アワジシ', '室津', 'ムロツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県淡路市富島', '28', '28226', '6561711', '兵庫県', 'ヒョウゴケン', '淡路市', 'アワジシ', '富島', 'トシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県淡路市石田', '28', '28226', '6561712', '兵庫県', 'ヒョウゴケン', '淡路市', 'アワジシ', '石田', 'イシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県淡路市野島蟇浦', '28', '28226', '6561721', '兵庫県', 'ヒョウゴケン', '淡路市', 'アワジシ', '野島蟇浦', 'ノジマヒキノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県淡路市野島轟木', '28', '28226', '6561722', '兵庫県', 'ヒョウゴケン', '淡路市', 'アワジシ', '野島轟木', 'ノジマトドロキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県淡路市野島大川', '28', '28226', '6561723', '兵庫県', 'ヒョウゴケン', '淡路市', 'アワジシ', '野島大川', 'ノジマオオカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県淡路市野島平林', '28', '28226', '6561724', '兵庫県', 'ヒョウゴケン', '淡路市', 'アワジシ', '野島平林', 'ノジマヒラバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県淡路市野島江崎', '28', '28226', '6561725', '兵庫県', 'ヒョウゴケン', '淡路市', 'アワジシ', '野島江崎', 'ノジマエザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県淡路市野島常盤', '28', '28226', '6561726', '兵庫県', 'ヒョウゴケン', '淡路市', 'アワジシ', '野島常盤', 'ノジマトキワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県淡路市野島貴船', '28', '28226', '6561727', '兵庫県', 'ヒョウゴケン', '淡路市', 'アワジシ', '野島貴船', 'ノジマキフネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県淡路市仁井', '28', '28226', '6561731', '兵庫県', 'ヒョウゴケン', '淡路市', 'アワジシ', '仁井', 'ニイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県淡路市小田', '28', '28226', '6561732', '兵庫県', 'ヒョウゴケン', '淡路市', 'アワジシ', '小田', 'オダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県淡路市長畠', '28', '28226', '6561733', '兵庫県', 'ヒョウゴケン', '淡路市', 'アワジシ', '長畠', 'ナガバタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県淡路市舟木', '28', '28226', '6561734', '兵庫県', 'ヒョウゴケン', '淡路市', 'アワジシ', '舟木', 'フナキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県淡路市久野々', '28', '28226', '6561735', '兵庫県', 'ヒョウゴケン', '淡路市', 'アワジシ', '久野々', 'クノノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県淡路市小倉', '28', '28226', '6561736', '兵庫県', 'ヒョウゴケン', '淡路市', 'アワジシ', '小倉', 'オグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県淡路市浅野南', '28', '28226', '6561741', '兵庫県', 'ヒョウゴケン', '淡路市', 'アワジシ', '浅野南', 'アサノミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県淡路市浅野神田', '28', '28226', '6561742', '兵庫県', 'ヒョウゴケン', '淡路市', 'アワジシ', '浅野神田', 'アサノカンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県淡路市斗ノ内', '28', '28226', '6561743', '兵庫県', 'ヒョウゴケン', '淡路市', 'アワジシ', '斗ノ内', 'トノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県淡路市', '28', '28226', '6562100', '兵庫県', 'ヒョウゴケン', '淡路市', 'アワジシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('78238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県洲本市安乎町平安浦', '28', '28205', '6562121', '兵庫県', 'ヒョウゴケン', '洲本市', 'スモトシ', '安乎町平安浦', 'アイガチョウヘイアンウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県洲本市安乎町中田', '28', '28205', '6562122', '兵庫県', 'ヒョウゴケン', '洲本市', 'スモトシ', '安乎町中田', 'アイガチョウナカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県洲本市安乎町古宮', '28', '28205', '6562123', '兵庫県', 'ヒョウゴケン', '洲本市', 'スモトシ', '安乎町古宮', 'アイガチョウフルミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県洲本市安乎町北谷', '28', '28205', '6562124', '兵庫県', 'ヒョウゴケン', '洲本市', 'スモトシ', '安乎町北谷', 'アイガチョウキタダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県洲本市安乎町山田原', '28', '28205', '6562125', '兵庫県', 'ヒョウゴケン', '洲本市', 'スモトシ', '安乎町山田原', 'アイガチョウヤマダハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県洲本市安乎町宮野原', '28', '28205', '6562126', '兵庫県', 'ヒョウゴケン', '洲本市', 'スモトシ', '安乎町宮野原', 'アイガチョウミヤノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県淡路市志筑', '28', '28226', '6562131', '兵庫県', 'ヒョウゴケン', '淡路市', 'アワジシ', '志筑', 'シヅキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県淡路市志筑新島', '28', '28226', '6562132', '兵庫県', 'ヒョウゴケン', '淡路市', 'アワジシ', '志筑新島', 'シヅキニイジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県淡路市塩尾', '28', '28226', '6562141', '兵庫県', 'ヒョウゴケン', '淡路市', 'アワジシ', '塩尾', 'シオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県淡路市塩田新島', '28', '28226', '6562142', '兵庫県', 'ヒョウゴケン', '淡路市', 'アワジシ', '塩田新島', 'シオタニイジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県淡路市里', '28', '28226', '6562143', '兵庫県', 'ヒョウゴケン', '淡路市', 'アワジシ', '里', 'サト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県淡路市下司', '28', '28226', '6562144', '兵庫県', 'ヒョウゴケン', '淡路市', 'アワジシ', '下司', 'クダシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県淡路市大町畑', '28', '28226', '6562151', '兵庫県', 'ヒョウゴケン', '淡路市', 'アワジシ', '大町畑', 'オオマチハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県淡路市木曽上', '28', '28226', '6562152', '兵庫県', 'ヒョウゴケン', '淡路市', 'アワジシ', '木曽上', 'キソカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県淡路市木曽上畑', '28', '28226', '6562153', '兵庫県', 'ヒョウゴケン', '淡路市', 'アワジシ', '木曽上畑', 'キソカミハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県淡路市木曽下', '28', '28226', '6562154', '兵庫県', 'ヒョウゴケン', '淡路市', 'アワジシ', '木曽下', 'キソシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県淡路市大町上', '28', '28226', '6562155', '兵庫県', 'ヒョウゴケン', '淡路市', 'アワジシ', '大町上', 'オオマチカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県淡路市大町下', '28', '28226', '6562156', '兵庫県', 'ヒョウゴケン', '淡路市', 'アワジシ', '大町下', 'オオマチシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県淡路市池ノ内', '28', '28226', '6562161', '兵庫県', 'ヒョウゴケン', '淡路市', 'アワジシ', '池ノ内', 'イケノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県淡路市王子', '28', '28226', '6562162', '兵庫県', 'ヒョウゴケン', '淡路市', 'アワジシ', '王子', 'オウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県淡路市中田', '28', '28226', '6562163', '兵庫県', 'ヒョウゴケン', '淡路市', 'アワジシ', '中田', 'ナカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県淡路市興隆寺', '28', '28226', '6562211', '兵庫県', 'ヒョウゴケン', '淡路市', 'アワジシ', '興隆寺', 'コウリュウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県淡路市佐野', '28', '28226', '6562212', '兵庫県', 'ヒョウゴケン', '淡路市', 'アワジシ', '佐野', 'サノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県淡路市佐野新島', '28', '28226', '6562213', '兵庫県', 'ヒョウゴケン', '淡路市', 'アワジシ', '佐野新島', 'サノニイジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県淡路市長沢', '28', '28226', '6562221', '兵庫県', 'ヒョウゴケン', '淡路市', 'アワジシ', '長沢', 'ナガサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県淡路市野田尾', '28', '28226', '6562222', '兵庫県', 'ヒョウゴケン', '淡路市', 'アワジシ', '野田尾', 'ノタオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県淡路市生穂', '28', '28226', '6562223', '兵庫県', 'ヒョウゴケン', '淡路市', 'アワジシ', '生穂', 'イクホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県淡路市大谷', '28', '28226', '6562224', '兵庫県', 'ヒョウゴケン', '淡路市', 'アワジシ', '大谷', 'オオタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県淡路市生穂新島', '28', '28226', '6562225', '兵庫県', 'ヒョウゴケン', '淡路市', 'アワジシ', '生穂新島', 'イクホニイジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県淡路市楠本', '28', '28226', '6562301', '兵庫県', 'ヒョウゴケン', '淡路市', 'アワジシ', '楠本', 'クスモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県淡路市大磯', '28', '28226', '6562302', '兵庫県', 'ヒョウゴケン', '淡路市', 'アワジシ', '大磯', 'オオイソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県淡路市小磯', '28', '28226', '6562303', '兵庫県', 'ヒョウゴケン', '淡路市', 'アワジシ', '小磯', 'コイソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県淡路市浜', '28', '28226', '6562304', '兵庫県', 'ヒョウゴケン', '淡路市', 'アワジシ', '浜', 'ハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県淡路市浦', '28', '28226', '6562305', '兵庫県', 'ヒョウゴケン', '淡路市', 'アワジシ', '浦', 'ウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県淡路市夢舞台', '28', '28226', '6562306', '兵庫県', 'ヒョウゴケン', '淡路市', 'アワジシ', '夢舞台', 'ユメブタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県淡路市南鵜崎', '28', '28226', '6562307', '兵庫県', 'ヒョウゴケン', '淡路市', 'アワジシ', '南鵜崎', 'ミナミウザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県淡路市久留麻', '28', '28226', '6562311', '兵庫県', 'ヒョウゴケン', '淡路市', 'アワジシ', '久留麻', 'クルマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県淡路市中持', '28', '28226', '6562321', '兵庫県', 'ヒョウゴケン', '淡路市', 'アワジシ', '中持', 'ナカモチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県淡路市白山', '28', '28226', '6562322', '兵庫県', 'ヒョウゴケン', '淡路市', 'アワジシ', '白山', 'シラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県淡路市河内', '28', '28226', '6562323', '兵庫県', 'ヒョウゴケン', '淡路市', 'アワジシ', '河内', 'コウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県淡路市仮屋', '28', '28226', '6562331', '兵庫県', 'ヒョウゴケン', '淡路市', 'アワジシ', '仮屋', 'カリヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県淡路市谷', '28', '28226', '6562332', '兵庫県', 'ヒョウゴケン', '淡路市', 'アワジシ', '谷', 'タニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県淡路市下田', '28', '28226', '6562333', '兵庫県', 'ヒョウゴケン', '淡路市', 'アワジシ', '下田', 'シモダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県淡路市釜口', '28', '28226', '6562334', '兵庫県', 'ヒョウゴケン', '淡路市', 'アワジシ', '釜口', 'カマグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県淡路市岩屋', '28', '28226', '6562401', '兵庫県', 'ヒョウゴケン', '淡路市', 'アワジシ', '岩屋', 'イワヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県淡路市野島江崎', '28', '28226', '6562451', '兵庫県', 'ヒョウゴケン', '淡路市', 'アワジシ', '野島江崎', 'ノジマエザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県洲本市相川組', '28', '28205', '6562531', '兵庫県', 'ヒョウゴケン', '洲本市', 'スモトシ', '相川組', 'アイカワグミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県洲本市中津川組', '28', '28205', '6562532', '兵庫県', 'ヒョウゴケン', '洲本市', 'スモトシ', '中津川組', 'ナカツガワグミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県洲本市畑田組', '28', '28205', '6562533', '兵庫県', 'ヒョウゴケン', '洲本市', 'スモトシ', '畑田組', 'ハタダグミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県洲本市由良', '28', '28205', '6562541', '兵庫県', 'ヒョウゴケン', '洲本市', 'スモトシ', '由良', 'ユラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県洲本市由良町内田', '28', '28205', '6562542', '兵庫県', 'ヒョウゴケン', '洲本市', 'スモトシ', '由良町内田', 'ユラチョウウチダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県洲本市由良町由良', '28', '28205', '6562543', '兵庫県', 'ヒョウゴケン', '洲本市', 'スモトシ', '由良町由良', 'ユラチョウユラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市灘区', '28', '28102', '6570000', '兵庫県', 'ヒョウゴケン', '神戸市灘区', 'コウベシナダク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('78298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市灘区高羽', '28', '28102', '6570001', '兵庫県', 'ヒョウゴケン', '神戸市灘区', 'コウベシナダク', '高羽', 'タカハ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市灘区篠原', '28', '28102', '6570002', '兵庫県', 'ヒョウゴケン', '神戸市灘区', 'コウベシナダク', '篠原', 'シノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市灘区鶴甲', '28', '28102', '6570011', '兵庫県', 'ヒョウゴケン', '神戸市灘区', 'コウベシナダク', '鶴甲', 'ツルカブト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市灘区一王山町', '28', '28102', '6570012', '兵庫県', 'ヒョウゴケン', '神戸市灘区', 'コウベシナダク', '一王山町', 'イチノウサンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市灘区六甲台町', '28', '28102', '6570013', '兵庫県', 'ヒョウゴケン', '神戸市灘区', 'コウベシナダク', '六甲台町', 'ロッコウダイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市灘区大土平町', '28', '28102', '6570014', '兵庫県', 'ヒョウゴケン', '神戸市灘区', 'コウベシナダク', '大土平町', 'オオドガヒラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市灘区篠原伯母野山町', '28', '28102', '6570015', '兵庫県', 'ヒョウゴケン', '神戸市灘区', 'コウベシナダク', '篠原伯母野山町', 'シノハラオバノヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市灘区篠原台', '28', '28102', '6570016', '兵庫県', 'ヒョウゴケン', '神戸市灘区', 'コウベシナダク', '篠原台', 'シノハラダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市灘区大月台', '28', '28102', '6570017', '兵庫県', 'ヒョウゴケン', '神戸市灘区', 'コウベシナダク', '大月台', 'オオツキダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市灘区水車新田', '28', '28102', '6570018', '兵庫県', 'ヒョウゴケン', '神戸市灘区', 'コウベシナダク', '水車新田', 'スイシャシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市灘区桜ケ丘町', '28', '28102', '6570021', '兵庫県', 'ヒョウゴケン', '神戸市灘区', 'コウベシナダク', '桜ケ丘町', 'サクラガオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市灘区土山町', '28', '28102', '6570022', '兵庫県', 'ヒョウゴケン', '神戸市灘区', 'コウベシナダク', '土山町', 'ツチヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市灘区高羽町', '28', '28102', '6570023', '兵庫県', 'ヒョウゴケン', '神戸市灘区', 'コウベシナダク', '高羽町', 'タカハチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市灘区楠丘町', '28', '28102', '6570024', '兵庫県', 'ヒョウゴケン', '神戸市灘区', 'コウベシナダク', '楠丘町', 'クスガオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市灘区高徳町', '28', '28102', '6570025', '兵庫県', 'ヒョウゴケン', '神戸市灘区', 'コウベシナダク', '高徳町', 'コウトクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市灘区弓木町', '28', '28102', '6570026', '兵庫県', 'ヒョウゴケン', '神戸市灘区', 'コウベシナダク', '弓木町', 'ユミノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市灘区永手町', '28', '28102', '6570027', '兵庫県', 'ヒョウゴケン', '神戸市灘区', 'コウベシナダク', '永手町', 'ナガテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市灘区森後町', '28', '28102', '6570028', '兵庫県', 'ヒョウゴケン', '神戸市灘区', 'コウベシナダク', '森後町', 'モリゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市灘区日尾町', '28', '28102', '6570029', '兵庫県', 'ヒョウゴケン', '神戸市灘区', 'コウベシナダク', '日尾町', 'ヒオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市灘区大和町', '28', '28102', '6570031', '兵庫県', 'ヒョウゴケン', '神戸市灘区', 'コウベシナダク', '大和町', 'ヤマトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市灘区中郷町', '28', '28102', '6570032', '兵庫県', 'ヒョウゴケン', '神戸市灘区', 'コウベシナダク', '中郷町', 'ナカゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市灘区徳井町', '28', '28102', '6570033', '兵庫県', 'ヒョウゴケン', '神戸市灘区', 'コウベシナダク', '徳井町', 'トクイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市灘区記田町', '28', '28102', '6570034', '兵庫県', 'ヒョウゴケン', '神戸市灘区', 'コウベシナダク', '記田町', 'キダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市灘区友田町', '28', '28102', '6570035', '兵庫県', 'ヒョウゴケン', '神戸市灘区', 'コウベシナダク', '友田町', 'トモダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市灘区桜口町', '28', '28102', '6570036', '兵庫県', 'ヒョウゴケン', '神戸市灘区', 'コウベシナダク', '桜口町', 'サクラグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市灘区備後町', '28', '28102', '6570037', '兵庫県', 'ヒョウゴケン', '神戸市灘区', 'コウベシナダク', '備後町', 'ビンゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市灘区深田町', '28', '28102', '6570038', '兵庫県', 'ヒョウゴケン', '神戸市灘区', 'コウベシナダク', '深田町', 'フカダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市灘区琵琶町', '28', '28102', '6570041', '兵庫県', 'ヒョウゴケン', '神戸市灘区', 'コウベシナダク', '琵琶町', 'ビワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市灘区烏帽子町', '28', '28102', '6570042', '兵庫県', 'ヒョウゴケン', '神戸市灘区', 'コウベシナダク', '烏帽子町', 'エボシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市灘区大石東町', '28', '28102', '6570043', '兵庫県', 'ヒョウゴケン', '神戸市灘区', 'コウベシナダク', '大石東町', 'オオイシヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市灘区鹿ノ下通', '28', '28102', '6570044', '兵庫県', 'ヒョウゴケン', '神戸市灘区', 'コウベシナダク', '鹿ノ下通', 'シカノシタドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市灘区下河原通', '28', '28102', '6570045', '兵庫県', 'ヒョウゴケン', '神戸市灘区', 'コウベシナダク', '下河原通', 'シモガワラドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市灘区八幡町', '28', '28102', '6570051', '兵庫県', 'ヒョウゴケン', '神戸市灘区', 'コウベシナダク', '八幡町', 'ヤハタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市灘区神前町', '28', '28102', '6570052', '兵庫県', 'ヒョウゴケン', '神戸市灘区', 'コウベシナダク', '神前町', 'カミマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市灘区六甲町', '28', '28102', '6570053', '兵庫県', 'ヒョウゴケン', '神戸市灘区', 'コウベシナダク', '六甲町', 'ロッコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市灘区稗原町', '28', '28102', '6570054', '兵庫県', 'ヒョウゴケン', '神戸市灘区', 'コウベシナダク', '稗原町', 'ヒエハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市灘区上河原通', '28', '28102', '6570055', '兵庫県', 'ヒョウゴケン', '神戸市灘区', 'コウベシナダク', '上河原通', 'カミガワラドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市灘区千旦通', '28', '28102', '6570056', '兵庫県', 'ヒョウゴケン', '神戸市灘区', 'コウベシナダク', '千旦通', 'センタンドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市灘区神ノ木通', '28', '28102', '6570057', '兵庫県', 'ヒョウゴケン', '神戸市灘区', 'コウベシナダク', '神ノ木通', 'カミノキドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市灘区将軍通', '28', '28102', '6570058', '兵庫県', 'ヒョウゴケン', '神戸市灘区', 'コウベシナダク', '将軍通', 'ショウグンドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市灘区篠原南町', '28', '28102', '6570059', '兵庫県', 'ヒョウゴケン', '神戸市灘区', 'コウベシナダク', '篠原南町', 'シノハラミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市灘区赤松町', '28', '28102', '6570061', '兵庫県', 'ヒョウゴケン', '神戸市灘区', 'コウベシナダク', '赤松町', 'アカマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市灘区寺口町', '28', '28102', '6570062', '兵庫県', 'ヒョウゴケン', '神戸市灘区', 'コウベシナダク', '寺口町', 'テラグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市灘区曾和町', '28', '28102', '6570063', '兵庫県', 'ヒョウゴケン', '神戸市灘区', 'コウベシナダク', '曾和町', 'ソワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市灘区山田町', '28', '28102', '6570064', '兵庫県', 'ヒョウゴケン', '神戸市灘区', 'コウベシナダク', '山田町', 'ヤマダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市灘区宮山町', '28', '28102', '6570065', '兵庫県', 'ヒョウゴケン', '神戸市灘区', 'コウベシナダク', '宮山町', 'ミヤヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市灘区篠原中町', '28', '28102', '6570066', '兵庫県', 'ヒョウゴケン', '神戸市灘区', 'コウベシナダク', '篠原中町', 'シノハラナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市灘区篠原本町', '28', '28102', '6570067', '兵庫県', 'ヒョウゴケン', '神戸市灘区', 'コウベシナダク', '篠原本町', 'シノハラホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市灘区篠原北町', '28', '28102', '6570068', '兵庫県', 'ヒョウゴケン', '神戸市灘区', 'コウベシナダク', '篠原北町', 'シノハラキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市灘区六甲山町', '28', '28102', '6570101', '兵庫県', 'ヒョウゴケン', '神戸市灘区', 'コウベシナダク', '六甲山町', 'ロッコウサンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市灘区畑原ノタ山', '28', '28102', '6570102', '兵庫県', 'ヒョウゴケン', '神戸市灘区', 'コウベシナダク', '畑原', 'ハタハラ', null, null, 'ノタ山', 'ノタヤマ');
INSERT INTO `ms_addresses` VALUES ('78349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市灘区上野小屋場', '28', '28102', '6570103', '兵庫県', 'ヒョウゴケン', '神戸市灘区', 'コウベシナダク', '上野', 'ウエノ', null, null, '小屋場', 'コヤバ');
INSERT INTO `ms_addresses` VALUES ('78350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市灘区上野三ノ休原', '28', '28102', '6570103', '兵庫県', 'ヒョウゴケン', '神戸市灘区', 'コウベシナダク', '上野', 'ウエノ', null, null, '三ノ休原', 'サンノキュウハラ');
INSERT INTO `ms_addresses` VALUES ('78351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市灘区摩耶山', '28', '28102', '6570104', '兵庫県', 'ヒョウゴケン', '神戸市灘区', 'コウベシナダク', '摩耶山', 'マヤサン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市灘区摩耶山町', '28', '28102', '6570105', '兵庫県', 'ヒョウゴケン', '神戸市灘区', 'コウベシナダク', '摩耶山町', 'マヤサンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市東灘区本山町森', '28', '28101', '6570111', '兵庫県', 'ヒョウゴケン', '神戸市東灘区', 'コウベシヒガシナダク', '本山町森', 'モトヤマチョウモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市灘区五毛', '28', '28102', '6570801', '兵庫県', 'ヒョウゴケン', '神戸市灘区', 'コウベシナダク', '五毛', 'ゴモウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市灘区原田', '28', '28102', '6570802', '兵庫県', 'ヒョウゴケン', '神戸市灘区', 'コウベシナダク', '原田', 'ハラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市灘区岩屋', '28', '28102', '6570803', '兵庫県', 'ヒョウゴケン', '神戸市灘区', 'コウベシナダク', '岩屋', 'イワヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市灘区城の下通', '28', '28102', '6570804', '兵庫県', 'ヒョウゴケン', '神戸市灘区', 'コウベシナダク', '城の下通', 'シロノシタドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市灘区青谷町', '28', '28102', '6570805', '兵庫県', 'ヒョウゴケン', '神戸市灘区', 'コウベシナダク', '青谷町', 'アオタニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市灘区長峰台', '28', '28102', '6570811', '兵庫県', 'ヒョウゴケン', '神戸市灘区', 'コウベシナダク', '長峰台', 'ナガミネダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市灘区箕岡通', '28', '28102', '6570812', '兵庫県', 'ヒョウゴケン', '神戸市灘区', 'コウベシナダク', '箕岡通', 'ミノオカドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市灘区高尾通', '28', '28102', '6570813', '兵庫県', 'ヒョウゴケン', '神戸市灘区', 'コウベシナダク', '高尾通', 'タカオドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市灘区五毛通', '28', '28102', '6570814', '兵庫県', 'ヒョウゴケン', '神戸市灘区', 'コウベシナダク', '五毛通', 'ゴモウドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市灘区薬師通', '28', '28102', '6570815', '兵庫県', 'ヒョウゴケン', '神戸市灘区', 'コウベシナダク', '薬師通', 'ヤクシドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市灘区国玉通', '28', '28102', '6570816', '兵庫県', 'ヒョウゴケン', '神戸市灘区', 'コウベシナダク', '国玉通', 'クニタマドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市灘区上野通', '28', '28102', '6570817', '兵庫県', 'ヒョウゴケン', '神戸市灘区', 'コウベシナダク', '上野通', 'ウエノドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市灘区赤坂通', '28', '28102', '6570821', '兵庫県', 'ヒョウゴケン', '神戸市灘区', 'コウベシナダク', '赤坂通', 'アカサカドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市灘区畑原通', '28', '28102', '6570822', '兵庫県', 'ヒョウゴケン', '神戸市灘区', 'コウベシナダク', '畑原通', 'ハタハラドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市灘区天城通', '28', '28102', '6570823', '兵庫県', 'ヒョウゴケン', '神戸市灘区', 'コウベシナダク', '天城通', 'アマギドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市灘区福住通', '28', '28102', '6570824', '兵庫県', 'ヒョウゴケン', '神戸市灘区', 'コウベシナダク', '福住通', 'フクズミドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市灘区中原通', '28', '28102', '6570825', '兵庫県', 'ヒョウゴケン', '神戸市灘区', 'コウベシナダク', '中原通', 'ナカハラドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市灘区倉石通', '28', '28102', '6570826', '兵庫県', 'ヒョウゴケン', '神戸市灘区', 'コウベシナダク', '倉石通', 'クライシドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市灘区水道筋', '28', '28102', '6570831', '兵庫県', 'ヒョウゴケン', '神戸市灘区', 'コウベシナダク', '水道筋', 'スイドウスジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市灘区岸地通', '28', '28102', '6570832', '兵庫県', 'ヒョウゴケン', '神戸市灘区', 'コウベシナダク', '岸地通', 'キシチドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市灘区大内通', '28', '28102', '6570833', '兵庫県', 'ヒョウゴケン', '神戸市灘区', 'コウベシナダク', '大内通', 'オオウチドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市灘区泉通', '28', '28102', '6570834', '兵庫県', 'ヒョウゴケン', '神戸市灘区', 'コウベシナダク', '泉通', 'イズミドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市灘区灘北通', '28', '28102', '6570835', '兵庫県', 'ヒョウゴケン', '神戸市灘区', 'コウベシナダク', '灘北通', 'ナダキタドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市灘区城内通', '28', '28102', '6570836', '兵庫県', 'ヒョウゴケン', '神戸市灘区', 'コウベシナダク', '城内通', 'シロノウチドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市灘区原田通', '28', '28102', '6570837', '兵庫県', 'ヒョウゴケン', '神戸市灘区', 'コウベシナダク', '原田通', 'ハラダドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市灘区王子町', '28', '28102', '6570838', '兵庫県', 'ヒョウゴケン', '神戸市灘区', 'コウベシナダク', '王子町', 'オウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市灘区灘南通', '28', '28102', '6570841', '兵庫県', 'ヒョウゴケン', '神戸市灘区', 'コウベシナダク', '灘南通', 'ナダミナミドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市灘区船寺通', '28', '28102', '6570842', '兵庫県', 'ヒョウゴケン', '神戸市灘区', 'コウベシナダク', '船寺通', 'フナデラドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市灘区大石北町', '28', '28102', '6570843', '兵庫県', 'ヒョウゴケン', '神戸市灘区', 'コウベシナダク', '大石北町', 'オオイシキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市灘区都通', '28', '28102', '6570844', '兵庫県', 'ヒョウゴケン', '神戸市灘区', 'コウベシナダク', '都通', 'ミヤコドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市灘区岩屋中町', '28', '28102', '6570845', '兵庫県', 'ヒョウゴケン', '神戸市灘区', 'コウベシナダク', '岩屋中町', 'イワヤナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市灘区岩屋北町', '28', '28102', '6570846', '兵庫県', 'ヒョウゴケン', '神戸市灘区', 'コウベシナダク', '岩屋北町', 'イワヤキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市灘区味泥町', '28', '28102', '6570851', '兵庫県', 'ヒョウゴケン', '神戸市灘区', 'コウベシナダク', '味泥町', 'ミドロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市灘区大石南町', '28', '28102', '6570852', '兵庫県', 'ヒョウゴケン', '神戸市灘区', 'コウベシナダク', '大石南町', 'オオイシミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市灘区灘浜町', '28', '28102', '6570853', '兵庫県', 'ヒョウゴケン', '神戸市灘区', 'コウベシナダク', '灘浜町', 'ナダハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市灘区摩耶埠頭', '28', '28102', '6570854', '兵庫県', 'ヒョウゴケン', '神戸市灘区', 'コウベシナダク', '摩耶埠頭', 'マヤフトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市灘区日出町', '28', '28102', '6570855', '兵庫県', 'ヒョウゴケン', '神戸市灘区', 'コウベシナダク', '日出町', 'ヒノデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市灘区摩耶海岸通', '28', '28102', '6570855', '兵庫県', 'ヒョウゴケン', '神戸市灘区', 'コウベシナダク', '摩耶海岸通', 'マヤカイガンドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市灘区岩屋南町', '28', '28102', '6570856', '兵庫県', 'ヒョウゴケン', '神戸市灘区', 'コウベシナダク', '岩屋南町', 'イワヤミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市灘区新在家北町', '28', '28102', '6570861', '兵庫県', 'ヒョウゴケン', '神戸市灘区', 'コウベシナダク', '新在家北町', 'シンザイケキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市灘区浜田町', '28', '28102', '6570862', '兵庫県', 'ヒョウゴケン', '神戸市灘区', 'コウベシナダク', '浜田町', 'ハマダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市灘区灘浜東町', '28', '28102', '6570863', '兵庫県', 'ヒョウゴケン', '神戸市灘区', 'コウベシナダク', '灘浜東町', 'ナダハマヒガシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市灘区新在家南町', '28', '28102', '6570864', '兵庫県', 'ヒョウゴケン', '神戸市灘区', 'コウベシナダク', '新在家南町', 'シンザイケミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市東灘区', '28', '28101', '6580000', '兵庫県', 'ヒョウゴケン', '神戸市東灘区', 'コウベシヒガシナダク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('78400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市東灘区森北町', '28', '28101', '6580001', '兵庫県', 'ヒョウゴケン', '神戸市東灘区', 'コウベシヒガシナダク', '森北町', 'モリキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市東灘区甲南台', '28', '28101', '6580002', '兵庫県', 'ヒョウゴケン', '神戸市東灘区', 'コウベシヒガシナダク', '甲南台', 'コウナンダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市東灘区本山北町', '28', '28101', '6580003', '兵庫県', 'ヒョウゴケン', '神戸市東灘区', 'コウベシヒガシナダク', '本山北町', 'モトヤマキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市東灘区本山町田辺', '28', '28101', '6580004', '兵庫県', 'ヒョウゴケン', '神戸市東灘区', 'コウベシヒガシナダク', '本山町田辺', 'モトヤマチョウタナベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市東灘区本山町北畑', '28', '28101', '6580005', '兵庫県', 'ヒョウゴケン', '神戸市東灘区', 'コウベシヒガシナダク', '本山町北畑', 'モトヤマチョウキタハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市東灘区森南町', '28', '28101', '6580011', '兵庫県', 'ヒョウゴケン', '神戸市東灘区', 'コウベシヒガシナダク', '森南町', 'モリミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市東灘区本庄町', '28', '28101', '6580012', '兵庫県', 'ヒョウゴケン', '神戸市東灘区', 'コウベシヒガシナダク', '本庄町', 'ホンジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市東灘区深江北町', '28', '28101', '6580013', '兵庫県', 'ヒョウゴケン', '神戸市東灘区', 'コウベシヒガシナダク', '深江北町', 'フカエキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市東灘区北青木', '28', '28101', '6580014', '兵庫県', 'ヒョウゴケン', '神戸市東灘区', 'コウベシヒガシナダク', '北青木', 'キタオウギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市東灘区本山南町', '28', '28101', '6580015', '兵庫県', 'ヒョウゴケン', '神戸市東灘区', 'コウベシヒガシナダク', '本山南町', 'モトヤマミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市東灘区本山中町', '28', '28101', '6580016', '兵庫県', 'ヒョウゴケン', '神戸市東灘区', 'コウベシヒガシナダク', '本山中町', 'モトヤマナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市東灘区深江本町', '28', '28101', '6580021', '兵庫県', 'ヒョウゴケン', '神戸市東灘区', 'コウベシヒガシナダク', '深江本町', 'フカエホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市東灘区深江南町', '28', '28101', '6580022', '兵庫県', 'ヒョウゴケン', '神戸市東灘区', 'コウベシヒガシナダク', '深江南町', 'フカエミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市東灘区深江浜町', '28', '28101', '6580023', '兵庫県', 'ヒョウゴケン', '神戸市東灘区', 'コウベシヒガシナダク', '深江浜町', 'フカエハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市東灘区魚崎浜町', '28', '28101', '6580024', '兵庫県', 'ヒョウゴケン', '神戸市東灘区', 'コウベシヒガシナダク', '魚崎浜町', 'ウオザキハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市東灘区魚崎南町', '28', '28101', '6580025', '兵庫県', 'ヒョウゴケン', '神戸市東灘区', 'コウベシヒガシナダク', '魚崎南町', 'ウオザキミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市東灘区魚崎西町', '28', '28101', '6580026', '兵庫県', 'ヒョウゴケン', '神戸市東灘区', 'コウベシヒガシナダク', '魚崎西町', 'ウオザキニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市東灘区青木', '28', '28101', '6580027', '兵庫県', 'ヒョウゴケン', '神戸市東灘区', 'コウベシヒガシナダク', '青木', 'オウギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市東灘区向洋町東', '28', '28101', '6580031', '兵庫県', 'ヒョウゴケン', '神戸市東灘区', 'コウベシヒガシナダク', '向洋町東', 'コウヨウチョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市東灘区向洋町中', '28', '28101', '6580032', '兵庫県', 'ヒョウゴケン', '神戸市東灘区', 'コウベシヒガシナダク', '向洋町中', 'コウヨウチョウナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市東灘区向洋町西', '28', '28101', '6580033', '兵庫県', 'ヒョウゴケン', '神戸市東灘区', 'コウベシヒガシナダク', '向洋町西', 'コウヨウチョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市東灘区住吉南町', '28', '28101', '6580041', '兵庫県', 'ヒョウゴケン', '神戸市東灘区', 'コウベシヒガシナダク', '住吉南町', 'スミヨシミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市東灘区住吉浜町', '28', '28101', '6580042', '兵庫県', 'ヒョウゴケン', '神戸市東灘区', 'コウベシヒガシナダク', '住吉浜町', 'スミヨシハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市東灘区御影浜町', '28', '28101', '6580043', '兵庫県', 'ヒョウゴケン', '神戸市東灘区', 'コウベシヒガシナダク', '御影浜町', 'ミカゲハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市東灘区御影塚町', '28', '28101', '6580044', '兵庫県', 'ヒョウゴケン', '神戸市東灘区', 'コウベシヒガシナダク', '御影塚町', 'ミカゲツカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市東灘区御影石町', '28', '28101', '6580045', '兵庫県', 'ヒョウゴケン', '神戸市東灘区', 'コウベシヒガシナダク', '御影石町', 'ミカゲイシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市東灘区御影本町', '28', '28101', '6580046', '兵庫県', 'ヒョウゴケン', '神戸市東灘区', 'コウベシヒガシナダク', '御影本町', 'ミカゲホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市東灘区御影', '28', '28101', '6580047', '兵庫県', 'ヒョウゴケン', '神戸市東灘区', 'コウベシヒガシナダク', '御影', 'ミカゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市東灘区御影郡家', '28', '28101', '6580048', '兵庫県', 'ヒョウゴケン', '神戸市東灘区', 'コウベシヒガシナダク', '御影郡家', 'ミカゲグンゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市東灘区住吉本町', '28', '28101', '6580051', '兵庫県', 'ヒョウゴケン', '神戸市東灘区', 'コウベシヒガシナダク', '住吉本町', 'スミヨシホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市東灘区住吉東町', '28', '28101', '6580052', '兵庫県', 'ヒョウゴケン', '神戸市東灘区', 'コウベシヒガシナダク', '住吉東町', 'スミヨシヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市東灘区住吉宮町', '28', '28101', '6580053', '兵庫県', 'ヒョウゴケン', '神戸市東灘区', 'コウベシヒガシナダク', '住吉宮町', 'スミヨシミヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市東灘区御影中町', '28', '28101', '6580054', '兵庫県', 'ヒョウゴケン', '神戸市東灘区', 'コウベシヒガシナダク', '御影中町', 'ミカゲナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市東灘区本山町田中', '28', '28101', '6580061', '兵庫県', 'ヒョウゴケン', '神戸市東灘区', 'コウベシヒガシナダク', '本山町田中', 'モトヤマチョウタナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市東灘区住吉台', '28', '28101', '6580062', '兵庫県', 'ヒョウゴケン', '神戸市東灘区', 'コウベシヒガシナダク', '住吉台', 'スミヨシダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市東灘区住吉山手', '28', '28101', '6580063', '兵庫県', 'ヒョウゴケン', '神戸市東灘区', 'コウベシヒガシナダク', '住吉山手', 'スミヨシヤマテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市東灘区鴨子ケ原', '28', '28101', '6580064', '兵庫県', 'ヒョウゴケン', '神戸市東灘区', 'コウベシヒガシナダク', '鴨子ケ原', 'カモコガハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市東灘区御影山手', '28', '28101', '6580065', '兵庫県', 'ヒョウゴケン', '神戸市東灘区', 'コウベシヒガシナダク', '御影山手', 'ミカゲヤマテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市東灘区渦森台', '28', '28101', '6580066', '兵庫県', 'ヒョウゴケン', '神戸市東灘区', 'コウベシヒガシナダク', '渦森台', 'ウズモリダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市東灘区本山町岡本', '28', '28101', '6580071', '兵庫県', 'ヒョウゴケン', '神戸市東灘区', 'コウベシヒガシナダク', '本山町岡本', 'モトヤマチョウオカモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市東灘区岡本', '28', '28101', '6580072', '兵庫県', 'ヒョウゴケン', '神戸市東灘区', 'コウベシヒガシナダク', '岡本', 'オカモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市東灘区西岡本', '28', '28101', '6580073', '兵庫県', 'ヒョウゴケン', '神戸市東灘区', 'コウベシヒガシナダク', '西岡本', 'ニシオカモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市東灘区田中町', '28', '28101', '6580081', '兵庫県', 'ヒョウゴケン', '神戸市東灘区', 'コウベシヒガシナダク', '田中町', 'タナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市東灘区魚崎北町', '28', '28101', '6580082', '兵庫県', 'ヒョウゴケン', '神戸市東灘区', 'コウベシヒガシナダク', '魚崎北町', 'ウオザキキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市東灘区魚崎中町', '28', '28101', '6580083', '兵庫県', 'ヒョウゴケン', '神戸市東灘区', 'コウベシヒガシナダク', '魚崎中町', 'ウオザキナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市東灘区甲南町', '28', '28101', '6580084', '兵庫県', 'ヒョウゴケン', '神戸市東灘区', 'コウベシヒガシナダク', '甲南町', 'コウナンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県芦屋市', '28', '28206', '6590000', '兵庫県', 'ヒョウゴケン', '芦屋市', 'アシヤシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('78477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県芦屋市剣谷', '28', '28206', '6590001', '兵庫県', 'ヒョウゴケン', '芦屋市', 'アシヤシ', '剣谷', 'ケンタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県芦屋市奥山', '28', '28206', '6590002', '兵庫県', 'ヒョウゴケン', '芦屋市', 'アシヤシ', '奥山', 'オクヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県芦屋市奥池町', '28', '28206', '6590003', '兵庫県', 'ヒョウゴケン', '芦屋市', 'アシヤシ', '奥池町', 'オクイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県芦屋市奥池南町', '28', '28206', '6590004', '兵庫県', 'ヒョウゴケン', '芦屋市', 'アシヤシ', '奥池南町', 'オクイケミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県芦屋市六麓荘町', '28', '28206', '6590011', '兵庫県', 'ヒョウゴケン', '芦屋市', 'アシヤシ', '六麓荘町', 'ロクロクソウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県芦屋市朝日ケ丘町', '28', '28206', '6590012', '兵庫県', 'ヒョウゴケン', '芦屋市', 'アシヤシ', '朝日ケ丘町', 'アサヒガオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県芦屋市岩園町', '28', '28206', '6590013', '兵庫県', 'ヒョウゴケン', '芦屋市', 'アシヤシ', '岩園町', 'イワゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県芦屋市翠ケ丘町', '28', '28206', '6590014', '兵庫県', 'ヒョウゴケン', '芦屋市', 'アシヤシ', '翠ケ丘町', 'ミドリガオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県芦屋市楠町', '28', '28206', '6590015', '兵庫県', 'ヒョウゴケン', '芦屋市', 'アシヤシ', '楠町', 'クスノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県芦屋市親王塚町', '28', '28206', '6590016', '兵庫県', 'ヒョウゴケン', '芦屋市', 'アシヤシ', '親王塚町', 'シンノウヅカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県芦屋市春日町', '28', '28206', '6590021', '兵庫県', 'ヒョウゴケン', '芦屋市', 'アシヤシ', '春日町', 'カスガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県芦屋市打出町', '28', '28206', '6590022', '兵庫県', 'ヒョウゴケン', '芦屋市', 'アシヤシ', '打出町', 'ウチデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県芦屋市大東町', '28', '28206', '6590023', '兵庫県', 'ヒョウゴケン', '芦屋市', 'アシヤシ', '大東町', 'ダイトウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県芦屋市南宮町', '28', '28206', '6590024', '兵庫県', 'ヒョウゴケン', '芦屋市', 'アシヤシ', '南宮町', 'ナングウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県芦屋市浜町', '28', '28206', '6590025', '兵庫県', 'ヒョウゴケン', '芦屋市', 'アシヤシ', '浜町', 'ハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県芦屋市西蔵町', '28', '28206', '6590026', '兵庫県', 'ヒョウゴケン', '芦屋市', 'アシヤシ', '西蔵町', 'ニシクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県芦屋市若宮町', '28', '28206', '6590027', '兵庫県', 'ヒョウゴケン', '芦屋市', 'アシヤシ', '若宮町', 'ワカミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県芦屋市打出小槌町', '28', '28206', '6590028', '兵庫県', 'ヒョウゴケン', '芦屋市', 'アシヤシ', '打出小槌町', 'ウチデコヅチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県芦屋市新浜町', '28', '28206', '6590031', '兵庫県', 'ヒョウゴケン', '芦屋市', 'アシヤシ', '新浜町', 'ニイハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県芦屋市浜風町', '28', '28206', '6590032', '兵庫県', 'ヒョウゴケン', '芦屋市', 'アシヤシ', '浜風町', 'ハマカゼチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県芦屋市高浜町', '28', '28206', '6590033', '兵庫県', 'ヒョウゴケン', '芦屋市', 'アシヤシ', '高浜町', 'タカハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県芦屋市陽光町', '28', '28206', '6590034', '兵庫県', 'ヒョウゴケン', '芦屋市', 'アシヤシ', '陽光町', 'ヨウコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県芦屋市海洋町', '28', '28206', '6590035', '兵庫県', 'ヒョウゴケン', '芦屋市', 'アシヤシ', '海洋町', 'カイヨウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県芦屋市涼風町', '28', '28206', '6590036', '兵庫県', 'ヒョウゴケン', '芦屋市', 'アシヤシ', '涼風町', 'スズカゼチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県芦屋市南浜町', '28', '28206', '6590037', '兵庫県', 'ヒョウゴケン', '芦屋市', 'アシヤシ', '南浜町', 'ミナミハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県芦屋市若葉町', '28', '28206', '6590041', '兵庫県', 'ヒョウゴケン', '芦屋市', 'アシヤシ', '若葉町', 'ワカバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県芦屋市緑町', '28', '28206', '6590042', '兵庫県', 'ヒョウゴケン', '芦屋市', 'アシヤシ', '緑町', 'ミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県芦屋市潮見町', '28', '28206', '6590043', '兵庫県', 'ヒョウゴケン', '芦屋市', 'アシヤシ', '潮見町', 'シオミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県芦屋市呉川町', '28', '28206', '6590051', '兵庫県', 'ヒョウゴケン', '芦屋市', 'アシヤシ', '呉川町', 'クレカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県芦屋市伊勢町', '28', '28206', '6590052', '兵庫県', 'ヒョウゴケン', '芦屋市', 'アシヤシ', '伊勢町', 'イセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県芦屋市松浜町', '28', '28206', '6590053', '兵庫県', 'ヒョウゴケン', '芦屋市', 'アシヤシ', '松浜町', 'マツハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県芦屋市浜芦屋町', '28', '28206', '6590054', '兵庫県', 'ヒョウゴケン', '芦屋市', 'アシヤシ', '浜芦屋町', 'ハマアシヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県芦屋市竹園町', '28', '28206', '6590055', '兵庫県', 'ヒョウゴケン', '芦屋市', 'アシヤシ', '竹園町', 'タケゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県芦屋市上宮川町', '28', '28206', '6590061', '兵庫県', 'ヒョウゴケン', '芦屋市', 'アシヤシ', '上宮川町', 'カミミヤガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県芦屋市宮塚町', '28', '28206', '6590062', '兵庫県', 'ヒョウゴケン', '芦屋市', 'アシヤシ', '宮塚町', 'ミヤヅカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県芦屋市宮川町', '28', '28206', '6590063', '兵庫県', 'ヒョウゴケン', '芦屋市', 'アシヤシ', '宮川町', 'ミヤガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県芦屋市精道町', '28', '28206', '6590064', '兵庫県', 'ヒョウゴケン', '芦屋市', 'アシヤシ', '精道町', 'セイドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県芦屋市公光町', '28', '28206', '6590065', '兵庫県', 'ヒョウゴケン', '芦屋市', 'アシヤシ', '公光町', 'キンミツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県芦屋市大桝町', '28', '28206', '6590066', '兵庫県', 'ヒョウゴケン', '芦屋市', 'アシヤシ', '大桝町', 'オオマスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県芦屋市茶屋之町', '28', '28206', '6590067', '兵庫県', 'ヒョウゴケン', '芦屋市', 'アシヤシ', '茶屋之町', 'チャヤノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県芦屋市業平町', '28', '28206', '6590068', '兵庫県', 'ヒョウゴケン', '芦屋市', 'アシヤシ', '業平町', 'ナリヒラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県芦屋市前田町', '28', '28206', '6590071', '兵庫県', 'ヒョウゴケン', '芦屋市', 'アシヤシ', '前田町', 'マエダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県芦屋市川西町', '28', '28206', '6590072', '兵庫県', 'ヒョウゴケン', '芦屋市', 'アシヤシ', '川西町', 'カワニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県芦屋市平田北町', '28', '28206', '6590073', '兵庫県', 'ヒョウゴケン', '芦屋市', 'アシヤシ', '平田北町', 'ヒラタキタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県芦屋市平田町', '28', '28206', '6590074', '兵庫県', 'ヒョウゴケン', '芦屋市', 'アシヤシ', '平田町', 'ヒラタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県芦屋市津知町', '28', '28206', '6590075', '兵庫県', 'ヒョウゴケン', '芦屋市', 'アシヤシ', '津知町', 'ツチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県芦屋市清水町', '28', '28206', '6590076', '兵庫県', 'ヒョウゴケン', '芦屋市', 'アシヤシ', '清水町', 'シミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県芦屋市城山', '28', '28206', '6590081', '兵庫県', 'ヒョウゴケン', '芦屋市', 'アシヤシ', '城山', 'シロヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県芦屋市山芦屋町', '28', '28206', '6590082', '兵庫県', 'ヒョウゴケン', '芦屋市', 'アシヤシ', '山芦屋町', 'ヤマアシヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県芦屋市西山町', '28', '28206', '6590083', '兵庫県', 'ヒョウゴケン', '芦屋市', 'アシヤシ', '西山町', 'ニシヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県芦屋市月若町', '28', '28206', '6590084', '兵庫県', 'ヒョウゴケン', '芦屋市', 'アシヤシ', '月若町', 'ツキワカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県芦屋市西芦屋町', '28', '28206', '6590085', '兵庫県', 'ヒョウゴケン', '芦屋市', 'アシヤシ', '西芦屋町', 'ニシアシヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県芦屋市三条南町', '28', '28206', '6590086', '兵庫県', 'ヒョウゴケン', '芦屋市', 'アシヤシ', '三条南町', 'サンジョウミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県芦屋市三条町', '28', '28206', '6590087', '兵庫県', 'ヒョウゴケン', '芦屋市', 'アシヤシ', '三条町', 'サンジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県芦屋市東山町', '28', '28206', '6590091', '兵庫県', 'ヒョウゴケン', '芦屋市', 'アシヤシ', '東山町', 'ヒガシヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県芦屋市大原町', '28', '28206', '6590092', '兵庫県', 'ヒョウゴケン', '芦屋市', 'アシヤシ', '大原町', 'オオハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県芦屋市船戸町', '28', '28206', '6590093', '兵庫県', 'ヒョウゴケン', '芦屋市', 'アシヤシ', '船戸町', 'フナドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県芦屋市松ノ内町', '28', '28206', '6590094', '兵庫県', 'ヒョウゴケン', '芦屋市', 'アシヤシ', '松ノ内町', 'マツノウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県芦屋市東芦屋町', '28', '28206', '6590095', '兵庫県', 'ヒョウゴケン', '芦屋市', 'アシヤシ', '東芦屋町', 'ヒガシアシヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県芦屋市山手町', '28', '28206', '6590096', '兵庫県', 'ヒョウゴケン', '芦屋市', 'アシヤシ', '山手町', 'ヤマテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道千歳市', '01', '01224', '0660000', '北海道', 'ホッカイドウ', '千歳市', 'チトセシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('78542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市', '28', '28202', '6600000', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('78543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道千歳市長都', '01', '01224', '0660001', '北海道', 'ホッカイドウ', '千歳市', 'チトセシ', '長都', 'オサツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道千歳市釜加', '01', '01224', '0660002', '北海道', 'ホッカイドウ', '千歳市', 'チトセシ', '釜加', 'カマカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道千歳市都', '01', '01224', '0660003', '北海道', 'ホッカイドウ', '千歳市', 'チトセシ', '都', 'ミヤコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道千歳市泉郷', '01', '01224', '0660004', '北海道', 'ホッカイドウ', '千歳市', 'チトセシ', '泉郷', 'イズミサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道千歳市協和', '01', '01224', '0660005', '北海道', 'ホッカイドウ', '千歳市', 'チトセシ', '協和', 'キョウワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市東七松町', '28', '28202', '6600051', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '東七松町', 'ヒガシナナマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市七松町', '28', '28202', '6600052', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '七松町', 'ナナマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市南七松町', '28', '28202', '6600053', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '南七松町', 'ミナミナナマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市西立花町', '28', '28202', '6600054', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '西立花町', 'ニシタチバナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市稲葉元町', '28', '28202', '6600055', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '稲葉元町', 'イナバモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道千歳市祝梅', '01', '01224', '0660006', '北海道', 'ホッカイドウ', '千歳市', 'チトセシ', '祝梅', 'シュクバイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市蓬川荘園', '28', '28202', '6600061', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '蓬川荘園', 'ヨモガワソウエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市浜田町', '28', '28202', '6600062', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '浜田町', 'ハマダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市大庄北', '28', '28202', '6600063', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '大庄北', 'オオショウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市稲葉荘', '28', '28202', '6600064', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '稲葉荘', 'イナバソウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道千歳市中央', '01', '01224', '0660007', '北海道', 'ホッカイドウ', '千歳市', 'チトセシ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市崇徳院', '28', '28202', '6600071', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '崇徳院', 'ストクイン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市大庄川田町', '28', '28202', '6600072', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '大庄川田町', 'オオショウカワタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市菜切山町', '28', '28202', '6600073', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '菜切山町', 'ナキリヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市琴浦町', '28', '28202', '6600074', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '琴浦町', 'コトウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市大庄中通', '28', '28202', '6600075', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '大庄中通', 'オオショウナカドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市大島', '28', '28202', '6600076', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '大島', 'オオシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市大庄西町', '28', '28202', '6600077', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '大庄西町', 'オオショウニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道千歳市根志越', '01', '01224', '0660008', '北海道', 'ホッカイドウ', '千歳市', 'チトセシ', '根志越', 'ネシコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市蓬川町', '28', '28202', '6600081', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '蓬川町', 'ヨモガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市水明町', '28', '28202', '6600082', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '水明町', 'スイメイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市道意町', '28', '28202', '6600083', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '道意町', 'ドイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市武庫川町', '28', '28202', '6600084', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '武庫川町', 'ムコガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市元浜町', '28', '28202', '6600085', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '元浜町', 'モトハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市丸島町', '28', '28202', '6600086', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '丸島町', 'マルシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市平左衛門町', '28', '28202', '6600087', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '平左衛門町', 'ヘイザエモンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道千歳市柏台南', '01', '01224', '0660009', '北海道', 'ホッカイドウ', '千歳市', 'チトセシ', '柏台南', 'カシワダイミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市中浜町', '28', '28202', '6600091', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '中浜町', 'ナカハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市鶴町', '28', '28202', '6600092', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '鶴町', 'ツルマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市西海岸町', '28', '28202', '6600093', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '西海岸町', 'ニシカイガンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市末広町', '28', '28202', '6600094', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '末広町', 'スエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市大浜町', '28', '28202', '6600095', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '大浜町', 'オオハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市扇町', '28', '28202', '6600096', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '扇町', 'オウギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道千歳市駒里', '01', '01224', '0660011', '北海道', 'ホッカイドウ', '千歳市', 'チトセシ', '駒里', 'コマサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道千歳市美々', '01', '01224', '0660012', '北海道', 'ホッカイドウ', '千歳市', 'チトセシ', '美々', 'ビビ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道千歳市柏台', '01', '01224', '0660013', '北海道', 'ホッカイドウ', '千歳市', 'チトセシ', '柏台', 'カシワダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道千歳市青葉丘', '01', '01224', '0660014', '北海道', 'ホッカイドウ', '千歳市', 'チトセシ', '青葉丘', 'アオバオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道千歳市青葉', '01', '01224', '0660015', '北海道', 'ホッカイドウ', '千歳市', 'チトセシ', '青葉', 'アオバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道千歳市日の出丘', '01', '01224', '0660016', '北海道', 'ホッカイドウ', '千歳市', 'チトセシ', '日の出丘', 'ヒノデオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道千歳市日の出', '01', '01224', '0660017', '北海道', 'ホッカイドウ', '千歳市', 'チトセシ', '日の出', 'ヒノデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道千歳市旭ケ丘', '01', '01224', '0660018', '北海道', 'ホッカイドウ', '千歳市', 'チトセシ', '旭ケ丘', 'アサヒガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道千歳市流通', '01', '01224', '0660019', '北海道', 'ホッカイドウ', '千歳市', 'チトセシ', '流通', 'リュウツウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道千歳市東郊', '01', '01224', '0660021', '北海道', 'ホッカイドウ', '千歳市', 'チトセシ', '東郊', 'トウコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道千歳市豊里', '01', '01224', '0660022', '北海道', 'ホッカイドウ', '千歳市', 'チトセシ', '豊里', 'トヨサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道千歳市寿', '01', '01224', '0660023', '北海道', 'ホッカイドウ', '千歳市', 'チトセシ', '寿', 'コトブキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道千歳市弥生', '01', '01224', '0660024', '北海道', 'ホッカイドウ', '千歳市', 'チトセシ', '弥生', 'ヤヨイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道千歳市梅ケ丘', '01', '01224', '0660025', '北海道', 'ホッカイドウ', '千歳市', 'チトセシ', '梅ケ丘', 'ウメガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道千歳市住吉', '01', '01224', '0660026', '北海道', 'ホッカイドウ', '千歳市', 'チトセシ', '住吉', 'スミヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道千歳市末広', '01', '01224', '0660027', '北海道', 'ホッカイドウ', '千歳市', 'チトセシ', '末広', 'スエヒロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道千歳市花園', '01', '01224', '0660028', '北海道', 'ホッカイドウ', '千歳市', 'チトセシ', '花園', 'ハナゾノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道千歳市稲穂', '01', '01224', '0660029', '北海道', 'ホッカイドウ', '千歳市', 'チトセシ', '稲穂', 'イナホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道千歳市長都駅前', '01', '01224', '0660031', '北海道', 'ホッカイドウ', '千歳市', 'チトセシ', '長都駅前', 'オサツエキマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道千歳市北陽', '01', '01224', '0660032', '北海道', 'ホッカイドウ', '千歳市', 'チトセシ', '北陽', 'ホクヨウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道千歳市北光', '01', '01224', '0660033', '北海道', 'ホッカイドウ', '千歳市', 'チトセシ', '北光', 'ホッコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道千歳市富丘', '01', '01224', '0660034', '北海道', 'ホッカイドウ', '千歳市', 'チトセシ', '富丘', 'トミオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道千歳市高台', '01', '01224', '0660035', '北海道', 'ホッカイドウ', '千歳市', 'チトセシ', '高台', 'タカダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道千歳市北栄', '01', '01224', '0660036', '北海道', 'ホッカイドウ', '千歳市', 'チトセシ', '北栄', 'ホクエイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道千歳市新富', '01', '01224', '0660037', '北海道', 'ホッカイドウ', '千歳市', 'チトセシ', '新富', 'シントミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道千歳市信濃', '01', '01224', '0660038', '北海道', 'ホッカイドウ', '千歳市', 'チトセシ', '信濃', 'シナノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道千歳市富士', '01', '01224', '0660039', '北海道', 'ホッカイドウ', '千歳市', 'チトセシ', '富士', 'フジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道千歳市清水町', '01', '01224', '0660041', '北海道', 'ホッカイドウ', '千歳市', 'チトセシ', '清水町', 'シミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道千歳市東雲町', '01', '01224', '0660042', '北海道', 'ホッカイドウ', '千歳市', 'チトセシ', '東雲町', 'シノノメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道千歳市朝日町', '01', '01224', '0660043', '北海道', 'ホッカイドウ', '千歳市', 'チトセシ', '朝日町', 'アサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道千歳市平和', '01', '01224', '0660044', '北海道', 'ホッカイドウ', '千歳市', 'チトセシ', '平和', 'ヘイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道千歳市真々地', '01', '01224', '0660045', '北海道', 'ホッカイドウ', '千歳市', 'チトセシ', '真々地', 'ママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道千歳市真町', '01', '01224', '0660046', '北海道', 'ホッカイドウ', '千歳市', 'チトセシ', '真町', 'シンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道千歳市本町', '01', '01224', '0660047', '北海道', 'ホッカイドウ', '千歳市', 'チトセシ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道千歳市泉沢', '01', '01224', '0660051', '北海道', 'ホッカイドウ', '千歳市', 'チトセシ', '泉沢', 'イズミサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道千歳市文京', '01', '01224', '0660052', '北海道', 'ホッカイドウ', '千歳市', 'チトセシ', '文京', 'ブンキョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道千歳市福住', '01', '01224', '0660053', '北海道', 'ホッカイドウ', '千歳市', 'チトセシ', '福住', 'フクズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道千歳市柏陽', '01', '01224', '0660054', '北海道', 'ホッカイドウ', '千歳市', 'チトセシ', '柏陽', 'ハクヨウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道千歳市里美', '01', '01224', '0660055', '北海道', 'ホッカイドウ', '千歳市', 'チトセシ', '里美', 'サトミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道千歳市白樺', '01', '01224', '0660056', '北海道', 'ホッカイドウ', '千歳市', 'チトセシ', '白樺', 'シラカバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道千歳市若草', '01', '01224', '0660057', '北海道', 'ホッカイドウ', '千歳市', 'チトセシ', '若草', 'ワカクサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道千歳市栄町', '01', '01224', '0660061', '北海道', 'ホッカイドウ', '千歳市', 'チトセシ', '栄町', 'サカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道千歳市千代田町', '01', '01224', '0660062', '北海道', 'ホッカイドウ', '千歳市', 'チトセシ', '千代田町', 'チヨダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道千歳市幸町', '01', '01224', '0660063', '北海道', 'ホッカイドウ', '千歳市', 'チトセシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道千歳市錦町', '01', '01224', '0660064', '北海道', 'ホッカイドウ', '千歳市', 'チトセシ', '錦町', 'ニシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道千歳市春日町', '01', '01224', '0660065', '北海道', 'ホッカイドウ', '千歳市', 'チトセシ', '春日町', 'カスガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道千歳市大和', '01', '01224', '0660066', '北海道', 'ホッカイドウ', '千歳市', 'チトセシ', '大和', 'ヤマト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道千歳市桂木', '01', '01224', '0660067', '北海道', 'ホッカイドウ', '千歳市', 'チトセシ', '桂木', 'カツラギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道千歳市蘭越', '01', '01224', '0660068', '北海道', 'ホッカイドウ', '千歳市', 'チトセシ', '蘭越', 'ランコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道千歳市新星', '01', '01224', '0660069', '北海道', 'ホッカイドウ', '千歳市', 'チトセシ', '新星', 'シンセイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道千歳市桜木', '01', '01224', '0660071', '北海道', 'ホッカイドウ', '千歳市', 'チトセシ', '桜木', 'サクラギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道千歳市自由ケ丘', '01', '01224', '0660072', '北海道', 'ホッカイドウ', '千歳市', 'チトセシ', '自由ケ丘', 'ジユウガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道千歳市北斗', '01', '01224', '0660073', '北海道', 'ホッカイドウ', '千歳市', 'チトセシ', '北斗', 'ホクト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道千歳市緑町', '01', '01224', '0660074', '北海道', 'ホッカイドウ', '千歳市', 'チトセシ', '緑町', 'ミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道千歳市北信濃', '01', '01224', '0660075', '北海道', 'ホッカイドウ', '千歳市', 'チトセシ', '北信濃', 'キタシナノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道千歳市あずさ', '01', '01224', '0660076', '北海道', 'ホッカイドウ', '千歳市', 'チトセシ', 'あずさ', 'アズサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道千歳市上長都', '01', '01224', '0660077', '北海道', 'ホッカイドウ', '千歳市', 'チトセシ', '上長都', 'カミオサツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道千歳市勇舞', '01', '01224', '0660078', '北海道', 'ホッカイドウ', '千歳市', 'チトセシ', '勇舞', 'ユウマイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市長洲東通', '28', '28202', '6600801', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '長洲東通', 'ナガスヒガシドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市長洲中通', '28', '28202', '6600802', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '長洲中通', 'ナガスナカドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市長洲本通', '28', '28202', '6600803', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '長洲本通', 'ナガスホンドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市北大物町', '28', '28202', '6600804', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '北大物町', 'キタダイモツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市西長洲町', '28', '28202', '6600805', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '西長洲町', 'ニシナガスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市金楽寺町', '28', '28202', '6600806', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '金楽寺町', 'キンラクジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市長洲西通', '28', '28202', '6600807', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '長洲西通', 'ナガスニシドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市潮江1丁目1番', '28', '28202', '6600808', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '潮江', 'シオエ', null, null, '1丁目1番', '01チョウメ1バン');
INSERT INTO `ms_addresses` VALUES ('78647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市潮江5丁目1番', '28', '28202', '6600808', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '潮江', 'シオエ', null, null, '5丁目1番', '05チョウメ1バン');
INSERT INTO `ms_addresses` VALUES ('78648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道千歳市清流', '01', '01224', '0660081', '北海道', 'ホッカイドウ', '千歳市', 'チトセシ', '清流', 'セイリュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市常光寺', '28', '28202', '6600811', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '常光寺', 'ジョウコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市今福', '28', '28202', '6600812', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '今福', 'イマフク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市杭瀬寺島', '28', '28202', '6600813', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '杭瀬寺島', 'クイセテラジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市杭瀬本町', '28', '28202', '6600814', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '杭瀬本町', 'クイセホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市杭瀬北新町', '28', '28202', '6600815', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '杭瀬北新町', 'クイセキタシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道千歳市幸福', '01', '01224', '0660082', '北海道', 'ホッカイドウ', '千歳市', 'チトセシ', '幸福', 'コウフク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市梶ケ島', '28', '28202', '6600821', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '梶ケ島', 'カジガシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市杭瀬南新町', '28', '28202', '6600822', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '杭瀬南新町', 'クイセミナミシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市大物町', '28', '28202', '6600823', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '大物町', 'ダイモツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市東本町', '28', '28202', '6600824', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '東本町', 'ヒガシホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市南城内', '28', '28202', '6600825', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '南城内', 'ミナミジョウナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市北城内', '28', '28202', '6600826', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '北城内', 'キタジョウナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市西大物町', '28', '28202', '6600827', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '西大物町', 'ニシダイモツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市東大物町', '28', '28202', '6600828', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '東大物町', 'ヒガシダイモツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市東松島町', '28', '28202', '6600831', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '東松島町', 'ヒガシマツシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市東初島町', '28', '28202', '6600832', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '東初島町', 'ヒガシハツシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市南初島町', '28', '28202', '6600833', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '南初島町', 'ミナミハツシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市北初島町', '28', '28202', '6600834', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '北初島町', 'キタハツシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市東向島東之町', '28', '28202', '6600835', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '東向島東之町', 'ヒガシムコウジマヒガシノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市西松島町', '28', '28202', '6600837', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '西松島町', 'ニシマツシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市東高洲町', '28', '28202', '6600841', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '東高洲町', 'ヒガシタカスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市大高洲町', '28', '28202', '6600842', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '大高洲町', 'オオタカスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市東海岸町', '28', '28202', '6600843', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '東海岸町', 'ヒガシカイガンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市東浜町', '28', '28202', '6600844', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '東浜町', 'ヒガシハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市西高洲町', '28', '28202', '6600845', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '西高洲町', 'ニシタカスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市中在家町', '28', '28202', '6600851', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '中在家町', 'ナカザイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市東向島西之町', '28', '28202', '6600856', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '東向島西之町', 'ヒガシムコウジマニシノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市西向島町', '28', '28202', '6600857', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '西向島町', 'ニシムコウジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市築地', '28', '28202', '6600858', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '築地', 'ツキジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市御園町', '28', '28202', '6600861', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '御園町', 'ミソノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市開明町', '28', '28202', '6600862', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '開明町', 'カイメイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市西本町北通', '28', '28202', '6600863', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '西本町北通', 'ニシホンマチキタドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市東桜木町', '28', '28202', '6600864', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '東桜木町', 'ヒガシサクラギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市西桜木町', '28', '28202', '6600865', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '西桜木町', 'ニシサクラギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市汐町', '28', '28202', '6600866', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '汐町', 'シオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市寺町', '28', '28202', '6600867', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '寺町', 'テラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市西御園町', '28', '28202', '6600868', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '西御園町', 'ニシミソノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市建家町', '28', '28202', '6600871', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '建家町', 'タテヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市玄番北之町', '28', '28202', '6600872', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '玄番北之町', 'ゲンバンキタノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市玄番南之町', '28', '28202', '6600873', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '玄番南之町', 'ゲンバンミナミノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市西本町', '28', '28202', '6600874', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '西本町', 'ニシホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市南竹谷町', '28', '28202', '6600875', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '南竹谷町', 'ミナミタケヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市竹谷町', '28', '28202', '6600876', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '竹谷町', 'タケヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市宮内町', '28', '28202', '6600877', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '宮内町', 'ミヤウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市北竹谷町', '28', '28202', '6600878', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '北竹谷町', 'キタタケヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市昭和通', '28', '28202', '6600881', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '昭和通', 'ショウワドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市昭和南通', '28', '28202', '6600882', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '昭和南通', 'ショウワミナミドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市神田北通', '28', '28202', '6600883', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '神田北通', 'カンダキタドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市神田中通', '28', '28202', '6600884', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '神田中通', 'カンダナカドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市神田南通', '28', '28202', '6600885', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '神田南通', 'カンダミナミドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市扶桑町', '28', '28202', '6600891', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '扶桑町', 'フソウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市東難波町', '28', '28202', '6600892', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '東難波町', 'ヒガシナニワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市西難波町', '28', '28202', '6600893', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '西難波町', 'ニシナニワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫小牧市丸山', '01', '01213', '0660271', '北海道', 'ホッカイドウ', '苫小牧市', 'トマコマイシ', '丸山', 'マルヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道千歳市支笏湖温泉', '01', '01224', '0660281', '北海道', 'ホッカイドウ', '千歳市', 'チトセシ', '支笏湖温泉', 'シコツコオンセン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道千歳市水明郷', '01', '01224', '0660282', '北海道', 'ホッカイドウ', '千歳市', 'チトセシ', '水明郷', 'スイメイキョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道千歳市モラップ', '01', '01224', '0660283', '北海道', 'ホッカイドウ', '千歳市', 'チトセシ', 'モラップ', 'モラップ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道千歳市支寒内', '01', '01224', '0660284', '北海道', 'ホッカイドウ', '千歳市', 'チトセシ', '支寒内', 'シシャモナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道千歳市美笛', '01', '01224', '0660285', '北海道', 'ホッカイドウ', '千歳市', 'チトセシ', '美笛', 'ビフエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道千歳市奥潭', '01', '01224', '0660286', '北海道', 'ホッカイドウ', '千歳市', 'チトセシ', '奥潭', 'オコタン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道千歳市幌美内', '01', '01224', '0660287', '北海道', 'ホッカイドウ', '千歳市', 'チトセシ', '幌美内', 'ポロピナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市塚口本町', '28', '28202', '6610001', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '塚口本町', 'ツカグチホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市塚口町', '28', '28202', '6610002', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '塚口町', 'ツカグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市富松町', '28', '28202', '6610003', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '富松町', 'トマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市東塚口町', '28', '28202', '6610011', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '東塚口町', 'ヒガシツカグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市南塚口町', '28', '28202', '6610012', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '南塚口町', 'ミナミツカグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市栗山町', '28', '28202', '6610013', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '栗山町', 'クリヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市上ノ島町', '28', '28202', '6610014', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '上ノ島町', 'カミノシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市名神町', '28', '28202', '6610021', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '名神町', 'メイシンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市尾浜町', '28', '28202', '6610022', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '尾浜町', 'オハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市大西町', '28', '28202', '6610023', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '大西町', 'オオニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市三反田町', '28', '28202', '6610024', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '三反田町', 'サンタンダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市立花町', '28', '28202', '6610025', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '立花町', 'タチバナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市水堂町', '28', '28202', '6610026', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '水堂町', 'ミズドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市武庫之荘本町', '28', '28202', '6610031', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '武庫之荘本町', 'ムコノソウホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市武庫之荘東', '28', '28202', '6610032', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '武庫之荘東', 'ムコノソウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市南武庫之荘', '28', '28202', '6610033', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '南武庫之荘', 'ミナミムコノソウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市武庫之荘西', '28', '28202', '6610034', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '武庫之荘西', 'ムコノソウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市武庫之荘', '28', '28202', '6610035', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '武庫之荘', 'ムコノソウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市武庫の里', '28', '28202', '6610041', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '武庫の里', 'ムコノサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市常吉', '28', '28202', '6610042', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '常吉', 'ツネヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市武庫元町', '28', '28202', '6610043', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '武庫元町', 'ムコモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市武庫町', '28', '28202', '6610044', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '武庫町', 'ムコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市武庫豊町', '28', '28202', '6610045', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '武庫豊町', 'ムコユタカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市常松', '28', '28202', '6610046', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '常松', 'ツネマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市西昆陽', '28', '28202', '6610047', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '西昆陽', 'ニシコヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市田能', '28', '28202', '6610951', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '田能', 'タノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市椎堂', '28', '28202', '6610952', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '椎堂', 'シドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市東園田町', '28', '28202', '6610953', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '東園田町', 'ヒガシソノダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市戸ノ内町', '28', '28202', '6610961', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '戸ノ内町', 'トノウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市額田町', '28', '28202', '6610962', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '額田町', 'ヌカタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市高田町', '28', '28202', '6610963', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '高田町', 'タカタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市神崎町', '28', '28202', '6610964', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '神崎町', 'カンザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市次屋', '28', '28202', '6610965', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '次屋', 'ツギヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市西川', '28', '28202', '6610966', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '西川', 'ニシカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市浜', '28', '28202', '6610967', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '浜', 'ハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市弥生ケ丘町', '28', '28202', '6610970', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '弥生ケ丘町', 'ヤヨイガオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市瓦宮', '28', '28202', '6610971', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '瓦宮', 'カワラノミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市小中島', '28', '28202', '6610972', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '小中島', 'コナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市善法寺町', '28', '28202', '6610973', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '善法寺町', 'ゼンポウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市若王寺', '28', '28202', '6610974', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '若王寺', 'ナコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市下坂部', '28', '28202', '6610975', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '下坂部', 'シモサカベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市潮江', '28', '28202', '6610976', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '潮江', 'シオエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市久々知', '28', '28202', '6610977', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '久々知', 'ククチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市久々知西町', '28', '28202', '6610978', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '久々知西町', 'ククチニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市上坂部', '28', '28202', '6610979', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '上坂部', 'カミサカベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市猪名寺', '28', '28202', '6610981', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '猪名寺', 'イナデラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市食満', '28', '28202', '6610982', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '食満', 'ケマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市口田中', '28', '28202', '6610983', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '口田中', 'クチタナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市御園', '28', '28202', '6610984', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '御園', 'ミソノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県尼崎市南清水', '28', '28202', '6610985', '兵庫県', 'ヒョウゴケン', '尼崎市', 'アマガサキシ', '南清水', 'ミナミシミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市', '28', '28204', '6620000', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('78782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市甲山町', '28', '28204', '6620001', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '甲山町', 'カブトヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市鷲林寺南町', '28', '28204', '6620002', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '鷲林寺南町', 'ジュウリンジミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市鷲林寺町', '28', '28204', '6620003', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '鷲林寺町', 'ジュウリンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市鷲林寺', '28', '28204', '6620004', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '鷲林寺', 'ジュウリンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市湯元町', '28', '28204', '6620005', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '湯元町', 'ユノモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市越水社家郷山', '28', '28204', '6620006', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '越水社家郷山', 'コシミズシャケゴウヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市甲陽園目神山町', '28', '28204', '6620011', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '甲陽園目神山町', 'コウヨウエンメガミヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市甲陽園東山町', '28', '28204', '6620012', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '甲陽園東山町', 'コウヨウエンヒガシヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市新甲陽町', '28', '28204', '6620013', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '新甲陽町', 'シンコウヨウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市甲陽園日之出町', '28', '28204', '6620014', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '甲陽園日之出町', 'コウヨウエンヒノデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市甲陽園本庄町', '28', '28204', '6620015', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '甲陽園本庄町', 'コウヨウエンホンジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市甲陽園若江町', '28', '28204', '6620016', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '甲陽園若江町', 'コウヨウエンワカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市甲陽園西山町', '28', '28204', '6620017', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '甲陽園西山町', 'コウヨウエンニシヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市甲陽園山王町', '28', '28204', '6620018', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '甲陽園山王町', 'コウヨウエンサンノウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市神原', '28', '28204', '6620021', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '神原', 'カンバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市奥畑', '28', '28204', '6620022', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '奥畑', 'オクハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市城山', '28', '28204', '6620023', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '城山', 'シロヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市名次町', '28', '28204', '6620024', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '名次町', 'ナツギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市北名次町', '28', '28204', '6620025', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '北名次町', 'キタナツギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市獅子ケ口町', '28', '28204', '6620026', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '獅子ケ口町', 'シシガグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市神園町', '28', '28204', '6620027', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '神園町', 'カミゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市満池谷町', '28', '28204', '6620031', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '満池谷町', 'マンチダニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市桜谷町', '28', '28204', '6620032', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '桜谷町', 'サクラダニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市清水町', '28', '28204', '6620033', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '清水町', 'シミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市西田町', '28', '28204', '6620034', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '西田町', 'ニシダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市若松町', '28', '28204', '6620035', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '若松町', 'ワカマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市大井手町', '28', '28204', '6620036', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '大井手町', 'オオイデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市結善町', '28', '28204', '6620037', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '結善町', 'ケツゼンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市南郷町', '28', '28204', '6620038', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '南郷町', 'ナンゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市末広町', '28', '28204', '6620041', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '末広町', 'スエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市分銅町', '28', '28204', '6620042', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '分銅町', 'ブンドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市常磐町', '28', '28204', '6620043', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '常磐町', 'トキワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市平松町', '28', '28204', '6620044', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '平松町', 'ヒラマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市安井町', '28', '28204', '6620045', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '安井町', 'ヤスイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市千歳町', '28', '28204', '6620046', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '千歳町', 'チトセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市寿町', '28', '28204', '6620047', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '寿町', 'コトブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市羽衣町', '28', '28204', '6620051', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '羽衣町', 'ハゴロモチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市霞町', '28', '28204', '6620052', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '霞町', 'カスミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市松園町', '28', '28204', '6620053', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '松園町', 'マツゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市大谷町', '28', '28204', '6620054', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '大谷町', 'オオタニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市松ケ丘町', '28', '28204', '6620061', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '松ケ丘町', 'マツガオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市木津山町', '28', '28204', '6620062', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '木津山町', 'キズヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市相生町', '28', '28204', '6620063', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '相生町', 'アイオイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市雲井町', '28', '28204', '6620064', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '雲井町', 'クモイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市殿山町', '28', '28204', '6620065', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '殿山町', 'トノヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市高塚町', '28', '28204', '6620066', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '高塚町', 'タカツカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市深谷町', '28', '28204', '6620067', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '深谷町', 'フカタニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市桜町', '28', '28204', '6620071', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '桜町', 'サクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市豊楽町', '28', '28204', '6620072', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '豊楽町', 'ホウラクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市松風町', '28', '28204', '6620073', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '松風町', 'マツカゼチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市石刎町', '28', '28204', '6620074', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '石刎町', 'イシバネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市南越木岩町', '28', '28204', '6620075', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '南越木岩町', 'ミナミコシキイワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市松生町', '28', '28204', '6620076', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '松生町', 'マツオイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市久出ケ谷町', '28', '28204', '6620077', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '久出ケ谷町', 'クデガヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市菊谷町', '28', '28204', '6620078', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '菊谷町', 'キクタニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市苦楽園三番町', '28', '28204', '6620081', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '苦楽園三番町', 'クラクエン03バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市苦楽園二番町', '28', '28204', '6620082', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '苦楽園二番町', 'クラクエン02バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市苦楽園一番町', '28', '28204', '6620083', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '苦楽園一番町', 'クラクエン01バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市樋之池町', '28', '28204', '6620084', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '樋之池町', 'ヒノイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市老松町', '28', '28204', '6620085', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '老松町', 'オイマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市苦楽園六番町', '28', '28204', '6620086', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '苦楽園六番町', 'クラクエン06バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市苦楽園五番町', '28', '28204', '6620087', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '苦楽園五番町', 'クラクエン05バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市苦楽園四番町', '28', '28204', '6620088', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '苦楽園四番町', 'クラクエン04バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市北山町', '28', '28204', '6620091', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '北山町', 'キタヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市甑岩町', '28', '28204', '6620092', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '甑岩町', 'コシキイワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市西平町', '28', '28204', '6620093', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '西平町', 'ニシヒラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市毘沙門町', '28', '28204', '6620094', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '毘沙門町', 'ビシャモンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市美作町', '28', '28204', '6620095', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '美作町', 'ミサクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市角石町', '28', '28204', '6620096', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '角石町', 'スミイシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市柏堂町', '28', '28204', '6620097', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '柏堂町', 'カヤンドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市柏堂西町', '28', '28204', '6620098', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '柏堂西町', 'カヤンドウニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市剣谷町', '28', '28204', '6620099', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '剣谷町', 'ケンダニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市仁川町', '28', '28204', '6620811', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '仁川町', 'ニガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市甲東園', '28', '28204', '6620812', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '甲東園', 'コウトウエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市上甲東園', '28', '28204', '6620813', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '上甲東園', 'カミコウトウエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市仁川五ケ山町', '28', '28204', '6620814', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '仁川五ケ山町', 'ニガワゴカヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市仁川百合野町', '28', '28204', '6620815', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '仁川百合野町', 'ニガワユリノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市神呪字中谷', '28', '28204', '6620821', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '神呪字中谷', 'カンノウアザナカタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市松籟荘', '28', '28204', '6620822', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '松籟荘', 'ショウライソウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市神呪町', '28', '28204', '6620823', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '神呪町', 'カンノウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市門戸東町', '28', '28204', '6620824', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '門戸東町', 'モンドヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市門戸荘', '28', '28204', '6620825', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '門戸荘', 'モンドソウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市門戸岡田町', '28', '28204', '6620826', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '門戸岡田町', 'モンドオカダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市岡田山', '28', '28204', '6620827', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '岡田山', 'オカダヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市門戸西町', '28', '28204', '6620828', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '門戸西町', 'モンドニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市丸橋町', '28', '28204', '6620831', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '丸橋町', 'マルハシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市甲風園', '28', '28204', '6620832', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '甲風園', 'コウフウエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市北昭和町', '28', '28204', '6620833', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '北昭和町', 'キタショウワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市南昭和町', '28', '28204', '6620834', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '南昭和町', 'ミナミショウワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市平木町', '28', '28204', '6620835', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '平木町', 'ヒラキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市大畑町', '28', '28204', '6620836', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '大畑町', 'オオハタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市広田町', '28', '28204', '6620837', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '広田町', 'ヒロタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市能登町', '28', '28204', '6620838', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '能登町', 'ノトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市両度町', '28', '28204', '6620841', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '両度町', 'リョウドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市芦原町', '28', '28204', '6620842', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '芦原町', 'アシハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市神祇官町', '28', '28204', '6620843', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '神祇官町', 'ジンギカンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市西福町', '28', '28204', '6620844', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '西福町', 'サイフクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市神明町', '28', '28204', '6620845', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '神明町', 'シンメイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市森下町', '28', '28204', '6620846', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '森下町', 'モリシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市中須佐町', '28', '28204', '6620851', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '中須佐町', 'ナカスサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市中殿町', '28', '28204', '6620852', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '中殿町', 'ナカドノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市津田町', '28', '28204', '6620853', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '津田町', 'ツダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市櫨塚町', '28', '28204', '6620854', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '櫨塚町', 'ハゼツカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市江上町', '28', '28204', '6620855', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '江上町', 'エガミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市城ケ堀町', '28', '28204', '6620856', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '城ケ堀町', 'ジョウガボリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市中前田町', '28', '28204', '6620857', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '中前田町', 'ナカマエダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市河原町', '28', '28204', '6620861', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '河原町', 'カワハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市青木町', '28', '28204', '6620862', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '青木町', 'アオキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市室川町', '28', '28204', '6620863', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '室川町', 'ムロカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市越水町', '28', '28204', '6620864', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '越水町', 'コシミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市神垣町', '28', '28204', '6620865', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '神垣町', 'カミガキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市柳本町', '28', '28204', '6620866', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '柳本町', 'ヤナギモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市大社町', '28', '28204', '6620867', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '大社町', 'タイシャチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市中屋町', '28', '28204', '6620868', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '中屋町', 'ナカヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市愛宕山', '28', '28204', '6620871', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '愛宕山', 'アタゴヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市高座町', '28', '28204', '6620872', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '高座町', 'タカクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市一ケ谷町', '28', '28204', '6620873', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '一ケ谷町', 'イチガヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市六軒町', '28', '28204', '6620874', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '六軒町', 'ロッケンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市五月ケ丘', '28', '28204', '6620875', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '五月ケ丘', 'サツキガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市上ケ原七番町', '28', '28204', '6620881', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '上ケ原七番町', 'ウエガハラ07バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市上ケ原八番町', '28', '28204', '6620882', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '上ケ原八番町', 'ウエガハラ08バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市上ケ原九番町', '28', '28204', '6620883', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '上ケ原九番町', 'ウエガハラ09バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市上ケ原十番町', '28', '28204', '6620884', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '上ケ原十番町', 'ウエガハラ10バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市上ケ原山手町', '28', '28204', '6620885', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '上ケ原山手町', 'ウエガハラヤマテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市上ケ原山田町', '28', '28204', '6620886', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '上ケ原山田町', 'ウエガハラヤマダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市上ケ原一番町', '28', '28204', '6620891', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '上ケ原一番町', 'ウエガハラ01バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市上ケ原二番町', '28', '28204', '6620892', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '上ケ原二番町', 'ウエガハラ02バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市上ケ原三番町', '28', '28204', '6620893', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '上ケ原三番町', 'ウエガハラ03バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市上ケ原四番町', '28', '28204', '6620894', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '上ケ原四番町', 'ウエガハラ04バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市上ケ原五番町', '28', '28204', '6620895', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '上ケ原五番町', 'ウエガハラ05バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市上ケ原六番町', '28', '28204', '6620896', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '上ケ原六番町', 'ウエガハラ06バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市池田町', '28', '28204', '6620911', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '池田町', 'イケダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市松原町', '28', '28204', '6620912', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '松原町', 'マツバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市染殿町', '28', '28204', '6620913', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '染殿町', 'ソメドノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市本町', '28', '28204', '6620914', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市馬場町', '28', '28204', '6620915', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '馬場町', 'ババチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市戸田町', '28', '28204', '6620916', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '戸田町', 'トダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市与古道町', '28', '28204', '6620917', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '与古道町', 'ヨコミチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市六湛寺町', '28', '28204', '6620918', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '六湛寺町', 'ロクタンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市用海町', '28', '28204', '6620921', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '用海町', 'ヨウガイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市東町', '28', '28204', '6620922', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '東町', 'ヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市浜松原町', '28', '28204', '6620923', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '浜松原町', 'ハママツバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市東浜町', '28', '28204', '6620924', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '東浜町', 'ヒガシハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市朝凪町', '28', '28204', '6620925', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '朝凪町', 'アサナギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市鞍掛町', '28', '28204', '6620926', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '鞍掛町', 'クラカケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市久保町', '28', '28204', '6620927', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '久保町', 'クボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市石在町', '28', '28204', '6620928', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '石在町', 'イシザイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市前浜町', '28', '28204', '6620931', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '前浜町', 'マエハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市泉町', '28', '28204', '6620932', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '泉町', 'イズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市西波止町', '28', '28204', '6620933', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '西波止町', 'ニシハトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市西宮浜', '28', '28204', '6620934', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '西宮浜', 'ニシノミヤハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市浜脇町', '28', '28204', '6620941', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '浜脇町', 'ハマワキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市浜町', '28', '28204', '6620942', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '浜町', 'ハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市建石町', '28', '28204', '6620943', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '建石町', 'タテイシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市川添町', '28', '28204', '6620944', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '川添町', 'カワゾエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市川東町', '28', '28204', '6620945', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '川東町', 'カワヒガシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市荒戎町', '28', '28204', '6620946', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '荒戎町', 'アラエビスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市宮前町', '28', '28204', '6620947', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '宮前町', 'ミヤマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市川西町', '28', '28204', '6620951', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '川西町', 'カワニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市中浜町', '28', '28204', '6620952', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '中浜町', 'ナカハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市堀切町', '28', '28204', '6620953', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '堀切町', 'ホリキリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市上葭原町', '28', '28204', '6620954', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '上葭原町', 'カミヨシハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市中葭原町', '28', '28204', '6620955', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '中葭原町', 'ナカヨシハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市下葭原町', '28', '28204', '6620956', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '下葭原町', 'シモヨシハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市大浜町', '28', '28204', '6620957', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '大浜町', 'オオハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市御茶家所町', '28', '28204', '6620961', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '御茶家所町', 'オチャヤショチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市松下町', '28', '28204', '6620962', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '松下町', 'マツシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市屋敷町', '28', '28204', '6620963', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '屋敷町', 'ヤシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市弓場町', '28', '28204', '6620964', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '弓場町', 'ユバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市郷免町', '28', '28204', '6620965', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '郷免町', 'ゴウメンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市和上町', '28', '28204', '6620971', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '和上町', 'ワジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市今在家町', '28', '28204', '6620972', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '今在家町', 'イマザイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市田中町', '28', '28204', '6620973', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '田中町', 'タナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市社家町', '28', '28204', '6620974', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '社家町', 'シャケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市市庭町', '28', '28204', '6620975', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '市庭町', 'イチニワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市宮西町', '28', '28204', '6620976', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '宮西町', 'ミヤニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市神楽町', '28', '28204', '6620977', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '神楽町', 'カグラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市産所町', '28', '28204', '6620978', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '産所町', 'サンショチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市田近野町', '28', '28204', '6638001', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '田近野町', 'タジカノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市一里山町', '28', '28204', '6638002', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '一里山町', 'イチリヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市上大市', '28', '28204', '6638003', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '上大市', 'カミオオイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市下大市東町', '28', '28204', '6638004', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '下大市東町', 'シモオオイチヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市下大市西町', '28', '28204', '6638005', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '下大市西町', 'シモオオイチニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市段上町', '28', '28204', '6638006', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '段上町', 'ダンジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市樋ノ口町', '28', '28204', '6638011', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '樋ノ口町', 'ヒノクチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市堤町', '28', '28204', '6638012', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '堤町', 'ツツミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市門前町', '28', '28204', '6638013', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '門前町', 'モンゼンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市林田町', '28', '28204', '6638014', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '林田町', 'ハヤシダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市野間町', '28', '28204', '6638015', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '野間町', 'ノマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市若山町', '28', '28204', '6638016', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '若山町', 'ワカヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市大島町', '28', '28204', '6638017', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '大島町', 'オオシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市上之町', '28', '28204', '6638021', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '上之町', 'カミノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市日野町', '28', '28204', '6638022', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '日野町', 'ヒノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市大森町', '28', '28204', '6638023', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '大森町', 'オオモリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市薬師町', '28', '28204', '6638024', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '薬師町', 'ヤクシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市荒木町', '28', '28204', '6638025', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '荒木町', 'アラキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市伏原町', '28', '28204', '6638031', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '伏原町', 'フシハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市高木西町', '28', '28204', '6638032', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '高木西町', 'タカギニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市高木東町', '28', '28204', '6638033', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '高木東町', 'タカギヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市長田町', '28', '28204', '6638034', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '長田町', 'ナガタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市北口町', '28', '28204', '6638035', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '北口町', 'キタグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市松山町', '28', '28204', '6638101', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '松山町', 'マツヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('78999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市松並町', '28', '28204', '6638102', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '松並町', 'マツナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市熊野町', '28', '28204', '6638103', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '熊野町', 'クマノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市天道町', '28', '28204', '6638104', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '天道町', 'テンドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市中島町', '28', '28204', '6638105', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '中島町', 'ナカジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市大屋町', '28', '28204', '6638106', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '大屋町', 'オオヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市瓦林町', '28', '28204', '6638107', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '瓦林町', 'カワラバヤシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市二見町', '28', '28204', '6638111', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '二見町', 'フタミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市甲子園口北町', '28', '28204', '6638112', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '甲子園口北町', 'コウシエングチキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市甲子園口', '28', '28204', '6638113', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '甲子園口', 'コウシエングチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市上甲子園', '28', '28204', '6638114', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '上甲子園', 'カミコウシエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市戸崎町', '28', '28204', '6638121', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '戸崎町', 'トザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市小曽根町', '28', '28204', '6638122', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '小曽根町', 'コソネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市小松東町', '28', '28204', '6638123', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '小松東町', 'コマツヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市小松南町', '28', '28204', '6638124', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '小松南町', 'コマツミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市小松西町', '28', '28204', '6638125', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '小松西町', 'コマツニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市小松北町', '28', '28204', '6638126', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '小松北町', 'コマツキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市小松町', '28', '28204', '6638127', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '小松町', 'コマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市武庫川町', '28', '28204', '6638131', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '武庫川町', 'ムコガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市東鳴尾町', '28', '28204', '6638132', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '東鳴尾町', 'ヒガシナルオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市上田東町', '28', '28204', '6638133', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '上田東町', 'ウエダヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市上田中町', '28', '28204', '6638134', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '上田中町', 'ウエダナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市上田西町', '28', '28204', '6638135', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '上田西町', 'ウエダニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市笠屋町', '28', '28204', '6638136', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '笠屋町', 'カサヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市池開町', '28', '28204', '6638137', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '池開町', 'イケビラキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市高須町', '28', '28204', '6638141', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '高須町', 'タカスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市鳴尾浜', '28', '28204', '6638142', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '鳴尾浜', 'ナルオハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市枝川町', '28', '28204', '6638143', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '枝川町', 'エダガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市甲子園洲鳥町', '28', '28204', '6638151', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '甲子園洲鳥町', 'コウシエンスドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市甲子園町', '28', '28204', '6638152', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '甲子園町', 'コウシエンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市南甲子園', '28', '28204', '6638153', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '南甲子園', 'ミナミコウシエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市浜甲子園', '28', '28204', '6638154', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '浜甲子園', 'ハマコウシエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市甲子園浜', '28', '28204', '6638155', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '甲子園浜', 'コウシエンハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市甲子園網引町', '28', '28204', '6638156', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '甲子園網引町', 'コウシエンアビキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市甲子園春風町', '28', '28204', '6638161', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '甲子園春風町', 'コウシエンハルカゼチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市甲子園砂田町', '28', '28204', '6638162', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '甲子園砂田町', 'コウシエンスナダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市甲子園三保町', '28', '28204', '6638163', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '甲子園三保町', 'コウシエンミホチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市甲子園六石町', '28', '28204', '6638164', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '甲子園六石町', 'コウシエンロッコクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市甲子園浦風町', '28', '28204', '6638165', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '甲子園浦風町', 'コウシエンウラカゼチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市甲子園高潮町', '28', '28204', '6638166', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '甲子園高潮町', 'コウシエンタカシオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市甲子園浜田町', '28', '28204', '6638167', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '甲子園浜田町', 'コウシエンハマダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市甲子園一番町', '28', '28204', '6638171', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '甲子園一番町', 'コウシエン01バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市甲子園二番町', '28', '28204', '6638172', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '甲子園二番町', 'コウシエン02バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市甲子園三番町', '28', '28204', '6638173', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '甲子園三番町', 'コウシエン03バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市甲子園四番町', '28', '28204', '6638174', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '甲子園四番町', 'コウシエン04バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市甲子園五番町', '28', '28204', '6638175', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '甲子園五番町', 'コウシエン05バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市甲子園六番町', '28', '28204', '6638176', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '甲子園六番町', 'コウシエン06バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市甲子園七番町', '28', '28204', '6638177', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '甲子園七番町', 'コウシエン07バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市甲子園八番町', '28', '28204', '6638178', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '甲子園八番町', 'コウシエン08バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市甲子園九番町', '28', '28204', '6638179', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '甲子園九番町', 'コウシエン09バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市若草町', '28', '28204', '6638181', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '若草町', 'ワカクサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市学文殿町', '28', '28204', '6638182', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '学文殿町', 'ガクブンデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市里中町', '28', '28204', '6638183', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '里中町', 'サトナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市鳴尾町', '28', '28204', '6638184', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '鳴尾町', 'ナルオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市古川町', '28', '28204', '6638185', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '古川町', 'フルカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市上鳴尾町', '28', '28204', '6638186', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '上鳴尾町', 'アゲナルオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市花園町', '28', '28204', '6638187', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '花園町', 'ハナゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市田代町', '28', '28204', '6638201', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '田代町', 'タシロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市高畑町', '28', '28204', '6638202', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '高畑町', 'タカハタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市深津町', '28', '28204', '6638203', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '深津町', 'フカズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市高松町', '28', '28204', '6638204', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '高松町', 'タカマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市今津山中町', '28', '28204', '6638211', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '今津山中町', 'イマヅヤマナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市今津野田町', '28', '28204', '6638212', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '今津野田町', 'イマヅノダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市今津上野町', '28', '28204', '6638213', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '今津上野町', 'イマヅウエノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市今津曙町', '28', '28204', '6638214', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '今津曙町', 'イマヅアケボノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市今津水波町', '28', '28204', '6638215', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '今津水波町', 'イマヅミズナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市今津大東町', '28', '28204', '6638221', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '今津大東町', 'イマヅオオヒガシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市今津久寿川町', '28', '28204', '6638222', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '今津久寿川町', 'イマヅクスガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市今津巽町', '28', '28204', '6638223', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '今津巽町', 'イマヅタツミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市今津真砂町', '28', '28204', '6638224', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '今津真砂町', 'イマヅマサゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市今津西浜町', '28', '28204', '6638225', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '今津西浜町', 'イマヅニシハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市今津港町', '28', '28204', '6638226', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '今津港町', 'イマヅミナトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市今津出在家町', '28', '28204', '6638227', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '今津出在家町', 'イマヅデザイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市今津二葉町', '28', '28204', '6638228', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '今津二葉町', 'イマヅフタバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市今津社前町', '28', '28204', '6638229', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '今津社前町', 'イマヅシャゼンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市津門西口町', '28', '28204', '6638231', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '津門西口町', 'ツトニシグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市津門宝津町', '28', '28204', '6638232', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '津門宝津町', 'ツトホウズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市津門川町', '28', '28204', '6638233', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '津門川町', 'ツトガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市津門住江町', '28', '28204', '6638234', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '津門住江町', 'ツトスミエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市津門大塚町', '28', '28204', '6638241', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '津門大塚町', 'ツトオオツカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市津門飯田町', '28', '28204', '6638242', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '津門飯田町', 'ツトイイデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市津門大箇町', '28', '28204', '6638243', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '津門大箇町', 'ツトオオゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市津門綾羽町', '28', '28204', '6638244', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '津門綾羽町', 'ツトアヤハチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市津門呉羽町', '28', '28204', '6638245', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '津門呉羽町', 'ツトクレハチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市津門仁辺町', '28', '28204', '6638246', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '津門仁辺町', 'ツトニベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市津門稲荷町', '28', '28204', '6638247', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '津門稲荷町', 'ツトイナリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県伊丹市', '28', '28207', '6640000', '兵庫県', 'ヒョウゴケン', '伊丹市', 'イタミシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('79094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県伊丹市荒牧', '28', '28207', '6640001', '兵庫県', 'ヒョウゴケン', '伊丹市', 'イタミシ', '荒牧', 'アラマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県伊丹市荻野', '28', '28207', '6640002', '兵庫県', 'ヒョウゴケン', '伊丹市', 'イタミシ', '荻野', 'オギノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県伊丹市大野', '28', '28207', '6640003', '兵庫県', 'ヒョウゴケン', '伊丹市', 'イタミシ', '大野', 'オオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県伊丹市東野', '28', '28207', '6640004', '兵庫県', 'ヒョウゴケン', '伊丹市', 'イタミシ', '東野', 'ヒガシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県伊丹市瑞原', '28', '28207', '6640005', '兵庫県', 'ヒョウゴケン', '伊丹市', 'イタミシ', '瑞原', 'ミズハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県伊丹市鴻池', '28', '28207', '6640006', '兵庫県', 'ヒョウゴケン', '伊丹市', 'イタミシ', '鴻池', 'コウノイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県伊丹市北野', '28', '28207', '6640007', '兵庫県', 'ヒョウゴケン', '伊丹市', 'イタミシ', '北野', 'キタノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県伊丹市荒牧南', '28', '28207', '6640008', '兵庫県', 'ヒョウゴケン', '伊丹市', 'イタミシ', '荒牧南', 'アラマキミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県伊丹市鋳物師', '28', '28207', '6640011', '兵庫県', 'ヒョウゴケン', '伊丹市', 'イタミシ', '鋳物師', 'イモジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県伊丹市緑ケ丘', '28', '28207', '6640012', '兵庫県', 'ヒョウゴケン', '伊丹市', 'イタミシ', '緑ケ丘', 'ミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県伊丹市瑞穂町', '28', '28207', '6640013', '兵庫県', 'ヒョウゴケン', '伊丹市', 'イタミシ', '瑞穂町', 'ミズホチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県伊丹市広畑', '28', '28207', '6640014', '兵庫県', 'ヒョウゴケン', '伊丹市', 'イタミシ', '広畑', 'ヒロハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県伊丹市昆陽池', '28', '28207', '6640015', '兵庫県', 'ヒョウゴケン', '伊丹市', 'イタミシ', '昆陽池', 'コヤイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県伊丹市昆陽北', '28', '28207', '6640016', '兵庫県', 'ヒョウゴケン', '伊丹市', 'イタミシ', '昆陽北', 'コヤキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県伊丹市瑞ケ丘', '28', '28207', '6640017', '兵庫県', 'ヒョウゴケン', '伊丹市', 'イタミシ', '瑞ケ丘', 'ミズガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県伊丹市寺本東', '28', '28207', '6640020', '兵庫県', 'ヒョウゴケン', '伊丹市', 'イタミシ', '寺本東', 'テラモトヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県伊丹市中野', '28', '28207', '6640021', '兵庫県', 'ヒョウゴケン', '伊丹市', 'イタミシ', '中野', 'ナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県伊丹市中野東', '28', '28207', '6640022', '兵庫県', 'ヒョウゴケン', '伊丹市', 'イタミシ', '中野東', 'ナカノヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県伊丹市中野西', '28', '28207', '6640023', '兵庫県', 'ヒョウゴケン', '伊丹市', 'イタミシ', '中野西', 'ナカノニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県伊丹市松ケ丘', '28', '28207', '6640024', '兵庫県', 'ヒョウゴケン', '伊丹市', 'イタミシ', '松ケ丘', 'マツガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県伊丹市奥畑', '28', '28207', '6640025', '兵庫県', 'ヒョウゴケン', '伊丹市', 'イタミシ', '奥畑', 'オクハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県伊丹市寺本', '28', '28207', '6640026', '兵庫県', 'ヒョウゴケン', '伊丹市', 'イタミシ', '寺本', 'テラモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県伊丹市池尻', '28', '28207', '6640027', '兵庫県', 'ヒョウゴケン', '伊丹市', 'イタミシ', '池尻', 'イケジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県伊丹市西野', '28', '28207', '6640028', '兵庫県', 'ヒョウゴケン', '伊丹市', 'イタミシ', '西野', 'ニシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県伊丹市中野北', '28', '28207', '6640029', '兵庫県', 'ヒョウゴケン', '伊丹市', 'イタミシ', '中野北', 'ナカノキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県伊丹市荻野西', '28', '28207', '6640031', '兵庫県', 'ヒョウゴケン', '伊丹市', 'イタミシ', '荻野西', 'オギノニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県伊丹市北伊丹', '28', '28207', '6640831', '兵庫県', 'ヒョウゴケン', '伊丹市', 'イタミシ', '北伊丹', 'キタイタミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県伊丹市下河原', '28', '28207', '6640832', '兵庫県', 'ヒョウゴケン', '伊丹市', 'イタミシ', '下河原', 'シモガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県伊丹市小阪田都賀元', '28', '28207', '6640833', '兵庫県', 'ヒョウゴケン', '伊丹市', 'イタミシ', '小阪田', 'オサカデン', null, null, '都賀元', 'トガモト');
INSERT INTO `ms_addresses` VALUES ('79123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県伊丹市西桑津', '28', '28207', '6640834', '兵庫県', 'ヒョウゴケン', '伊丹市', 'イタミシ', '西桑津', 'ニシクワヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県伊丹市東桑津', '28', '28207', '6640835', '兵庫県', 'ヒョウゴケン', '伊丹市', 'イタミシ', '東桑津', 'ヒガシクワヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県伊丹市北本町', '28', '28207', '6640836', '兵庫県', 'ヒョウゴケン', '伊丹市', 'イタミシ', '北本町', 'キタホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県伊丹市北河原', '28', '28207', '6640837', '兵庫県', 'ヒョウゴケン', '伊丹市', 'イタミシ', '北河原', 'キタガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県伊丹市中村', '28', '28207', '6640838', '兵庫県', 'ヒョウゴケン', '伊丹市', 'イタミシ', '中村', 'ナカムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県伊丹市桑津', '28', '28207', '6640839', '兵庫県', 'ヒョウゴケン', '伊丹市', 'イタミシ', '桑津', 'クワヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県伊丹市森本', '28', '28207', '6640842', '兵庫県', 'ヒョウゴケン', '伊丹市', 'イタミシ', '森本', 'モリモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県伊丹市岩屋', '28', '28207', '6640843', '兵庫県', 'ヒョウゴケン', '伊丹市', 'イタミシ', '岩屋', 'イワヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県伊丹市口酒井', '28', '28207', '6640844', '兵庫県', 'ヒョウゴケン', '伊丹市', 'イタミシ', '口酒井', 'クチサカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県伊丹市東有岡', '28', '28207', '6640845', '兵庫県', 'ヒョウゴケン', '伊丹市', 'イタミシ', '東有岡', 'ヒガシアリオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県伊丹市伊丹', '28', '28207', '6640846', '兵庫県', 'ヒョウゴケン', '伊丹市', 'イタミシ', '伊丹', 'イタミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県伊丹市藤ノ木', '28', '28207', '6640847', '兵庫県', 'ヒョウゴケン', '伊丹市', 'イタミシ', '藤ノ木', 'フジノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県伊丹市中央', '28', '28207', '6640851', '兵庫県', 'ヒョウゴケン', '伊丹市', 'イタミシ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県伊丹市南本町', '28', '28207', '6640852', '兵庫県', 'ヒョウゴケン', '伊丹市', 'イタミシ', '南本町', 'ミナミホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県伊丹市平松', '28', '28207', '6640853', '兵庫県', 'ヒョウゴケン', '伊丹市', 'イタミシ', '平松', 'ヒラマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県伊丹市南町', '28', '28207', '6640854', '兵庫県', 'ヒョウゴケン', '伊丹市', 'イタミシ', '南町', 'ミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県伊丹市御願塚', '28', '28207', '6640855', '兵庫県', 'ヒョウゴケン', '伊丹市', 'イタミシ', '御願塚', 'ゴガヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県伊丹市梅ノ木', '28', '28207', '6640856', '兵庫県', 'ヒョウゴケン', '伊丹市', 'イタミシ', '梅ノ木', 'ウメノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県伊丹市行基町', '28', '28207', '6640857', '兵庫県', 'ヒョウゴケン', '伊丹市', 'イタミシ', '行基町', 'ギョウキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県伊丹市西台', '28', '28207', '6640858', '兵庫県', 'ヒョウゴケン', '伊丹市', 'イタミシ', '西台', 'ニシダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県伊丹市稲野町', '28', '28207', '6640861', '兵庫県', 'ヒョウゴケン', '伊丹市', 'イタミシ', '稲野町', 'イナノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県伊丹市若菱町', '28', '28207', '6640862', '兵庫県', 'ヒョウゴケン', '伊丹市', 'イタミシ', '若菱町', 'ワカビシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県伊丹市柏木町', '28', '28207', '6640863', '兵庫県', 'ヒョウゴケン', '伊丹市', 'イタミシ', '柏木町', 'カシワギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県伊丹市安堂寺町', '28', '28207', '6640864', '兵庫県', 'ヒョウゴケン', '伊丹市', 'イタミシ', '安堂寺町', 'アンドウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県伊丹市南野', '28', '28207', '6640865', '兵庫県', 'ヒョウゴケン', '伊丹市', 'イタミシ', '南野', 'ミナミノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県伊丹市堀池', '28', '28207', '6640871', '兵庫県', 'ヒョウゴケン', '伊丹市', 'イタミシ', '堀池', 'ホリイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県伊丹市車塚', '28', '28207', '6640872', '兵庫県', 'ヒョウゴケン', '伊丹市', 'イタミシ', '車塚', 'クルマヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県伊丹市野間', '28', '28207', '6640873', '兵庫県', 'ヒョウゴケン', '伊丹市', 'イタミシ', '野間', 'ノマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県伊丹市山田', '28', '28207', '6640874', '兵庫県', 'ヒョウゴケン', '伊丹市', 'イタミシ', '山田', 'ヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県伊丹市野間北', '28', '28207', '6640875', '兵庫県', 'ヒョウゴケン', '伊丹市', 'イタミシ', '野間北', 'ノマキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県伊丹市昆陽', '28', '28207', '6640881', '兵庫県', 'ヒョウゴケン', '伊丹市', 'イタミシ', '昆陽', 'コヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県伊丹市鈴原町', '28', '28207', '6640882', '兵庫県', 'ヒョウゴケン', '伊丹市', 'イタミシ', '鈴原町', 'スズハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県伊丹市南鈴原', '28', '28207', '6640883', '兵庫県', 'ヒョウゴケン', '伊丹市', 'イタミシ', '南鈴原', 'ミナミスズハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県伊丹市美鈴町', '28', '28207', '6640884', '兵庫県', 'ヒョウゴケン', '伊丹市', 'イタミシ', '美鈴町', 'ミスズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県伊丹市昆陽泉町', '28', '28207', '6640885', '兵庫県', 'ヒョウゴケン', '伊丹市', 'イタミシ', '昆陽泉町', 'コヤイズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県伊丹市昆陽東', '28', '28207', '6640886', '兵庫県', 'ヒョウゴケン', '伊丹市', 'イタミシ', '昆陽東', 'コヤヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県伊丹市南野北', '28', '28207', '6640887', '兵庫県', 'ヒョウゴケン', '伊丹市', 'イタミシ', '南野北', 'ミナミノキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県伊丹市昆陽南', '28', '28207', '6640888', '兵庫県', 'ヒョウゴケン', '伊丹市', 'イタミシ', '昆陽南', 'コヤミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県伊丹市北園', '28', '28207', '6640891', '兵庫県', 'ヒョウゴケン', '伊丹市', 'イタミシ', '北園', 'キタゾノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県伊丹市高台', '28', '28207', '6640892', '兵庫県', 'ヒョウゴケン', '伊丹市', 'イタミシ', '高台', 'タカダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県伊丹市春日丘', '28', '28207', '6640893', '兵庫県', 'ヒョウゴケン', '伊丹市', 'イタミシ', '春日丘', 'カスガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県伊丹市清水', '28', '28207', '6640894', '兵庫県', 'ヒョウゴケン', '伊丹市', 'イタミシ', '清水', 'シミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県伊丹市宮ノ前', '28', '28207', '6640895', '兵庫県', 'ヒョウゴケン', '伊丹市', 'イタミシ', '宮ノ前', 'ミヤノマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県伊丹市船原', '28', '28207', '6640896', '兵庫県', 'ヒョウゴケン', '伊丹市', 'イタミシ', '船原', 'フナハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県伊丹市桜ケ丘', '28', '28207', '6640897', '兵庫県', 'ヒョウゴケン', '伊丹市', 'イタミシ', '桜ケ丘', 'サクラガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県伊丹市千僧', '28', '28207', '6640898', '兵庫県', 'ヒョウゴケン', '伊丹市', 'イタミシ', '千僧', 'センゾ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県伊丹市大鹿', '28', '28207', '6640899', '兵庫県', 'ヒョウゴケン', '伊丹市', 'イタミシ', '大鹿', 'オオジカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市', '28', '28214', '6650000', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('79192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市長寿ガ丘', '28', '28214', '6650001', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '長寿ガ丘', 'チョウジュガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市月見山', '28', '28214', '6650002', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '月見山', 'ツキミヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市湯本町', '28', '28214', '6650003', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '湯本町', 'ユモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市梅野町', '28', '28214', '6650004', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '梅野町', 'ウメノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市武庫山', '28', '28214', '6650005', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '武庫山', 'ムコヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市紅葉ガ丘', '28', '28214', '6650006', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '紅葉ガ丘', 'モミジガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市伊孑志武庫山', '28', '28214', '6650007', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '伊孑志', 'イソシ', null, null, '武庫山', 'ムコヤマ');
INSERT INTO `ms_addresses` VALUES ('79199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市南口', '28', '28214', '6650011', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '南口', 'ミナミグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市寿楽荘', '28', '28214', '6650012', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '寿楽荘', 'ジュラクソウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市宝梅', '28', '28214', '6650013', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '宝梅', 'ホウバイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市青葉台', '28', '28214', '6650014', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '青葉台', 'アオバダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市光ガ丘', '28', '28214', '6650015', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '光ガ丘', 'ヒカリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市宝松苑', '28', '28214', '6650016', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '宝松苑', 'ホウショウエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市小林西山', '28', '28214', '6650017', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '小林西山', 'オバヤシニシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市中州', '28', '28214', '6650021', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '中州', 'ナカス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市野上', '28', '28214', '6650022', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '野上', 'ノガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市蔵人', '28', '28214', '6650023', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '蔵人', 'クランド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市逆瀬台', '28', '28214', '6650024', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '逆瀬台', 'サカセダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市ゆずり葉台', '28', '28214', '6650025', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', 'ゆずり葉台', 'ユズリハダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市末広町', '28', '28214', '6650031', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '末広町', 'スエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市東洋町', '28', '28214', '6650032', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '東洋町', 'トウヨウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市伊孑志', '28', '28214', '6650033', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '伊孑志', 'イソシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市小林', '28', '28214', '6650034', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '小林', 'オバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市逆瀬川', '28', '28214', '6650035', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '逆瀬川', 'サカセガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市御所の前町', '28', '28214', '6650041', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '御所の前町', 'ゴショノマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市美幸町', '28', '28214', '6650042', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '美幸町', 'ミユキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市高松町', '28', '28214', '6650043', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '高松町', 'タカマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市末成町', '28', '28214', '6650044', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '末成町', 'スエナリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市光明町', '28', '28214', '6650045', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '光明町', 'コウミョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市福井町', '28', '28214', '6650046', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '福井町', 'フクイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市亀井町', '28', '28214', '6650047', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '亀井町', 'カメイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市高司', '28', '28214', '6650051', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '高司', 'タカツカサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市新明和町', '28', '28214', '6650052', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '新明和町', 'シンメイワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市駒の町', '28', '28214', '6650053', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '駒の町', 'コマノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市鹿塩', '28', '28214', '6650054', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '鹿塩', 'カシオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市大成町', '28', '28214', '6650055', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '大成町', 'タイセイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市中野町', '28', '28214', '6650056', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '中野町', 'ナカノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市大吹町', '28', '28214', '6650057', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '大吹町', 'オオブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市仁川北', '28', '28214', '6650061', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '仁川北', 'ニガワキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市仁川高台', '28', '28214', '6650062', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '仁川高台', 'ニガワタカダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市仁川高丸', '28', '28214', '6650063', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '仁川高丸', 'ニガワタカマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市仁川うぐいす台', '28', '28214', '6650064', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '仁川うぐいす台', 'ニガワウグイスダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市仁川旭ガ丘', '28', '28214', '6650065', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '仁川旭ガ丘', 'ニガワアサヒガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市仁川団地', '28', '28214', '6650066', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '仁川団地', 'ニガワダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市仁川月見ガ丘', '28', '28214', '6650067', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '仁川月見ガ丘', 'ニガワツキミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市社町', '28', '28214', '6650071', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '社町', 'ヤシロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市千種', '28', '28214', '6650072', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '千種', 'チグサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市塔の町', '28', '28214', '6650073', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '塔の町', 'トウノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市仁川台', '28', '28214', '6650074', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '仁川台', 'ニガワダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市仁川宮西町', '28', '28214', '6650075', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '仁川宮西町', 'ニガワミヤニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市谷口町', '28', '28214', '6650076', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '谷口町', 'タニグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市花屋敷松ガ丘', '28', '28214', '6650801', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '花屋敷松ガ丘', 'ハナヤシキマツガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市花屋敷荘園', '28', '28214', '6650802', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '花屋敷荘園', 'ハナヤシキソウエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市花屋敷つつじガ丘', '28', '28214', '6650803', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '花屋敷つつじガ丘', 'ハナヤシキツツジガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市雲雀丘山手', '28', '28214', '6650804', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '雲雀丘山手', 'ヒバリガオカヤマテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市雲雀丘', '28', '28214', '6650805', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '雲雀丘', 'ヒバリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市ふじガ丘', '28', '28214', '6650806', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', 'ふじガ丘', 'フジガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市長尾台', '28', '28214', '6650807', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '長尾台', 'ナガオダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市切畑長尾山', '28', '28214', '6650808', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '切畑', 'キリハタ', null, null, '長尾山', 'ナガオサン');
INSERT INTO `ms_addresses` VALUES ('79251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市南ひばりガ丘', '28', '28214', '6650811', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '南ひばりガ丘', 'ミナミヒバリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市口谷東', '28', '28214', '6650812', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '口谷東', 'クチタニヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市口谷西', '28', '28214', '6650813', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '口谷西', 'クチタニニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市山本野里', '28', '28214', '6650814', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '山本野里', 'ヤマモトノザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市山本丸橋', '28', '28214', '6650815', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '山本丸橋', 'ヤマモトマルハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市平井', '28', '28214', '6650816', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '平井', 'ヒライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市平井山荘', '28', '28214', '6650817', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '平井山荘', 'ヒライサンソウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市安倉北', '28', '28214', '6650821', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '安倉北', 'アクラキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市安倉中', '28', '28214', '6650822', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '安倉中', 'アクラナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市安倉南', '28', '28214', '6650823', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '安倉南', 'アクラミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市金井町', '28', '28214', '6650824', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '金井町', 'カナイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市安倉西', '28', '28214', '6650825', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '安倉西', 'アクラニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市弥生町', '28', '28214', '6650826', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '弥生町', 'ヤヨイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市小浜', '28', '28214', '6650827', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '小浜', 'コハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市米谷', '28', '28214', '6650831', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '米谷', 'マイタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市向月町', '28', '28214', '6650832', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '向月町', 'コウゲツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市鶴の荘', '28', '28214', '6650833', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '鶴の荘', 'ツルノソウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市美座', '28', '28214', '6650834', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '美座', 'ミザ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市旭町', '28', '28214', '6650835', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '旭町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市清荒神', '28', '28214', '6650836', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '清荒神', 'キヨシコウジン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市米谷清', '28', '28214', '6650837', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '米谷清', 'マイタニキヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市御殿山', '28', '28214', '6650841', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '御殿山', 'ゴテンヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市川面', '28', '28214', '6650842', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '川面', 'カワモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市宮の町', '28', '28214', '6650843', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '宮の町', 'ミヤノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市武庫川町', '28', '28214', '6650844', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '武庫川町', 'ムコガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市栄町', '28', '28214', '6650845', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市桜ガ丘', '28', '28214', '6650846', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '桜ガ丘', 'サクラガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市すみれガ丘', '28', '28214', '6650847', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', 'すみれガ丘', 'スミレガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市川面長尾山', '28', '28214', '6650848', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '川面', 'カワモ', null, null, '長尾山', 'ナガオヤマ');
INSERT INTO `ms_addresses` VALUES ('79280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市泉ガ丘', '28', '28214', '6650851', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '泉ガ丘', 'イズミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市売布', '28', '28214', '6650852', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '売布', 'メフ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市売布ガ丘', '28', '28214', '6650853', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '売布ガ丘', 'メフガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市売布山手町', '28', '28214', '6650854', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '売布山手町', 'メフヤマテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市売布きよしガ丘', '28', '28214', '6650855', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '売布きよしガ丘', 'メフキヨシガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市中山寺', '28', '28214', '6650861', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '中山寺', 'ナカヤマデラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市今里町', '28', '28214', '6650862', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '今里町', 'イマザトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市三笠町', '28', '28214', '6650863', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '三笠町', 'ミカサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市泉町', '28', '28214', '6650864', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '泉町', 'イズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市寿町', '28', '28214', '6650865', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '寿町', 'コトブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市星の荘', '28', '28214', '6650866', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '星の荘', 'ホシノソウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市売布東の町', '28', '28214', '6650867', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '売布東の町', 'メフヒガシノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市中山荘園', '28', '28214', '6650868', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '中山荘園', 'ナカヤマソウエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市中山五月台', '28', '28214', '6650871', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '中山五月台', 'ナカヤマサツキダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市中筋平井', '28', '28214', '6650872', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '中筋', 'ナカスジ', null, null, '平井', 'ヒライ');
INSERT INTO `ms_addresses` VALUES ('79295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市長尾町', '28', '28214', '6650873', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '長尾町', 'ナガオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市中筋', '28', '28214', '6650874', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '中筋', 'ナカスジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市中筋山手', '28', '28214', '6650875', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '中筋山手', 'ナカスジヤマテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市中山台', '28', '28214', '6650876', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '中山台', 'ナカヤマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市中山桜台', '28', '28214', '6650877', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '中山桜台', 'ナカヤマサクラダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市山本東', '28', '28214', '6650881', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '山本東', 'ヤマモトヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市山本南', '28', '28214', '6650882', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '山本南', 'ヤマモトミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市山本中', '28', '28214', '6650883', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '山本中', 'ヤマモトナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市山本西', '28', '28214', '6650884', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '山本西', 'ヤマモトニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市山本台', '28', '28214', '6650885', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '山本台', 'ヤマモトダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市山手台西', '28', '28214', '6650886', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '山手台西', 'ヤマテダイニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市山手台東', '28', '28214', '6650887', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '山手台東', 'ヤマテダイヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川西市満願寺町', '28', '28217', '6650891', '兵庫県', 'ヒョウゴケン', '川西市', 'カワニシシ', '満願寺町', 'マンガンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川西市', '28', '28217', '6660000', '兵庫県', 'ヒョウゴケン', '川西市', 'カワニシシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('79317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川西市鴬の森町', '28', '28217', '6660001', '兵庫県', 'ヒョウゴケン', '川西市', 'カワニシシ', '鴬の森町', 'ウグイスノモリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川西市滝山町', '28', '28217', '6660002', '兵庫県', 'ヒョウゴケン', '川西市', 'カワニシシ', '滝山町', 'タキヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川西市丸の内町', '28', '28217', '6660003', '兵庫県', 'ヒョウゴケン', '川西市', 'カワニシシ', '丸の内町', 'マルノウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川西市萩原', '28', '28217', '6660004', '兵庫県', 'ヒョウゴケン', '川西市', 'カワニシシ', '萩原', 'ハギハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川西市萩原台東', '28', '28217', '6660005', '兵庫県', 'ヒョウゴケン', '川西市', 'カワニシシ', '萩原台東', 'ハギハラダイヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川西市萩原台西1丁目', '28', '28217', '6660006', '兵庫県', 'ヒョウゴケン', '川西市', 'カワニシシ', '萩原台西', 'ハギハラダイニシ', null, null, '1丁目', '01チョウメ');
INSERT INTO `ms_addresses` VALUES ('79323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川西市萩原台西2丁目', '28', '28217', '6660006', '兵庫県', 'ヒョウゴケン', '川西市', 'カワニシシ', '萩原台西', 'ハギハラダイニシ', null, null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('79324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川西市萩原台西3丁目', '28', '28217', '6660006', '兵庫県', 'ヒョウゴケン', '川西市', 'カワニシシ', '萩原台西', 'ハギハラダイニシ', null, null, '3丁目', '03チョウメ');
INSERT INTO `ms_addresses` VALUES ('79325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川西市鴬が丘', '28', '28217', '6660007', '兵庫県', 'ヒョウゴケン', '川西市', 'カワニシシ', '鴬が丘', 'ウグイスガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川西市出在家町', '28', '28217', '6660011', '兵庫県', 'ヒョウゴケン', '川西市', 'カワニシシ', '出在家町', 'デザイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川西市絹延町', '28', '28217', '6660012', '兵庫県', 'ヒョウゴケン', '川西市', 'カワニシシ', '絹延町', 'キヌノベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川西市美園町', '28', '28217', '6660013', '兵庫県', 'ヒョウゴケン', '川西市', 'カワニシシ', '美園町', 'ミソノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川西市小戸', '28', '28217', '6660014', '兵庫県', 'ヒョウゴケン', '川西市', 'カワニシシ', '小戸', 'オオベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川西市小花', '28', '28217', '6660015', '兵庫県', 'ヒョウゴケン', '川西市', 'カワニシシ', '小花', 'オバナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川西市中央町', '28', '28217', '6660016', '兵庫県', 'ヒョウゴケン', '川西市', 'カワニシシ', '中央町', 'チュウオウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川西市火打', '28', '28217', '6660017', '兵庫県', 'ヒョウゴケン', '川西市', 'カワニシシ', '火打', 'ヒウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川西市栄根', '28', '28217', '6660021', '兵庫県', 'ヒョウゴケン', '川西市', 'カワニシシ', '栄根', 'サカネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川西市下加茂', '28', '28217', '6660022', '兵庫県', 'ヒョウゴケン', '川西市', 'カワニシシ', '下加茂', 'シタカモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川西市東久代', '28', '28217', '6660023', '兵庫県', 'ヒョウゴケン', '川西市', 'カワニシシ', '東久代', 'ヒガシクシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川西市久代', '28', '28217', '6660024', '兵庫県', 'ヒョウゴケン', '川西市', 'カワニシシ', '久代', 'クシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川西市加茂', '28', '28217', '6660025', '兵庫県', 'ヒョウゴケン', '川西市', 'カワニシシ', '加茂', 'カモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川西市南花屋敷', '28', '28217', '6660026', '兵庫県', 'ヒョウゴケン', '川西市', 'カワニシシ', '南花屋敷', 'ミナミハナヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川西市霞ケ丘', '28', '28217', '6660031', '兵庫県', 'ヒョウゴケン', '川西市', 'カワニシシ', '霞ケ丘', 'カスミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川西市日高町', '28', '28217', '6660032', '兵庫県', 'ヒョウゴケン', '川西市', 'カワニシシ', '日高町', 'ヒダカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川西市栄町', '28', '28217', '6660033', '兵庫県', 'ヒョウゴケン', '川西市', 'カワニシシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川西市寺畑', '28', '28217', '6660034', '兵庫県', 'ヒョウゴケン', '川西市', 'カワニシシ', '寺畑', 'テラハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川西市花屋敷', '28', '28217', '6660035', '兵庫県', 'ヒョウゴケン', '川西市', 'カワニシシ', '花屋敷', 'ハナヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川西市花屋敷山手町', '28', '28217', '6660036', '兵庫県', 'ヒョウゴケン', '川西市', 'カワニシシ', '花屋敷山手町', 'ハナヤシキヤマテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川西市松が丘町', '28', '28217', '6660037', '兵庫県', 'ヒョウゴケン', '川西市', 'カワニシシ', '松が丘町', 'マツガオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川西市黒川', '28', '28217', '6660101', '兵庫県', 'ヒョウゴケン', '川西市', 'カワニシシ', '黒川', 'クロカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川西市横路', '28', '28217', '6660102', '兵庫県', 'ヒョウゴケン', '川西市', 'カワニシシ', '横路', 'ヨコジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川西市国崎', '28', '28217', '6660103', '兵庫県', 'ヒョウゴケン', '川西市', 'カワニシシ', '国崎', 'クニサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川西市笹部', '28', '28217', '6660104', '兵庫県', 'ヒョウゴケン', '川西市', 'カワニシシ', '笹部', 'ササベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川西市見野', '28', '28217', '6660105', '兵庫県', 'ヒョウゴケン', '川西市', 'カワニシシ', '見野', 'ミノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川西市山下町', '28', '28217', '6660106', '兵庫県', 'ヒョウゴケン', '川西市', 'カワニシシ', '山下町', 'ヤマシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川西市下財町', '28', '28217', '6660107', '兵庫県', 'ヒョウゴケン', '川西市', 'カワニシシ', '下財町', 'ゲザイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川西市大和東', '28', '28217', '6660111', '兵庫県', 'ヒョウゴケン', '川西市', 'カワニシシ', '大和東', 'ダイワヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川西市大和西', '28', '28217', '6660112', '兵庫県', 'ヒョウゴケン', '川西市', 'カワニシシ', '大和西', 'ダイワニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川西市長尾町', '28', '28217', '6660113', '兵庫県', 'ヒョウゴケン', '川西市', 'カワニシシ', '長尾町', 'ナガオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川西市東畦野山手', '28', '28217', '6660114', '兵庫県', 'ヒョウゴケン', '川西市', 'カワニシシ', '東畦野山手', 'ヒガシウネノヤマテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川西市向陽台', '28', '28217', '6660115', '兵庫県', 'ヒョウゴケン', '川西市', 'カワニシシ', '向陽台', 'コウヨウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川西市水明台', '28', '28217', '6660116', '兵庫県', 'ヒョウゴケン', '川西市', 'カワニシシ', '水明台', 'スイメイダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川西市東畦野', '28', '28217', '6660117', '兵庫県', 'ヒョウゴケン', '川西市', 'カワニシシ', '東畦野', 'ヒガシウネノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川西市平野', '28', '28217', '6660121', '兵庫県', 'ヒョウゴケン', '川西市', 'カワニシシ', '平野', 'ヒラノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川西市東多田', '28', '28217', '6660122', '兵庫県', 'ヒョウゴケン', '川西市', 'カワニシシ', '東多田', 'ヒガシタダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川西市鼓が滝', '28', '28217', '6660123', '兵庫県', 'ヒョウゴケン', '川西市', 'カワニシシ', '鼓が滝', 'ツツミガタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川西市多田桜木', '28', '28217', '6660124', '兵庫県', 'ヒョウゴケン', '川西市', 'カワニシシ', '多田桜木', 'タダサクラギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川西市新田', '28', '28217', '6660125', '兵庫県', 'ヒョウゴケン', '川西市', 'カワニシシ', '新田', 'シンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川西市多田院', '28', '28217', '6660126', '兵庫県', 'ヒョウゴケン', '川西市', 'カワニシシ', '多田院', 'タダイン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川西市多田院多田所町', '28', '28217', '6660127', '兵庫県', 'ヒョウゴケン', '川西市', 'カワニシシ', '多田院多田所町', 'タダインタダドコロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川西市多田院西', '28', '28217', '6660128', '兵庫県', 'ヒョウゴケン', '川西市', 'カワニシシ', '多田院西', 'タダインニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川西市緑台', '28', '28217', '6660129', '兵庫県', 'ヒョウゴケン', '川西市', 'カワニシシ', '緑台', 'ミドリダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川西市矢問', '28', '28217', '6660131', '兵庫県', 'ヒョウゴケン', '川西市', 'カワニシシ', '矢問', 'ヤトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川西市矢問東町', '28', '28217', '6660132', '兵庫県', 'ヒョウゴケン', '川西市', 'カワニシシ', '矢問東町', 'ヤトウヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川西市鴬台', '28', '28217', '6660133', '兵庫県', 'ヒョウゴケン', '川西市', 'カワニシシ', '鴬台', 'ウグイスダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川西市萩原台西3丁目', '28', '28217', '6660134', '兵庫県', 'ヒョウゴケン', '川西市', 'カワニシシ', '萩原台西', 'ハギハラダイニシ', null, null, '3丁目', '03チョウメ');
INSERT INTO `ms_addresses` VALUES ('79373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川西市錦松台', '28', '28217', '6660135', '兵庫県', 'ヒョウゴケン', '川西市', 'カワニシシ', '錦松台', 'キンショウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川西市南野坂', '28', '28217', '6660136', '兵庫県', 'ヒョウゴケン', '川西市', 'カワニシシ', '南野坂', 'ミナミノサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川西市湯山台', '28', '28217', '6660137', '兵庫県', 'ヒョウゴケン', '川西市', 'カワニシシ', '湯山台', 'ユヤマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川西市西多田', '28', '28217', '6660138', '兵庫県', 'ヒョウゴケン', '川西市', 'カワニシシ', '西多田', 'ニシタダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川西市虫生', '28', '28217', '6660141', '兵庫県', 'ヒョウゴケン', '川西市', 'カワニシシ', '虫生', 'ムシュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川西市清和台東', '28', '28217', '6660142', '兵庫県', 'ヒョウゴケン', '川西市', 'カワニシシ', '清和台東', 'セイワダイヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川西市清和台西', '28', '28217', '6660143', '兵庫県', 'ヒョウゴケン', '川西市', 'カワニシシ', '清和台西', 'セイワダイニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川西市柳谷', '28', '28217', '6660144', '兵庫県', 'ヒョウゴケン', '川西市', 'カワニシシ', '柳谷', 'ヤナギタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川西市けやき坂', '28', '28217', '6660145', '兵庫県', 'ヒョウゴケン', '川西市', 'カワニシシ', 'けやき坂', 'ケヤキザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川西市芋生', '28', '28217', '6660146', '兵庫県', 'ヒョウゴケン', '川西市', 'カワニシシ', '芋生', 'イモオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川西市若宮', '28', '28217', '6660147', '兵庫県', 'ヒョウゴケン', '川西市', 'カワニシシ', '若宮', 'ワカミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川西市赤松', '28', '28217', '6660148', '兵庫県', 'ヒョウゴケン', '川西市', 'カワニシシ', '赤松', 'アカマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川西市美山台', '28', '28217', '6660151', '兵庫県', 'ヒョウゴケン', '川西市', 'カワニシシ', '美山台', 'ミヤマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川西市丸山台', '28', '28217', '6660152', '兵庫県', 'ヒョウゴケン', '川西市', 'カワニシシ', '丸山台', 'マルヤマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川西市一庫', '28', '28217', '6660153', '兵庫県', 'ヒョウゴケン', '川西市', 'カワニシシ', '一庫', 'ヒトクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川西市山原', '28', '28217', '6660154', '兵庫県', 'ヒョウゴケン', '川西市', 'カワニシシ', '山原', 'ヤマハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川西市西畦野', '28', '28217', '6660155', '兵庫県', 'ヒョウゴケン', '川西市', 'カワニシシ', '西畦野', 'ニシウネノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川西市石道', '28', '28217', '6660156', '兵庫県', 'ヒョウゴケン', '川西市', 'カワニシシ', '石道', 'イシミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川西市緑が丘', '28', '28217', '6660157', '兵庫県', 'ヒョウゴケン', '川西市', 'カワニシシ', '緑が丘', 'ミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川西市清流台', '28', '28217', '6660158', '兵庫県', 'ヒョウゴケン', '川西市', 'カワニシシ', '清流台', 'セイリュウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市切畑長尾山', '28', '28214', '6660161', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '切畑', 'キリハタ', null, null, '長尾山', 'ナガオサン');
INSERT INTO `ms_addresses` VALUES ('79394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川辺郡猪名川町', '28', '28301', '6660200', '兵庫県', 'ヒョウゴケン', '川辺郡猪名川町', 'カワベグンイナガワチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('79395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川辺郡猪名川町杉生', '28', '28301', '6660201', '兵庫県', 'ヒョウゴケン', '川辺郡猪名川町', 'カワベグンイナガワチョウ', '杉生', 'スギオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川辺郡猪名川町鎌倉', '28', '28301', '6660202', '兵庫県', 'ヒョウゴケン', '川辺郡猪名川町', 'カワベグンイナガワチョウ', '鎌倉', 'カマクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川辺郡猪名川町西畑', '28', '28301', '6660203', '兵庫県', 'ヒョウゴケン', '川辺郡猪名川町', 'カワベグンイナガワチョウ', '西畑', 'ニシハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川辺郡猪名川町柏原', '28', '28301', '6660204', '兵庫県', 'ヒョウゴケン', '川辺郡猪名川町', 'カワベグンイナガワチョウ', '柏原', 'カシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川辺郡猪名川町仁頂寺', '28', '28301', '6660211', '兵庫県', 'ヒョウゴケン', '川辺郡猪名川町', 'カワベグンイナガワチョウ', '仁頂寺', 'ニジョウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川辺郡猪名川町旭ケ丘', '28', '28301', '6660212', '兵庫県', 'ヒョウゴケン', '川辺郡猪名川町', 'カワベグンイナガワチョウ', '旭ケ丘', 'アサヒガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川辺郡猪名川町清水東', '28', '28301', '6660213', '兵庫県', 'ヒョウゴケン', '川辺郡猪名川町', 'カワベグンイナガワチョウ', '清水東', 'シミズヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川辺郡猪名川町清水', '28', '28301', '6660214', '兵庫県', 'ヒョウゴケン', '川辺郡猪名川町', 'カワベグンイナガワチョウ', '清水', 'シミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川辺郡猪名川町島', '28', '28301', '6660215', '兵庫県', 'ヒョウゴケン', '川辺郡猪名川町', 'カワベグンイナガワチョウ', '島', 'シマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川辺郡猪名川町杤原', '28', '28301', '6660221', '兵庫県', 'ヒョウゴケン', '川辺郡猪名川町', 'カワベグンイナガワチョウ', '杤原', 'トチハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川辺郡猪名川町槻並', '28', '28301', '6660222', '兵庫県', 'ヒョウゴケン', '川辺郡猪名川町', 'カワベグンイナガワチョウ', '槻並', 'ツクナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川辺郡猪名川町木間生', '28', '28301', '6660223', '兵庫県', 'ヒョウゴケン', '川辺郡猪名川町', 'カワベグンイナガワチョウ', '木間生', 'コモオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川辺郡猪名川町万善', '28', '28301', '6660224', '兵庫県', 'ヒョウゴケン', '川辺郡猪名川町', 'カワベグンイナガワチョウ', '万善', 'マンゼン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川辺郡猪名川町木津', '28', '28301', '6660225', '兵庫県', 'ヒョウゴケン', '川辺郡猪名川町', 'カワベグンイナガワチョウ', '木津', 'キヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川辺郡猪名川町林田', '28', '28301', '6660226', '兵庫県', 'ヒョウゴケン', '川辺郡猪名川町', 'カワベグンイナガワチョウ', '林田', 'ハヤシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川辺郡猪名川町笹尾', '28', '28301', '6660227', '兵庫県', 'ヒョウゴケン', '川辺郡猪名川町', 'カワベグンイナガワチョウ', '笹尾', 'ササオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川辺郡猪名川町上阿古谷', '28', '28301', '6660231', '兵庫県', 'ヒョウゴケン', '川辺郡猪名川町', 'カワベグンイナガワチョウ', '上阿古谷', 'カミアコタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川辺郡猪名川町民田', '28', '28301', '6660232', '兵庫県', 'ヒョウゴケン', '川辺郡猪名川町', 'カワベグンイナガワチョウ', '民田', 'タミダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川辺郡猪名川町紫合', '28', '28301', '6660233', '兵庫県', 'ヒョウゴケン', '川辺郡猪名川町', 'カワベグンイナガワチョウ', '紫合', 'ユウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川辺郡猪名川町北野', '28', '28301', '6660234', '兵庫県', 'ヒョウゴケン', '川辺郡猪名川町', 'カワベグンイナガワチョウ', '北野', 'キタノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川辺郡猪名川町南田原', '28', '28301', '6660235', '兵庫県', 'ヒョウゴケン', '川辺郡猪名川町', 'カワベグンイナガワチョウ', '南田原', 'ミナミタハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川辺郡猪名川町北田原', '28', '28301', '6660236', '兵庫県', 'ヒョウゴケン', '川辺郡猪名川町', 'カワベグンイナガワチョウ', '北田原', 'キタタハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川辺郡猪名川町下阿古谷', '28', '28301', '6660237', '兵庫県', 'ヒョウゴケン', '川辺郡猪名川町', 'カワベグンイナガワチョウ', '下阿古谷', 'シモアコタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川辺郡猪名川町内馬場', '28', '28301', '6660241', '兵庫県', 'ヒョウゴケン', '川辺郡猪名川町', 'カワベグンイナガワチョウ', '内馬場', 'ウチババ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川辺郡猪名川町原', '28', '28301', '6660242', '兵庫県', 'ヒョウゴケン', '川辺郡猪名川町', 'カワベグンイナガワチョウ', '原', 'ハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川辺郡猪名川町柏梨田', '28', '28301', '6660243', '兵庫県', 'ヒョウゴケン', '川辺郡猪名川町', 'カワベグンイナガワチョウ', '柏梨田', 'カシウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川辺郡猪名川町上野', '28', '28301', '6660244', '兵庫県', 'ヒョウゴケン', '川辺郡猪名川町', 'カワベグンイナガワチョウ', '上野', 'ウエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川辺郡猪名川町つつじが丘', '28', '28301', '6660245', '兵庫県', 'ヒョウゴケン', '川辺郡猪名川町', 'カワベグンイナガワチョウ', 'つつじが丘', 'ツツジガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川辺郡猪名川町猪名川台', '28', '28301', '6660246', '兵庫県', 'ヒョウゴケン', '川辺郡猪名川町', 'カワベグンイナガワチョウ', '猪名川台', 'イナガワダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川辺郡猪名川町若葉', '28', '28301', '6660251', '兵庫県', 'ヒョウゴケン', '川辺郡猪名川町', 'カワベグンイナガワチョウ', '若葉', 'ワカバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川辺郡猪名川町広根', '28', '28301', '6660252', '兵庫県', 'ヒョウゴケン', '川辺郡猪名川町', 'カワベグンイナガワチョウ', '広根', 'ヒロネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川辺郡猪名川町差組', '28', '28301', '6660253', '兵庫県', 'ヒョウゴケン', '川辺郡猪名川町', 'カワベグンイナガワチョウ', '差組', 'サシクミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川辺郡猪名川町肝川', '28', '28301', '6660254', '兵庫県', 'ヒョウゴケン', '川辺郡猪名川町', 'カワベグンイナガワチョウ', '肝川', 'キモカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川辺郡猪名川町猪渕', '28', '28301', '6660255', '兵庫県', 'ヒョウゴケン', '川辺郡猪名川町', 'カワベグンイナガワチョウ', '猪渕', 'イブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川辺郡猪名川町銀山', '28', '28301', '6660256', '兵庫県', 'ヒョウゴケン', '川辺郡猪名川町', 'カワベグンイナガワチョウ', '銀山', 'ギンザン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川辺郡猪名川町白金', '28', '28301', '6660257', '兵庫県', 'ヒョウゴケン', '川辺郡猪名川町', 'カワベグンイナガワチョウ', '白金', 'シロガネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川辺郡猪名川町松尾台', '28', '28301', '6660261', '兵庫県', 'ヒョウゴケン', '川辺郡猪名川町', 'カワベグンイナガワチョウ', '松尾台', 'マツオダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県川辺郡猪名川町伏見台', '28', '28301', '6660262', '兵庫県', 'ヒョウゴケン', '川辺郡猪名川町', 'カワベグンイナガワチョウ', '伏見台', 'フシミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県養父市', '28', '28222', '6670000', '兵庫県', 'ヒョウゴケン', '養父市', 'ヤブシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('79436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県養父市八鹿町青山', '28', '28222', '6670001', '兵庫県', 'ヒョウゴケン', '養父市', 'ヤブシ', '八鹿町青山', 'ヨウカチョウアオヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県養父市八鹿町三谷', '28', '28222', '6670002', '兵庫県', 'ヒョウゴケン', '養父市', 'ヤブシ', '八鹿町三谷', 'ヨウカチョウミタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県養父市八鹿町宿南', '28', '28222', '6670003', '兵庫県', 'ヒョウゴケン', '養父市', 'ヤブシ', '八鹿町宿南', 'ヨウカチョウシュクナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県養父市八鹿町上小田', '28', '28222', '6670004', '兵庫県', 'ヒョウゴケン', '養父市', 'ヤブシ', '八鹿町上小田', 'ヨウカチョウカミオダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県養父市八鹿町下小田', '28', '28222', '6670005', '兵庫県', 'ヒョウゴケン', '養父市', 'ヤブシ', '八鹿町下小田', 'ヨウカチョウシモオダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県養父市八鹿町浅間', '28', '28222', '6670011', '兵庫県', 'ヒョウゴケン', '養父市', 'ヤブシ', '八鹿町浅間', 'ヨウカチョウアサマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県養父市八鹿町伊佐', '28', '28222', '6670012', '兵庫県', 'ヒョウゴケン', '養父市', 'ヤブシ', '八鹿町伊佐', 'ヨウカチョウイザ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県養父市八鹿町坂本', '28', '28222', '6670013', '兵庫県', 'ヒョウゴケン', '養父市', 'ヤブシ', '八鹿町坂本', 'ヨウカチョウサカモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県養父市八鹿町岩崎', '28', '28222', '6670014', '兵庫県', 'ヒョウゴケン', '養父市', 'ヤブシ', '八鹿町岩崎', 'ヨウカチョウイワサイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県養父市八鹿町大江', '28', '28222', '6670015', '兵庫県', 'ヒョウゴケン', '養父市', 'ヤブシ', '八鹿町大江', 'ヨウカチョウオオエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県養父市八鹿町舞狂', '28', '28222', '6670016', '兵庫県', 'ヒョウゴケン', '養父市', 'ヤブシ', '八鹿町舞狂', 'ヨウカチョウブキョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県養父市八鹿町八鹿', '28', '28222', '6670021', '兵庫県', 'ヒョウゴケン', '養父市', 'ヤブシ', '八鹿町八鹿', 'ヨウカチョウヨウカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県養父市八鹿町下網場', '28', '28222', '6670022', '兵庫県', 'ヒョウゴケン', '養父市', 'ヤブシ', '八鹿町下網場', 'ヨウカチョウシモナンバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県養父市八鹿町上網場', '28', '28222', '6670023', '兵庫県', 'ヒョウゴケン', '養父市', 'ヤブシ', '八鹿町上網場', 'ヨウカチョウカミナンバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県養父市八鹿町朝倉', '28', '28222', '6670024', '兵庫県', 'ヒョウゴケン', '養父市', 'ヤブシ', '八鹿町朝倉', 'ヨウカチョウアサクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県養父市八鹿町九鹿', '28', '28222', '6670031', '兵庫県', 'ヒョウゴケン', '養父市', 'ヤブシ', '八鹿町九鹿', 'ヨウカチョウクロク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県養父市八鹿町小山', '28', '28222', '6670032', '兵庫県', 'ヒョウゴケン', '養父市', 'ヤブシ', '八鹿町小山', 'ヨウカチョウコヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県養父市八鹿町八木', '28', '28222', '6670041', '兵庫県', 'ヒョウゴケン', '養父市', 'ヤブシ', '八鹿町八木', 'ヨウカチョウヤギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県養父市八鹿町今滝寺', '28', '28222', '6670042', '兵庫県', 'ヒョウゴケン', '養父市', 'ヤブシ', '八鹿町今滝寺', 'ヨウカチョウコンリュウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県養父市八鹿町高柳', '28', '28222', '6670043', '兵庫県', 'ヒョウゴケン', '養父市', 'ヤブシ', '八鹿町高柳', 'ヨウカチョウタカヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県養父市八鹿町国木', '28', '28222', '6670044', '兵庫県', 'ヒョウゴケン', '養父市', 'ヤブシ', '八鹿町国木', 'ヨウカチョウクヌギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県養父市八鹿町米里', '28', '28222', '6670045', '兵庫県', 'ヒョウゴケン', '養父市', 'ヤブシ', '八鹿町米里', 'ヨウカチョウメイリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県養父市八鹿町石原', '28', '28222', '6670051', '兵庫県', 'ヒョウゴケン', '養父市', 'ヤブシ', '八鹿町石原', 'ヨウカチョウイシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県養父市八鹿町日畑', '28', '28222', '6670052', '兵庫県', 'ヒョウゴケン', '養父市', 'ヤブシ', '八鹿町日畑', 'ヨウカチョウヒバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県養父市八鹿町小佐', '28', '28222', '6670053', '兵庫県', 'ヒョウゴケン', '養父市', 'ヤブシ', '八鹿町小佐', 'ヨウカチョウオサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県養父市広谷', '28', '28222', '6670101', '兵庫県', 'ヒョウゴケン', '養父市', 'ヤブシ', '広谷', 'ヒロタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県養父市十二所', '28', '28222', '6670102', '兵庫県', 'ヒョウゴケン', '養父市', 'ヤブシ', '十二所', 'ジュウニショ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県養父市浅野', '28', '28222', '6670103', '兵庫県', 'ヒョウゴケン', '養父市', 'ヤブシ', '浅野', 'アザノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県養父市伊豆', '28', '28222', '6670104', '兵庫県', 'ヒョウゴケン', '養父市', 'ヤブシ', '伊豆', 'イズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県養父市左近山', '28', '28222', '6670105', '兵庫県', 'ヒョウゴケン', '養父市', 'ヤブシ', '左近山', 'サコヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県養父市玉見', '28', '28222', '6670106', '兵庫県', 'ヒョウゴケン', '養父市', 'ヤブシ', '玉見', 'タマミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県養父市新津', '28', '28222', '6670107', '兵庫県', 'ヒョウゴケン', '養父市', 'ヤブシ', '新津', 'シンヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県養父市大薮', '28', '28222', '6670111', '兵庫県', 'ヒョウゴケン', '養父市', 'ヤブシ', '大薮', 'オオヤブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県養父市養父市場', '28', '28222', '6670112', '兵庫県', 'ヒョウゴケン', '養父市', 'ヤブシ', '養父市場', 'ヤブイチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県養父市薮崎', '28', '28222', '6670113', '兵庫県', 'ヒョウゴケン', '養父市', 'ヤブシ', '薮崎', 'ヤブサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県養父市小城', '28', '28222', '6670114', '兵庫県', 'ヒョウゴケン', '養父市', 'ヤブシ', '小城', 'コジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県養父市上箇', '28', '28222', '6670115', '兵庫県', 'ヒョウゴケン', '養父市', 'ヤブシ', '上箇', 'アゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県養父市奥米地', '28', '28222', '6670121', '兵庫県', 'ヒョウゴケン', '養父市', 'ヤブシ', '奥米地', 'オクメイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県養父市中米地', '28', '28222', '6670122', '兵庫県', 'ヒョウゴケン', '養父市', 'ヤブシ', '中米地', 'ナカメイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県養父市鉄屋米地', '28', '28222', '6670123', '兵庫県', 'ヒョウゴケン', '養父市', 'ヤブシ', '鉄屋米地', 'カナヤメイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県養父市口米地', '28', '28222', '6670124', '兵庫県', 'ヒョウゴケン', '養父市', 'ヤブシ', '口米地', 'クチメイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県養父市大塚', '28', '28222', '6670125', '兵庫県', 'ヒョウゴケン', '養父市', 'ヤブシ', '大塚', 'オオツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県養父市堀畑', '28', '28222', '6670126', '兵庫県', 'ヒョウゴケン', '養父市', 'ヤブシ', '堀畑', 'ホリハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県養父市上野', '28', '28222', '6670131', '兵庫県', 'ヒョウゴケン', '養父市', 'ヤブシ', '上野', 'ウエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県養父市稲津', '28', '28222', '6670132', '兵庫県', 'ヒョウゴケン', '養父市', 'ヤブシ', '稲津', 'イナヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県養父市畑', '28', '28222', '6670133', '兵庫県', 'ヒョウゴケン', '養父市', 'ヤブシ', '畑', 'ハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県養父市大坪', '28', '28222', '6670134', '兵庫県', 'ヒョウゴケン', '養父市', 'ヤブシ', '大坪', 'オオツボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県養父市船谷', '28', '28222', '6670135', '兵庫県', 'ヒョウゴケン', '養父市', 'ヤブシ', '船谷', 'フネダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県養父市三谷', '28', '28222', '6670136', '兵庫県', 'ヒョウゴケン', '養父市', 'ヤブシ', '三谷', 'ミタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県養父市森', '28', '28222', '6670141', '兵庫県', 'ヒョウゴケン', '養父市', 'ヤブシ', '森', 'モリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県養父市建屋', '28', '28222', '6670142', '兵庫県', 'ヒョウゴケン', '養父市', 'ヤブシ', '建屋', 'タキノヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県養父市能座', '28', '28222', '6670143', '兵庫県', 'ヒョウゴケン', '養父市', 'ヤブシ', '能座', 'ノウザ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県養父市餅耕地', '28', '28222', '6670144', '兵庫県', 'ヒョウゴケン', '養父市', 'ヤブシ', '餅耕地', 'モチゴウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県養父市長野', '28', '28222', '6670145', '兵庫県', 'ヒョウゴケン', '養父市', 'ヤブシ', '長野', 'ナガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県養父市大屋町上山', '28', '28222', '6670301', '兵庫県', 'ヒョウゴケン', '養父市', 'ヤブシ', '大屋町上山', 'オオヤチョウウヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県養父市大屋町樽見', '28', '28222', '6670302', '兵庫県', 'ヒョウゴケン', '養父市', 'ヤブシ', '大屋町樽見', 'オオヤチョウタルミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県養父市大屋町おうみ', '28', '28222', '6670303', '兵庫県', 'ヒョウゴケン', '養父市', 'ヤブシ', '大屋町おうみ', 'オオヤチョウオウミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県養父市大屋町中', '28', '28222', '6670304', '兵庫県', 'ヒョウゴケン', '養父市', 'ヤブシ', '大屋町中', 'オオヤチョウナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県養父市大屋町由良', '28', '28222', '6670304', '兵庫県', 'ヒョウゴケン', '養父市', 'ヤブシ', '大屋町由良', 'オオヤチョウユラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県養父市大屋町夏梅', '28', '28222', '6670305', '兵庫県', 'ヒョウゴケン', '養父市', 'ヤブシ', '大屋町夏梅', 'オオヤチョウナツメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県養父市大屋町宮垣', '28', '28222', '6670306', '兵庫県', 'ヒョウゴケン', '養父市', 'ヤブシ', '大屋町宮垣', 'オオヤチョウミヤガキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県養父市大屋町大屋市場', '28', '28222', '6670311', '兵庫県', 'ヒョウゴケン', '養父市', 'ヤブシ', '大屋町大屋市場', 'オオヤチョウオオヤイチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県養父市大屋町山路', '28', '28222', '6670312', '兵庫県', 'ヒョウゴケン', '養父市', 'ヤブシ', '大屋町山路', 'オオヤチョウヤマジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県養父市大屋町笠谷', '28', '28222', '6670313', '兵庫県', 'ヒョウゴケン', '養父市', 'ヤブシ', '大屋町笠谷', 'オオヤチョウカサダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県養父市大屋町大杉', '28', '28222', '6670314', '兵庫県', 'ヒョウゴケン', '養父市', 'ヤブシ', '大屋町大杉', 'オオヤチョウオオスギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県養父市大屋町加保', '28', '28222', '6670315', '兵庫県', 'ヒョウゴケン', '養父市', 'ヤブシ', '大屋町加保', 'オオヤチョウカボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県養父市大屋町蔵垣', '28', '28222', '6670321', '兵庫県', 'ヒョウゴケン', '養父市', 'ヤブシ', '大屋町蔵垣', 'オオヤチョウクラガキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県養父市大屋町筏', '28', '28222', '6670322', '兵庫県', 'ヒョウゴケン', '養父市', 'ヤブシ', '大屋町筏', 'オオヤチョウイカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県養父市大屋町若杉', '28', '28222', '6670323', '兵庫県', 'ヒョウゴケン', '養父市', 'ヤブシ', '大屋町若杉', 'オオヤチョウワカス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県養父市大屋町横行', '28', '28222', '6670324', '兵庫県', 'ヒョウゴケン', '養父市', 'ヤブシ', '大屋町横行', 'オオヤチョウヨコイキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県養父市大屋町栗ノ下', '28', '28222', '6670325', '兵庫県', 'ヒョウゴケン', '養父市', 'ヤブシ', '大屋町栗ノ下', 'オオヤチョウクリノシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県養父市大屋町中間', '28', '28222', '6670325', '兵庫県', 'ヒョウゴケン', '養父市', 'ヤブシ', '大屋町中間', 'オオヤチョウナカマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県養父市大屋町糸原', '28', '28222', '6670431', '兵庫県', 'ヒョウゴケン', '養父市', 'ヤブシ', '大屋町糸原', 'オオヤチョウイトワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県養父市大屋町宮本', '28', '28222', '6670432', '兵庫県', 'ヒョウゴケン', '養父市', 'ヤブシ', '大屋町宮本', 'オオヤチョウミヤモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県養父市大屋町門野', '28', '28222', '6670433', '兵庫県', 'ヒョウゴケン', '養父市', 'ヤブシ', '大屋町門野', 'オオヤチョウカドノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県養父市大屋町須西', '28', '28222', '6670434', '兵庫県', 'ヒョウゴケン', '養父市', 'ヤブシ', '大屋町須西', 'オオヤチョウスサイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県養父市大屋町和田', '28', '28222', '6670435', '兵庫県', 'ヒョウゴケン', '養父市', 'ヤブシ', '大屋町和田', 'オオヤチョウワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県養父市大屋町明延', '28', '28222', '6670436', '兵庫県', 'ヒョウゴケン', '養父市', 'ヤブシ', '大屋町明延', 'オオヤチョウアケノベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県養父市三宅', '28', '28222', '6671101', '兵庫県', 'ヒョウゴケン', '養父市', 'ヤブシ', '三宅', 'ミヤケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県養父市大谷', '28', '28222', '6671102', '兵庫県', 'ヒョウゴケン', '養父市', 'ヤブシ', '大谷', 'オオタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県養父市万久里', '28', '28222', '6671103', '兵庫県', 'ヒョウゴケン', '養父市', 'ヤブシ', '万久里', 'マクリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県養父市尾崎', '28', '28222', '6671104', '兵庫県', 'ヒョウゴケン', '養父市', 'ヤブシ', '尾崎', 'オサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県養父市関宮', '28', '28222', '6671105', '兵庫県', 'ヒョウゴケン', '養父市', 'ヤブシ', '関宮', 'セキノミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県養父市吉井', '28', '28222', '6671111', '兵庫県', 'ヒョウゴケン', '養父市', 'ヤブシ', '吉井', 'ヨシイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県養父市出合', '28', '28222', '6671112', '兵庫県', 'ヒョウゴケン', '養父市', 'ヤブシ', '出合', 'デアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県養父市川原場', '28', '28222', '6671113', '兵庫県', 'ヒョウゴケン', '養父市', 'ヤブシ', '川原場', 'カワラバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県養父市小路頃', '28', '28222', '6671114', '兵庫県', 'ヒョウゴケン', '養父市', 'ヤブシ', '小路頃', 'オジコロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県養父市葛畑', '28', '28222', '6671115', '兵庫県', 'ヒョウゴケン', '養父市', 'ヤブシ', '葛畑', 'カズラハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県養父市中瀬', '28', '28222', '6671116', '兵庫県', 'ヒョウゴケン', '養父市', 'ヤブシ', '中瀬', 'ナカゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県養父市轟', '28', '28222', '6671117', '兵庫県', 'ヒョウゴケン', '養父市', 'ヤブシ', '轟', 'トドロキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県養父市安井', '28', '28222', '6671118', '兵庫県', 'ヒョウゴケン', '養父市', 'ヤブシ', '安井', 'ヤスイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県養父市鵜縄', '28', '28222', '6671119', '兵庫県', 'ヒョウゴケン', '養父市', 'ヤブシ', '鵜縄', 'ウナワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県養父市外野', '28', '28222', '6671121', '兵庫県', 'ヒョウゴケン', '養父市', 'ヤブシ', '外野', 'トノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県養父市草出', '28', '28222', '6671122', '兵庫県', 'ヒョウゴケン', '養父市', 'ヤブシ', '草出', 'クサイデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県養父市梨ケ原', '28', '28222', '6671123', '兵庫県', 'ヒョウゴケン', '養父市', 'ヤブシ', '梨ケ原', 'ナシガハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県養父市丹戸', '28', '28222', '6671124', '兵庫県', 'ヒョウゴケン', '養父市', 'ヤブシ', '丹戸', 'タンド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県養父市奈良尾', '28', '28222', '6671125', '兵庫県', 'ヒョウゴケン', '養父市', 'ヤブシ', '奈良尾', 'ナラオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県養父市福定', '28', '28222', '6671126', '兵庫県', 'ヒョウゴケン', '養父市', 'ヤブシ', '福定', 'フクサダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県養父市大久保', '28', '28222', '6671127', '兵庫県', 'ヒョウゴケン', '養父市', 'ヤブシ', '大久保', 'オオクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県養父市別宮', '28', '28222', '6671128', '兵庫県', 'ヒョウゴケン', '養父市', 'ヤブシ', '別宮', 'ベツクウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡香美町村岡区境', '28', '28585', '6671301', '兵庫県', 'ヒョウゴケン', '美方郡香美町', 'ミカタグンカミチョウ', '村岡区境', 'ムラオカクサカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡香美町村岡区山田', '28', '28585', '6671302', '兵庫県', 'ヒョウゴケン', '美方郡香美町', 'ミカタグンカミチョウ', '村岡区山田', 'ムラオカクヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡香美町村岡区小城', '28', '28585', '6671303', '兵庫県', 'ヒョウゴケン', '美方郡香美町', 'ミカタグンカミチョウ', '村岡区小城', 'ムラオカクコジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡香美町村岡区和佐父', '28', '28585', '6671304', '兵庫県', 'ヒョウゴケン', '美方郡香美町', 'ミカタグンカミチョウ', '村岡区和佐父', 'ムラオカクワサブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡香美町村岡区村岡', '28', '28585', '6671311', '兵庫県', 'ヒョウゴケン', '美方郡香美町', 'ミカタグンカミチョウ', '村岡区村岡', 'ムラオカクムラオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡香美町村岡区相田', '28', '28585', '6671312', '兵庫県', 'ヒョウゴケン', '美方郡香美町', 'ミカタグンカミチョウ', '村岡区相田', 'ムラオカクアイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡香美町村岡区神坂', '28', '28585', '6671313', '兵庫県', 'ヒョウゴケン', '美方郡香美町', 'ミカタグンカミチョウ', '村岡区神坂', 'ムラオカクカンザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡香美町村岡区萩山', '28', '28585', '6671314', '兵庫県', 'ヒョウゴケン', '美方郡香美町', 'ミカタグンカミチョウ', '村岡区萩山', 'ムラオカクハギヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡香美町村岡区板仕野', '28', '28585', '6671315', '兵庫県', 'ヒョウゴケン', '美方郡香美町', 'ミカタグンカミチョウ', '村岡区板仕野', 'ムラオカクイタシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡香美町村岡区鹿田', '28', '28585', '6671316', '兵庫県', 'ヒョウゴケン', '美方郡香美町', 'ミカタグンカミチョウ', '村岡区鹿田', 'ムラオカクシカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡香美町村岡区用野', '28', '28585', '6671317', '兵庫県', 'ヒョウゴケン', '美方郡香美町', 'ミカタグンカミチョウ', '村岡区用野', 'ムラオカクヨウノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡香美町村岡区大糠', '28', '28585', '6671321', '兵庫県', 'ヒョウゴケン', '美方郡香美町', 'ミカタグンカミチョウ', '村岡区大糠', 'ムラオカクオオヌカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡香美町村岡区寺河内', '28', '28585', '6671322', '兵庫県', 'ヒョウゴケン', '美方郡香美町', 'ミカタグンカミチョウ', '村岡区寺河内', 'ムラオカクテラガワウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡香美町村岡区耀山', '28', '28585', '6671323', '兵庫県', 'ヒョウゴケン', '美方郡香美町', 'ミカタグンカミチョウ', '村岡区耀山', 'ムラオカクカカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡香美町村岡区市原', '28', '28585', '6671324', '兵庫県', 'ヒョウゴケン', '美方郡香美町', 'ミカタグンカミチョウ', '村岡区市原', 'ムラオカクイチバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡香美町村岡区高井', '28', '28585', '6671325', '兵庫県', 'ヒョウゴケン', '美方郡香美町', 'ミカタグンカミチョウ', '村岡区高井', 'ムラオカクタカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡香美町村岡区光陽', '28', '28585', '6671326', '兵庫県', 'ヒョウゴケン', '美方郡香美町', 'ミカタグンカミチョウ', '村岡区光陽', 'ムラオカクコウヨウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡香美町村岡区作山', '28', '28585', '6671331', '兵庫県', 'ヒョウゴケン', '美方郡香美町', 'ミカタグンカミチョウ', '村岡区作山', 'ムラオカクツクリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡香美町村岡区八井谷', '28', '28585', '6671332', '兵庫県', 'ヒョウゴケン', '美方郡香美町', 'ミカタグンカミチョウ', '村岡区八井谷', 'ムラオカクヤイダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡香美町村岡区大野', '28', '28585', '6671333', '兵庫県', 'ヒョウゴケン', '美方郡香美町', 'ミカタグンカミチョウ', '村岡区大野', 'ムラオカクオオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡香美町村岡区福岡', '28', '28585', '6671334', '兵庫県', 'ヒョウゴケン', '美方郡香美町', 'ミカタグンカミチョウ', '村岡区福岡', 'ムラオカクフクオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡香美町村岡区黒田', '28', '28585', '6671335', '兵庫県', 'ヒョウゴケン', '美方郡香美町', 'ミカタグンカミチョウ', '村岡区黒田', 'ムラオカククロダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡香美町村岡区宿', '28', '28585', '6671336', '兵庫県', 'ヒョウゴケン', '美方郡香美町', 'ミカタグンカミチョウ', '村岡区宿', 'ムラオカクヤド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡香美町村岡区日影', '28', '28585', '6671337', '兵庫県', 'ヒョウゴケン', '美方郡香美町', 'ミカタグンカミチョウ', '村岡区日影', 'ムラオカクヒカゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡香美町村岡区森脇', '28', '28585', '6671341', '兵庫県', 'ヒョウゴケン', '美方郡香美町', 'ミカタグンカミチョウ', '村岡区森脇', 'ムラオカクモリワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡香美町村岡区口大谷', '28', '28585', '6671342', '兵庫県', 'ヒョウゴケン', '美方郡香美町', 'ミカタグンカミチョウ', '村岡区口大谷', 'ムラオカククチオオタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡香美町村岡区中大谷', '28', '28585', '6671343', '兵庫県', 'ヒョウゴケン', '美方郡香美町', 'ミカタグンカミチョウ', '村岡区中大谷', 'ムラオカクナカオオタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡香美町村岡区大笹', '28', '28585', '6671344', '兵庫県', 'ヒョウゴケン', '美方郡香美町', 'ミカタグンカミチョウ', '村岡区大笹', 'ムラオカクオオササ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡香美町村岡区高坂', '28', '28585', '6671345', '兵庫県', 'ヒョウゴケン', '美方郡香美町', 'ミカタグンカミチョウ', '村岡区高坂', 'ムラオカクタカサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡香美町村岡区池ケ平', '28', '28585', '6671346', '兵庫県', 'ヒョウゴケン', '美方郡香美町', 'ミカタグンカミチョウ', '村岡区池ケ平', 'ムラオカクイケガナル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡香美町村岡区和池', '28', '28585', '6671347', '兵庫県', 'ヒョウゴケン', '美方郡香美町', 'ミカタグンカミチョウ', '村岡区和池', 'ムラオカクワチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡香美町村岡区丸味', '28', '28585', '6671351', '兵庫県', 'ヒョウゴケン', '美方郡香美町', 'ミカタグンカミチョウ', '村岡区丸味', 'ムラオカクマルミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡香美町村岡区長板', '28', '28585', '6671352', '兵庫県', 'ヒョウゴケン', '美方郡香美町', 'ミカタグンカミチョウ', '村岡区長板', 'ムラオカクナガイタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡香美町村岡区熊波', '28', '28585', '6671353', '兵庫県', 'ヒョウゴケン', '美方郡香美町', 'ミカタグンカミチョウ', '村岡区熊波', 'ムラオカククマナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡香美町村岡区柤岡', '28', '28585', '6671354', '兵庫県', 'ヒョウゴケン', '美方郡香美町', 'ミカタグンカミチョウ', '村岡区柤岡', 'ムラオカクケビオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡香美町村岡区長瀬', '28', '28585', '6671361', '兵庫県', 'ヒョウゴケン', '美方郡香美町', 'ミカタグンカミチョウ', '村岡区長瀬', 'ムラオカクナガセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡香美町村岡区原', '28', '28585', '6671362', '兵庫県', 'ヒョウゴケン', '美方郡香美町', 'ミカタグンカミチョウ', '村岡区原', 'ムラオカクハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡香美町村岡区味取', '28', '28585', '6671363', '兵庫県', 'ヒョウゴケン', '美方郡香美町', 'ミカタグンカミチョウ', '村岡区味取', 'ムラオカクミドリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡香美町村岡区長須', '28', '28585', '6671364', '兵庫県', 'ヒョウゴケン', '美方郡香美町', 'ミカタグンカミチョウ', '村岡区長須', 'ムラオカクナガス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡香美町村岡区高津', '28', '28585', '6671365', '兵庫県', 'ヒョウゴケン', '美方郡香美町', 'ミカタグンカミチョウ', '村岡区高津', 'ムラオカクタカヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡香美町村岡区川会', '28', '28585', '6671366', '兵庫県', 'ヒョウゴケン', '美方郡香美町', 'ミカタグンカミチョウ', '村岡区川会', 'ムラオカクカワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡香美町村岡区和田', '28', '28585', '6671367', '兵庫県', 'ヒョウゴケン', '美方郡香美町', 'ミカタグンカミチョウ', '村岡区和田', 'ムラオカクワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡香美町村岡区入江', '28', '28585', '6671368', '兵庫県', 'ヒョウゴケン', '美方郡香美町', 'ミカタグンカミチョウ', '村岡区入江', 'ムラオカクイリエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡香美町小代区久須部', '28', '28585', '6671501', '兵庫県', 'ヒョウゴケン', '美方郡香美町', 'ミカタグンカミチョウ', '小代区久須部', 'オジロククスベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡香美町小代区城山', '28', '28585', '6671502', '兵庫県', 'ヒョウゴケン', '美方郡香美町', 'ミカタグンカミチョウ', '小代区城山', 'オジロクジョウヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡香美町小代区大谷', '28', '28585', '6671503', '兵庫県', 'ヒョウゴケン', '美方郡香美町', 'ミカタグンカミチョウ', '小代区大谷', 'オジロクオオタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡香美町小代区神水', '28', '28585', '6671511', '兵庫県', 'ヒョウゴケン', '美方郡香美町', 'ミカタグンカミチョウ', '小代区神水', 'オジロクカンズイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡香美町小代区石寺', '28', '28585', '6671512', '兵庫県', 'ヒョウゴケン', '美方郡香美町', 'ミカタグンカミチョウ', '小代区石寺', 'オジロクイシデラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡香美町小代区広井', '28', '28585', '6671513', '兵庫県', 'ヒョウゴケン', '美方郡香美町', 'ミカタグンカミチョウ', '小代区広井', 'オジロクヒロイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡香美町小代区神場', '28', '28585', '6671514', '兵庫県', 'ヒョウゴケン', '美方郡香美町', 'ミカタグンカミチョウ', '小代区神場', 'オジロクカンバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡香美町小代区水間', '28', '28585', '6671515', '兵庫県', 'ヒョウゴケン', '美方郡香美町', 'ミカタグンカミチョウ', '小代区水間', 'オジロクミズマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡香美町小代区野間谷', '28', '28585', '6671521', '兵庫県', 'ヒョウゴケン', '美方郡香美町', 'ミカタグンカミチョウ', '小代区野間谷', 'オジロクノマタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡香美町小代区実山', '28', '28585', '6671522', '兵庫県', 'ヒョウゴケン', '美方郡香美町', 'ミカタグンカミチョウ', '小代区実山', 'オジロクサネヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡香美町小代区平野', '28', '28585', '6671523', '兵庫県', 'ヒョウゴケン', '美方郡香美町', 'ミカタグンカミチョウ', '小代区平野', 'オジロクヒラノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡香美町小代区茅野', '28', '28585', '6671531', '兵庫県', 'ヒョウゴケン', '美方郡香美町', 'ミカタグンカミチョウ', '小代区茅野', 'オジロクカヤノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡香美町小代区新屋', '28', '28585', '6671532', '兵庫県', 'ヒョウゴケン', '美方郡香美町', 'ミカタグンカミチョウ', '小代区新屋', 'オジロクニイヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡香美町小代区秋岡', '28', '28585', '6671533', '兵庫県', 'ヒョウゴケン', '美方郡香美町', 'ミカタグンカミチョウ', '小代区秋岡', 'オジロクアキオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡香美町小代区佐坊', '28', '28585', '6671541', '兵庫県', 'ヒョウゴケン', '美方郡香美町', 'ミカタグンカミチョウ', '小代区佐坊', 'オジロクサボウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡香美町小代区鍛治屋', '28', '28585', '6671542', '兵庫県', 'ヒョウゴケン', '美方郡香美町', 'ミカタグンカミチョウ', '小代区鍛治屋', 'オジロクカジヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡香美町小代区忠宮', '28', '28585', '6671543', '兵庫県', 'ヒョウゴケン', '美方郡香美町', 'ミカタグンカミチョウ', '小代区忠宮', 'オジロクタダノミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡香美町小代区貫田', '28', '28585', '6671544', '兵庫県', 'ヒョウゴケン', '美方郡香美町', 'ミカタグンカミチョウ', '小代区貫田', 'オジロクヌキダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡香美町小代区東垣', '28', '28585', '6671545', '兵庫県', 'ヒョウゴケン', '美方郡香美町', 'ミカタグンカミチョウ', '小代区東垣', 'オジロクヒガシガキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市', '28', '28209', '6680000', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('79602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市伊賀谷', '28', '28209', '6680001', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '伊賀谷', 'イガダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市岩熊', '28', '28209', '6680002', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '岩熊', 'イワクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市江野', '28', '28209', '6680003', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '江野', 'ゴウノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市新堂', '28', '28209', '6680004', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '新堂', 'シンドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市滝', '28', '28209', '6680005', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '滝', 'タキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市森津', '28', '28209', '6680006', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '森津', 'モリヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市上陰', '28', '28209', '6680011', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '上陰', 'カミカゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市下陰', '28', '28209', '6680012', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '下陰', 'シモカゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市中陰', '28', '28209', '6680013', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '中陰', 'ナカカゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市野田', '28', '28209', '6680014', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '野田', 'ノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市一日市', '28', '28209', '6680015', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '一日市', 'ヒトイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市宮島', '28', '28209', '6680016', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '宮島', 'ミヤジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市泉町', '28', '28209', '6680021', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '泉町', 'イズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市小田井町', '28', '28209', '6680022', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '小田井町', 'オダイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市加広町', '28', '28209', '6680023', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '加広町', 'カヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市寿町', '28', '28209', '6680024', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '寿町', 'コトブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市幸町', '28', '28209', '6680025', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市元町', '28', '28209', '6680026', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '元町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市若松町', '28', '28209', '6680027', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '若松町', 'ワカマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市大手町', '28', '28209', '6680031', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '大手町', 'オオテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市千代田町', '28', '28209', '6680032', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '千代田町', 'チヨダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市中央町', '28', '28209', '6680033', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '中央町', 'チュウオウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市大磯町', '28', '28209', '6680041', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '大磯町', 'オオイソチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市京町', '28', '28209', '6680042', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '京町', 'キョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市桜町', '28', '28209', '6680043', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '桜町', 'サクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市山王町', '28', '28209', '6680044', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '山王町', 'サンノウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市城南町', '28', '28209', '6680045', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '城南町', 'ジョウナンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市立野町', '28', '28209', '6680046', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '立野町', 'タチノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市三坂町', '28', '28209', '6680047', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '三坂町', 'ミサカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市九日市上町', '28', '28209', '6680051', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '九日市上町', 'ココノカイチカミノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市九日市下町', '28', '28209', '6680052', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '九日市下町', 'ココノカイチシモノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市九日市中町', '28', '28209', '6680053', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '九日市中町', 'ココノカイチナカノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市塩津町', '28', '28209', '6680054', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '塩津町', 'シオツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市昭和町', '28', '28209', '6680055', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '昭和町', 'ショウワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市妙楽寺', '28', '28209', '6680056', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '妙楽寺', 'ミョウラクジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市弥栄町', '28', '28209', '6680057', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '弥栄町', 'ヤサカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市上佐野', '28', '28209', '6680061', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '上佐野', 'カミサノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市佐野', '28', '28209', '6680062', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '佐野', 'サノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市正法寺', '28', '28209', '6680063', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '正法寺', 'ショウボウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市高屋', '28', '28209', '6680064', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '高屋', 'タカヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市戸牧', '28', '28209', '6680065', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '戸牧', 'トベラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市内町', '28', '28209', '6680071', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '内町', 'ウチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市大谷', '28', '28209', '6680072', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '大谷', 'オオタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市辻', '28', '28209', '6680073', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '辻', 'ツジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市野垣', '28', '28209', '6680074', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '野垣', 'ノガキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市福成寺', '28', '28209', '6680075', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '福成寺', 'フクジョウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市船谷', '28', '28209', '6680076', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '船谷', 'フナダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市目坂', '28', '28209', '6680077', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '目坂', 'メサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市吉井', '28', '28209', '6680078', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '吉井', 'ヨシイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市岩井', '28', '28209', '6680081', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '岩井', 'イワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市庄', '28', '28209', '6680082', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '庄', 'ショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市栃江', '28', '28209', '6680083', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '栃江', 'トチエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市福田', '28', '28209', '6680084', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '福田', 'フクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市宮井', '28', '28209', '6680085', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '宮井', 'ミヤイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市出石町奥小野', '28', '28209', '6680201', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '出石町奥小野', 'イズシチョウオクオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市出石町口小野', '28', '28209', '6680202', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '出石町口小野', 'イズシチョウクチオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市出石町袴狭', '28', '28209', '6680203', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '出石町袴狭', 'イズシチョウハカザ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市出石町宮内', '28', '28209', '6680204', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '出石町宮内', 'イズシチョウミヤウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市出石町嶋', '28', '28209', '6680205', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '出石町嶋', 'イズシチョウシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市出石町福居', '28', '28209', '6680206', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '出石町福居', 'イズシチョウフクイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市出石町伊豆', '28', '28209', '6680207', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '出石町伊豆', 'イズシチョウイズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市出石町安良', '28', '28209', '6680208', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '出石町安良', 'イズシチョウヤスラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市出石町田多地', '28', '28209', '6680209', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '出石町田多地', 'イズシチョウタダチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市出石町下谷', '28', '28209', '6680211', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '出石町下谷', 'イズシチョウシモタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市出石町谷山', '28', '28209', '6680212', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '出石町谷山', 'イズシチョウタニヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市出石町伊木', '28', '28209', '6680213', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '出石町伊木', 'イズシチョウイギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市出石町内町', '28', '28209', '6680214', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '出石町内町', 'イズシチョウウチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市出石町魚屋', '28', '28209', '6680215', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '出石町魚屋', 'イズシチョウウオヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市出石町材木', '28', '28209', '6680216', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '出石町材木', 'イズシチョウザイモク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市出石町東條', '28', '28209', '6680217', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '出石町東條', 'イズシチョウトウジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市出石町入佐', '28', '28209', '6680218', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '出石町入佐', 'イズシチョウイルサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市出石町町分', '28', '28209', '6680221', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '出石町町分', 'イズシチョウマチブン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市出石町寺町', '28', '28209', '6680222', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '出石町寺町', 'イズシチョウテラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市出石町鉄砲', '28', '28209', '6680223', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '出石町鉄砲', 'イズシチョウテッポウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市出石町本町', '28', '28209', '6680224', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '出石町本町', 'イズシチョウホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市出石町八木', '28', '28209', '6680225', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '出石町八木', 'イズシチョウヤギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市出石町川原', '28', '28209', '6680231', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '出石町川原', 'イズシチョウカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市出石町宵田', '28', '28209', '6680232', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '出石町宵田', 'イズシチョウヨイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市出石町田結庄', '28', '28209', '6680233', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '出石町田結庄', 'イズシチョウタイノショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市出石町柳', '28', '28209', '6680234', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '出石町柳', 'イズシチョウヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市出石町鍛冶屋', '28', '28209', '6680235', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '出石町鍛冶屋', 'イズシチョウカジヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市出石町松枝', '28', '28209', '6680236', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '出石町松枝', 'イズシチョウマツガエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市出石町馬場', '28', '28209', '6680237', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '出石町馬場', 'イズシチョウババ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市出石町弘原', '28', '28209', '6680238', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '出石町弘原', 'イズシチョウヒロハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市出石町寺坂', '28', '28209', '6680241', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '出石町寺坂', 'イズシチョウテラサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市出石町桐野', '28', '28209', '6680242', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '出石町桐野', 'イズシチョウキリノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市出石町中野', '28', '28209', '6680243', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '出石町中野', 'イズシチョウナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市出石町上野', '28', '28209', '6680244', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '出石町上野', 'イズシチョウウエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市出石町百合', '28', '28209', '6680245', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '出石町百合', 'イズシチョウユリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市出石町日野辺', '28', '28209', '6680246', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '出石町日野辺', 'イズシチョウヒノベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市出石町奥山', '28', '28209', '6680251', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '出石町奥山', 'イズシチョウオクヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市出石町和屋', '28', '28209', '6680252', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '出石町和屋', 'イズシチョウワヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市出石町榎見', '28', '28209', '6680253', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '出石町榎見', 'イズシチョウヨノミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市出石町中村', '28', '28209', '6680254', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '出石町中村', 'イズシチョウナカムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市出石町上村', '28', '28209', '6680255', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '出石町上村', 'イズシチョウカミムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市出石町小人', '28', '28209', '6680256', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '出石町小人', 'イズシチョウコビト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市出石町坪口', '28', '28209', '6680257', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '出石町坪口', 'イズシチョウツボグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市出石町荒木', '28', '28209', '6680261', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '出石町荒木', 'イズシチョウアラキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市出石町細見', '28', '28209', '6680262', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '出石町細見', 'イズシチョウホソミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市出石町福住', '28', '28209', '6680263', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '出石町福住', 'イズシチョウフクスミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市出石町暮坂', '28', '28209', '6680264', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '出石町暮坂', 'イズシチョウクレサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市出石町福見', '28', '28209', '6680265', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '出石町福見', 'イズシチョウフクミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市出石町平田', '28', '28209', '6680266', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '出石町平田', 'イズシチョウヒラタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市出石町大谷', '28', '28209', '6680271', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '出石町大谷', 'イズシチョウオオタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市出石町鳥居', '28', '28209', '6680272', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '出石町鳥居', 'イズシチョウトリイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市出石町坪井', '28', '28209', '6680273', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '出石町坪井', 'イズシチョウツボイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市出石町水上', '28', '28209', '6680274', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '出石町水上', 'イズシチョウムナガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市出石町長砂', '28', '28209', '6680275', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '出石町長砂', 'イズシチョウナガスナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市出石町森井', '28', '28209', '6680276', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '出石町森井', 'イズシチョウモリイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市出石町丸中', '28', '28209', '6680277', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '出石町丸中', 'イズシチョウマルナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市出石町三木', '28', '28209', '6680278', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '出石町三木', 'イズシチョウミツキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市出石町片間', '28', '28209', '6680279', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '出石町片間', 'イズシチョウカタマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市但東町奥矢根', '28', '28209', '6680301', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '但東町奥矢根', 'タントウチョウオクヤネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市但東町矢根', '28', '28209', '6680302', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '但東町矢根', 'タントウチョウヤネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市但東町畑', '28', '28209', '6680303', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '但東町畑', 'タントウチョウハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市但東町水石', '28', '28209', '6680304', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '但東町水石', 'タントウチョウミズシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市但東町出合', '28', '28209', '6680311', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '但東町出合', 'タントウチョウデアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市但東町南尾', '28', '28209', '6680312', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '但東町南尾', 'タントウチョウミノオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市但東町出合市場', '28', '28209', '6680313', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '但東町出合市場', 'タントウチョウデアイイチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市但東町日殿', '28', '28209', '6680314', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '但東町日殿', 'タントウチョウヒドノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市但東町河本', '28', '28209', '6680315', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '但東町河本', 'タントウチョウコウモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市但東町天谷', '28', '28209', '6680316', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '但東町天谷', 'タントウチョウアマダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市但東町西谷', '28', '28209', '6680317', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '但東町西谷', 'タントウチョウニシダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市但東町唐川', '28', '28209', '6680321', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '但東町唐川', 'タントウチョウカラカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市但東町三原', '28', '28209', '6680322', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '但東町三原', 'タントウチョウミハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市但東町小谷', '28', '28209', '6680323', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '但東町小谷', 'タントウチョウオダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市但東町相田', '28', '28209', '6680324', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '但東町相田', 'タントウチョウアイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市但東町佐々木', '28', '28209', '6680325', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '但東町佐々木', 'タントウチョウササキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市但東町木村', '28', '28209', '6680331', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '但東町木村', 'タントウチョウキムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市但東町西野々', '28', '28209', '6680332', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '但東町西野々', 'タントウチョウニシノノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市但東町高竜寺', '28', '28209', '6680333', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '但東町高竜寺', 'タントウチョウコウリュウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市但東町坂野', '28', '28209', '6680334', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '但東町坂野', 'タントウチョウサカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市但東町太田', '28', '28209', '6680335', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '但東町太田', 'タントウチョウオオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市但東町日向', '28', '28209', '6680336', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '但東町日向', 'タントウチョウヒナダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市但東町東里', '28', '28209', '6680337', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '但東町東里', 'タントウチョウトウリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市但東町口藤', '28', '28209', '6680341', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '但東町口藤', 'タントウチョウクチフジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市但東町中藤', '28', '28209', '6680342', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '但東町中藤', 'タントウチョウナカフジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市但東町奥藤', '28', '28209', '6680343', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '但東町奥藤', 'タントウチョウオクフジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市但東町虫生', '28', '28209', '6680344', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '但東町虫生', 'タントウチョウムシュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市但東町中山', '28', '28209', '6680345', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '但東町中山', 'タントウチョウナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市但東町畑山', '28', '28209', '6680351', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '但東町畑山', 'タントウチョウハタヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市但東町赤花', '28', '28209', '6680352', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '但東町赤花', 'タントウチョウアカバナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市但東町奥赤', '28', '28209', '6680353', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '但東町奥赤', 'タントウチョウオクアカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市但東町坂津', '28', '28209', '6680354', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '但東町坂津', 'タントウチョウサカヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市但東町正法寺', '28', '28209', '6680361', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '但東町正法寺', 'タントウチョウショウボウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市但東町平田', '28', '28209', '6680362', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '但東町平田', 'タントウチョウヒラタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市但東町栗尾', '28', '28209', '6680363', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '但東町栗尾', 'タントウチョウクリオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市但東町佐田', '28', '28209', '6680364', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '但東町佐田', 'タントウチョウサダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市但東町薬王寺', '28', '28209', '6680371', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '但東町薬王寺', 'タントウチョウヤクオウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市但東町大河内', '28', '28209', '6680372', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '但東町大河内', 'タントウチョウオオゴウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市但東町久畑', '28', '28209', '6680373', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '但東町久畑', 'タントウチョウクバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市但東町後', '28', '28209', '6680374', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '但東町後', 'タントウチョウウシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市但東町東中', '28', '28209', '6680375', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '但東町東中', 'タントウチョウヒガシナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市但東町小坂', '28', '28209', '6680376', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '但東町小坂', 'タントウチョウコザコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市赤石', '28', '28209', '6680801', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '赤石', 'アカイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市金剛寺', '28', '28209', '6680802', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '金剛寺', 'コンゴウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市下鶴井', '28', '28209', '6680803', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '下鶴井', 'シモツルイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市野上', '28', '28209', '6680804', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '野上', 'ノジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市船町', '28', '28209', '6680805', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '船町', 'フナマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市森', '28', '28209', '6680806', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '森', 'モリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市山本', '28', '28209', '6680807', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '山本', 'ヤマモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市鎌田', '28', '28209', '6680811', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '鎌田', 'カマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市栄町', '28', '28209', '6680812', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市下宮', '28', '28209', '6680813', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '下宮', 'シモノミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市祥雲寺', '28', '28209', '6680814', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '祥雲寺', 'ショウウンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市日撫', '28', '28209', '6680815', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '日撫', 'ヒナド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市法花寺', '28', '28209', '6680816', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '法花寺', 'ホッケイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市六地蔵', '28', '28209', '6680817', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '六地蔵', 'ロクジゾウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市市場', '28', '28209', '6680821', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '市場', 'イチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市奥野', '28', '28209', '6680822', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '奥野', 'オクノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市三宅', '28', '28209', '6680823', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '三宅', 'ミヤケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市森尾', '28', '28209', '6680824', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '森尾', 'モリオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市神美台', '28', '28209', '6680831', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '神美台', 'カミヨシダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市倉見', '28', '28209', '6680832', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '倉見', 'クラミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市立石', '28', '28209', '6680833', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '立石', 'タテイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市長谷', '28', '28209', '6680834', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '長谷', 'ナガタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市加陽', '28', '28209', '6680841', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '加陽', 'カヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市中郷', '28', '28209', '6680842', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '中郷', 'ナカノゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市引野', '28', '28209', '6680843', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '引野', 'ヒキノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市土渕', '28', '28209', '6680844', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '土渕', 'ヒジウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市今森', '28', '28209', '6680851', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '今森', 'イマモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市江本', '28', '28209', '6680852', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '江本', 'エモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市清冷寺', '28', '28209', '6680853', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '清冷寺', 'ショウレンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市八社宮', '28', '28209', '6680854', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '八社宮', 'ハサミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市伏', '28', '28209', '6680855', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '伏', 'フシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市大篠岡', '28', '28209', '6680861', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '大篠岡', 'オオシノカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市香住', '28', '28209', '6680862', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '香住', 'カスミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市上鉢山', '28', '28209', '6680863', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '上鉢山', 'カミハチヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市木内', '28', '28209', '6680864', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '木内', 'キナシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市下鉢山', '28', '28209', '6680865', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '下鉢山', 'シモハチヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市駄坂', '28', '28209', '6680866', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '駄坂', 'ダサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市梶原', '28', '28209', '6680871', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '梶原', 'カジワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市河谷', '28', '28209', '6680872', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '河谷', 'コウダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市庄境', '28', '28209', '6680873', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '庄境', 'ショウザカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市中谷', '28', '28209', '6680874', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '中谷', 'ナカノタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市百合地', '28', '28209', '6680875', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '百合地', 'ユルジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市塩瀬町生瀬', '28', '28204', '6691101', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '塩瀬町生瀬', 'シオセチョウナマゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市生瀬町', '28', '28204', '6691102', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '生瀬町', 'ナマゼチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市生瀬東町', '28', '28204', '6691103', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '生瀬東町', 'ナマゼヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市生瀬武庫川町', '28', '28204', '6691104', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '生瀬武庫川町', 'ナマセムコガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市生瀬高台', '28', '28204', '6691111', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '生瀬高台', 'ナマゼタカダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市宝生ケ丘', '28', '28204', '6691112', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '宝生ケ丘', 'ホウショウガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市花の峯', '28', '28204', '6691121', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '花の峯', 'ハナノミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市青葉台', '28', '28204', '6691122', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '青葉台', 'アオバダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市清瀬台', '28', '28204', '6691131', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '清瀬台', 'キヨセダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市名塩南台', '28', '28204', '6691132', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '名塩南台', 'ナジオミナミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市東山台', '28', '28204', '6691133', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '東山台', 'ヒガシヤマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市名塩新町', '28', '28204', '6691134', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '名塩新町', 'ナジオシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市国見台', '28', '28204', '6691135', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '国見台', 'クニミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市名塩木之元', '28', '28204', '6691136', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '名塩木之元', 'ナジオコノモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市塩瀬町名塩', '28', '28204', '6691141', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '塩瀬町名塩', 'シオセチョウナジオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市名塩山荘', '28', '28204', '6691142', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '名塩山荘', 'ナジオサンソウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市名塩ガーデン', '28', '28204', '6691143', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '名塩ガーデン', 'ナジオガーデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市名塩茶園町', '28', '28204', '6691144', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '名塩茶園町', 'ナジオチャエンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市名塩平成台', '28', '28204', '6691145', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '名塩平成台', 'ナジオヘイセイダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市名塩さくら台', '28', '28204', '6691146', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '名塩さくら台', 'ナジオサクラダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市名塩', '28', '28204', '6691147', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '名塩', 'ナジオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市名塩東久保', '28', '28204', '6691148', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '名塩東久保', 'ナジオトウクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市名塩赤坂', '28', '28204', '6691149', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '名塩赤坂', 'ナジオアカサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神戸市北区道場町生野', '28', '28109', '6691161', '兵庫県', 'ヒョウゴケン', '神戸市北区', 'コウベシキタク', '道場町生野', 'ドウジョウチョウイクノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市名塩美山', '28', '28204', '6691162', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '名塩美山', 'ナジオミヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市香合新田', '28', '28214', '6691201', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '香合新田', 'コウゴウシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市上佐曽利', '28', '28214', '6691202', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '上佐曽利', 'カミサソリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市下佐曽利', '28', '28214', '6691203', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '下佐曽利', 'シモサソリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市長谷', '28', '28214', '6691204', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '長谷', 'ナガタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市芝辻新田', '28', '28214', '6691205', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '芝辻新田', 'シバツジシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市大原野', '28', '28214', '6691211', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '大原野', 'オオハラノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市波豆', '28', '28214', '6691221', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '波豆', 'ハズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市境野', '28', '28214', '6691222', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '境野', 'サカイノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市玉瀬', '28', '28214', '6691231', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '玉瀬', 'タマセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市切畑', '28', '28214', '6691241', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '切畑', 'キリハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宝塚市切畑長尾山', '28', '28214', '6691241', '兵庫県', 'ヒョウゴケン', '宝塚市', 'タカラヅカシ', '切畑', 'キリハタ', null, null, '長尾山', 'ナガオサン');
INSERT INTO `ms_addresses` VALUES ('79875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西宮市塩瀬町名塩', '28', '28204', '6691251', '兵庫県', 'ヒョウゴケン', '西宮市', 'ニシノミヤシ', '塩瀬町名塩', 'シオセチョウナジオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三田市', '28', '28219', '6691300', '兵庫県', 'ヒョウゴケン', '三田市', 'サンダシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('79877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三田市上青野', '28', '28219', '6691301', '兵庫県', 'ヒョウゴケン', '三田市', 'サンダシ', '上青野', 'カミアオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三田市下青野', '28', '28219', '6691302', '兵庫県', 'ヒョウゴケン', '三田市', 'サンダシ', '下青野', 'シモアオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三田市末', '28', '28219', '6691303', '兵庫県', 'ヒョウゴケン', '三田市', 'サンダシ', '末', 'スエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三田市北浦', '28', '28219', '6691304', '兵庫県', 'ヒョウゴケン', '三田市', 'サンダシ', '北浦', 'キタウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三田市加茂', '28', '28219', '6691311', '兵庫県', 'ヒョウゴケン', '三田市', 'サンダシ', '加茂', 'カモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三田市東野上', '28', '28219', '6691312', '兵庫県', 'ヒョウゴケン', '三田市', 'サンダシ', '東野上', 'ヒガシノガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三田市福島', '28', '28219', '6691313', '兵庫県', 'ヒョウゴケン', '三田市', 'サンダシ', '福島', 'フクシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三田市西野上', '28', '28219', '6691314', '兵庫県', 'ヒョウゴケン', '三田市', 'サンダシ', '西野上', 'ニシノガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三田市下井沢', '28', '28219', '6691315', '兵庫県', 'ヒョウゴケン', '三田市', 'サンダシ', '下井沢', 'シモイサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三田市上井沢', '28', '28219', '6691316', '兵庫県', 'ヒョウゴケン', '三田市', 'サンダシ', '上井沢', 'カミイサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三田市宮脇', '28', '28219', '6691317', '兵庫県', 'ヒョウゴケン', '三田市', 'サンダシ', '宮脇', 'ミヤワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三田市けやき台', '28', '28219', '6691321', '兵庫県', 'ヒョウゴケン', '三田市', 'サンダシ', 'けやき台', 'ケヤキダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三田市すずかけ台', '28', '28219', '6691322', '兵庫県', 'ヒョウゴケン', '三田市', 'サンダシ', 'すずかけ台', 'スズカケダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三田市あかしあ台', '28', '28219', '6691323', '兵庫県', 'ヒョウゴケン', '三田市', 'サンダシ', 'あかしあ台', 'アカシアダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三田市ゆりのき台', '28', '28219', '6691324', '兵庫県', 'ヒョウゴケン', '三田市', 'サンダシ', 'ゆりのき台', 'ユリノキダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三田市さくら坂', '28', '28219', '6691325', '兵庫県', 'ヒョウゴケン', '三田市', 'サンダシ', 'さくら坂', 'サクラザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三田市広野', '28', '28219', '6691331', '兵庫県', 'ヒョウゴケン', '三田市', 'サンダシ', '広野', 'ヒロノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三田市広沢', '28', '28219', '6691332', '兵庫県', 'ヒョウゴケン', '三田市', 'サンダシ', '広沢', 'ヒロサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三田市下内神', '28', '28219', '6691333', '兵庫県', 'ヒョウゴケン', '三田市', 'サンダシ', '下内神', 'シモウチガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三田市中内神', '28', '28219', '6691334', '兵庫県', 'ヒョウゴケン', '三田市', 'サンダシ', '中内神', 'ナカウチガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三田市沢谷', '28', '28219', '6691335', '兵庫県', 'ヒョウゴケン', '三田市', 'サンダシ', '沢谷', 'サワダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三田市馬渡', '28', '28219', '6691336', '兵庫県', 'ヒョウゴケン', '三田市', 'サンダシ', '馬渡', 'ウマワタリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三田市学園', '28', '28219', '6691337', '兵庫県', 'ヒョウゴケン', '三田市', 'サンダシ', '学園', 'ガクエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三田市上内神', '28', '28219', '6691338', '兵庫県', 'ヒョウゴケン', '三田市', 'サンダシ', '上内神', 'カミウチガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三田市テクノパーク', '28', '28219', '6691339', '兵庫県', 'ヒョウゴケン', '三田市', 'サンダシ', 'テクノパーク', 'テクノパーク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三田市西相野', '28', '28219', '6691341', '兵庫県', 'ヒョウゴケン', '三田市', 'サンダシ', '西相野', 'ニシアイノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三田市四ツ辻', '28', '28219', '6691342', '兵庫県', 'ヒョウゴケン', '三田市', 'サンダシ', '四ツ辻', 'ヨツツジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三田市洞', '28', '28219', '6691343', '兵庫県', 'ヒョウゴケン', '三田市', 'サンダシ', '洞', 'ホラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三田市溝口', '28', '28219', '6691344', '兵庫県', 'ヒョウゴケン', '三田市', 'サンダシ', '溝口', 'ミゾグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三田市下相野', '28', '28219', '6691345', '兵庫県', 'ヒョウゴケン', '三田市', 'サンダシ', '下相野', 'シモアイノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三田市上相野', '28', '28219', '6691346', '兵庫県', 'ヒョウゴケン', '三田市', 'サンダシ', '上相野', 'カミアイノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三田市つつじが丘南', '28', '28219', '6691347', '兵庫県', 'ヒョウゴケン', '三田市', 'サンダシ', 'つつじが丘南', 'ツツジガオカミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三田市つつじが丘北', '28', '28219', '6691348', '兵庫県', 'ヒョウゴケン', '三田市', 'サンダシ', 'つつじが丘北', 'ツツジガオカキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三田市大川瀬', '28', '28219', '6691349', '兵庫県', 'ヒョウゴケン', '三田市', 'サンダシ', '大川瀬', 'オオカワセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三田市上本庄', '28', '28219', '6691351', '兵庫県', 'ヒョウゴケン', '三田市', 'サンダシ', '上本庄', 'カミホンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三田市須磨田', '28', '28219', '6691352', '兵庫県', 'ヒョウゴケン', '三田市', 'サンダシ', '須磨田', 'スマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三田市東山', '28', '28219', '6691353', '兵庫県', 'ヒョウゴケン', '三田市', 'サンダシ', '東山', 'ヒガシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三田市大畑', '28', '28219', '6691354', '兵庫県', 'ヒョウゴケン', '三田市', 'サンダシ', '大畑', 'オオハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三田市長坂', '28', '28219', '6691355', '兵庫県', 'ヒョウゴケン', '三田市', 'サンダシ', '長坂', 'ナガサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三田市井ノ草', '28', '28219', '6691356', '兵庫県', 'ヒョウゴケン', '三田市', 'サンダシ', '井ノ草', 'イノクサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三田市東本庄', '28', '28219', '6691357', '兵庫県', 'ヒョウゴケン', '三田市', 'サンダシ', '東本庄', 'ヒガシホンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三田市藍本', '28', '28219', '6691358', '兵庫県', 'ヒョウゴケン', '三田市', 'サンダシ', '藍本', 'アイモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三田市小柿', '28', '28219', '6691401', '兵庫県', 'ヒョウゴケン', '三田市', 'サンダシ', '小柿', 'コガキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三田市末吉', '28', '28219', '6691402', '兵庫県', 'ヒョウゴケン', '三田市', 'サンダシ', '末吉', 'スエヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三田市川原', '28', '28219', '6691403', '兵庫県', 'ヒョウゴケン', '三田市', 'サンダシ', '川原', 'カワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三田市十倉', '28', '28219', '6691404', '兵庫県', 'ヒョウゴケン', '三田市', 'サンダシ', '十倉', 'トクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三田市酒井', '28', '28219', '6691405', '兵庫県', 'ヒョウゴケン', '三田市', 'サンダシ', '酒井', 'サカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三田市田中', '28', '28219', '6691406', '兵庫県', 'ヒョウゴケン', '三田市', 'サンダシ', '田中', 'タナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三田市布木', '28', '28219', '6691407', '兵庫県', 'ヒョウゴケン', '三田市', 'サンダシ', '布木', 'フキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三田市波豆川', '28', '28219', '6691411', '兵庫県', 'ヒョウゴケン', '三田市', 'サンダシ', '波豆川', 'ハズカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三田市木器', '28', '28219', '6691412', '兵庫県', 'ヒョウゴケン', '三田市', 'サンダシ', '木器', 'コウヅキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三田市下槻瀬', '28', '28219', '6691413', '兵庫県', 'ヒョウゴケン', '三田市', 'サンダシ', '下槻瀬', 'シモヅキセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三田市市之瀬', '28', '28219', '6691414', '兵庫県', 'ヒョウゴケン', '三田市', 'サンダシ', '市之瀬', 'イチノセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三田市上槻瀬', '28', '28219', '6691415', '兵庫県', 'ヒョウゴケン', '三田市', 'サンダシ', '上槻瀬', 'カミヅキセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三田市下里', '28', '28219', '6691416', '兵庫県', 'ヒョウゴケン', '三田市', 'サンダシ', '下里', 'シモザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三田市鈴鹿', '28', '28219', '6691417', '兵庫県', 'ヒョウゴケン', '三田市', 'サンダシ', '鈴鹿', 'スズカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三田市母子', '28', '28219', '6691501', '兵庫県', 'ヒョウゴケン', '三田市', 'サンダシ', '母子', 'モウシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三田市永沢寺', '28', '28219', '6691502', '兵庫県', 'ヒョウゴケン', '三田市', 'サンダシ', '永沢寺', 'エイタクジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三田市乙原', '28', '28219', '6691503', '兵庫県', 'ヒョウゴケン', '三田市', 'サンダシ', '乙原', 'オチバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三田市小野', '28', '28219', '6691504', '兵庫県', 'ヒョウゴケン', '三田市', 'サンダシ', '小野', 'オノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三田市尼寺', '28', '28219', '6691505', '兵庫県', 'ヒョウゴケン', '三田市', 'サンダシ', '尼寺', 'ニンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三田市志手原', '28', '28219', '6691506', '兵庫県', 'ヒョウゴケン', '三田市', 'サンダシ', '志手原', 'シデハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三田市香下', '28', '28219', '6691507', '兵庫県', 'ヒョウゴケン', '三田市', 'サンダシ', '香下', 'カシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三田市山田', '28', '28219', '6691511', '兵庫県', 'ヒョウゴケン', '三田市', 'サンダシ', '山田', 'ヤマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三田市高次', '28', '28219', '6691512', '兵庫県', 'ヒョウゴケン', '三田市', 'サンダシ', '高次', 'タカスギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三田市三輪', '28', '28219', '6691513', '兵庫県', 'ヒョウゴケン', '三田市', 'サンダシ', '三輪', 'ミワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三田市川除', '28', '28219', '6691514', '兵庫県', 'ヒョウゴケン', '三田市', 'サンダシ', '川除', 'カワヨケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三田市大原', '28', '28219', '6691515', '兵庫県', 'ヒョウゴケン', '三田市', 'サンダシ', '大原', 'オオハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三田市友が丘', '28', '28219', '6691516', '兵庫県', 'ヒョウゴケン', '三田市', 'サンダシ', '友が丘', 'トモガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三田市成谷', '28', '28219', '6691517', '兵庫県', 'ヒョウゴケン', '三田市', 'サンダシ', '成谷', 'ナルタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三田市桑原', '28', '28219', '6691521', '兵庫県', 'ヒョウゴケン', '三田市', 'サンダシ', '桑原', 'クワバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三田市下田中', '28', '28219', '6691522', '兵庫県', 'ヒョウゴケン', '三田市', 'サンダシ', '下田中', 'シモタナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三田市寺村町', '28', '28219', '6691523', '兵庫県', 'ヒョウゴケン', '三田市', 'サンダシ', '寺村町', 'テラムラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三田市八景町', '28', '28219', '6691524', '兵庫県', 'ヒョウゴケン', '三田市', 'サンダシ', '八景町', 'ハッケイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三田市対中町', '28', '28219', '6691525', '兵庫県', 'ヒョウゴケン', '三田市', 'サンダシ', '対中町', 'タイナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三田市相生町', '28', '28219', '6691526', '兵庫県', 'ヒョウゴケン', '三田市', 'サンダシ', '相生町', 'アイオイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三田市中町', '28', '28219', '6691527', '兵庫県', 'ヒョウゴケン', '三田市', 'サンダシ', '中町', 'ナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三田市駅前町', '28', '28219', '6691528', '兵庫県', 'ヒョウゴケン', '三田市', 'サンダシ', '駅前町', 'エキマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三田市中央町', '28', '28219', '6691529', '兵庫県', 'ヒョウゴケン', '三田市', 'サンダシ', '中央町', 'チュウオウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三田市天神', '28', '28219', '6691531', '兵庫県', 'ヒョウゴケン', '三田市', 'サンダシ', '天神', 'テンジン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三田市屋敷町', '28', '28219', '6691532', '兵庫県', 'ヒョウゴケン', '三田市', 'サンダシ', '屋敷町', 'ヤシキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三田市三田町', '28', '28219', '6691533', '兵庫県', 'ヒョウゴケン', '三田市', 'サンダシ', '三田町', 'サンダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三田市横山町', '28', '28219', '6691534', '兵庫県', 'ヒョウゴケン', '三田市', 'サンダシ', '横山町', 'ヨコヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三田市南が丘', '28', '28219', '6691535', '兵庫県', 'ヒョウゴケン', '三田市', 'サンダシ', '南が丘', 'ミナミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三田市', '28', '28219', '6691536', '兵庫県', 'ヒョウゴケン', '三田市', 'サンダシ', null, '　', '（直番地）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('79962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三田市西山', '28', '28219', '6691537', '兵庫県', 'ヒョウゴケン', '三田市', 'サンダシ', '西山', 'ニシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三田市貴志', '28', '28219', '6691541', '兵庫県', 'ヒョウゴケン', '三田市', 'サンダシ', '貴志', 'キシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三田市上深田', '28', '28219', '6691542', '兵庫県', 'ヒョウゴケン', '三田市', 'サンダシ', '上深田', 'カミフカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三田市下深田', '28', '28219', '6691543', '兵庫県', 'ヒョウゴケン', '三田市', 'サンダシ', '下深田', 'シモフカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三田市武庫が丘', '28', '28219', '6691544', '兵庫県', 'ヒョウゴケン', '三田市', 'サンダシ', '武庫が丘', 'ムコガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三田市狭間が丘', '28', '28219', '6691545', '兵庫県', 'ヒョウゴケン', '三田市', 'サンダシ', '狭間が丘', 'ハサマガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三田市弥生が丘', '28', '28219', '6691546', '兵庫県', 'ヒョウゴケン', '三田市', 'サンダシ', '弥生が丘', 'ヤヨイガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三田市富士が丘', '28', '28219', '6691547', '兵庫県', 'ヒョウゴケン', '三田市', 'サンダシ', '富士が丘', 'フジガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三田市池尻', '28', '28219', '6691548', '兵庫県', 'ヒョウゴケン', '三田市', 'サンダシ', '池尻', 'イケジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市初田', '28', '28221', '6692101', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '初田', 'ハツダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市南矢代', '28', '28221', '6692102', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '南矢代', 'ミナミヤシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市波賀野', '28', '28221', '6692103', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '波賀野', 'ハガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市矢代新', '28', '28221', '6692104', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '矢代新', 'ヤシロシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市犬飼', '28', '28221', '6692105', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '犬飼', 'イヌカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市牛ケ瀬', '28', '28221', '6692106', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '牛ケ瀬', 'ウシガセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市当野', '28', '28221', '6692111', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '当野', 'トウノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市古森', '28', '28221', '6692112', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '古森', 'コウモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市草野', '28', '28221', '6692113', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '草野', 'クサノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市油井', '28', '28221', '6692114', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '油井', 'アブライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市見内', '28', '28221', '6692121', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '見内', 'ミウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市波賀野新田', '28', '28221', '6692122', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '波賀野新田', 'ハガノシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市古市', '28', '28221', '6692123', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '古市', 'フルイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市不来坂', '28', '28221', '6692124', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '不来坂', 'コノサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市住山', '28', '28221', '6692125', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '住山', 'スミヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市今田町辰巳', '28', '28221', '6692131', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '今田町辰巳', 'コンダチョウタツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市今田町上小野原', '28', '28221', '6692132', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '今田町上小野原', 'コンダチョウカミオノバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市今田町下小野原', '28', '28221', '6692133', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '今田町下小野原', 'コンダチョウシモオノバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市今田町休場', '28', '28221', '6692134', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '今田町休場', 'コンダチョウヤスンバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市今田町上立杭', '28', '28221', '6692135', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '今田町上立杭', 'コンダチョウカミタチクイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市今田町下立杭', '28', '28221', '6692141', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '今田町下立杭', 'コンダチョウシモタチクイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市今田町東庄', '28', '28221', '6692142', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '今田町東庄', 'コンダチョウヒガシショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市今田町釜屋', '28', '28221', '6692143', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '今田町釜屋', 'コンダチョウカマヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市今田町間新田', '28', '28221', '6692144', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '今田町間新田', 'コンダチョウアイシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市今田町木津', '28', '28221', '6692145', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '今田町木津', 'コンダチョウコツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市今田町今田', '28', '28221', '6692151', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '今田町今田', 'コンダチョウコンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('79999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市今田町荻野分', '28', '28221', '6692152', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '今田町荻野分', 'コンダチョウオギノブン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市今田町今田新田', '28', '28221', '6692153', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '今田町今田新田', 'コンダチョウコンダシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市今田町市原', '28', '28221', '6692154', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '今田町市原', 'コンダチョウイチハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市今田町芦原新田', '28', '28221', '6692155', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '今田町芦原新田', 'コンダチョウアシハラシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市今田町佐曽良新田', '28', '28221', '6692156', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '今田町佐曽良新田', 'コンダチョウサソラシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市今田町四斗谷', '28', '28221', '6692161', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '今田町四斗谷', 'コンダチョウシトダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市今田町黒石', '28', '28221', '6692162', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '今田町黒石', 'コンダチョウクロイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市今田町本荘', '28', '28221', '6692163', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '今田町本荘', 'コンダチョウホンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市東古佐', '28', '28221', '6692201', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '東古佐', 'ヒガシコサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市東吹', '28', '28221', '6692202', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '東吹', 'ヒガシブキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市吹新', '28', '28221', '6692203', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '吹新', 'フキシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市杉', '28', '28221', '6692204', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '杉', 'スギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市網掛', '28', '28221', '6692205', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '網掛', 'アガケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市西吹', '28', '28221', '6692206', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '西吹', 'ニシブキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市大沢新', '28', '28221', '6692211', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '大沢新', 'オオザワシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市大沢', '28', '28221', '6692212', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '大沢', 'オオザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市中野', '28', '28221', '6692213', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '中野', 'ナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市味間新', '28', '28221', '6692214', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '味間新', 'アジマシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市西古佐', '28', '28221', '6692221', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '西古佐', 'ニシコサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市味間南', '28', '28221', '6692222', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '味間南', 'アジマミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市味間奥', '28', '28221', '6692223', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '味間奥', 'アジマオク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市味間北', '28', '28221', '6692224', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '味間北', 'アジマキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市住吉台', '28', '28221', '6692231', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '住吉台', 'スミヨシダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市', '28', '28221', '6692300', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('80025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市火打岩', '28', '28221', '6692301', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '火打岩', 'ヒウチワン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市奥畑', '28', '28221', '6692302', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '奥畑', 'オクハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市瀬利', '28', '28221', '6692303', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '瀬利', 'セリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市今谷', '28', '28221', '6692304', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '今谷', 'イマダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市畑宮', '28', '28221', '6692305', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '畑宮', 'ハタミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市大上', '28', '28221', '6692306', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '大上', 'オオガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市般若寺', '28', '28221', '6692307', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '般若寺', 'ハンニャジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市和田', '28', '28221', '6692308', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '和田', 'ワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市大渕', '28', '28221', '6692309', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '大渕', 'オオブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市新荘', '28', '28221', '6692311', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '新荘', 'シンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市菅', '28', '28221', '6692312', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '菅', 'スゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市野間', '28', '28221', '6692313', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '野間', 'ノマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市東沢田', '28', '28221', '6692314', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '東沢田', 'ヒガシサワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市筋山', '28', '28221', '6692315', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '筋山', 'スジヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市前沢田', '28', '28221', '6692316', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '前沢田', 'マエサワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市北沢田', '28', '28221', '6692317', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '北沢田', 'キタサワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市大熊', '28', '28221', '6692318', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '大熊', 'オオクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市黒岡', '28', '28221', '6692321', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '黒岡', 'クロオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市呉服町', '28', '28221', '6692322', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '呉服町', 'ゴフクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市立町', '28', '28221', '6692323', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '立町', 'タツマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市東新町', '28', '28221', '6692324', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '東新町', 'ヒガシシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市河原町', '28', '28221', '6692325', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '河原町', 'カワラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市小川町', '28', '28221', '6692326', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '小川町', 'オガワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市二階町', '28', '28221', '6692331', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '二階町', 'ニカイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市北新町', '28', '28221', '6692332', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '北新町', 'キタシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市南新町', '28', '28221', '6692333', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '南新町', 'ミナミシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市西新町', '28', '28221', '6692334', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '西新町', 'ニシシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市乾新町', '28', '28221', '6692335', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '乾新町', 'イヌイシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市魚屋町', '28', '28221', '6692336', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '魚屋町', 'ウオヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市山内町', '28', '28221', '6692337', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '山内町', 'ヤマウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市郡家', '28', '28221', '6692341', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '郡家', 'グンゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市西町', '28', '28221', '6692342', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '西町', 'ニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市風深', '28', '28221', '6692343', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '風深', 'フウカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市吹上', '28', '28221', '6692344', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '吹上', 'フキガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市東岡屋', '28', '28221', '6692345', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '東岡屋', 'ヒガシオカヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市西岡屋', '28', '28221', '6692346', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '西岡屋', 'ニシオカヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市東浜谷', '28', '28221', '6692351', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '東浜谷', 'ヒガシハマダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市西浜谷', '28', '28221', '6692352', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '西浜谷', 'ニシハマダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市野尻', '28', '28221', '6692353', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '野尻', 'ノジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市有居', '28', '28221', '6692354', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '有居', 'アリイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市大野', '28', '28221', '6692355', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '大野', 'オオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市矢代', '28', '28221', '6692356', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '矢代', 'ヤシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市今福', '28', '28221', '6692357', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '今福', 'イマフク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市丸山', '28', '28221', '6692361', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '丸山', 'マルヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市知足', '28', '28221', '6692362', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '知足', 'チソク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市大谷', '28', '28221', '6692363', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '大谷', 'オオタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市鷲尾', '28', '28221', '6692364', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '鷲尾', 'ワシオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市佐倉', '28', '28221', '6692365', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '佐倉', 'サクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市寺内', '28', '28221', '6692366', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '寺内', 'テラウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市熊谷', '28', '28221', '6692367', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '熊谷', 'クマダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市藤岡口', '28', '28221', '6692368', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '藤岡口', 'フジオカクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市藤岡奥', '28', '28221', '6692369', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '藤岡奥', 'フジオカオク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市奥県守', '28', '28221', '6692401', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '奥県守', 'オクアガタモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市県守', '28', '28221', '6692402', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '県守', 'アガタモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市東本荘', '28', '28221', '6692403', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '東本荘', 'ヒガシホンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市西本荘', '28', '28221', '6692404', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '西本荘', 'ニシホンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市佐貫谷', '28', '28221', '6692405', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '佐貫谷', 'サヌキダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市泉', '28', '28221', '6692406', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '泉', 'イズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市倉谷', '28', '28221', '6692407', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '倉谷', 'クラタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市春日江', '28', '28221', '6692408', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '春日江', 'カスガエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市辻', '28', '28221', '6692411', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '辻', 'ツジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市小中', '28', '28221', '6692412', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '小中', 'コナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市畑市', '28', '28221', '6692413', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '畑市', 'ハタイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市宮ノ前', '28', '28221', '6692414', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '宮ノ前', 'ミヤノマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市上宿', '28', '28221', '6692415', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '上宿', 'カミジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市井ノ上', '28', '28221', '6692416', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '井ノ上', 'イノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市北島', '28', '28221', '6692417', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '北島', 'キタジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市畑井', '28', '28221', '6692418', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '畑井', 'ハタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市後川新田', '28', '28221', '6692421', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '後川新田', 'シツカワシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市後川上', '28', '28221', '6692422', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '後川上', 'シツカワカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市後川中', '28', '28221', '6692423', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '後川中', 'シツカワナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市後川下', '28', '28221', '6692424', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '後川下', 'シツカワシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市後川奥', '28', '28221', '6692425', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '後川奥', 'シツカワオク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市八上下', '28', '28221', '6692431', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '八上下', 'ヤカミシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市八上内', '28', '28221', '6692432', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '八上内', 'ヤカミウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市西八上', '28', '28221', '6692433', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '西八上', 'ニシヤカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市殿町', '28', '28221', '6692434', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '殿町', 'トノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市小多田', '28', '28221', '6692435', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '小多田', 'オタダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市池上', '28', '28221', '6692436', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '池上', 'イケガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市糯ケ坪', '28', '28221', '6692437', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '糯ケ坪', 'モチガツボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市京町', '28', '28221', '6692438', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '京町', 'キョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市渋谷', '28', '28221', '6692439', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '渋谷', 'シブタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市日置', '28', '28221', '6692441', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '日置', 'ヒオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市曽地口', '28', '28221', '6692442', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '曽地口', 'ソウジクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市曽地中', '28', '28221', '6692443', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '曽地中', 'ソウジナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市曽地奥', '28', '28221', '6692444', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '曽地奥', 'ソウジオク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市野々垣', '28', '28221', '6692445', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '野々垣', 'ノノガキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市八上上', '28', '28221', '6692446', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '八上上', 'ヤカミカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市西荘', '28', '28221', '6692447', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '西荘', 'ニシジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市北', '28', '28221', '6692451', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '北', 'キタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市野中', '28', '28221', '6692452', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '野中', 'ノナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市谷山', '28', '28221', '6692453', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '谷山', 'タニヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市岩崎', '28', '28221', '6692454', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '岩崎', 'イワザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市宇土', '28', '28221', '6692455', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '宇土', 'ウド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市小枕', '28', '28221', '6692461', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '小枕', 'コマクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市真南条上', '28', '28221', '6692462', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '真南条上', 'マナンジョウカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市真南条中', '28', '28221', '6692463', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '真南条中', 'マナンジョウナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市真南条下', '28', '28221', '6692464', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '真南条下', 'マナンジョウシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市栗栖野', '28', '28221', '6692465', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '栗栖野', 'クリスノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市奥原山', '28', '28221', '6692501', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '奥原山', 'オクハラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市中原山', '28', '28221', '6692502', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '中原山', 'ナカハラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市下原山', '28', '28221', '6692503', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '下原山', 'シモハラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市西野々', '28', '28221', '6692504', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '西野々', 'ニシノノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市安口', '28', '28221', '6692505', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '安口', 'ハダカス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市本明谷', '28', '28221', '6692511', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '本明谷', 'ホンミョウダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市川原', '28', '28221', '6692512', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '川原', 'カワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市福住', '28', '28221', '6692513', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '福住', 'フクスミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市二之坪', '28', '28221', '6692521', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '二之坪', 'ニノツボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市小野奥谷', '28', '28221', '6692522', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '小野奥谷', 'オノオクダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市小野新', '28', '28221', '6692523', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '小野新', 'オノシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市箱谷', '28', '28221', '6692524', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '箱谷', 'ハコダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市栃梨', '28', '28221', '6692525', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '栃梨', 'トチナシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市向井', '28', '28221', '6692526', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '向井', 'ムカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市松ケ鼻', '28', '28221', '6692527', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '松ケ鼻', 'マツガハナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市垂水', '28', '28221', '6692531', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '垂水', 'タルミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市小立', '28', '28221', '6692532', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '小立', 'オダチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市山田', '28', '28221', '6692533', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '山田', 'ヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市上筱見', '28', '28221', '6692534', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '上筱見', 'カミササミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市下筱見', '28', '28221', '6692535', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '下筱見', 'シモササミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市井串', '28', '28221', '6692541', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '井串', 'イクシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市細工所', '28', '28221', '6692542', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '細工所', 'サイクジョ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市塩岡', '28', '28221', '6692543', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '塩岡', 'ショウカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市草ノ上', '28', '28221', '6692544', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '草ノ上', 'クサノカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市小田中', '28', '28221', '6692545', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '小田中', 'コダナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市安田', '28', '28221', '6692551', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '安田', 'ヤスダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市藤之木', '28', '28221', '6692552', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '藤之木', 'フジノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市幡路', '28', '28221', '6692553', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '幡路', 'ハダチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市貝田', '28', '28221', '6692554', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '貝田', 'カイタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市中', '28', '28221', '6692601', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '中', 'ナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市三熊', '28', '28221', '6692602', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '三熊', 'ミクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市福井', '28', '28221', '6692603', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '福井', 'フクイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市小原', '28', '28221', '6692604', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '小原', 'オバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市藤坂', '28', '28221', '6692605', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '藤坂', 'フジサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市大藤', '28', '28221', '6692611', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '大藤', 'オオフジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市立金', '28', '28221', '6692612', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '立金', 'タツガネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市市野々', '28', '28221', '6692613', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '市野々', 'イチノノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市小倉', '28', '28221', '6692614', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '小倉', 'オグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市宮代', '28', '28221', '6692615', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '宮代', 'ミヤシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市奥山', '28', '28221', '6692616', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '奥山', 'オクヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市川阪', '28', '28221', '6692701', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '川阪', 'カワサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市本郷', '28', '28221', '6692702', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '本郷', 'ホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市桑原', '28', '28221', '6692703', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '桑原', 'クワバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市遠方', '28', '28221', '6692704', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '遠方', 'オチカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市栗柄', '28', '28221', '6692711', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '栗柄', 'クリカラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市坂本', '28', '28221', '6692712', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '坂本', 'サカモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市倉本', '28', '28221', '6692713', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '倉本', 'クラモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市垣屋', '28', '28221', '6692714', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '垣屋', 'カキヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市打坂', '28', '28221', '6692715', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '打坂', 'ウチサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市乗竹', '28', '28221', '6692716', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '乗竹', 'ノリタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市高坂', '28', '28221', '6692717', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '高坂', 'タカサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市市山', '28', '28221', '6692718', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '市山', 'イチヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市西谷', '28', '28221', '6692721', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '西谷', 'ニシタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市河内台', '28', '28221', '6692722', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '河内台', 'カワウチダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市口阪本', '28', '28221', '6692723', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '口阪本', 'クチサカモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市川北', '28', '28221', '6692724', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '川北', 'カワギタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市川北新田', '28', '28221', '6692725', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '川北新田', 'カワギタシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市黒田', '28', '28221', '6692726', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '黒田', 'クロダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市高屋', '28', '28221', '6692727', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '高屋', 'タカヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市西阪本', '28', '28221', '6692728', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '西阪本', 'ニシサカモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市小坂', '28', '28221', '6692731', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '小坂', 'オサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市上板井', '28', '28221', '6692732', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '上板井', 'カミイタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市下板井', '28', '28221', '6692733', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '下板井', 'シモイタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市宮田', '28', '28221', '6692734', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '宮田', 'ミヤダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市川西', '28', '28221', '6692735', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '川西', 'カワニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市西木之部', '28', '28221', '6692736', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '西木之部', 'ニシキノベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市東木之部', '28', '28221', '6692737', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '東木之部', 'ヒガシキノベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市追入', '28', '28221', '6692801', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '追入', 'オイレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市大山宮', '28', '28221', '6692802', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '大山宮', 'オオヤマミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市大山上', '28', '28221', '6692803', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '大山上', 'オオヤマカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市荒子新田', '28', '28221', '6692804', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '荒子新田', 'アラコシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市園田分', '28', '28221', '6692805', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '園田分', 'ソノダブン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市石住', '28', '28221', '6692811', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '石住', 'イシズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市高倉', '28', '28221', '6692812', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '高倉', 'タカクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市一印谷', '28', '28221', '6692813', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '一印谷', 'イチインダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市長安寺', '28', '28221', '6692814', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '長安寺', 'チョウアンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市町ノ田', '28', '28221', '6692815', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '町ノ田', 'チョウノタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市東河地', '28', '28221', '6692821', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '東河地', 'トウコウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市明野', '28', '28221', '6692822', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '明野', 'アケノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市大山下', '28', '28221', '6692823', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '大山下', 'オオヤマシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市北野', '28', '28221', '6692824', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '北野', 'キタノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市北野新田', '28', '28221', '6692825', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '北野新田', 'キタノシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市徳永', '28', '28221', '6692826', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '徳永', 'トクナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県篠山市大山新', '28', '28221', '6692827', '兵庫県', 'ヒョウゴケン', '篠山市', 'ササヤマシ', '大山新', 'オオヤマシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市山南町上滝', '28', '28223', '6693101', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '山南町上滝', 'サンナンチョウカミタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市山南町下滝', '28', '28223', '6693102', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '山南町下滝', 'サンナンチョウシモタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市山南町篠場', '28', '28223', '6693103', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '山南町篠場', 'サンナンチョウササバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市山南町畑内', '28', '28223', '6693104', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '山南町畑内', 'サンナンチョウハタウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市山南町北太田', '28', '28223', '6693105', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '山南町北太田', 'サンナンチョウキタオオダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市山南町阿草', '28', '28223', '6693111', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '山南町阿草', 'サンナンチョウアクサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市山南町青田', '28', '28223', '6693112', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '山南町青田', 'サンナンチョウアオダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市山南町太田', '28', '28223', '6693113', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '山南町太田', 'サンナンチョウオオダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市山南町奥野々', '28', '28223', '6693121', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '山南町奥野々', 'サンナンチョウオクノノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市山南町玉巻', '28', '28223', '6693122', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '山南町玉巻', 'サンナンチョウタマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市山南町大河', '28', '28223', '6693123', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '山南町大河', 'サンナンチョウオオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市山南町大谷', '28', '28223', '6693124', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '山南町大谷', 'サンナンチョウオオタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市山南町池谷', '28', '28223', '6693125', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '山南町池谷', 'サンナンチョウイケダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市山南町長野', '28', '28223', '6693126', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '山南町長野', 'サンナンチョウナガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市山南町岡本', '28', '28223', '6693127', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '山南町岡本', 'サンナンチョウオカモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市山南町金屋', '28', '28223', '6693128', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '山南町金屋', 'サンナンチョウカナヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市山南町谷川', '28', '28223', '6693131', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '山南町谷川', 'サンナンチョウタニガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市山南町山崎', '28', '28223', '6693132', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '山南町山崎', 'サンナンチョウヤマサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市山南町岩屋', '28', '28223', '6693141', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '山南町岩屋', 'サンナンチョウイワヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市山南町村森', '28', '28223', '6693142', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '山南町村森', 'サンナンチョウムラモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市山南町井原', '28', '28223', '6693143', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '山南町井原', 'サンナンチョウイバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市山南町奥', '28', '28223', '6693144', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '山南町奥', 'サンナンチョウオク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市山南町野坂', '28', '28223', '6693145', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '山南町野坂', 'サンナンチョウノサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市山南町南中', '28', '28223', '6693146', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '山南町南中', 'サンナンチョウミナミナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市山南町子茂田', '28', '28223', '6693147', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '山南町子茂田', 'サンナンチョウシモダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市山南町草部', '28', '28223', '6693151', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '山南町草部', 'サンナンチョウクサベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市山南町北和田', '28', '28223', '6693152', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '山南町北和田', 'サンナンチョウキタワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市山南町前川', '28', '28223', '6693153', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '山南町前川', 'サンナンチョウマエガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市山南町梶', '28', '28223', '6693154', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '山南町梶', 'サンナンチョウカジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市山南町小新屋', '28', '28223', '6693155', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '山南町小新屋', 'サンナンチョウコニヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市山南町金倉', '28', '28223', '6693156', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '山南町金倉', 'サンナンチョウカナクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市山南町和田', '28', '28223', '6693157', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '山南町和田', 'サンナンチョウワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市山南町応地', '28', '28223', '6693158', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '山南町応地', 'サンナンチョウオウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市山南町美和', '28', '28223', '6693159', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '山南町美和', 'サンナンチョウミワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市山南町五ケ野', '28', '28223', '6693161', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '山南町五ケ野', 'サンナンチョウゴガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市山南町坂尻', '28', '28223', '6693162', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '山南町坂尻', 'サンナンチョウサカジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市山南町山本', '28', '28223', '6693163', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '山南町山本', 'サンナンチョウヤマモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市山南町若林', '28', '28223', '6693164', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '山南町若林', 'サンナンチョウワカバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市山南町富田', '28', '28223', '6693165', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '山南町富田', 'サンナンチョウトミタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市山南町小野尻', '28', '28223', '6693166', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '山南町小野尻', 'サンナンチョウオノジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市山南町小畑', '28', '28223', '6693167', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '山南町小畑', 'サンナンチョウオバタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市山南町西谷', '28', '28223', '6693168', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '山南町西谷', 'サンナンチョウニシタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市', '28', '28223', '6693300', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('80254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市柏原町南多田', '28', '28223', '6693301', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '柏原町南多田', 'カイバラチョウミナミタダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市柏原町東奥', '28', '28223', '6693302', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '柏原町東奥', 'カイバラチョウヒガシオク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市柏原町見長', '28', '28223', '6693303', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '柏原町見長', 'カイバラチョウミナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市柏原町上小倉', '28', '28223', '6693304', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '柏原町上小倉', 'カイバラチョウカミオグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市柏原町下小倉', '28', '28223', '6693305', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '柏原町下小倉', 'カイバラチョウシモオグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市柏原町北中', '28', '28223', '6693306', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '柏原町北中', 'カイバラチョウキタナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市柏原町石戸', '28', '28223', '6693307', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '柏原町石戸', 'カイバラチョウイシド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市柏原町小南', '28', '28223', '6693308', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '柏原町小南', 'カイバラチョウコミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市柏原町柏原', '28', '28223', '6693309', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '柏原町柏原', 'カイバラチョウカイバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市柏原町母坪', '28', '28223', '6693311', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '柏原町母坪', 'カイバラチョウホツボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市柏原町田路', '28', '28223', '6693312', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '柏原町田路', 'カイバラチョウタジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市柏原町北山', '28', '28223', '6693313', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '柏原町北山', 'カイバラチョウキタヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市柏原町挙田', '28', '28223', '6693314', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '柏原町挙田', 'カイバラチョウアグタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市柏原町大新屋', '28', '28223', '6693315', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '柏原町大新屋', 'カイバラチョウオオニヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市柏原町鴨野', '28', '28223', '6693316', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '柏原町鴨野', 'カイバラチョウカモノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市春日町山田', '28', '28223', '6693401', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '春日町山田', 'カスガチョウヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市春日町新才', '28', '28223', '6693402', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '春日町新才', 'カスガチョウシンサイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市春日町長王', '28', '28223', '6693403', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '春日町長王', 'カスガチョウナガオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市春日町牛河内', '28', '28223', '6693404', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '春日町牛河内', 'カスガチョウウシガワチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市春日町朝日', '28', '28223', '6693411', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '春日町朝日', 'カスガチョウアサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市春日町園部', '28', '28223', '6693412', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '春日町園部', 'カスガチョウソノベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市春日町石才', '28', '28223', '6693413', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '春日町石才', 'カスガチョウイシザイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市春日町歌道谷', '28', '28223', '6693414', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '春日町歌道谷', 'カスガチョウウトウダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市春日町坂', '28', '28223', '6693415', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '春日町坂', 'カスガチョウサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市春日町野山', '28', '28223', '6693416', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '春日町野山', 'カスガチョウノヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市氷上町市辺', '28', '28223', '6693461', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '氷上町市辺', 'ヒカミチョウイチベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市氷上町大崎', '28', '28223', '6693462', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '氷上町大崎', 'ヒカミチョウオオサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市氷上町北野', '28', '28223', '6693463', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '氷上町北野', 'ヒカミチョウキタノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市氷上町石生', '28', '28223', '6693464', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '氷上町石生', 'ヒカミチョウイソウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市氷上町横田', '28', '28223', '6693465', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '氷上町横田', 'ヒカミチョウヨコタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市氷上町稲継', '28', '28223', '6693466', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '氷上町稲継', 'ヒカミチョウイナツギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市氷上町本郷', '28', '28223', '6693467', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '氷上町本郷', 'ヒカミチョウホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市氷上町新郷', '28', '28223', '6693571', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '氷上町新郷', 'ヒカミチョウシンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市氷上町谷村', '28', '28223', '6693572', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '氷上町谷村', 'ヒカミチョウタニムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市氷上町油利', '28', '28223', '6693573', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '氷上町油利', 'ヒカミチョウユリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市氷上町朝阪', '28', '28223', '6693574', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '氷上町朝阪', 'ヒカミチョウアサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市氷上町小野', '28', '28223', '6693575', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '氷上町小野', 'ヒカミチョウオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市氷上町稲畑', '28', '28223', '6693581', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '氷上町稲畑', 'ヒカミチョウイナハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市氷上町佐野', '28', '28223', '6693582', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '氷上町佐野', 'ヒカミチョウサノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市氷上町福田', '28', '28223', '6693583', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '氷上町福田', 'ヒカミチョウフクタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市氷上町成松', '28', '28223', '6693601', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '氷上町成松', 'ヒカミチョウナリマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市氷上町常楽', '28', '28223', '6693602', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '氷上町常楽', 'ヒカミチョウジョウラク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市氷上町西中', '28', '28223', '6693603', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '氷上町西中', 'ヒカミチョウニシナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市氷上町犬岡', '28', '28223', '6693604', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '氷上町犬岡', 'ヒカミチョウイヌオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市氷上町黒田', '28', '28223', '6693605', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '氷上町黒田', 'ヒカミチョウクロダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市氷上町上成松', '28', '28223', '6693606', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '氷上町上成松', 'ヒカミチョウアゲナリマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市氷上町柿柴', '28', '28223', '6693611', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '氷上町柿柴', 'ヒカミチョウカキシバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市氷上町長野', '28', '28223', '6693612', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '氷上町長野', 'ヒカミチョウオサノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市氷上町上新庄', '28', '28223', '6693613', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '氷上町上新庄', 'ヒカミチョウカミシンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市氷上町下新庄', '28', '28223', '6693614', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '氷上町下新庄', 'ヒカミチョウシモシンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市氷上町大谷', '28', '28223', '6693621', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '氷上町大谷', 'ヒカミチョウオオタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市氷上町三原', '28', '28223', '6693622', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '氷上町三原', 'ヒカミチョウミハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市氷上町中野', '28', '28223', '6693623', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '氷上町中野', 'ヒカミチョウナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市氷上町三方', '28', '28223', '6693624', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '氷上町三方', 'ヒカミチョウミカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市氷上町中', '28', '28223', '6693625', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '氷上町中', 'ヒカミチョウナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市氷上町清住', '28', '28223', '6693626', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '氷上町清住', 'ヒカミチョウキヨズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市氷上町賀茂', '28', '28223', '6693631', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '氷上町賀茂', 'ヒカミチョウカモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市氷上町井中', '28', '28223', '6693632', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '氷上町井中', 'ヒカミチョウイナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市氷上町御油', '28', '28223', '6693633', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '氷上町御油', 'ヒカミチョウゴユ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市氷上町沼', '28', '28223', '6693634', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '氷上町沼', 'ヒカミチョウヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市氷上町絹山', '28', '28223', '6693641', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '氷上町絹山', 'ヒカミチョウキヌヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市氷上町香良', '28', '28223', '6693642', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '氷上町香良', 'ヒカミチョウコウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市氷上町伊佐口', '28', '28223', '6693643', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '氷上町伊佐口', 'ヒカミチョウイサクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市氷上町日比宇', '28', '28223', '6693644', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '氷上町日比宇', 'ヒカミチョウヒビウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市氷上町鴨内', '28', '28223', '6693645', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '氷上町鴨内', 'ヒカミチョウカモウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市氷上町小谷', '28', '28223', '6693646', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '氷上町小谷', 'ヒカミチョウコタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市氷上町氷上', '28', '28223', '6693651', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '氷上町氷上', 'ヒカミチョウヒカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市氷上町桟敷', '28', '28223', '6693652', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '氷上町桟敷', 'ヒカミチョウサジキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市氷上町北油良', '28', '28223', '6693653', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '氷上町北油良', 'ヒカミチョウキタユラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市氷上町南油良', '28', '28223', '6693654', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '氷上町南油良', 'ヒカミチョウミナミユラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市青垣町東芦田', '28', '28223', '6693801', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '青垣町東芦田', 'アオガキチョウヒガシアシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市青垣町栗住野', '28', '28223', '6693802', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '青垣町栗住野', 'アオガキチョウクリスノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市青垣町西芦田', '28', '28223', '6693803', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '青垣町西芦田', 'アオガキチョウニシアシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市青垣町田井縄', '28', '28223', '6693804', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '青垣町田井縄', 'アオガキチョウタイナワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市青垣町佐治', '28', '28223', '6693811', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '青垣町佐治', 'アオガキチョウサジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市青垣町小倉', '28', '28223', '6693812', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '青垣町小倉', 'アオガキチョウオグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市青垣町桧倉', '28', '28223', '6693821', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '青垣町桧倉', 'アオガキチョウヒノクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市青垣町大名草', '28', '28223', '6693822', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '青垣町大名草', 'アオガキチョウオナザ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市青垣町大稗', '28', '28223', '6693823', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '青垣町大稗', 'アオガキチョウオビエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市青垣町小稗', '28', '28223', '6693824', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '青垣町小稗', 'アオガキチョウコビエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市青垣町惣持', '28', '28223', '6693825', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '青垣町惣持', 'アオガキチョウソウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市青垣町文室', '28', '28223', '6693826', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '青垣町文室', 'アオガキチョウフムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市青垣町稲土', '28', '28223', '6693827', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '青垣町稲土', 'アオガキチョウイナヅチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市青垣町市原', '28', '28223', '6693831', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '青垣町市原', 'アオガキチョウイチバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市青垣町遠阪', '28', '28223', '6693832', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '青垣町遠阪', 'アオガキチョウトオザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市青垣町山垣', '28', '28223', '6693833', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '青垣町山垣', 'アオガキチョウヤマガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市青垣町中佐治', '28', '28223', '6693834', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '青垣町中佐治', 'アオガキチョウナカサジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市青垣町口塩久', '28', '28223', '6693841', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '青垣町口塩久', 'アオガキチョウクチシオク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市青垣町沢野', '28', '28223', '6693842', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '青垣町沢野', 'アオガキチョウサワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市青垣町奥塩久', '28', '28223', '6693843', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '青垣町奥塩久', 'アオガキチョウオクシオク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市春日町池尾', '28', '28223', '6694121', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '春日町池尾', 'カスガチョウイケオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市春日町小多利', '28', '28223', '6694122', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '春日町小多利', 'カスガチョウコダリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市春日町多利', '28', '28223', '6694123', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '春日町多利', 'カスガチョウタリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市春日町野上野', '28', '28223', '6694124', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '春日町野上野', 'カスガチョウノコノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市春日町多田', '28', '28223', '6694125', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '春日町多田', 'カスガチョウタダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市春日町七日市', '28', '28223', '6694131', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '春日町七日市', 'カスガチョウナヌカイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市春日町野村', '28', '28223', '6694132', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '春日町野村', 'カスガチョウノムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市春日町平松', '28', '28223', '6694133', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '春日町平松', 'カスガチョウヒラマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市春日町古河', '28', '28223', '6694134', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '春日町古河', 'カスガチョウフルカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市春日町稲塚', '28', '28223', '6694135', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '春日町稲塚', 'カスガチョウイナヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市春日町黒井', '28', '28223', '6694141', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '春日町黒井', 'カスガチョウクロイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市春日町上三井庄', '28', '28223', '6694251', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '春日町上三井庄', 'カスガチョウカミミノショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市春日町下三井庄', '28', '28223', '6694252', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '春日町下三井庄', 'カスガチョウシモミノショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市春日町鹿場', '28', '28223', '6694253', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '春日町鹿場', 'カスガチョウカンバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市春日町野瀬', '28', '28223', '6694261', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '春日町野瀬', 'カスガチョウノセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市春日町栢野', '28', '28223', '6694262', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '春日町栢野', 'カスガチョウカヤノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市春日町広瀬', '28', '28223', '6694263', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '春日町広瀬', 'カスガチョウヒロセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市春日町松森', '28', '28223', '6694264', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '春日町松森', 'カスガチョウマツモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市春日町中山', '28', '28223', '6694265', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '春日町中山', 'カスガチョウナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市春日町柚津', '28', '28223', '6694271', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '春日町柚津', 'カスガチョウユヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市春日町東中', '28', '28223', '6694272', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '春日町東中', 'カスガチョウヒガシナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市春日町国領', '28', '28223', '6694273', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '春日町国領', 'カスガチョウコクリョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市春日町棚原', '28', '28223', '6694274', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '春日町棚原', 'カスガチョウタナバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市市島町下竹田', '28', '28223', '6694301', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '市島町下竹田', 'イチジマチョウシモタケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市市島町中竹田', '28', '28223', '6694302', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '市島町中竹田', 'イチジマチョウナカタケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市市島町戸平', '28', '28223', '6694311', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '市島町戸平', 'イチジマチョウトベラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市市島町北奥', '28', '28223', '6694312', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '市島町北奥', 'イチジマチョウキタオク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市市島町多利', '28', '28223', '6694313', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '市島町多利', 'イチジマチョウタリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市市島町南', '28', '28223', '6694314', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '市島町南', 'イチジマチョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市市島町喜多', '28', '28223', '6694315', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '市島町喜多', 'イチジマチョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市市島町岩戸', '28', '28223', '6694316', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '市島町岩戸', 'イチジマチョウイワト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市市島町上牧', '28', '28223', '6694317', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '市島町上牧', 'イチジマチョウウエマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市市島町上垣', '28', '28223', '6694321', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '市島町上垣', 'イチジマチョウウエガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市市島町上田', '28', '28223', '6694322', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '市島町上田', 'イチジマチョウカミダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市市島町梶原', '28', '28223', '6694323', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '市島町梶原', 'イチジマチョウカジワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市市島町市島', '28', '28223', '6694324', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '市島町市島', 'イチジマチョウイチジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市市島町北岡本', '28', '28223', '6694325', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '市島町北岡本', 'イチジマチョウキタオカモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市市島町東勅使', '28', '28223', '6694331', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '市島町東勅使', 'イチジマチョウヒガシチョクシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市市島町勅使', '28', '28223', '6694332', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '市島町勅使', 'イチジマチョウチョクシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市市島町戸坂', '28', '28223', '6694333', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '市島町戸坂', 'イチジマチョウトサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市市島町白毫寺', '28', '28223', '6694334', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '市島町白毫寺', 'イチジマチョウビャクゴウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市市島町与戸', '28', '28223', '6694335', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '市島町与戸', 'イチジマチョウヨト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市市島町乙河内', '28', '28223', '6694336', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '市島町乙河内', 'イチジマチョウオトガワチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市市島町酒梨', '28', '28223', '6694337', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '市島町酒梨', 'イチジマチョウサナセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市市島町上竹田', '28', '28223', '6694341', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '市島町上竹田', 'イチジマチョウカミタケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市市島町矢代', '28', '28223', '6694342', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '市島町矢代', 'イチジマチョウヤシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市市島町下鴨阪', '28', '28223', '6694343', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '市島町下鴨阪', 'イチジマチョウシモカモサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市市島町上鴨阪', '28', '28223', '6694344', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '市島町上鴨阪', 'イチジマチョウカミカモサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県丹波市市島町徳尾', '28', '28223', '6694345', '兵庫県', 'ヒョウゴケン', '丹波市', 'タンバシ', '市島町徳尾', 'イチジマチョウトクオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市山東町滝田', '28', '28225', '6695101', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '山東町滝田', 'サントウチョウタキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市山東町大垣', '28', '28225', '6695102', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '山東町大垣', 'サントウチョウオオカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市山東町矢名瀬町', '28', '28225', '6695103', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '山東町矢名瀬町', 'サントウチョウヤナセマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市山東町末歳', '28', '28225', '6695104', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '山東町末歳', 'サントウチョウマッサイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市山東町新堂', '28', '28225', '6695111', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '山東町新堂', 'サントウチョウシンドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市山東町大内', '28', '28225', '6695112', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '山東町大内', 'サントウチョウオオウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市山東町塩田', '28', '28225', '6695113', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '山東町塩田', 'サントウチョウシオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市山東町野間', '28', '28225', '6695114', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '山東町野間', 'サントウチョウノマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市山東町金浦', '28', '28225', '6695115', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '山東町金浦', 'サントウチョウカナウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市山東町和賀', '28', '28225', '6695121', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '山東町和賀', 'サントウチョウワガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市山東町早田', '28', '28225', '6695122', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '山東町早田', 'サントウチョウワサダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市山東町一品', '28', '28225', '6695123', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '山東町一品', 'サントウチョウイッポウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市山東町柴', '28', '28225', '6695124', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '山東町柴', 'サントウチョウシバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市山東町粟鹿', '28', '28225', '6695125', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '山東町粟鹿', 'サントウチョウアワガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市山東町柊木', '28', '28225', '6695131', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '山東町柊木', 'サントウチョウヒイラギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市山東町溝黒', '28', '28225', '6695132', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '山東町溝黒', 'サントウチョウミゾクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市山東町喜多垣', '28', '28225', '6695133', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '山東町喜多垣', 'サントウチョウキタガキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市山東町迫間', '28', '28225', '6695134', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '山東町迫間', 'サントウチョウハサマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市山東町森', '28', '28225', '6695135', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '山東町森', 'サントウチョウモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市山東町与布土', '28', '28225', '6695136', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '山東町与布土', 'サントウチョウヨフド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市山東町三保', '28', '28225', '6695141', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '山東町三保', 'サントウチョウミホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市山東町越田', '28', '28225', '6695142', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '山東町越田', 'サントウチョウオッタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市山東町柿坪', '28', '28225', '6695143', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '山東町柿坪', 'サントウチョウカキツボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市山東町小谷', '28', '28225', '6695151', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '山東町小谷', 'サントウチョウコタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市山東町楽音寺', '28', '28225', '6695152', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '山東町楽音寺', 'サントウチョウガクオンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市山東町大月', '28', '28225', '6695153', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '山東町大月', 'サントウチョウオオツキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市', '28', '28225', '6695200', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('80433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市和田山町和田山', '28', '28225', '6695201', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '和田山町和田山', 'ワダヤマチョウワダヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市和田山町東谷', '28', '28225', '6695202', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '和田山町東谷', 'ワダヤマチョウヒガシダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市和田山町寺谷', '28', '28225', '6695203', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '和田山町寺谷', 'ワダヤマチョウテラダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市和田山町駅北', '28', '28225', '6695204', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '和田山町駅北', 'ワダヤマチョウエキキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市和田山町平野', '28', '28225', '6695211', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '和田山町平野', 'ワダヤマチョウヒラノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市和田山町柳原', '28', '28225', '6695212', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '和田山町柳原', 'ワダヤマチョウヤナギハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市和田山町玉置', '28', '28225', '6695213', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '和田山町玉置', 'ワダヤマチョウタマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市和田山町桑原', '28', '28225', '6695214', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '和田山町桑原', 'ワダヤマチョウクワバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市和田山町枚田岡', '28', '28225', '6695215', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '和田山町枚田岡', 'ワダヤマチョウヒラタオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市和田山町弥生が丘', '28', '28225', '6695216', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '和田山町弥生が丘', 'ワダヤマチョウヤヨイガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市和田山町白井', '28', '28225', '6695220', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '和田山町白井', 'ワダヤマチョウシライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市和田山町秋葉台', '28', '28225', '6695221', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '和田山町秋葉台', 'ワダヤマチョウアキバダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市和田山町万葉台', '28', '28225', '6695222', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '和田山町万葉台', 'ワダヤマチョウマンヨウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市和田山町室尾', '28', '28225', '6695223', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '和田山町室尾', 'ワダヤマチョウムロオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市和田山町岡田', '28', '28225', '6695224', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '和田山町岡田', 'ワダヤマチョウオカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市和田山町野村', '28', '28225', '6695225', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '和田山町野村', 'ワダヤマチョウノムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市和田山町中', '28', '28225', '6695226', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '和田山町中', 'ワダヤマチョウナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市和田山町東和田', '28', '28225', '6695227', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '和田山町東和田', 'ワダヤマチョウヒガシワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市和田山町久田和', '28', '28225', '6695228', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '和田山町久田和', 'ワダヤマチョウクダワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市和田山町宮', '28', '28225', '6695229', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '和田山町宮', 'ワダヤマチョウミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市和田山町林垣', '28', '28225', '6695231', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '和田山町林垣', 'ワダヤマチョウハヤシガキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市和田山町寺内', '28', '28225', '6695232', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '和田山町寺内', 'ワダヤマチョウテラウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市和田山町高生田', '28', '28225', '6695233', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '和田山町高生田', 'ワダヤマチョウタコウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市和田山町市場', '28', '28225', '6695234', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '和田山町市場', 'ワダヤマチョウイチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市和田山町和田', '28', '28225', '6695235', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '和田山町和田', 'ワダヤマチョウワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市和田山町内海', '28', '28225', '6695236', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '和田山町内海', 'ワダヤマチョウウツノミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市和田山町竹ノ内', '28', '28225', '6695237', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '和田山町竹ノ内', 'ワダヤマチョウタケノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市和田山町朝日', '28', '28225', '6695238', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '和田山町朝日', 'ワダヤマチョウアサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市和田山町土田', '28', '28225', '6695241', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '和田山町土田', 'ワダヤマチョウハンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市和田山町宮田', '28', '28225', '6695242', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '和田山町宮田', 'ワダヤマチョウミヤダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市和田山町高田', '28', '28225', '6695243', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '和田山町高田', 'ワダヤマチョウタカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市和田山町宮内', '28', '28225', '6695244', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '和田山町宮内', 'ワダヤマチョウミヤウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市和田山町法道寺', '28', '28225', '6695245', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '和田山町法道寺', 'ワダヤマチョウホウドウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市和田山町岡', '28', '28225', '6695246', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '和田山町岡', 'ワダヤマチョウオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市和田山町栄町', '28', '28225', '6695251', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '和田山町栄町', 'ワダヤマチョウサカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市和田山町竹田', '28', '28225', '6695252', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '和田山町竹田', 'ワダヤマチョウタケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市和田山町久世田', '28', '28225', '6695253', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '和田山町久世田', 'ワダヤマチョウクセダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市和田山町安井', '28', '28225', '6695254', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '和田山町安井', 'ワダヤマチョウヤスイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市和田山町殿', '28', '28225', '6695255', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '和田山町殿', 'ワダヤマチョウトノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市和田山町三波', '28', '28225', '6695256', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '和田山町三波', 'ワダヤマチョウサンナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市和田山町藤和', '28', '28225', '6695257', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '和田山町藤和', 'ワダヤマチョウフジワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市和田山町城南台', '28', '28225', '6695258', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '和田山町城南台', 'ワダヤマチョウジョウナンダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市和田山町枚田', '28', '28225', '6695261', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '和田山町枚田', 'ワダヤマチョウヒラタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市和田山町市御堂', '28', '28225', '6695262', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '和田山町市御堂', 'ワダヤマチョウイチミドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市和田山町久留引', '28', '28225', '6695263', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '和田山町久留引', 'ワダヤマチョウクルブキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市和田山町加都', '28', '28225', '6695264', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '和田山町加都', 'ワダヤマチョウカツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市和田山町筒江', '28', '28225', '6695265', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '和田山町筒江', 'ワダヤマチョウツツエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市和田山町比治', '28', '28225', '6695266', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '和田山町比治', 'ワダヤマチョウヒジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市和田山町法興寺', '28', '28225', '6695267', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '和田山町法興寺', 'ワダヤマチョウホツコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市和田山町立ノ原', '28', '28225', '6695268', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '和田山町立ノ原', 'ワダヤマチョウタツノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市日高町江原', '28', '28209', '6695301', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '日高町江原', 'ヒダカチョウエバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市日高町岩中', '28', '28209', '6695302', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '日高町岩中', 'ヒダカチョウイワナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市日高町東構', '28', '28209', '6695303', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '日高町東構', 'ヒダカチョウヒガシガマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市日高町宵田', '28', '28209', '6695304', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '日高町宵田', 'ヒダカチョウヨイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市日高町祢布', '28', '28209', '6695305', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '日高町祢布', 'ヒダカチョウニョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市日高町水上', '28', '28209', '6695306', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '日高町水上', 'ヒダカチョウミノカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市日高町松岡', '28', '28209', '6695307', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '日高町松岡', 'ヒダカチョウマツオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市日高町日置', '28', '28209', '6695311', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '日高町日置', 'ヒダカチョウヒオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市日高町日高', '28', '28209', '6695312', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '日高町日高', 'ヒダカチョウヒダカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市日高町鶴岡', '28', '28209', '6695313', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '日高町鶴岡', 'ヒダカチョウツルオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市日高町赤崎', '28', '28209', '6695314', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '日高町赤崎', 'ヒダカチョウアカサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市日高町浅倉', '28', '28209', '6695315', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '日高町浅倉', 'ヒダカチョウアサクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市日高町土居', '28', '28209', '6695321', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '日高町土居', 'ヒダカチョウドイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市日高町府市場', '28', '28209', '6695322', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '日高町府市場', 'ヒダカチョウフイチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市日高町府中新', '28', '28209', '6695323', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '日高町府中新', 'ヒダカチョウフチュウシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市日高町上郷', '28', '28209', '6695324', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '日高町上郷', 'ヒダカチョウカミノゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市日高町堀', '28', '28209', '6695325', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '日高町堀', 'ヒダカチョウホリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市日高町池上', '28', '28209', '6695326', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '日高町池上', 'ヒダカチョウイケガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市日高町野々庄', '28', '28209', '6695327', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '日高町野々庄', 'ヒダカチョウノノショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市日高町西芝', '28', '28209', '6695328', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '日高町西芝', 'ヒダカチョウニシシバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市日高町東芝', '28', '28209', '6695328', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '日高町東芝', 'ヒダカチョウヒガシシバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市日高町上石', '28', '28209', '6695331', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '日高町上石', 'ヒダカチョウアゲシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市日高町竹貫', '28', '28209', '6695332', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '日高町竹貫', 'ヒダカチョウタカヌキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市日高町藤井', '28', '28209', '6695333', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '日高町藤井', 'ヒダカチョウフジイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市日高町山本', '28', '28209', '6695334', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '日高町山本', 'ヒダカチョウヤマモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市日高町奈佐路', '28', '28209', '6695335', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '日高町奈佐路', 'ヒダカチョウナサジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市日高町谷', '28', '28209', '6695336', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '日高町谷', 'ヒダカチョウタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市日高町中', '28', '28209', '6695337', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '日高町中', 'ヒダカチョウナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市日高町猪爪', '28', '28209', '6695338', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '日高町猪爪', 'ヒダカチョウイノツメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市日高町大岡', '28', '28209', '6695339', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '日高町大岡', 'ヒダカチョウオオオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市日高町河江', '28', '28209', '6695339', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '日高町河江', 'ヒダカチョウカワエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市日高町小河江', '28', '28209', '6695339', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '日高町小河江', 'ヒダカチョウコガワエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市日高町八代', '28', '28209', '6695339', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '日高町八代', 'ヒダカチョウヤシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市日高町国分寺', '28', '28209', '6695341', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '日高町国分寺', 'ヒダカチョウコクブンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市日高町久斗', '28', '28209', '6695342', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '日高町久斗', 'ヒダカチョウクト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市日高町道場', '28', '28209', '6695343', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '日高町道場', 'ヒダカチョウドウジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市日高町夏栗', '28', '28209', '6695344', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '日高町夏栗', 'ヒダカチョウナツクリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市日高町久田谷', '28', '28209', '6695345', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '日高町久田谷', 'ヒダカチョウクタダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市日高町伊府', '28', '28209', '6695346', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '日高町伊府', 'ヒダカチョウイブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市日高町佐田', '28', '28209', '6695351', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '日高町佐田', 'ヒダカチョウサタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市日高町知見', '28', '28209', '6695352', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '日高町知見', 'ヒダカチョウチミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市日高町森山', '28', '28209', '6695353', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '日高町森山', 'ヒダカチョウモリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市日高町観音寺', '28', '28209', '6695354', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '日高町観音寺', 'ヒダカチョウカンノンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市日高町篠垣', '28', '28209', '6695355', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '日高町篠垣', 'ヒダカチョウシノガキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市日高町荒川', '28', '28209', '6695356', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '日高町荒川', 'ヒダカチョウアラカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市日高町猪子垣', '28', '28209', '6695357', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '日高町猪子垣', 'ヒダカチョウイノコガキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市日高町田ノ口', '28', '28209', '6695357', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '日高町田ノ口', 'ヒダカチョウタノクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市日高町殿', '28', '28209', '6695358', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '日高町殿', 'ヒダカチョウトノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市日高町広井', '28', '28209', '6695358', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '日高町広井', 'ヒダカチョウヒロイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市日高町羽尻', '28', '28209', '6695359', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '日高町羽尻', 'ヒダカチョウハジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市日高町栗山', '28', '28209', '6695361', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '日高町栗山', 'ヒダカチョウクリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市日高町芝', '28', '28209', '6695362', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '日高町芝', 'ヒダカチョウシバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市日高町野', '28', '28209', '6695363', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '日高町野', 'ヒダカチョウノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市日高町庄境', '28', '28209', '6695364', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '日高町庄境', 'ヒダカチョウショウザカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市日高町十戸', '28', '28209', '6695365', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '日高町十戸', 'ヒダカチョウジュウゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市日高町頃垣', '28', '28209', '6695366', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '日高町頃垣', 'ヒダカチョウコロガキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市日高町石井', '28', '28209', '6695367', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '日高町石井', 'ヒダカチョウイシイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市日高町山宮', '28', '28209', '6695368', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '日高町山宮', 'ヒダカチョウヤマノミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市日高町栃本', '28', '28209', '6695369', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '日高町栃本', 'ヒダカチョウトチモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市日高町太田', '28', '28209', '6695371', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '日高町太田', 'ヒダカチョウタダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市日高町栗栖野', '28', '28209', '6695372', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '日高町栗栖野', 'ヒダカチョウクリスノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市日高町東河内', '28', '28209', '6695373', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '日高町東河内', 'ヒダカチョウヒガシゴウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市日高町水口', '28', '28209', '6695374', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '日高町水口', 'ヒダカチョウミノクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市日高町稲葉', '28', '28209', '6695375', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '日高町稲葉', 'ヒダカチョウイナンバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市日高町万劫', '28', '28209', '6695376', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '日高町万劫', 'ヒダカチョウマンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市日高町山田', '28', '28209', '6695377', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '日高町山田', 'ヒダカチョウヤマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市日高町万場', '28', '28209', '6695378', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '日高町万場', 'ヒダカチョウマンバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市日高町名色', '28', '28209', '6695379', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '日高町名色', 'ヒダカチョウナシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市城崎町湯島', '28', '28209', '6696101', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '城崎町湯島', 'キノサキチョウユシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市城崎町桃島', '28', '28209', '6696102', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '城崎町桃島', 'キノサキチョウモモシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市城崎町今津', '28', '28209', '6696103', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '城崎町今津', 'キノサキチョウイマヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市城崎町楽々浦', '28', '28209', '6696111', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '城崎町楽々浦', 'キノサキチョウササウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市城崎町飯谷', '28', '28209', '6696112', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '城崎町飯谷', 'キノサキチョウハンダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市城崎町結', '28', '28209', '6696113', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '城崎町結', 'キノサキチョウムスブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市城崎町戸島', '28', '28209', '6696114', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '城崎町戸島', 'キノサキチョウトシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市城崎町来日', '28', '28209', '6696115', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '城崎町来日', 'キノサキチョウクルヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市城崎町上山', '28', '28209', '6696116', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '城崎町上山', 'キノサキチョウウヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市津居山', '28', '28209', '6696121', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '津居山', 'ツイヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市瀬戸', '28', '28209', '6696122', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '瀬戸', 'セト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市小島', '28', '28209', '6696123', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '小島', 'オシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市気比', '28', '28209', '6696124', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '気比', 'ケヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市田結', '28', '28209', '6696125', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '田結', 'タイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市三原', '28', '28209', '6696126', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '三原', 'ミハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市畑上', '28', '28209', '6696127', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '畑上', 'ハタガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市竹野町竹野', '28', '28209', '6696201', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '竹野町竹野', 'タケノチョウタケノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市竹野町宇日', '28', '28209', '6696202', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '竹野町宇日', 'タケノチョウウヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市竹野町田久日', '28', '28209', '6696203', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '竹野町田久日', 'タケノチョウタクヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市竹野町和田', '28', '28209', '6696211', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '竹野町和田', 'タケノチョウワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市竹野町松本', '28', '28209', '6696212', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '竹野町松本', 'タケノチョウマツモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市竹野町羽入', '28', '28209', '6696213', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '竹野町羽入', 'タケノチョウハニュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市竹野町阿金谷', '28', '28209', '6696214', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '竹野町阿金谷', 'タケノチョウアコンダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市竹野町草飼', '28', '28209', '6696215', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '竹野町草飼', 'タケノチョウクサカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市竹野町切浜', '28', '28209', '6696216', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '竹野町切浜', 'タケノチョウキリハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市竹野町浜須井', '28', '28209', '6696217', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '竹野町浜須井', 'タケノチョウハマスイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市竹野町奥須井', '28', '28209', '6696218', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '竹野町奥須井', 'タケノチョウオクスイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市竹野町須谷', '28', '28209', '6696221', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '竹野町須谷', 'タケノチョウスダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市竹野町小丸', '28', '28209', '6696222', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '竹野町小丸', 'タケノチョウコマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市竹野町芦谷', '28', '28209', '6696223', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '竹野町芦谷', 'タケノチョウアシダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市竹野町鬼神谷', '28', '28209', '6696224', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '竹野町鬼神谷', 'タケノチョウオジンダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市竹野町轟', '28', '28209', '6696225', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '竹野町轟', 'タケノチョウトドロキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市竹野町下塚', '28', '28209', '6696226', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '竹野町下塚', 'タケノチョウシモヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市竹野町林', '28', '28209', '6696227', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '竹野町林', 'タケノチョウハヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市竹野町東大谷', '28', '28209', '6696228', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '竹野町東大谷', 'タケノチョウヒガシオオタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市竹野町金原', '28', '28209', '6696229', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '竹野町金原', 'タケノチョウキンバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市竹野町坊岡', '28', '28209', '6696331', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '竹野町坊岡', 'タケノチョウボウオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市竹野町森本', '28', '28209', '6696332', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '竹野町森本', 'タケノチョウモリモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市竹野町御又', '28', '28209', '6696333', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '竹野町御又', 'タケノチョウオンマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市竹野町河内', '28', '28209', '6696334', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '竹野町河内', 'タケノチョウカワチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市竹野町門谷', '28', '28209', '6696335', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '竹野町門谷', 'タケノチョウモンダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市竹野町小城', '28', '28209', '6696341', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '竹野町小城', 'タケノチョウコジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市竹野町二連原', '28', '28209', '6696342', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '竹野町二連原', 'タケノチョウニレンバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市竹野町段', '28', '28209', '6696343', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '竹野町段', 'タケノチョウダン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市竹野町椒', '28', '28209', '6696344', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '竹野町椒', 'タケノチョウハジカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市竹野町須野谷', '28', '28209', '6696351', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '竹野町須野谷', 'タケノチョウスノタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市竹野町大森', '28', '28209', '6696352', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '竹野町大森', 'タケノチョウオオモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市竹野町桑野本', '28', '28209', '6696353', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '竹野町桑野本', 'タケノチョウクワノモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市竹野町川南谷', '28', '28209', '6696354', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '竹野町川南谷', 'タケノチョウカナンダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県豊岡市竹野町三原', '28', '28209', '6696355', '兵庫県', 'ヒョウゴケン', '豊岡市', 'トヨオカシ', '竹野町三原', 'タケノチョウミハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡香美町香住区無南垣', '28', '28585', '6696401', '兵庫県', 'ヒョウゴケン', '美方郡香美町', 'ミカタグンカミチョウ', '香住区無南垣', 'カスミクムナガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡香美町香住区訓谷', '28', '28585', '6696402', '兵庫県', 'ヒョウゴケン', '美方郡香美町', 'ミカタグンカミチョウ', '香住区訓谷', 'カスミククンダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡香美町香住区安木', '28', '28585', '6696403', '兵庫県', 'ヒョウゴケン', '美方郡香美町', 'ミカタグンカミチョウ', '香住区安木', 'カスミクヤスギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡香美町香住区相谷', '28', '28585', '6696404', '兵庫県', 'ヒョウゴケン', '美方郡香美町', 'ミカタグンカミチョウ', '香住区相谷', 'カスミクアイダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡香美町香住区九斗', '28', '28585', '6696411', '兵庫県', 'ヒョウゴケン', '美方郡香美町', 'ミカタグンカミチョウ', '香住区九斗', 'カスミククト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡香美町香住区米地', '28', '28585', '6696412', '兵庫県', 'ヒョウゴケン', '美方郡香美町', 'ミカタグンカミチョウ', '香住区米地', 'カスミクメジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡香美町香住区下岡', '28', '28585', '6696413', '兵庫県', 'ヒョウゴケン', '美方郡香美町', 'ミカタグンカミチョウ', '香住区下岡', 'カスミクシモオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡香美町香住区上岡', '28', '28585', '6696414', '兵庫県', 'ヒョウゴケン', '美方郡香美町', 'ミカタグンカミチョウ', '香住区上岡', 'カスミクカミオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡香美町香住区西下岡', '28', '28585', '6696415', '兵庫県', 'ヒョウゴケン', '美方郡香美町', 'ミカタグンカミチョウ', '香住区西下岡', 'カスミクニシシモオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡香美町香住区丹生地', '28', '28585', '6696416', '兵庫県', 'ヒョウゴケン', '美方郡香美町', 'ミカタグンカミチョウ', '香住区丹生地', 'カスミクニウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡香美町香住区本見塚', '28', '28585', '6696421', '兵庫県', 'ヒョウゴケン', '美方郡香美町', 'ミカタグンカミチョウ', '香住区本見塚', 'カスミクモトミヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡香美町香住区土生', '28', '28585', '6696422', '兵庫県', 'ヒョウゴケン', '美方郡香美町', 'ミカタグンカミチョウ', '香住区土生', 'カスミクハブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡香美町香住区畑', '28', '28585', '6696423', '兵庫県', 'ヒョウゴケン', '美方郡香美町', 'ミカタグンカミチョウ', '香住区畑', 'カスミクハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡香美町香住区隼人', '28', '28585', '6696424', '兵庫県', 'ヒョウゴケン', '美方郡香美町', 'ミカタグンカミチョウ', '香住区隼人', 'カスミクハヤト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡香美町香住区大梶', '28', '28585', '6696425', '兵庫県', 'ヒョウゴケン', '美方郡香美町', 'ミカタグンカミチョウ', '香住区大梶', 'カスミクオオカジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡香美町香住区三川', '28', '28585', '6696426', '兵庫県', 'ヒョウゴケン', '美方郡香美町', 'ミカタグンカミチョウ', '香住区三川', 'カスミクミカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡香美町香住区浦上', '28', '28585', '6696431', '兵庫県', 'ヒョウゴケン', '美方郡香美町', 'ミカタグンカミチョウ', '香住区浦上', 'カスミクウラガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡香美町香住区上計', '28', '28585', '6696432', '兵庫県', 'ヒョウゴケン', '美方郡香美町', 'ミカタグンカミチョウ', '香住区上計', 'カスミクアゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡香美町香住区沖浦', '28', '28585', '6696433', '兵庫県', 'ヒョウゴケン', '美方郡香美町', 'ミカタグンカミチョウ', '香住区沖浦', 'カスミクオキノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡香美町', '28', '28585', '6696500', '兵庫県', 'ヒョウゴケン', '美方郡香美町', 'ミカタグンカミチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('80627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡香美町香住区境', '28', '28585', '6696541', '兵庫県', 'ヒョウゴケン', '美方郡香美町', 'ミカタグンカミチョウ', '香住区境', 'カスミクサカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡香美町香住区一日市', '28', '28585', '6696542', '兵庫県', 'ヒョウゴケン', '美方郡香美町', 'ミカタグンカミチョウ', '香住区一日市', 'カスミクヒトイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡香美町香住区若松', '28', '28585', '6696543', '兵庫県', 'ヒョウゴケン', '美方郡香美町', 'ミカタグンカミチョウ', '香住区若松', 'カスミクワカマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡香美町香住区香住', '28', '28585', '6696544', '兵庫県', 'ヒョウゴケン', '美方郡香美町', 'ミカタグンカミチョウ', '香住区香住', 'カスミクカスミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡香美町香住区森', '28', '28585', '6696545', '兵庫県', 'ヒョウゴケン', '美方郡香美町', 'ミカタグンカミチョウ', '香住区森', 'カスミクモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡香美町香住区七日市', '28', '28585', '6696546', '兵庫県', 'ヒョウゴケン', '美方郡香美町', 'ミカタグンカミチョウ', '香住区七日市', 'カスミクナヌカイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡香美町香住区守柄', '28', '28585', '6696551', '兵庫県', 'ヒョウゴケン', '美方郡香美町', 'ミカタグンカミチョウ', '香住区守柄', 'カスミクスカラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡香美町香住区加鹿野', '28', '28585', '6696552', '兵庫県', 'ヒョウゴケン', '美方郡香美町', 'ミカタグンカミチョウ', '香住区加鹿野', 'カスミクカジカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡香美町香住区三谷', '28', '28585', '6696553', '兵庫県', 'ヒョウゴケン', '美方郡香美町', 'ミカタグンカミチョウ', '香住区三谷', 'カスミクミタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡香美町香住区大谷', '28', '28585', '6696554', '兵庫県', 'ヒョウゴケン', '美方郡香美町', 'ミカタグンカミチョウ', '香住区大谷', 'カスミクオオダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡香美町香住区大野', '28', '28585', '6696555', '兵庫県', 'ヒョウゴケン', '美方郡香美町', 'ミカタグンカミチョウ', '香住区大野', 'カスミクオオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡香美町香住区中野', '28', '28585', '6696556', '兵庫県', 'ヒョウゴケン', '美方郡香美町', 'ミカタグンカミチョウ', '香住区中野', 'カスミクナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡香美町香住区藤', '28', '28585', '6696557', '兵庫県', 'ヒョウゴケン', '美方郡香美町', 'ミカタグンカミチョウ', '香住区藤', 'カスミクフジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡香美町香住区八原', '28', '28585', '6696558', '兵庫県', 'ヒョウゴケン', '美方郡香美町', 'ミカタグンカミチョウ', '香住区八原', 'カスミクヤハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡香美町香住区小原', '28', '28585', '6696559', '兵庫県', 'ヒョウゴケン', '美方郡香美町', 'ミカタグンカミチョウ', '香住区小原', 'カスミクコバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡香美町香住区間室', '28', '28585', '6696561', '兵庫県', 'ヒョウゴケン', '美方郡香美町', 'ミカタグンカミチョウ', '香住区間室', 'カスミクマムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡香美町香住区油良', '28', '28585', '6696562', '兵庫県', 'ヒョウゴケン', '美方郡香美町', 'ミカタグンカミチョウ', '香住区油良', 'カスミクユラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡香美町香住区矢田', '28', '28585', '6696563', '兵庫県', 'ヒョウゴケン', '美方郡香美町', 'ミカタグンカミチョウ', '香住区矢田', 'カスミクヤダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡香美町香住区下浜', '28', '28585', '6696564', '兵庫県', 'ヒョウゴケン', '美方郡香美町', 'ミカタグンカミチョウ', '香住区下浜', 'カスミクシモノハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡香美町香住区余部', '28', '28585', '6696671', '兵庫県', 'ヒョウゴケン', '美方郡香美町', 'ミカタグンカミチョウ', '香住区余部', 'カスミクアマルベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡香美町香住区鎧', '28', '28585', '6696672', '兵庫県', 'ヒョウゴケン', '美方郡香美町', 'ミカタグンカミチョウ', '香住区鎧', 'カスミクヨロイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡新温泉町', '28', '28586', '6696700', '兵庫県', 'ヒョウゴケン', '美方郡新温泉町', 'ミカタグンシンオンセンチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('80650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡新温泉町芦屋', '28', '28586', '6696701', '兵庫県', 'ヒョウゴケン', '美方郡新温泉町', 'ミカタグンシンオンセンチョウ', '芦屋', 'アシヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡新温泉町浜坂', '28', '28586', '6696702', '兵庫県', 'ヒョウゴケン', '美方郡新温泉町', 'ミカタグンシンオンセンチョウ', '浜坂', 'ハマサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡新温泉町清富', '28', '28586', '6696711', '兵庫県', 'ヒョウゴケン', '美方郡新温泉町', 'ミカタグンシンオンセンチョウ', '清富', 'キヨトミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡新温泉町指杭', '28', '28586', '6696712', '兵庫県', 'ヒョウゴケン', '美方郡新温泉町', 'ミカタグンシンオンセンチョウ', '指杭', 'サシクイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡新温泉町田井', '28', '28586', '6696713', '兵庫県', 'ヒョウゴケン', '美方郡新温泉町', 'ミカタグンシンオンセンチョウ', '田井', 'タイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡新温泉町赤崎', '28', '28586', '6696714', '兵庫県', 'ヒョウゴケン', '美方郡新温泉町', 'ミカタグンシンオンセンチョウ', '赤崎', 'アカサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡新温泉町三尾', '28', '28586', '6696715', '兵庫県', 'ヒョウゴケン', '美方郡新温泉町', 'ミカタグンシンオンセンチョウ', '三尾', 'ミオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡新温泉町和田', '28', '28586', '6696716', '兵庫県', 'ヒョウゴケン', '美方郡新温泉町', 'ミカタグンシンオンセンチョウ', '和田', 'ワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡新温泉町久谷', '28', '28586', '6696721', '兵庫県', 'ヒョウゴケン', '美方郡新温泉町', 'ミカタグンシンオンセンチョウ', '久谷', 'クタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡新温泉町高末', '28', '28586', '6696722', '兵庫県', 'ヒョウゴケン', '美方郡新温泉町', 'ミカタグンシンオンセンチョウ', '高末', 'タカスエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡新温泉町正法庵', '28', '28586', '6696723', '兵庫県', 'ヒョウゴケン', '美方郡新温泉町', 'ミカタグンシンオンセンチョウ', '正法庵', 'ショウボウアン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡新温泉町辺地', '28', '28586', '6696724', '兵庫県', 'ヒョウゴケン', '美方郡新温泉町', 'ミカタグンシンオンセンチョウ', '辺地', 'ヘッチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡新温泉町藤尾', '28', '28586', '6696725', '兵庫県', 'ヒョウゴケン', '美方郡新温泉町', 'ミカタグンシンオンセンチョウ', '藤尾', 'フジオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡新温泉町境', '28', '28586', '6696726', '兵庫県', 'ヒョウゴケン', '美方郡新温泉町', 'ミカタグンシンオンセンチョウ', '境', 'サカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡新温泉町久斗山', '28', '28586', '6696727', '兵庫県', 'ヒョウゴケン', '美方郡新温泉町', 'ミカタグンシンオンセンチョウ', '久斗山', 'クトヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡新温泉町対田', '28', '28586', '6696728', '兵庫県', 'ヒョウゴケン', '美方郡新温泉町', 'ミカタグンシンオンセンチョウ', '対田', 'タイタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡新温泉町二日市', '28', '28586', '6696731', '兵庫県', 'ヒョウゴケン', '美方郡新温泉町', 'ミカタグンシンオンセンチョウ', '二日市', 'フツカイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡新温泉町福富', '28', '28586', '6696732', '兵庫県', 'ヒョウゴケン', '美方郡新温泉町', 'ミカタグンシンオンセンチョウ', '福富', 'フクトミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡新温泉町七釜', '28', '28586', '6696741', '兵庫県', 'ヒョウゴケン', '美方郡新温泉町', 'ミカタグンシンオンセンチョウ', '七釜', 'シチカマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡新温泉町新市', '28', '28586', '6696742', '兵庫県', 'ヒョウゴケン', '美方郡新温泉町', 'ミカタグンシンオンセンチョウ', '新市', 'シンイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡新温泉町古市', '28', '28586', '6696743', '兵庫県', 'ヒョウゴケン', '美方郡新温泉町', 'ミカタグンシンオンセンチョウ', '古市', 'フルイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡新温泉町用土', '28', '28586', '6696744', '兵庫県', 'ヒョウゴケン', '美方郡新温泉町', 'ミカタグンシンオンセンチョウ', '用土', 'ヨウド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡新温泉町栃谷', '28', '28586', '6696745', '兵庫県', 'ヒョウゴケン', '美方郡新温泉町', 'ミカタグンシンオンセンチョウ', '栃谷', 'トチダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡新温泉町戸田', '28', '28586', '6696746', '兵庫県', 'ヒョウゴケン', '美方郡新温泉町', 'ミカタグンシンオンセンチョウ', '戸田', 'ヘダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡新温泉町三谷', '28', '28586', '6696747', '兵庫県', 'ヒョウゴケン', '美方郡新温泉町', 'ミカタグンシンオンセンチョウ', '三谷', 'ミタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡新温泉町居組', '28', '28586', '6696751', '兵庫県', 'ヒョウゴケン', '美方郡新温泉町', 'ミカタグンシンオンセンチョウ', '居組', 'イグミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡新温泉町釜屋', '28', '28586', '6696752', '兵庫県', 'ヒョウゴケン', '美方郡新温泉町', 'ミカタグンシンオンセンチョウ', '釜屋', 'カマヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡新温泉町諸寄', '28', '28586', '6696753', '兵庫県', 'ヒョウゴケン', '美方郡新温泉町', 'ミカタグンシンオンセンチョウ', '諸寄', 'モロヨセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡新温泉町竹田後山', '28', '28586', '6696761', '兵庫県', 'ヒョウゴケン', '美方郡新温泉町', 'ミカタグンシンオンセンチョウ', '竹田', 'タケダ', null, null, '後山', 'ウシロヤマ');
INSERT INTO `ms_addresses` VALUES ('80679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡新温泉町竹田細見谷', '28', '28586', '6696761', '兵庫県', 'ヒョウゴケン', '美方郡新温泉町', 'ミカタグンシンオンセンチョウ', '竹田', 'タケダ', null, null, '細見谷', 'ホソミダニ');
INSERT INTO `ms_addresses` VALUES ('80681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡新温泉町井土', '28', '28586', '6696801', '兵庫県', 'ヒョウゴケン', '美方郡新温泉町', 'ミカタグンシンオンセンチョウ', '井土', 'イド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡新温泉町金屋', '28', '28586', '6696802', '兵庫県', 'ヒョウゴケン', '美方郡新温泉町', 'ミカタグンシンオンセンチョウ', '金屋', 'カナヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡新温泉町今岡', '28', '28586', '6696803', '兵庫県', 'ヒョウゴケン', '美方郡新温泉町', 'ミカタグンシンオンセンチョウ', '今岡', 'イマオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡新温泉町熊谷', '28', '28586', '6696804', '兵庫県', 'ヒョウゴケン', '美方郡新温泉町', 'ミカタグンシンオンセンチョウ', '熊谷', 'クマダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡新温泉町伊角', '28', '28586', '6696805', '兵庫県', 'ヒョウゴケン', '美方郡新温泉町', 'ミカタグンシンオンセンチョウ', '伊角', 'イスミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡新温泉町桧尾', '28', '28586', '6696806', '兵庫県', 'ヒョウゴケン', '美方郡新温泉町', 'ミカタグンシンオンセンチョウ', '桧尾', 'ヒノキオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡新温泉町春来', '28', '28586', '6696807', '兵庫県', 'ヒョウゴケン', '美方郡新温泉町', 'ミカタグンシンオンセンチョウ', '春来', 'ハルキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡新温泉町歌長', '28', '28586', '6696808', '兵庫県', 'ヒョウゴケン', '美方郡新温泉町', 'ミカタグンシンオンセンチョウ', '歌長', 'ウタオサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡新温泉町多子', '28', '28586', '6696811', '兵庫県', 'ヒョウゴケン', '美方郡新温泉町', 'ミカタグンシンオンセンチョウ', '多子', 'オイゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡新温泉町切畑', '28', '28586', '6696812', '兵庫県', 'ヒョウゴケン', '美方郡新温泉町', 'ミカタグンシンオンセンチョウ', '切畑', 'キリハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡新温泉町丹土', '28', '28586', '6696813', '兵庫県', 'ヒョウゴケン', '美方郡新温泉町', 'ミカタグンシンオンセンチョウ', '丹土', 'タンド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡新温泉町中辻', '28', '28586', '6696814', '兵庫県', 'ヒョウゴケン', '美方郡新温泉町', 'ミカタグンシンオンセンチョウ', '中辻', 'ナカツジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡新温泉町桐岡', '28', '28586', '6696815', '兵庫県', 'ヒョウゴケン', '美方郡新温泉町', 'ミカタグンシンオンセンチョウ', '桐岡', 'キリオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡新温泉町湯', '28', '28586', '6696821', '兵庫県', 'ヒョウゴケン', '美方郡新温泉町', 'ミカタグンシンオンセンチョウ', '湯', 'ユ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡新温泉町細田', '28', '28586', '6696822', '兵庫県', 'ヒョウゴケン', '美方郡新温泉町', 'ミカタグンシンオンセンチョウ', '細田', 'ホソダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡新温泉町竹田', '28', '28586', '6696831', '兵庫県', 'ヒョウゴケン', '美方郡新温泉町', 'ミカタグンシンオンセンチョウ', '竹田', 'タケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡新温泉町飯野', '28', '28586', '6696832', '兵庫県', 'ヒョウゴケン', '美方郡新温泉町', 'ミカタグンシンオンセンチョウ', '飯野', 'イイノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡新温泉町塩山', '28', '28586', '6696833', '兵庫県', 'ヒョウゴケン', '美方郡新温泉町', 'ミカタグンシンオンセンチョウ', '塩山', 'シオヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡新温泉町千原', '28', '28586', '6696941', '兵庫県', 'ヒョウゴケン', '美方郡新温泉町', 'ミカタグンシンオンセンチョウ', '千原', 'チハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡新温泉町鐘尾', '28', '28586', '6696942', '兵庫県', 'ヒョウゴケン', '美方郡新温泉町', 'ミカタグンシンオンセンチョウ', '鐘尾', 'カネオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡新温泉町千谷', '28', '28586', '6696943', '兵庫県', 'ヒョウゴケン', '美方郡新温泉町', 'ミカタグンシンオンセンチョウ', '千谷', 'チダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡新温泉町宮脇', '28', '28586', '6696944', '兵庫県', 'ヒョウゴケン', '美方郡新温泉町', 'ミカタグンシンオンセンチョウ', '宮脇', 'ミヤワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡新温泉町内山', '28', '28586', '6696945', '兵庫県', 'ヒョウゴケン', '美方郡新温泉町', 'ミカタグンシンオンセンチョウ', '内山', 'ウチヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡新温泉町越坂', '28', '28586', '6696946', '兵庫県', 'ヒョウゴケン', '美方郡新温泉町', 'ミカタグンシンオンセンチョウ', '越坂', 'オッサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡新温泉町前', '28', '28586', '6696951', '兵庫県', 'ヒョウゴケン', '美方郡新温泉町', 'ミカタグンシンオンセンチョウ', '前', 'マエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡新温泉町海上', '28', '28586', '6696952', '兵庫県', 'ヒョウゴケン', '美方郡新温泉町', 'ミカタグンシンオンセンチョウ', '海上', 'ウミガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡新温泉町石橋', '28', '28586', '6696953', '兵庫県', 'ヒョウゴケン', '美方郡新温泉町', 'ミカタグンシンオンセンチョウ', '石橋', 'イシバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県美方郡新温泉町岸田', '28', '28586', '6696954', '兵庫県', 'ヒョウゴケン', '美方郡新温泉町', 'ミカタグンシンオンセンチョウ', '岸田', 'キシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道江別市', '01', '01217', '0670000', '北海道', 'ホッカイドウ', '江別市', 'エベツシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('80711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市', '28', '28201', '6700000', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('80712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市河間町', '28', '28201', '6700001', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '河間町', 'コバサマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市鍛冶町', '28', '28201', '6700002', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '鍛冶町', 'カジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市米屋町', '28', '28201', '6700003', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '米屋町', 'コメヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市福本町', '28', '28201', '6700004', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '福本町', 'フクモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市金屋町', '28', '28201', '6700005', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '金屋町', 'カナヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市八木町', '28', '28201', '6700006', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '八木町', 'ヤギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市生野町', '28', '28201', '6700007', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '生野町', 'イクノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市橋之町', '28', '28201', '6700008', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '橋之町', 'ハシノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市鍵町', '28', '28201', '6700009', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '鍵町', 'カギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道江別市王子', '01', '01217', '0670001', '北海道', 'ホッカイドウ', '江別市', 'エベツシ', '王子', 'オウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市坊主町', '28', '28201', '6700011', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '坊主町', 'ボウズマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市本町', '28', '28201', '6700012', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市竹田町', '28', '28201', '6700013', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '竹田町', 'タケダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市堺町', '28', '28201', '6700014', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '堺町', 'サカイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市総社本町', '28', '28201', '6700015', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '総社本町', 'ソウジャホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市坂元町', '28', '28201', '6700016', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '坂元町', 'サカモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市福中町', '28', '28201', '6700017', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '福中町', 'フクナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道江別市緑町西', '01', '01217', '0670002', '北海道', 'ホッカイドウ', '江別市', 'エベツシ', '緑町西', 'ミドリマチニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市山野井町', '28', '28201', '6700021', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '山野井町', 'ヤマノイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市小利木町', '28', '28201', '6700022', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '小利木町', 'コリキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市柳町', '28', '28201', '6700023', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '柳町', 'ヤナギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市鷹匠町', '28', '28201', '6700024', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '鷹匠町', 'タカジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市材木町', '28', '28201', '6700025', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '材木町', 'ザイモクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市岡町', '28', '28201', '6700026', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '岡町', 'オカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市景福寺前', '28', '28201', '6700027', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '景福寺前', 'ケイフクジマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市岩端町', '28', '28201', '6700028', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '岩端町', 'イワバナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市嵐山町', '28', '28201', '6700029', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '嵐山町', 'アラシヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道江別市緑町東', '01', '01217', '0670003', '北海道', 'ホッカイドウ', '江別市', 'エベツシ', '緑町東', 'ミドリマチヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市吉田町', '28', '28201', '6700031', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '吉田町', 'ヨシダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市龍野町', '28', '28201', '6700032', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '龍野町', 'タツノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市西新町', '28', '28201', '6700033', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '西新町', 'ニシシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市船丘町', '28', '28201', '6700034', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '船丘町', 'フナオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市琴岡町', '28', '28201', '6700035', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '琴岡町', 'コトオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市山畑新田', '28', '28201', '6700036', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '山畑新田', 'ヤマハタシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市柿山伏', '28', '28201', '6700037', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '柿山伏', 'カキヤマブシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市農人町', '28', '28201', '6700038', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '農人町', 'ノウニンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道江別市若草町', '01', '01217', '0670004', '北海道', 'ホッカイドウ', '江別市', 'エベツシ', '若草町', 'ワカクサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市上片町', '28', '28201', '6700041', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '上片町', 'カミカタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市米田町', '28', '28201', '6700042', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '米田町', 'ヨネダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市小姓町', '28', '28201', '6700043', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '小姓町', 'コショウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市地内町', '28', '28201', '6700044', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '地内町', 'ジナイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市片田町', '28', '28201', '6700045', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '片田町', 'カタダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市東雲町', '28', '28201', '6700046', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '東雲町', 'シノノメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市花影町', '28', '28201', '6700047', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '花影町', 'ハナカゲチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市船橋町', '28', '28201', '6700048', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '船橋町', 'フナハシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市元町', '28', '28201', '6700049', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '元町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道江別市牧場町', '01', '01217', '0670005', '北海道', 'ホッカイドウ', '江別市', 'エベツシ', '牧場町', 'マキバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市名古山町', '28', '28201', '6700051', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '名古山町', 'ナゴヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市今宿', '28', '28201', '6700052', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '今宿', 'イマジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市南車崎', '28', '28201', '6700053', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '南車崎', 'ミナミクルマザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市南今宿', '28', '28201', '6700054', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '南今宿', 'ミナミイマジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市神子岡前', '28', '28201', '6700055', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '神子岡前', 'ミコオカマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市東今宿', '28', '28201', '6700056', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '東今宿', 'ヒガシイマジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市北今宿', '28', '28201', '6700057', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '北今宿', 'キタイマジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市車崎', '28', '28201', '6700058', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '車崎', 'クルマザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市西今宿', '28', '28201', '6700061', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '西今宿', 'ニシイマジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市高岡新町', '28', '28201', '6700062', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '高岡新町', 'タカオカシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市下手野', '28', '28201', '6700063', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '下手野', 'シモテノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市東夢前台', '28', '28201', '6700064', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '東夢前台', 'ヒガシユメサキダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市上手野', '28', '28201', '6700065', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '上手野', 'カミテノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市藤ケ台', '28', '28201', '6700066', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '藤ケ台', 'フジガダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市御立北', '28', '28201', '6700071', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '御立北', 'ミタチキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市御立東', '28', '28201', '6700072', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '御立東', 'ミタチヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市御立中', '28', '28201', '6700073', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '御立中', 'ミタチナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市御立西', '28', '28201', '6700074', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '御立西', 'ミタチニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市北夢前台', '28', '28201', '6700075', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '北夢前台', 'キタユメサキダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市田寺東', '28', '28201', '6700081', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '田寺東', 'タデラヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市田寺山手町', '28', '28201', '6700082', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '田寺山手町', 'タデラヤマテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市辻井', '28', '28201', '6700083', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '辻井', 'ツジイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市東辻井', '28', '28201', '6700084', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '東辻井', 'ヒガシツジイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市山吹', '28', '28201', '6700085', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '山吹', 'ヤマブキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市田寺', '28', '28201', '6700086', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '田寺', 'タデラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市北新在家', '28', '28201', '6700091', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '北新在家', 'キタシンザイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市新在家本町', '28', '28201', '6700092', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '新在家本町', 'シンザイケホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市南新在家', '28', '28201', '6700093', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '南新在家', 'ミナミシンザイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市新在家中の町', '28', '28201', '6700094', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '新在家中の町', 'シンザイケナカノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市新在家', '28', '28201', '6700095', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '新在家', 'シンザイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市西新在家', '28', '28201', '6700096', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '西新在家', 'ニシシンザイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道江別市1条', '01', '01217', '0670011', '北海道', 'ホッカイドウ', '江別市', 'エベツシ', '1条', '01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道江別市2条', '01', '01217', '0670012', '北海道', 'ホッカイドウ', '江別市', 'エベツシ', '2条', '02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道江別市3条', '01', '01217', '0670013', '北海道', 'ホッカイドウ', '江別市', 'エベツシ', '3条', '03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道江別市4条', '01', '01217', '0670014', '北海道', 'ホッカイドウ', '江別市', 'エベツシ', '4条', '04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道江別市5条', '01', '01217', '0670015', '北海道', 'ホッカイドウ', '江別市', 'エベツシ', '5条', '05ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道江別市6条', '01', '01217', '0670016', '北海道', 'ホッカイドウ', '江別市', 'エベツシ', '6条', '06ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道江別市7条', '01', '01217', '0670017', '北海道', 'ホッカイドウ', '江別市', 'エベツシ', '7条', '07ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道江別市8条', '01', '01217', '0670018', '北海道', 'ホッカイドウ', '江別市', 'エベツシ', '8条', '08ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道江別市豊幌', '01', '01217', '0670021', '北海道', 'ホッカイドウ', '江別市', 'エベツシ', '豊幌', 'トヨホロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道江別市江別太', '01', '01217', '0670022', '北海道', 'ホッカイドウ', '江別市', 'エベツシ', '江別太', 'エベツブト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道江別市東光町', '01', '01217', '0670023', '北海道', 'ホッカイドウ', '江別市', 'エベツシ', '東光町', 'トウコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道江別市朝日町', '01', '01217', '0670024', '北海道', 'ホッカイドウ', '江別市', 'エベツシ', '朝日町', 'アサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道江別市あけぼの町', '01', '01217', '0670025', '北海道', 'ホッカイドウ', '江別市', 'エベツシ', 'あけぼの町', 'アケボノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道江別市豊幌花園町', '01', '01217', '0670026', '北海道', 'ホッカイドウ', '江別市', 'エベツシ', '豊幌花園町', 'トヨホロハナゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道江別市豊幌美咲町', '01', '01217', '0670027', '北海道', 'ホッカイドウ', '江別市', 'エベツシ', '豊幌美咲町', 'トヨホロミサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道江別市豊幌はみんぐ町', '01', '01217', '0670028', '北海道', 'ホッカイドウ', '江別市', 'エベツシ', '豊幌はみんぐ町', 'トヨホロハミングチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道江別市元町', '01', '01217', '0670031', '北海道', 'ホッカイドウ', '江別市', 'エベツシ', '元町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道江別市元江別', '01', '01217', '0670032', '北海道', 'ホッカイドウ', '江別市', 'エベツシ', '元江別', 'モトエベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道江別市対雁', '01', '01217', '0670033', '北海道', 'ホッカイドウ', '江別市', 'エベツシ', '対雁', 'ツイシカリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道江別市いずみ野', '01', '01217', '0670034', '北海道', 'ホッカイドウ', '江別市', 'エベツシ', 'いずみ野', 'イズミノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道江別市元江別本町', '01', '01217', '0670041', '北海道', 'ホッカイドウ', '江別市', 'エベツシ', '元江別本町', 'モトエベツホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道江別市見晴台', '01', '01217', '0670042', '北海道', 'ホッカイドウ', '江別市', 'エベツシ', '見晴台', 'ミハラシダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道江別市工栄町', '01', '01217', '0670051', '北海道', 'ホッカイドウ', '江別市', 'エベツシ', '工栄町', 'コウエイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道江別市角山', '01', '01217', '0670052', '北海道', 'ホッカイドウ', '江別市', 'エベツシ', '角山', 'カクヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道江別市中島', '01', '01217', '0670053', '北海道', 'ホッカイドウ', '江別市', 'エベツシ', '中島', 'ナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道江別市八幡', '01', '01217', '0670054', '北海道', 'ホッカイドウ', '江別市', 'エベツシ', '八幡', 'ヤハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道江別市篠津', '01', '01217', '0670055', '北海道', 'ホッカイドウ', '江別市', 'エベツシ', '篠津', 'シノツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道江別市美原', '01', '01217', '0670056', '北海道', 'ホッカイドウ', '江別市', 'エベツシ', '美原', 'ミハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道江別市萌えぎ野東', '01', '01217', '0670057', '北海道', 'ホッカイドウ', '江別市', 'エベツシ', '萌えぎ野東', 'モエギノヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道江別市萌えぎ野中央', '01', '01217', '0670058', '北海道', 'ホッカイドウ', '江別市', 'エベツシ', '萌えぎ野中央', 'モエギノチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道江別市萌えぎ野西', '01', '01217', '0670059', '北海道', 'ホッカイドウ', '江別市', 'エベツシ', '萌えぎ野西', 'モエギノニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道江別市上江別東町', '01', '01217', '0670061', '北海道', 'ホッカイドウ', '江別市', 'エベツシ', '上江別東町', 'カミエベツヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道江別市上江別南町', '01', '01217', '0670062', '北海道', 'ホッカイドウ', '江別市', 'エベツシ', '上江別南町', 'カミエベツミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道江別市上江別西町', '01', '01217', '0670063', '北海道', 'ホッカイドウ', '江別市', 'エベツシ', '上江別西町', 'カミエベツニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道江別市上江別', '01', '01217', '0670064', '北海道', 'ホッカイドウ', '江別市', 'エベツシ', '上江別', 'カミエベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道江別市ゆめみ野東町', '01', '01217', '0670065', '北海道', 'ホッカイドウ', '江別市', 'エベツシ', 'ゆめみ野東町', 'ユメミノヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道江別市ゆめみ野南町', '01', '01217', '0670066', '北海道', 'ホッカイドウ', '江別市', 'エベツシ', 'ゆめみ野南町', 'ユメミノミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道江別市萩ケ岡', '01', '01217', '0670071', '北海道', 'ホッカイドウ', '江別市', 'エベツシ', '萩ケ岡', 'ハギガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道江別市一番町', '01', '01217', '0670072', '北海道', 'ホッカイドウ', '江別市', 'エベツシ', '一番町', 'イチバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道江別市弥生町', '01', '01217', '0670073', '北海道', 'ホッカイドウ', '江別市', 'エベツシ', '弥生町', 'ヤヨイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道江別市高砂町', '01', '01217', '0670074', '北海道', 'ホッカイドウ', '江別市', 'エベツシ', '高砂町', 'タカサゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道江別市向ケ丘', '01', '01217', '0670075', '北海道', 'ホッカイドウ', '江別市', 'エベツシ', '向ケ丘', 'ムコウガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市仁豊野', '28', '28201', '6700801', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '仁豊野', 'ニブノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市砥堀', '28', '28201', '6700802', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '砥堀', 'トホリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市城見台', '28', '28201', '6700803', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '城見台', 'シロミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市保城', '28', '28201', '6700804', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '保城', 'ホウシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市西中島', '28', '28201', '6700805', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '西中島', 'ニシナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市増位新町', '28', '28201', '6700806', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '増位新町', 'マスイシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市増位本町', '28', '28201', '6700807', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '増位本町', 'マスイホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市白国', '28', '28201', '6700808', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '白国', 'シラクニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市野里', '28', '28201', '6700811', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '野里', 'ノザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市睦町', '28', '28201', '6700812', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '睦町', 'ムツミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市野里慶雲寺前町', '28', '28201', '6700813', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '野里慶雲寺前町', 'ノザトケイウンジマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市野里上野町', '28', '28201', '6700814', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '野里上野町', 'ノザトウエノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市野里大和町', '28', '28201', '6700815', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '野里大和町', 'ノザトダイワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市威徳寺町', '28', '28201', '6700816', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '威徳寺町', 'イトクジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市梅ケ枝町', '28', '28201', '6700817', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '梅ケ枝町', 'ウメガエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市東郷町', '28', '28201', '6700821', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '東郷町', 'トウゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市市川台', '28', '28201', '6700822', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '市川台', 'イチカワダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市宮上町', '28', '28201', '6700823', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '宮上町', 'ミヤウエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市京町', '28', '28201', '6700824', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '京町', 'キョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市市川橋通', '28', '28201', '6700825', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '市川橋通', 'イチカワバシドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市楠町', '28', '28201', '6700826', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '楠町', 'クスノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市丸尾町', '28', '28201', '6700827', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '丸尾町', 'マルオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市城見町', '28', '28201', '6700831', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '城見町', 'シロミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市双葉町', '28', '28201', '6700832', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '双葉町', 'フタバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市大善町', '28', '28201', '6700833', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '大善町', 'ダイゼンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市神和町', '28', '28201', '6700834', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '神和町', 'シンワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市幸町', '28', '28201', '6700835', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市神屋町', '28', '28201', '6700836', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '神屋町', 'カミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市宮西町', '28', '28201', '6700837', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '宮西町', 'ミヤニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市城東町', '28', '28201', '6700841', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '城東町', 'ジョウトウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市城東町毘沙門', '28', '28201', '6700842', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '城東町毘沙門', 'ジョウトウマチビシャモン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市城東町清水', '28', '28201', '6700843', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '城東町清水', 'ジョウトウマチシミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市城東町野田', '28', '28201', '6700844', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '城東町野田', 'ジョウトウマチノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市城東町京口台', '28', '28201', '6700845', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '城東町京口台', 'ジョウトウマチキョウグチダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市天神町', '28', '28201', '6700846', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '天神町', 'テンジンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市城東町中河原', '28', '28201', '6700847', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '城東町中河原', 'ジョウトウマチナカガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市城東町竹之門', '28', '28201', '6700848', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '城東町竹之門', 'ジョウトウマチタケノモン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市城東町五軒屋', '28', '28201', '6700849', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '城東町五軒屋', 'ジョウトウマチゴケンヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市京口町', '28', '28201', '6700851', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '京口町', 'キョウグチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市国府寺町', '28', '28201', '6700852', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '国府寺町', 'コオデラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市大黒壱丁町', '28', '28201', '6700853', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '大黒壱丁町', 'ダイコクイッチョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市五軒邸', '28', '28201', '6700854', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '五軒邸', 'ゴケンヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市福居町', '28', '28201', '6700855', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '福居町', 'フクイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市同心町', '28', '28201', '6700856', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '同心町', 'ドウシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市五郎右衛門邸', '28', '28201', '6700857', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '五郎右衛門邸', 'ゴロウエモンテイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市野里東町', '28', '28201', '6700861', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '野里東町', 'ノザトヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市野里新町', '28', '28201', '6700862', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '野里新町', 'ノザトシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市野里東同心町', '28', '28201', '6700863', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '野里東同心町', 'ノザトヒガシドウシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市野里中町', '28', '28201', '6700864', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '野里中町', 'ノザトナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市野里月丘町', '28', '28201', '6700865', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '野里月丘町', 'ノザトツキオカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市野里堀留町', '28', '28201', '6700866', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '野里堀留町', 'ノザトホリドメマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市野里寺町', '28', '28201', '6700867', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '野里寺町', 'ノザトテラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市大野町', '28', '28201', '6700868', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '大野町', 'オオノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市伊伝居', '28', '28201', '6700871', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '伊伝居', 'イデイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市八代', '28', '28201', '6700872', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '八代', 'ヤシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市八代東光寺町', '28', '28201', '6700873', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '八代東光寺町', 'ヤシロトウコウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市八代本町', '28', '28201', '6700874', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '八代本町', 'ヤシロホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市南八代町', '28', '28201', '6700875', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '南八代町', 'ミナミヤシロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市西八代町', '28', '28201', '6700876', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '西八代町', 'ニシヤシロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市北八代', '28', '28201', '6700877', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '北八代', 'キタヤシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市峰南町', '28', '28201', '6700881', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '峰南町', 'ホウナンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市広峰', '28', '28201', '6700882', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '広峰', 'ヒロミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市城北新町', '28', '28201', '6700883', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '城北新町', 'ジョウホクシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市城北本町', '28', '28201', '6700884', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '城北本町', 'ジョウホクホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市八代宮前町', '28', '28201', '6700885', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '八代宮前町', 'ヤシロミヤマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市八代緑ケ丘町', '28', '28201', '6700886', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '八代緑ケ丘町', 'ヤシロミドリガオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市北平野南の町', '28', '28201', '6700887', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '北平野南の町', 'キタヒラノミナミノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市広嶺山', '28', '28201', '6700891', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '広嶺山', 'ヒロミネヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市北平野奥垣内', '28', '28201', '6700892', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '北平野奥垣内', 'キタヒラノオクガイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市北平野', '28', '28201', '6700893', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '北平野', 'キタヒラノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市梅ケ谷町', '28', '28201', '6700894', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '梅ケ谷町', 'ウメガタニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市北平野台町', '28', '28201', '6700895', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '北平野台町', 'キタヒラノダイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市上大野', '28', '28201', '6700896', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '上大野', 'カミオオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市西大寿台', '28', '28201', '6700897', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '西大寿台', 'ニシダイジュダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市大寿台', '28', '28201', '6700898', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '大寿台', 'ダイジュダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市西二階町', '28', '28201', '6700901', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '西二階町', 'ニシニカイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市白銀町', '28', '28201', '6700902', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '白銀町', 'シロガネマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市立町', '28', '28201', '6700903', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '立町', 'タテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市塩町', '28', '28201', '6700904', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '塩町', 'シオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市魚町', '28', '28201', '6700905', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '魚町', 'ウオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市博労町', '28', '28201', '6700906', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '博労町', 'バクロウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市十二所前町', '28', '28201', '6700911', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '十二所前町', 'ジュウニショマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市南町', '28', '28201', '6700912', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '南町', 'ミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市西駅前町', '28', '28201', '6700913', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '西駅前町', 'ニシエキマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市豆腐町', '28', '28201', '6700914', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '豆腐町', 'トウフマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市高尾町', '28', '28201', '6700915', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '高尾町', 'タカオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市久保町', '28', '28201', '6700916', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '久保町', 'クボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市忍町', '28', '28201', '6700917', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '忍町', 'シノブマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市綿町', '28', '28201', '6700921', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '綿町', 'ワタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市二階町', '28', '28201', '6700922', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '二階町', 'ニカイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市呉服町', '28', '28201', '6700923', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '呉服町', 'ゴフクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市紺屋町', '28', '28201', '6700924', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '紺屋町', 'コンヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市亀井町', '28', '28201', '6700925', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '亀井町', 'カメイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市東駅前町', '28', '28201', '6700926', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '東駅前町', 'ヒガシエキマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市駅前町', '28', '28201', '6700927', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '駅前町', 'エキマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市坂田町', '28', '28201', '6700931', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '坂田町', 'サカタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市下寺町', '28', '28201', '6700932', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '下寺町', 'シモデラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市平野町', '28', '28201', '6700933', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '平野町', 'ヒラノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市朝日町', '28', '28201', '6700934', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '朝日町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市北条口', '28', '28201', '6700935', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '北条口', 'ホウジョウグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市古二階町', '28', '28201', '6700936', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '古二階町', 'コニカイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市元塩町', '28', '28201', '6700937', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '元塩町', 'モトシオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市三左衛門堀西の町', '28', '28201', '6700940', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '三左衛門堀西の町', 'サンザエモンボリニシノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市若菜町', '28', '28201', '6700941', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '若菜町', 'ワカナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市日出町', '28', '28201', '6700942', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '日出町', 'ヒノデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市市之郷町', '28', '28201', '6700943', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '市之郷町', 'イチノゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市阿保', '28', '28201', '6700944', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '阿保', 'アボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市北条梅原町', '28', '28201', '6700945', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '北条梅原町', 'ホウジョウウメハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市北条永良町', '28', '28201', '6700946', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '北条永良町', 'ホウジョウナガラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市北条', '28', '28201', '6700947', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '北条', 'ホウジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市北条宮の町', '28', '28201', '6700948', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '北条宮の町', 'ホウジョウミヤノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市三左衛門堀東の町', '28', '28201', '6700949', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '三左衛門堀東の町', 'サンザエモンボリヒガシノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市庄田', '28', '28201', '6700951', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '庄田', 'ショウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市南条', '28', '28201', '6700952', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '南条', 'ナンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市三条町1丁目', '28', '28201', '6700953', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '三条町', 'サンジョウチョウ', null, null, '1丁目', '01チョウメ');
INSERT INTO `ms_addresses` VALUES ('80947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市栗山町', '28', '28201', '6700954', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '栗山町', 'クリヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市安田', '28', '28201', '6700955', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '安田', 'ヤスダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市南畝町', '28', '28201', '6700961', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '南畝町', 'ノウネンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市南駅前町', '28', '28201', '6700962', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '南駅前町', 'ミナミエキマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市豊沢町', '28', '28201', '6700964', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '豊沢町', 'トヨザワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市東延末', '28', '28201', '6700965', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '東延末', 'ヒガシノブスエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市延末', '28', '28201', '6700966', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '延末', 'ノブスエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市西延末', '28', '28201', '6700971', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '西延末', 'ニシノブスエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市手柄', '28', '28201', '6700972', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '手柄', 'テガラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市亀山', '28', '28201', '6700973', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '亀山', 'カメヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市飯田', '28', '28201', '6700974', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '飯田', 'イイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市中地南町', '28', '28201', '6700975', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '中地南町', 'チュウジミナミノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市中地', '28', '28201', '6700976', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '中地', 'チュウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市西庄', '28', '28201', '6700981', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '西庄', 'サイショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市岡田', '28', '28201', '6700982', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '岡田', 'オカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市井ノ口', '28', '28201', '6700983', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '井ノ口', 'イノグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市町坪', '28', '28201', '6700984', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '町坪', 'チョウノツボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市玉手', '28', '28201', '6700985', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '玉手', 'タマテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市苫編', '28', '28201', '6700986', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '苫編', 'トマミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市苫編南', '28', '28201', '6700987', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '苫編南', 'トマミミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市町坪南町', '28', '28201', '6700989', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '町坪南町', 'チョウノツボミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市神田町', '28', '28201', '6700991', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '神田町', 'カンダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市福沢町', '28', '28201', '6700992', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '福沢町', 'フクザワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市千代田町', '28', '28201', '6700993', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '千代田町', 'チヨダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市定元町', '28', '28201', '6700994', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '定元町', 'サダモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市土山東の町', '28', '28201', '6700995', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '土山東の町', 'ツチヤマヒガシノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('80973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市土山', '28', '28201', '6700996', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '土山', 'ツチヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市大塩町', '28', '28201', '6710101', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '大塩町', 'オオシオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市大塩町汐咲', '28', '28201', '6710102', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '大塩町汐咲', 'オオシオチョウシオサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市大塩町宮前', '28', '28201', '6710103', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '大塩町宮前', 'オオシオチョウミヤマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市的形町的形', '28', '28201', '6710111', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '的形町的形', 'マトガタチョウマトガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市的形町福泊', '28', '28201', '6710112', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '的形町福泊', 'マトガタチョウフクドマリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県高砂市北浜町牛谷', '28', '28216', '6710121', '兵庫県', 'ヒョウゴケン', '高砂市', 'タカサゴシ', '北浜町牛谷', 'キタハマチョウウシタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県高砂市北浜町北脇', '28', '28216', '6710122', '兵庫県', 'ヒョウゴケン', '高砂市', 'タカサゴシ', '北浜町北脇', 'キタハマチョウキタワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県高砂市北浜町西浜', '28', '28216', '6710123', '兵庫県', 'ヒョウゴケン', '高砂市', 'タカサゴシ', '北浜町西浜', 'キタハマチョウニシハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市飾東町小原新', '28', '28201', '6710201', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '飾東町小原新', 'シキトウチョウオハラシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市飾東町北野', '28', '28201', '6710202', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '飾東町北野', 'シキトウチョウキタノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市飾東町大釜', '28', '28201', '6710203', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '飾東町大釜', 'シキトウチョウオオガマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市飾東町大釜新', '28', '28201', '6710204', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '飾東町大釜新', 'シキトウチョウオオガマシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市飾東町清住', '28', '28201', '6710205', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '飾東町清住', 'シキトウチョウキヨスミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市飾東町山崎', '28', '28201', '6710207', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '飾東町山崎', 'シキトウチョウヤマサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市飾東町八重畑', '28', '28201', '6710208', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '飾東町八重畑', 'シキトウチョウヤエバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市飾東町小原', '28', '28201', '6710209', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '飾東町小原', 'シキトウチョウオハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市飾東町塩崎', '28', '28201', '6710211', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '飾東町塩崎', 'シキトウチョウシオザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市飾東町北山', '28', '28201', '6710212', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '飾東町北山', 'シキトウチョウキタヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市飾東町唐端新', '28', '28201', '6710214', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '飾東町唐端新', 'シキトウチョウカラハタシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市飾東町夕陽ケ丘', '28', '28201', '6710215', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '飾東町夕陽ケ丘', 'シキトウチョウユウヒガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市飾東町志吹', '28', '28201', '6710216', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '飾東町志吹', 'シキトウチョウシブキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市飾東町佐良和', '28', '28201', '6710217', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '飾東町佐良和', 'シキトウチョウサロオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市飾東町庄', '28', '28201', '6710218', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '飾東町庄', 'シキトウチョウショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市飾東町豊国', '28', '28201', '6710219', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '飾東町豊国', 'シキトウチョウトヨクニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市別所町別所', '28', '28201', '6710221', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '別所町別所', 'ベッショチョウベッショ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市別所町小林', '28', '28201', '6710222', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '別所町小林', 'ベッショチョウコバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市別所町北宿', '28', '28201', '6710223', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '別所町北宿', 'ベッショチョウキタジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市別所町佐土', '28', '28201', '6710224', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '別所町佐土', 'ベッショチョウサヅチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市別所町家具町', '28', '28201', '6710225', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '別所町家具町', 'ベッショチョウカグマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市別所町佐土新', '28', '28201', '6710226', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '別所町佐土新', 'ベッショチョウサヅチシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市御国野町深志野', '28', '28201', '6710231', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '御国野町深志野', 'ミクニノチョウフカシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市御国野町御着', '28', '28201', '6710232', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '御国野町御着', 'ミクニノチョウゴチャク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市御国野町西御着', '28', '28201', '6710233', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '御国野町西御着', 'ミクニノチョウニシゴチャク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市御国野町国分寺', '28', '28201', '6710234', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '御国野町国分寺', 'ミクニノチョウコクブンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市四郷町上鈴', '28', '28201', '6710241', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '四郷町上鈴', 'シゴウチョウカミスズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市四郷町中鈴', '28', '28201', '6710242', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '四郷町中鈴', 'シゴウチョウナカスズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市四郷町本郷', '28', '28201', '6710243', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '四郷町本郷', 'シゴウチョウホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市四郷町見野', '28', '28201', '6710244', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '四郷町見野', 'シゴウチョウミノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市四郷町明田', '28', '28201', '6710245', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '四郷町明田', 'シゴウチョウアケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市四郷町坂元', '28', '28201', '6710246', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '四郷町坂元', 'シゴウチョウサカモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市四郷町東阿保', '28', '28201', '6710247', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '四郷町東阿保', 'シゴウチョウヒガシアボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市四郷町山脇', '28', '28201', '6710248', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '四郷町山脇', 'シゴウチョウヤマワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市花田町上原田', '28', '28201', '6710251', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '花田町上原田', 'ハナダチョウカミハラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市花田町加納原田', '28', '28201', '6710252', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '花田町加納原田', 'ハナダチョウカノウハラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市花田町一本松', '28', '28201', '6710253', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '花田町一本松', 'ハナダチョウイッポンマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市花田町勅旨', '28', '28201', '6710254', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '花田町勅旨', 'ハナダチョウチョクシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市花田町小川', '28', '28201', '6710255', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '花田町小川', 'ハナダチョウオガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市花田町高木', '28', '28201', '6710256', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '花田町高木', 'ハナダチョウタカギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市広畑区東夢前台', '28', '28201', '6711101', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '広畑区東夢前台', 'ヒロハタクヒガシユメサキダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市広畑区蒲田', '28', '28201', '6711102', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '広畑区蒲田', 'ヒロハタクカマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市広畑区西夢前台', '28', '28201', '6711103', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '広畑区西夢前台', 'ヒロハタクニシユメサキダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市広畑区才', '28', '28201', '6711104', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '広畑区才', 'ヒロハタクサイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市広畑区則直', '28', '28201', '6711105', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '広畑区則直', 'ヒロハタクノリナオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市広畑区京見町', '28', '28201', '6711106', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '広畑区京見町', 'ヒロハタクキョウミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市広畑区西蒲田', '28', '28201', '6711107', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '広畑区西蒲田', 'ヒロハタクニシカマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市広畑区城山町', '28', '28201', '6711108', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '広畑区城山町', 'ヒロハタクシロヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市広畑区北河原町', '28', '28201', '6711111', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '広畑区北河原町', 'ヒロハタクキタカワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市広畑区北野町', '28', '28201', '6711112', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '広畑区北野町', 'ヒロハタクキタノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市広畑区清水町', '28', '28201', '6711113', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '広畑区清水町', 'ヒロハタクシミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市広畑区本町', '28', '28201', '6711114', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '広畑区本町', 'ヒロハタクホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市広畑区末広町', '28', '28201', '6711115', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '広畑区末広町', 'ヒロハタクスエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市広畑区正門通', '28', '28201', '6711116', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '広畑区正門通', 'ヒロハタクセイモンドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市広畑区東新町', '28', '28201', '6711121', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '広畑区東新町', 'ヒロハタクヒガシシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市広畑区夢前町', '28', '28201', '6711122', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '広畑区夢前町', 'ヒロハタクユメサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市広畑区富士町', '28', '28201', '6711123', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '広畑区富士町', 'ヒロハタクフジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市広畑区鶴町', '28', '28201', '6711124', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '広畑区鶴町', 'ヒロハタクツルマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市広畑区長町', '28', '28201', '6711125', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '広畑区長町', 'ヒロハタクナガマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市大津区天神町', '28', '28201', '6711131', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '大津区天神町', 'オオツクテンジンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市大津区勘兵衛町', '28', '28201', '6711132', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '大津区勘兵衛町', 'オオツクカンベエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市大津区吉美', '28', '28201', '6711133', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '大津区吉美', 'オオツクキビ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市大津区真砂町', '28', '28201', '6711134', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '大津区真砂町', 'オオツクマサゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市大津区新町', '28', '28201', '6711135', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '大津区新町', 'オオツクシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市大津区恵美酒町', '28', '28201', '6711136', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '大津区恵美酒町', 'オオツクエビスマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市大津区西土井', '28', '28201', '6711141', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '大津区西土井', 'オオツクニシドイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市大津区北天満町', '28', '28201', '6711142', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '大津区北天満町', 'オオツクキタテンマンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市大津区天満', '28', '28201', '6711143', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '大津区天満', 'オオツクテンマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市大津区長松', '28', '28201', '6711144', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '大津区長松', 'オオツクナガマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市大津区平松', '28', '28201', '6711145', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '大津区平松', 'オオツクヒラマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市大津区大津町', '28', '28201', '6711146', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '大津区大津町', 'オオツクオオツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市広畑区早瀬町', '28', '28201', '6711151', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '広畑区早瀬町', 'ヒロハタクハヤセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市広畑区小松町', '28', '28201', '6711152', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '広畑区小松町', 'ヒロハタクコマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市広畑区高浜町', '28', '28201', '6711153', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '広畑区高浜町', 'ヒロハタクタカハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市広畑区吾妻町', '28', '28201', '6711154', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '広畑区吾妻町', 'ヒロハタクアヅマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市広畑区大町', '28', '28201', '6711155', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '広畑区大町', 'ヒロハタクオオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市広畑区小坂', '28', '28201', '6711156', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '広畑区小坂', 'ヒロハタクコサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市勝原区下太田', '28', '28201', '6711201', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '勝原区下太田', 'カツハラクシモオオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市勝原区勝山町', '28', '28201', '6711202', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '勝原区勝山町', 'カツハラクカツヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市勝原区丁', '28', '28201', '6711203', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '勝原区丁', 'カツハラクヨロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市勝原区朝日谷', '28', '28201', '6711204', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '勝原区朝日谷', 'カツハラクアサヒダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市勝原区大谷', '28', '28201', '6711205', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '勝原区大谷', 'カツハラクオオタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市勝原区熊見', '28', '28201', '6711211', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '勝原区熊見', 'カツハラククマミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市勝原区勝原町', '28', '28201', '6711212', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '勝原区勝原町', 'カツハラクカツハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市勝原区宮田', '28', '28201', '6711213', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '勝原区宮田', 'カツハラクミヤタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市勝原区山戸', '28', '28201', '6711214', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '勝原区山戸', 'カツハラクヤマト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市網干区田井', '28', '28201', '6711221', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '網干区田井', 'アボシクタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市網干区宮内', '28', '28201', '6711222', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '網干区宮内', 'アボシクミヤウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市網干区坂上', '28', '28201', '6711223', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '網干区坂上', 'アボシクサカウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市網干区津市場', '28', '28201', '6711224', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '網干区津市場', 'アボシクツイチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市網干区福井', '28', '28201', '6711225', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '網干区福井', 'アボシクフクイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市網干区高田', '28', '28201', '6711226', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '網干区高田', 'アボシクタカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市網干区和久', '28', '28201', '6711227', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '網干区和久', 'アボシクワク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市網干区坂出', '28', '28201', '6711228', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '網干区坂出', 'アボシクサカデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市網干区大江島', '28', '28201', '6711231', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '網干区大江島', 'アボシクオオエジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市網干区大江島寺前町', '28', '28201', '6711232', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '網干区大江島寺前町', 'アボシクオオエジマテラマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市網干区大江島古川町', '28', '28201', '6711233', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '網干区大江島古川町', 'アボシクオオエジマフルカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市網干区新在家', '28', '28201', '6711234', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '網干区新在家', 'アボシクシンザイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市網干区北新在家', '28', '28201', '6711235', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '網干区北新在家', 'アボシクキタシンザイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市網干区網干浜', '28', '28201', '6711236', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '網干区網干浜', 'アボシクアボシハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市網干区興浜', '28', '28201', '6711241', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '網干区興浜', 'アボシクオキノハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市網干区浜田', '28', '28201', '6711242', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '網干区浜田', 'アボシクハマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市網干区垣内北町', '28', '28201', '6711251', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '網干区垣内北町', 'アボシクカイチキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市網干区垣内東町', '28', '28201', '6711252', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '網干区垣内東町', 'アボシクカイチヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市網干区垣内中町', '28', '28201', '6711253', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '網干区垣内中町', 'アボシクカイチナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市網干区余子浜', '28', '28201', '6711254', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '網干区余子浜', 'アボシクヨコハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市網干区垣内南町', '28', '28201', '6711255', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '網干区垣内南町', 'アボシクカイチミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市網干区垣内西町', '28', '28201', '6711256', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '網干区垣内西町', 'アボシクカイチニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市網干区垣内本町', '28', '28201', '6711257', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '網干区垣内本町', 'アボシクカイチホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市余部区下余部', '28', '28201', '6711261', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '余部区下余部', 'ヨベクシモヨベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市余部区上余部', '28', '28201', '6711262', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '余部区上余部', 'ヨベクカミヨベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市余部区上川原', '28', '28201', '6711263', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '余部区上川原', 'ヨベクカミガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市御津町黒崎', '28', '28229', '6711301', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '御津町黒崎', 'ミツチョウクロサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市御津町中島', '28', '28229', '6711311', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '御津町中島', 'ミツチョウナカシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市御津町碇岩', '28', '28229', '6711312', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '御津町碇岩', 'ミツチョウイカリイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市御津町苅屋', '28', '28229', '6711321', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '御津町苅屋', 'ミツチョウカリヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市御津町岩見', '28', '28229', '6711331', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '御津町岩見', 'ミツチョウイワミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市御津町室津', '28', '28229', '6711332', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '御津町室津', 'ミツチョウムロツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市御津町釜屋', '28', '28229', '6711341', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '御津町釜屋', 'ミツチョウカマヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市御津町朝臣', '28', '28229', '6711342', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '御津町朝臣', 'ミツチョウアサトミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県揖保郡太子町', '28', '28464', '6711500', '兵庫県', 'ヒョウゴケン', '揖保郡太子町', 'イボグンタイシチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('81160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県揖保郡太子町山田', '28', '28464', '6711501', '兵庫県', 'ヒョウゴケン', '揖保郡太子町', 'イボグンタイシチョウ', '山田', 'ヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県揖保郡太子町原', '28', '28464', '6711502', '兵庫県', 'ヒョウゴケン', '揖保郡太子町', 'イボグンタイシチョウ', '原', 'ハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県揖保郡太子町天満山', '28', '28464', '6711503', '兵庫県', 'ヒョウゴケン', '揖保郡太子町', 'イボグンタイシチョウ', '天満山', 'テンマヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県揖保郡太子町黒岡', '28', '28464', '6711504', '兵庫県', 'ヒョウゴケン', '揖保郡太子町', 'イボグンタイシチョウ', '黒岡', 'クロオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県揖保郡太子町太田', '28', '28464', '6711511', '兵庫県', 'ヒョウゴケン', '揖保郡太子町', 'イボグンタイシチョウ', '太田', 'オオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県揖保郡太子町東出', '28', '28464', '6711521', '兵庫県', 'ヒョウゴケン', '揖保郡太子町', 'イボグンタイシチョウ', '東出', 'トウデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県揖保郡太子町矢田部', '28', '28464', '6711522', '兵庫県', 'ヒョウゴケン', '揖保郡太子町', 'イボグンタイシチョウ', '矢田部', 'ヤタベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県揖保郡太子町東南', '28', '28464', '6711523', '兵庫県', 'ヒョウゴケン', '揖保郡太子町', 'イボグンタイシチョウ', '東南', 'トウナン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県揖保郡太子町東保', '28', '28464', '6711524', '兵庫県', 'ヒョウゴケン', '揖保郡太子町', 'イボグンタイシチョウ', '東保', 'トウボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県揖保郡太子町立岡', '28', '28464', '6711531', '兵庫県', 'ヒョウゴケン', '揖保郡太子町', 'イボグンタイシチョウ', '立岡', 'タツオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県揖保郡太子町糸井', '28', '28464', '6711532', '兵庫県', 'ヒョウゴケン', '揖保郡太子町', 'イボグンタイシチョウ', '糸井', 'イトイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県揖保郡太子町竹広', '28', '28464', '6711533', '兵庫県', 'ヒョウゴケン', '揖保郡太子町', 'イボグンタイシチョウ', '竹広', 'タケヒロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県揖保郡太子町福地', '28', '28464', '6711534', '兵庫県', 'ヒョウゴケン', '揖保郡太子町', 'イボグンタイシチョウ', '福地', 'フクジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県揖保郡太子町蓮常寺', '28', '28464', '6711535', '兵庫県', 'ヒョウゴケン', '揖保郡太子町', 'イボグンタイシチョウ', '蓮常寺', 'レンジョウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県揖保郡太子町塚森', '28', '28464', '6711541', '兵庫県', 'ヒョウゴケン', '揖保郡太子町', 'イボグンタイシチョウ', '塚森', 'ツカモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県揖保郡太子町米田', '28', '28464', '6711542', '兵庫県', 'ヒョウゴケン', '揖保郡太子町', 'イボグンタイシチョウ', '米田', 'ヨネダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県揖保郡太子町沖代', '28', '28464', '6711543', '兵庫県', 'ヒョウゴケン', '揖保郡太子町', 'イボグンタイシチョウ', '沖代', 'オキダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県揖保郡太子町吉福', '28', '28464', '6711544', '兵庫県', 'ヒョウゴケン', '揖保郡太子町', 'イボグンタイシチョウ', '吉福', 'ヨシフク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県揖保郡太子町岩見構', '28', '28464', '6711545', '兵庫県', 'ヒョウゴケン', '揖保郡太子町', 'イボグンタイシチョウ', '岩見構', 'イワミカマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県揖保郡太子町馬場', '28', '28464', '6711551', '兵庫県', 'ヒョウゴケン', '揖保郡太子町', 'イボグンタイシチョウ', '馬場', 'ババ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県揖保郡太子町下阿曽', '28', '28464', '6711552', '兵庫県', 'ヒョウゴケン', '揖保郡太子町', 'イボグンタイシチョウ', '下阿曽', 'シモアソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県揖保郡太子町老原', '28', '28464', '6711553', '兵庫県', 'ヒョウゴケン', '揖保郡太子町', 'イボグンタイシチョウ', '老原', 'オイバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県揖保郡太子町船代', '28', '28464', '6711554', '兵庫県', 'ヒョウゴケン', '揖保郡太子町', 'イボグンタイシチョウ', '船代', 'フナダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県揖保郡太子町宮本', '28', '28464', '6711555', '兵庫県', 'ヒョウゴケン', '揖保郡太子町', 'イボグンタイシチョウ', '宮本', 'ミヤモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県揖保郡太子町常全', '28', '28464', '6711556', '兵庫県', 'ヒョウゴケン', '揖保郡太子町', 'イボグンタイシチョウ', '常全', 'ジョウゼン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県揖保郡太子町阿曽', '28', '28464', '6711557', '兵庫県', 'ヒョウゴケン', '揖保郡太子町', 'イボグンタイシチョウ', '阿曽', 'アソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県揖保郡太子町鵤', '28', '28464', '6711561', '兵庫県', 'ヒョウゴケン', '揖保郡太子町', 'イボグンタイシチョウ', '鵤', 'イカルガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県揖保郡太子町広坂', '28', '28464', '6711571', '兵庫県', 'ヒョウゴケン', '揖保郡太子町', 'イボグンタイシチョウ', '広坂', 'ヒロサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県揖保郡太子町王子', '28', '28464', '6711572', '兵庫県', 'ヒョウゴケン', '揖保郡太子町', 'イボグンタイシチョウ', '王子', 'オウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県揖保郡太子町上太田', '28', '28464', '6711573', '兵庫県', 'ヒョウゴケン', '揖保郡太子町', 'イボグンタイシチョウ', '上太田', 'カミオオダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県揖保郡太子町松ケ下', '28', '28464', '6711574', '兵庫県', 'ヒョウゴケン', '揖保郡太子町', 'イボグンタイシチョウ', '松ケ下', 'マツガシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県揖保郡太子町佐用岡', '28', '28464', '6711575', '兵庫県', 'ヒョウゴケン', '揖保郡太子町', 'イボグンタイシチョウ', '佐用岡', 'サヨオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県揖保郡太子町松尾', '28', '28464', '6711576', '兵庫県', 'ヒョウゴケン', '揖保郡太子町', 'イボグンタイシチョウ', '松尾', 'マツオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市揖保川町半田', '28', '28229', '6711601', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '揖保川町半田', 'イボガワチョウハンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市揖保川町野田', '28', '28229', '6711602', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '揖保川町野田', 'イボガワチョウノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市揖保川町養久', '28', '28229', '6711603', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '揖保川町養久', 'イボガワチョウヤク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市揖保川町新在家', '28', '28229', '6711611', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '揖保川町新在家', 'イボガワチョウシンザイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市揖保川町本條', '28', '28229', '6711612', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '揖保川町本條', 'イボガワチョウホンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市揖保川町二塚', '28', '28229', '6711613', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '揖保川町二塚', 'イボガワチョウフタツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市揖保川町正條', '28', '28229', '6711621', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '揖保川町正條', 'イボガワチョウショウジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市揖保川町山津屋', '28', '28229', '6711631', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '揖保川町山津屋', 'イボガワチョウヤマツヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市揖保川町黍田', '28', '28229', '6711632', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '揖保川町黍田', 'イボガワチョウキビタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市揖保川町原', '28', '28229', '6711641', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '揖保川町原', 'イボガワチョウハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市揖保川町大門', '28', '28229', '6711642', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '揖保川町大門', 'イボガワチョウダイモン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市揖保川町神戸北山', '28', '28229', '6711643', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '揖保川町神戸北山', 'イボガワチョウカンベキタヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市揖保川町片島', '28', '28229', '6711651', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '揖保川町片島', 'イボガワチョウカタシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市揖保川町袋尻', '28', '28229', '6711661', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '揖保川町袋尻', 'イボガワチョウフクロジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市揖保川町市場', '28', '28229', '6711662', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '揖保川町市場', 'イボガワチョウイチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市揖保川町浦部', '28', '28229', '6711663', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '揖保川町浦部', 'イボガワチョウウラベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市揖保川町金剛山', '28', '28229', '6711664', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '揖保川町金剛山', 'イボガワチョウコンゴウサン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市揖保川町馬場', '28', '28229', '6711665', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '揖保川町馬場', 'イボガワチョウウマバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市夢前町山之内', '28', '28201', '6712101', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '夢前町山之内', 'ユメサキチョウヤマノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市夢前町新庄', '28', '28201', '6712102', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '夢前町新庄', 'ユメサキチョウシンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市夢前町前之庄', '28', '28201', '6712103', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '夢前町前之庄', 'ユメサキチョウマエノショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市夢前町神種', '28', '28201', '6712105', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '夢前町神種', 'ユメサキチョウコノクサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市夢前町莇野', '28', '28201', '6712106', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '夢前町莇野', 'ユメサキチョウアゾノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市夢前町杉之内', '28', '28201', '6712111', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '夢前町杉之内', 'ユメサキチョウスギノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市夢前町塩田', '28', '28201', '6712112', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '夢前町塩田', 'ユメサキチョウシオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市夢前町古知之庄', '28', '28201', '6712113', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '夢前町古知之庄', 'ユメサキチョウコチノショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市夢前町糸田', '28', '28201', '6712114', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '夢前町糸田', 'ユメサキチョウイトタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市夢前町又坂', '28', '28201', '6712115', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '夢前町又坂', 'ユメサキチョウマタサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市夢前町寺', '28', '28201', '6712116', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '夢前町寺', 'ユメサキチョウテラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市夢前町高長', '28', '28201', '6712117', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '夢前町高長', 'ユメサキチョウコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市夢前町宮置', '28', '28201', '6712121', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '夢前町宮置', 'ユメサキチョウミヤオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市夢前町置本', '28', '28201', '6712122', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '夢前町置本', 'ユメサキチョウオキモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市夢前町山冨', '28', '28201', '6712123', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '夢前町山冨', 'ユメサキチョウヤマトミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市夢前町玉田', '28', '28201', '6712124', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '夢前町玉田', 'ユメサキチョウタマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市夢前町戸倉', '28', '28201', '6712131', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '夢前町戸倉', 'ユメサキチョウトクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市夢前町古瀬畑', '28', '28201', '6712132', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '夢前町古瀬畑', 'ユメサキチョウコセバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市夢前町芦田', '28', '28201', '6712133', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '夢前町芦田', 'ユメサキチョウアシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市夢前町菅生澗', '28', '28201', '6712134', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '夢前町菅生澗', 'ユメサキチョウスゴウダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市夢前町塚本', '28', '28201', '6712135', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '夢前町塚本', 'ユメサキチョウツカモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市夢前町護持', '28', '28201', '6712136', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '夢前町護持', 'ユメサキチョウゴジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市夢前町野畑', '28', '28201', '6712137', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '夢前町野畑', 'ユメサキチョウノバタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市書写', '28', '28201', '6712201', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '書写', 'ショシャ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市北夢前台1丁目', '28', '28201', '6712202', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '北夢前台', 'キタユメサキダイ', null, null, '1丁目', '01チョウメ');
INSERT INTO `ms_addresses` VALUES ('81248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市書写台', '28', '28201', '6712203', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '書写台', 'ショシャダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市田井台', '28', '28201', '6712211', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '田井台', 'タイダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市川西', '28', '28201', '6712212', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '川西', 'カワニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市川西台', '28', '28201', '6712213', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '川西台', 'カワニシダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市西夢前台', '28', '28201', '6712214', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '西夢前台', 'ニシユメサキダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市飾西台', '28', '28201', '6712215', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '飾西台', 'シキサイダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市飾西', '28', '28201', '6712216', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '飾西', 'シキサイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市町田', '28', '28201', '6712217', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '町田', 'チョウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市青山北', '28', '28201', '6712221', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '青山北', 'アオヤマキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市青山', '28', '28201', '6712222', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '青山', 'アオヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市青山南', '28', '28201', '6712223', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '青山南', 'アオヤマミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市青山西', '28', '28201', '6712224', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '青山西', 'アオヤマニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市石倉', '28', '28201', '6712231', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '石倉', 'イシクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市相野', '28', '28201', '6712232', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '相野', 'アイノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市太市中', '28', '28201', '6712233', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '太市中', 'オオイチナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市西脇', '28', '28201', '6712234', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '西脇', 'ニシワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市刀出', '28', '28201', '6712241', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '刀出', 'カタナデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市六角', '28', '28201', '6712242', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '六角', 'ロッカク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市菅生台', '28', '28201', '6712243', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '菅生台', 'スゴウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市実法寺', '28', '28201', '6712244', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '実法寺', 'ジホウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市白鳥台', '28', '28201', '6712245', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '白鳥台', 'ハクチョウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市打越', '28', '28201', '6712246', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '打越', 'ウチコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市緑台', '28', '28201', '6712247', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '緑台', 'ミドリダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市安富町安志', '28', '28201', '6712401', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '安富町安志', 'ヤストミチョウアンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市安富町三森', '28', '28201', '6712411', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '安富町三森', 'ヤストミチョウミツモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市安富町名坂', '28', '28201', '6712412', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '安富町名坂', 'ヤストミチョウナサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市安富町末広', '28', '28201', '6712413', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '安富町末広', 'ヤストミチョウスエヒロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市安富町杤原', '28', '28201', '6712414', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '安富町杤原', 'ヤストミチョウトチハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市安富町皆河', '28', '28201', '6712415', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '安富町皆河', 'ヤストミチョウミナゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市安富町関', '28', '28201', '6712416', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '安富町関', 'ヤストミチョウセキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市安富町長野', '28', '28201', '6712421', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '安富町長野', 'ヤストミチョウナガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市安富町塩野', '28', '28201', '6712422', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '安富町塩野', 'ヤストミチョウシオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市安富町狭戸', '28', '28201', '6712423', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '安富町狭戸', 'ヤストミチョウセバト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市安富町瀬川', '28', '28201', '6712424', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '安富町瀬川', 'ヤストミチョウセガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市安富町三坂', '28', '28201', '6712425', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '安富町三坂', 'ヤストミチョウミサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市安富町植木野', '28', '28201', '6712426', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '安富町植木野', 'ヤストミチョウウエキノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市', '28', '28227', '6712500', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('81287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市山崎町上ノ', '28', '28227', '6712501', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '山崎町上ノ', 'ヤマサキチョウカミノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市山崎町中野', '28', '28227', '6712502', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '山崎町中野', 'ヤマサキチョウナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市山崎町大谷', '28', '28227', '6712503', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '山崎町大谷', 'ヤマサキチョウオオタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市山崎町東下野', '28', '28227', '6712504', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '山崎町東下野', 'ヤマサキチョウヒガシシモノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市山崎町片山', '28', '28227', '6712505', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '山崎町片山', 'ヤマサキチョウカタヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市山崎町宇野', '28', '28227', '6712506', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '山崎町宇野', 'ヤマサキチョウウノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市山崎町下牧谷', '28', '28227', '6712507', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '山崎町下牧谷', 'ヤマサキチョウシモマキダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市山崎町上牧谷', '28', '28227', '6712508', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '山崎町上牧谷', 'ヤマサキチョウカミマキダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市山崎町清野', '28', '28227', '6712511', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '山崎町清野', 'ヤマサキチョウセイノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市山崎町与位', '28', '28227', '6712512', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '山崎町与位', 'ヤマサキチョウヨイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市山崎町梯', '28', '28227', '6712513', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '山崎町梯', 'ヤマサキチョウカケハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市山崎町田井', '28', '28227', '6712514', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '山崎町田井', 'ヤマサキチョウタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市山崎町五十波', '28', '28227', '6712515', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '山崎町五十波', 'ヤマサキチョウイカバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市山崎町三津', '28', '28227', '6712516', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '山崎町三津', 'ヤマサキチョウミツヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市山崎町生谷', '28', '28227', '6712517', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '山崎町生谷', 'ヤマサキチョウイギダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市山崎町横須', '28', '28227', '6712518', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '山崎町横須', 'ヤマサキチョウヨコス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市山崎町下町', '28', '28227', '6712519', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '山崎町下町', 'ヤマサキチョウシモマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市山崎町木ノ谷', '28', '28227', '6712521', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '山崎町木ノ谷', 'ヤマサキチョウキノタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市山崎町杉ケ瀬', '28', '28227', '6712522', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '山崎町杉ケ瀬', 'ヤマサキチョウスギガセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市山崎町母栖', '28', '28227', '6712523', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '山崎町母栖', 'ヤマサキチョウモス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市山崎町三谷', '28', '28227', '6712524', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '山崎町三谷', 'ヤマサキチョウミタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市山崎町神谷', '28', '28227', '6712525', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '山崎町神谷', 'ヤマサキチョウコウダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市山崎町矢原', '28', '28227', '6712526', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '山崎町矢原', 'ヤマサキチョウヤバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市山崎町岸田', '28', '28227', '6712527', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '山崎町岸田', 'ヤマサキチョウキシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市山崎町野々上', '28', '28227', '6712528', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '山崎町野々上', 'ヤマサキチョウノノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市山崎町中', '28', '28227', '6712531', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '山崎町中', 'ヤマサキチョウナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市山崎町高所', '28', '28227', '6712532', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '山崎町高所', 'ヤマサキチョウコウゾ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市山崎町須賀沢', '28', '28227', '6712533', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '山崎町須賀沢', 'ヤマサキチョウスカザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市山崎町川戸', '28', '28227', '6712534', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '山崎町川戸', 'ヤマサキチョウカワト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市山崎町宇原', '28', '28227', '6712535', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '山崎町宇原', 'ヤマサキチョウウワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市山崎町下宇原', '28', '28227', '6712536', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '山崎町下宇原', 'ヤマサキチョウシモウワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市山崎町下広瀬', '28', '28227', '6712541', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '山崎町下広瀬', 'ヤマサキチョウシモビロセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市山崎町船元', '28', '28227', '6712542', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '山崎町船元', 'ヤマサキチョウフナモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市山崎町野', '28', '28227', '6712543', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '山崎町野', 'ヤマサキチョウノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市山崎町千本屋', '28', '28227', '6712544', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '山崎町千本屋', 'ヤマサキチョウセンボンヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市山崎町中井', '28', '28227', '6712545', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '山崎町中井', 'ヤマサキチョウナカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市山崎町春安', '28', '28227', '6712551', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '山崎町春安', 'ヤマサキチョウハルヤス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市山崎町段', '28', '28227', '6712552', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '山崎町段', 'ヤマサキチョウダン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市山崎町鶴木', '28', '28227', '6712553', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '山崎町鶴木', 'ヤマサキチョウツルギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市山崎町御名', '28', '28227', '6712554', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '山崎町御名', 'ヤマサキチョウゴミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市山崎町金谷', '28', '28227', '6712555', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '山崎町金谷', 'ヤマサキチョウカナヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市山崎町下比地', '28', '28227', '6712556', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '山崎町下比地', 'ヤマサキチョウシモヒジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市山崎町中比地', '28', '28227', '6712557', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '山崎町中比地', 'ヤマサキチョウナカヒジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市山崎町上比地', '28', '28227', '6712558', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '山崎町上比地', 'ヤマサキチョウカミヒジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市山崎町塩山', '28', '28227', '6712560', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '山崎町塩山', 'ヤマサキチョウシオヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市山崎町小茅野', '28', '28227', '6712561', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '山崎町小茅野', 'ヤマサキチョウコガイノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市山崎町大沢', '28', '28227', '6712562', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '山崎町大沢', 'ヤマサキチョウオオサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市山崎町塩田', '28', '28227', '6712563', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '山崎町塩田', 'ヤマサキチョウシオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市山崎町青木', '28', '28227', '6712564', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '山崎町青木', 'ヤマサキチョウアオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市山崎町高下', '28', '28227', '6712565', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '山崎町高下', 'ヤマサキチョウコウゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市山崎町市場', '28', '28227', '6712566', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '山崎町市場', 'ヤマサキチョウイチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市山崎町木谷', '28', '28227', '6712567', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '山崎町木谷', 'ヤマサキチョウキダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市山崎町葛根', '28', '28227', '6712568', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '山崎町葛根', 'ヤマサキチョウカズラネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市山崎町土万', '28', '28227', '6712569', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '山崎町土万', 'ヤマサキチョウヒジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市山崎町加生', '28', '28227', '6712570', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '山崎町加生', 'ヤマサキチョウカショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市山崎町上寺', '28', '28227', '6712571', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '山崎町上寺', 'ヤマサキチョウウエデラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市山崎町庄能', '28', '28227', '6712572', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '山崎町庄能', 'ヤマサキチョウショウノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市山崎町今宿', '28', '28227', '6712573', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '山崎町今宿', 'ヤマサキチョウイマジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市山崎町中広瀬', '28', '28227', '6712574', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '山崎町中広瀬', 'ヤマサキチョウナカビロセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市山崎町山田', '28', '28227', '6712575', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '山崎町山田', 'ヤマサキチョウヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市山崎町鹿沢', '28', '28227', '6712576', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '山崎町鹿沢', 'ヤマサキチョウシカサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市山崎町山崎', '28', '28227', '6712577', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '山崎町山崎', 'ヤマサキチョウヤマサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市山崎町元山崎', '28', '28227', '6712578', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '山崎町元山崎', 'ヤマサキチョウモトヤマサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市山崎町門前', '28', '28227', '6712579', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '山崎町門前', 'ヤマサキチョウモンゼン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市千種町千草', '28', '28227', '6713201', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '千種町千草', 'チクサチョウチクサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市千種町黒土', '28', '28227', '6713202', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '千種町黒土', 'チクサチョウクロヅチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市千種町岩野辺', '28', '28227', '6713211', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '千種町岩野辺', 'チクサチョウイワノベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市千種町鷹巣', '28', '28227', '6713212', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '千種町鷹巣', 'チクサチョウタカノス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市千種町西山', '28', '28227', '6713221', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '千種町西山', 'チクサチョウニシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市千種町奥西山', '28', '28227', '6713222', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '千種町奥西山', 'チクサチョウオクニシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市千種町室', '28', '28227', '6713223', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '千種町室', 'チクサチョウムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市千種町七野', '28', '28227', '6713224', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '千種町七野', 'チクサチョウヒツノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市千種町下河野', '28', '28227', '6713225', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '千種町下河野', 'チクサチョウケゴノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市千種町河呂', '28', '28227', '6713231', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '千種町河呂', 'チクサチョウコウロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市千種町河内', '28', '28227', '6713232', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '千種町河内', 'チクサチョウコウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市千種町西河内', '28', '28227', '6713233', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '千種町西河内', 'チクサチョウニシゴウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市一宮町倉床', '28', '28227', '6714101', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '一宮町倉床', 'イチノミヤチョウクラトコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市一宮町横山', '28', '28227', '6714102', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '一宮町横山', 'イチノミヤチョウヨコヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市一宮町黒原', '28', '28227', '6714103', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '一宮町黒原', 'イチノミヤチョウクロハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市一宮町井内', '28', '28227', '6714104', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '一宮町井内', 'イチノミヤチョウイウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市一宮町上岸田', '28', '28227', '6714105', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '一宮町上岸田', 'イチノミヤチョウカミキシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市一宮町百千家満', '28', '28227', '6714106', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '一宮町百千家満', 'イチノミヤチョウオチヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市一宮町草木', '28', '28227', '6714107', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '一宮町草木', 'イチノミヤチョウクサギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市一宮町千町', '28', '28227', '6714108', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '一宮町千町', 'イチノミヤチョウセンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市一宮町公文', '28', '28227', '6714111', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '一宮町公文', 'イチノミヤチョウクモン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市一宮町森添', '28', '28227', '6714112', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '一宮町森添', 'イチノミヤチョウモリソエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市一宮町三方町', '28', '28227', '6714113', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '一宮町三方町', 'イチノミヤチョウミカタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市一宮町福野', '28', '28227', '6714114', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '一宮町福野', 'イチノミヤチョウフクノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市一宮町河原田', '28', '28227', '6714115', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '一宮町河原田', 'イチノミヤチョウカワハラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市一宮町福中', '28', '28227', '6714121', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '一宮町福中', 'イチノミヤチョウフクナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市一宮町福知', '28', '28227', '6714122', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '一宮町福知', 'イチノミヤチョウフクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市一宮町生栖', '28', '28227', '6714123', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '一宮町生栖', 'イチノミヤチョウイギス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市一宮町深河谷', '28', '28227', '6714124', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '一宮町深河谷', 'イチノミヤチョウフカダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市一宮町西深', '28', '28227', '6714125', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '一宮町西深', 'イチノミヤチョウニシブカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市一宮町安積', '28', '28227', '6714131', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '一宮町安積', 'イチノミヤチョウアヅミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市一宮町東市場', '28', '28227', '6714132', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '一宮町東市場', 'イチノミヤチョウヒガシイチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市一宮町須行名', '28', '28227', '6714133', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '一宮町須行名', 'イチノミヤチョウスギョウメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市一宮町伊和', '28', '28227', '6714134', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '一宮町伊和', 'イチノミヤチョウイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市一宮町安黒', '28', '28227', '6714135', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '一宮町安黒', 'イチノミヤチョウアグロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市一宮町嶋田', '28', '28227', '6714136', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '一宮町嶋田', 'イチノミヤチョウシマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市一宮町閏賀', '28', '28227', '6714137', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '一宮町閏賀', 'イチノミヤチョウウルカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市一宮町西安積', '28', '28227', '6714138', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '一宮町西安積', 'イチノミヤチョウニシアヅミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市一宮町杉田', '28', '28227', '6714139', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '一宮町杉田', 'イチノミヤチョウスギタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市一宮町東河内', '28', '28227', '6714141', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '一宮町東河内', 'イチノミヤチョウヒガシゴウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市一宮町能倉', '28', '28227', '6714142', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '一宮町能倉', 'イチノミヤチョウヨクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市一宮町上野田', '28', '28227', '6714143', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '一宮町上野田', 'イチノミヤチョウカミノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市一宮町下野田', '28', '28227', '6714144', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '一宮町下野田', 'イチノミヤチョウシモノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市波賀町戸倉', '28', '28227', '6714201', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '波賀町戸倉', 'ハガチョウトクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市波賀町道谷', '28', '28227', '6714202', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '波賀町道谷', 'ハガチョウドウタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市波賀町鹿伏', '28', '28227', '6714203', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '波賀町鹿伏', 'ハガチョウシカブシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市波賀町引原', '28', '28227', '6714204', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '波賀町引原', 'ハガチョウヒキハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市波賀町音水', '28', '28227', '6714211', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '波賀町音水', 'ハガチョウオンズイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市波賀町日ノ原', '28', '28227', '6714212', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '波賀町日ノ原', 'ハガチョウヒノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市波賀町原', '28', '28227', '6714213', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '波賀町原', 'ハガチョウハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市波賀町野尻', '28', '28227', '6714214', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '波賀町野尻', 'ハガチョウノジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市波賀町飯見', '28', '28227', '6714215', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '波賀町飯見', 'ハガチョウイイミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市波賀町皆木', '28', '28227', '6714216', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '波賀町皆木', 'ハガチョウミナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市波賀町上野', '28', '28227', '6714221', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '波賀町上野', 'ハガチョウウエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市波賀町有賀', '28', '28227', '6714231', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '波賀町有賀', 'ハガチョウアリガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市波賀町斉木', '28', '28227', '6714232', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '波賀町斉木', 'ハガチョウサイキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市波賀町安賀', '28', '28227', '6714241', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '波賀町安賀', 'ハガチョウヤスガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市波賀町今市', '28', '28227', '6714242', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '波賀町今市', 'ハガチョウイマイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市波賀町小野', '28', '28227', '6714243', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '波賀町小野', 'ハガチョウオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市波賀町谷', '28', '28227', '6714244', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '波賀町谷', 'ハガチョウタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県宍粟市波賀町日見谷', '28', '28227', '6714245', '兵庫県', 'ヒョウゴケン', '宍粟市', 'シソウシ', '波賀町日見谷', 'ハガチョウヒミタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市家島町真浦', '28', '28201', '6720101', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '家島町真浦', 'イエシマチョウマウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市家島町宮', '28', '28201', '6720102', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '家島町宮', 'イエシマチョウミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市家島町坊勢', '28', '28201', '6720103', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '家島町坊勢', 'イエシマチョウボウゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市兼田', '28', '28201', '6728001', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '兼田', 'カネダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市北原', '28', '28201', '6728002', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '北原', 'キタハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市奥山', '28', '28201', '6728003', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '奥山', 'オクヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市継', '28', '28201', '6728004', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '継', 'ツギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市白浜町神田', '28', '28201', '6728011', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '白浜町神田', 'シラハマチョウカンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市白浜町寺家', '28', '28201', '6728012', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '白浜町寺家', 'シラハマチョウジケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市白浜町宇佐崎北', '28', '28201', '6728013', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '白浜町宇佐崎北', 'シラハマチョウウサザキキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市東山', '28', '28201', '6728014', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '東山', 'ヒガシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市八家', '28', '28201', '6728015', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '八家', 'ヤカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市木場', '28', '28201', '6728016', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '木場', 'キバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市木場十八反町', '28', '28201', '6728017', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '木場十八反町', 'キバジュウハッタンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市木場前中町', '28', '28201', '6728018', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '木場前中町', 'キバマエナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市木場前七反町', '28', '28201', '6728019', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '木場前七反町', 'キバマエナナタンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市白浜町宇佐崎中', '28', '28201', '6728021', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '白浜町宇佐崎中', 'シラハマチョウウサザキナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市白浜町宇佐崎南', '28', '28201', '6728022', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '白浜町宇佐崎南', 'シラハマチョウウサザキミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市白浜町', '28', '28201', '6728023', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '白浜町', 'シラハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市白浜町灘浜', '28', '28201', '6728024', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '白浜町灘浜', 'シラハマチョウナダハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市飾磨区堀川町', '28', '28201', '6728025', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '飾磨区堀川町', 'シカマクホリカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市飾磨区阿成植木', '28', '28201', '6728030', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '飾磨区阿成植木', 'シカマクアナセウエキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市飾磨区妻鹿', '28', '28201', '6728031', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '飾磨区妻鹿', 'シカマクメガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市飾磨区妻鹿東海町', '28', '28201', '6728032', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '飾磨区妻鹿東海町', 'シカマクメガトウカイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市飾磨区妻鹿日田町', '28', '28201', '6728033', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '飾磨区妻鹿日田町', 'シカマクメガヒダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市飾磨区妻鹿常盤町', '28', '28201', '6728034', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '飾磨区妻鹿常盤町', 'シカマクメガトキワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市飾磨区中島', '28', '28201', '6728035', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '飾磨区中島', 'シカマクナカシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市飾磨区三和町', '28', '28201', '6728036', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '飾磨区三和町', 'シカマクサンワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市飾磨区阿成', '28', '28201', '6728037', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '飾磨区阿成', 'シカマクアナセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市飾磨区阿成鹿古', '28', '28201', '6728038', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '飾磨区阿成鹿古', 'シカマクアナセカコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市飾磨区阿成渡場', '28', '28201', '6728039', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '飾磨区阿成渡場', 'シカマクアナセワタシバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市飾磨区野田町', '28', '28201', '6728040', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '飾磨区野田町', 'シカマクノダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市三条町2丁目', '28', '28201', '6728041', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '三条町', 'サンジョウチョウ', null, null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('81451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市飾磨区上野田', '28', '28201', '6728043', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '飾磨区上野田', 'シカマクカミノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市飾磨区下野田', '28', '28201', '6728044', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '飾磨区下野田', 'シカマクシモノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市飾磨区中野田', '28', '28201', '6728045', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '飾磨区中野田', 'シカマクナカノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市飾磨区都倉', '28', '28201', '6728046', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '飾磨区都倉', 'シカマクトクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市飾磨区亀山', '28', '28201', '6728047', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '飾磨区亀山', 'シカマクカメヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市飾磨区三宅', '28', '28201', '6728048', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '飾磨区三宅', 'シカマクミヤケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市佃町', '28', '28201', '6728049', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '佃町', 'ツクダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市飾磨区清水', '28', '28201', '6728051', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '飾磨区清水', 'シカマクシミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市飾磨区玉地', '28', '28201', '6728052', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '飾磨区玉地', 'シカマクタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市飾磨区栄町', '28', '28201', '6728053', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '飾磨区栄町', 'シカマクサカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市飾磨区東堀', '28', '28201', '6728054', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '飾磨区東堀', 'シカマクヒガシボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市飾磨区宮', '28', '28201', '6728055', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '飾磨区宮', 'シカマクミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市飾磨区御幸', '28', '28201', '6728056', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '飾磨区御幸', 'シカマクゴコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市飾磨区恵美酒', '28', '28201', '6728057', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '飾磨区恵美酒', 'シカマクエビス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市飾磨区阿成中垣内', '28', '28201', '6728058', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '飾磨区阿成中垣内', 'シカマクアナセナカカイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市飾磨区阿成下垣内', '28', '28201', '6728059', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '飾磨区阿成下垣内', 'シカマクアナセシモカイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市飾磨区天神', '28', '28201', '6728061', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '飾磨区天神', 'シカマクテンジン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市飾磨区大浜', '28', '28201', '6728062', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '飾磨区大浜', 'シカマクオオハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市飾磨区須加', '28', '28201', '6728063', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '飾磨区須加', 'シカマクスカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市飾磨区細江', '28', '28201', '6728064', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '飾磨区細江', 'シカマクホソエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市飾磨区加茂南', '28', '28201', '6728069', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '飾磨区加茂南', 'シカマクカモミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市飾磨区加茂東', '28', '28201', '6728070', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '飾磨区加茂東', 'シカマクカモヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市飾磨区構', '28', '28201', '6728071', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '飾磨区構', 'シカマクカマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市飾磨区蓼野町', '28', '28201', '6728072', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '飾磨区蓼野町', 'シカマクタデノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市飾磨区加茂北', '28', '28201', '6728073', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '飾磨区加茂北', 'シカマクカモキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市飾磨区加茂', '28', '28201', '6728074', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '飾磨区加茂', 'シカマクカモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市飾磨区思案橋', '28', '28201', '6728075', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '飾磨区思案橋', 'シカマクシアンバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市飾磨区入船町', '28', '28201', '6728076', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '飾磨区入船町', 'シカマクイリフネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市飾磨区粕谷新町', '28', '28201', '6728077', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '飾磨区粕谷新町', 'シカマクカスヤシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市飾磨区英賀', '28', '28201', '6728078', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '飾磨区英賀', 'シカマクアガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市飾磨区今在家', '28', '28201', '6728079', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '飾磨区今在家', 'シカマクイマザイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市飾磨区英賀宮町', '28', '28201', '6728080', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '飾磨区英賀宮町', 'シカマクアガミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市飾磨区高町', '28', '28201', '6728081', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '飾磨区高町', 'シカマクタカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市飾磨区付城', '28', '28201', '6728082', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '飾磨区付城', 'シカマクツケシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市飾磨区城南町', '28', '28201', '6728083', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '飾磨区城南町', 'シカマクジョウナンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市飾磨区英賀清水町', '28', '28201', '6728084', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '飾磨区英賀清水町', 'シカマクアガシミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市飾磨区中浜町', '28', '28201', '6728085', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '飾磨区中浜町', 'シカマクナカハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市飾磨区西浜町', '28', '28201', '6728086', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '飾磨区西浜町', 'シカマクニシハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市飾磨区英賀東町', '28', '28201', '6728087', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '飾磨区英賀東町', 'シカマクアガヒガシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市飾磨区英賀西町', '28', '28201', '6728088', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '飾磨区英賀西町', 'シカマクアガニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市飾磨区英賀宮台', '28', '28201', '6728089', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '飾磨区英賀宮台', 'シカマクアガミヤダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市飾磨区今在家北', '28', '28201', '6728090', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '飾磨区今在家北', 'シカマクイマザイケキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市飾磨区英賀保駅前町', '28', '28201', '6728091', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '飾磨区英賀保駅前町', 'シカマクアガホエキマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市飾磨区英賀春日町', '28', '28201', '6728092', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '飾磨区英賀春日町', 'シカマクアガカスガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市飾磨区矢倉町', '28', '28201', '6728093', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '飾磨区矢倉町', 'シカマクヤグラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市飾磨区鎌倉町', '28', '28201', '6728094', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '飾磨区鎌倉町', 'シカマクカマクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市飾磨区若宮町', '28', '28201', '6728095', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '飾磨区若宮町', 'シカマクワカミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市飾磨区山崎台', '28', '28201', '6728096', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '飾磨区山崎台', 'シカマクヤマサキダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市飾磨区山崎', '28', '28201', '6728097', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '飾磨区山崎', 'シカマクヤマサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市飾磨区富士見ケ丘町', '28', '28201', '6728098', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '飾磨区富士見ケ丘町', 'シカマクフジミガオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市', '28', '28203', '6730000', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('81510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市明南町', '28', '28203', '6730001', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '明南町', 'メイナンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市旭が丘', '28', '28203', '6730002', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '旭が丘', 'アサヒガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市鳥羽', '28', '28203', '6730003', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '鳥羽', 'トバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市鳥羽弁財天', '28', '28203', '6730004', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '鳥羽弁財天', 'トバベンザイテン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市小久保', '28', '28203', '6730005', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '小久保', 'コクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市鳥羽二本松', '28', '28203', '6730006', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '鳥羽二本松', 'トバニホンマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市鳥羽西鳥羽', '28', '28203', '6730007', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '鳥羽西鳥羽', 'トバニシトバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市沢野', '28', '28203', '6730008', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '沢野', 'サワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市西明石町', '28', '28203', '6730011', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '西明石町', 'ニシアカシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市和坂', '28', '28203', '6730012', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '和坂', 'ワサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市和坂稲荷町', '28', '28203', '6730013', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '和坂稲荷町', 'ワサカイナリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市川崎町', '28', '28203', '6730014', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '川崎町', 'カワサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市花園町', '28', '28203', '6730015', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '花園町', 'ハナゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市松の内', '28', '28203', '6730016', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '松の内', 'マツノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市野々上', '28', '28203', '6730017', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '野々上', 'ノノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市西明石北町', '28', '28203', '6730018', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '西明石北町', 'ニシアカシキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市北王子町', '28', '28203', '6730021', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '北王子町', 'キタオウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市王子', '28', '28203', '6730022', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '王子', 'オウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市西新町', '28', '28203', '6730023', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '西新町', 'ニシシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市南王子町', '28', '28203', '6730024', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '南王子町', 'ミナミオウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市田町', '28', '28203', '6730025', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '田町', 'タマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市船上町', '28', '28203', '6730026', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '船上町', 'フナゲチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市新明町', '28', '28203', '6730027', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '新明町', 'シンメイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市硯町', '28', '28203', '6730028', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '硯町', 'スズリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市大道町', '28', '28203', '6730029', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '大道町', 'ダイドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市宮の上', '28', '28203', '6730031', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '宮の上', 'ミヤノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市立石', '28', '28203', '6730032', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '立石', 'タテイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市林崎町', '28', '28203', '6730033', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '林崎町', 'ハヤシサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市林', '28', '28203', '6730034', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '林', 'ハヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市南貴崎町', '28', '28203', '6730035', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '南貴崎町', 'ミナミキサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市松江', '28', '28203', '6730036', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '松江', 'マツエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市貴崎', '28', '28203', '6730037', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '貴崎', 'キサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市別所町', '28', '28203', '6730038', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '別所町', 'ベッショチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市西明石南町', '28', '28203', '6730041', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '西明石南町', 'ニシアカシミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市東藤江', '28', '28203', '6730042', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '東藤江', 'ヒガシフジエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市藤江川添', '28', '28203', '6730043', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '藤江', 'フジエ', null, null, '川添', 'カワゾエ');
INSERT INTO `ms_addresses` VALUES ('81546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市藤江', '28', '28203', '6730044', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '藤江', 'フジエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市藤江若林', '28', '28203', '6730045', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '藤江', 'フジエ', null, null, '若林', 'ワカバヤシ');
INSERT INTO `ms_addresses` VALUES ('81548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市藤が丘', '28', '28203', '6730046', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '藤が丘', 'フジガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市藤江中谷町', '28', '28203', '6730047', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '藤江', 'フジエ', null, null, '中谷町', 'ナカタニチョウ');
INSERT INTO `ms_addresses` VALUES ('81550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市藤江中谷山', '28', '28203', '6730048', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '藤江', 'フジエ', null, null, '中谷山', 'ナカタニヤマ');
INSERT INTO `ms_addresses` VALUES ('81551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市西明石西町', '28', '28203', '6730049', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '西明石西町', 'ニシアカシニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市', '28', '28215', '6730400', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('81553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市跡部', '28', '28215', '6730401', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '跡部', 'アトベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市加佐', '28', '28215', '6730402', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '加佐', 'カサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市末広', '28', '28215', '6730403', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '末広', 'スエヒロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市大村', '28', '28215', '6730404', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '大村', 'オオムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市平田', '28', '28215', '6730405', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '平田', 'ヒラタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市久留美', '28', '28215', '6730411', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '久留美', 'クルミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市岩宮', '28', '28215', '6730412', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '岩宮', 'イワミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市大塚', '28', '28215', '6730413', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '大塚', 'オオツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市芝町', '28', '28215', '6730414', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '芝町', 'シバマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市府内', '28', '28215', '6730415', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '府内', 'フナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市平井', '28', '28215', '6730421', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '平井', 'ヒライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市与呂木', '28', '28215', '6730422', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '与呂木', 'ヨロキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市宿原', '28', '28215', '6730423', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '宿原', 'シュクハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市自由が丘本町', '28', '28215', '6730424', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '自由が丘本町', 'ジユウガオカホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市君が峰町', '28', '28215', '6730425', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '君が峰町', 'キミガミネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市本町', '28', '28215', '6730431', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市上の丸町', '28', '28215', '6730432', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '上の丸町', 'ウエノマルチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市福井', '28', '28215', '6730433', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '福井', 'フクイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市別所町小林', '28', '28215', '6730434', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '別所町小林', 'ベッショチョウコバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市別所町高木', '28', '28215', '6730435', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '別所町高木', 'ベッショチョウタカギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市さつき台', '28', '28215', '6730436', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', 'さつき台', 'サツキダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市別所町朝日ケ丘', '28', '28215', '6730441', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '別所町朝日ケ丘', 'ベッショチョウアサヒガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市別所町興治', '28', '28215', '6730442', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '別所町興治', 'ベッショチョウオキハル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市別所町巴', '28', '28215', '6730443', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '別所町巴', 'ベッショチョウトモエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市別所町東這田', '28', '28215', '6730444', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '別所町東這田', 'ベッショチョウヒガシホウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市別所町西這田', '28', '28215', '6730445', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '別所町西這田', 'ベッショチョウニシホウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市別所町花尻', '28', '28215', '6730446', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '別所町花尻', 'ベッショチョウハナジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市別所町近藤', '28', '28215', '6730451', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '別所町近藤', 'ベッショチョウコンドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市別所町石野', '28', '28215', '6730452', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '別所町石野', 'ベッショチョウイシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市別所町下石野', '28', '28215', '6730453', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '別所町下石野', 'ベッショチョウシモイシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市別所町正法寺', '28', '28215', '6730454', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '別所町正法寺', 'ベッショチョウショウボウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市別所町和田', '28', '28215', '6730455', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '別所町和田', 'ベッショチョウワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市鳥町', '28', '28215', '6730456', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '鳥町', 'トリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市志染町吉田', '28', '28215', '6730501', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '志染町吉田', 'シジミチョウヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市志染町安福田', '28', '28215', '6730502', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '志染町安福田', 'シジミチョウアブタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市志染町窟屋', '28', '28215', '6730503', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '志染町窟屋', 'シジミチョウイワヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市志染町高男寺', '28', '28215', '6730504', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '志染町高男寺', 'シジミチョウコウナンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市志染町細目', '28', '28215', '6730505', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '志染町細目', 'シジミチョウホソメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市志染町四合谷', '28', '28215', '6730506', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '志染町四合谷', 'シジミチョウシゴウダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市志染町志染中', '28', '28215', '6730511', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '志染町志染中', 'シジミチョウシジミナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市志染町井上', '28', '28215', '6730512', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '志染町井上', 'シジミチョウイノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市志染町大谷', '28', '28215', '6730513', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '志染町大谷', 'シジミチョウオオタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市志染町戸田', '28', '28215', '6730514', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '志染町戸田', 'シジミチョウトダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市志染町三津田', '28', '28215', '6730515', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '志染町三津田', 'シジミチョウミツダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市志染町御坂', '28', '28215', '6730516', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '志染町御坂', 'シジミチョウミサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市志染町青山', '28', '28215', '6730521', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '志染町青山', 'シジミチョウアオヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市緑が丘町西', '28', '28215', '6730531', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '緑が丘町西', 'ミドリガオカチョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市緑が丘町中', '28', '28215', '6730532', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '緑が丘町中', 'ミドリガオカチョウナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市緑が丘町東', '28', '28215', '6730533', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '緑が丘町東', 'ミドリガオカチョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市緑が丘町本町', '28', '28215', '6730534', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '緑が丘町本町', 'ミドリガオカチョウホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市志染町広野', '28', '28215', '6730541', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '志染町広野', 'シジミチョウヒロノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市志染町西自由が丘', '28', '28215', '6730551', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '志染町西自由が丘', 'シジミチョウニシジユウガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市志染町中自由が丘', '28', '28215', '6730552', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '志染町中自由が丘', 'シジミチョウナカジユウガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市志染町東自由が丘', '28', '28215', '6730553', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '志染町東自由が丘', 'シジミチョウヒガシジユウガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市細川町瑞穂', '28', '28215', '6730701', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '細川町瑞穂', 'ホソカワチョウミズホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市細川町中里', '28', '28215', '6730702', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '細川町中里', 'ホソカワチョウナカザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市細川町垂穂', '28', '28215', '6730703', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '細川町垂穂', 'ホソカワチョウタルホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市細川町増田', '28', '28215', '6730704', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '細川町増田', 'ホソカワチョウマスダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市細川町金屋', '28', '28215', '6730711', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '細川町金屋', 'ホソカワチョウカナヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市細川町桃津', '28', '28215', '6730712', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '細川町桃津', 'ホソカワチョウモモヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市細川町豊地', '28', '28215', '6730713', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '細川町豊地', 'ホソカワチョウトヨチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市細川町細川中', '28', '28215', '6730714', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '細川町細川中', 'ホソカワチョウホソカワナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市細川町西', '28', '28215', '6730715', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '細川町西', 'ホソカワチョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市細川町高篠', '28', '28215', '6730721', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '細川町高篠', 'ホソカワチョウタカシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市細川町脇川', '28', '28215', '6730722', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '細川町脇川', 'ホソカワチョウワキガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市加佐草荷野', '28', '28215', '6730723', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '加佐草荷野', 'カサソウカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市細川町高畑', '28', '28215', '6730724', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '細川町高畑', 'ホソカワチョウタカハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市口吉川町東中', '28', '28215', '6730731', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '口吉川町東中', 'クチヨカワチョウヒガシナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市口吉川町馬場', '28', '28215', '6730732', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '口吉川町馬場', 'クチヨカワチョウババ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市口吉川町東', '28', '28215', '6730733', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '口吉川町東', 'クチヨカワチョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市口吉川町蓮花寺', '28', '28215', '6730734', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '口吉川町蓮花寺', 'クチヨカワチョウレンゲジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市口吉川町西中', '28', '28215', '6730735', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '口吉川町西中', 'クチヨカワチョウニシナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市口吉川町桃坂', '28', '28215', '6730736', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '口吉川町桃坂', 'クチヨカワチョウモモザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市口吉川町殿畑', '28', '28215', '6730741', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '口吉川町殿畑', 'クチヨカワチョウトノハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市口吉川町保木', '28', '28215', '6730742', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '口吉川町保木', 'クチヨカワチョウホキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市口吉川町桾原', '28', '28215', '6730743', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '口吉川町桾原', 'クチヨカワチョウクヌギハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市口吉川町里脇', '28', '28215', '6730751', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '口吉川町里脇', 'クチヨカワチョウサトワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市口吉川町吉祥寺', '28', '28215', '6730752', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '口吉川町吉祥寺', 'クチヨカワチョウキツショウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市口吉川町槇', '28', '28215', '6730753', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '口吉川町槇', 'クチヨカワチョウマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市口吉川町善祥寺', '28', '28215', '6730754', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '口吉川町善祥寺', 'クチヨカワチョウゼンショウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市口吉川町大島', '28', '28215', '6730755', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '口吉川町大島', 'クチヨカワチョウオオシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市口吉川町南畑', '28', '28215', '6730756', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '口吉川町南畑', 'クチヨカワチョウミナミバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市口吉川町笹原', '28', '28215', '6730757', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '口吉川町笹原', 'クチヨカワチョウササハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市口吉川町久次', '28', '28215', '6730758', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '口吉川町久次', 'クチヨカワチョウヒサツグ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市太寺天王町', '28', '28203', '6730841', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '太寺天王町', 'タイデラテンノウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市荷山町', '28', '28203', '6730842', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '荷山町', 'ニヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市太寺大野町', '28', '28203', '6730843', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '太寺大野町', 'タイデラオオノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市東野町', '28', '28203', '6730844', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '東野町', 'ヒガシノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市太寺', '28', '28203', '6730845', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '太寺', 'タイデラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市上ノ丸', '28', '28203', '6730846', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '上ノ丸', 'ウエノマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市明石公園', '28', '28203', '6730847', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '明石公園', 'アカシコウエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市鷹匠町', '28', '28203', '6730848', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '鷹匠町', 'タカショウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市茶園場町', '28', '28203', '6730849', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '茶園場町', 'サエンバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市朝霧北町', '28', '28203', '6730851', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '朝霧北町', 'アサギリキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市朝霧台', '28', '28203', '6730852', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '朝霧台', 'アサギリダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市朝霧山手町', '28', '28203', '6730853', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '朝霧山手町', 'アサギリヤマテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市東朝霧丘', '28', '28203', '6730854', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '東朝霧丘', 'ヒガシアサギリオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市中朝霧丘', '28', '28203', '6730855', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '中朝霧丘', 'ナカアサギリオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市西朝霧丘', '28', '28203', '6730856', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '西朝霧丘', 'ニシアサギリオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市北朝霧丘', '28', '28203', '6730857', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '北朝霧丘', 'キタアサギリオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市松が丘北町', '28', '28203', '6730861', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '松が丘北町', 'マツガオカキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市松が丘', '28', '28203', '6730862', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '松が丘', 'マツガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市大蔵谷狩口', '28', '28203', '6730863', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '大蔵谷狩口', 'オオクラダニカリグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市大蔵谷東山西山', '28', '28203', '6730864', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '大蔵谷東山西山', 'オオクラダニヒガシヤマニシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市大蔵谷清水', '28', '28203', '6730865', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '大蔵谷清水', 'オオクラダニシミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市朝霧町', '28', '28203', '6730866', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '朝霧町', 'アサギリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市大蔵谷奥', '28', '28203', '6730867', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '大蔵谷奥', 'オオクラダニオク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市東山町', '28', '28203', '6730868', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '東山町', 'ヒガシヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市大蔵谷東山', '28', '28203', '6730869', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '大蔵谷東山', 'オオクラダニヒガシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市大蔵八幡町', '28', '28203', '6730871', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '大蔵八幡町', 'オオクラハチマンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市大蔵町', '28', '28203', '6730872', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '大蔵町', 'オオクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市大蔵中町', '28', '28203', '6730873', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '大蔵中町', 'オオクラナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市大蔵本町', '28', '28203', '6730874', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '大蔵本町', 'オオクラホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市大蔵天神町', '28', '28203', '6730875', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '大蔵天神町', 'オオクラテンジンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市東人丸町', '28', '28203', '6730876', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '東人丸町', 'ヒガシヒトマルチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市人丸町', '28', '28203', '6730877', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '人丸町', 'ヒトマルチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市山下町', '28', '28203', '6730878', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '山下町', 'ヤマシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市大蔵海岸通', '28', '28203', '6730879', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '大蔵海岸通', 'オオクラカイガンドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市天文町', '28', '28203', '6730881', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '天文町', 'テンモンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市相生町', '28', '28203', '6730882', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '相生町', 'アイオイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市中崎', '28', '28203', '6730883', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '中崎', 'ナカサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市鍛治屋町', '28', '28203', '6730884', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '鍛治屋町', 'カジヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市桜町', '28', '28203', '6730885', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '桜町', 'サクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市東仲ノ町', '28', '28203', '6730886', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '東仲ノ町', 'ヒガシナカノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市大明石町', '28', '28203', '6730891', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '大明石町', 'オオアカシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市本町', '28', '28203', '6730892', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市材木町', '28', '28203', '6730893', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '材木町', 'ザイモクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市港町', '28', '28203', '6730894', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '港町', 'ミナトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市岬町', '28', '28203', '6730895', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '岬町', 'ミサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市日富美町', '28', '28203', '6730896', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '日富美町', 'ヒフミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市大観町', '28', '28203', '6730897', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '大観町', 'タイカンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市樽屋町', '28', '28203', '6730898', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '樽屋町', 'タルヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市吉川町新田', '28', '28215', '6731101', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '吉川町新田', 'ヨカワチョウニッタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市吉川町冨岡', '28', '28215', '6731102', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '吉川町冨岡', 'ヨカワチョウトミオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市吉川町前田', '28', '28215', '6731103', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '吉川町前田', 'ヨカワチョウマエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市吉川町上中', '28', '28215', '6731104', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '吉川町上中', 'ヨカワチョウカミナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市吉川町古川', '28', '28215', '6731105', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '吉川町古川', 'ヨカワチョウフルカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市吉川町実楽', '28', '28215', '6731106', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '吉川町実楽', 'ヨカワチョウジツラク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市吉川町有安', '28', '28215', '6731107', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '吉川町有安', 'ヨカワチョウアリヤス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市吉川町古市', '28', '28215', '6731108', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '吉川町古市', 'ヨカワチョウフルイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市吉川町上荒川', '28', '28215', '6731111', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '吉川町上荒川', 'ヨカワチョウカミアラカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市吉川町畑枝', '28', '28215', '6731112', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '吉川町畑枝', 'ヨカワチョウハタエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市吉川町福井', '28', '28215', '6731113', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '吉川町福井', 'ヨカワチョウフクイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市吉川町吉安', '28', '28215', '6731114', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '吉川町吉安', 'ヨカワチョウキチヤス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市吉川町大沢', '28', '28215', '6731115', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '吉川町大沢', 'ヨカワチョウオオソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市吉川町大畑', '28', '28215', '6731116', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '吉川町大畑', 'ヨカワチョウオオハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市吉川町みなぎ台', '28', '28215', '6731117', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '吉川町みなぎ台', 'ヨカワチョウミナギダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市吉川町貸潮', '28', '28215', '6731118', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '吉川町貸潮', 'ヨカワチョウカシオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市吉川町鍛治屋', '28', '28215', '6731119', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '吉川町鍛治屋', 'ヨカワチョウカジヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市吉川町米田', '28', '28215', '6731121', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '吉川町米田', 'ヨカワチョウヨネダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市吉川町西奥', '28', '28215', '6731122', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '吉川町西奥', 'ヨカワチョウニシオク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市吉川町湯谷', '28', '28215', '6731123', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '吉川町湯谷', 'ヨカワチョウユダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市吉川町法光寺', '28', '28215', '6731124', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '吉川町法光寺', 'ヨカワチョウホウコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市吉川町田谷', '28', '28215', '6731125', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '吉川町田谷', 'ヨカワチョウタヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市吉川町上松', '28', '28215', '6731126', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '吉川町上松', 'ヨカワチョウウエマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市吉川町長谷', '28', '28215', '6731127', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '吉川町長谷', 'ヨカワチョウナガタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市吉川町山上', '28', '28215', '6731128', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '吉川町山上', 'ヨカワチョウヤマノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市吉川町渡瀬', '28', '28215', '6731129', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '吉川町渡瀬', 'ヨカワチョウワタセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市吉川町稲田', '28', '28215', '6731231', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '吉川町稲田', 'ヨカワチョウイナダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市吉川町金会', '28', '28215', '6731232', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '吉川町金会', 'ヨカワチョウキンカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市吉川町毘沙門', '28', '28215', '6731233', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '吉川町毘沙門', 'ヨカワチョウビシャモン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市吉川町福吉', '28', '28215', '6731234', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '吉川町福吉', 'ヨカワチョウフクヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市吉川町市野瀬', '28', '28215', '6731235', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '吉川町市野瀬', 'ヨカワチョウイチノセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市吉川町東田', '28', '28215', '6731236', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '吉川町東田', 'ヨカワチョウヒガシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市吉川町楠原', '28', '28215', '6731241', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '吉川町楠原', 'ヨカワチョウクスハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市吉川町奥谷', '28', '28215', '6731242', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '吉川町奥谷', 'ヨカワチョウオクダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市吉川町豊岡', '28', '28215', '6731243', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '吉川町豊岡', 'ヨカワチョウトヨオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県三木市吉川町水上', '28', '28215', '6731244', '兵庫県', 'ヒョウゴケン', '三木市', 'ミキシ', '吉川町水上', 'ヨカワチョウミズカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加東市黒谷', '28', '28228', '6731301', '兵庫県', 'ヒョウゴケン', '加東市', 'カトウシ', '黒谷', 'クロダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加東市秋津', '28', '28228', '6731302', '兵庫県', 'ヒョウゴケン', '加東市', 'カトウシ', '秋津', 'アキツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加東市少分谷', '28', '28228', '6731303', '兵庫県', 'ヒョウゴケン', '加東市', 'カトウシ', '少分谷', 'ショウブダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加東市長貞', '28', '28228', '6731304', '兵庫県', 'ヒョウゴケン', '加東市', 'カトウシ', '長貞', 'ナガサダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加東市天神', '28', '28228', '6731311', '兵庫県', 'ヒョウゴケン', '加東市', 'カトウシ', '天神', 'テンジン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加東市掎鹿谷', '28', '28228', '6731312', '兵庫県', 'ヒョウゴケン', '加東市', 'カトウシ', '掎鹿谷', 'ハシカダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加東市永福', '28', '28228', '6731313', '兵庫県', 'ヒョウゴケン', '加東市', 'カトウシ', '永福', 'エイフク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加東市横谷', '28', '28228', '6731314', '兵庫県', 'ヒョウゴケン', '加東市', 'カトウシ', '横谷', 'ヨコダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加東市岩屋', '28', '28228', '6731321', '兵庫県', 'ヒョウゴケン', '加東市', 'カトウシ', '岩屋', 'イワヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加東市森', '28', '28228', '6731322', '兵庫県', 'ヒョウゴケン', '加東市', 'カトウシ', '森', 'モリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加東市岡本', '28', '28228', '6731323', '兵庫県', 'ヒョウゴケン', '加東市', 'カトウシ', '岡本', 'オカモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加東市新定', '28', '28228', '6731324', '兵庫県', 'ヒョウゴケン', '加東市', 'カトウシ', '新定', 'シンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加東市大畑', '28', '28228', '6731325', '兵庫県', 'ヒョウゴケン', '加東市', 'カトウシ', '大畑', 'オオハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加東市森尾', '28', '28228', '6731331', '兵庫県', 'ヒョウゴケン', '加東市', 'カトウシ', '森尾', 'モリオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加東市栄枝', '28', '28228', '6731332', '兵庫県', 'ヒョウゴケン', '加東市', 'カトウシ', '栄枝', 'サカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加東市小沢', '28', '28228', '6731333', '兵庫県', 'ヒョウゴケン', '加東市', 'カトウシ', '小沢', 'オザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加東市吉井', '28', '28228', '6731334', '兵庫県', 'ヒョウゴケン', '加東市', 'カトウシ', '吉井', 'ヨシイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加東市藪', '28', '28228', '6731335', '兵庫県', 'ヒョウゴケン', '加東市', 'カトウシ', '藪', 'ヤブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加東市東垂水', '28', '28228', '6731336', '兵庫県', 'ヒョウゴケン', '加東市', 'カトウシ', '東垂水', 'ヒガシタルミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加東市松沢', '28', '28228', '6731337', '兵庫県', 'ヒョウゴケン', '加東市', 'カトウシ', '松沢', 'マツザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加東市厚利', '28', '28228', '6731338', '兵庫県', 'ヒョウゴケン', '加東市', 'カトウシ', '厚利', 'アツトシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加東市南山', '28', '28228', '6731341', '兵庫県', 'ヒョウゴケン', '加東市', 'カトウシ', '南山', 'ミナミヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加東市', '28', '28228', '6731400', '兵庫県', 'ヒョウゴケン', '加東市', 'カトウシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('81748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加東市上鴨川', '28', '28228', '6731401', '兵庫県', 'ヒョウゴケン', '加東市', 'カトウシ', '上鴨川', 'カミカモガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加東市平木', '28', '28228', '6731402', '兵庫県', 'ヒョウゴケン', '加東市', 'カトウシ', '平木', 'ヒラキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加東市下鴨川', '28', '28228', '6731403', '兵庫県', 'ヒョウゴケン', '加東市', 'カトウシ', '下鴨川', 'シモカモガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加東市馬瀬', '28', '28228', '6731404', '兵庫県', 'ヒョウゴケン', '加東市', 'カトウシ', '馬瀬', 'ウマゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加東市畑', '28', '28228', '6731411', '兵庫県', 'ヒョウゴケン', '加東市', 'カトウシ', '畑', 'ハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加東市廻渕', '28', '28228', '6731412', '兵庫県', 'ヒョウゴケン', '加東市', 'カトウシ', '廻渕', 'マワリブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加東市池之内', '28', '28228', '6731413', '兵庫県', 'ヒョウゴケン', '加東市', 'カトウシ', '池之内', 'イケノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加東市上久米', '28', '28228', '6731414', '兵庫県', 'ヒョウゴケン', '加東市', 'カトウシ', '上久米', 'カミクメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加東市下久米', '28', '28228', '6731415', '兵庫県', 'ヒョウゴケン', '加東市', 'カトウシ', '下久米', 'シモクメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加東市久米', '28', '28228', '6731416', '兵庫県', 'ヒョウゴケン', '加東市', 'カトウシ', '久米', 'クメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加東市山国', '28', '28228', '6731421', '兵庫県', 'ヒョウゴケン', '加東市', 'カトウシ', '山国', 'ヤマクニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加東市屋度', '28', '28228', '6731422', '兵庫県', 'ヒョウゴケン', '加東市', 'カトウシ', '屋度', 'ヤド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加東市東古瀬', '28', '28228', '6731423', '兵庫県', 'ヒョウゴケン', '加東市', 'カトウシ', '東古瀬', 'ヒガシゴセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加東市中古瀬', '28', '28228', '6731424', '兵庫県', 'ヒョウゴケン', '加東市', 'カトウシ', '中古瀬', 'ナカゴセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加東市西古瀬', '28', '28228', '6731425', '兵庫県', 'ヒョウゴケン', '加東市', 'カトウシ', '西古瀬', 'ニシコセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加東市社', '28', '28228', '6731431', '兵庫県', 'ヒョウゴケン', '加東市', 'カトウシ', '社', 'ヤシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加東市ひろのが丘', '28', '28228', '6731432', '兵庫県', 'ヒョウゴケン', '加東市', 'カトウシ', 'ひろのが丘', 'ヒロノガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加東市松尾', '28', '28228', '6731433', '兵庫県', 'ヒョウゴケン', '加東市', 'カトウシ', '松尾', 'マツオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加東市東実', '28', '28228', '6731434', '兵庫県', 'ヒョウゴケン', '加東市', 'カトウシ', '東実', 'トウジツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加東市田中', '28', '28228', '6731441', '兵庫県', 'ヒョウゴケン', '加東市', 'カトウシ', '田中', 'タナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加東市出水', '28', '28228', '6731442', '兵庫県', 'ヒョウゴケン', '加東市', 'カトウシ', '出水', 'イズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加東市福吉', '28', '28228', '6731443', '兵庫県', 'ヒョウゴケン', '加東市', 'カトウシ', '福吉', 'フクヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加東市沢部', '28', '28228', '6731444', '兵庫県', 'ヒョウゴケン', '加東市', 'カトウシ', '沢部', 'サワベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加東市大門', '28', '28228', '6731445', '兵庫県', 'ヒョウゴケン', '加東市', 'カトウシ', '大門', 'ダイモン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加東市上田', '28', '28228', '6731446', '兵庫県', 'ヒョウゴケン', '加東市', 'カトウシ', '上田', 'ウエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加東市佐保', '28', '28228', '6731447', '兵庫県', 'ヒョウゴケン', '加東市', 'カトウシ', '佐保', 'サホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加東市家原', '28', '28228', '6731451', '兵庫県', 'ヒョウゴケン', '加東市', 'カトウシ', '家原', 'イエハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加東市鳥居', '28', '28228', '6731452', '兵庫県', 'ヒョウゴケン', '加東市', 'カトウシ', '鳥居', 'トリイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加東市貝原', '28', '28228', '6731453', '兵庫県', 'ヒョウゴケン', '加東市', 'カトウシ', '貝原', 'カイハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加東市野村', '28', '28228', '6731454', '兵庫県', 'ヒョウゴケン', '加東市', 'カトウシ', '野村', 'ノムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加東市西垂水', '28', '28228', '6731455', '兵庫県', 'ヒョウゴケン', '加東市', 'カトウシ', '西垂水', 'ニシタルミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加東市窪田', '28', '28228', '6731456', '兵庫県', 'ヒョウゴケン', '加東市', 'カトウシ', '窪田', 'クボタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加東市木梨', '28', '28228', '6731461', '兵庫県', 'ヒョウゴケン', '加東市', 'カトウシ', '木梨', 'キナシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加東市藤田', '28', '28228', '6731462', '兵庫県', 'ヒョウゴケン', '加東市', 'カトウシ', '藤田', 'フジタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加東市梶原', '28', '28228', '6731463', '兵庫県', 'ヒョウゴケン', '加東市', 'カトウシ', '梶原', 'カジワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加東市上中', '28', '28228', '6731464', '兵庫県', 'ヒョウゴケン', '加東市', 'カトウシ', '上中', 'カミナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加東市喜田', '28', '28228', '6731465', '兵庫県', 'ヒョウゴケン', '加東市', 'カトウシ', '喜田', 'キタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加東市山口', '28', '28228', '6731471', '兵庫県', 'ヒョウゴケン', '加東市', 'カトウシ', '山口', 'ヤマグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加東市上三草', '28', '28228', '6731472', '兵庫県', 'ヒョウゴケン', '加東市', 'カトウシ', '上三草', 'カミミクサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加東市下三草', '28', '28228', '6731473', '兵庫県', 'ヒョウゴケン', '加東市', 'カトウシ', '下三草', 'シモミクサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加東市牧野', '28', '28228', '6731474', '兵庫県', 'ヒョウゴケン', '加東市', 'カトウシ', '牧野', 'マキノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加東市吉馬', '28', '28228', '6731475', '兵庫県', 'ヒョウゴケン', '加東市', 'カトウシ', '吉馬', 'ヨシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市大久保町大窪', '28', '28203', '6740051', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '大久保町大窪', 'オオクボチョウオオクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市大久保町松陰新田', '28', '28203', '6740052', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '大久保町松陰新田', 'オオクボチョウマツカゲシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市大久保町松陰', '28', '28203', '6740053', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '大久保町松陰', 'オオクボチョウマツカゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市大久保町西脇', '28', '28203', '6740054', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '大久保町西脇', 'オオクボチョウニシワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市大久保町緑が丘', '28', '28203', '6740055', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '大久保町緑が丘', 'オオクボチョウミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市大久保町山手台', '28', '28203', '6740056', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '大久保町山手台', 'オオクボチョウヤマテダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市大久保町高丘', '28', '28203', '6740057', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '大久保町高丘', 'オオクボチョウタカオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市大久保町森田', '28', '28203', '6740061', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '大久保町森田', 'オオクボチョウモリタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市大久保町谷八木', '28', '28203', '6740062', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '大久保町谷八木', 'オオクボチョウタニヤギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市大久保町八木', '28', '28203', '6740063', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '大久保町八木', 'オオクボチョウヤギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市大久保町江井島', '28', '28203', '6740064', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '大久保町江井島', 'オオクボチョウエイガシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市大久保町西島', '28', '28203', '6740065', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '大久保町西島', 'オオクボチョウニシジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市大久保町福田', '28', '28203', '6740066', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '大久保町福田', 'オオクボチョウフクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市大久保町大久保町', '28', '28203', '6740067', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '大久保町大久保町', 'オオクボチョウオオクボマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市大久保町ゆりのき通', '28', '28203', '6740068', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '大久保町ゆりのき通', 'オオクボチョウユリノキドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市大久保町わかば', '28', '28203', '6740069', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '大久保町わかば', 'オオクボチョウワカバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市魚住町金ケ崎', '28', '28203', '6740071', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '魚住町金ケ崎', 'ウオズミチョウカナガサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市魚住町長坂寺', '28', '28203', '6740072', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '魚住町長坂寺', 'ウオズミチョウチョウハンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市魚住町鴨池', '28', '28203', '6740073', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '魚住町鴨池', 'ウオズミチョウカモイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市魚住町清水', '28', '28203', '6740074', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '魚住町清水', 'ウオズミチョウシミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市魚住町錦が丘', '28', '28203', '6740081', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '魚住町錦が丘', 'ウオズミチョウニシキガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市魚住町中尾', '28', '28203', '6740082', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '魚住町中尾', 'ウオズミチョウナカオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市魚住町住吉', '28', '28203', '6740083', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '魚住町住吉', 'ウオズミチョウスミヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市魚住町西岡', '28', '28203', '6740084', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '魚住町西岡', 'ウオズミチョウニシオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市二見町福里', '28', '28203', '6740091', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '二見町福里', 'フタミチョウフクサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市二見町東二見', '28', '28203', '6740092', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '二見町東二見', 'フタミチョウヒガシフタミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市二見町南二見', '28', '28203', '6740093', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '二見町南二見', 'フタミチョウミナミフタミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市二見町西二見', '28', '28203', '6740094', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '二見町西二見', 'フタミチョウニシフタミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県明石市二見町西二見駅前', '28', '28203', '6740095', '兵庫県', 'ヒョウゴケン', '明石市', 'アカシシ', '二見町西二見駅前', 'フタミチョウニシフタミエキマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市', '28', '28210', '6750000', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('81832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加西市', '28', '28220', '6750000', '兵庫県', 'ヒョウゴケン', '加西市', 'カサイシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('81833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市西条山手', '28', '28210', '6750001', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '西条山手', 'サイジョウヤマテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市山手', '28', '28210', '6750002', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '山手', 'ヤマテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市神野町神野', '28', '28210', '6750003', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '神野町神野', 'カンノチョウカンノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市神野町福留', '28', '28210', '6750004', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '神野町福留', 'カンノチョウフクドメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市神野町石守', '28', '28210', '6750005', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '神野町石守', 'カンノチョウイシモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市神野町日岡苑', '28', '28210', '6750006', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '神野町日岡苑', 'カンノチョウヒオカエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市神野町西之山', '28', '28210', '6750007', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '神野町西之山', 'カンノチョウニシノヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市新神野', '28', '28210', '6750008', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '新神野', 'シンカンノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市神野町西条', '28', '28210', '6750009', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '神野町西条', 'カンノチョウサイジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市野口町北野', '28', '28210', '6750011', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '野口町北野', 'ノグチチョウキタノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市野口町野口', '28', '28210', '6750012', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '野口町野口', 'ノグチチョウノグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市野口町二屋', '28', '28210', '6750013', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '野口町二屋', 'ノグチチョウフタヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市野口町古大内', '28', '28210', '6750014', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '野口町古大内', 'ノグチチョウフルオウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市野口町坂井', '28', '28210', '6750015', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '野口町坂井', 'ノグチチョウサカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市野口町長砂', '28', '28210', '6750016', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '野口町長砂', 'ノグチチョウナガスナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市野口町良野', '28', '28210', '6750017', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '野口町良野', 'ノグチチョウヨシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市野口町坂元', '28', '28210', '6750018', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '野口町坂元', 'ノグチチョウサカモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市野口町水足', '28', '28210', '6750019', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '野口町水足', 'ノグチチョウミズアシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市尾上町安田', '28', '28210', '6750021', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '尾上町安田', 'オノエチョウヤスタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市尾上町口里', '28', '28210', '6750022', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '尾上町口里', 'オノエチョウクチリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市尾上町池田', '28', '28210', '6750023', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '尾上町池田', 'オノエチョウイケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市尾上町長田', '28', '28210', '6750024', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '尾上町長田', 'オノエチョウナガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市尾上町養田', '28', '28210', '6750025', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '尾上町養田', 'オノエチョウヨウタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市尾上町旭', '28', '28210', '6750026', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '尾上町旭', 'オノエチョウアサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市尾上町今福', '28', '28210', '6750027', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '尾上町今福', 'オノエチョウイマフク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市加古川町北在家', '28', '28210', '6750031', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '加古川町北在家', 'カコガワチョウキタザイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市加古川町備後', '28', '28210', '6750032', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '加古川町備後', 'カコガワチョウビンゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市加古川町南備後', '28', '28210', '6750033', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '加古川町南備後', 'カコガワチョウミナミビンゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市加古川町稲屋', '28', '28210', '6750034', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '加古川町稲屋', 'カコガワチョウイナヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市加古川町友沢', '28', '28210', '6750035', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '加古川町友沢', 'カコガワチョウトモサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市加古川町西河原', '28', '28210', '6750036', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '加古川町西河原', 'カコガワチョウニシガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市加古川町本町', '28', '28210', '6750037', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '加古川町本町', 'カコガワチョウホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市加古川町木村', '28', '28210', '6750038', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '加古川町木村', 'カコガワチョウキムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市加古川町粟津', '28', '28210', '6750039', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '加古川町粟津', 'カコガワチョウアワヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市西神吉町宮前', '28', '28210', '6750041', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '西神吉町宮前', 'ニシカンキチョウミヤマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市西神吉町西村', '28', '28210', '6750042', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '西神吉町西村', 'ニシカンキチョウニシムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市西神吉町中西', '28', '28210', '6750043', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '西神吉町中西', 'ニシカンキチョウナカニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市西神吉町大国', '28', '28210', '6750044', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '西神吉町大国', 'ニシカンキチョウオオグニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市西神吉町岸', '28', '28210', '6750045', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '西神吉町岸', 'ニシカンキチョウキシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市西神吉町辻', '28', '28210', '6750046', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '西神吉町辻', 'ニシカンキチョウツジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市西神吉町鼎', '28', '28210', '6750047', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '西神吉町鼎', 'ニシカンキチョウカナエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市東神吉町升田', '28', '28210', '6750051', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '東神吉町升田', 'ヒガシカンキチョウマスダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市東神吉町出河原', '28', '28210', '6750052', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '東神吉町出河原', 'ヒガシカンキチョウデガハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市米田町船頭', '28', '28210', '6750053', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '米田町船頭', 'ヨネダチョウセンドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市米田町平津', '28', '28210', '6750054', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '米田町平津', 'ヨネダチョウヒラツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市東神吉町西井ノ口', '28', '28210', '6750055', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '東神吉町西井ノ口', 'ヒガシカンキチョウニシイノクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市東神吉町砂部', '28', '28210', '6750056', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '東神吉町砂部', 'ヒガシカンキチョウイサベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市東神吉町神吉', '28', '28210', '6750057', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '東神吉町神吉', 'ヒガシカンキチョウカンキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市東神吉町天下原', '28', '28210', '6750058', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '東神吉町天下原', 'ヒガシカンキチョウアマガハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市加古川町大野', '28', '28210', '6750061', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '加古川町大野', 'カコガワチョウオオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市加古川町美乃利', '28', '28210', '6750062', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '加古川町美乃利', 'カコガワチョウミノリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市加古川町平野', '28', '28210', '6750063', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '加古川町平野', 'カコガワチョウヒラノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市加古川町溝之口', '28', '28210', '6750064', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '加古川町溝之口', 'カコガワチョウミゾノクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市加古川町篠原町', '28', '28210', '6750065', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '加古川町篠原町', 'カコガワチョウシノハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市加古川町寺家町', '28', '28210', '6750066', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '加古川町寺家町', 'カコガワチョウジケマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市加古川町河原', '28', '28210', '6750067', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '加古川町河原', 'カコガワチョウカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市加古川町中津', '28', '28210', '6750068', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '加古川町中津', 'カコガワチョウナカツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古郡播磨町', '28', '28382', '6750100', '兵庫県', 'ヒョウゴケン', '加古郡播磨町', 'カコグンハリマチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('81891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市平岡町新在家', '28', '28210', '6750101', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '平岡町新在家', 'ヒラオカチョウシンザイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市平岡町西谷', '28', '28210', '6750102', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '平岡町西谷', 'ヒラオカチョウニシタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市平岡町高畑', '28', '28210', '6750103', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '平岡町高畑', 'ヒラオカチョウタカハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市平岡町土山', '28', '28210', '6750104', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '平岡町土山', 'ヒラオカチョウツチヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市平岡町つつじ野', '28', '28210', '6750105', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '平岡町つつじ野', 'ヒラオカチョウツツジノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市平岡町二俣', '28', '28210', '6750111', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '平岡町二俣', 'ヒラオカチョウフタマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市平岡町山之上', '28', '28210', '6750112', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '平岡町山之上', 'ヒラオカチョウヤマノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市平岡町中野', '28', '28210', '6750113', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '平岡町中野', 'ヒラオカチョウナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市平岡町八反田', '28', '28210', '6750114', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '平岡町八反田', 'ヒラオカチョウハッタンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市平岡町一色', '28', '28210', '6750115', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '平岡町一色', 'ヒラオカチョウイシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市平岡町一色東', '28', '28210', '6750116', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '平岡町一色東', 'ヒラオカチョウイシキヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市平岡町一色西', '28', '28210', '6750117', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '平岡町一色西', 'ヒラオカチョウイシキニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市別府町新野辺北町', '28', '28210', '6750121', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '別府町新野辺北町', 'ベフチョウシノベキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市別府町別府', '28', '28210', '6750122', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '別府町別府', 'ベフチョウベフ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市別府町朝日町', '28', '28210', '6750123', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '別府町朝日町', 'ベフチョウアサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市別府町緑町', '28', '28210', '6750124', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '別府町緑町', 'ベフチョウミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市別府町西脇', '28', '28210', '6750125', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '別府町西脇', 'ベフチョウニシワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市別府町本町', '28', '28210', '6750126', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '別府町本町', 'ベフチョウホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市別府町石町', '28', '28210', '6750127', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '別府町石町', 'ベフチョウイシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市別府町中島町', '28', '28210', '6750128', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '別府町中島町', 'ベフチョウナカシママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市別府町新野辺', '28', '28210', '6750131', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '別府町新野辺', 'ベフチョウシノベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市別府町宮田町', '28', '28210', '6750132', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '別府町宮田町', 'ベフチョウミヤデンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市別府町西町', '28', '28210', '6750133', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '別府町西町', 'ベフチョウニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市別府町元町', '28', '28210', '6750134', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '別府町元町', 'ベフチョウモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市別府町東町', '28', '28210', '6750135', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '別府町東町', 'ベフチョウヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市別府町港町', '28', '28210', '6750136', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '別府町港町', 'ベフチョウミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市金沢町', '28', '28210', '6750137', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '金沢町', 'カナザワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古郡播磨町野添城', '28', '28382', '6750141', '兵庫県', 'ヒョウゴケン', '加古郡播磨町', 'カコグンハリマチョウ', '野添城', 'ノゾエジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古郡播磨町大中', '28', '28382', '6750142', '兵庫県', 'ヒョウゴケン', '加古郡播磨町', 'カコグンハリマチョウ', '大中', 'オオナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古郡播磨町宮北', '28', '28382', '6750143', '兵庫県', 'ヒョウゴケン', '加古郡播磨町', 'カコグンハリマチョウ', '宮北', 'ミヤキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古郡播磨町北本荘', '28', '28382', '6750144', '兵庫県', 'ヒョウゴケン', '加古郡播磨町', 'カコグンハリマチョウ', '北本荘', 'キタホンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古郡播磨町宮西', '28', '28382', '6750145', '兵庫県', 'ヒョウゴケン', '加古郡播磨町', 'カコグンハリマチョウ', '宮西', 'ミヤニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古郡播磨町古田', '28', '28382', '6750146', '兵庫県', 'ヒョウゴケン', '加古郡播磨町', 'カコグンハリマチョウ', '古田', 'フルタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古郡播磨町南大中', '28', '28382', '6750147', '兵庫県', 'ヒョウゴケン', '加古郡播磨町', 'カコグンハリマチョウ', '南大中', 'ミナミオオナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古郡播磨町北古田', '28', '28382', '6750148', '兵庫県', 'ヒョウゴケン', '加古郡播磨町', 'カコグンハリマチョウ', '北古田', 'キタフルタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古郡播磨町南野添', '28', '28382', '6750150', '兵庫県', 'ヒョウゴケン', '加古郡播磨町', 'カコグンハリマチョウ', '南野添', 'ミナミノゾエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古郡播磨町野添', '28', '28382', '6750151', '兵庫県', 'ヒョウゴケン', '加古郡播磨町', 'カコグンハリマチョウ', '野添', 'ノゾエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古郡播磨町野添南', '28', '28382', '6750153', '兵庫県', 'ヒョウゴケン', '加古郡播磨町', 'カコグンハリマチョウ', '野添南', 'ノゾエミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古郡播磨町本荘', '28', '28382', '6750154', '兵庫県', 'ヒョウゴケン', '加古郡播磨町', 'カコグンハリマチョウ', '本荘', 'ホンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古郡播磨町新島', '28', '28382', '6750155', '兵庫県', 'ヒョウゴケン', '加古郡播磨町', 'カコグンハリマチョウ', '新島', 'ニイジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古郡播磨町東本荘', '28', '28382', '6750156', '兵庫県', 'ヒョウゴケン', '加古郡播磨町', 'カコグンハリマチョウ', '東本荘', 'ヒガシホンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古郡播磨町上野添', '28', '28382', '6750157', '兵庫県', 'ヒョウゴケン', '加古郡播磨町', 'カコグンハリマチョウ', '上野添', 'カミノゾエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古郡播磨町北野添', '28', '28382', '6750158', '兵庫県', 'ヒョウゴケン', '加古郡播磨町', 'カコグンハリマチョウ', '北野添', 'キタノゾエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古郡播磨町東野添', '28', '28382', '6750159', '兵庫県', 'ヒョウゴケン', '加古郡播磨町', 'カコグンハリマチョウ', '東野添', 'ヒガシノゾエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古郡播磨町西野添', '28', '28382', '6750160', '兵庫県', 'ヒョウゴケン', '加古郡播磨町', 'カコグンハリマチョウ', '西野添', 'ニシノゾエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古郡播磨町二子', '28', '28382', '6750162', '兵庫県', 'ヒョウゴケン', '加古郡播磨町', 'カコグンハリマチョウ', '二子', 'フタゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古郡播磨町古宮', '28', '28382', '6750163', '兵庫県', 'ヒョウゴケン', '加古郡播磨町', 'カコグンハリマチョウ', '古宮', 'コミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古郡播磨町東新島', '28', '28382', '6750164', '兵庫県', 'ヒョウゴケン', '加古郡播磨町', 'カコグンハリマチョウ', '東新島', 'ヒガシニイジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市志方町大澤', '28', '28210', '6750301', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '志方町大澤', 'シカタチョウオオザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市志方町野尻', '28', '28210', '6750302', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '志方町野尻', 'シカタチョウノジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市志方町細工所', '28', '28210', '6750303', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '志方町細工所', 'シカタチョウサイクジョ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市志方町高畑', '28', '28210', '6750304', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '志方町高畑', 'シカタチョウタカハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市志方町大宗', '28', '28210', '6750305', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '志方町大宗', 'シカタチョウオオムネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市志方町東中', '28', '28210', '6750306', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '志方町東中', 'シカタチョウヒガシナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市志方町岡', '28', '28210', '6750311', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '志方町岡', 'シカタチョウオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市志方町広尾', '28', '28210', '6750312', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '志方町広尾', 'シカタチョウヒロオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市志方町投松', '28', '28210', '6750313', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '志方町投松', 'シカタチョウネジマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市志方町上冨木', '28', '28210', '6750314', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '志方町上冨木', 'シカタチョウカミトミキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市志方町志方町', '28', '28210', '6750321', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '志方町志方町', 'シカタチョウシカタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市志方町西牧', '28', '28210', '6750331', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '志方町西牧', 'シカタチョウニシマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市志方町横大路', '28', '28210', '6750332', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '志方町横大路', 'シカタチョウヨコオオジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市志方町西山', '28', '28210', '6750333', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '志方町西山', 'シカタチョウニシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市志方町成井', '28', '28210', '6750334', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '志方町成井', 'シカタチョウナルイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市志方町原', '28', '28210', '6750335', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '志方町原', 'シカタチョウハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市志方町山中', '28', '28210', '6750336', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '志方町山中', 'シカタチョウヤマナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市志方町畑', '28', '28210', '6750341', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '志方町畑', 'シカタチョウハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市志方町雑郷', '28', '28210', '6750342', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '志方町雑郷', 'シカタチョウゾウゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市志方町行常', '28', '28210', '6750343', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '志方町行常', 'シカタチョウユキツネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市志方町東飯坂', '28', '28210', '6750344', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '志方町東飯坂', 'シカタチョウヒガシイイザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市志方町西飯坂', '28', '28210', '6750345', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '志方町西飯坂', 'シカタチョウニシイイザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市志方町西中', '28', '28210', '6750346', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '志方町西中', 'シカタチョウニシナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市志方町永室', '28', '28210', '6750347', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '志方町永室', 'シカタチョウナガムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古郡稲美町', '28', '28381', '6751100', '兵庫県', 'ヒョウゴケン', '加古郡稲美町', 'カコグンイナミチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('81977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古郡稲美町下草谷', '28', '28381', '6751101', '兵庫県', 'ヒョウゴケン', '加古郡稲美町', 'カコグンイナミチョウ', '下草谷', 'シモクサダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古郡稲美町草谷', '28', '28381', '6751102', '兵庫県', 'ヒョウゴケン', '加古郡稲美町', 'カコグンイナミチョウ', '草谷', 'クサダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古郡稲美町野谷', '28', '28381', '6751103', '兵庫県', 'ヒョウゴケン', '加古郡稲美町', 'カコグンイナミチョウ', '野谷', 'ノダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古郡稲美町野寺', '28', '28381', '6751104', '兵庫県', 'ヒョウゴケン', '加古郡稲美町', 'カコグンイナミチョウ', '野寺', 'ノデラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古郡稲美町加古', '28', '28381', '6751105', '兵庫県', 'ヒョウゴケン', '加古郡稲美町', 'カコグンイナミチョウ', '加古', 'カコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古郡稲美町印南', '28', '28381', '6751111', '兵庫県', 'ヒョウゴケン', '加古郡稲美町', 'カコグンイナミチョウ', '印南', 'インナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古郡稲美町六分一', '28', '28381', '6751112', '兵庫県', 'ヒョウゴケン', '加古郡稲美町', 'カコグンイナミチョウ', '六分一', 'ロクブイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古郡稲美町岡', '28', '28381', '6751113', '兵庫県', 'ヒョウゴケン', '加古郡稲美町', 'カコグンイナミチョウ', '岡', 'オカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古郡稲美町国安', '28', '28381', '6751114', '兵庫県', 'ヒョウゴケン', '加古郡稲美町', 'カコグンイナミチョウ', '国安', 'クニヤス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古郡稲美町国岡', '28', '28381', '6751115', '兵庫県', 'ヒョウゴケン', '加古郡稲美町', 'カコグンイナミチョウ', '国岡', 'クニオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古郡稲美町蛸草', '28', '28381', '6751116', '兵庫県', 'ヒョウゴケン', '加古郡稲美町', 'カコグンイナミチョウ', '蛸草', 'タコクサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古郡稲美町北山', '28', '28381', '6751121', '兵庫県', 'ヒョウゴケン', '加古郡稲美町', 'カコグンイナミチョウ', '北山', 'キタヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古郡稲美町中村', '28', '28381', '6751122', '兵庫県', 'ヒョウゴケン', '加古郡稲美町', 'カコグンイナミチョウ', '中村', 'ナカムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古郡稲美町国北', '28', '28381', '6751123', '兵庫県', 'ヒョウゴケン', '加古郡稲美町', 'カコグンイナミチョウ', '国北', 'クニホク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古郡稲美町森安', '28', '28381', '6751124', '兵庫県', 'ヒョウゴケン', '加古郡稲美町', 'カコグンイナミチョウ', '森安', 'モリヤス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古郡稲美町和田', '28', '28381', '6751125', '兵庫県', 'ヒョウゴケン', '加古郡稲美町', 'カコグンイナミチョウ', '和田', 'ワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古郡稲美町幸竹', '28', '28381', '6751126', '兵庫県', 'ヒョウゴケン', '加古郡稲美町', 'カコグンイナミチョウ', '幸竹', 'コウタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古郡稲美町中一色', '28', '28381', '6751127', '兵庫県', 'ヒョウゴケン', '加古郡稲美町', 'カコグンイナミチョウ', '中一色', 'ナカイシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市八幡町宗佐', '28', '28210', '6751201', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '八幡町宗佐', 'ヤハタチョウソウサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市八幡町野村', '28', '28210', '6751202', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '八幡町野村', 'ヤハタチョウノムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市八幡町下村', '28', '28210', '6751203', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '八幡町下村', 'ヤハタチョウシモムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('81999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市八幡町上西条', '28', '28210', '6751204', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '八幡町上西条', 'ヤハタチョウカミサイジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市八幡町中西条', '28', '28210', '6751205', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '八幡町中西条', 'ヤハタチョウナカサイジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市八幡町船町', '28', '28210', '6751206', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '八幡町船町', 'ヤハタチョウフナマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市上荘町白沢', '28', '28210', '6751211', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '上荘町白沢', 'カミソウチョウシラサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市上荘町井ノ口', '28', '28210', '6751212', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '上荘町井ノ口', 'カミソウチョウイノクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市上荘町国包', '28', '28210', '6751213', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '上荘町国包', 'カミソウチョウクニカネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市上荘町見土呂', '28', '28210', '6751214', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '上荘町見土呂', 'カミソウチョウミドロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市上荘町都台', '28', '28210', '6751215', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '上荘町都台', 'カミソウチョウミヤコダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市上荘町都染', '28', '28210', '6751216', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '上荘町都染', 'カミソウチョウツゾメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市上荘町薬栗', '28', '28210', '6751217', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '上荘町薬栗', 'カミソウチョウクスクリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市上荘町小野', '28', '28210', '6751218', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '上荘町小野', 'カミソウチョウオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市平荘町山角', '28', '28210', '6751221', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '平荘町山角', 'ヘイソウチョウヤマカド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市平荘町神木', '28', '28210', '6751222', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '平荘町神木', 'ヘイソウチョウコウギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市平荘町新中山', '28', '28210', '6751223', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '平荘町新中山', 'ヘイソウチョウシンナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市平荘町上原', '28', '28210', '6751224', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '平荘町上原', 'ヘイソウチョウカミハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市平荘町中山', '28', '28210', '6751225', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '平荘町中山', 'ヘイソウチョウナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市平荘町磐', '28', '28210', '6751226', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '平荘町磐', 'ヘイソウチョウイワオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市平荘町養老', '28', '28210', '6751231', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '平荘町養老', 'ヘイソウチョウヨウロウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市平荘町里', '28', '28210', '6751232', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '平荘町里', 'ヘイソウチョウサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市平荘町池尻', '28', '28210', '6751233', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '平荘町池尻', 'ヘイソウチョウイケジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市平荘町西山', '28', '28210', '6751234', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '平荘町西山', 'ヘイソウチョウニシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市平荘町小畑', '28', '28210', '6751235', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '平荘町小畑', 'ヘイソウチョウコバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加古川市平荘町一本松', '28', '28210', '6751236', '兵庫県', 'ヒョウゴケン', '加古川市', 'カコガワシ', '平荘町一本松', 'ヘイソウチョウイッポンマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県小野市', '28', '28218', '6751300', '兵庫県', 'ヒョウゴケン', '小野市', 'オノシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('82024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県小野市小田町', '28', '28218', '6751301', '兵庫県', 'ヒョウゴケン', '小野市', 'オノシ', '小田町', 'オダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県小野市曽根町', '28', '28218', '6751302', '兵庫県', 'ヒョウゴケン', '小野市', 'オノシ', '曽根町', 'ソネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県小野市池田町', '28', '28218', '6751303', '兵庫県', 'ヒョウゴケン', '小野市', 'オノシ', '池田町', 'イケダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県小野市中谷町', '28', '28218', '6751304', '兵庫県', 'ヒョウゴケン', '小野市', 'オノシ', '中谷町', 'ナカタニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県小野市脇本町', '28', '28218', '6751305', '兵庫県', 'ヒョウゴケン', '小野市', 'オノシ', '脇本町', 'ワキモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県小野市船木町', '28', '28218', '6751306', '兵庫県', 'ヒョウゴケン', '小野市', 'オノシ', '船木町', 'フナキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県小野市菅田町', '28', '28218', '6751307', '兵庫県', 'ヒョウゴケン', '小野市', 'オノシ', '菅田町', 'スガタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県小野市中番町', '28', '28218', '6751308', '兵庫県', 'ヒョウゴケン', '小野市', 'オノシ', '中番町', 'ナカバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県小野市福住町', '28', '28218', '6751309', '兵庫県', 'ヒョウゴケン', '小野市', 'オノシ', '福住町', 'フクズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県小野市万勝寺町', '28', '28218', '6751311', '兵庫県', 'ヒョウゴケン', '小野市', 'オノシ', '万勝寺町', 'マンショウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県小野市栄町', '28', '28218', '6751312', '兵庫県', 'ヒョウゴケン', '小野市', 'オノシ', '栄町', 'サカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県小野市大開町', '28', '28218', '6751313', '兵庫県', 'ヒョウゴケン', '小野市', 'オノシ', '大開町', 'ダイカイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県小野市長尾町', '28', '28218', '6751314', '兵庫県', 'ヒョウゴケン', '小野市', 'オノシ', '長尾町', 'ナガオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県小野市日吉町', '28', '28218', '6751315', '兵庫県', 'ヒョウゴケン', '小野市', 'オノシ', '日吉町', 'ヒヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県小野市天神町', '28', '28218', '6751316', '兵庫県', 'ヒョウゴケン', '小野市', 'オノシ', '天神町', 'テンジンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県小野市浄谷町', '28', '28218', '6751317', '兵庫県', 'ヒョウゴケン', '小野市', 'オノシ', '浄谷町', 'キヨタニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県小野市北丘町', '28', '28218', '6751318', '兵庫県', 'ヒョウゴケン', '小野市', 'オノシ', '北丘町', 'キタオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県小野市山田町', '28', '28218', '6751321', '兵庫県', 'ヒョウゴケン', '小野市', 'オノシ', '山田町', 'ヤマダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県小野市匠台', '28', '28218', '6751322', '兵庫県', 'ヒョウゴケン', '小野市', 'オノシ', '匠台', 'タクミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県小野市榊町', '28', '28218', '6751323', '兵庫県', 'ヒョウゴケン', '小野市', 'オノシ', '榊町', 'サガキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県小野市育ケ丘町', '28', '28218', '6751324', '兵庫県', 'ヒョウゴケン', '小野市', 'オノシ', '育ケ丘町', 'イクガオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県小野市樫山町', '28', '28218', '6751325', '兵庫県', 'ヒョウゴケン', '小野市', 'オノシ', '樫山町', 'カシヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県小野市池尻町', '28', '28218', '6751326', '兵庫県', 'ヒョウゴケン', '小野市', 'オノシ', '池尻町', 'イケジリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県小野市市場町', '28', '28218', '6751327', '兵庫県', 'ヒョウゴケン', '小野市', 'オノシ', '市場町', 'イチバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県小野市二葉町', '28', '28218', '6751328', '兵庫県', 'ヒョウゴケン', '小野市', 'オノシ', '二葉町', 'フタバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県小野市神明町', '28', '28218', '6751331', '兵庫県', 'ヒョウゴケン', '小野市', 'オノシ', '神明町', 'シンメイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県小野市中町', '28', '28218', '6751332', '兵庫県', 'ヒョウゴケン', '小野市', 'オノシ', '中町', 'ナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県小野市垂井町', '28', '28218', '6751333', '兵庫県', 'ヒョウゴケン', '小野市', 'オノシ', '垂井町', 'タルイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県小野市大島町', '28', '28218', '6751334', '兵庫県', 'ヒョウゴケン', '小野市', 'オノシ', '大島町', 'オオシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県小野市片山町', '28', '28218', '6751335', '兵庫県', 'ヒョウゴケン', '小野市', 'オノシ', '片山町', 'カタヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県小野市下大部町', '28', '28218', '6751336', '兵庫県', 'ヒョウゴケン', '小野市', 'オノシ', '下大部町', 'シモオオベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県小野市久茂町', '28', '28218', '6751337', '兵庫県', 'ヒョウゴケン', '小野市', 'オノシ', '久茂町', 'クモチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県小野市田園町', '28', '28218', '6751338', '兵庫県', 'ヒョウゴケン', '小野市', 'オノシ', '田園町', 'デンエンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県小野市西脇町', '28', '28218', '6751341', '兵庫県', 'ヒョウゴケン', '小野市', 'オノシ', '西脇町', 'ニシワキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県小野市阿形町', '28', '28218', '6751342', '兵庫県', 'ヒョウゴケン', '小野市', 'オノシ', '阿形町', 'アガタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県小野市来住町', '28', '28218', '6751343', '兵庫県', 'ヒョウゴケン', '小野市', 'オノシ', '来住町', 'キシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県小野市下来住町', '28', '28218', '6751344', '兵庫県', 'ヒョウゴケン', '小野市', 'オノシ', '下来住町', 'シモキシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県小野市黍田町', '28', '28218', '6751345', '兵庫県', 'ヒョウゴケン', '小野市', 'オノシ', '黍田町', 'キビタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県小野市福甸町', '28', '28218', '6751346', '兵庫県', 'ヒョウゴケン', '小野市', 'オノシ', '福甸町', 'フクデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県小野市南青野町', '28', '28218', '6751350', '兵庫県', 'ヒョウゴケン', '小野市', 'オノシ', '南青野町', 'ミナミアオノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県小野市桜台', '28', '28218', '6751351', '兵庫県', 'ヒョウゴケン', '小野市', 'オノシ', '桜台', 'サクラダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県小野市青野ケ原町', '28', '28218', '6751352', '兵庫県', 'ヒョウゴケン', '小野市', 'オノシ', '青野ケ原町', 'アオノガハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県小野市西山町', '28', '28218', '6751352', '兵庫県', 'ヒョウゴケン', '小野市', 'オノシ', '西山町', 'ニシヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県小野市復井町', '28', '28218', '6751352', '兵庫県', 'ヒョウゴケン', '小野市', 'オノシ', '復井町', 'フクイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県小野市河合中町', '28', '28218', '6751353', '兵庫県', 'ヒョウゴケン', '小野市', 'オノシ', '河合中町', 'カワイナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県小野市河合西町', '28', '28218', '6751354', '兵庫県', 'ヒョウゴケン', '小野市', 'オノシ', '河合西町', 'カワイニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県小野市新部町', '28', '28218', '6751355', '兵庫県', 'ヒョウゴケン', '小野市', 'オノシ', '新部町', 'シンベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県小野市旭町', '28', '28218', '6751356', '兵庫県', 'ヒョウゴケン', '小野市', 'オノシ', '旭町', 'アサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県小野市三和町', '28', '28218', '6751357', '兵庫県', 'ヒョウゴケン', '小野市', 'オノシ', '三和町', 'ミワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県小野市粟生町', '28', '28218', '6751358', '兵庫県', 'ヒョウゴケン', '小野市', 'オノシ', '粟生町', 'アオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県小野市昭和町', '28', '28218', '6751359', '兵庫県', 'ヒョウゴケン', '小野市', 'オノシ', '昭和町', 'ショウワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県小野市喜多町', '28', '28218', '6751360', '兵庫県', 'ヒョウゴケン', '小野市', 'オノシ', '喜多町', 'キタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県小野市住吉町', '28', '28218', '6751361', '兵庫県', 'ヒョウゴケン', '小野市', 'オノシ', '住吉町', 'スミヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県小野市久保木町', '28', '28218', '6751362', '兵庫県', 'ヒョウゴケン', '小野市', 'オノシ', '久保木町', 'クボキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県小野市高山町', '28', '28218', '6751362', '兵庫県', 'ヒョウゴケン', '小野市', 'オノシ', '高山町', 'タカヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県小野市古川町', '28', '28218', '6751363', '兵庫県', 'ヒョウゴケン', '小野市', 'オノシ', '古川町', 'フルカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県小野市鹿野町', '28', '28218', '6751364', '兵庫県', 'ヒョウゴケン', '小野市', 'オノシ', '鹿野町', 'カノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県小野市広渡町', '28', '28218', '6751365', '兵庫県', 'ヒョウゴケン', '小野市', 'オノシ', '広渡町', 'コウドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県小野市中島町', '28', '28218', '6751366', '兵庫県', 'ヒョウゴケン', '小野市', 'オノシ', '中島町', 'ナカシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県小野市敷地町', '28', '28218', '6751367', '兵庫県', 'ヒョウゴケン', '小野市', 'オノシ', '敷地町', 'シキジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県小野市住永町', '28', '28218', '6751368', '兵庫県', 'ヒョウゴケン', '小野市', 'オノシ', '住永町', 'スミナガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県小野市高田町', '28', '28218', '6751369', '兵庫県', 'ヒョウゴケン', '小野市', 'オノシ', '高田町', 'タカタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県小野市黒川町', '28', '28218', '6751371', '兵庫県', 'ヒョウゴケン', '小野市', 'オノシ', '黒川町', 'クロカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県小野市本町', '28', '28218', '6751372', '兵庫県', 'ヒョウゴケン', '小野市', 'オノシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県小野市東本町', '28', '28218', '6751373', '兵庫県', 'ヒョウゴケン', '小野市', 'オノシ', '東本町', 'ヒガシホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県小野市本町1丁目', '28', '28218', '6751374', '兵庫県', 'ヒョウゴケン', '小野市', 'オノシ', '本町', 'ホンマチ', null, null, '1丁目', '01チョウメ');
INSERT INTO `ms_addresses` VALUES ('82090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県小野市西本町', '28', '28218', '6751375', '兵庫県', 'ヒョウゴケン', '小野市', 'オノシ', '西本町', 'ニシホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県小野市丸山町', '28', '28218', '6751376', '兵庫県', 'ヒョウゴケン', '小野市', 'オノシ', '丸山町', 'マルヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県小野市葉多町', '28', '28218', '6751377', '兵庫県', 'ヒョウゴケン', '小野市', 'オノシ', '葉多町', 'ハタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県小野市王子町', '28', '28218', '6751378', '兵庫県', 'ヒョウゴケン', '小野市', 'オノシ', '王子町', 'オウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県小野市上新町', '28', '28218', '6751378', '兵庫県', 'ヒョウゴケン', '小野市', 'オノシ', '上新町', 'カミシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県小野市上本町', '28', '28218', '6751379', '兵庫県', 'ヒョウゴケン', '小野市', 'オノシ', '上本町', 'カミホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加西市繁昌町', '28', '28220', '6752101', '兵庫県', 'ヒョウゴケン', '加西市', 'カサイシ', '繁昌町', 'ハンジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加西市中野町', '28', '28220', '6752102', '兵庫県', 'ヒョウゴケン', '加西市', 'カサイシ', '中野町', 'ナカノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加西市鶉野町', '28', '28220', '6752103', '兵庫県', 'ヒョウゴケン', '加西市', 'カサイシ', '鶉野町', 'ウズラノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加西市上宮木町', '28', '28220', '6752104', '兵庫県', 'ヒョウゴケン', '加西市', 'カサイシ', '上宮木町', 'カミミヤキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加西市下宮木町', '28', '28220', '6752105', '兵庫県', 'ヒョウゴケン', '加西市', 'カサイシ', '下宮木町', 'シモミヤキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加西市桑原田町', '28', '28220', '6752111', '兵庫県', 'ヒョウゴケン', '加西市', 'カサイシ', '桑原田町', 'クワハラダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加西市栄町', '28', '28220', '6752112', '兵庫県', 'ヒョウゴケン', '加西市', 'カサイシ', '栄町', 'サカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加西市網引町', '28', '28220', '6752113', '兵庫県', 'ヒョウゴケン', '加西市', 'カサイシ', '網引町', 'アビキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加西市田原町', '28', '28220', '6752114', '兵庫県', 'ヒョウゴケン', '加西市', 'カサイシ', '田原町', 'タハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加西市琵琶甲町', '28', '28220', '6752201', '兵庫県', 'ヒョウゴケン', '加西市', 'カサイシ', '琵琶甲町', 'ビワコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加西市野条町', '28', '28220', '6752202', '兵庫県', 'ヒョウゴケン', '加西市', 'カサイシ', '野条町', 'ノウジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加西市牛居町', '28', '28220', '6752203', '兵庫県', 'ヒョウゴケン', '加西市', 'カサイシ', '牛居町', 'ウシイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加西市新生町', '28', '28220', '6752204', '兵庫県', 'ヒョウゴケン', '加西市', 'カサイシ', '新生町', 'シンジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加西市野田町', '28', '28220', '6752211', '兵庫県', 'ヒョウゴケン', '加西市', 'カサイシ', '野田町', 'ノダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加西市東笠原町', '28', '28220', '6752212', '兵庫県', 'ヒョウゴケン', '加西市', 'カサイシ', '東笠原町', 'ヒガシカサハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加西市西笠原町', '28', '28220', '6752213', '兵庫県', 'ヒョウゴケン', '加西市', 'カサイシ', '西笠原町', 'ニシカサハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加西市倉谷町', '28', '28220', '6752221', '兵庫県', 'ヒョウゴケン', '加西市', 'カサイシ', '倉谷町', 'クラタニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加西市坂本町', '28', '28220', '6752222', '兵庫県', 'ヒョウゴケン', '加西市', 'カサイシ', '坂本町', 'サカモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加西市三口町', '28', '28220', '6752223', '兵庫県', 'ヒョウゴケン', '加西市', 'カサイシ', '三口町', 'ミクチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加西市王子町', '28', '28220', '6752231', '兵庫県', 'ヒョウゴケン', '加西市', 'カサイシ', '王子町', 'オウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加西市戸田井町', '28', '28220', '6752232', '兵庫県', 'ヒョウゴケン', '加西市', 'カサイシ', '戸田井町', 'トタイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加西市両月町', '28', '28220', '6752233', '兵庫県', 'ヒョウゴケン', '加西市', 'カサイシ', '両月町', 'ワチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加西市大村町', '28', '28220', '6752234', '兵庫県', 'ヒョウゴケン', '加西市', 'カサイシ', '大村町', 'オオムラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加西市段下町', '28', '28220', '6752241', '兵庫県', 'ヒョウゴケン', '加西市', 'カサイシ', '段下町', 'ダンゲチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加西市尾崎町', '28', '28220', '6752242', '兵庫県', 'ヒョウゴケン', '加西市', 'カサイシ', '尾崎町', 'オサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加西市中西町', '28', '28220', '6752243', '兵庫県', 'ヒョウゴケン', '加西市', 'カサイシ', '中西町', 'ナカニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加西市北条町小谷', '28', '28220', '6752301', '兵庫県', 'ヒョウゴケン', '加西市', 'カサイシ', '北条町小谷', 'ホウジョウチョウコダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加西市北条町栗田', '28', '28220', '6752302', '兵庫県', 'ヒョウゴケン', '加西市', 'カサイシ', '北条町栗田', 'ホウジョウチョウクリダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加西市北条町古坂', '28', '28220', '6752303', '兵庫県', 'ヒョウゴケン', '加西市', 'カサイシ', '北条町古坂', 'ホウジョウチョウフルサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加西市北条町横尾', '28', '28220', '6752311', '兵庫県', 'ヒョウゴケン', '加西市', 'カサイシ', '北条町横尾', 'ホウジョウチョウヨコオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加西市北条町北条', '28', '28220', '6752312', '兵庫県', 'ヒョウゴケン', '加西市', 'カサイシ', '北条町北条', 'ホウジョウチョウホウジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加西市北条町黒駒', '28', '28220', '6752313', '兵庫県', 'ヒョウゴケン', '加西市', 'カサイシ', '北条町黒駒', 'ホウジョウチョウクロコマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加西市北条町東高室', '28', '28220', '6752321', '兵庫県', 'ヒョウゴケン', '加西市', 'カサイシ', '北条町東高室', 'ホウジョウチョウヒガシタカムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加西市北条町西高室', '28', '28220', '6752322', '兵庫県', 'ヒョウゴケン', '加西市', 'カサイシ', '北条町西高室', 'ホウジョウチョウニシタカムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加西市北条町西南', '28', '28220', '6752323', '兵庫県', 'ヒョウゴケン', '加西市', 'カサイシ', '北条町西南', 'ホウジョウチョウニシナン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加西市北条町東南', '28', '28220', '6752324', '兵庫県', 'ヒョウゴケン', '加西市', 'カサイシ', '北条町東南', 'ホウジョウチョウヒガシナン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加西市東横田町', '28', '28220', '6752331', '兵庫県', 'ヒョウゴケン', '加西市', 'カサイシ', '東横田町', 'ヒガシヨコタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加西市鎮岩町', '28', '28220', '6752332', '兵庫県', 'ヒョウゴケン', '加西市', 'カサイシ', '鎮岩町', 'トコナベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加西市岸呂町', '28', '28220', '6752333', '兵庫県', 'ヒョウゴケン', '加西市', 'カサイシ', '岸呂町', 'キシロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加西市福住町', '28', '28220', '6752334', '兵庫県', 'ヒョウゴケン', '加西市', 'カサイシ', '福住町', 'フクズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加西市西横田町', '28', '28220', '6752335', '兵庫県', 'ヒョウゴケン', '加西市', 'カサイシ', '西横田町', 'ニシヨコタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加西市坂元町', '28', '28220', '6752336', '兵庫県', 'ヒョウゴケン', '加西市', 'カサイシ', '坂元町', 'サカモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加西市市村町', '28', '28220', '6752337', '兵庫県', 'ヒョウゴケン', '加西市', 'カサイシ', '市村町', 'イチムラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加西市東長町', '28', '28220', '6752341', '兵庫県', 'ヒョウゴケン', '加西市', 'カサイシ', '東長町', 'ヒガシオサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加西市西長町', '28', '28220', '6752342', '兵庫県', 'ヒョウゴケン', '加西市', 'カサイシ', '西長町', 'ニシオサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加西市中山町', '28', '28220', '6752343', '兵庫県', 'ヒョウゴケン', '加西市', 'カサイシ', '中山町', 'ナカヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加西市大柳町', '28', '28220', '6752344', '兵庫県', 'ヒョウゴケン', '加西市', 'カサイシ', '大柳町', 'オヤナギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加西市西剣坂町', '28', '28220', '6752345', '兵庫県', 'ヒョウゴケン', '加西市', 'カサイシ', '西剣坂町', 'ニシケンザカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加西市東剣坂町', '28', '28220', '6752346', '兵庫県', 'ヒョウゴケン', '加西市', 'カサイシ', '東剣坂町', 'ヒガシケンザカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加西市福居町', '28', '28220', '6752351', '兵庫県', 'ヒョウゴケン', '加西市', 'カサイシ', '福居町', 'フクイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加西市谷口町', '28', '28220', '6752352', '兵庫県', 'ヒョウゴケン', '加西市', 'カサイシ', '谷口町', 'タニグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加西市吉野町', '28', '28220', '6752353', '兵庫県', 'ヒョウゴケン', '加西市', 'カサイシ', '吉野町', 'ヨシノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加西市山下町', '28', '28220', '6752354', '兵庫県', 'ヒョウゴケン', '加西市', 'カサイシ', '山下町', 'ヤマシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加西市谷町', '28', '28220', '6752361', '兵庫県', 'ヒョウゴケン', '加西市', 'カサイシ', '谷町', 'タニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加西市西上野町', '28', '28220', '6752362', '兵庫県', 'ヒョウゴケン', '加西市', 'カサイシ', '西上野町', 'ニシウエノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加西市吸谷町', '28', '28220', '6752363', '兵庫県', 'ヒョウゴケン', '加西市', 'カサイシ', '吸谷町', 'スイダニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加西市窪田町', '28', '28220', '6752364', '兵庫県', 'ヒョウゴケン', '加西市', 'カサイシ', '窪田町', 'クボタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加西市畑町', '28', '28220', '6752365', '兵庫県', 'ヒョウゴケン', '加西市', 'カサイシ', '畑町', 'ハタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加西市西谷町', '28', '28220', '6752366', '兵庫県', 'ヒョウゴケン', '加西市', 'カサイシ', '西谷町', 'ニシタニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加西市国正町', '28', '28220', '6752401', '兵庫県', 'ヒョウゴケン', '加西市', 'カサイシ', '国正町', 'クニマサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加西市田谷町', '28', '28220', '6752402', '兵庫県', 'ヒョウゴケン', '加西市', 'カサイシ', '田谷町', 'タヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加西市小印南町', '28', '28220', '6752403', '兵庫県', 'ヒョウゴケン', '加西市', 'カサイシ', '小印南町', 'コイナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加西市油谷町', '28', '28220', '6752404', '兵庫県', 'ヒョウゴケン', '加西市', 'カサイシ', '油谷町', 'ユダニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加西市大工町', '28', '28220', '6752411', '兵庫県', 'ヒョウゴケン', '加西市', 'カサイシ', '大工町', 'ダイクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加西市鍛治屋町', '28', '28220', '6752412', '兵庫県', 'ヒョウゴケン', '加西市', 'カサイシ', '鍛治屋町', 'カジヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加西市青野町', '28', '28220', '6752413', '兵庫県', 'ヒョウゴケン', '加西市', 'カサイシ', '青野町', 'アオノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加西市馬渡谷町', '28', '28220', '6752414', '兵庫県', 'ヒョウゴケン', '加西市', 'カサイシ', '馬渡谷町', 'モオタニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加西市河内町', '28', '28220', '6752421', '兵庫県', 'ヒョウゴケン', '加西市', 'カサイシ', '河内町', 'コウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加西市山田町', '28', '28220', '6752422', '兵庫県', 'ヒョウゴケン', '加西市', 'カサイシ', '山田町', 'ヤマダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加西市和泉町', '28', '28220', '6752423', '兵庫県', 'ヒョウゴケン', '加西市', 'カサイシ', '和泉町', 'イズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加西市野上町', '28', '28220', '6752424', '兵庫県', 'ヒョウゴケン', '加西市', 'カサイシ', '野上町', 'ノガミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加西市池上町', '28', '28220', '6752425', '兵庫県', 'ヒョウゴケン', '加西市', 'カサイシ', '池上町', 'イケガミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加西市西野々町', '28', '28220', '6752426', '兵庫県', 'ヒョウゴケン', '加西市', 'カサイシ', '西野々町', 'ニシノノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加西市島町', '28', '28220', '6752431', '兵庫県', 'ヒョウゴケン', '加西市', 'カサイシ', '島町', 'シマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加西市満久町', '28', '28220', '6752432', '兵庫県', 'ヒョウゴケン', '加西市', 'カサイシ', '満久町', 'マクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加西市北町', '28', '28220', '6752433', '兵庫県', 'ヒョウゴケン', '加西市', 'カサイシ', '北町', 'キタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加西市上野町', '28', '28220', '6752434', '兵庫県', 'ヒョウゴケン', '加西市', 'カサイシ', '上野町', 'ウエノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加西市越水町', '28', '28220', '6752441', '兵庫県', 'ヒョウゴケン', '加西市', 'カサイシ', '越水町', 'ウテミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加西市中富町', '28', '28220', '6752442', '兵庫県', 'ヒョウゴケン', '加西市', 'カサイシ', '中富町', 'ナカトミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加西市笹倉町', '28', '28220', '6752443', '兵庫県', 'ヒョウゴケン', '加西市', 'カサイシ', '笹倉町', 'ササクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加西市鴨谷町', '28', '28220', '6752444', '兵庫県', 'ヒョウゴケン', '加西市', 'カサイシ', '鴨谷町', 'カモダニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加西市殿原町', '28', '28220', '6752445', '兵庫県', 'ヒョウゴケン', '加西市', 'カサイシ', '殿原町', 'トノハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加西市上万願寺町', '28', '28220', '6752451', '兵庫県', 'ヒョウゴケン', '加西市', 'カサイシ', '上万願寺町', 'カミマンガンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加西市下万願寺町', '28', '28220', '6752452', '兵庫県', 'ヒョウゴケン', '加西市', 'カサイシ', '下万願寺町', 'シモマンガンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加西市上道山町', '28', '28220', '6752453', '兵庫県', 'ヒョウゴケン', '加西市', 'カサイシ', '上道山町', 'カミミチヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加西市下道山町', '28', '28220', '6752454', '兵庫県', 'ヒョウゴケン', '加西市', 'カサイシ', '下道山町', 'シモミチヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加西市大内町', '28', '28220', '6752455', '兵庫県', 'ヒョウゴケン', '加西市', 'カサイシ', '大内町', 'オオチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加西市若井町', '28', '28220', '6752456', '兵庫県', 'ヒョウゴケン', '加西市', 'カサイシ', '若井町', 'ワカイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加西市佐谷町', '28', '28220', '6752461', '兵庫県', 'ヒョウゴケン', '加西市', 'カサイシ', '佐谷町', 'サタニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加西市別所町', '28', '28220', '6752462', '兵庫県', 'ヒョウゴケン', '加西市', 'カサイシ', '別所町', 'ベッショチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加西市広原町', '28', '28220', '6752463', '兵庫県', 'ヒョウゴケン', '加西市', 'カサイシ', '広原町', 'ヒロワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加西市下芥田町', '28', '28220', '6752464', '兵庫県', 'ヒョウゴケン', '加西市', 'カサイシ', '下芥田町', 'シモゲタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加西市上芥田町', '28', '28220', '6752465', '兵庫県', 'ヒョウゴケン', '加西市', 'カサイシ', '上芥田町', 'カミゲタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県高砂市', '28', '28216', '6760000', '兵庫県', 'ヒョウゴケン', '高砂市', 'タカサゴシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('82208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県高砂市中島', '28', '28216', '6760001', '兵庫県', 'ヒョウゴケン', '高砂市', 'タカサゴシ', '中島', 'ナカシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県高砂市末広町', '28', '28216', '6760002', '兵庫県', 'ヒョウゴケン', '高砂市', 'タカサゴシ', '末広町', 'スエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県高砂市今市', '28', '28216', '6760003', '兵庫県', 'ヒョウゴケン', '高砂市', 'タカサゴシ', '今市', 'イマイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県高砂市荒井町千鳥', '28', '28216', '6760004', '兵庫県', 'ヒョウゴケン', '高砂市', 'タカサゴシ', '荒井町千鳥', 'アライチョウチドリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県高砂市荒井町御旅', '28', '28216', '6760005', '兵庫県', 'ヒョウゴケン', '高砂市', 'タカサゴシ', '荒井町御旅', 'アライチョウオタビ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県高砂市荒井町南栄町', '28', '28216', '6760006', '兵庫県', 'ヒョウゴケン', '高砂市', 'タカサゴシ', '荒井町南栄町', 'アライチョウミナミサカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県高砂市荒井町中町', '28', '28216', '6760007', '兵庫県', 'ヒョウゴケン', '高砂市', 'タカサゴシ', '荒井町中町', 'アライチョウナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県高砂市荒井町新浜', '28', '28216', '6760008', '兵庫県', 'ヒョウゴケン', '高砂市', 'タカサゴシ', '荒井町新浜', 'アライチョウシンハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県高砂市荒井町小松原', '28', '28216', '6760011', '兵庫県', 'ヒョウゴケン', '高砂市', 'タカサゴシ', '荒井町小松原', 'アライチョウコマツバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県高砂市荒井町中新町', '28', '28216', '6760012', '兵庫県', 'ヒョウゴケン', '高砂市', 'タカサゴシ', '荒井町中新町', 'アライチョウナカシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県高砂市荒井町蓮池', '28', '28216', '6760013', '兵庫県', 'ヒョウゴケン', '高砂市', 'タカサゴシ', '荒井町蓮池', 'アライチョウハスイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県高砂市荒井町日之出町', '28', '28216', '6760014', '兵庫県', 'ヒョウゴケン', '高砂市', 'タカサゴシ', '荒井町日之出町', 'アライチョウヒノデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県高砂市荒井町紙町', '28', '28216', '6760015', '兵庫県', 'ヒョウゴケン', '高砂市', 'タカサゴシ', '荒井町紙町', 'アライチョウカミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県高砂市荒井町扇町', '28', '28216', '6760016', '兵庫県', 'ヒョウゴケン', '高砂市', 'タカサゴシ', '荒井町扇町', 'アライチョウオオギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県高砂市荒井町東本町', '28', '28216', '6760017', '兵庫県', 'ヒョウゴケン', '高砂市', 'タカサゴシ', '荒井町東本町', 'アライチョウヒガシホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県高砂市荒井町若宮町', '28', '28216', '6760018', '兵庫県', 'ヒョウゴケン', '高砂市', 'タカサゴシ', '荒井町若宮町', 'アライチョウワカミヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県高砂市緑丘', '28', '28216', '6760019', '兵庫県', 'ヒョウゴケン', '高砂市', 'タカサゴシ', '緑丘', 'ミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県高砂市高砂町朝日町', '28', '28216', '6760021', '兵庫県', 'ヒョウゴケン', '高砂市', 'タカサゴシ', '高砂町朝日町', 'タカサゴチョウアサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県高砂市高砂町浜田町', '28', '28216', '6760022', '兵庫県', 'ヒョウゴケン', '高砂市', 'タカサゴシ', '高砂町浜田町', 'タカサゴチョウハマダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県高砂市高砂町松波町', '28', '28216', '6760023', '兵庫県', 'ヒョウゴケン', '高砂市', 'タカサゴシ', '高砂町松波町', 'タカサゴチョウマツナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県高砂市高砂町木曽町', '28', '28216', '6760024', '兵庫県', 'ヒョウゴケン', '高砂市', 'タカサゴシ', '高砂町木曽町', 'タカサゴチョウキソマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県高砂市西畑', '28', '28216', '6760025', '兵庫県', 'ヒョウゴケン', '高砂市', 'タカサゴシ', '西畑', 'ニシハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県高砂市高砂町沖浜町', '28', '28216', '6760026', '兵庫県', 'ヒョウゴケン', '高砂市', 'タカサゴシ', '高砂町沖浜町', 'タカサゴチョウオキハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県高砂市高砂町宮前町', '28', '28216', '6760027', '兵庫県', 'ヒョウゴケン', '高砂市', 'タカサゴシ', '高砂町宮前町', 'タカサゴチョウミヤマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県高砂市高砂町相生町', '28', '28216', '6760028', '兵庫県', 'ヒョウゴケン', '高砂市', 'タカサゴシ', '高砂町相生町', 'タカサゴチョウアイオイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県高砂市高砂町向島町', '28', '28216', '6760031', '兵庫県', 'ヒョウゴケン', '高砂市', 'タカサゴシ', '高砂町向島町', 'タカサゴチョウムコウジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県高砂市高砂町東浜町', '28', '28216', '6760032', '兵庫県', 'ヒョウゴケン', '高砂市', 'タカサゴシ', '高砂町東浜町', 'タカサゴチョウヒガシハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県高砂市高砂町材木町', '28', '28216', '6760033', '兵庫県', 'ヒョウゴケン', '高砂市', 'タカサゴシ', '高砂町材木町', 'タカサゴチョウザイモクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県高砂市高砂町船頭町', '28', '28216', '6760034', '兵庫県', 'ヒョウゴケン', '高砂市', 'タカサゴシ', '高砂町船頭町', 'タカサゴチョウセンドウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県高砂市高砂町清水町', '28', '28216', '6760035', '兵庫県', 'ヒョウゴケン', '高砂市', 'タカサゴシ', '高砂町清水町', 'タカサゴチョウシミズマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県高砂市高砂町高瀬町', '28', '28216', '6760036', '兵庫県', 'ヒョウゴケン', '高砂市', 'タカサゴシ', '高砂町高瀬町', 'タカサゴチョウタカセマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県高砂市高砂町藍屋町', '28', '28216', '6760037', '兵庫県', 'ヒョウゴケン', '高砂市', 'タカサゴシ', '高砂町藍屋町', 'タカサゴチョウアイヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県高砂市高砂町栄町', '28', '28216', '6760038', '兵庫県', 'ヒョウゴケン', '高砂市', 'タカサゴシ', '高砂町栄町', 'タカサゴチョウサカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県高砂市高砂町今津町', '28', '28216', '6760041', '兵庫県', 'ヒョウゴケン', '高砂市', 'タカサゴシ', '高砂町今津町', 'タカサゴチョウイマヅマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県高砂市高砂町南浜町', '28', '28216', '6760042', '兵庫県', 'ヒョウゴケン', '高砂市', 'タカサゴシ', '高砂町南浜町', 'タカサゴチョウミナミハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県高砂市高砂町東宮町', '28', '28216', '6760043', '兵庫県', 'ヒョウゴケン', '高砂市', 'タカサゴシ', '高砂町東宮町', 'タカサゴチョウヒガシミヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県高砂市高砂町南材木町', '28', '28216', '6760044', '兵庫県', 'ヒョウゴケン', '高砂市', 'タカサゴシ', '高砂町南材木町', 'タカサゴチョウミナミザイモクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県高砂市高砂町戎町', '28', '28216', '6760045', '兵庫県', 'ヒョウゴケン', '高砂市', 'タカサゴシ', '高砂町戎町', 'タカサゴチョウエビスマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県高砂市高砂町西宮町', '28', '28216', '6760046', '兵庫県', 'ヒョウゴケン', '高砂市', 'タカサゴシ', '高砂町西宮町', 'タカサゴチョウニシミヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県高砂市高砂町南本町', '28', '28216', '6760047', '兵庫県', 'ヒョウゴケン', '高砂市', 'タカサゴシ', '高砂町南本町', 'タカサゴチョウミナミホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県高砂市高砂町猟師町', '28', '28216', '6760048', '兵庫県', 'ヒョウゴケン', '高砂市', 'タカサゴシ', '高砂町猟師町', 'タカサゴチョウリョウシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県高砂市高砂町田町', '28', '28216', '6760049', '兵庫県', 'ヒョウゴケン', '高砂市', 'タカサゴシ', '高砂町田町', 'タカサゴチョウタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県高砂市高砂町横町', '28', '28216', '6760051', '兵庫県', 'ヒョウゴケン', '高砂市', 'タカサゴシ', '高砂町横町', 'タカサゴチョウヨコマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県高砂市高砂町南渡海町', '28', '28216', '6760052', '兵庫県', 'ヒョウゴケン', '高砂市', 'タカサゴシ', '高砂町南渡海町', 'タカサゴチョウミナミトカイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県高砂市高砂町魚町', '28', '28216', '6760053', '兵庫県', 'ヒョウゴケン', '高砂市', 'タカサゴシ', '高砂町魚町', 'タカサゴチョウウオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県高砂市高砂町狩網町', '28', '28216', '6760054', '兵庫県', 'ヒョウゴケン', '高砂市', 'タカサゴシ', '高砂町狩網町', 'タカサゴチョウカリアミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県高砂市高砂町釣船町', '28', '28216', '6760055', '兵庫県', 'ヒョウゴケン', '高砂市', 'タカサゴシ', '高砂町釣船町', 'タカサゴチョウツリフネマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県高砂市高砂町大工町', '28', '28216', '6760056', '兵庫県', 'ヒョウゴケン', '高砂市', 'タカサゴシ', '高砂町大工町', 'タカサゴチョウダイクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県高砂市高砂町農人町', '28', '28216', '6760061', '兵庫県', 'ヒョウゴケン', '高砂市', 'タカサゴシ', '高砂町農人町', 'タカサゴチョウノウニンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県高砂市高砂町北渡海町', '28', '28216', '6760062', '兵庫県', 'ヒョウゴケン', '高砂市', 'タカサゴシ', '高砂町北渡海町', 'タカサゴチョウキタトカイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県高砂市高砂町次郎助町', '28', '28216', '6760063', '兵庫県', 'ヒョウゴケン', '高砂市', 'タカサゴシ', '高砂町次郎助町', 'タカサゴチョウジロスケマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県高砂市高砂町北本町', '28', '28216', '6760064', '兵庫県', 'ヒョウゴケン', '高砂市', 'タカサゴシ', '高砂町北本町', 'タカサゴチョウキタホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県高砂市高砂町細工町', '28', '28216', '6760065', '兵庫県', 'ヒョウゴケン', '高砂市', 'タカサゴシ', '高砂町細工町', 'タカサゴチョウサイクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県高砂市高砂町鍵町', '28', '28216', '6760066', '兵庫県', 'ヒョウゴケン', '高砂市', 'タカサゴシ', '高砂町鍵町', 'タカサゴチョウカギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県高砂市高砂町東農人町', '28', '28216', '6760067', '兵庫県', 'ヒョウゴケン', '高砂市', 'タカサゴシ', '高砂町東農人町', 'タカサゴチョウヒガシノウニンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県高砂市高砂町鍛冶屋町', '28', '28216', '6760068', '兵庫県', 'ヒョウゴケン', '高砂市', 'タカサゴシ', '高砂町鍛冶屋町', 'タカサゴチョウカジヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県高砂市伊保東', '28', '28216', '6760071', '兵庫県', 'ヒョウゴケン', '高砂市', 'タカサゴシ', '伊保東', 'イホヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県高砂市伊保港町', '28', '28216', '6760072', '兵庫県', 'ヒョウゴケン', '高砂市', 'タカサゴシ', '伊保港町', 'イホミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県高砂市高須', '28', '28216', '6760073', '兵庫県', 'ヒョウゴケン', '高砂市', 'タカサゴシ', '高須', 'タカス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県高砂市梅井', '28', '28216', '6760074', '兵庫県', 'ヒョウゴケン', '高砂市', 'タカサゴシ', '梅井', 'ウメイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県高砂市伊保崎南', '28', '28216', '6760075', '兵庫県', 'ヒョウゴケン', '高砂市', 'タカサゴシ', '伊保崎南', 'イホザキミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県高砂市伊保崎', '28', '28216', '6760076', '兵庫県', 'ヒョウゴケン', '高砂市', 'タカサゴシ', '伊保崎', 'イホザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県高砂市松陽', '28', '28216', '6760077', '兵庫県', 'ヒョウゴケン', '高砂市', 'タカサゴシ', '松陽', 'ショウヨウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県高砂市伊保', '28', '28216', '6760078', '兵庫県', 'ヒョウゴケン', '高砂市', 'タカサゴシ', '伊保', 'イホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県高砂市伊保町中筋', '28', '28216', '6760081', '兵庫県', 'ヒョウゴケン', '高砂市', 'タカサゴシ', '伊保町中筋', 'イホチョウナカスジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県高砂市曽根町', '28', '28216', '6760082', '兵庫県', 'ヒョウゴケン', '高砂市', 'タカサゴシ', '曽根町', 'ソネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県高砂市米田町米田新', '28', '28216', '6760801', '兵庫県', 'ヒョウゴケン', '高砂市', 'タカサゴシ', '米田町米田新', 'ヨネダチョウヨネダシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県高砂市米田町古新', '28', '28216', '6760802', '兵庫県', 'ヒョウゴケン', '高砂市', 'タカサゴシ', '米田町古新', 'ヨネダチョウコシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県高砂市百合丘', '28', '28216', '6760803', '兵庫県', 'ヒョウゴケン', '高砂市', 'タカサゴシ', '百合丘', 'ユリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県高砂市美保里', '28', '28216', '6760804', '兵庫県', 'ヒョウゴケン', '高砂市', 'タカサゴシ', '美保里', 'ミホノサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県高砂市米田町米田', '28', '28216', '6760805', '兵庫県', 'ヒョウゴケン', '高砂市', 'タカサゴシ', '米田町米田', 'ヨネダチョウヨネダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県高砂市米田町塩市', '28', '28216', '6760806', '兵庫県', 'ヒョウゴケン', '高砂市', 'タカサゴシ', '米田町塩市', 'ヨネダチョウシオイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県高砂市米田町島', '28', '28216', '6760807', '兵庫県', 'ヒョウゴケン', '高砂市', 'タカサゴシ', '米田町島', 'ヨネダチョウシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県高砂市神爪', '28', '28216', '6760808', '兵庫県', 'ヒョウゴケン', '高砂市', 'タカサゴシ', '神爪', 'カヅメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県高砂市米田団地', '28', '28216', '6760809', '兵庫県', 'ヒョウゴケン', '高砂市', 'タカサゴシ', '米田団地', 'ヨネダダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県高砂市竜山', '28', '28216', '6760811', '兵庫県', 'ヒョウゴケン', '高砂市', 'タカサゴシ', '竜山', 'タツヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県高砂市中筋', '28', '28216', '6760812', '兵庫県', 'ヒョウゴケン', '高砂市', 'タカサゴシ', '中筋', 'ナカスジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県高砂市時光寺町', '28', '28216', '6760813', '兵庫県', 'ヒョウゴケン', '高砂市', 'タカサゴシ', '時光寺町', 'ジコウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県高砂市春日野町', '28', '28216', '6760814', '兵庫県', 'ヒョウゴケン', '高砂市', 'タカサゴシ', '春日野町', 'カスガノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県高砂市阿弥陀', '28', '28216', '6760815', '兵庫県', 'ヒョウゴケン', '高砂市', 'タカサゴシ', '阿弥陀', 'アミダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県高砂市金ケ田町', '28', '28216', '6760816', '兵庫県', 'ヒョウゴケン', '高砂市', 'タカサゴシ', '金ケ田町', 'カナケダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県高砂市阿弥陀町長尾', '28', '28216', '6760821', '兵庫県', 'ヒョウゴケン', '高砂市', 'タカサゴシ', '阿弥陀町長尾', 'アミダチョウナガオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県高砂市阿弥陀町魚橋', '28', '28216', '6760822', '兵庫県', 'ヒョウゴケン', '高砂市', 'タカサゴシ', '阿弥陀町魚橋', 'アミダチョウウオハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県高砂市阿弥陀町生石', '28', '28216', '6760823', '兵庫県', 'ヒョウゴケン', '高砂市', 'タカサゴシ', '阿弥陀町生石', 'アミダチョウオオシコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県高砂市阿弥陀町南池', '28', '28216', '6760824', '兵庫県', 'ヒョウゴケン', '高砂市', 'タカサゴシ', '阿弥陀町南池', 'アミダチョウミナミイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県高砂市阿弥陀町北池', '28', '28216', '6760825', '兵庫県', 'ヒョウゴケン', '高砂市', 'タカサゴシ', '阿弥陀町北池', 'アミダチョウキタイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県高砂市阿弥陀町北山', '28', '28216', '6760826', '兵庫県', 'ヒョウゴケン', '高砂市', 'タカサゴシ', '阿弥陀町北山', 'アミダチョウキタヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県高砂市阿弥陀町阿弥陀', '28', '28216', '6760827', '兵庫県', 'ヒョウゴケン', '高砂市', 'タカサゴシ', '阿弥陀町阿弥陀', 'アミダチョウアミダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県高砂市阿弥陀町地徳', '28', '28216', '6760828', '兵庫県', 'ヒョウゴケン', '高砂市', 'タカサゴシ', '阿弥陀町地徳', 'アミダチョウジトク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西脇市', '28', '28213', '6770000', '兵庫県', 'ヒョウゴケン', '西脇市', 'ニシワキシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('82311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西脇市大木町', '28', '28213', '6770001', '兵庫県', 'ヒョウゴケン', '西脇市', 'ニシワキシ', '大木町', 'オオギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西脇市前島町', '28', '28213', '6770002', '兵庫県', 'ヒョウゴケン', '西脇市', 'ニシワキシ', '前島町', 'マエジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西脇市西田町', '28', '28213', '6770003', '兵庫県', 'ヒョウゴケン', '西脇市', 'ニシワキシ', '西田町', 'ニシダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西脇市市原町', '28', '28213', '6770004', '兵庫県', 'ヒョウゴケン', '西脇市', 'ニシワキシ', '市原町', 'イチハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西脇市野中町', '28', '28213', '6770005', '兵庫県', 'ヒョウゴケン', '西脇市', 'ニシワキシ', '野中町', 'ノナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西脇市羽安町', '28', '28213', '6770006', '兵庫県', 'ヒョウゴケン', '西脇市', 'ニシワキシ', '羽安町', 'ハヤスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西脇市富吉上町', '28', '28213', '6770011', '兵庫県', 'ヒョウゴケン', '西脇市', 'ニシワキシ', '富吉上町', 'トミヨシカミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西脇市富吉南町', '28', '28213', '6770012', '兵庫県', 'ヒョウゴケン', '西脇市', 'ニシワキシ', '富吉南町', 'トミヨシミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西脇市日野町', '28', '28213', '6770013', '兵庫県', 'ヒョウゴケン', '西脇市', 'ニシワキシ', '日野町', 'ヒノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西脇市郷瀬町', '28', '28213', '6770014', '兵庫県', 'ヒョウゴケン', '西脇市', 'ニシワキシ', '郷瀬町', 'ゴノセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西脇市西脇', '28', '28213', '6770015', '兵庫県', 'ヒョウゴケン', '西脇市', 'ニシワキシ', '西脇', 'ニシワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西脇市高田井町', '28', '28213', '6770016', '兵庫県', 'ヒョウゴケン', '西脇市', 'ニシワキシ', '高田井町', 'コウダイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西脇市小坂町', '28', '28213', '6770017', '兵庫県', 'ヒョウゴケン', '西脇市', 'ニシワキシ', '小坂町', 'コサカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西脇市富田町', '28', '28213', '6770018', '兵庫県', 'ヒョウゴケン', '西脇市', 'ニシワキシ', '富田町', 'トミタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西脇市蒲江', '28', '28213', '6770021', '兵庫県', 'ヒョウゴケン', '西脇市', 'ニシワキシ', '蒲江', 'コモエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西脇市寺内', '28', '28213', '6770022', '兵庫県', 'ヒョウゴケン', '西脇市', 'ニシワキシ', '寺内', 'テラウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西脇市西嶋', '28', '28213', '6770023', '兵庫県', 'ヒョウゴケン', '西脇市', 'ニシワキシ', '西嶋', 'ニシジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西脇市嶋', '28', '28213', '6770024', '兵庫県', 'ヒョウゴケン', '西脇市', 'ニシワキシ', '嶋', 'シマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西脇市大野', '28', '28213', '6770025', '兵庫県', 'ヒョウゴケン', '西脇市', 'ニシワキシ', '大野', 'オオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西脇市坂本', '28', '28213', '6770026', '兵庫県', 'ヒョウゴケン', '西脇市', 'ニシワキシ', '坂本', 'サカモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西脇市住吉町', '28', '28213', '6770031', '兵庫県', 'ヒョウゴケン', '西脇市', 'ニシワキシ', '住吉町', 'スミヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西脇市中畑町', '28', '28213', '6770032', '兵庫県', 'ヒョウゴケン', '西脇市', 'ニシワキシ', '中畑町', 'ナカハタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西脇市鹿野町', '28', '28213', '6770033', '兵庫県', 'ヒョウゴケン', '西脇市', 'ニシワキシ', '鹿野町', 'シカノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西脇市塚口町', '28', '28213', '6770034', '兵庫県', 'ヒョウゴケン', '西脇市', 'ニシワキシ', '塚口町', 'ツカグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西脇市上戸田', '28', '28213', '6770035', '兵庫県', 'ヒョウゴケン', '西脇市', 'ニシワキシ', '上戸田', 'カミトダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西脇市津万', '28', '28213', '6770036', '兵庫県', 'ヒョウゴケン', '西脇市', 'ニシワキシ', '津万', 'ツマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西脇市比延町', '28', '28213', '6770037', '兵庫県', 'ヒョウゴケン', '西脇市', 'ニシワキシ', '比延町', 'ヒエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西脇市大垣内', '28', '28213', '6770038', '兵庫県', 'ヒョウゴケン', '西脇市', 'ニシワキシ', '大垣内', 'オオガチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西脇市上比延町', '28', '28213', '6770039', '兵庫県', 'ヒョウゴケン', '西脇市', 'ニシワキシ', '上比延町', 'カミヒエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西脇市高嶋町', '28', '28213', '6770041', '兵庫県', 'ヒョウゴケン', '西脇市', 'ニシワキシ', '高嶋町', 'タカシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西脇市堀町', '28', '28213', '6770042', '兵庫県', 'ヒョウゴケン', '西脇市', 'ニシワキシ', '堀町', 'ホリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西脇市下戸田', '28', '28213', '6770043', '兵庫県', 'ヒョウゴケン', '西脇市', 'ニシワキシ', '下戸田', 'シモトダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西脇市上野', '28', '28213', '6770044', '兵庫県', 'ヒョウゴケン', '西脇市', 'ニシワキシ', '上野', 'ウエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西脇市谷町', '28', '28213', '6770051', '兵庫県', 'ヒョウゴケン', '西脇市', 'ニシワキシ', '谷町', 'タニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西脇市和田町', '28', '28213', '6770052', '兵庫県', 'ヒョウゴケン', '西脇市', 'ニシワキシ', '和田町', 'ワダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西脇市和布町', '28', '28213', '6770053', '兵庫県', 'ヒョウゴケン', '西脇市', 'ニシワキシ', '和布町', 'ワブチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西脇市野村町', '28', '28213', '6770054', '兵庫県', 'ヒョウゴケン', '西脇市', 'ニシワキシ', '野村町', 'ノムラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西脇市高松町', '28', '28213', '6770055', '兵庫県', 'ヒョウゴケン', '西脇市', 'ニシワキシ', '高松町', 'タカマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西脇市板波町', '28', '28213', '6770056', '兵庫県', 'ヒョウゴケン', '西脇市', 'ニシワキシ', '板波町', 'イタバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西脇市野村町茜が丘', '28', '28213', '6770057', '兵庫県', 'ヒョウゴケン', '西脇市', 'ニシワキシ', '野村町茜が丘', 'ノムラチョウアカネガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西脇市合山町', '28', '28213', '6770061', '兵庫県', 'ヒョウゴケン', '西脇市', 'ニシワキシ', '合山町', 'アヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西脇市出会町', '28', '28213', '6770062', '兵庫県', 'ヒョウゴケン', '西脇市', 'ニシワキシ', '出会町', 'デアイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西脇市平野町', '28', '28213', '6770063', '兵庫県', 'ヒョウゴケン', '西脇市', 'ニシワキシ', '平野町', 'ヒラノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西脇市八坂町', '28', '28213', '6770064', '兵庫県', 'ヒョウゴケン', '西脇市', 'ニシワキシ', '八坂町', 'ヤサカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西脇市岡崎町', '28', '28213', '6770065', '兵庫県', 'ヒョウゴケン', '西脇市', 'ニシワキシ', '岡崎町', 'オカザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西脇市水尾町', '28', '28213', '6770066', '兵庫県', 'ヒョウゴケン', '西脇市', 'ニシワキシ', '水尾町', 'ミズオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西脇市明楽寺町', '28', '28213', '6770067', '兵庫県', 'ヒョウゴケン', '西脇市', 'ニシワキシ', '明楽寺町', 'ミョウラクジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西脇市落方町', '28', '28213', '6770068', '兵庫県', 'ヒョウゴケン', '西脇市', 'ニシワキシ', '落方町', 'オチカタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西脇市上王子町', '28', '28213', '6770069', '兵庫県', 'ヒョウゴケン', '西脇市', 'ニシワキシ', '上王子町', 'カミオウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県多可郡多可町八千代区大屋', '28', '28365', '6770101', '兵庫県', 'ヒョウゴケン', '多可郡多可町', 'タカグンタカチョウ', '八千代区大屋', 'ヤチヨクオオヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県多可郡多可町八千代区坂本', '28', '28365', '6770102', '兵庫県', 'ヒョウゴケン', '多可郡多可町', 'タカグンタカチョウ', '八千代区坂本', 'ヤチヨクサカモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県多可郡多可町八千代区中村', '28', '28365', '6770103', '兵庫県', 'ヒョウゴケン', '多可郡多可町', 'タカグンタカチョウ', '八千代区中村', 'ヤチヨクナカムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県多可郡多可町八千代区横屋', '28', '28365', '6770104', '兵庫県', 'ヒョウゴケン', '多可郡多可町', 'タカグンタカチョウ', '八千代区横屋', 'ヤチヨクヨコヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県多可郡多可町八千代区下村', '28', '28365', '6770105', '兵庫県', 'ヒョウゴケン', '多可郡多可町', 'タカグンタカチョウ', '八千代区下村', 'ヤチヨクシモムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県多可郡多可町八千代区門田', '28', '28365', '6770111', '兵庫県', 'ヒョウゴケン', '多可郡多可町', 'タカグンタカチョウ', '八千代区門田', 'ヤチヨクカドタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県多可郡多可町八千代区赤坂', '28', '28365', '6770112', '兵庫県', 'ヒョウゴケン', '多可郡多可町', 'タカグンタカチョウ', '八千代区赤坂', 'ヤチヨクアカサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県多可郡多可町八千代区俵田', '28', '28365', '6770113', '兵庫県', 'ヒョウゴケン', '多可郡多可町', 'タカグンタカチョウ', '八千代区俵田', 'ヤチヨクタワラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県多可郡多可町八千代区仕出原', '28', '28365', '6770114', '兵庫県', 'ヒョウゴケン', '多可郡多可町', 'タカグンタカチョウ', '八千代区仕出原', 'ヤチヨクシデハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県多可郡多可町八千代区中野間', '28', '28365', '6770121', '兵庫県', 'ヒョウゴケン', '多可郡多可町', 'タカグンタカチョウ', '八千代区中野間', 'ヤチヨクナカノマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県多可郡多可町八千代区下野間', '28', '28365', '6770122', '兵庫県', 'ヒョウゴケン', '多可郡多可町', 'タカグンタカチョウ', '八千代区下野間', 'ヤチヨクシモノマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県多可郡多可町八千代区下三原', '28', '28365', '6770131', '兵庫県', 'ヒョウゴケン', '多可郡多可町', 'タカグンタカチョウ', '八千代区下三原', 'ヤチヨクシモミハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県多可郡多可町八千代区大和', '28', '28365', '6770132', '兵庫県', 'ヒョウゴケン', '多可郡多可町', 'タカグンタカチョウ', '八千代区大和', 'ヤチヨクヤマト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県相生市', '28', '28208', '6780000', '兵庫県', 'ヒョウゴケン', '相生市', 'アイオイシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('82376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県相生市山手', '28', '28208', '6780001', '兵庫県', 'ヒョウゴケン', '相生市', 'アイオイシ', '山手', 'ヤマテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県相生市汐見台', '28', '28208', '6780002', '兵庫県', 'ヒョウゴケン', '相生市', 'アイオイシ', '汐見台', 'シオミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県相生市陸', '28', '28208', '6780003', '兵庫県', 'ヒョウゴケン', '相生市', 'アイオイシ', '陸', 'クガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県相生市池之内', '28', '28208', '6780004', '兵庫県', 'ヒョウゴケン', '相生市', 'アイオイシ', '池之内', 'イケノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県相生市大石町', '28', '28208', '6780005', '兵庫県', 'ヒョウゴケン', '相生市', 'アイオイシ', '大石町', 'オオイシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県相生市本郷町', '28', '28208', '6780006', '兵庫県', 'ヒョウゴケン', '相生市', 'アイオイシ', '本郷町', 'ホンゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県相生市陸本町', '28', '28208', '6780007', '兵庫県', 'ヒョウゴケン', '相生市', 'アイオイシ', '陸本町', 'クガホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県相生市栄町', '28', '28208', '6780008', '兵庫県', 'ヒョウゴケン', '相生市', 'アイオイシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県相生市那波野', '28', '28208', '6780011', '兵庫県', 'ヒョウゴケン', '相生市', 'アイオイシ', '那波野', 'ナバノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県相生市古池', '28', '28208', '6780012', '兵庫県', 'ヒョウゴケン', '相生市', 'アイオイシ', '古池', 'フルイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県相生市赤坂', '28', '28208', '6780021', '兵庫県', 'ヒョウゴケン', '相生市', 'アイオイシ', '赤坂', 'アカサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県相生市垣内町', '28', '28208', '6780022', '兵庫県', 'ヒョウゴケン', '相生市', 'アイオイシ', '垣内町', 'カキウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県相生市向陽台', '28', '28208', '6780023', '兵庫県', 'ヒョウゴケン', '相生市', 'アイオイシ', '向陽台', 'コウヨウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県相生市双葉', '28', '28208', '6780024', '兵庫県', 'ヒョウゴケン', '相生市', 'アイオイシ', '双葉', 'フタバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県相生市古池本町', '28', '28208', '6780025', '兵庫県', 'ヒョウゴケン', '相生市', 'アイオイシ', '古池本町', 'フルイケホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県相生市旭', '28', '28208', '6780031', '兵庫県', 'ヒョウゴケン', '相生市', 'アイオイシ', '旭', 'アサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県相生市相生', '28', '28208', '6780041', '兵庫県', 'ヒョウゴケン', '相生市', 'アイオイシ', '相生', 'アイオイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県相生市川原町', '28', '28208', '6780042', '兵庫県', 'ヒョウゴケン', '相生市', 'アイオイシ', '川原町', 'カワハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県相生市大谷町', '28', '28208', '6780043', '兵庫県', 'ヒョウゴケン', '相生市', 'アイオイシ', '大谷町', 'オオタニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県相生市野瀬', '28', '28208', '6780044', '兵庫県', 'ヒョウゴケン', '相生市', 'アイオイシ', '野瀬', 'ノセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県相生市那波大浜町', '28', '28208', '6780051', '兵庫県', 'ヒョウゴケン', '相生市', 'アイオイシ', '那波大浜町', 'ナバオオハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県相生市大島町', '28', '28208', '6780052', '兵庫県', 'ヒョウゴケン', '相生市', 'アイオイシ', '大島町', 'オオシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県相生市那波南本町', '28', '28208', '6780053', '兵庫県', 'ヒョウゴケン', '相生市', 'アイオイシ', '那波南本町', 'ナバミナミホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県相生市那波西本町', '28', '28208', '6780054', '兵庫県', 'ヒョウゴケン', '相生市', 'アイオイシ', '那波西本町', 'ナバニシホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県相生市那波本町', '28', '28208', '6780055', '兵庫県', 'ヒョウゴケン', '相生市', 'アイオイシ', '那波本町', 'ナバホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県相生市那波東本町', '28', '28208', '6780056', '兵庫県', 'ヒョウゴケン', '相生市', 'アイオイシ', '那波東本町', 'ナバヒガシホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県相生市桜ケ丘町', '28', '28208', '6780061', '兵庫県', 'ヒョウゴケン', '相生市', 'アイオイシ', '桜ケ丘町', 'サクラガオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県相生市千尋町', '28', '28208', '6780062', '兵庫県', 'ヒョウゴケン', '相生市', 'アイオイシ', '千尋町', 'チヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県相生市佐方', '28', '28208', '6780063', '兵庫県', 'ヒョウゴケン', '相生市', 'アイオイシ', '佐方', 'サガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県相生市青葉台', '28', '28208', '6780064', '兵庫県', 'ヒョウゴケン', '相生市', 'アイオイシ', '青葉台', 'アオバダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県相生市西谷町', '28', '28208', '6780065', '兵庫県', 'ヒョウゴケン', '相生市', 'アイオイシ', '西谷町', 'ニシタニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県相生市山崎町', '28', '28208', '6780066', '兵庫県', 'ヒョウゴケン', '相生市', 'アイオイシ', '山崎町', 'ヤマサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県相生市那波', '28', '28208', '6780067', '兵庫県', 'ヒョウゴケン', '相生市', 'アイオイシ', '那波', 'ナバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県相生市緑ケ丘', '28', '28208', '6780071', '兵庫県', 'ヒョウゴケン', '相生市', 'アイオイシ', '緑ケ丘', 'ミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県相生市竜泉町', '28', '28208', '6780072', '兵庫県', 'ヒョウゴケン', '相生市', 'アイオイシ', '竜泉町', 'リュウセンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県相生市菅原町', '28', '28208', '6780073', '兵庫県', 'ヒョウゴケン', '相生市', 'アイオイシ', '菅原町', 'スガハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県相生市ひかりが丘', '28', '28208', '6780074', '兵庫県', 'ヒョウゴケン', '相生市', 'アイオイシ', 'ひかりが丘', 'ヒカリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県相生市若狭野町雨内', '28', '28208', '6780081', '兵庫県', 'ヒョウゴケン', '相生市', 'アイオイシ', '若狭野町雨内', 'ワカサノチョウアマウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県相生市若狭野町入野', '28', '28208', '6780081', '兵庫県', 'ヒョウゴケン', '相生市', 'アイオイシ', '若狭野町入野', 'ワカサノチョウイリノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県相生市若狭野町上松', '28', '28208', '6780081', '兵庫県', 'ヒョウゴケン', '相生市', 'アイオイシ', '若狭野町上松', 'ワカサノチョウウエマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県相生市若狭野町西後明', '28', '28208', '6780081', '兵庫県', 'ヒョウゴケン', '相生市', 'アイオイシ', '若狭野町西後明', 'ワカサノチョウニシゴミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県相生市若狭野町東後明', '28', '28208', '6780081', '兵庫県', 'ヒョウゴケン', '相生市', 'アイオイシ', '若狭野町東後明', 'ワカサノチョウヒガシゴミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県相生市若狭野町若狭野', '28', '28208', '6780081', '兵庫県', 'ヒョウゴケン', '相生市', 'アイオイシ', '若狭野町若狭野', 'ワカサノチョウワカサノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県相生市若狭野町下土井', '28', '28208', '6780082', '兵庫県', 'ヒョウゴケン', '相生市', 'アイオイシ', '若狭野町下土井', 'ワカサノチョウシモドイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県相生市若狭野町出', '28', '28208', '6780082', '兵庫県', 'ヒョウゴケン', '相生市', 'アイオイシ', '若狭野町出', 'ワカサノチョウデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県相生市若狭野町寺田', '28', '28208', '6780082', '兵庫県', 'ヒョウゴケン', '相生市', 'アイオイシ', '若狭野町寺田', 'ワカサノチョウテラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県相生市若狭野町野々', '28', '28208', '6780082', '兵庫県', 'ヒョウゴケン', '相生市', 'アイオイシ', '若狭野町野々', 'ワカサノチョウノノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県相生市若狭野町八洞', '28', '28208', '6780082', '兵庫県', 'ヒョウゴケン', '相生市', 'アイオイシ', '若狭野町八洞', 'ワカサノチョウハットウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県相生市若狭野町福井', '28', '28208', '6780082', '兵庫県', 'ヒョウゴケン', '相生市', 'アイオイシ', '若狭野町福井', 'ワカサノチョウフクイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県相生市矢野町瓜生', '28', '28208', '6780091', '兵庫県', 'ヒョウゴケン', '相生市', 'アイオイシ', '矢野町瓜生', 'ヤノチョウウリュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県相生市矢野町金坂', '28', '28208', '6780091', '兵庫県', 'ヒョウゴケン', '相生市', 'アイオイシ', '矢野町金坂', 'ヤノチョウカネサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県相生市矢野町釜出', '28', '28208', '6780091', '兵庫県', 'ヒョウゴケン', '相生市', 'アイオイシ', '矢野町釜出', 'ヤノチョウカマデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県相生市矢野町上', '28', '28208', '6780091', '兵庫県', 'ヒョウゴケン', '相生市', 'アイオイシ', '矢野町上', 'ヤノチョウカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県相生市矢野町榊', '28', '28208', '6780091', '兵庫県', 'ヒョウゴケン', '相生市', 'アイオイシ', '矢野町榊', 'ヤノチョウサカキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県相生市矢野町菅谷', '28', '28208', '6780091', '兵庫県', 'ヒョウゴケン', '相生市', 'アイオイシ', '矢野町菅谷', 'ヤノチョウスガタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県相生市矢野町中野', '28', '28208', '6780091', '兵庫県', 'ヒョウゴケン', '相生市', 'アイオイシ', '矢野町中野', 'ヤノチョウナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県相生市矢野町能下', '28', '28208', '6780091', '兵庫県', 'ヒョウゴケン', '相生市', 'アイオイシ', '矢野町能下', 'ヤノチョウノウゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県相生市矢野町二木', '28', '28208', '6780091', '兵庫県', 'ヒョウゴケン', '相生市', 'アイオイシ', '矢野町二木', 'ヤノチョウフタツギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県相生市矢野町真広', '28', '28208', '6780091', '兵庫県', 'ヒョウゴケン', '相生市', 'アイオイシ', '矢野町真広', 'ヤノチョウマヒロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県相生市矢野町森', '28', '28208', '6780091', '兵庫県', 'ヒョウゴケン', '相生市', 'アイオイシ', '矢野町森', 'ヤノチョウモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県相生市矢野町小河', '28', '28208', '6780092', '兵庫県', 'ヒョウゴケン', '相生市', 'アイオイシ', '矢野町小河', 'ヤノチョウオウゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県相生市矢野町上土井', '28', '28208', '6780092', '兵庫県', 'ヒョウゴケン', '相生市', 'アイオイシ', '矢野町上土井', 'ヤノチョウカミドイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県相生市矢野町下田', '28', '28208', '6780092', '兵庫県', 'ヒョウゴケン', '相生市', 'アイオイシ', '矢野町下田', 'ヤノチョウシモダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県相生市相生', '28', '28208', '6780141', '兵庫県', 'ヒョウゴケン', '相生市', 'アイオイシ', '相生', 'アイオイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂市中山', '28', '28212', '6780161', '兵庫県', 'ヒョウゴケン', '赤穂市', 'アコウシ', '中山', 'ナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂市周世', '28', '28212', '6780162', '兵庫県', 'ヒョウゴケン', '赤穂市', 'アコウシ', '周世', 'スセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂市高雄', '28', '28212', '6780163', '兵庫県', 'ヒョウゴケン', '赤穂市', 'アコウシ', '高雄', 'タカオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂市目坂', '28', '28212', '6780164', '兵庫県', 'ヒョウゴケン', '赤穂市', 'アコウシ', '目坂', 'メサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂市木津', '28', '28212', '6780165', '兵庫県', 'ヒョウゴケン', '赤穂市', 'アコウシ', '木津', 'キヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂市真殿', '28', '28212', '6780166', '兵庫県', 'ヒョウゴケン', '赤穂市', 'アコウシ', '真殿', 'マトノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂市高野', '28', '28212', '6780171', '兵庫県', 'ヒョウゴケン', '赤穂市', 'アコウシ', '高野', 'コウノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂市坂越', '28', '28212', '6780172', '兵庫県', 'ヒョウゴケン', '赤穂市', 'アコウシ', '坂越', 'サコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂市浜市', '28', '28212', '6780173', '兵庫県', 'ヒョウゴケン', '赤穂市', 'アコウシ', '浜市', 'ハマイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂市砂子', '28', '28212', '6780174', '兵庫県', 'ヒョウゴケン', '赤穂市', 'アコウシ', '砂子', 'マナゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂市北野中', '28', '28212', '6780175', '兵庫県', 'ヒョウゴケン', '赤穂市', 'アコウシ', '北野中', 'キタノナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂市南野中', '28', '28212', '6780176', '兵庫県', 'ヒョウゴケン', '赤穂市', 'アコウシ', '南野中', 'ミナミノナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂市', '28', '28212', '6780200', '兵庫県', 'ヒョウゴケン', '赤穂市', 'アコウシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('82456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂市塩屋', '28', '28212', '6780201', '兵庫県', 'ヒョウゴケン', '赤穂市', 'アコウシ', '塩屋', 'シオヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂市山手町', '28', '28212', '6780202', '兵庫県', 'ヒョウゴケン', '赤穂市', 'アコウシ', '山手町', 'ヤマテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂市元町', '28', '28212', '6780203', '兵庫県', 'ヒョウゴケン', '赤穂市', 'アコウシ', '元町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂市寿町', '28', '28212', '6780204', '兵庫県', 'ヒョウゴケン', '赤穂市', 'アコウシ', '寿町', 'コトブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂市大町', '28', '28212', '6780205', '兵庫県', 'ヒョウゴケン', '赤穂市', 'アコウシ', '大町', 'オオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂市宮前町', '28', '28212', '6780206', '兵庫県', 'ヒョウゴケン', '赤穂市', 'アコウシ', '宮前町', 'ミヤマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂市西浜北町', '28', '28212', '6780207', '兵庫県', 'ヒョウゴケン', '赤穂市', 'アコウシ', '西浜北町', 'ニシハマキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂市西浜町', '28', '28212', '6780208', '兵庫県', 'ヒョウゴケン', '赤穂市', 'アコウシ', '西浜町', 'ニシハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂市南宮町', '28', '28212', '6780211', '兵庫県', 'ヒョウゴケン', '赤穂市', 'アコウシ', '南宮町', 'ナングウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂市清水町', '28', '28212', '6780212', '兵庫県', 'ヒョウゴケン', '赤穂市', 'アコウシ', '清水町', 'シミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂市元塩町', '28', '28212', '6780213', '兵庫県', 'ヒョウゴケン', '赤穂市', 'アコウシ', '元塩町', 'モトシオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂市朝日町', '28', '28212', '6780214', '兵庫県', 'ヒョウゴケン', '赤穂市', 'アコウシ', '朝日町', 'アサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂市御崎', '28', '28212', '6780215', '兵庫県', 'ヒョウゴケン', '赤穂市', 'アコウシ', '御崎', 'ミサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂市正保橋町', '28', '28212', '6780216', '兵庫県', 'ヒョウゴケン', '赤穂市', 'アコウシ', '正保橋町', 'ショウホバシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂市本水尾町', '28', '28212', '6780217', '兵庫県', 'ヒョウゴケン', '赤穂市', 'アコウシ', '本水尾町', 'ホンミオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂市尾崎', '28', '28212', '6780221', '兵庫県', 'ヒョウゴケン', '赤穂市', 'アコウシ', '尾崎', 'オサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂市東浜町', '28', '28212', '6780222', '兵庫県', 'ヒョウゴケン', '赤穂市', 'アコウシ', '東浜町', 'ヒガシハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂市元禄橋町', '28', '28212', '6780223', '兵庫県', 'ヒョウゴケン', '赤穂市', 'アコウシ', '元禄橋町', 'ゲンロクバシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂市元沖町', '28', '28212', '6780224', '兵庫県', 'ヒョウゴケン', '赤穂市', 'アコウシ', '元沖町', 'モトオキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂市海浜町', '28', '28212', '6780225', '兵庫県', 'ヒョウゴケン', '赤穂市', 'アコウシ', '海浜町', 'カイヒンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂市さつき町', '28', '28212', '6780226', '兵庫県', 'ヒョウゴケン', '赤穂市', 'アコウシ', 'さつき町', 'サツキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂市中浜町', '28', '28212', '6780227', '兵庫県', 'ヒョウゴケン', '赤穂市', 'アコウシ', '中浜町', 'ナカハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂市松原町', '28', '28212', '6780228', '兵庫県', 'ヒョウゴケン', '赤穂市', 'アコウシ', '松原町', 'マツバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂市大橋町', '28', '28212', '6780229', '兵庫県', 'ヒョウゴケン', '赤穂市', 'アコウシ', '大橋町', 'オオハシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂市細野町', '28', '28212', '6780231', '兵庫県', 'ヒョウゴケン', '赤穂市', 'アコウシ', '細野町', 'ホソノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂市中広', '28', '28212', '6780232', '兵庫県', 'ヒョウゴケン', '赤穂市', 'アコウシ', '中広', 'ナカヒロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂市加里屋中洲', '28', '28212', '6780233', '兵庫県', 'ヒョウゴケン', '赤穂市', 'アコウシ', '加里屋中洲', 'カリヤナカス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂市加里屋南', '28', '28212', '6780234', '兵庫県', 'ヒョウゴケン', '赤穂市', 'アコウシ', '加里屋南', 'カリヤミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂市上仮屋', '28', '28212', '6780235', '兵庫県', 'ヒョウゴケン', '赤穂市', 'アコウシ', '上仮屋', 'カミカリヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂市上仮屋南', '28', '28212', '6780236', '兵庫県', 'ヒョウゴケン', '赤穂市', 'アコウシ', '上仮屋南', 'カミカリヤミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂市上仮屋北', '28', '28212', '6780237', '兵庫県', 'ヒョウゴケン', '赤穂市', 'アコウシ', '上仮屋北', 'カミカリヤキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂市農神町', '28', '28212', '6780238', '兵庫県', 'ヒョウゴケン', '赤穂市', 'アコウシ', '農神町', 'ノウジンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂市加里屋', '28', '28212', '6780239', '兵庫県', 'ヒョウゴケン', '赤穂市', 'アコウシ', '加里屋', 'カリヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂市惣門町', '28', '28212', '6780241', '兵庫県', 'ヒョウゴケン', '赤穂市', 'アコウシ', '惣門町', 'ソウモンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂市長池町', '28', '28212', '6780242', '兵庫県', 'ヒョウゴケン', '赤穂市', 'アコウシ', '長池町', 'ナガイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂市若草町', '28', '28212', '6780243', '兵庫県', 'ヒョウゴケン', '赤穂市', 'アコウシ', '若草町', 'ワカクサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂市城西町', '28', '28212', '6780244', '兵庫県', 'ヒョウゴケン', '赤穂市', 'アコウシ', '城西町', 'ジョウサイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂市三樋町', '28', '28212', '6780245', '兵庫県', 'ヒョウゴケン', '赤穂市', 'アコウシ', '三樋町', 'ミツヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂市六百目町', '28', '28212', '6780246', '兵庫県', 'ヒョウゴケン', '赤穂市', 'アコウシ', '六百目町', 'ロッピャクメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂市平成町', '28', '28212', '6780247', '兵庫県', 'ヒョウゴケン', '赤穂市', 'アコウシ', '平成町', 'ヘイセイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂市板屋町', '28', '28212', '6780248', '兵庫県', 'ヒョウゴケン', '赤穂市', 'アコウシ', '板屋町', 'イタヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂市片浜町', '28', '28212', '6780249', '兵庫県', 'ヒョウゴケン', '赤穂市', 'アコウシ', '片浜町', 'カタハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂市磯浜町', '28', '28212', '6780250', '兵庫県', 'ヒョウゴケン', '赤穂市', 'アコウシ', '磯浜町', 'イソハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂市西有年湯の内', '28', '28212', '6780251', '兵庫県', 'ヒョウゴケン', '赤穂市', 'アコウシ', '西有年', 'ニシウネ', null, null, '湯の内', 'ユノウチ');
INSERT INTO `ms_addresses` VALUES ('82500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂市大津', '28', '28212', '6780252', '兵庫県', 'ヒョウゴケン', '赤穂市', 'アコウシ', '大津', 'オオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂市木生谷', '28', '28212', '6780253', '兵庫県', 'ヒョウゴケン', '赤穂市', 'アコウシ', '木生谷', 'キュウノタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂市折方', '28', '28212', '6780254', '兵庫県', 'ヒョウゴケン', '赤穂市', 'アコウシ', '折方', 'オリカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂市新田', '28', '28212', '6780255', '兵庫県', 'ヒョウゴケン', '赤穂市', 'アコウシ', '新田', 'シンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂市鷆和', '28', '28212', '6780256', '兵庫県', 'ヒョウゴケン', '赤穂市', 'アコウシ', '鷆和', 'テンワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂市福浦', '28', '28212', '6780257', '兵庫県', 'ヒョウゴケン', '赤穂市', 'アコウシ', '福浦', 'フクウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂市古浜町', '28', '28212', '6780258', '兵庫県', 'ヒョウゴケン', '赤穂市', 'アコウシ', '古浜町', 'コハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂市黒崎町', '28', '28212', '6780259', '兵庫県', 'ヒョウゴケン', '赤穂市', 'アコウシ', '黒崎町', 'クロサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂市有年楢原', '28', '28212', '6781181', '兵庫県', 'ヒョウゴケン', '赤穂市', 'アコウシ', '有年楢原', 'ウネナラバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂市有年原', '28', '28212', '6781182', '兵庫県', 'ヒョウゴケン', '赤穂市', 'アコウシ', '有年原', 'ウネハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂市有年牟礼', '28', '28212', '6781183', '兵庫県', 'ヒョウゴケン', '赤穂市', 'アコウシ', '有年牟礼', 'ウネムレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂市有年横尾', '28', '28212', '6781184', '兵庫県', 'ヒョウゴケン', '赤穂市', 'アコウシ', '有年横尾', 'ウネヨコオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂市東有年', '28', '28212', '6781185', '兵庫県', 'ヒョウゴケン', '赤穂市', 'アコウシ', '東有年', 'ヒガシウネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂市西有年', '28', '28212', '6781186', '兵庫県', 'ヒョウゴケン', '赤穂市', 'アコウシ', '西有年', 'ニシウネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂郡上郡町', '28', '28481', '6781200', '兵庫県', 'ヒョウゴケン', '赤穂郡上郡町', 'アコウグンカミゴオリチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('82518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂郡上郡町金出地', '28', '28481', '6781201', '兵庫県', 'ヒョウゴケン', '赤穂郡上郡町', 'アコウグンカミゴオリチョウ', '金出地', 'カナジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂郡上郡町野桑', '28', '28481', '6781202', '兵庫県', 'ヒョウゴケン', '赤穂郡上郡町', 'アコウグンカミゴオリチョウ', '野桑', 'ノクワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂郡上郡町尾長谷', '28', '28481', '6781203', '兵庫県', 'ヒョウゴケン', '赤穂郡上郡町', 'アコウグンカミゴオリチョウ', '尾長谷', 'オナガダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂郡上郡町大冨', '28', '28481', '6781204', '兵庫県', 'ヒョウゴケン', '赤穂郡上郡町', 'アコウグンカミゴオリチョウ', '大冨', 'オオトミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂郡上郡町光都', '28', '28481', '6781205', '兵庫県', 'ヒョウゴケン', '赤穂郡上郡町', 'アコウグンカミゴオリチョウ', '光都', 'コウト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂郡上郡町小野豆', '28', '28481', '6781211', '兵庫県', 'ヒョウゴケン', '赤穂郡上郡町', 'アコウグンカミゴオリチョウ', '小野豆', 'オノズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂郡上郡町佐用谷', '28', '28481', '6781212', '兵庫県', 'ヒョウゴケン', '赤穂郡上郡町', 'アコウグンカミゴオリチョウ', '佐用谷', 'サヨダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂郡上郡町宇野山', '28', '28481', '6781213', '兵庫県', 'ヒョウゴケン', '赤穂郡上郡町', 'アコウグンカミゴオリチョウ', '宇野山', 'ウノヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂郡上郡町休治', '28', '28481', '6781214', '兵庫県', 'ヒョウゴケン', '赤穂郡上郡町', 'アコウグンカミゴオリチョウ', '休治', 'キュウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂郡上郡町正福寺', '28', '28481', '6781215', '兵庫県', 'ヒョウゴケン', '赤穂郡上郡町', 'アコウグンカミゴオリチョウ', '正福寺', 'ショウフクジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂郡上郡町中野', '28', '28481', '6781216', '兵庫県', 'ヒョウゴケン', '赤穂郡上郡町', 'アコウグンカミゴオリチョウ', '中野', 'ナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂郡上郡町宿', '28', '28481', '6781217', '兵庫県', 'ヒョウゴケン', '赤穂郡上郡町', 'アコウグンカミゴオリチョウ', '宿', 'シュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂郡上郡町宇治山', '28', '28481', '6781218', '兵庫県', 'ヒョウゴケン', '赤穂郡上郡町', 'アコウグンカミゴオリチョウ', '宇治山', 'ウジヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂郡上郡町奥', '28', '28481', '6781219', '兵庫県', 'ヒョウゴケン', '赤穂郡上郡町', 'アコウグンカミゴオリチョウ', '奥', 'オク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂郡上郡町神明寺', '28', '28481', '6781221', '兵庫県', 'ヒョウゴケン', '赤穂郡上郡町', 'アコウグンカミゴオリチョウ', '神明寺', 'ジミョウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂郡上郡町西野山', '28', '28481', '6781222', '兵庫県', 'ヒョウゴケン', '赤穂郡上郡町', 'アコウグンカミゴオリチョウ', '西野山', 'ニシノヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂郡上郡町釜島', '28', '28481', '6781223', '兵庫県', 'ヒョウゴケン', '赤穂郡上郡町', 'アコウグンカミゴオリチョウ', '釜島', 'カマシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂郡上郡町與井新', '28', '28481', '6781224', '兵庫県', 'ヒョウゴケン', '赤穂郡上郡町', 'アコウグンカミゴオリチョウ', '與井新', 'ヨイシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂郡上郡町與井', '28', '28481', '6781225', '兵庫県', 'ヒョウゴケン', '赤穂郡上郡町', 'アコウグンカミゴオリチョウ', '與井', 'ヨイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂郡上郡町高田台', '28', '28481', '6781226', '兵庫県', 'ヒョウゴケン', '赤穂郡上郡町', 'アコウグンカミゴオリチョウ', '高田台', 'タカタダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂郡上郡町上郡', '28', '28481', '6781231', '兵庫県', 'ヒョウゴケン', '赤穂郡上郡町', 'アコウグンカミゴオリチョウ', '上郡', 'カミゴオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂郡上郡町竹万', '28', '28481', '6781232', '兵庫県', 'ヒョウゴケン', '赤穂郡上郡町', 'アコウグンカミゴオリチョウ', '竹万', 'チクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂郡上郡町大持', '28', '28481', '6781233', '兵庫県', 'ヒョウゴケン', '赤穂郡上郡町', 'アコウグンカミゴオリチョウ', '大持', 'ダイモチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂郡上郡町山野里', '28', '28481', '6781241', '兵庫県', 'ヒョウゴケン', '赤穂郡上郡町', 'アコウグンカミゴオリチョウ', '山野里', 'ヤマノサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂郡上郡町栗原', '28', '28481', '6781242', '兵庫県', 'ヒョウゴケン', '赤穂郡上郡町', 'アコウグンカミゴオリチョウ', '栗原', 'クリバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂郡上郡町落地', '28', '28481', '6781243', '兵庫県', 'ヒョウゴケン', '赤穂郡上郡町', 'アコウグンカミゴオリチョウ', '落地', 'オロチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂郡上郡町梨ケ原', '28', '28481', '6781244', '兵庫県', 'ヒョウゴケン', '赤穂郡上郡町', 'アコウグンカミゴオリチョウ', '梨ケ原', 'ナシガハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂郡上郡町井上', '28', '28481', '6781251', '兵庫県', 'ヒョウゴケン', '赤穂郡上郡町', 'アコウグンカミゴオリチョウ', '井上', 'イノカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂郡上郡町船坂', '28', '28481', '6781252', '兵庫県', 'ヒョウゴケン', '赤穂郡上郡町', 'アコウグンカミゴオリチョウ', '船坂', 'フナサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂郡上郡町別名', '28', '28481', '6781253', '兵庫県', 'ヒョウゴケン', '赤穂郡上郡町', 'アコウグンカミゴオリチョウ', '別名', 'ベツミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂郡上郡町高山', '28', '28481', '6781254', '兵庫県', 'ヒョウゴケン', '赤穂郡上郡町', 'アコウグンカミゴオリチョウ', '高山', 'タカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂郡上郡町行頭', '28', '28481', '6781255', '兵庫県', 'ヒョウゴケン', '赤穂郡上郡町', 'アコウグンカミゴオリチョウ', '行頭', 'ユクトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂郡上郡町八保', '28', '28481', '6781256', '兵庫県', 'ヒョウゴケン', '赤穂郡上郡町', 'アコウグンカミゴオリチョウ', '八保', 'ヤホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂郡上郡町旭日', '28', '28481', '6781261', '兵庫県', 'ヒョウゴケン', '赤穂郡上郡町', 'アコウグンカミゴオリチョウ', '旭日', 'アサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂郡上郡町岩木', '28', '28481', '6781262', '兵庫県', 'ヒョウゴケン', '赤穂郡上郡町', 'アコウグンカミゴオリチョウ', '岩木', 'イワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂郡上郡町楠', '28', '28481', '6781271', '兵庫県', 'ヒョウゴケン', '赤穂郡上郡町', 'アコウグンカミゴオリチョウ', '楠', 'クスノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂郡上郡町細野', '28', '28481', '6781272', '兵庫県', 'ヒョウゴケン', '赤穂郡上郡町', 'アコウグンカミゴオリチョウ', '細野', 'ホソノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂郡上郡町赤松', '28', '28481', '6781273', '兵庫県', 'ヒョウゴケン', '赤穂郡上郡町', 'アコウグンカミゴオリチョウ', '赤松', 'アカマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂郡上郡町柏野', '28', '28481', '6781274', '兵庫県', 'ヒョウゴケン', '赤穂郡上郡町', 'アコウグンカミゴオリチョウ', '柏野', 'カシワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂郡上郡町大枝', '28', '28481', '6781275', '兵庫県', 'ヒョウゴケン', '赤穂郡上郡町', 'アコウグンカミゴオリチョウ', '大枝', 'オエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂郡上郡町大枝新', '28', '28481', '6781276', '兵庫県', 'ヒョウゴケン', '赤穂郡上郡町', 'アコウグンカミゴオリチョウ', '大枝新', 'オエダシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂郡上郡町苔縄', '28', '28481', '6781277', '兵庫県', 'ヒョウゴケン', '赤穂郡上郡町', 'アコウグンカミゴオリチョウ', '苔縄', 'コケナワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県赤穂郡上郡町河野原', '28', '28481', '6781278', '兵庫県', 'ヒョウゴケン', '赤穂郡上郡町', 'アコウグンカミゴオリチョウ', '河野原', 'コウノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加西市都染町', '28', '28220', '6790101', '兵庫県', 'ヒョウゴケン', '加西市', 'カサイシ', '都染町', 'ツソメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加西市青野原町', '28', '28220', '6790102', '兵庫県', 'ヒョウゴケン', '加西市', 'カサイシ', '青野原町', 'アオノハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加西市別府町', '28', '28220', '6790103', '兵庫県', 'ヒョウゴケン', '加西市', 'カサイシ', '別府町', 'ベフチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加西市常吉町', '28', '28220', '6790104', '兵庫県', 'ヒョウゴケン', '加西市', 'カサイシ', '常吉町', 'ツネヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加西市朝妻町', '28', '28220', '6790105', '兵庫県', 'ヒョウゴケン', '加西市', 'カサイシ', '朝妻町', 'アサヅマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加西市豊倉町', '28', '28220', '6790106', '兵庫県', 'ヒョウゴケン', '加西市', 'カサイシ', '豊倉町', 'トヨクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加西市玉野町', '28', '28220', '6790107', '兵庫県', 'ヒョウゴケン', '加西市', 'カサイシ', '玉野町', 'タマノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加西市山枝町', '28', '28220', '6790108', '兵庫県', 'ヒョウゴケン', '加西市', 'カサイシ', '山枝町', 'ヤマエダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加西市玉丘町', '28', '28220', '6790109', '兵庫県', 'ヒョウゴケン', '加西市', 'カサイシ', '玉丘町', 'タマオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加東市曽我', '28', '28228', '6790201', '兵庫県', 'ヒョウゴケン', '加東市', 'カトウシ', '曽我', 'ソガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加東市多井田', '28', '28228', '6790202', '兵庫県', 'ヒョウゴケン', '加東市', 'カトウシ', '多井田', 'オイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加東市稲尾', '28', '28228', '6790203', '兵庫県', 'ヒョウゴケン', '加東市', 'カトウシ', '稲尾', 'イナオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加東市新町', '28', '28228', '6790204', '兵庫県', 'ヒョウゴケン', '加東市', 'カトウシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加東市北野', '28', '28228', '6790205', '兵庫県', 'ヒョウゴケン', '加東市', 'カトウシ', '北野', 'キタノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加東市穂積', '28', '28228', '6790206', '兵庫県', 'ヒョウゴケン', '加東市', 'カトウシ', '穂積', 'ホヅミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加東市滝野団地', '28', '28228', '6790207', '兵庫県', 'ヒョウゴケン', '加東市', 'カトウシ', '滝野団地', 'タキノダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加東市上滝野', '28', '28228', '6790211', '兵庫県', 'ヒョウゴケン', '加東市', 'カトウシ', '上滝野', 'カミタキノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加東市下滝野', '28', '28228', '6790212', '兵庫県', 'ヒョウゴケン', '加東市', 'カトウシ', '下滝野', 'シモタキノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加東市光明寺', '28', '28228', '6790213', '兵庫県', 'ヒョウゴケン', '加東市', 'カトウシ', '光明寺', 'コウミョウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加東市河高', '28', '28228', '6790221', '兵庫県', 'ヒョウゴケン', '加東市', 'カトウシ', '河高', 'コウタカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加東市高岡', '28', '28228', '6790222', '兵庫県', 'ヒョウゴケン', '加東市', 'カトウシ', '高岡', 'タカオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県加東市桜台', '28', '28228', '6790223', '兵庫県', 'ヒョウゴケン', '加東市', 'カトウシ', '桜台', 'サクラダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西脇市黒田庄町小苗', '28', '28213', '6790301', '兵庫県', 'ヒョウゴケン', '西脇市', 'ニシワキシ', '黒田庄町小苗', 'クロダショウチョウコナエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西脇市黒田庄町黒田', '28', '28213', '6790302', '兵庫県', 'ヒョウゴケン', '西脇市', 'ニシワキシ', '黒田庄町黒田', 'クロダショウチョウクロダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西脇市黒田庄町前坂', '28', '28213', '6790303', '兵庫県', 'ヒョウゴケン', '西脇市', 'ニシワキシ', '黒田庄町前坂', 'クロダショウチョウマエサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西脇市黒田庄町船町', '28', '28213', '6790304', '兵庫県', 'ヒョウゴケン', '西脇市', 'ニシワキシ', '黒田庄町船町', 'クロダショウチョウフナマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西脇市黒田庄町喜多', '28', '28213', '6790311', '兵庫県', 'ヒョウゴケン', '西脇市', 'ニシワキシ', '黒田庄町喜多', 'クロダショウチョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西脇市黒田庄町門柳', '28', '28213', '6790312', '兵庫県', 'ヒョウゴケン', '西脇市', 'ニシワキシ', '黒田庄町門柳', 'クロダショウチョウモンリュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西脇市黒田庄町岡', '28', '28213', '6790313', '兵庫県', 'ヒョウゴケン', '西脇市', 'ニシワキシ', '黒田庄町岡', 'クロダショウチョウオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西脇市黒田庄町福地', '28', '28213', '6790314', '兵庫県', 'ヒョウゴケン', '西脇市', 'ニシワキシ', '黒田庄町福地', 'クロダショウチョウフクジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西脇市黒田庄町津万井', '28', '28213', '6790315', '兵庫県', 'ヒョウゴケン', '西脇市', 'ニシワキシ', '黒田庄町津万井', 'クロダショウチョウツマイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西脇市黒田庄町大門', '28', '28213', '6790316', '兵庫県', 'ヒョウゴケン', '西脇市', 'ニシワキシ', '黒田庄町大門', 'クロダショウチョウダイモン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西脇市黒田庄町田高', '28', '28213', '6790321', '兵庫県', 'ヒョウゴケン', '西脇市', 'ニシワキシ', '黒田庄町田高', 'クロダショウチョウタコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西脇市黒田庄町石原', '28', '28213', '6790322', '兵庫県', 'ヒョウゴケン', '西脇市', 'ニシワキシ', '黒田庄町石原', 'クロダショウチョウイシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西脇市黒田庄町西澤', '28', '28213', '6790323', '兵庫県', 'ヒョウゴケン', '西脇市', 'ニシワキシ', '黒田庄町西澤', 'クロダショウチョウニシザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県西脇市黒田庄町大伏', '28', '28213', '6790324', '兵庫県', 'ヒョウゴケン', '西脇市', 'ニシワキシ', '黒田庄町大伏', 'クロダショウチョウオオフシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県多可郡多可町', '28', '28365', '6791100', '兵庫県', 'ヒョウゴケン', '多可郡多可町', 'タカグンタカチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('82616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県多可郡多可町中区門前', '28', '28365', '6791101', '兵庫県', 'ヒョウゴケン', '多可郡多可町', 'タカグンタカチョウ', '中区門前', 'ナカクモンゼン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県多可郡多可町中区安楽田', '28', '28365', '6791102', '兵庫県', 'ヒョウゴケン', '多可郡多可町', 'タカグンタカチョウ', '中区安楽田', 'ナカクアラタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県多可郡多可町中区牧野', '28', '28365', '6791103', '兵庫県', 'ヒョウゴケン', '多可郡多可町', 'タカグンタカチョウ', '中区牧野', 'ナカクマキノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県多可郡多可町中区田野口', '28', '28365', '6791104', '兵庫県', 'ヒョウゴケン', '多可郡多可町', 'タカグンタカチョウ', '中区田野口', 'ナカクタノクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県多可郡多可町中区東山', '28', '28365', '6791105', '兵庫県', 'ヒョウゴケン', '多可郡多可町', 'タカグンタカチョウ', '中区東山', 'ナカクヒガシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県多可郡多可町中区高岸', '28', '28365', '6791106', '兵庫県', 'ヒョウゴケン', '多可郡多可町', 'タカグンタカチョウ', '中区高岸', 'ナカクタカギシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県多可郡多可町中区奥中', '28', '28365', '6791107', '兵庫県', 'ヒョウゴケン', '多可郡多可町', 'タカグンタカチョウ', '中区奥中', 'ナカクオクナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県多可郡多可町中区徳畑', '28', '28365', '6791107', '兵庫県', 'ヒョウゴケン', '多可郡多可町', 'タカグンタカチョウ', '中区徳畑', 'ナカクトクバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県多可郡多可町中区鍛冶屋', '28', '28365', '6791111', '兵庫県', 'ヒョウゴケン', '多可郡多可町', 'タカグンタカチョウ', '中区鍛冶屋', 'ナカクカジヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県多可郡多可町中区間子', '28', '28365', '6791112', '兵庫県', 'ヒョウゴケン', '多可郡多可町', 'タカグンタカチョウ', '中区間子', 'ナカクマコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県多可郡多可町中区中村町', '28', '28365', '6791113', '兵庫県', 'ヒョウゴケン', '多可郡多可町', 'タカグンタカチョウ', '中区中村町', 'ナカクナカムラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県多可郡多可町中区岸上', '28', '28365', '6791114', '兵庫県', 'ヒョウゴケン', '多可郡多可町', 'タカグンタカチョウ', '中区岸上', 'ナカクキシカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県多可郡多可町中区天田', '28', '28365', '6791115', '兵庫県', 'ヒョウゴケン', '多可郡多可町', 'タカグンタカチョウ', '中区天田', 'ナカクアマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県多可郡多可町中区東安田', '28', '28365', '6791121', '兵庫県', 'ヒョウゴケン', '多可郡多可町', 'タカグンタカチョウ', '中区東安田', 'ナカクヒガシヤスダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県多可郡多可町中区中安田', '28', '28365', '6791122', '兵庫県', 'ヒョウゴケン', '多可郡多可町', 'タカグンタカチョウ', '中区中安田', 'ナカクナカヤスダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県多可郡多可町中区西安田', '28', '28365', '6791123', '兵庫県', 'ヒョウゴケン', '多可郡多可町', 'タカグンタカチョウ', '中区西安田', 'ナカクニシヤスダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県多可郡多可町中区森本', '28', '28365', '6791124', '兵庫県', 'ヒョウゴケン', '多可郡多可町', 'タカグンタカチョウ', '中区森本', 'ナカクモリモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県多可郡多可町中区曽我井', '28', '28365', '6791131', '兵庫県', 'ヒョウゴケン', '多可郡多可町', 'タカグンタカチョウ', '中区曽我井', 'ナカクソガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県多可郡多可町中区坂本', '28', '28365', '6791132', '兵庫県', 'ヒョウゴケン', '多可郡多可町', 'タカグンタカチョウ', '中区坂本', 'ナカクサカモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県多可郡多可町中区糀屋', '28', '28365', '6791133', '兵庫県', 'ヒョウゴケン', '多可郡多可町', 'タカグンタカチョウ', '中区糀屋', 'ナカクコウジヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県多可郡多可町中区茂利', '28', '28365', '6791134', '兵庫県', 'ヒョウゴケン', '多可郡多可町', 'タカグンタカチョウ', '中区茂利', 'ナカクシゲリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県多可郡多可町中区安坂', '28', '28365', '6791135', '兵庫県', 'ヒョウゴケン', '多可郡多可町', 'タカグンタカチョウ', '中区安坂', 'ナカクアサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県多可郡多可町加美区豊部', '28', '28365', '6791201', '兵庫県', 'ヒョウゴケン', '多可郡多可町', 'タカグンタカチョウ', '加美区豊部', 'カミクトヨベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県多可郡多可町加美区熊野部', '28', '28365', '6791202', '兵庫県', 'ヒョウゴケン', '多可郡多可町', 'タカグンタカチョウ', '加美区熊野部', 'カミククマノベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県多可郡多可町加美区多田', '28', '28365', '6791203', '兵庫県', 'ヒョウゴケン', '多可郡多可町', 'タカグンタカチョウ', '加美区多田', 'カミクタダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県多可郡多可町加美区棚釜', '28', '28365', '6791204', '兵庫県', 'ヒョウゴケン', '多可郡多可町', 'タカグンタカチョウ', '加美区棚釜', 'カミクタナカマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県多可郡多可町加美区岩座神', '28', '28365', '6791205', '兵庫県', 'ヒョウゴケン', '多可郡多可町', 'タカグンタカチョウ', '加美区岩座神', 'カミクイサリガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県多可郡多可町加美区寺内', '28', '28365', '6791211', '兵庫県', 'ヒョウゴケン', '多可郡多可町', 'タカグンタカチョウ', '加美区寺内', 'カミクテラウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県多可郡多可町加美区西脇', '28', '28365', '6791212', '兵庫県', 'ヒョウゴケン', '多可郡多可町', 'タカグンタカチョウ', '加美区西脇', 'カミクニシワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県多可郡多可町加美区山野部', '28', '28365', '6791213', '兵庫県', 'ヒョウゴケン', '多可郡多可町', 'タカグンタカチョウ', '加美区山野部', 'カミクヤマノベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県多可郡多可町加美区的場', '28', '28365', '6791214', '兵庫県', 'ヒョウゴケン', '多可郡多可町', 'タカグンタカチョウ', '加美区的場', 'カミクマトバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県多可郡多可町加美区奥荒田', '28', '28365', '6791215', '兵庫県', 'ヒョウゴケン', '多可郡多可町', 'タカグンタカチョウ', '加美区奥荒田', 'カミクオクアラタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県多可郡多可町加美区山寄上', '28', '28365', '6791321', '兵庫県', 'ヒョウゴケン', '多可郡多可町', 'タカグンタカチョウ', '加美区山寄上', 'カミクヤマヨリカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県多可郡多可町加美区鳥羽', '28', '28365', '6791322', '兵庫県', 'ヒョウゴケン', '多可郡多可町', 'タカグンタカチョウ', '加美区鳥羽', 'カミクトリマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県多可郡多可町加美区清水', '28', '28365', '6791323', '兵庫県', 'ヒョウゴケン', '多可郡多可町', 'タカグンタカチョウ', '加美区清水', 'カミクキヨミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県多可郡多可町加美区轟', '28', '28365', '6791324', '兵庫県', 'ヒョウゴケン', '多可郡多可町', 'タカグンタカチョウ', '加美区轟', 'カミクトドロキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県多可郡多可町加美区山口', '28', '28365', '6791325', '兵庫県', 'ヒョウゴケン', '多可郡多可町', 'タカグンタカチョウ', '加美区山口', 'カミクヤマグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県多可郡多可町加美区西山', '28', '28365', '6791326', '兵庫県', 'ヒョウゴケン', '多可郡多可町', 'タカグンタカチョウ', '加美区西山', 'カミクニシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県多可郡多可町加美区市原', '28', '28365', '6791327', '兵庫県', 'ヒョウゴケン', '多可郡多可町', 'タカグンタカチョウ', '加美区市原', 'カミクイチハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県多可郡多可町加美区丹治', '28', '28365', '6791331', '兵庫県', 'ヒョウゴケン', '多可郡多可町', 'タカグンタカチョウ', '加美区丹治', 'カミクタンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県多可郡多可町加美区大袋', '28', '28365', '6791332', '兵庫県', 'ヒョウゴケン', '多可郡多可町', 'タカグンタカチョウ', '加美区大袋', 'カミクオオブクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県多可郡多可町加美区三谷', '28', '28365', '6791333', '兵庫県', 'ヒョウゴケン', '多可郡多可町', 'タカグンタカチョウ', '加美区三谷', 'カミクミダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県多可郡多可町加美区箸荷', '28', '28365', '6791334', '兵庫県', 'ヒョウゴケン', '多可郡多可町', 'タカグンタカチョウ', '加美区箸荷', 'カミクハセガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県多可郡多可町加美区門村', '28', '28365', '6791335', '兵庫県', 'ヒョウゴケン', '多可郡多可町', 'タカグンタカチョウ', '加美区門村', 'カミクカドムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県多可郡多可町加美区杉原', '28', '28365', '6791336', '兵庫県', 'ヒョウゴケン', '多可郡多可町', 'タカグンタカチョウ', '加美区杉原', 'カミクスギハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県多可郡多可町加美区奥豊部', '28', '28365', '6791337', '兵庫県', 'ヒョウゴケン', '多可郡多可町', 'タカグンタカチョウ', '加美区奥豊部', 'カミクオクトヨベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県多可郡多可町加美区観音寺', '28', '28365', '6791338', '兵庫県', 'ヒョウゴケン', '多可郡多可町', 'タカグンタカチョウ', '加美区観音寺', 'カミクカンノンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市船津町', '28', '28201', '6792101', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '船津町', 'フナツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市山田町多田', '28', '28201', '6792111', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '山田町多田', 'ヤマダチョウタダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市山田町北山田', '28', '28201', '6792112', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '山田町北山田', 'ヤマダチョウキタヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市山田町南山田', '28', '28201', '6792113', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '山田町南山田', 'ヤマダチョウミナミヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市山田町牧野', '28', '28201', '6792114', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '山田町牧野', 'ヤマダチョウマキノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市山田町西山田', '28', '28201', '6792115', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '山田町西山田', 'ヤマダチョウニシヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市豊富町神谷', '28', '28201', '6792121', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '豊富町神谷', 'トヨトミチョウコダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市豊富町御蔭', '28', '28201', '6792122', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '豊富町御蔭', 'トヨトミチョウミカゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市豊富町豊富', '28', '28201', '6792123', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '豊富町豊富', 'トヨトミチョウトヨトミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市豊富町甲丘', '28', '28201', '6792124', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '豊富町甲丘', 'トヨトミチョウカブトガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市香寺町犬飼', '28', '28201', '6792131', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '香寺町犬飼', 'コウデラチョウイヌカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市香寺町須加院', '28', '28201', '6792132', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '香寺町須加院', 'コウデラチョウスカイン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市香寺町岩部', '28', '28201', '6792141', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '香寺町岩部', 'コウデラチョウイワベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市香寺町広瀬', '28', '28201', '6792142', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '香寺町広瀬', 'コウデラチョウヒロセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市香寺町中仁野', '28', '28201', '6792143', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '香寺町中仁野', 'コウデラチョウナカニノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市香寺町中屋', '28', '28201', '6792144', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '香寺町中屋', 'コウデラチョウナカヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市香寺町香呂', '28', '28201', '6792151', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '香寺町香呂', 'コウデラチョウコウロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市香寺町行重', '28', '28201', '6792152', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '香寺町行重', 'コウデラチョウユキシゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市香寺町田野', '28', '28201', '6792153', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '香寺町田野', 'コウデラチョウタノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市香寺町相坂', '28', '28201', '6792154', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '香寺町相坂', 'コウデラチョウアイサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市香寺町矢田部', '28', '28201', '6792155', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '香寺町矢田部', 'コウデラチョウヤタベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市香寺町溝口', '28', '28201', '6792161', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '香寺町溝口', 'コウデラチョウミゾグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市香寺町野田', '28', '28201', '6792162', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '香寺町野田', 'コウデラチョウノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市香寺町土師', '28', '28201', '6792163', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '香寺町土師', 'コウデラチョウハゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市香寺町中寺', '28', '28201', '6792164', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '香寺町中寺', 'コウデラチョウナカデラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市香寺町恒屋', '28', '28201', '6792165', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '香寺町恒屋', 'コウデラチョウツネヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市香寺町中村', '28', '28201', '6792166', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '香寺町中村', 'コウデラチョウナカムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市香寺町久畑', '28', '28201', '6792167', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '香寺町久畑', 'コウデラチョウクバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神崎郡福崎町', '28', '28443', '6792200', '兵庫県', 'ヒョウゴケン', '神崎郡福崎町', 'カンザキグンフクサキチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('82694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神崎郡福崎町大貫', '28', '28443', '6792201', '兵庫県', 'ヒョウゴケン', '神崎郡福崎町', 'カンザキグンフクサキチョウ', '大貫', 'オオヌキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神崎郡福崎町八千種', '28', '28443', '6792202', '兵庫県', 'ヒョウゴケン', '神崎郡福崎町', 'カンザキグンフクサキチョウ', '八千種', 'ヤチクサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神崎郡福崎町南田原', '28', '28443', '6792203', '兵庫県', 'ヒョウゴケン', '神崎郡福崎町', 'カンザキグンフクサキチョウ', '南田原', 'ミナミタワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神崎郡福崎町西田原', '28', '28443', '6792204', '兵庫県', 'ヒョウゴケン', '神崎郡福崎町', 'カンザキグンフクサキチョウ', '西田原', 'ニシタワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神崎郡福崎町東田原', '28', '28443', '6792205', '兵庫県', 'ヒョウゴケン', '神崎郡福崎町', 'カンザキグンフクサキチョウ', '東田原', 'ヒガシタワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神崎郡福崎町山崎', '28', '28443', '6792211', '兵庫県', 'ヒョウゴケン', '神崎郡福崎町', 'カンザキグンフクサキチョウ', '山崎', 'ヤマサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神崎郡福崎町福田', '28', '28443', '6792212', '兵庫県', 'ヒョウゴケン', '神崎郡福崎町', 'カンザキグンフクサキチョウ', '福田', 'フクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神崎郡福崎町馬田', '28', '28443', '6792213', '兵庫県', 'ヒョウゴケン', '神崎郡福崎町', 'カンザキグンフクサキチョウ', '馬田', 'ウマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神崎郡福崎町福崎新', '28', '28443', '6792214', '兵庫県', 'ヒョウゴケン', '神崎郡福崎町', 'カンザキグンフクサキチョウ', '福崎新', 'フクサキシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神崎郡福崎町西治', '28', '28443', '6792215', '兵庫県', 'ヒョウゴケン', '神崎郡福崎町', 'カンザキグンフクサキチョウ', '西治', 'サイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神崎郡福崎町高橋', '28', '28443', '6792216', '兵庫県', 'ヒョウゴケン', '神崎郡福崎町', 'カンザキグンフクサキチョウ', '高橋', 'タカハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神崎郡福崎町高岡', '28', '28443', '6792217', '兵庫県', 'ヒョウゴケン', '神崎郡福崎町', 'カンザキグンフクサキチョウ', '高岡', 'タカオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神崎郡福崎町田口', '28', '28443', '6792218', '兵庫県', 'ヒョウゴケン', '神崎郡福崎町', 'カンザキグンフクサキチョウ', '田口', 'タグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神崎郡市川町', '28', '28442', '6792300', '兵庫県', 'ヒョウゴケン', '神崎郡市川町', 'カンザキグンイチカワチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('82718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神崎郡市川町上牛尾', '28', '28442', '6792301', '兵庫県', 'ヒョウゴケン', '神崎郡市川町', 'カンザキグンイチカワチョウ', '上牛尾', 'カミウシオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神崎郡市川町下牛尾', '28', '28442', '6792302', '兵庫県', 'ヒョウゴケン', '神崎郡市川町', 'カンザキグンイチカワチョウ', '下牛尾', 'シモウシオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神崎郡市川町上瀬加', '28', '28442', '6792303', '兵庫県', 'ヒョウゴケン', '神崎郡市川町', 'カンザキグンイチカワチョウ', '上瀬加', 'カミセカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神崎郡市川町下瀬加', '28', '28442', '6792304', '兵庫県', 'ヒョウゴケン', '神崎郡市川町', 'カンザキグンイチカワチョウ', '下瀬加', 'シモセカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神崎郡市川町上田中', '28', '28442', '6792311', '兵庫県', 'ヒョウゴケン', '神崎郡市川町', 'カンザキグンイチカワチョウ', '上田中', 'ウエダナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神崎郡市川町保喜', '28', '28442', '6792312', '兵庫県', 'ヒョウゴケン', '神崎郡市川町', 'カンザキグンイチカワチョウ', '保喜', 'ホキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神崎郡市川町西田中', '28', '28442', '6792313', '兵庫県', 'ヒョウゴケン', '神崎郡市川町', 'カンザキグンイチカワチョウ', '西田中', 'ニシタナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神崎郡市川町北田中', '28', '28442', '6792314', '兵庫県', 'ヒョウゴケン', '神崎郡市川町', 'カンザキグンイチカワチョウ', '北田中', 'キタタナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神崎郡市川町西川辺', '28', '28442', '6792315', '兵庫県', 'ヒョウゴケン', '神崎郡市川町', 'カンザキグンイチカワチョウ', '西川辺', 'ニシカワナベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神崎郡市川町東川辺', '28', '28442', '6792316', '兵庫県', 'ヒョウゴケン', '神崎郡市川町', 'カンザキグンイチカワチョウ', '東川辺', 'ヒガシカワナベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神崎郡市川町浅野', '28', '28442', '6792317', '兵庫県', 'ヒョウゴケン', '神崎郡市川町', 'カンザキグンイチカワチョウ', '浅野', 'アサノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神崎郡市川町小畑', '28', '28442', '6792318', '兵庫県', 'ヒョウゴケン', '神崎郡市川町', 'カンザキグンイチカワチョウ', '小畑', 'オバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神崎郡市川町千原', '28', '28442', '6792321', '兵庫県', 'ヒョウゴケン', '神崎郡市川町', 'カンザキグンイチカワチョウ', '千原', 'チハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神崎郡市川町小谷', '28', '28442', '6792322', '兵庫県', 'ヒョウゴケン', '神崎郡市川町', 'カンザキグンイチカワチョウ', '小谷', 'コダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神崎郡市川町甘地', '28', '28442', '6792323', '兵庫県', 'ヒョウゴケン', '神崎郡市川町', 'カンザキグンイチカワチョウ', '甘地', 'アマジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神崎郡市川町坂戸', '28', '28442', '6792324', '兵庫県', 'ヒョウゴケン', '神崎郡市川町', 'カンザキグンイチカワチョウ', '坂戸', 'サカド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神崎郡市川町奥', '28', '28442', '6792325', '兵庫県', 'ヒョウゴケン', '神崎郡市川町', 'カンザキグンイチカワチョウ', '奥', 'オク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神崎郡市川町谷', '28', '28442', '6792326', '兵庫県', 'ヒョウゴケン', '神崎郡市川町', 'カンザキグンイチカワチョウ', '谷', 'タニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神崎郡市川町近平', '28', '28442', '6792327', '兵庫県', 'ヒョウゴケン', '神崎郡市川町', 'カンザキグンイチカワチョウ', '近平', 'チカラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神崎郡市川町小室', '28', '28442', '6792331', '兵庫県', 'ヒョウゴケン', '神崎郡市川町', 'カンザキグンイチカワチョウ', '小室', 'コムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神崎郡市川町田中', '28', '28442', '6792332', '兵庫県', 'ヒョウゴケン', '神崎郡市川町', 'カンザキグンイチカワチョウ', '田中', 'タナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神崎郡市川町神崎', '28', '28442', '6792333', '兵庫県', 'ヒョウゴケン', '神崎郡市川町', 'カンザキグンイチカワチョウ', '神崎', 'カンザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神崎郡市川町鶴居', '28', '28442', '6792334', '兵庫県', 'ヒョウゴケン', '神崎郡市川町', 'カンザキグンイチカワチョウ', '鶴居', 'ツルイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神崎郡市川町美佐', '28', '28442', '6792335', '兵庫県', 'ヒョウゴケン', '神崎郡市川町', 'カンザキグンイチカワチョウ', '美佐', 'ミサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神崎郡市川町沢', '28', '28442', '6792336', '兵庫県', 'ヒョウゴケン', '神崎郡市川町', 'カンザキグンイチカワチョウ', '沢', 'サワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神崎郡市川町屋形', '28', '28442', '6792337', '兵庫県', 'ヒョウゴケン', '神崎郡市川町', 'カンザキグンイチカワチョウ', '屋形', 'ヤカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神崎郡神河町新田', '28', '28446', '6792401', '兵庫県', 'ヒョウゴケン', '神崎郡神河町', 'カンザキグンカミカワチョウ', '新田', 'シンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神崎郡神河町作畑', '28', '28446', '6792402', '兵庫県', 'ヒョウゴケン', '神崎郡神河町', 'カンザキグンカミカワチョウ', '作畑', 'サクハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神崎郡神河町大畑', '28', '28446', '6792403', '兵庫県', 'ヒョウゴケン', '神崎郡神河町', 'カンザキグンカミカワチョウ', '大畑', 'オオハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神崎郡神河町越知', '28', '28446', '6792404', '兵庫県', 'ヒョウゴケン', '神崎郡神河町', 'カンザキグンカミカワチョウ', '越知', 'オチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神崎郡神河町岩屋', '28', '28446', '6792405', '兵庫県', 'ヒョウゴケン', '神崎郡神河町', 'カンザキグンカミカワチョウ', '岩屋', 'イワヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神崎郡神河町根宇野', '28', '28446', '6792411', '兵庫県', 'ヒョウゴケン', '神崎郡神河町', 'カンザキグンカミカワチョウ', '根宇野', 'ミヨノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神崎郡神河町山田', '28', '28446', '6792412', '兵庫県', 'ヒョウゴケン', '神崎郡神河町', 'カンザキグンカミカワチョウ', '山田', 'ヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神崎郡神河町中村', '28', '28446', '6792413', '兵庫県', 'ヒョウゴケン', '神崎郡神河町', 'カンザキグンカミカワチョウ', '中村', 'ナカムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神崎郡神河町粟賀町', '28', '28446', '6792414', '兵庫県', 'ヒョウゴケン', '神崎郡神河町', 'カンザキグンカミカワチョウ', '粟賀町', 'アワガマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神崎郡神河町福本', '28', '28446', '6792415', '兵庫県', 'ヒョウゴケン', '神崎郡神河町', 'カンザキグンカミカワチョウ', '福本', 'フクモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神崎郡神河町加納', '28', '28446', '6792421', '兵庫県', 'ヒョウゴケン', '神崎郡神河町', 'カンザキグンカミカワチョウ', '加納', 'カノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神崎郡神河町貝野', '28', '28446', '6792422', '兵庫県', 'ヒョウゴケン', '神崎郡神河町', 'カンザキグンカミカワチョウ', '貝野', 'カイノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神崎郡神河町寺野', '28', '28446', '6792423', '兵庫県', 'ヒョウゴケン', '神崎郡神河町', 'カンザキグンカミカワチョウ', '寺野', 'テラノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神崎郡神河町柏尾', '28', '28446', '6792424', '兵庫県', 'ヒョウゴケン', '神崎郡神河町', 'カンザキグンカミカワチョウ', '柏尾', 'カシオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神崎郡神河町東柏尾', '28', '28446', '6792425', '兵庫県', 'ヒョウゴケン', '神崎郡神河町', 'カンザキグンカミカワチョウ', '東柏尾', 'ヒガシカシオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神崎郡神河町猪篠', '28', '28446', '6792431', '兵庫県', 'ヒョウゴケン', '神崎郡神河町', 'カンザキグンカミカワチョウ', '猪篠', 'イザサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神崎郡神河町大山', '28', '28446', '6792432', '兵庫県', 'ヒョウゴケン', '神崎郡神河町', 'カンザキグンカミカワチョウ', '大山', 'オオヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神崎郡神河町杉', '28', '28446', '6792433', '兵庫県', 'ヒョウゴケン', '神崎郡神河町', 'カンザキグンカミカワチョウ', '杉', 'スギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神崎郡神河町吉冨', '28', '28446', '6792434', '兵庫県', 'ヒョウゴケン', '神崎郡神河町', 'カンザキグンカミカワチョウ', '吉冨', 'ヨシトミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神崎郡神河町', '28', '28446', '6793100', '兵庫県', 'ヒョウゴケン', '神崎郡神河町', 'カンザキグンカミカワチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('82766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神崎郡神河町渕', '28', '28446', '6793101', '兵庫県', 'ヒョウゴケン', '神崎郡神河町', 'カンザキグンカミカワチョウ', '渕', 'フチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神崎郡神河町栗', '28', '28446', '6793102', '兵庫県', 'ヒョウゴケン', '神崎郡神河町', 'カンザキグンカミカワチョウ', '栗', 'クリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神崎郡神河町長谷', '28', '28446', '6793103', '兵庫県', 'ヒョウゴケン', '神崎郡神河町', 'カンザキグンカミカワチョウ', '長谷', 'ハセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神崎郡神河町川上', '28', '28446', '6793104', '兵庫県', 'ヒョウゴケン', '神崎郡神河町', 'カンザキグンカミカワチョウ', '川上', 'カワカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神崎郡神河町大河', '28', '28446', '6793111', '兵庫県', 'ヒョウゴケン', '神崎郡神河町', 'カンザキグンカミカワチョウ', '大河', 'オオカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神崎郡神河町鍛治', '28', '28446', '6793112', '兵庫県', 'ヒョウゴケン', '神崎郡神河町', 'カンザキグンカミカワチョウ', '鍛治', 'カジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神崎郡神河町野村', '28', '28446', '6793113', '兵庫県', 'ヒョウゴケン', '神崎郡神河町', 'カンザキグンカミカワチョウ', '野村', 'ノムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神崎郡神河町新野', '28', '28446', '6793114', '兵庫県', 'ヒョウゴケン', '神崎郡神河町', 'カンザキグンカミカワチョウ', '新野', 'ニイノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神崎郡神河町比延', '28', '28446', '6793115', '兵庫県', 'ヒョウゴケン', '神崎郡神河町', 'カンザキグンカミカワチョウ', '比延', 'ヒエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神崎郡神河町寺前', '28', '28446', '6793116', '兵庫県', 'ヒョウゴケン', '神崎郡神河町', 'カンザキグンカミカワチョウ', '寺前', 'テラマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神崎郡神河町上岩', '28', '28446', '6793121', '兵庫県', 'ヒョウゴケン', '神崎郡神河町', 'カンザキグンカミカワチョウ', '上岩', 'アゲイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神崎郡神河町高朝田', '28', '28446', '6793122', '兵庫県', 'ヒョウゴケン', '神崎郡神河町', 'カンザキグンカミカワチョウ', '高朝田', 'タカチョウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神崎郡神河町宮野', '28', '28446', '6793123', '兵庫県', 'ヒョウゴケン', '神崎郡神河町', 'カンザキグンカミカワチョウ', '宮野', 'ミヤノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神崎郡神河町南小田', '28', '28446', '6793124', '兵庫県', 'ヒョウゴケン', '神崎郡神河町', 'カンザキグンカミカワチョウ', '南小田', 'ミナミオダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県神崎郡神河町上小田', '28', '28446', '6793125', '兵庫県', 'ヒョウゴケン', '神崎郡神河町', 'カンザキグンカミカワチョウ', '上小田', 'カミオダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市生野町口銀谷', '28', '28225', '6793301', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '生野町口銀谷', 'イクノチョウクチガナヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市生野町円山', '28', '28225', '6793302', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '生野町円山', 'イクノチョウマルヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市生野町真弓', '28', '28225', '6793311', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '生野町真弓', 'イクノチョウマユミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市生野町新町', '28', '28225', '6793321', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '生野町新町', 'イクノチョウシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市生野町奥銀谷', '28', '28225', '6793322', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '生野町奥銀谷', 'イクノチョウオクガナヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市生野町竹原野', '28', '28225', '6793323', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '生野町竹原野', 'イクノチョウタケハラノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市生野町小野', '28', '28225', '6793324', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '生野町小野', 'イクノチョウコノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市生野町猪野々', '28', '28225', '6793325', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '生野町猪野々', 'イクノチョウイノノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市生野町白口', '28', '28225', '6793326', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '生野町白口', 'イクノチョウシラクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市生野町栃原', '28', '28225', '6793331', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '生野町栃原', 'イクノチョウトチハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市生野町川尻', '28', '28225', '6793332', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '生野町川尻', 'イクノチョウカワシリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市生野町黒川', '28', '28225', '6793341', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '生野町黒川', 'イクノチョウクロガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市物部', '28', '28225', '6793401', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '物部', 'モノノベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市桑市', '28', '28225', '6793402', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '桑市', 'クワイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市立脇', '28', '28225', '6793403', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '立脇', 'タチワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市沢', '28', '28225', '6793411', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '沢', 'サワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市山内', '28', '28225', '6793412', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '山内', 'ヤマウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市納座', '28', '28225', '6793413', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '納座', 'ノウザ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市川上', '28', '28225', '6793414', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '川上', 'カワカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市伊由市場', '28', '28225', '6793421', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '伊由市場', 'イユウイチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市石田', '28', '28225', '6793422', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '石田', 'イシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市多々良木', '28', '28225', '6793423', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '多々良木', 'タタラギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市立野', '28', '28225', '6793424', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '立野', 'タテノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市新井', '28', '28225', '6793431', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '新井', 'ニイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市山口', '28', '28225', '6793432', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '山口', 'ヤマグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市岩津', '28', '28225', '6793433', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '岩津', 'イワツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市羽渕', '28', '28225', '6793441', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '羽渕', 'ハブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市田路', '28', '28225', '6793442', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '田路', 'トウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市上八代', '28', '28225', '6793451', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '上八代', 'カミヤシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市八代', '28', '28225', '6793452', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '八代', 'ヤシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県朝来市佐嚢', '28', '28225', '6793453', '兵庫県', 'ヒョウゴケン', '朝来市', 'アサゴシ', '佐嚢', 'サノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市揖西町新宮', '28', '28229', '6794001', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '揖西町新宮', 'イッサイチョウシングウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市揖西町中垣内', '28', '28229', '6794002', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '揖西町中垣内', 'イッサイチョウナカガイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市揖西町小神', '28', '28229', '6794003', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '揖西町小神', 'イッサイチョウオガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市揖西町清水新', '28', '28229', '6794004', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '揖西町清水新', 'イッサイチョウシミズシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市揖西町清水', '28', '28229', '6794005', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '揖西町清水', 'イッサイチョウシミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市揖西町田井', '28', '28229', '6794006', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '揖西町田井', 'イッサイチョウタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市揖西町構', '28', '28229', '6794007', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '揖西町構', 'イッサイチョウカマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市揖西町芦原台', '28', '28229', '6794008', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '揖西町芦原台', 'イッサイチョウアシハラダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市揖西町佐江', '28', '28229', '6794011', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '揖西町佐江', 'イッサイチョウサエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市揖西町前地', '28', '28229', '6794012', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '揖西町前地', 'イッサイチョウマエジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市揖西町北山', '28', '28229', '6794013', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '揖西町北山', 'イッサイチョウキタヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市揖西町竹万', '28', '28229', '6794014', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '揖西町竹万', 'イッサイチョウチクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市揖西町龍子', '28', '28229', '6794015', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '揖西町龍子', 'イッサイチョウリュウコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市揖西町南山', '28', '28229', '6794016', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '揖西町南山', 'イッサイチョウミナミヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市揖西町土師', '28', '28229', '6794017', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '揖西町土師', 'イッサイチョウハゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市揖西町小犬丸', '28', '28229', '6794021', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '揖西町小犬丸', 'イッサイチョウコイヌマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市揖西町北沢', '28', '28229', '6794022', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '揖西町北沢', 'イッサイチョウキタサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市揖西町住吉', '28', '28229', '6794023', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '揖西町住吉', 'イッサイチョウスミヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市揖西町尾崎', '28', '28229', '6794024', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '揖西町尾崎', 'イッサイチョウオサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市揖西町小畑', '28', '28229', '6794025', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '揖西町小畑', 'イッサイチョウオバタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市揖西町竹原', '28', '28229', '6794026', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '揖西町竹原', 'イッサイチョウタケハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市揖西町長尾', '28', '28229', '6794027', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '揖西町長尾', 'イッサイチョウナガオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市', '28', '28229', '6794100', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('82837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市神岡町奥村', '28', '28229', '6794101', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '神岡町奥村', 'カミオカチョウオクムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市神岡町北横内', '28', '28229', '6794102', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '神岡町北横内', 'カミオカチョウキタヨコウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市神岡町上横内', '28', '28229', '6794103', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '神岡町上横内', 'カミオカチョウカミヨコウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市神岡町筒井', '28', '28229', '6794104', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '神岡町筒井', 'カミオカチョウツツイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市神岡町西鳥井', '28', '28229', '6794105', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '神岡町西鳥井', 'カミオカチョウニシトリイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市神岡町横内', '28', '28229', '6794106', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '神岡町横内', 'カミオカチョウヨコウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市神岡町西横内', '28', '28229', '6794107', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '神岡町西横内', 'カミオカチョウニシヨコウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市神岡町大住寺', '28', '28229', '6794108', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '神岡町大住寺', 'カミオカチョウダイジュウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市神岡町東觜崎', '28', '28229', '6794109', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '神岡町東觜崎', 'カミオカチョウヒガシハシサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市神岡町野部', '28', '28229', '6794111', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '神岡町野部', 'カミオカチョウノベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市神岡町追分', '28', '28229', '6794112', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '神岡町追分', 'カミオカチョウオイワケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市神岡町田中', '28', '28229', '6794113', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '神岡町田中', 'カミオカチョウタナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市神岡町寄井', '28', '28229', '6794114', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '神岡町寄井', 'カミオカチョウヨリイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市神岡町入野', '28', '28229', '6794115', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '神岡町入野', 'カミオカチョウイリノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市神岡町沢田', '28', '28229', '6794116', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '神岡町沢田', 'カミオカチョウサワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市龍野町島田', '28', '28229', '6794121', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '龍野町島田', 'タツノチョウシマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市龍野町日飼', '28', '28229', '6794122', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '龍野町日飼', 'タツノチョウヒガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市龍野町片山', '28', '28229', '6794123', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '龍野町片山', 'タツノチョウカタヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市龍野町中井', '28', '28229', '6794124', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '龍野町中井', 'タツノチョウナカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市龍野町末政', '28', '28229', '6794125', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '龍野町末政', 'タツノチョウスエマサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市龍野町中村', '28', '28229', '6794126', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '龍野町中村', 'タツノチョウナカムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市龍野町宮脇', '28', '28229', '6794127', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '龍野町宮脇', 'タツノチョウミヤワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市龍野町小宅北', '28', '28229', '6794128', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '龍野町小宅北', 'タツノチョウオヤケキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市龍野町堂本', '28', '28229', '6794129', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '龍野町堂本', 'タツノチョウドウモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市誉田町長真', '28', '28229', '6794130', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '誉田町長真', 'ホンダチョウナガザネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市誉田町内山', '28', '28229', '6794131', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '誉田町内山', 'ホンダチョウウチヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市誉田町福田', '28', '28229', '6794132', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '誉田町福田', 'ホンダチョウフクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市誉田町誉', '28', '28229', '6794133', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '誉田町誉', 'ホンダチョウホマレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市誉田町広山', '28', '28229', '6794134', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '誉田町広山', 'ホンダチョウヒロヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市誉田町高駄', '28', '28229', '6794135', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '誉田町高駄', 'ホンダチョウタカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市誉田町井上', '28', '28229', '6794136', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '誉田町井上', 'ホンダチョウイノカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市誉田町片吹', '28', '28229', '6794137', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '誉田町片吹', 'ホンダチョウカタブキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市誉田町下沖', '28', '28229', '6794138', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '誉田町下沖', 'ホンダチョウシモオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市誉田町上沖', '28', '28229', '6794139', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '誉田町上沖', 'ホンダチョウカミオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市揖保町栄', '28', '28229', '6794141', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '揖保町栄', 'イボチョウサカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市揖保町松原', '28', '28229', '6794142', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '揖保町松原', 'イボチョウマツバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市揖保町東用', '28', '28229', '6794143', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '揖保町東用', 'イボチョウトウヨウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市揖保町真砂', '28', '28229', '6794144', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '揖保町真砂', 'イボチョウマサゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市揖保町萩原', '28', '28229', '6794145', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '揖保町萩原', 'イボチョウハイバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市揖保町今市', '28', '28229', '6794146', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '揖保町今市', 'イボチョウイマイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市揖保町山下', '28', '28229', '6794151', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '揖保町山下', 'イボチョウヤマシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市揖保町中臣', '28', '28229', '6794152', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '揖保町中臣', 'イボチョウナカジン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市揖保町門前', '28', '28229', '6794153', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '揖保町門前', 'イボチョウモンゼン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市揖保町西構', '28', '28229', '6794154', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '揖保町西構', 'イボチョウニシガマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市揖保町揖保中', '28', '28229', '6794155', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '揖保町揖保中', 'イボチョウイボナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市揖保町揖保上', '28', '28229', '6794156', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '揖保町揖保上', 'イボチョウイボカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市龍野町日山', '28', '28229', '6794161', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '龍野町日山', 'タツノチョウヒヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市龍野町下霞城', '28', '28229', '6794162', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '龍野町下霞城', 'タツノチョウシモカジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市龍野町福の神', '28', '28229', '6794163', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '龍野町福の神', 'タツノチョウフクノカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市龍野町立町', '28', '28229', '6794164', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '龍野町立町', 'タツノチョウタテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市龍野町本町', '28', '28229', '6794165', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '龍野町本町', 'タツノチョウホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市龍野町川原町', '28', '28229', '6794166', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '龍野町川原町', 'タツノチョウカワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市龍野町富永', '28', '28229', '6794167', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '龍野町富永', 'タツノチョウトミナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市龍野町四箇', '28', '28229', '6794168', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '龍野町四箇', 'タツノチョウヨッカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市龍野町大道', '28', '28229', '6794169', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '龍野町大道', 'タツノチョウダイドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市龍野町中霞城', '28', '28229', '6794170', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '龍野町中霞城', 'タツノチョウナカカジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市龍野町北龍野', '28', '28229', '6794171', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '龍野町北龍野', 'タツノチョウキタタツノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市龍野町上川原', '28', '28229', '6794172', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '龍野町上川原', 'タツノチョウカミガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市龍野町門の外', '28', '28229', '6794173', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '龍野町門の外', 'タツノチョウモンノソト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市龍野町柳原', '28', '28229', '6794174', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '龍野町柳原', 'タツノチョウヤナギハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市龍野町旭町', '28', '28229', '6794175', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '龍野町旭町', 'タツノチョウアサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市龍野町水神町', '28', '28229', '6794176', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '龍野町水神町', 'タツノチョウスイジンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市龍野町下川原', '28', '28229', '6794177', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '龍野町下川原', 'タツノチョウシモガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市龍野町大手', '28', '28229', '6794178', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '龍野町大手', 'タツノチョウオオテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市龍野町上霞城', '28', '28229', '6794179', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '龍野町上霞城', 'タツノチョウカミカジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市林田町久保', '28', '28201', '6794201', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '林田町久保', 'ハヤシダチョウクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市林田町下構', '28', '28201', '6794202', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '林田町下構', 'ハヤシダチョウシモカマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市林田町中構', '28', '28201', '6794203', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '林田町中構', 'ハヤシダチョウナカカマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市林田町上構', '28', '28201', '6794204', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '林田町上構', 'ハヤシダチョウカミカマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市林田町新町', '28', '28201', '6794205', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '林田町新町', 'ハヤシダチョウシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市林田町林田', '28', '28201', '6794206', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '林田町林田', 'ハヤシダチョウハヤシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市林田町六九谷', '28', '28201', '6794211', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '林田町六九谷', 'ハヤシダチョウムクダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市林田町松山', '28', '28201', '6794212', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '林田町松山', 'ハヤシダチョウマツヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市林田町山田', '28', '28201', '6794213', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '林田町山田', 'ハヤシダチョウヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市林田町中山下', '28', '28201', '6794214', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '林田町中山下', 'ハヤシダチョウナカヤマシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市林田町八幡', '28', '28201', '6794215', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '林田町八幡', 'ハヤシダチョウヤハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市林田町林谷', '28', '28201', '6794221', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '林田町林谷', 'ハヤシダチョウハヤシダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市林田町口佐見', '28', '28201', '6794222', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '林田町口佐見', 'ハヤシダチョウクチサミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市林田町奥佐見', '28', '28201', '6794223', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '林田町奥佐見', 'ハヤシダチョウオクサミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市林田町大堤', '28', '28201', '6794231', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '林田町大堤', 'ハヤシダチョウオオヅツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市林田町上伊勢', '28', '28201', '6794232', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '林田町上伊勢', 'ハヤシダチョウカミイセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県姫路市林田町下伊勢', '28', '28201', '6794233', '兵庫県', 'ヒョウゴケン', '姫路市', 'ヒメジシ', '林田町下伊勢', 'ハヤシダチョウシモイセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市新宮町篠首', '28', '28229', '6794301', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '新宮町篠首', 'シングウチョウシノクビ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市新宮町香山', '28', '28229', '6794302', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '新宮町香山', 'シングウチョウコウヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市新宮町上笹', '28', '28229', '6794303', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '新宮町上笹', 'シングウチョウカミササ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市新宮町下笹', '28', '28229', '6794304', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '新宮町下笹', 'シングウチョウシモササ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市新宮町吉島', '28', '28229', '6794305', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '新宮町吉島', 'シングウチョウヨシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市新宮町宮内', '28', '28229', '6794311', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '新宮町宮内', 'シングウチョウミヤウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市新宮町下野', '28', '28229', '6794312', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '新宮町下野', 'シングウチョウシモノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市新宮町新宮', '28', '28229', '6794313', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '新宮町新宮', 'シングウチョウシングウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市新宮町曽我井', '28', '28229', '6794314', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '新宮町曽我井', 'シングウチョウソガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市新宮町井野原', '28', '28229', '6794315', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '新宮町井野原', 'シングウチョウイノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市新宮町芝田', '28', '28229', '6794316', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '新宮町芝田', 'シングウチョウコゲタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市新宮町段之上', '28', '28229', '6794321', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '新宮町段之上', 'シングウチョウダンノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市新宮町仙正', '28', '28229', '6794322', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '新宮町仙正', 'シングウチョウセンショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市新宮町北村', '28', '28229', '6794323', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '新宮町北村', 'シングウチョウキタムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市新宮町觜崎', '28', '28229', '6794324', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '新宮町觜崎', 'シングウチョウハシサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市新宮町佐野', '28', '28229', '6794325', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '新宮町佐野', 'シングウチョウサノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市新宮町船渡', '28', '28229', '6794326', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '新宮町船渡', 'シングウチョウフナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市新宮町中野庄', '28', '28229', '6794327', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '新宮町中野庄', 'シングウチョウナカノショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市新宮町市野保', '28', '28229', '6794331', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '新宮町市野保', 'シングウチョウイチノホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市新宮町馬立', '28', '28229', '6794332', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '新宮町馬立', 'シングウチョウウマタテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市新宮町下野田', '28', '28229', '6794333', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '新宮町下野田', 'シングウチョウシモノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市新宮町能地', '28', '28229', '6794341', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '新宮町能地', 'シングウチョウノウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市新宮町平野', '28', '28229', '6794342', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '新宮町平野', 'シングウチョウヒラノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市新宮町大屋', '28', '28229', '6794343', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '新宮町大屋', 'シングウチョウオオヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市新宮町善定', '28', '28229', '6794344', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '新宮町善定', 'シングウチョウゼンジョ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市新宮町福栖', '28', '28229', '6794345', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '新宮町福栖', 'シングウチョウフクス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市新宮町千本', '28', '28229', '6794346', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '新宮町千本', 'シングウチョウセンボン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県佐用郡佐用町上本郷', '28', '28501', '6795131', '兵庫県', 'ヒョウゴケン', '佐用郡佐用町', 'サヨウグンサヨウチョウ', '上本郷', 'カミホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県佐用郡佐用町下本郷', '28', '28501', '6795132', '兵庫県', 'ヒョウゴケン', '佐用郡佐用町', 'サヨウグンサヨウチョウ', '下本郷', 'シモホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県佐用郡佐用町三日月', '28', '28501', '6795133', '兵庫県', 'ヒョウゴケン', '佐用郡佐用町', 'サヨウグンサヨウチョウ', '三日月', 'ミカヅキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県佐用郡佐用町乃井野', '28', '28501', '6795134', '兵庫県', 'ヒョウゴケン', '佐用郡佐用町', 'サヨウグンサヨウチョウ', '乃井野', 'ノイノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県佐用郡佐用町春哉', '28', '28501', '6795135', '兵庫県', 'ヒョウゴケン', '佐用郡佐用町', 'サヨウグンサヨウチョウ', '春哉', 'ハルカナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県佐用郡佐用町志文', '28', '28501', '6795136', '兵庫県', 'ヒョウゴケン', '佐用郡佐用町', 'サヨウグンサヨウチョウ', '志文', 'シブミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県佐用郡佐用町真宗', '28', '28501', '6795137', '兵庫県', 'ヒョウゴケン', '佐用郡佐用町', 'サヨウグンサヨウチョウ', '真宗', 'サノムネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県佐用郡佐用町廣山', '28', '28501', '6795141', '兵庫県', 'ヒョウゴケン', '佐用郡佐用町', 'サヨウグンサヨウチョウ', '廣山', 'ヒロヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県佐用郡佐用町弦谷', '28', '28501', '6795142', '兵庫県', 'ヒョウゴケン', '佐用郡佐用町', 'サヨウグンサヨウチョウ', '弦谷', 'ツルダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県佐用郡佐用町三原', '28', '28501', '6795143', '兵庫県', 'ヒョウゴケン', '佐用郡佐用町', 'サヨウグンサヨウチョウ', '三原', 'ミハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県佐用郡佐用町三ツ尾', '28', '28501', '6795144', '兵庫県', 'ヒョウゴケン', '佐用郡佐用町', 'サヨウグンサヨウチョウ', '三ツ尾', 'ミツオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県佐用郡佐用町大畑', '28', '28501', '6795145', '兵庫県', 'ヒョウゴケン', '佐用郡佐用町', 'サヨウグンサヨウチョウ', '大畑', 'オオハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県佐用郡佐用町大下り', '28', '28501', '6795146', '兵庫県', 'ヒョウゴケン', '佐用郡佐用町', 'サヨウグンサヨウチョウ', '大下り', 'オオサガリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県佐用郡佐用町末廣', '28', '28501', '6795147', '兵庫県', 'ヒョウゴケン', '佐用郡佐用町', 'サヨウグンサヨウチョウ', '末廣', 'スエヒロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県佐用郡佐用町光都', '28', '28501', '6795148', '兵庫県', 'ヒョウゴケン', '佐用郡佐用町', 'サヨウグンサヨウチョウ', '光都', 'コウト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市新宮町奥小屋', '28', '28229', '6795151', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '新宮町奥小屋', 'シングウチョウオクゴヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市新宮町牧', '28', '28229', '6795152', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '新宮町牧', 'シングウチョウマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市新宮町時重', '28', '28229', '6795153', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '新宮町時重', 'シングウチョウトキシゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市新宮町鍛冶屋', '28', '28229', '6795154', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '新宮町鍛冶屋', 'シングウチョウカジヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市新宮町栗町', '28', '28229', '6795155', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '新宮町栗町', 'シングウチョウクリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市新宮町下莇原', '28', '28229', '6795161', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '新宮町下莇原', 'シングウチョウシモアザワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市新宮町上莇原', '28', '28229', '6795162', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '新宮町上莇原', 'シングウチョウカミアザワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市新宮町角亀', '28', '28229', '6795163', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '新宮町角亀', 'シングウチョウツノガメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市新宮町二柏野', '28', '28229', '6795164', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '新宮町二柏野', 'シングウチョウフタツガイノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県たつの市新宮町光都', '28', '28229', '6795165', '兵庫県', 'ヒョウゴケン', 'たつの市', 'タツノシ', '新宮町光都', 'シングウチョウコウト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県佐用郡佐用町多賀', '28', '28501', '6795201', '兵庫県', 'ヒョウゴケン', '佐用郡佐用町', 'サヨウグンサヨウチョウ', '多賀', 'タガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県佐用郡佐用町中島', '28', '28501', '6795202', '兵庫県', 'ヒョウゴケン', '佐用郡佐用町', 'サヨウグンサヨウチョウ', '中島', 'ナカシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県佐用郡佐用町米田', '28', '28501', '6795203', '兵庫県', 'ヒョウゴケン', '佐用郡佐用町', 'サヨウグンサヨウチョウ', '米田', 'ヨネダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県佐用郡佐用町小山', '28', '28501', '6795204', '兵庫県', 'ヒョウゴケン', '佐用郡佐用町', 'サヨウグンサヨウチョウ', '小山', 'コヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県佐用郡佐用町安川', '28', '28501', '6795205', '兵庫県', 'ヒョウゴケン', '佐用郡佐用町', 'サヨウグンサヨウチョウ', '安川', 'ヤスカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県佐用郡佐用町土井', '28', '28501', '6795206', '兵庫県', 'ヒョウゴケン', '佐用郡佐用町', 'サヨウグンサヨウチョウ', '土井', 'ドイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県佐用郡佐用町宝蔵寺', '28', '28501', '6795207', '兵庫県', 'ヒョウゴケン', '佐用郡佐用町', 'サヨウグンサヨウチョウ', '宝蔵寺', 'ホウゾウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県佐用郡佐用町下徳久', '28', '28501', '6795211', '兵庫県', 'ヒョウゴケン', '佐用郡佐用町', 'サヨウグンサヨウチョウ', '下徳久', 'シモトクサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県佐用郡佐用町林崎', '28', '28501', '6795212', '兵庫県', 'ヒョウゴケン', '佐用郡佐用町', 'サヨウグンサヨウチョウ', '林崎', 'ハヤシサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県佐用郡佐用町東徳久', '28', '28501', '6795213', '兵庫県', 'ヒョウゴケン', '佐用郡佐用町', 'サヨウグンサヨウチョウ', '東徳久', 'ヒガシトクサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県佐用郡佐用町西徳久', '28', '28501', '6795214', '兵庫県', 'ヒョウゴケン', '佐用郡佐用町', 'サヨウグンサヨウチョウ', '西徳久', 'ニシトクサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県佐用郡佐用町平松', '28', '28501', '6795215', '兵庫県', 'ヒョウゴケン', '佐用郡佐用町', 'サヨウグンサヨウチョウ', '平松', 'ヒラマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県佐用郡佐用町漆野', '28', '28501', '6795221', '兵庫県', 'ヒョウゴケン', '佐用郡佐用町', 'サヨウグンサヨウチョウ', '漆野', 'ウルシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県佐用郡佐用町西下野', '28', '28501', '6795222', '兵庫県', 'ヒョウゴケン', '佐用郡佐用町', 'サヨウグンサヨウチョウ', '西下野', 'ニシシモノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県佐用郡佐用町下三河', '28', '28501', '6795223', '兵庫県', 'ヒョウゴケン', '佐用郡佐用町', 'サヨウグンサヨウチョウ', '下三河', 'シモミカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県佐用郡佐用町中三河', '28', '28501', '6795224', '兵庫県', 'ヒョウゴケン', '佐用郡佐用町', 'サヨウグンサヨウチョウ', '中三河', 'ナカミカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県佐用郡佐用町上三河', '28', '28501', '6795225', '兵庫県', 'ヒョウゴケン', '佐用郡佐用町', 'サヨウグンサヨウチョウ', '上三河', 'カミミカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県佐用郡佐用町河崎', '28', '28501', '6795226', '兵庫県', 'ヒョウゴケン', '佐用郡佐用町', 'サヨウグンサヨウチョウ', '河崎', 'コウザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('82998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県佐用郡佐用町船越', '28', '28501', '6795227', '兵庫県', 'ヒョウゴケン', '佐用郡佐用町', 'サヨウグンサヨウチョウ', '船越', 'フナコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県佐用郡佐用町', '28', '28501', '6795300', '兵庫県', 'ヒョウゴケン', '佐用郡佐用町', 'サヨウグンサヨウチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('83001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県佐用郡佐用町佐用', '28', '28501', '6795301', '兵庫県', 'ヒョウゴケン', '佐用郡佐用町', 'サヨウグンサヨウチョウ', '佐用', 'サヨウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県佐用郡佐用町山脇', '28', '28501', '6795302', '兵庫県', 'ヒョウゴケン', '佐用郡佐用町', 'サヨウグンサヨウチョウ', '山脇', 'ヤマワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県佐用郡佐用町真盛', '28', '28501', '6795303', '兵庫県', 'ヒョウゴケン', '佐用郡佐用町', 'サヨウグンサヨウチョウ', '真盛', 'サネモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県佐用郡佐用町山田', '28', '28501', '6795304', '兵庫県', 'ヒョウゴケン', '佐用郡佐用町', 'サヨウグンサヨウチョウ', '山田', 'ヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県佐用郡佐用町長尾', '28', '28501', '6795305', '兵庫県', 'ヒョウゴケン', '佐用郡佐用町', 'サヨウグンサヨウチョウ', '長尾', 'ナガオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県佐用郡佐用町本位田', '28', '28501', '6795306', '兵庫県', 'ヒョウゴケン', '佐用郡佐用町', 'サヨウグンサヨウチョウ', '本位田', 'ホンイデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県佐用郡佐用町円応寺', '28', '28501', '6795307', '兵庫県', 'ヒョウゴケン', '佐用郡佐用町', 'サヨウグンサヨウチョウ', '円応寺', 'エンノウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県佐用郡佐用町福沢', '28', '28501', '6795311', '兵庫県', 'ヒョウゴケン', '佐用郡佐用町', 'サヨウグンサヨウチョウ', '福沢', 'フクサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県佐用郡佐用町仁方', '28', '28501', '6795312', '兵庫県', 'ヒョウゴケン', '佐用郡佐用町', 'サヨウグンサヨウチョウ', '仁方', 'ニガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県佐用郡佐用町西河内', '28', '28501', '6795313', '兵庫県', 'ヒョウゴケン', '佐用郡佐用町', 'サヨウグンサヨウチョウ', '西河内', 'ニシガイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県佐用郡佐用町大木谷', '28', '28501', '6795314', '兵庫県', 'ヒョウゴケン', '佐用郡佐用町', 'サヨウグンサヨウチョウ', '大木谷', 'オオキダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県佐用郡佐用町淀', '28', '28501', '6795315', '兵庫県', 'ヒョウゴケン', '佐用郡佐用町', 'サヨウグンサヨウチョウ', '淀', 'ヨド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県佐用郡佐用町豊福', '28', '28501', '6795316', '兵庫県', 'ヒョウゴケン', '佐用郡佐用町', 'サヨウグンサヨウチョウ', '豊福', 'トヨフク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県佐用郡佐用町末包', '28', '28501', '6795317', '兵庫県', 'ヒョウゴケン', '佐用郡佐用町', 'サヨウグンサヨウチョウ', '末包', 'スエカネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県佐用郡佐用町東中山', '28', '28501', '6795318', '兵庫県', 'ヒョウゴケン', '佐用郡佐用町', 'サヨウグンサヨウチョウ', '東中山', 'ヒガシナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県佐用郡佐用町大畠', '28', '28501', '6795319', '兵庫県', 'ヒョウゴケン', '佐用郡佐用町', 'サヨウグンサヨウチョウ', '大畠', 'オオバタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県佐用郡佐用町下石井', '28', '28501', '6795321', '兵庫県', 'ヒョウゴケン', '佐用郡佐用町', 'サヨウグンサヨウチョウ', '下石井', 'シモイシイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県佐用郡佐用町上石井', '28', '28501', '6795322', '兵庫県', 'ヒョウゴケン', '佐用郡佐用町', 'サヨウグンサヨウチョウ', '上石井', 'カミイシイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県佐用郡佐用町若州', '28', '28501', '6795323', '兵庫県', 'ヒョウゴケン', '佐用郡佐用町', 'サヨウグンサヨウチョウ', '若州', 'ワカス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県佐用郡佐用町奥海', '28', '28501', '6795324', '兵庫県', 'ヒョウゴケン', '佐用郡佐用町', 'サヨウグンサヨウチョウ', '奥海', 'オネミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県佐用郡佐用町水根', '28', '28501', '6795325', '兵庫県', 'ヒョウゴケン', '佐用郡佐用町', 'サヨウグンサヨウチョウ', '水根', 'ミズネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県佐用郡佐用町平福', '28', '28501', '6795331', '兵庫県', 'ヒョウゴケン', '佐用郡佐用町', 'サヨウグンサヨウチョウ', '平福', 'ヒラフク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県佐用郡佐用町延吉', '28', '28501', '6795332', '兵庫県', 'ヒョウゴケン', '佐用郡佐用町', 'サヨウグンサヨウチョウ', '延吉', 'ノブヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県佐用郡佐用町庵', '28', '28501', '6795333', '兵庫県', 'ヒョウゴケン', '佐用郡佐用町', 'サヨウグンサヨウチョウ', '庵', 'イオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県佐用郡佐用町桑野', '28', '28501', '6795334', '兵庫県', 'ヒョウゴケン', '佐用郡佐用町', 'サヨウグンサヨウチョウ', '桑野', 'クワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県佐用郡佐用町海内', '28', '28501', '6795335', '兵庫県', 'ヒョウゴケン', '佐用郡佐用町', 'サヨウグンサヨウチョウ', '海内', 'ミウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県佐用郡佐用町横坂', '28', '28501', '6795341', '兵庫県', 'ヒョウゴケン', '佐用郡佐用町', 'サヨウグンサヨウチョウ', '横坂', 'ヨコサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県佐用郡佐用町宗行', '28', '28501', '6795342', '兵庫県', 'ヒョウゴケン', '佐用郡佐用町', 'サヨウグンサヨウチョウ', '宗行', 'ムネユキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県佐用郡佐用町口長谷', '28', '28501', '6795343', '兵庫県', 'ヒョウゴケン', '佐用郡佐用町', 'サヨウグンサヨウチョウ', '口長谷', 'クチナガタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県佐用郡佐用町奥長谷', '28', '28501', '6795344', '兵庫県', 'ヒョウゴケン', '佐用郡佐用町', 'サヨウグンサヨウチョウ', '奥長谷', 'オクナガタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県佐用郡佐用町奥金近', '28', '28501', '6795345', '兵庫県', 'ヒョウゴケン', '佐用郡佐用町', 'サヨウグンサヨウチョウ', '奥金近', 'オクカネチカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県佐用郡佐用町口金近', '28', '28501', '6795346', '兵庫県', 'ヒョウゴケン', '佐用郡佐用町', 'サヨウグンサヨウチョウ', '口金近', 'クチカネチカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県佐用郡佐用町桜山', '28', '28501', '6795501', '兵庫県', 'ヒョウゴケン', '佐用郡佐用町', 'サヨウグンサヨウチョウ', '桜山', 'サクラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県佐用郡佐用町才金', '28', '28501', '6795502', '兵庫県', 'ヒョウゴケン', '佐用郡佐用町', 'サヨウグンサヨウチョウ', '才金', 'サイカネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県佐用郡佐用町本郷', '28', '28501', '6795503', '兵庫県', 'ヒョウゴケン', '佐用郡佐用町', 'サヨウグンサヨウチョウ', '本郷', 'ホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県佐用郡佐用町大垣内', '28', '28501', '6795504', '兵庫県', 'ヒョウゴケン', '佐用郡佐用町', 'サヨウグンサヨウチョウ', '大垣内', 'オオガイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県佐用郡佐用町皆田', '28', '28501', '6795505', '兵庫県', 'ヒョウゴケン', '佐用郡佐用町', 'サヨウグンサヨウチョウ', '皆田', 'カイタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県佐用郡佐用町福中', '28', '28501', '6795511', '兵庫県', 'ヒョウゴケン', '佐用郡佐用町', 'サヨウグンサヨウチョウ', '福中', 'フクナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県佐用郡佐用町南中山', '28', '28501', '6795512', '兵庫県', 'ヒョウゴケン', '佐用郡佐用町', 'サヨウグンサヨウチョウ', '南中山', 'ミナミナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県佐用郡佐用町金屋', '28', '28501', '6795513', '兵庫県', 'ヒョウゴケン', '佐用郡佐用町', 'サヨウグンサヨウチョウ', '金屋', 'カナヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県佐用郡佐用町福吉', '28', '28501', '6795514', '兵庫県', 'ヒョウゴケン', '佐用郡佐用町', 'サヨウグンサヨウチョウ', '福吉', 'フクヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県佐用郡佐用町早瀬', '28', '28501', '6795521', '兵庫県', 'ヒョウゴケン', '佐用郡佐用町', 'サヨウグンサヨウチョウ', '早瀬', 'ハヤセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県佐用郡佐用町仁位', '28', '28501', '6795522', '兵庫県', 'ヒョウゴケン', '佐用郡佐用町', 'サヨウグンサヨウチョウ', '仁位', 'ニイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県佐用郡佐用町上月', '28', '28501', '6795523', '兵庫県', 'ヒョウゴケン', '佐用郡佐用町', 'サヨウグンサヨウチョウ', '上月', 'コウヅキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県佐用郡佐用町寄延', '28', '28501', '6795524', '兵庫県', 'ヒョウゴケン', '佐用郡佐用町', 'サヨウグンサヨウチョウ', '寄延', 'ヨリノブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県佐用郡佐用町目高', '28', '28501', '6795525', '兵庫県', 'ヒョウゴケン', '佐用郡佐用町', 'サヨウグンサヨウチョウ', '目高', 'メタカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県佐用郡佐用町宇根', '28', '28501', '6795531', '兵庫県', 'ヒョウゴケン', '佐用郡佐用町', 'サヨウグンサヨウチョウ', '宇根', 'ウネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県佐用郡佐用町須安', '28', '28501', '6795532', '兵庫県', 'ヒョウゴケン', '佐用郡佐用町', 'サヨウグンサヨウチョウ', '須安', 'スヤス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県佐用郡佐用町力万', '28', '28501', '6795533', '兵庫県', 'ヒョウゴケン', '佐用郡佐用町', 'サヨウグンサヨウチョウ', '力万', 'リキマン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県佐用郡佐用町西大畠', '28', '28501', '6795534', '兵庫県', 'ヒョウゴケン', '佐用郡佐用町', 'サヨウグンサヨウチョウ', '西大畠', 'ニシオオバタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県佐用郡佐用町小日山', '28', '28501', '6795535', '兵庫県', 'ヒョウゴケン', '佐用郡佐用町', 'サヨウグンサヨウチョウ', '小日山', 'コビヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県佐用郡佐用町久崎', '28', '28501', '6795641', '兵庫県', 'ヒョウゴケン', '佐用郡佐用町', 'サヨウグンサヨウチョウ', '久崎', 'クザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県佐用郡佐用町円光寺', '28', '28501', '6795642', '兵庫県', 'ヒョウゴケン', '佐用郡佐用町', 'サヨウグンサヨウチョウ', '円光寺', 'エンコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県佐用郡佐用町下秋里', '28', '28501', '6795643', '兵庫県', 'ヒョウゴケン', '佐用郡佐用町', 'サヨウグンサヨウチョウ', '下秋里', 'シモアキサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県佐用郡佐用町上秋里', '28', '28501', '6795644', '兵庫県', 'ヒョウゴケン', '佐用郡佐用町', 'サヨウグンサヨウチョウ', '上秋里', 'カミアキサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県佐用郡佐用町西新宿', '28', '28501', '6795645', '兵庫県', 'ヒョウゴケン', '佐用郡佐用町', 'サヨウグンサヨウチョウ', '西新宿', 'ニシシンジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県佐用郡佐用町大日山', '28', '28501', '6795646', '兵庫県', 'ヒョウゴケン', '佐用郡佐用町', 'サヨウグンサヨウチョウ', '大日山', 'オオビヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県佐用郡佐用町櫛田', '28', '28501', '6795651', '兵庫県', 'ヒョウゴケン', '佐用郡佐用町', 'サヨウグンサヨウチョウ', '櫛田', 'クシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県佐用郡佐用町家内', '28', '28501', '6795652', '兵庫県', 'ヒョウゴケン', '佐用郡佐用町', 'サヨウグンサヨウチョウ', '家内', 'ケナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県佐用郡佐用町小赤松', '28', '28501', '6795653', '兵庫県', 'ヒョウゴケン', '佐用郡佐用町', 'サヨウグンサヨウチョウ', '小赤松', 'コアカマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '兵庫県佐用郡佐用町大酒', '28', '28501', '6795654', '兵庫県', 'ヒョウゴケン', '佐用郡佐用町', 'サヨウグンサヨウチョウ', '大酒', 'オオザケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市', '01', '01210', '0680000', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('83069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市', '31', '31201', '6800000', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('83070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市浜坂', '31', '31201', '6800001', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '浜坂', 'ハマサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市浜坂東', '31', '31201', '6800002', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '浜坂東', 'ハマサカヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市覚寺', '31', '31201', '6800003', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '覚寺', 'カクジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市北園', '31', '31201', '6800004', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '北園', 'キタゾノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市円護寺', '31', '31201', '6800005', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '円護寺', 'エンゴジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市丸山町', '31', '31201', '6800006', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '丸山町', 'マルヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市湯所町', '31', '31201', '6800007', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '湯所町', 'ユトコロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市山城町', '31', '31201', '6800008', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '山城町', 'ヤマシロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市1条東', '01', '01210', '0680001', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '1条東', '01ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市東町', '31', '31201', '6800011', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '東町', 'ヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市栗谷町', '31', '31201', '6800012', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '栗谷町', 'クリタニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市江崎町', '31', '31201', '6800013', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '江崎町', 'エザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市馬場町', '31', '31201', '6800014', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '馬場町', 'ババノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市上町', '31', '31201', '6800015', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '上町', 'ウエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市中町', '31', '31201', '6800016', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '中町', 'ナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市尚徳町', '31', '31201', '6800017', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '尚徳町', 'ショウトクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市2条東', '01', '01210', '0680002', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '2条東', '02ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市材木町', '31', '31201', '6800021', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '材木町', 'ザイモクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市西町', '31', '31201', '6800022', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '西町', 'ニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市片原', '31', '31201', '6800023', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '片原', 'カタハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市玄好町', '31', '31201', '6800024', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '玄好町', 'ゲンコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市3条東', '01', '01210', '0680003', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '3条東', '03ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市本町', '31', '31201', '6800031', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市茶町', '31', '31201', '6800032', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '茶町', 'チャマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市二階町', '31', '31201', '6800033', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '二階町', 'ニカイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市元魚町', '31', '31201', '6800034', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '元魚町', 'モトウオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市新町', '31', '31201', '6800035', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市川端', '31', '31201', '6800036', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '川端', 'カワバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市元町', '31', '31201', '6800037', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '元町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市4条東', '01', '01210', '0680004', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '4条東', '04ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市掛出町', '31', '31201', '6800041', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '掛出町', 'カケダシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市庖丁人町', '31', '31201', '6800042', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '庖丁人町', 'ホウチョウニンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市大榎町', '31', '31201', '6800043', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '大榎町', 'オオエノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市御弓町', '31', '31201', '6800044', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '御弓町', 'オユミノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市大工町頭', '31', '31201', '6800045', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '大工町頭', 'ダイクマチガシラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市元大工町', '31', '31201', '6800046', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '元大工町', 'モトダイクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市上魚町', '31', '31201', '6800047', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '上魚町', 'カミウオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市5条東', '01', '01210', '0680005', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '5条東', '05ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市若桜町', '31', '31201', '6800051', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '若桜町', 'ワカサマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市鍛冶町', '31', '31201', '6800052', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '鍛冶町', 'カジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市寺町', '31', '31201', '6800053', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '寺町', 'テラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市桶屋町', '31', '31201', '6800054', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '桶屋町', 'オケヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市戎町', '31', '31201', '6800055', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '戎町', 'エビスマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市職人町', '31', '31201', '6800056', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '職人町', 'ショクニンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市6条東', '01', '01210', '0680006', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '6条東', '06ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市立川町', '31', '31201', '6800061', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '立川町', 'タチカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市吉方町', '31', '31201', '6800062', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '吉方町', 'ヨシカタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市7条東', '01', '01210', '0680007', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '7条東', '07ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市百谷', '31', '31201', '6800071', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '百谷', 'モモダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市滝山', '31', '31201', '6800072', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '滝山', 'タキヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市小西谷', '31', '31201', '6800073', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '小西谷', 'コザイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市卯垣', '31', '31201', '6800074', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '卯垣', 'ボウガキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市8条東', '01', '01210', '0680008', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '8条東', '08ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市岩倉', '31', '31201', '6800081', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '岩倉', 'イワクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市9条東', '01', '01210', '0680009', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '9条東', '09ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市10条東', '01', '01210', '0680010', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '10条東', '10ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市11条東', '01', '01210', '0680011', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '11条東', '11ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市12条東', '01', '01210', '0680012', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '12条東', '12ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市東町1条', '01', '01210', '0680013', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '東町1条', 'ヒガシマチ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市国府町高岡', '31', '31201', '6800131', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '国府町高岡', 'コクフチョウタカオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市国府町神垣', '31', '31201', '6800132', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '国府町神垣', 'コクフチョウコウガケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市国府町山根', '31', '31201', '6800133', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '国府町山根', 'コクフチョウヤマネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市国府町清水', '31', '31201', '6800134', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '国府町清水', 'コクフチョウスンズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市国府町谷', '31', '31201', '6800135', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '国府町谷', 'コクフチョウタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市国府町糸谷', '31', '31201', '6800136', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '国府町糸谷', 'コクフチョウイトタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市東町2条', '01', '01210', '0680014', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '東町2条', 'ヒガシマチ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市国府町美歎', '31', '31201', '6800141', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '国府町美歎', 'コクフチョウミタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市国府町麻生', '31', '31201', '6800142', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '国府町麻生', 'コクフチョウアソウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市国府町玉鉾', '31', '31201', '6800143', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '国府町玉鉾', 'コクフチョウタマボコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市国府町岡益', '31', '31201', '6800144', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '国府町岡益', 'コクフチョウオカマス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市国府町広西', '31', '31201', '6800145', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '国府町広西', 'コクフチョウヒロセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市国府町町屋', '31', '31201', '6800146', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '国府町町屋', 'コクフチョウマチヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市東町', '01', '01210', '0680015', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '東町', 'ヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市国府町宮下', '31', '31201', '6800151', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '国府町宮下', 'コクフチョウミヤノシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市国府町庁', '31', '31201', '6800152', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '国府町庁', 'コクフチョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市国府町法花寺', '31', '31201', '6800153', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '国府町法花寺', 'コクフチョウホッケジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市国府町三代寺', '31', '31201', '6800154', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '国府町三代寺', 'コクフチョウサンダイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市国府町国分寺', '31', '31201', '6800155', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '国府町国分寺', 'コクフチョウコクブンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市国府町中郷', '31', '31201', '6800156', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '国府町中郷', 'コクフチョウチュウゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市稔町', '01', '01210', '0680016', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '稔町', 'ミノリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市国府町雨滝', '31', '31201', '6800201', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '国府町雨滝', 'コクフチョウアメダキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市国府町石井谷', '31', '31201', '6800202', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '国府町石井谷', 'コクフチョウイワイダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市国府町大石', '31', '31201', '6800203', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '国府町大石', 'コクフチョウオオイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市国府町楠城', '31', '31201', '6800204', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '国府町楠城', 'コクフチョウナワシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市国府町拾石', '31', '31201', '6800205', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '国府町拾石', 'コクフチョウジッコク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市国府町栃本', '31', '31201', '6800206', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '国府町栃本', 'コクフチョウトチモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市国府町下木原', '31', '31201', '6800207', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '国府町下木原', 'コクフチョウシモキハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市国府町木原', '31', '31201', '6800208', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '国府町木原', 'コクフチョウキハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市1条西', '01', '01210', '0680021', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '1条西', '01ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市国府町菅野', '31', '31201', '6800211', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '国府町菅野', 'コクフチョウスガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市国府町上地', '31', '31201', '6800212', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '国府町上地', 'コクフチョウワジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市国府町上上地', '31', '31201', '6800213', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '国府町上上地', 'コクフチョウカミワジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市国府町上荒舟', '31', '31201', '6800214', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '国府町上荒舟', 'コクフチョウカミアラフネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市国府町山崎', '31', '31201', '6800215', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '国府町山崎', 'コクフチョウヤマサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市国府町荒舟', '31', '31201', '6800216', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '国府町荒舟', 'コクフチョウアラフネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市2条西', '01', '01210', '0680022', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '2条西', '02ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市国府町神護', '31', '31201', '6800221', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '国府町神護', 'コクフチョウカンゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市国府町殿', '31', '31201', '6800222', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '国府町殿', 'コクフチョウトノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市国府町中河原', '31', '31201', '6800223', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '国府町中河原', 'コクフチョウナカガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市国府町松尾', '31', '31201', '6800224', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '国府町松尾', 'コクフチョウマツオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市国府町吉野', '31', '31201', '6800225', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '国府町吉野', 'コクフチョウヨシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市国府町新井', '31', '31201', '6800226', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '国府町新井', 'コクフチョウニイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市3条西', '01', '01210', '0680023', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '3条西', '03ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市4条西', '01', '01210', '0680024', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '4条西', '04ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市5条西', '01', '01210', '0680025', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '5条西', '05ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市6条西', '01', '01210', '0680026', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '6条西', '06ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市7条西', '01', '01210', '0680027', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '7条西', '07ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市8条西', '01', '01210', '0680028', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '8条西', '08ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市9条西', '01', '01210', '0680029', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '9条西', '09ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市10条西', '01', '01210', '0680030', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '10条西', '10ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡八頭町姫路', '31', '31329', '6800301', '鳥取県', 'トットリケン', '八頭郡八頭町', 'ヤズグンヤズチョウ', '姫路', 'ヒメジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡八頭町明辺', '31', '31329', '6800302', '鳥取県', 'トットリケン', '八頭郡八頭町', 'ヤズグンヤズチョウ', '明辺', 'アケナベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡八頭町落岩', '31', '31329', '6800303', '鳥取県', 'トットリケン', '八頭郡八頭町', 'ヤズグンヤズチョウ', '落岩', 'オチイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡八頭町山志谷', '31', '31329', '6800304', '鳥取県', 'トットリケン', '八頭郡八頭町', 'ヤズグンヤズチョウ', '山志谷', 'ヤマシダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡八頭町麻生', '31', '31329', '6800305', '鳥取県', 'トットリケン', '八頭郡八頭町', 'ヤズグンヤズチョウ', '麻生', 'アソウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡八頭町野町', '31', '31329', '6800306', '鳥取県', 'トットリケン', '八頭郡八頭町', 'ヤズグンヤズチョウ', '野町', 'ノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡八頭町福地', '31', '31329', '6800307', '鳥取県', 'トットリケン', '八頭郡八頭町', 'ヤズグンヤズチョウ', '福地', 'フクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市11条西', '01', '01210', '0680031', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '11条西', '11ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡八頭町市場', '31', '31329', '6800311', '鳥取県', 'トットリケン', '八頭郡八頭町', 'ヤズグンヤズチョウ', '市場', 'イチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡八頭町覚王寺', '31', '31329', '6800312', '鳥取県', 'トットリケン', '八頭郡八頭町', 'ヤズグンヤズチョウ', '覚王寺', 'カクオウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡八頭町上津黒', '31', '31329', '6800313', '鳥取県', 'トットリケン', '八頭郡八頭町', 'ヤズグンヤズチョウ', '上津黒', 'カミツグロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡八頭町下津黒', '31', '31329', '6800314', '鳥取県', 'トットリケン', '八頭郡八頭町', 'ヤズグンヤズチョウ', '下津黒', 'シモツグロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡八頭町別府', '31', '31329', '6800315', '鳥取県', 'トットリケン', '八頭郡八頭町', 'ヤズグンヤズチョウ', '別府', 'ベフ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡八頭町篠波', '31', '31329', '6800316', '鳥取県', 'トットリケン', '八頭郡八頭町', 'ヤズグンヤズチョウ', '篠波', 'ササナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市12条西', '01', '01210', '0680032', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '12条西', '12ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市13条西', '01', '01210', '0680033', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '13条西', '13ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市有明町南', '01', '01210', '0680034', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '有明町南', 'アリアケチョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市有明町中央', '01', '01210', '0680035', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '有明町中央', 'アリアケチョウチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡八頭町', '31', '31329', '6800400', '鳥取県', 'トットリケン', '八頭郡八頭町', 'ヤズグンヤズチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('83200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡八頭町上野', '31', '31329', '6800401', '鳥取県', 'トットリケン', '八頭郡八頭町', 'ヤズグンヤズチョウ', '上野', 'カミノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡八頭町隼福', '31', '31329', '6800402', '鳥取県', 'トットリケン', '八頭郡八頭町', 'ヤズグンヤズチョウ', '隼福', 'ハヤフク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡八頭町福井', '31', '31329', '6800403', '鳥取県', 'トットリケン', '八頭郡八頭町', 'ヤズグンヤズチョウ', '福井', 'フクイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡八頭町見槻中', '31', '31329', '6800404', '鳥取県', 'トットリケン', '八頭郡八頭町', 'ヤズグンヤズチョウ', '見槻中', 'ミヅキナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡八頭町隼郡家', '31', '31329', '6800405', '鳥取県', 'トットリケン', '八頭郡八頭町', 'ヤズグンヤズチョウ', '隼郡家', 'ハヤブサコオゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡八頭町見槻', '31', '31329', '6800406', '鳥取県', 'トットリケン', '八頭郡八頭町', 'ヤズグンヤズチョウ', '見槻', 'ミヅキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡八頭町志子部', '31', '31329', '6800407', '鳥取県', 'トットリケン', '八頭郡八頭町', 'ヤズグンヤズチョウ', '志子部', 'シコベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡八頭町西谷', '31', '31329', '6800408', '鳥取県', 'トットリケン', '八頭郡八頭町', 'ヤズグンヤズチョウ', '西谷', 'ニシダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市北1条西', '01', '01210', '0680041', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '北1条西', 'キタ01ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡八頭町船岡殿', '31', '31329', '6800411', '鳥取県', 'トットリケン', '八頭郡八頭町', 'ヤズグンヤズチョウ', '船岡殿', 'フナオカトノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡八頭町水口', '31', '31329', '6800412', '鳥取県', 'トットリケン', '八頭郡八頭町', 'ヤズグンヤズチョウ', '水口', 'ミナクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡八頭町塩上', '31', '31329', '6800413', '鳥取県', 'トットリケン', '八頭郡八頭町', 'ヤズグンヤズチョウ', '塩上', 'シオノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡八頭町橋本', '31', '31329', '6800414', '鳥取県', 'トットリケン', '八頭郡八頭町', 'ヤズグンヤズチョウ', '橋本', 'ハシモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡八頭町下野', '31', '31329', '6800415', '鳥取県', 'トットリケン', '八頭郡八頭町', 'ヤズグンヤズチョウ', '下野', 'シモツケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡八頭町大江', '31', '31329', '6800416', '鳥取県', 'トットリケン', '八頭郡八頭町', 'ヤズグンヤズチョウ', '大江', 'オオエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市北2条西', '01', '01210', '0680042', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '北2条西', 'キタ02ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡八頭町下門尾', '31', '31329', '6800421', '鳥取県', 'トットリケン', '八頭郡八頭町', 'ヤズグンヤズチョウ', '下門尾', 'シモカドオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡八頭町門尾', '31', '31329', '6800422', '鳥取県', 'トットリケン', '八頭郡八頭町', 'ヤズグンヤズチョウ', '門尾', 'カドオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡八頭町堀越', '31', '31329', '6800423', '鳥取県', 'トットリケン', '八頭郡八頭町', 'ヤズグンヤズチョウ', '堀越', 'ホリゴシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡八頭町稲荷', '31', '31329', '6800424', '鳥取県', 'トットリケン', '八頭郡八頭町', 'ヤズグンヤズチョウ', '稲荷', 'イナリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡八頭町井古', '31', '31329', '6800425', '鳥取県', 'トットリケン', '八頭郡八頭町', 'ヤズグンヤズチョウ', '井古', 'イゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡八頭町下坂', '31', '31329', '6800426', '鳥取県', 'トットリケン', '八頭郡八頭町', 'ヤズグンヤズチョウ', '下坂', 'オリサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡八頭町奥谷', '31', '31329', '6800427', '鳥取県', 'トットリケン', '八頭郡八頭町', 'ヤズグンヤズチョウ', '奥谷', 'オクダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市北3条西', '01', '01210', '0680043', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '北3条西', 'キタ03ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡八頭町下峰寺', '31', '31329', '6800431', '鳥取県', 'トットリケン', '八頭郡八頭町', 'ヤズグンヤズチョウ', '下峰寺', 'シモミネデラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡八頭町上峰寺', '31', '31329', '6800432', '鳥取県', 'トットリケン', '八頭郡八頭町', 'ヤズグンヤズチョウ', '上峰寺', 'カミミネデラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡八頭町山上', '31', '31329', '6800433', '鳥取県', 'トットリケン', '八頭郡八頭町', 'ヤズグンヤズチョウ', '山上', 'ヤマノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡八頭町延命寺', '31', '31329', '6800434', '鳥取県', 'トットリケン', '八頭郡八頭町', 'ヤズグンヤズチョウ', '延命寺', 'エンメイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡八頭町大坪', '31', '31329', '6800435', '鳥取県', 'トットリケン', '八頭郡八頭町', 'ヤズグンヤズチョウ', '大坪', 'オオツボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡八頭町山路', '31', '31329', '6800436', '鳥取県', 'トットリケン', '八頭郡八頭町', 'ヤズグンヤズチョウ', '山路', 'ヤマジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡八頭町花原', '31', '31329', '6800437', '鳥取県', 'トットリケン', '八頭郡八頭町', 'ヤズグンヤズチョウ', '花原', 'ハナバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡八頭町山田', '31', '31329', '6800438', '鳥取県', 'トットリケン', '八頭郡八頭町', 'ヤズグンヤズチョウ', '山田', 'ヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市北4条西', '01', '01210', '0680044', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '北4条西', 'キタ04ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡八頭町西御門', '31', '31329', '6800441', '鳥取県', 'トットリケン', '八頭郡八頭町', 'ヤズグンヤズチョウ', '西御門', 'ニシミカド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡八頭町市谷', '31', '31329', '6800442', '鳥取県', 'トットリケン', '八頭郡八頭町', 'ヤズグンヤズチョウ', '市谷', 'イチノタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡八頭町郡家殿', '31', '31329', '6800443', '鳥取県', 'トットリケン', '八頭郡八頭町', 'ヤズグンヤズチョウ', '郡家殿', 'コウゲトノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡八頭町花', '31', '31329', '6800444', '鳥取県', 'トットリケン', '八頭郡八頭町', 'ヤズグンヤズチョウ', '花', 'ハナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡八頭町大門', '31', '31329', '6800445', '鳥取県', 'トットリケン', '八頭郡八頭町', 'ヤズグンヤズチョウ', '大門', 'ダイモン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市北5条西', '01', '01210', '0680045', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '北5条西', 'キタ05ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡八頭町久能寺', '31', '31329', '6800451', '鳥取県', 'トットリケン', '八頭郡八頭町', 'ヤズグンヤズチョウ', '久能寺', 'クノウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡八頭町池田', '31', '31329', '6800452', '鳥取県', 'トットリケン', '八頭郡八頭町', 'ヤズグンヤズチョウ', '池田', 'イケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡八頭町万代寺', '31', '31329', '6800453', '鳥取県', 'トットリケン', '八頭郡八頭町', 'ヤズグンヤズチョウ', '万代寺', 'マンタイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡八頭町石田百井', '31', '31329', '6800454', '鳥取県', 'トットリケン', '八頭郡八頭町', 'ヤズグンヤズチョウ', '石田百井', 'イシダモモイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡八頭町土師百井', '31', '31329', '6800455', '鳥取県', 'トットリケン', '八頭郡八頭町', 'ヤズグンヤズチョウ', '土師百井', 'ハジモモイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡八頭町米岡', '31', '31329', '6800456', '鳥取県', 'トットリケン', '八頭郡八頭町', 'ヤズグンヤズチョウ', '米岡', 'ヨネオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡八頭町国中', '31', '31329', '6800457', '鳥取県', 'トットリケン', '八頭郡八頭町', 'ヤズグンヤズチョウ', '国中', 'クニナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市緑町', '01', '01210', '0680046', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '緑町', 'ミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡八頭町郡家', '31', '31329', '6800461', '鳥取県', 'トットリケン', '八頭郡八頭町', 'ヤズグンヤズチョウ', '郡家', 'コオゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡八頭町福本', '31', '31329', '6800462', '鳥取県', 'トットリケン', '八頭郡八頭町', 'ヤズグンヤズチョウ', '福本', 'フクモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡八頭町宮谷', '31', '31329', '6800463', '鳥取県', 'トットリケン', '八頭郡八頭町', 'ヤズグンヤズチョウ', '宮谷', 'ミヤダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市若松町', '01', '01210', '0680047', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '若松町', 'ワカマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡八頭町船岡', '31', '31329', '6800471', '鳥取県', 'トットリケン', '八頭郡八頭町', 'ヤズグンヤズチョウ', '船岡', 'フナオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡八頭町下濃', '31', '31329', '6800472', '鳥取県', 'トットリケン', '八頭郡八頭町', 'ヤズグンヤズチョウ', '下濃', 'シモノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡八頭町坂田', '31', '31329', '6800473', '鳥取県', 'トットリケン', '八頭郡八頭町', 'ヤズグンヤズチョウ', '坂田', 'サカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡八頭町破岩', '31', '31329', '6800474', '鳥取県', 'トットリケン', '八頭郡八頭町', 'ヤズグンヤズチョウ', '破岩', 'ワレイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市西川町', '01', '01210', '0680048', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '西川町', 'ニシカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市元町1条西', '01', '01210', '0680051', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '元町1条西', 'モトマチ01ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市元町2条西', '01', '01210', '0680052', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '元町2条西', 'モトマチ02ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡八頭町安井宿', '31', '31329', '6800521', '鳥取県', 'トットリケン', '八頭郡八頭町', 'ヤズグンヤズチョウ', '安井宿', 'ヤスイシュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡八頭町新興寺', '31', '31329', '6800522', '鳥取県', 'トットリケン', '八頭郡八頭町', 'ヤズグンヤズチョウ', '新興寺', 'シンゴウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡八頭町小別府', '31', '31329', '6800523', '鳥取県', 'トットリケン', '八頭郡八頭町', 'ヤズグンヤズチョウ', '小別府', 'コベフ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡八頭町茂田', '31', '31329', '6800524', '鳥取県', 'トットリケン', '八頭郡八頭町', 'ヤズグンヤズチョウ', '茂田', 'モダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡八頭町横田', '31', '31329', '6800525', '鳥取県', 'トットリケン', '八頭郡八頭町', 'ヤズグンヤズチョウ', '横田', 'ヨコタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡八頭町日下部', '31', '31329', '6800526', '鳥取県', 'トットリケン', '八頭郡八頭町', 'ヤズグンヤズチョウ', '日下部', 'クサカベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡八頭町桜ヶ丘', '31', '31329', '6800527', '鳥取県', 'トットリケン', '八頭郡八頭町', 'ヤズグンヤズチョウ', '桜ヶ丘', 'サクラガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市北本町西', '01', '01210', '0680053', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '北本町西', 'キタホンチョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡八頭町才代', '31', '31329', '6800531', '鳥取県', 'トットリケン', '八頭郡八頭町', 'ヤズグンヤズチョウ', '才代', 'サイタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡八頭町東', '31', '31329', '6800532', '鳥取県', 'トットリケン', '八頭郡八頭町', 'ヤズグンヤズチョウ', '東', 'ヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡八頭町皆原', '31', '31329', '6800533', '鳥取県', 'トットリケン', '八頭郡八頭町', 'ヤズグンヤズチョウ', '皆原', 'カイハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡八頭町鍛冶屋', '31', '31329', '6800534', '鳥取県', 'トットリケン', '八頭郡八頭町', 'ヤズグンヤズチョウ', '鍛冶屋', 'カジヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡八頭町三山口', '31', '31329', '6800535', '鳥取県', 'トットリケン', '八頭郡八頭町', 'ヤズグンヤズチョウ', '三山口', 'ミヤマグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡八頭町三浦', '31', '31329', '6800536', '鳥取県', 'トットリケン', '八頭郡八頭町', 'ヤズグンヤズチョウ', '三浦', 'ミウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡八頭町岩淵', '31', '31329', '6800537', '鳥取県', 'トットリケン', '八頭郡八頭町', 'ヤズグンヤズチョウ', '岩淵', 'イワブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市元町1条東', '01', '01210', '0680054', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '元町1条東', 'モトマチ01ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡八頭町清徳', '31', '31329', '6800541', '鳥取県', 'トットリケン', '八頭郡八頭町', 'ヤズグンヤズチョウ', '清徳', 'セイトク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡八頭町茂谷', '31', '31329', '6800542', '鳥取県', 'トットリケン', '八頭郡八頭町', 'ヤズグンヤズチョウ', '茂谷', 'モタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡八頭町奥野', '31', '31329', '6800543', '鳥取県', 'トットリケン', '八頭郡八頭町', 'ヤズグンヤズチョウ', '奥野', 'オクノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡八頭町佐崎', '31', '31329', '6800544', '鳥取県', 'トットリケン', '八頭郡八頭町', 'ヤズグンヤズチョウ', '佐崎', 'ササキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡八頭町柿原', '31', '31329', '6800545', '鳥取県', 'トットリケン', '八頭郡八頭町', 'ヤズグンヤズチョウ', '柿原', 'カキハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市元町2条東', '01', '01210', '0680055', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '元町2条東', 'モトマチ02ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市元町3条東', '01', '01210', '0680056', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '元町3条東', 'モトマチ03ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市北本町東', '01', '01210', '0680057', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '北本町東', 'キタホンチョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市桜木1条', '01', '01210', '0680058', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '桜木1条', 'サクラギ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡八頭町北山', '31', '31329', '6800601', '鳥取県', 'トットリケン', '八頭郡八頭町', 'ヤズグンヤズチョウ', '北山', 'キタヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡八頭町用呂', '31', '31329', '6800602', '鳥取県', 'トットリケン', '八頭郡八頭町', 'ヤズグンヤズチョウ', '用呂', 'ヨウロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡八頭町日田', '31', '31329', '6800603', '鳥取県', 'トットリケン', '八頭郡八頭町', 'ヤズグンヤズチョウ', '日田', 'ヒダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡八頭町南', '31', '31329', '6800604', '鳥取県', 'トットリケン', '八頭郡八頭町', 'ヤズグンヤズチョウ', '南', 'ミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡八頭町島', '31', '31329', '6800605', '鳥取県', 'トットリケン', '八頭郡八頭町', 'ヤズグンヤズチョウ', '島', 'シマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡八頭町重枝', '31', '31329', '6800606', '鳥取県', 'トットリケン', '八頭郡八頭町', 'ヤズグンヤズチョウ', '重枝', 'シゲエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡八頭町徳丸', '31', '31329', '6800607', '鳥取県', 'トットリケン', '八頭郡八頭町', 'ヤズグンヤズチョウ', '徳丸', 'トクマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市北6条西', '01', '01210', '0680061', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '北6条西', 'キタ06ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡八頭町富枝', '31', '31329', '6800611', '鳥取県', 'トットリケン', '八頭郡八頭町', 'ヤズグンヤズチョウ', '富枝', 'トミエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡八頭町志谷', '31', '31329', '6800612', '鳥取県', 'トットリケン', '八頭郡八頭町', 'ヤズグンヤズチョウ', '志谷', 'シタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡八頭町稗谷', '31', '31329', '6800613', '鳥取県', 'トットリケン', '八頭郡八頭町', 'ヤズグンヤズチョウ', '稗谷', 'ヒエダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡八頭町中', '31', '31329', '6800614', '鳥取県', 'トットリケン', '八頭郡八頭町', 'ヤズグンヤズチョウ', '中', 'ナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡若桜町', '31', '31325', '6800700', '鳥取県', 'トットリケン', '八頭郡若桜町', 'ヤズグンワカサチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('83299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡若桜町若桜', '31', '31325', '6800701', '鳥取県', 'トットリケン', '八頭郡若桜町', 'ヤズグンワカサチョウ', '若桜', 'ワカサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡若桜町三倉', '31', '31325', '6800711', '鳥取県', 'トットリケン', '八頭郡若桜町', 'ヤズグンワカサチョウ', '三倉', 'ミクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡若桜町高野', '31', '31325', '6800712', '鳥取県', 'トットリケン', '八頭郡若桜町', 'ヤズグンワカサチョウ', '高野', 'タカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡若桜町赤松', '31', '31325', '6800713', '鳥取県', 'トットリケン', '八頭郡若桜町', 'ヤズグンワカサチョウ', '赤松', 'アカマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡若桜町来見野', '31', '31325', '6800714', '鳥取県', 'トットリケン', '八頭郡若桜町', 'ヤズグンワカサチョウ', '来見野', 'クルミノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡若桜町諸鹿', '31', '31325', '6800715', '鳥取県', 'トットリケン', '八頭郡若桜町', 'ヤズグンワカサチョウ', '諸鹿', 'モロガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡若桜町屋堂羅', '31', '31325', '6800721', '鳥取県', 'トットリケン', '八頭郡若桜町', 'ヤズグンワカサチョウ', '屋堂羅', 'ヤドラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡若桜町浅井', '31', '31325', '6800722', '鳥取県', 'トットリケン', '八頭郡若桜町', 'ヤズグンワカサチョウ', '浅井', 'アサイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡若桜町香田', '31', '31325', '6800723', '鳥取県', 'トットリケン', '八頭郡若桜町', 'ヤズグンワカサチョウ', '香田', 'コウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡若桜町長砂', '31', '31325', '6800724', '鳥取県', 'トットリケン', '八頭郡若桜町', 'ヤズグンワカサチョウ', '長砂', 'ナガスナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡若桜町湯原', '31', '31325', '6800725', '鳥取県', 'トットリケン', '八頭郡若桜町', 'ヤズグンワカサチョウ', '湯原', 'ユワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡若桜町淵見', '31', '31325', '6800726', '鳥取県', 'トットリケン', '八頭郡若桜町', 'ヤズグンワカサチョウ', '淵見', 'フチミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡若桜町茗荷谷', '31', '31325', '6800727', '鳥取県', 'トットリケン', '八頭郡若桜町', 'ヤズグンワカサチョウ', '茗荷谷', 'ミョウガダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡若桜町つく米', '31', '31325', '6800728', '鳥取県', 'トットリケン', '八頭郡若桜町', 'ヤズグンワカサチョウ', 'つく米', 'ツクヨネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡若桜町岩屋堂', '31', '31325', '6800731', '鳥取県', 'トットリケン', '八頭郡若桜町', 'ヤズグンワカサチョウ', '岩屋堂', 'イワヤドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡若桜町中原', '31', '31325', '6800732', '鳥取県', 'トットリケン', '八頭郡若桜町', 'ヤズグンワカサチョウ', '中原', 'ナカハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡若桜町大野', '31', '31325', '6800733', '鳥取県', 'トットリケン', '八頭郡若桜町', 'ヤズグンワカサチョウ', '大野', 'オオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡若桜町小船', '31', '31325', '6800734', '鳥取県', 'トットリケン', '八頭郡若桜町', 'ヤズグンワカサチョウ', '小船', 'オブネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡若桜町落折', '31', '31325', '6800735', '鳥取県', 'トットリケン', '八頭郡若桜町', 'ヤズグンワカサチョウ', '落折', 'オチオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡若桜町大炊', '31', '31325', '6800741', '鳥取県', 'トットリケン', '八頭郡若桜町', 'ヤズグンワカサチョウ', '大炊', 'オオイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡若桜町岸野', '31', '31325', '6800742', '鳥取県', 'トットリケン', '八頭郡若桜町', 'ヤズグンワカサチョウ', '岸野', 'キシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡若桜町糸白見', '31', '31325', '6800743', '鳥取県', 'トットリケン', '八頭郡若桜町', 'ヤズグンワカサチョウ', '糸白見', 'イトシロミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡若桜町根安', '31', '31325', '6800744', '鳥取県', 'トットリケン', '八頭郡若桜町', 'ヤズグンワカサチョウ', '根安', 'ネヤス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡若桜町須澄', '31', '31325', '6800745', '鳥取県', 'トットリケン', '八頭郡若桜町', 'ヤズグンワカサチョウ', '須澄', 'ススミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡若桜町吉川', '31', '31325', '6800746', '鳥取県', 'トットリケン', '八頭郡若桜町', 'ヤズグンワカサチョウ', '吉川', 'ヨシカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市松並町', '31', '31201', '6800801', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '松並町', 'マツナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市青葉町', '31', '31201', '6800802', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '青葉町', 'アオバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市田園町', '31', '31201', '6800803', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '田園町', 'デンエンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市田島', '31', '31201', '6800804', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '田島', 'タシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市相生町', '31', '31201', '6800805', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '相生町', 'アイオイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市薬師町', '31', '31201', '6800806', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '薬師町', 'ヤクシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市西品治', '31', '31201', '6800811', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '西品治', 'ニシホンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市新品治町', '31', '31201', '6800812', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '新品治町', 'シンホンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市寿町', '31', '31201', '6800813', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '寿町', 'コトブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市南町', '31', '31201', '6800814', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '南町', 'ミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市瓦町', '31', '31201', '6800821', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '瓦町', 'カワラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市今町', '31', '31201', '6800822', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '今町', 'イママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市幸町', '31', '31201', '6800823', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市行徳', '31', '31201', '6800824', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '行徳', 'ギョウトク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市栄町', '31', '31201', '6800831', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市弥生町', '31', '31201', '6800832', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '弥生町', 'ヤヨイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市末広温泉町', '31', '31201', '6800833', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '末広温泉町', 'スエヒロオンセンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市永楽温泉町', '31', '31201', '6800834', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '永楽温泉町', 'エイラクオンセンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市東品治町', '31', '31201', '6800835', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '東品治町', 'ヒガシホンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市吉方温泉', '31', '31201', '6800841', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '吉方温泉', 'ヨシカタオンセン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市吉方', '31', '31201', '6800842', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '吉方', 'ヨシカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市南吉方', '31', '31201', '6800843', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '南吉方', 'ミナミヨシカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市興南町', '31', '31201', '6800844', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '興南町', 'コウナンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市富安', '31', '31201', '6800845', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '富安', 'トミヤス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市扇町', '31', '31201', '6800846', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '扇町', 'オウギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市天神町', '31', '31201', '6800847', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '天神町', 'テンジンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市大杙', '31', '31201', '6800851', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '大杙', 'オオクイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市東今在家', '31', '31201', '6800852', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '東今在家', 'ヒガシイマザイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市桜谷', '31', '31201', '6800853', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '桜谷', 'サクラダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市正蓮寺', '31', '31201', '6800854', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '正蓮寺', 'ショウレンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市面影', '31', '31201', '6800855', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '面影', 'オモカゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市新', '31', '31201', '6800861', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '新', 'シン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市雲山', '31', '31201', '6800862', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '雲山', 'クモヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市大覚寺', '31', '31201', '6800863', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '大覚寺', 'ダイカクジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市吉成', '31', '31201', '6800864', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '吉成', 'ヨシナリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市古市', '31', '31201', '6800865', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '古市', 'フルイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市吉成南町', '31', '31201', '6800871', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '吉成南町', 'ヨシナリミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市宮長', '31', '31201', '6800872', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '宮長', 'ミヤナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市的場', '31', '31201', '6800873', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '的場', 'マトバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市叶', '31', '31201', '6800874', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '叶', 'カノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市数津', '31', '31201', '6800875', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '数津', 'スヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市江津', '31', '31201', '6800901', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '江津', 'エヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市秋里', '31', '31201', '6800902', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '秋里', 'アキサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市南隈', '31', '31201', '6800903', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '南隈', 'ミナミガクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市晩稲', '31', '31201', '6800904', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '晩稲', 'オクテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市賀露町', '31', '31201', '6800905', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '賀露町', 'カロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市港町', '31', '31201', '6800906', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '港町', 'ミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市賀露町北', '31', '31201', '6800907', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '賀露町北', 'カロチョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市賀露町西', '31', '31201', '6800908', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '賀露町西', 'カロチョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市賀露町南', '31', '31201', '6800909', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '賀露町南', 'カロチョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市千代水', '31', '31201', '6800911', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '千代水', 'チヨミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市商栄町', '31', '31201', '6800912', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '商栄町', 'ショウエイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市安長', '31', '31201', '6800913', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '安長', 'ヤスナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市南安長', '31', '31201', '6800914', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '南安長', 'ミナミヤスナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市緑ケ丘', '31', '31201', '6800915', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '緑ケ丘', 'ミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市古海', '31', '31201', '6800921', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '古海', 'フルミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市菖蒲', '31', '31201', '6800922', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '菖蒲', 'ショウブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市服部', '31', '31201', '6800923', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '服部', 'ハットリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市野寺', '31', '31201', '6800924', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '野寺', 'ノデラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市岩吉', '31', '31201', '6800931', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '岩吉', 'イワヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市五反田町', '31', '31201', '6800932', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '五反田町', 'ゴタンダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市徳吉', '31', '31201', '6800933', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '徳吉', 'トクヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市徳尾', '31', '31201', '6800934', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '徳尾', 'トクノオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市里仁', '31', '31201', '6800935', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '里仁', 'サトニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市湖山町北', '31', '31201', '6800941', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '湖山町北', 'コヤマチョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市湖山町東', '31', '31201', '6800942', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '湖山町東', 'コヤマチョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市足山', '31', '31201', '6800943', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '足山', 'タリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市布勢', '31', '31201', '6800944', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '布勢', 'フセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市湖山町南', '31', '31201', '6800945', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '湖山町南', 'コヤマチョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市湖山町', '31', '31201', '6800946', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '湖山町', 'コヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市湖山町西', '31', '31201', '6800947', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '湖山町西', 'コヤマチョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市栗沢町北斗', '01', '01210', '0680101', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '栗沢町北斗', 'クリサワチョウホクト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市栗沢町栗部', '01', '01210', '0680102', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '栗沢町栗部', 'クリサワチョウクリベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市栗沢町砺波', '01', '01210', '0680103', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '栗沢町砺波', 'クリサワチョウトナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市栗沢町耕成', '01', '01210', '0680104', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '栗沢町耕成', 'クリサワチョウコウセイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市栗沢町自協', '01', '01210', '0680105', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '栗沢町自協', 'クリサワチョウジキョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市栗沢町越前', '01', '01210', '0680106', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '栗沢町越前', 'クリサワチョウエチゼン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市栗沢町由良', '01', '01210', '0680111', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '栗沢町由良', 'クリサワチョウユラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市栗沢町上幌', '01', '01210', '0680112', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '栗沢町上幌', 'クリサワチョウカミホロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市栗沢町宮村', '01', '01210', '0680113', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '栗沢町宮村', 'クリサワチョウミヤムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市馬場', '31', '31201', '6801131', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '馬場', 'ババ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市国安', '31', '31201', '6801132', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '国安', 'クニヤス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市源太', '31', '31201', '6801133', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '源太', 'ゲンタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市栗沢町茂世丑', '01', '01210', '0680114', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '栗沢町茂世丑', 'クリサワチョウモセウシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市蔵田', '31', '31201', '6801141', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '蔵田', 'クラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市橋本', '31', '31201', '6801142', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '橋本', 'ハシモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市八坂', '31', '31201', '6801143', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '八坂', 'ハツサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市円通寺', '31', '31201', '6801144', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '円通寺', 'エンツウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市西円通寺', '31', '31201', '6801145', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '西円通寺', 'ニシエンツウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市赤子田', '31', '31201', '6801146', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '赤子田', 'アコダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市栗沢町最上', '01', '01210', '0680115', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '栗沢町最上', 'クリサワチョウモガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市倭文', '31', '31201', '6801151', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '倭文', 'シトリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市玉津', '31', '31201', '6801152', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '玉津', 'タマヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市長谷', '31', '31201', '6801153', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '長谷', 'ハセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市下砂見', '31', '31201', '6801154', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '下砂見', 'シモスナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市中砂見', '31', '31201', '6801155', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '中砂見', 'ナカスナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市上砂見', '31', '31201', '6801156', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '上砂見', 'カミスナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市岩坪', '31', '31201', '6801157', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '岩坪', 'イワツボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市向国安', '31', '31201', '6801161', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '向国安', 'ムコウグニヤス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市竹生', '31', '31201', '6801162', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '竹生', 'タケナリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市横枕', '31', '31201', '6801163', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '横枕', 'ヨコマクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市猪子', '31', '31201', '6801164', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '猪子', 'イノコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市下味野', '31', '31201', '6801165', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '下味野', 'シモアジノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市朝月', '31', '31201', '6801166', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '朝月', 'アサヅキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市上味野', '31', '31201', '6801167', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '上味野', 'カミアジノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市本高', '31', '31201', '6801171', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '本高', 'モトダカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市北村', '31', '31201', '6801172', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '北村', 'キタムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市西今在家', '31', '31201', '6801173', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '西今在家', 'ニシイマザイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市篠坂', '31', '31201', '6801174', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '篠坂', 'シノザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市中村', '31', '31201', '6801175', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '中村', 'ナカムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市有富', '31', '31201', '6801176', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '有富', 'アリドメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市高路', '31', '31201', '6801177', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '高路', 'コウロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市河原町袋河原', '31', '31201', '6801201', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '河原町袋河原', 'カワハラチョウフクロガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市河原町布袋', '31', '31201', '6801202', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '河原町布袋', 'カワハラチョウホテイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市河原町稲常', '31', '31201', '6801203', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '河原町稲常', 'カワハラチョウイナツネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市河原町片山', '31', '31201', '6801204', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '河原町片山', 'カワハラチョウカタヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市河原町今在家', '31', '31201', '6801205', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '河原町今在家', 'カワハラチョウイマザイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市河原町三谷', '31', '31201', '6801206', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '河原町三谷', 'カワハラチョウミタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市河原町郷原', '31', '31201', '6801207', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '河原町郷原', 'カワハラチョウゴウバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市河原町鮎ケ丘', '31', '31201', '6801208', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '河原町鮎ケ丘', 'カワハラチョウアユガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市栗沢町北本町', '01', '01210', '0680121', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '栗沢町北本町', 'クリサワチョウキタホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市河原町山手', '31', '31201', '6801211', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '河原町山手', 'カワハラチョウヤマテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市河原町徳吉', '31', '31201', '6801212', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '河原町徳吉', 'カワハラチョウトクヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市河原町高福', '31', '31201', '6801213', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '河原町高福', 'カワハラチョウタカフク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市河原町八日市', '31', '31201', '6801214', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '河原町八日市', 'カワハラチョウヨウカイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市河原町和奈見', '31', '31201', '6801215', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '河原町和奈見', 'カワハラチョウワナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市河原町釜口', '31', '31201', '6801216', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '河原町釜口', 'カワハラチョウカマグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市栗沢町北幸穂', '01', '01210', '0680122', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '栗沢町北幸穂', 'クリサワチョウキタサチホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市河原町渡一木', '31', '31201', '6801221', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '河原町渡一木', 'カワハラチョウワタリヒトツギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市河原町曳田', '31', '31201', '6801222', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '河原町曳田', 'カワハラチョウヒケタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市河原町天神原', '31', '31201', '6801223', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '河原町天神原', 'カワハラチョウテンジンバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市河原町中井', '31', '31201', '6801224', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '河原町中井', 'カワハラチョウナカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市河原町牛戸', '31', '31201', '6801225', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '河原町牛戸', 'カワハラチョウウシト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市栗沢町東本町', '01', '01210', '0680123', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '栗沢町東本町', 'クリサワチョウヒガシホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市河原町湯谷', '31', '31201', '6801231', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '河原町湯谷', 'カワハラチョウユダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市河原町小畑', '31', '31201', '6801232', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '河原町小畑', 'カワハラチョウオバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市河原町弓河内', '31', '31201', '6801233', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '河原町弓河内', 'カワハラチョウユミゴウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市河原町北村', '31', '31201', '6801234', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '河原町北村', 'カワハラチョウキタムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市栗沢町幸穂町', '01', '01210', '0680124', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '栗沢町幸穂町', 'クリサワチョウサチホチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市河原町長瀬', '31', '31201', '6801241', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '河原町長瀬', 'カワハラチョウナガセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市河原町谷一木', '31', '31201', '6801242', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '河原町谷一木', 'カワハラチョウタニヒトツギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市河原町佐貫', '31', '31201', '6801243', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '河原町佐貫', 'カワハラチョウサヌキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市河原町水根', '31', '31201', '6801244', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '河原町水根', 'カワハラチョウミズネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市河原町小倉', '31', '31201', '6801245', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '河原町小倉', 'カワハラチョウオグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市河原町山上', '31', '31201', '6801246', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '河原町山上', 'カワハラチョウヤマガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市栗沢町南本町', '01', '01210', '0680125', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '栗沢町南本町', 'クリサワチョウミナミホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市河原町河原', '31', '31201', '6801251', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '河原町河原', 'カワハラチョウカワハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市河原町本鹿', '31', '31201', '6801252', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '河原町本鹿', 'カワハラチョウホンガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市河原町小河内', '31', '31201', '6801253', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '河原町小河内', 'カワハラチョウオゴウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市河原町神馬', '31', '31201', '6801254', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '河原町神馬', 'カワハラチョウカンバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市栗沢町西本町', '01', '01210', '0680126', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '栗沢町西本町', 'クリサワチョウニシホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市栗沢町本町', '01', '01210', '0680127', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '栗沢町本町', 'クリサワチョウホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市栗沢町小西', '01', '01210', '0680131', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '栗沢町小西', 'クリサワチョウコニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市栗沢町南幸穂', '01', '01210', '0680132', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '栗沢町南幸穂', 'クリサワチョウミナミサチホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市栗沢町加茂川', '01', '01210', '0680133', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '栗沢町加茂川', 'クリサワチョウカモガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市栗沢町栗丘', '01', '01210', '0680134', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '栗沢町栗丘', 'クリサワチョウクリオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市栗沢町岐阜', '01', '01210', '0680135', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '栗沢町岐阜', 'クリサワチョウギフ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市栗沢町必成', '01', '01210', '0680136', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '栗沢町必成', 'クリサワチョウヒッセイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市嶋', '31', '31201', '6801411', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '嶋', 'シマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市宮谷', '31', '31201', '6801412', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '宮谷', 'ミヤダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市野坂', '31', '31201', '6801413', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '野坂', 'ノサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市下段', '31', '31201', '6801414', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '下段', 'シモダン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市大塚', '31', '31201', '6801415', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '大塚', 'オオヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市高住', '31', '31201', '6801416', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '高住', 'タカズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市桂見', '31', '31201', '6801417', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '桂見', 'カツラミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市大桷', '31', '31201', '6801418', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '大桷', 'ダイカク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市上段', '31', '31201', '6801421', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '上段', 'カミダン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市上原', '31', '31201', '6801422', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '上原', 'ウエバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市松上', '31', '31201', '6801423', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '松上', 'マツガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市槇原', '31', '31201', '6801424', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '槇原', 'マキバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市河内', '31', '31201', '6801425', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '河内', 'コウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市細見', '31', '31201', '6801426', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '細見', 'ホソミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市尾崎', '31', '31201', '6801427', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '尾崎', 'オサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市三山口', '31', '31201', '6801428', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '三山口', 'ミヤマグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市妙徳寺', '31', '31201', '6801431', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '妙徳寺', 'ミョウトクジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市双六原', '31', '31201', '6801432', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '双六原', 'ソウロクバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市矢矯', '31', '31201', '6801433', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '矢矯', 'ヤハギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市洞谷', '31', '31201', '6801434', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '洞谷', 'ホラダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市瀬田蔵', '31', '31201', '6801435', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '瀬田蔵', 'セタグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市長柄', '31', '31201', '6801436', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '長柄', 'ナガラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市大畑', '31', '31201', '6801437', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '大畑', 'オオバタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市福井', '31', '31201', '6801438', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '福井', 'フクイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市金沢', '31', '31201', '6801439', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '金沢', 'カナザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市良田', '31', '31201', '6801441', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '良田', 'ヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市吉岡温泉町', '31', '31201', '6801442', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '吉岡温泉町', 'ヨシオカオンセンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市六反田', '31', '31201', '6801443', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '六反田', 'ロクタンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市松原', '31', '31201', '6801444', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '松原', 'マツバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡栗山町阿野呂', '01', '01429', '0680351', '北海道', 'ホッカイドウ', '夕張郡栗山町', 'ユウバリグンクリヤマチョウ', '阿野呂', 'アノロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡栗山町大井分', '01', '01429', '0680352', '北海道', 'ホッカイドウ', '夕張郡栗山町', 'ユウバリグンクリヤマチョウ', '大井分', 'オオイワケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡栗山町継立', '01', '01429', '0680353', '北海道', 'ホッカイドウ', '夕張郡栗山町', 'ユウバリグンクリヤマチョウ', '継立', 'ツギタテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡栗山町日出', '01', '01429', '0680354', '北海道', 'ホッカイドウ', '夕張郡栗山町', 'ユウバリグンクリヤマチョウ', '日出', 'ヒノデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡栗山町御園', '01', '01429', '0680355', '北海道', 'ホッカイドウ', '夕張郡栗山町', 'ユウバリグンクリヤマチョウ', '御園', 'ミソノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡栗山町南角田', '01', '01429', '0680356', '北海道', 'ホッカイドウ', '夕張郡栗山町', 'ユウバリグンクリヤマチョウ', '南角田', 'ミナミカクタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡栗山町南学田', '01', '01429', '0680357', '北海道', 'ホッカイドウ', '夕張郡栗山町', 'ユウバリグンクリヤマチョウ', '南学田', 'ミナミガクデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡栗山町桜山', '01', '01429', '0680358', '北海道', 'ホッカイドウ', '夕張郡栗山町', 'ユウバリグンクリヤマチョウ', '桜山', 'サクラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡栗山町滝下', '01', '01429', '0680361', '北海道', 'ホッカイドウ', '夕張郡栗山町', 'ユウバリグンクリヤマチョウ', '滝下', 'タキシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡栗山町円山', '01', '01429', '0680362', '北海道', 'ホッカイドウ', '夕張郡栗山町', 'ユウバリグンクリヤマチョウ', '円山', 'マルヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡栗山町円山東山', '01', '01429', '0680363', '北海道', 'ホッカイドウ', '夕張郡栗山町', 'ユウバリグンクリヤマチョウ', '円山東山', 'マルヤマヒガシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張市', '01', '01209', '0680400', '北海道', 'ホッカイドウ', '夕張市', 'ユウバリシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('83526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張市高松', '01', '01209', '0680401', '北海道', 'ホッカイドウ', '夕張市', 'ユウバリシ', '高松', 'タカマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張市社光', '01', '01209', '0680402', '北海道', 'ホッカイドウ', '夕張市', 'ユウバリシ', '社光', 'シャコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張市本町', '01', '01209', '0680403', '北海道', 'ホッカイドウ', '夕張市', 'ユウバリシ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張市昭和', '01', '01209', '0680404', '北海道', 'ホッカイドウ', '夕張市', 'ユウバリシ', '昭和', 'ショウワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張市旭町', '01', '01209', '0680405', '北海道', 'ホッカイドウ', '夕張市', 'ユウバリシ', '旭町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張市住初', '01', '01209', '0680406', '北海道', 'ホッカイドウ', '夕張市', 'ユウバリシ', '住初', 'スミゾメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張市福住', '01', '01209', '0680407', '北海道', 'ホッカイドウ', '夕張市', 'ユウバリシ', '福住', 'フクズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張市富岡', '01', '01209', '0680408', '北海道', 'ホッカイドウ', '夕張市', 'ユウバリシ', '富岡', 'トミオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張市丁未', '01', '01209', '0680409', '北海道', 'ホッカイドウ', '夕張市', 'ユウバリシ', '丁未', 'テイミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張市末広', '01', '01209', '0680411', '北海道', 'ホッカイドウ', '夕張市', 'ユウバリシ', '末広', 'スエヒロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張市鹿の谷東丘町', '01', '01209', '0680412', '北海道', 'ホッカイドウ', '夕張市', 'ユウバリシ', '鹿の谷東丘町', 'シカノタニヒガシオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張市鹿の谷', '01', '01209', '0680413', '北海道', 'ホッカイドウ', '夕張市', 'ユウバリシ', '鹿の谷', 'シカノタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張市鹿の谷山手町', '01', '01209', '0680414', '北海道', 'ホッカイドウ', '夕張市', 'ユウバリシ', '鹿の谷山手町', 'シカノタニヤマテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張市常盤', '01', '01209', '0680421', '北海道', 'ホッカイドウ', '夕張市', 'ユウバリシ', '常盤', 'トキワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張市日吉', '01', '01209', '0680422', '北海道', 'ホッカイドウ', '夕張市', 'ユウバリシ', '日吉', 'ヒヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張市平和', '01', '01209', '0680423', '北海道', 'ホッカイドウ', '夕張市', 'ユウバリシ', '平和', 'ヘイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張市千代田', '01', '01209', '0680424', '北海道', 'ホッカイドウ', '夕張市', 'ユウバリシ', '千代田', 'チヨダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張市若菜', '01', '01209', '0680425', '北海道', 'ホッカイドウ', '夕張市', 'ユウバリシ', '若菜', 'ワカナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張市富野', '01', '01209', '0680426', '北海道', 'ホッカイドウ', '夕張市', 'ユウバリシ', '富野', 'トミノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張市清水沢', '01', '01209', '0680531', '北海道', 'ホッカイドウ', '夕張市', 'ユウバリシ', '清水沢', 'シミズサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張市清水沢清栄町', '01', '01209', '0680532', '北海道', 'ホッカイドウ', '夕張市', 'ユウバリシ', '清水沢清栄町', 'シミズサワセイエイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張市清水沢清湖町', '01', '01209', '0680533', '北海道', 'ホッカイドウ', '夕張市', 'ユウバリシ', '清水沢清湖町', 'シミズサワセイコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張市清水沢宮前町', '01', '01209', '0680534', '北海道', 'ホッカイドウ', '夕張市', 'ユウバリシ', '清水沢宮前町', 'シミズサワミヤマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張市清水沢清陵町', '01', '01209', '0680535', '北海道', 'ホッカイドウ', '夕張市', 'ユウバリシ', '清水沢清陵町', 'シミズサワセイリョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張市南清水沢', '01', '01209', '0680536', '北海道', 'ホッカイドウ', '夕張市', 'ユウバリシ', '南清水沢', 'ミナミシミズサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張市南部住の江町', '01', '01209', '0680540', '北海道', 'ホッカイドウ', '夕張市', 'ユウバリシ', '南部住の江町', 'ナンブスミノエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張市南部遠幌町', '01', '01209', '0680541', '北海道', 'ホッカイドウ', '夕張市', 'ユウバリシ', '南部遠幌町', 'ナンブエンホロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張市南部夕南町', '01', '01209', '0680542', '北海道', 'ホッカイドウ', '夕張市', 'ユウバリシ', '南部夕南町', 'ナンブユウナンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張市南部若美町', '01', '01209', '0680543', '北海道', 'ホッカイドウ', '夕張市', 'ユウバリシ', '南部若美町', 'ナンブワカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張市南部大宮町', '01', '01209', '0680544', '北海道', 'ホッカイドウ', '夕張市', 'ユウバリシ', '南部大宮町', 'ナンブオオミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張市南部東町', '01', '01209', '0680545', '北海道', 'ホッカイドウ', '夕張市', 'ユウバリシ', '南部東町', 'ナンブアズマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張市南部青葉町', '01', '01209', '0680546', '北海道', 'ホッカイドウ', '夕張市', 'ユウバリシ', '南部青葉町', 'ナンブアオバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張市南部菊水町', '01', '01209', '0680546', '北海道', 'ホッカイドウ', '夕張市', 'ユウバリシ', '南部菊水町', 'ナンブキクスイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張市南部新光町', '01', '01209', '0680547', '北海道', 'ホッカイドウ', '夕張市', 'ユウバリシ', '南部新光町', 'ナンブシンコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張市南部幌南町', '01', '01209', '0680548', '北海道', 'ホッカイドウ', '夕張市', 'ユウバリシ', '南部幌南町', 'ナンブコウナンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張市南部岳見町', '01', '01209', '0680549', '北海道', 'ホッカイドウ', '夕張市', 'ユウバリシ', '南部岳見町', 'ナンブタケミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張市鹿島白金', '01', '01209', '0680661', '北海道', 'ホッカイドウ', '夕張市', 'ユウバリシ', '鹿島白金', 'カシマシロガネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張市鹿島明石町', '01', '01209', '0680662', '北海道', 'ホッカイドウ', '夕張市', 'ユウバリシ', '鹿島明石町', 'カシマアカシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張市鹿島千年町', '01', '01209', '0680663', '北海道', 'ホッカイドウ', '夕張市', 'ユウバリシ', '鹿島千年町', 'カシマチトセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張市鹿島錦町', '01', '01209', '0680664', '北海道', 'ホッカイドウ', '夕張市', 'ユウバリシ', '鹿島錦町', 'カシマニシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張市鹿島宝町', '01', '01209', '0680665', '北海道', 'ホッカイドウ', '夕張市', 'ユウバリシ', '鹿島宝町', 'カシマタカラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張市鹿島緑町', '01', '01209', '0680671', '北海道', 'ホッカイドウ', '夕張市', 'ユウバリシ', '鹿島緑町', 'カシマミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張市鹿島富士見町', '01', '01209', '0680672', '北海道', 'ホッカイドウ', '夕張市', 'ユウバリシ', '鹿島富士見町', 'カシマフジミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張市鹿島栄町', '01', '01209', '0680673', '北海道', 'ホッカイドウ', '夕張市', 'ユウバリシ', '鹿島栄町', 'カシマサカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張市鹿島代々木町', '01', '01209', '0680674', '北海道', 'ホッカイドウ', '夕張市', 'ユウバリシ', '鹿島代々木町', 'カシマヨヨギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張市鹿島北栄町', '01', '01209', '0680675', '北海道', 'ホッカイドウ', '夕張市', 'ユウバリシ', '鹿島北栄町', 'カシマホクエイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張市沼ノ沢', '01', '01209', '0680751', '北海道', 'ホッカイドウ', '夕張市', 'ユウバリシ', '沼ノ沢', 'ヌマノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張市真谷地', '01', '01209', '0680752', '北海道', 'ホッカイドウ', '夕張市', 'ユウバリシ', '真谷地', 'マヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張市登川', '01', '01209', '0680753', '北海道', 'ホッカイドウ', '夕張市', 'ユウバリシ', '登川', 'ノボリカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張市楓', '01', '01209', '0680754', '北海道', 'ホッカイドウ', '夕張市', 'ユウバリシ', '楓', 'カエデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張市紅葉山', '01', '01209', '0680755', '北海道', 'ホッカイドウ', '夕張市', 'ユウバリシ', '紅葉山', 'モミジヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張市滝ノ上', '01', '01209', '0680756', '北海道', 'ホッカイドウ', '夕張市', 'ユウバリシ', '滝ノ上', 'タキノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市南町1条', '01', '01210', '0680801', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '南町1条', 'ミナミマチ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市南町2条', '01', '01210', '0680802', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '南町2条', 'ミナミマチ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市福部町久志羅上野', '31', '31201', '6808021', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '福部町久志羅', 'フクベチョウクジラ', null, null, '上野', 'ウエノ');
INSERT INTO `ms_addresses` VALUES ('83582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市福部町左近上野', '31', '31201', '6808022', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '福部町左近', 'フクベチョウサコ', null, null, '上野', 'ウエノ');
INSERT INTO `ms_addresses` VALUES ('83583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市南町3条', '01', '01210', '0680803', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '南町3条', 'ミナミマチ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市南町4条', '01', '01210', '0680804', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '南町4条', 'ミナミマチ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市南町5条', '01', '01210', '0680805', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '南町5条', 'ミナミマチ05ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市南町6条', '01', '01210', '0680806', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '南町6条', 'ミナミマチ06ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市国府町稲葉丘', '31', '31201', '6808062', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '国府町稲葉丘', 'コクフチョウイナバガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市国府町奥谷', '31', '31201', '6808063', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '国府町奥谷', 'コクフチョウオクダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市国府町分上', '31', '31201', '6808064', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '国府町分上', 'コクフチョウブンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市国府町新町', '31', '31201', '6808065', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '国府町新町', 'コクフチョウシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市国府町新通り', '31', '31201', '6808066', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '国府町新通り', 'コクフチョウシンドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市南町7条', '01', '01210', '0680807', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '南町7条', 'ミナミマチ07ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市南町8条', '01', '01210', '0680808', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '南町8条', 'ミナミマチ08ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市南町9条', '01', '01210', '0680809', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '南町9条', 'ミナミマチ09ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市南町', '01', '01210', '0680810', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '南町', 'ミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市美園1条', '01', '01210', '0680811', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '美園1条', 'ミソノ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市美園2条', '01', '01210', '0680812', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '美園2条', 'ミソノ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市美園3条', '01', '01210', '0680813', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '美園3条', 'ミソノ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市美園4条', '01', '01210', '0680814', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '美園4条', 'ミソノ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市美園5条', '01', '01210', '0680815', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '美園5条', 'ミソノ05ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市美園6条', '01', '01210', '0680816', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '美園6条', 'ミソノ06ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市美園7条', '01', '01210', '0680817', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '美園7条', 'ミソノ07ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市並木町', '01', '01210', '0680818', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '並木町', 'ナミキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市栄町', '01', '01210', '0680821', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市日の出台', '01', '01210', '0680822', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '日の出台', 'ヒノデダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市日の出南', '01', '01210', '0680823', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '日の出南', 'ヒノデミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市日の出北', '01', '01210', '0680824', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '日の出北', 'ヒノデキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市日の出町', '01', '01210', '0680825', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '日の出町', 'ヒノデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市東山町', '01', '01210', '0680826', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '東山町', 'ヒガシヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市春日町', '01', '01210', '0680827', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '春日町', 'カスガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市鳩が丘', '01', '01210', '0680828', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '鳩が丘', 'ハトガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市かえで町', '01', '01210', '0680829', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', 'かえで町', 'カエデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市若駒', '01', '01210', '0680830', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '若駒', 'ワカコマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市ふじ町1条', '01', '01210', '0680831', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', 'ふじ町1条', 'フジチョウ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市ふじ町2条', '01', '01210', '0680832', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', 'ふじ町2条', 'フジチョウ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市志文町', '01', '01210', '0680833', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '志文町', 'シブンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市駒園', '01', '01210', '0680834', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '駒園', 'コマゾノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市緑が丘', '01', '01210', '0680835', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '緑が丘', 'ミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市上志文町', '01', '01210', '0680836', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '上志文町', 'カミシブンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市宝水町', '01', '01210', '0680837', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '宝水町', 'ホウスイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市志文本町1条', '01', '01210', '0680841', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '志文本町1条', 'シブンホンチョウ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市志文本町2条', '01', '01210', '0680842', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '志文本町2条', 'シブンホンチョウ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市志文本町3条', '01', '01210', '0680843', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '志文本町3条', 'シブンホンチョウ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市志文本町4条', '01', '01210', '0680844', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '志文本町4条', 'シブンホンチョウ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市志文本町5条', '01', '01210', '0680845', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '志文本町5条', 'シブンホンチョウ05ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市下志文町', '01', '01210', '0680846', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '下志文町', 'シモシブンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市金子町', '01', '01210', '0680847', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '金子町', 'カネコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市大和1条', '01', '01210', '0680851', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '大和1条', 'ヤマト01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市大和2条', '01', '01210', '0680852', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '大和2条', 'ヤマト02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市大和3条', '01', '01210', '0680853', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '大和3条', 'ヤマト03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市大和4条', '01', '01210', '0680854', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '大和4条', 'ヤマト04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市大和町', '01', '01210', '0680855', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '大和町', 'ヤマトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県岩美郡岩美町', '31', '31302', '6810000', '鳥取県', 'トットリケン', '岩美郡岩美町', 'イワミグンイワミチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('83667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県岩美郡岩美町牧谷', '31', '31302', '6810001', '鳥取県', 'トットリケン', '岩美郡岩美町', 'イワミグンイワミチョウ', '牧谷', 'マキダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県岩美郡岩美町相谷', '31', '31302', '6810002', '鳥取県', 'トットリケン', '岩美郡岩美町', 'イワミグンイワミチョウ', '相谷', 'アイダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県岩美郡岩美町浦富', '31', '31302', '6810003', '鳥取県', 'トットリケン', '岩美郡岩美町', 'イワミグンイワミチョウ', '浦富', 'ウラドメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県岩美郡岩美町陸上', '31', '31302', '6810011', '鳥取県', 'トットリケン', '岩美郡岩美町', 'イワミグンイワミチョウ', '陸上', 'クガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県岩美郡岩美町田河内', '31', '31302', '6810012', '鳥取県', 'トットリケン', '岩美郡岩美町', 'イワミグンイワミチョウ', '田河内', 'タノコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県岩美郡岩美町小羽尾', '31', '31302', '6810013', '鳥取県', 'トットリケン', '岩美郡岩美町', 'イワミグンイワミチョウ', '小羽尾', 'コバネオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県岩美郡岩美町大羽尾', '31', '31302', '6810014', '鳥取県', 'トットリケン', '岩美郡岩美町', 'イワミグンイワミチョウ', '大羽尾', 'オオバネオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県岩美郡岩美町長谷', '31', '31302', '6810021', '鳥取県', 'トットリケン', '岩美郡岩美町', 'イワミグンイワミチョウ', '長谷', 'ナガタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県岩美郡岩美町白地', '31', '31302', '6810022', '鳥取県', 'トットリケン', '岩美郡岩美町', 'イワミグンイワミチョウ', '白地', 'シラジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県岩美郡岩美町真名', '31', '31302', '6810023', '鳥取県', 'トットリケン', '岩美郡岩美町', 'イワミグンイワミチョウ', '真名', 'マナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県岩美郡岩美町岩井', '31', '31302', '6810024', '鳥取県', 'トットリケン', '岩美郡岩美町', 'イワミグンイワミチョウ', '岩井', 'イワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県岩美郡岩美町宇治', '31', '31302', '6810025', '鳥取県', 'トットリケン', '岩美郡岩美町', 'イワミグンイワミチョウ', '宇治', 'ウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県岩美郡岩美町蒲生', '31', '31302', '6810031', '鳥取県', 'トットリケン', '岩美郡岩美町', 'イワミグンイワミチョウ', '蒲生', 'ガモウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県岩美郡岩美町洗井', '31', '31302', '6810032', '鳥取県', 'トットリケン', '岩美郡岩美町', 'イワミグンイワミチョウ', '洗井', 'アライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県岩美郡岩美町鳥越', '31', '31302', '6810033', '鳥取県', 'トットリケン', '岩美郡岩美町', 'イワミグンイワミチョウ', '鳥越', 'トリゴエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県岩美郡岩美町銀山', '31', '31302', '6810034', '鳥取県', 'トットリケン', '岩美郡岩美町', 'イワミグンイワミチョウ', '銀山', 'ギンザン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県岩美郡岩美町馬場', '31', '31302', '6810035', '鳥取県', 'トットリケン', '岩美郡岩美町', 'イワミグンイワミチョウ', '馬場', 'ババ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県岩美郡岩美町相山', '31', '31302', '6810036', '鳥取県', 'トットリケン', '岩美郡岩美町', 'イワミグンイワミチョウ', '相山', 'アイヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県岩美郡岩美町黒谷', '31', '31302', '6810041', '鳥取県', 'トットリケン', '岩美郡岩美町', 'イワミグンイワミチョウ', '黒谷', 'クロダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県岩美郡岩美町小田', '31', '31302', '6810042', '鳥取県', 'トットリケン', '岩美郡岩美町', 'イワミグンイワミチョウ', '小田', 'オダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県岩美郡岩美町大坂', '31', '31302', '6810043', '鳥取県', 'トットリケン', '岩美郡岩美町', 'イワミグンイワミチョウ', '大坂', 'オオサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県岩美郡岩美町外邑', '31', '31302', '6810044', '鳥取県', 'トットリケン', '岩美郡岩美町', 'イワミグンイワミチョウ', '外邑', 'トノムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県岩美郡岩美町唐川', '31', '31302', '6810045', '鳥取県', 'トットリケン', '岩美郡岩美町', 'イワミグンイワミチョウ', '唐川', 'カラカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県岩美郡岩美町延興寺', '31', '31302', '6810046', '鳥取県', 'トットリケン', '岩美郡岩美町', 'イワミグンイワミチョウ', '延興寺', 'エンゴウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県岩美郡岩美町池谷', '31', '31302', '6810047', '鳥取県', 'トットリケン', '岩美郡岩美町', 'イワミグンイワミチョウ', '池谷', 'イケダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県岩美郡岩美町河崎', '31', '31302', '6810051', '鳥取県', 'トットリケン', '岩美郡岩美町', 'イワミグンイワミチョウ', '河崎', 'カワサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県岩美郡岩美町岩常', '31', '31302', '6810052', '鳥取県', 'トットリケン', '岩美郡岩美町', 'イワミグンイワミチョウ', '岩常', 'イワツネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県岩美郡岩美町高住', '31', '31302', '6810053', '鳥取県', 'トットリケン', '岩美郡岩美町', 'イワミグンイワミチョウ', '高住', 'タカズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県岩美郡岩美町院内', '31', '31302', '6810054', '鳥取県', 'トットリケン', '岩美郡岩美町', 'イワミグンイワミチョウ', '院内', 'インナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県岩美郡岩美町荒金', '31', '31302', '6810055', '鳥取県', 'トットリケン', '岩美郡岩美町', 'イワミグンイワミチョウ', '荒金', 'アラカネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県岩美郡岩美町長郷', '31', '31302', '6810056', '鳥取県', 'トットリケン', '岩美郡岩美町', 'イワミグンイワミチョウ', '長郷', 'チョウゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県岩美郡岩美町高山', '31', '31302', '6810061', '鳥取県', 'トットリケン', '岩美郡岩美町', 'イワミグンイワミチョウ', '高山', 'タカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県岩美郡岩美町恩志', '31', '31302', '6810062', '鳥取県', 'トットリケン', '岩美郡岩美町', 'イワミグンイワミチョウ', '恩志', 'オンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県岩美郡岩美町太田', '31', '31302', '6810063', '鳥取県', 'トットリケン', '岩美郡岩美町', 'イワミグンイワミチョウ', '太田', 'オオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県岩美郡岩美町本庄', '31', '31302', '6810064', '鳥取県', 'トットリケン', '岩美郡岩美町', 'イワミグンイワミチョウ', '本庄', 'ホンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県岩美郡岩美町新井', '31', '31302', '6810065', '鳥取県', 'トットリケン', '岩美郡岩美町', 'イワミグンイワミチョウ', '新井', 'ニイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県岩美郡岩美町田後', '31', '31302', '6810071', '鳥取県', 'トットリケン', '岩美郡岩美町', 'イワミグンイワミチョウ', '田後', 'タジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県岩美郡岩美町岩本', '31', '31302', '6810072', '鳥取県', 'トットリケン', '岩美郡岩美町', 'イワミグンイワミチョウ', '岩本', 'イワモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県岩美郡岩美町大谷', '31', '31302', '6810073', '鳥取県', 'トットリケン', '岩美郡岩美町', 'イワミグンイワミチョウ', '大谷', 'オオタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県岩美郡岩美町網代', '31', '31302', '6810074', '鳥取県', 'トットリケン', '岩美郡岩美町', 'イワミグンイワミチョウ', '網代', 'アジロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩郡新篠津村', '01', '01304', '0681100', '北海道', 'ホッカイドウ', '石狩郡新篠津村', 'イシカリグンシンシノツムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('83708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩郡新篠津村萌出', '01', '01304', '0681101', '北海道', 'ホッカイドウ', '石狩郡新篠津村', 'イシカリグンシンシノツムラ', '萌出', 'モエデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩郡新篠津村いなほ', '01', '01304', '0681102', '北海道', 'ホッカイドウ', '石狩郡新篠津村', 'イシカリグンシンシノツムラ', 'いなほ', 'イナホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩郡新篠津村西の里', '01', '01304', '0681103', '北海道', 'ホッカイドウ', '石狩郡新篠津村', 'イシカリグンシンシノツムラ', '西の里', 'ニシノサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩郡新篠津村かつら', '01', '01304', '0681104', '北海道', 'ホッカイドウ', '石狩郡新篠津村', 'イシカリグンシンシノツムラ', 'かつら', 'カツラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩郡新篠津村東明', '01', '01304', '0681111', '北海道', 'ホッカイドウ', '石狩郡新篠津村', 'イシカリグンシンシノツムラ', '東明', 'トウメイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩郡新篠津村あけぼの', '01', '01304', '0681112', '北海道', 'ホッカイドウ', '石狩郡新篠津村', 'イシカリグンシンシノツムラ', 'あけぼの', 'アケボノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩郡新篠津村ふらわー', '01', '01304', '0681113', '北海道', 'ホッカイドウ', '石狩郡新篠津村', 'イシカリグンシンシノツムラ', 'ふらわー', 'フラワー', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩郡新篠津村南ケ丘', '01', '01304', '0681114', '北海道', 'ホッカイドウ', '石狩郡新篠津村', 'イシカリグンシンシノツムラ', '南ケ丘', 'ミナミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩郡新篠津村みずほ', '01', '01304', '0681115', '北海道', 'ホッカイドウ', '石狩郡新篠津村', 'イシカリグンシンシノツムラ', 'みずほ', 'ミズホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩郡新篠津村上達布', '01', '01304', '0681116', '北海道', 'ホッカイドウ', '石狩郡新篠津村', 'イシカリグンシンシノツムラ', '上達布', 'カミタップ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩郡新篠津村新湧', '01', '01304', '0681121', '北海道', 'ホッカイドウ', '石狩郡新篠津村', 'イシカリグンシンシノツムラ', '新湧', 'シンユウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩郡新篠津村北新', '01', '01304', '0681122', '北海道', 'ホッカイドウ', '石狩郡新篠津村', 'イシカリグンシンシノツムラ', '北新', 'ホクシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩郡新篠津村川上', '01', '01304', '0681123', '北海道', 'ホッカイドウ', '石狩郡新篠津村', 'イシカリグンシンシノツムラ', '川上', 'カワカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩郡新篠津村高倉', '01', '01304', '0681124', '北海道', 'ホッカイドウ', '石狩郡新篠津村', 'イシカリグンシンシノツムラ', '高倉', 'タカクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩郡新篠津村上篠津', '01', '01304', '0681125', '北海道', 'ホッカイドウ', '石狩郡新篠津村', 'イシカリグンシンシノツムラ', '上篠津', 'カミシノツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩郡新篠津村豊ケ丘', '01', '01304', '0681126', '北海道', 'ホッカイドウ', '石狩郡新篠津村', 'イシカリグンシンシノツムラ', '豊ケ丘', 'トヨガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩郡新篠津村沼之端', '01', '01304', '0681127', '北海道', 'ホッカイドウ', '石狩郡新篠津村', 'イシカリグンシンシノツムラ', '沼之端', 'ヌマノハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩郡新篠津村基線', '01', '01304', '0681131', '北海道', 'ホッカイドウ', '石狩郡新篠津村', 'イシカリグンシンシノツムラ', '基線', 'キセン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩郡新篠津村豊野', '01', '01304', '0681132', '北海道', 'ホッカイドウ', '石狩郡新篠津村', 'イシカリグンシンシノツムラ', '豊野', 'トヨノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩郡新篠津村平安', '01', '01304', '0681133', '北海道', 'ホッカイドウ', '石狩郡新篠津村', 'イシカリグンシンシノツムラ', '平安', 'ヘイアン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩郡新篠津村宍粟', '01', '01304', '0681134', '北海道', 'ホッカイドウ', '石狩郡新篠津村', 'イシカリグンシンシノツムラ', '宍粟', 'シソウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩郡新篠津村袋達布', '01', '01304', '0681135', '北海道', 'ホッカイドウ', '石狩郡新篠津村', 'イシカリグンシンシノツムラ', '袋達布', 'フクロタップ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩郡新篠津村下達布', '01', '01304', '0681136', '北海道', 'ホッカイドウ', '石狩郡新篠津村', 'イシカリグンシンシノツムラ', '下達布', 'シモタップ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩郡新篠津村中篠津', '01', '01304', '0681137', '北海道', 'ホッカイドウ', '石狩郡新篠津村', 'イシカリグンシンシノツムラ', '中篠津', 'ナカシノツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩郡新篠津村新西篠津', '01', '01304', '0681138', '北海道', 'ホッカイドウ', '石狩郡新篠津村', 'イシカリグンシンシノツムラ', '新西篠津', 'シンニシシノツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩郡新篠津村西篠津', '01', '01304', '0681141', '北海道', 'ホッカイドウ', '石狩郡新篠津村', 'イシカリグンシンシノツムラ', '西篠津', 'ニシシノツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩郡新篠津村新樺', '01', '01304', '0681142', '北海道', 'ホッカイドウ', '石狩郡新篠津村', 'イシカリグンシンシノツムラ', '新樺', 'シンカバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩郡新篠津村武田', '01', '01304', '0681143', '北海道', 'ホッカイドウ', '石狩郡新篠津村', 'イシカリグンシンシノツムラ', '武田', 'タケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩郡新篠津村拓新', '01', '01304', '0681144', '北海道', 'ホッカイドウ', '石狩郡新篠津村', 'イシカリグンシンシノツムラ', '拓新', 'タクシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩郡新篠津村西高倉', '01', '01304', '0681145', '北海道', 'ホッカイドウ', '石狩郡新篠津村', 'イシカリグンシンシノツムラ', '西高倉', 'ニシタカクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩郡新篠津村新高倉', '01', '01304', '0681146', '北海道', 'ホッカイドウ', '石狩郡新篠津村', 'イシカリグンシンシノツムラ', '新高倉', 'シンタカクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩郡新篠津村西原', '01', '01304', '0681151', '北海道', 'ホッカイドウ', '石狩郡新篠津村', 'イシカリグンシンシノツムラ', '西原', 'ニシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩郡新篠津村川下', '01', '01304', '0681152', '北海道', 'ホッカイドウ', '石狩郡新篠津村', 'イシカリグンシンシノツムラ', '川下', 'カワシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩郡新篠津村中原', '01', '01304', '0681153', '北海道', 'ホッカイドウ', '石狩郡新篠津村', 'イシカリグンシンシノツムラ', '中原', 'ナカハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市北村北都新中島', '01', '01210', '0681161', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '北村北都', 'キタムラホクト', null, null, '新中島', 'シンナカジマ');
INSERT INTO `ms_addresses` VALUES ('83747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市北村豊正', '01', '01210', '0681201', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '北村豊正', 'キタムラホウセイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市北村中小屋', '01', '01210', '0681202', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '北村中小屋', 'キタムラナカゴヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市北村大願', '01', '01210', '0681203', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '北村大願', 'キタムラオオネガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市北村栄町', '01', '01210', '0681204', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '北村栄町', 'キタムラサカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市北村豊里', '01', '01210', '0681205', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '北村豊里', 'キタムラトヨサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市北村北都', '01', '01210', '0681211', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '北村北都', 'キタムラホクト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市北村中央', '01', '01210', '0681212', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '北村中央', 'キタムラチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市北村赤川', '01', '01210', '0681213', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '北村赤川', 'キタムラアカガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市北村美唄達布', '01', '01210', '0681214', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '北村美唄達布', 'キタムラビバイタップ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市北村幌達布', '01', '01210', '0681215', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '北村幌達布', 'キタムラホロタップ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道樺戸郡月形町雁里', '01', '01430', '0681231', '北海道', 'ホッカイドウ', '樺戸郡月形町', 'カバトグンツキガタチョウ', '雁里', 'カリサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市', '31', '31203', '6820000', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('83761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市穴窪', '31', '31203', '6820001', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '穴窪', 'アナクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市中江', '31', '31203', '6820002', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '中江', 'ナカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市新田', '31', '31203', '6820003', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '新田', 'シンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市古川沢', '31', '31203', '6820004', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '古川沢', 'フルカワサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市下古川', '31', '31203', '6820005', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '下古川', 'シモフルカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市井手畑', '31', '31203', '6820006', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '井手畑', 'イデバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市大塚', '31', '31203', '6820011', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '大塚', 'オオツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市清谷', '31', '31203', '6820012', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '清谷', 'セイダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市福庭', '31', '31203', '6820013', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '福庭', 'フクバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市海田東町', '31', '31203', '6820014', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '海田東町', 'カイダヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市海田南町', '31', '31203', '6820015', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '海田南町', 'カイダミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市海田西町', '31', '31203', '6820016', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '海田西町', 'カイダニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市清谷町', '31', '31203', '6820017', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '清谷町', 'セイダニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市福庭町', '31', '31203', '6820018', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '福庭町', 'フクバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市上井', '31', '31203', '6820021', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '上井', 'アゲイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市上井町', '31', '31203', '6820022', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '上井町', 'アゲイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市山根', '31', '31203', '6820023', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '山根', 'ヤマネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市伊木', '31', '31203', '6820024', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '伊木', 'イギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市八屋', '31', '31203', '6820025', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '八屋', 'ヤツヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市下余戸', '31', '31203', '6820031', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '下余戸', 'シモヨド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市上余戸', '31', '31203', '6820032', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '上余戸', 'カミヨド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市栗尾', '31', '31203', '6820033', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '栗尾', 'クリオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市大原', '31', '31203', '6820034', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '大原', 'オハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市広栄町', '31', '31203', '6820035', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '広栄町', 'コウエイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市虹ケ丘町', '31', '31203', '6820036', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '虹ケ丘町', 'ニジガオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市河北町', '31', '31203', '6820041', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '河北町', 'カホクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市大平町', '31', '31203', '6820042', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '大平町', 'オオヒラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市天神町', '31', '31203', '6820043', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '天神町', 'テンジンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市小田', '31', '31203', '6820044', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '小田', 'コダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市小田東', '31', '31203', '6820045', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '小田東', 'コダヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡三朝町', '31', '31364', '6820100', '鳥取県', 'トットリケン', '東伯郡三朝町', 'トウハクグンミササチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('83792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡三朝町大瀬', '31', '31364', '6820121', '鳥取県', 'トットリケン', '東伯郡三朝町', 'トウハクグンミササチョウ', '大瀬', 'オオゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡三朝町山田', '31', '31364', '6820122', '鳥取県', 'トットリケン', '東伯郡三朝町', 'トウハクグンミササチョウ', '山田', 'ヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡三朝町恋谷', '31', '31364', '6820123', '鳥取県', 'トットリケン', '東伯郡三朝町', 'トウハクグンミササチョウ', '恋谷', 'コイダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡三朝町三朝', '31', '31364', '6820123', '鳥取県', 'トットリケン', '東伯郡三朝町', 'トウハクグンミササチョウ', '三朝', 'ミササ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡三朝町砂原', '31', '31364', '6820124', '鳥取県', 'トットリケン', '東伯郡三朝町', 'トウハクグンミササチョウ', '砂原', 'スナワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡三朝町徳本', '31', '31364', '6820125', '鳥取県', 'トットリケン', '東伯郡三朝町', 'トウハクグンミササチョウ', '徳本', 'トクモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡三朝町横手', '31', '31364', '6820125', '鳥取県', 'トットリケン', '東伯郡三朝町', 'トウハクグンミササチョウ', '横手', 'ヨコテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡三朝町俵原', '31', '31364', '6820131', '鳥取県', 'トットリケン', '東伯郡三朝町', 'トウハクグンミササチョウ', '俵原', 'タワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡三朝町三徳', '31', '31364', '6820132', '鳥取県', 'トットリケン', '東伯郡三朝町', 'トウハクグンミササチョウ', '三徳', 'ミトク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡三朝町桜ケ丘', '31', '31364', '6820133', '鳥取県', 'トットリケン', '東伯郡三朝町', 'トウハクグンミササチョウ', '桜ケ丘', 'サクラガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡三朝町吉田', '31', '31364', '6820133', '鳥取県', 'トットリケン', '東伯郡三朝町', 'トウハクグンミササチョウ', '吉田', 'ヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡三朝町余戸', '31', '31364', '6820134', '鳥取県', 'トットリケン', '東伯郡三朝町', 'トウハクグンミササチョウ', '余戸', 'ヨド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡三朝町片柴', '31', '31364', '6820135', '鳥取県', 'トットリケン', '東伯郡三朝町', 'トウハクグンミササチョウ', '片柴', 'カタシバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡三朝町坂本', '31', '31364', '6820136', '鳥取県', 'トットリケン', '東伯郡三朝町', 'トウハクグンミササチョウ', '坂本', 'サカモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡三朝町中津', '31', '31364', '6820141', '鳥取県', 'トットリケン', '東伯郡三朝町', 'トウハクグンミササチョウ', '中津', 'ナカツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡三朝町神倉', '31', '31364', '6820142', '鳥取県', 'トットリケン', '東伯郡三朝町', 'トウハクグンミササチョウ', '神倉', 'カンノクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡三朝町東小鹿', '31', '31364', '6820143', '鳥取県', 'トットリケン', '東伯郡三朝町', 'トウハクグンミササチョウ', '東小鹿', 'ヒガシオシカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡三朝町西小鹿', '31', '31364', '6820144', '鳥取県', 'トットリケン', '東伯郡三朝町', 'トウハクグンミササチョウ', '西小鹿', 'ニシオシカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡三朝町西尾', '31', '31364', '6820145', '鳥取県', 'トットリケン', '東伯郡三朝町', 'トウハクグンミササチョウ', '西尾', 'ニシオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡三朝町高橋', '31', '31364', '6820146', '鳥取県', 'トットリケン', '東伯郡三朝町', 'トウハクグンミササチョウ', '高橋', 'タカハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡三朝町今泉', '31', '31364', '6820151', '鳥取県', 'トットリケン', '東伯郡三朝町', 'トウハクグンミササチョウ', '今泉', 'イマイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡三朝町若宮', '31', '31364', '6820151', '鳥取県', 'トットリケン', '東伯郡三朝町', 'トウハクグンミササチョウ', '若宮', 'ワカミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡三朝町本泉', '31', '31364', '6820152', '鳥取県', 'トットリケン', '東伯郡三朝町', 'トウハクグンミササチョウ', '本泉', 'モトイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡三朝町天神', '31', '31364', '6820153', '鳥取県', 'トットリケン', '東伯郡三朝町', 'トウハクグンミササチョウ', '天神', 'テンジン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡三朝町森', '31', '31364', '6820153', '鳥取県', 'トットリケン', '東伯郡三朝町', 'トウハクグンミササチョウ', '森', 'モリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡三朝町鎌田', '31', '31364', '6820154', '鳥取県', 'トットリケン', '東伯郡三朝町', 'トウハクグンミササチョウ', '鎌田', 'カマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡三朝町吉尾', '31', '31364', '6820155', '鳥取県', 'トットリケン', '東伯郡三朝町', 'トウハクグンミササチョウ', '吉尾', 'ヨシオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡三朝町下谷', '31', '31364', '6820156', '鳥取県', 'トットリケン', '東伯郡三朝町', 'トウハクグンミササチョウ', '下谷', 'シモダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡三朝町小河内', '31', '31364', '6820157', '鳥取県', 'トットリケン', '東伯郡三朝町', 'トウハクグンミササチョウ', '小河内', 'オゴチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡三朝町笏賀', '31', '31364', '6820158', '鳥取県', 'トットリケン', '東伯郡三朝町', 'トウハクグンミササチョウ', '笏賀', 'ツガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡三朝町福田', '31', '31364', '6820159', '鳥取県', 'トットリケン', '東伯郡三朝町', 'トウハクグンミササチョウ', '福田', 'フクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡三朝町柿谷', '31', '31364', '6820161', '鳥取県', 'トットリケン', '東伯郡三朝町', 'トウハクグンミササチョウ', '柿谷', 'カキダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡三朝町鉛山', '31', '31364', '6820162', '鳥取県', 'トットリケン', '東伯郡三朝町', 'トウハクグンミササチョウ', '鉛山', 'ナマリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡三朝町福吉', '31', '31364', '6820163', '鳥取県', 'トットリケン', '東伯郡三朝町', 'トウハクグンミササチョウ', '福吉', 'フクヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡三朝町湯谷', '31', '31364', '6820171', '鳥取県', 'トットリケン', '東伯郡三朝町', 'トウハクグンミササチョウ', '湯谷', 'ユタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡三朝町赤松', '31', '31364', '6820172', '鳥取県', 'トットリケン', '東伯郡三朝町', 'トウハクグンミササチョウ', '赤松', 'アカマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡三朝町恩地', '31', '31364', '6820173', '鳥取県', 'トットリケン', '東伯郡三朝町', 'トウハクグンミササチョウ', '恩地', 'オンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡三朝町助谷', '31', '31364', '6820176', '鳥取県', 'トットリケン', '東伯郡三朝町', 'トウハクグンミササチョウ', '助谷', 'スケダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡三朝町大柿', '31', '31364', '6820177', '鳥取県', 'トットリケン', '東伯郡三朝町', 'トウハクグンミササチョウ', '大柿', 'オオガキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡三朝町牧', '31', '31364', '6820178', '鳥取県', 'トットリケン', '東伯郡三朝町', 'トウハクグンミササチョウ', '牧', 'マキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡三朝町木地山', '31', '31364', '6820301', '鳥取県', 'トットリケン', '東伯郡三朝町', 'トウハクグンミササチョウ', '木地山', 'キジヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡三朝町加谷', '31', '31364', '6820302', '鳥取県', 'トットリケン', '東伯郡三朝町', 'トウハクグンミササチョウ', '加谷', 'カダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡三朝町穴鴨', '31', '31364', '6820303', '鳥取県', 'トットリケン', '東伯郡三朝町', 'トウハクグンミササチョウ', '穴鴨', 'アナガモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡三朝町福山', '31', '31364', '6820311', '鳥取県', 'トットリケン', '東伯郡三朝町', 'トウハクグンミササチョウ', '福山', 'フクヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡三朝町下西谷', '31', '31364', '6820312', '鳥取県', 'トットリケン', '東伯郡三朝町', 'トウハクグンミササチョウ', '下西谷', 'シモニシダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡三朝町上西谷', '31', '31364', '6820313', '鳥取県', 'トットリケン', '東伯郡三朝町', 'トウハクグンミササチョウ', '上西谷', 'カミニシダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡三朝町田代', '31', '31364', '6820314', '鳥取県', 'トットリケン', '東伯郡三朝町', 'トウハクグンミササチョウ', '田代', 'タシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡三朝町大谷', '31', '31364', '6820315', '鳥取県', 'トットリケン', '東伯郡三朝町', 'トウハクグンミササチョウ', '大谷', 'オオタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡三朝町下畑', '31', '31364', '6820316', '鳥取県', 'トットリケン', '東伯郡三朝町', 'トウハクグンミササチョウ', '下畑', 'シモバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡三朝町福本', '31', '31364', '6820317', '鳥取県', 'トットリケン', '東伯郡三朝町', 'トウハクグンミササチョウ', '福本', 'フクモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡三朝町曹源寺', '31', '31364', '6820374', '鳥取県', 'トットリケン', '東伯郡三朝町', 'トウハクグンミササチョウ', '曹源寺', 'ソウゲンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡三朝町久原', '31', '31364', '6820375', '鳥取県', 'トットリケン', '東伯郡三朝町', 'トウハクグンミササチョウ', '久原', 'クバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市関金町安歩', '31', '31203', '6820401', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '関金町安歩', 'セキガネチョウアブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市関金町大鳥居', '31', '31203', '6820402', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '関金町大鳥居', 'セキガネチョウオオドリイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市関金町松河原', '31', '31203', '6820403', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '関金町松河原', 'セキガネチョウマツガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市関金町泰久寺', '31', '31203', '6820404', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '関金町泰久寺', 'セキガネチョウタイキュウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市関金町関金宿', '31', '31203', '6820411', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '関金町関金宿', 'セキガネチョウセキガネシュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市関金町山口', '31', '31203', '6820412', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '関金町山口', 'セキガネチョウヤマグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市関金町郡家', '31', '31203', '6820413', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '関金町郡家', 'セキガネチョウコオゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市関金町今西', '31', '31203', '6820421', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '関金町今西', 'セキガネチョウイマニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市関金町堀', '31', '31203', '6820422', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '関金町堀', 'セキガネチョウホリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市関金町明高', '31', '31203', '6820423', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '関金町明高', 'セキガネチョウミョウコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市関金町米富', '31', '31203', '6820431', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '関金町米富', 'セキガネチョウヨネドメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市関金町福原', '31', '31203', '6820432', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '関金町福原', 'セキガネチョウフクハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市関金町小泉', '31', '31203', '6820433', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '関金町小泉', 'セキガネチョウコイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市関金町野添', '31', '31203', '6820434', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '関金町野添', 'セキガネチョウノゾエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市下米積', '31', '31203', '6820601', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '下米積', 'シモヨナヅミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市上米積', '31', '31203', '6820602', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '上米積', 'カミヨナヅミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市三江', '31', '31203', '6820603', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '三江', 'ミエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市福本', '31', '31203', '6820604', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '福本', 'フクモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市福富', '31', '31203', '6820605', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '福富', 'フクドミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市沢谷', '31', '31203', '6820606', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '沢谷', 'サワダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市尾田', '31', '31203', '6820607', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '尾田', 'オダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市杉野', '31', '31203', '6820611', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '杉野', 'スギノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市中野', '31', '31203', '6820612', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '中野', 'ナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市志津', '31', '31203', '6820613', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '志津', 'シツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市森', '31', '31203', '6820615', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '森', 'モリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市忰谷', '31', '31203', '6820621', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '忰谷', 'カセダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市長谷', '31', '31203', '6820622', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '長谷', 'ナガタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市大河内', '31', '31203', '6820623', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '大河内', 'オオカチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市般若', '31', '31203', '6820624', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '般若', 'ハンニャ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市椋波', '31', '31203', '6820625', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '椋波', 'モクナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市立見', '31', '31203', '6820626', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '立見', 'タテミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市上大立', '31', '31203', '6820631', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '上大立', 'カミオオタチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市大立', '31', '31203', '6820632', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '大立', 'オオタチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市河来見', '31', '31203', '6820633', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '河来見', 'カワクルミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市桜', '31', '31203', '6820634', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '桜', 'サクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市服部', '31', '31203', '6820635', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '服部', 'ハットリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市今在家', '31', '31203', '6820641', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '今在家', 'イマザイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市上福田', '31', '31203', '6820642', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '上福田', 'カミフクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市下福田', '31', '31203', '6820643', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '下福田', 'シモフクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市福積', '31', '31203', '6820644', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '福積', 'フクヅミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市岡', '31', '31203', '6820645', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '岡', 'オカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡湯梨浜町', '31', '31370', '6820700', '鳥取県', 'トットリケン', '東伯郡湯梨浜町', 'トウハクグンユリハマチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('83891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡湯梨浜町宇野', '31', '31370', '6820701', '鳥取県', 'トットリケン', '東伯郡湯梨浜町', 'トウハクグンユリハマチョウ', '宇野', 'ウノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡湯梨浜町橋津', '31', '31370', '6820702', '鳥取県', 'トットリケン', '東伯郡湯梨浜町', 'トウハクグンユリハマチョウ', '橋津', 'ハシヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡湯梨浜町上橋津', '31', '31370', '6820703', '鳥取県', 'トットリケン', '東伯郡湯梨浜町', 'トウハクグンユリハマチョウ', '上橋津', 'カミハシヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡湯梨浜町南谷', '31', '31370', '6820704', '鳥取県', 'トットリケン', '東伯郡湯梨浜町', 'トウハクグンユリハマチョウ', '南谷', 'ミナミダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡湯梨浜町下浅津', '31', '31370', '6820711', '鳥取県', 'トットリケン', '東伯郡湯梨浜町', 'トウハクグンユリハマチョウ', '下浅津', 'シモアソヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡湯梨浜町上浅津', '31', '31370', '6820712', '鳥取県', 'トットリケン', '東伯郡湯梨浜町', 'トウハクグンユリハマチョウ', '上浅津', 'カミアソヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡湯梨浜町光吉', '31', '31370', '6820713', '鳥取県', 'トットリケン', '東伯郡湯梨浜町', 'トウハクグンユリハマチョウ', '光吉', 'ミツヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡湯梨浜町赤池', '31', '31370', '6820714', '鳥取県', 'トットリケン', '東伯郡湯梨浜町', 'トウハクグンユリハマチョウ', '赤池', 'アカイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡湯梨浜町はわい温泉', '31', '31370', '6820715', '鳥取県', 'トットリケン', '東伯郡湯梨浜町', 'トウハクグンユリハマチョウ', 'はわい温泉', 'ハワイオンセン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡湯梨浜町田後', '31', '31370', '6820721', '鳥取県', 'トットリケン', '東伯郡湯梨浜町', 'トウハクグンユリハマチョウ', '田後', 'タジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡湯梨浜町はわい長瀬', '31', '31370', '6820722', '鳥取県', 'トットリケン', '東伯郡湯梨浜町', 'トウハクグンユリハマチョウ', 'はわい長瀬', 'ハワイナガセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡湯梨浜町久留', '31', '31370', '6820723', '鳥取県', 'トットリケン', '東伯郡湯梨浜町', 'トウハクグンユリハマチョウ', '久留', 'ヒサドメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡湯梨浜町水下', '31', '31370', '6820724', '鳥取県', 'トットリケン', '東伯郡湯梨浜町', 'トウハクグンユリハマチョウ', '水下', 'ミズオチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市巌城', '31', '31203', '6820801', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '巌城', 'イワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市東巌城町', '31', '31203', '6820802', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '東巌城町', 'ヒガシイワキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市見日町', '31', '31203', '6820803', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '見日町', 'ミルカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市東昭和町', '31', '31203', '6820804', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '東昭和町', 'ヒガシショウワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市南昭和町', '31', '31203', '6820805', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '南昭和町', 'ミナミショウワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市昭和町', '31', '31203', '6820806', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '昭和町', 'ショウワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市幸町', '31', '31203', '6820807', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '幸町', 'サイワイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市上灘町', '31', '31203', '6820811', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '上灘町', 'ウワナダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市下田中町', '31', '31203', '6820812', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '下田中町', 'シモタナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市円谷町', '31', '31203', '6820813', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '円谷町', 'エンダニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市米田町', '31', '31203', '6820814', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '米田町', 'ヨネダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市新陽町', '31', '31203', '6820815', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '新陽町', 'シンヨウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市駄経寺町', '31', '31203', '6820816', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '駄経寺町', 'ダキョウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市住吉町', '31', '31203', '6820817', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '住吉町', 'スミヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市魚町', '31', '31203', '6820821', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '魚町', 'ウオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市葵町', '31', '31203', '6820822', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '葵町', 'アオイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市東町', '31', '31203', '6820823', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '東町', 'ヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市仲ノ町', '31', '31203', '6820824', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '仲ノ町', 'ナカノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市西仲町', '31', '31203', '6820825', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '西仲町', 'ニシナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市東仲町', '31', '31203', '6820826', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '東仲町', 'ヒガシナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市八幡町', '31', '31203', '6820831', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '八幡町', 'ハチマンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市富海', '31', '31203', '6820832', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '富海', 'トドミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市東鴨新町', '31', '31203', '6820833', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '東鴨新町', 'ヒガシガモシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市東鴨', '31', '31203', '6820834', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '東鴨', 'ヒガシガモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市長坂町', '31', '31203', '6820835', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '長坂町', 'ナガサカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市長坂新町', '31', '31203', '6820836', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '長坂新町', 'ナガサカシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市下大江', '31', '31203', '6820837', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '下大江', 'シモオオエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市大宮', '31', '31203', '6820841', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '大宮', 'オオミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市岩倉', '31', '31203', '6820842', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '岩倉', 'イワクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市菅原', '31', '31203', '6820843', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '菅原', 'スゲガハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市広瀬', '31', '31203', '6820844', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '広瀬', 'ヒロセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市耳', '31', '31203', '6820845', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '耳', 'ミミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市鴨河内', '31', '31203', '6820846', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '鴨河内', 'カモゴウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市福山', '31', '31203', '6820847', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '福山', 'フクヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市西倉吉町', '31', '31203', '6820851', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '西倉吉町', 'ニシクラヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市丸山町', '31', '31203', '6820852', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '丸山町', 'マルヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市余戸谷町', '31', '31203', '6820853', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '余戸谷町', 'ヨドヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市みどり町', '31', '31203', '6820854', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', 'みどり町', 'ミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市生田', '31', '31203', '6820855', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '生田', 'イクタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市中河原', '31', '31203', '6820856', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '中河原', 'ナカガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市北野', '31', '31203', '6820857', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '北野', 'キタノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市新町', '31', '31203', '6820861', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市西町', '31', '31203', '6820862', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '西町', 'ニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市瀬崎町', '31', '31203', '6820863', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '瀬崎町', 'セサキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市鍛冶町', '31', '31203', '6820864', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '鍛冶町', 'カジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市越中町', '31', '31203', '6820865', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '越中町', 'エッチュウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市広瀬町', '31', '31203', '6820866', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '広瀬町', 'ヒロセマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市越殿町', '31', '31203', '6820867', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '越殿町', 'コシドノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市旭田町', '31', '31203', '6820871', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '旭田町', 'アサヒダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市福吉町', '31', '31203', '6820872', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '福吉町', 'フクヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市東岩倉町', '31', '31203', '6820873', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '東岩倉町', 'ヒガシイワクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市西岩倉町', '31', '31203', '6820874', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '西岩倉町', 'ニシイワクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市金森町', '31', '31203', '6820875', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '金森町', 'カナモリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市宮川町', '31', '31203', '6820881', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '宮川町', 'ミヤガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市湊町', '31', '31203', '6820882', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '湊町', 'ミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市荒神町', '31', '31203', '6820883', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '荒神町', 'コウジンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市研屋町', '31', '31203', '6820884', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '研屋町', 'トギヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市堺町', '31', '31203', '6820885', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '堺町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市大正町', '31', '31203', '6820886', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '大正町', 'タイショウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市明治町', '31', '31203', '6820887', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '明治町', 'メイジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市穴沢', '31', '31203', '6820901', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '穴沢', 'アナザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市上神', '31', '31203', '6820902', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '上神', 'カズワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市北面', '31', '31203', '6820903', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '北面', 'キタモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市尾原', '31', '31203', '6820904', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '尾原', 'オワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市別所', '31', '31203', '6820905', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '別所', 'ベッシヨ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市寺谷', '31', '31203', '6820911', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '寺谷', 'テラダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市和田', '31', '31203', '6820912', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '和田', 'ワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市和田東町', '31', '31203', '6820913', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '和田東町', 'ワダヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市馬場町', '31', '31203', '6820914', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '馬場町', 'ババチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市不入岡', '31', '31203', '6820915', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '不入岡', 'フニオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市西福守町', '31', '31203', '6820921', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '西福守町', 'ニシフクモリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市福守町', '31', '31203', '6820922', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '福守町', 'フクモリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市鴨川町', '31', '31203', '6820923', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '鴨川町', 'カモガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市河原町', '31', '31203', '6820924', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '河原町', 'カワラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市秋喜', '31', '31203', '6820925', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '秋喜', 'シュウキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市秋喜西町', '31', '31203', '6820926', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '秋喜西町', 'シュウキニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市小鴨', '31', '31203', '6820931', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '小鴨', 'オガモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市蔵内', '31', '31203', '6820932', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '蔵内', 'クラウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市石塚', '31', '31203', '6820933', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '石塚', 'イシヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市上古川', '31', '31203', '6820934', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '上古川', 'カミフルカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市大谷', '31', '31203', '6820941', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '大谷', 'オオタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市国府', '31', '31203', '6820942', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '国府', 'コウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市国分寺', '31', '31203', '6820943', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '国分寺', 'コクブンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市福光', '31', '31203', '6820944', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '福光', 'フクミツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市黒見', '31', '31203', '6820945', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '黒見', 'クロミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市横田', '31', '31203', '6820946', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '横田', 'ヨコタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市大沢', '31', '31203', '6820947', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '大沢', 'オオサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市大谷茶屋', '31', '31203', '6820948', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '大谷茶屋', 'オオタニチャヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市津原', '31', '31203', '6820951', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '津原', 'ツワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市鋤', '31', '31203', '6820952', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '鋤', 'スキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市半坂', '31', '31203', '6820953', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '半坂', 'ハンザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県倉吉市谷', '31', '31203', '6820954', '鳥取県', 'トットリケン', '倉吉市', 'クラヨシシ', '谷', 'タニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道三笠市', '01', '01222', '0682100', '北海道', 'ホッカイドウ', '三笠市', 'ミカサシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('83997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道三笠市桂沢', '01', '01222', '0682101', '北海道', 'ホッカイドウ', '三笠市', 'ミカサシ', '桂沢', 'カツラザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道三笠市西桂沢', '01', '01222', '0682102', '北海道', 'ホッカイドウ', '三笠市', 'ミカサシ', '西桂沢', 'ニシカツラザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('83999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道三笠市奔別新町', '01', '01222', '0682103', '北海道', 'ホッカイドウ', '三笠市', 'ミカサシ', '奔別新町', 'ポンベツシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道三笠市東清住町', '01', '01222', '0682104', '北海道', 'ホッカイドウ', '三笠市', 'ミカサシ', '東清住町', 'ヒガシキヨズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道三笠市清住町', '01', '01222', '0682105', '北海道', 'ホッカイドウ', '三笠市', 'ミカサシ', '清住町', 'キヨズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道三笠市美園町', '01', '01222', '0682106', '北海道', 'ホッカイドウ', '三笠市', 'ミカサシ', '美園町', 'ミソノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道三笠市若草町', '01', '01222', '0682107', '北海道', 'ホッカイドウ', '三笠市', 'ミカサシ', '若草町', 'ワカクサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道三笠市柏町', '01', '01222', '0682108', '北海道', 'ホッカイドウ', '三笠市', 'ミカサシ', '柏町', 'カシワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道三笠市幾春別錦町', '01', '01222', '0682111', '北海道', 'ホッカイドウ', '三笠市', 'ミカサシ', '幾春別錦町', 'イクシュンベツニシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道三笠市幾春別川向町', '01', '01222', '0682112', '北海道', 'ホッカイドウ', '三笠市', 'ミカサシ', '幾春別川向町', 'イクシュンベツカワムカイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道三笠市幾春別山手町', '01', '01222', '0682113', '北海道', 'ホッカイドウ', '三笠市', 'ミカサシ', '幾春別山手町', 'イクシュンベツヤマテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道三笠市幾春別栗丘町', '01', '01222', '0682114', '北海道', 'ホッカイドウ', '三笠市', 'ミカサシ', '幾春別栗丘町', 'イクシュンベツクリオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道三笠市幾春別滝見町', '01', '01222', '0682115', '北海道', 'ホッカイドウ', '三笠市', 'ミカサシ', '幾春別滝見町', 'イクシュンベツタキミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道三笠市幾春別町', '01', '01222', '0682116', '北海道', 'ホッカイドウ', '三笠市', 'ミカサシ', '幾春別町', 'イクシュンベツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道三笠市幾春別中島町', '01', '01222', '0682117', '北海道', 'ホッカイドウ', '三笠市', 'ミカサシ', '幾春別中島町', 'イクシュンベツナカジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道三笠市幾春別千住町', '01', '01222', '0682118', '北海道', 'ホッカイドウ', '三笠市', 'ミカサシ', '幾春別千住町', 'イクシュンベツセンジュウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道三笠市弥生桜木町', '01', '01222', '0682121', '北海道', 'ホッカイドウ', '三笠市', 'ミカサシ', '弥生桜木町', 'ヤヨイサクラギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道三笠市弥生並木町', '01', '01222', '0682122', '北海道', 'ホッカイドウ', '三笠市', 'ミカサシ', '弥生並木町', 'ヤヨイナミキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道三笠市弥生桃山町', '01', '01222', '0682123', '北海道', 'ホッカイドウ', '三笠市', 'ミカサシ', '弥生桃山町', 'ヤヨイモモヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道三笠市弥生花園町', '01', '01222', '0682124', '北海道', 'ホッカイドウ', '三笠市', 'ミカサシ', '弥生花園町', 'ヤヨイハナゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道三笠市弥生橘町', '01', '01222', '0682125', '北海道', 'ホッカイドウ', '三笠市', 'ミカサシ', '弥生橘町', 'ヤヨイタチバナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道三笠市弥生町', '01', '01222', '0682126', '北海道', 'ホッカイドウ', '三笠市', 'ミカサシ', '弥生町', 'ヤヨイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道三笠市弥生柳町', '01', '01222', '0682127', '北海道', 'ホッカイドウ', '三笠市', 'ミカサシ', '弥生柳町', 'ヤヨイヤナギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道三笠市弥生藤枝町', '01', '01222', '0682128', '北海道', 'ホッカイドウ', '三笠市', 'ミカサシ', '弥生藤枝町', 'ヤヨイフジエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道三笠市唐松春光町', '01', '01222', '0682131', '北海道', 'ホッカイドウ', '三笠市', 'ミカサシ', '唐松春光町', 'トウマツシュンコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道三笠市唐松緑町', '01', '01222', '0682132', '北海道', 'ホッカイドウ', '三笠市', 'ミカサシ', '唐松緑町', 'トウマツミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道三笠市唐松常盤町', '01', '01222', '0682133', '北海道', 'ホッカイドウ', '三笠市', 'ミカサシ', '唐松常盤町', 'トウマツトキワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道三笠市唐松千代田町', '01', '01222', '0682134', '北海道', 'ホッカイドウ', '三笠市', 'ミカサシ', '唐松千代田町', 'トウマツチヨダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道三笠市唐松町', '01', '01222', '0682135', '北海道', 'ホッカイドウ', '三笠市', 'ミカサシ', '唐松町', 'トウマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道三笠市唐松栄町', '01', '01222', '0682136', '北海道', 'ホッカイドウ', '三笠市', 'ミカサシ', '唐松栄町', 'トウマツサカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道三笠市唐松青山町', '01', '01222', '0682137', '北海道', 'ホッカイドウ', '三笠市', 'ミカサシ', '唐松青山町', 'トウマツアオヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道三笠市本町', '01', '01222', '0682141', '北海道', 'ホッカイドウ', '三笠市', 'ミカサシ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道三笠市幌内住吉町', '01', '01222', '0682142', '北海道', 'ホッカイドウ', '三笠市', 'ミカサシ', '幌内住吉町', 'ホロナイスミヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道三笠市幌内北星町', '01', '01222', '0682143', '北海道', 'ホッカイドウ', '三笠市', 'ミカサシ', '幌内北星町', 'ホロナイホクセイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道三笠市幌内金谷町', '01', '01222', '0682144', '北海道', 'ホッカイドウ', '三笠市', 'ミカサシ', '幌内金谷町', 'ホロナイカナヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道三笠市幌内町', '01', '01222', '0682145', '北海道', 'ホッカイドウ', '三笠市', 'ミカサシ', '幌内町', 'ホロナイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道三笠市幌内春日町', '01', '01222', '0682146', '北海道', 'ホッカイドウ', '三笠市', 'ミカサシ', '幌内春日町', 'ホロナイカスガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道三笠市幌内新栄町', '01', '01222', '0682147', '北海道', 'ホッカイドウ', '三笠市', 'ミカサシ', '幌内新栄町', 'ホロナイシンエイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道三笠市幌内初音町', '01', '01222', '0682148', '北海道', 'ホッカイドウ', '三笠市', 'ミカサシ', '幌内初音町', 'ホロナイハツネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道三笠市有明町', '01', '01222', '0682151', '北海道', 'ホッカイドウ', '三笠市', 'ミカサシ', '有明町', 'アリアケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道三笠市多賀町', '01', '01222', '0682152', '北海道', 'ホッカイドウ', '三笠市', 'ミカサシ', '多賀町', 'タガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道三笠市幸町', '01', '01222', '0682153', '北海道', 'ホッカイドウ', '三笠市', 'ミカサシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道三笠市高美町', '01', '01222', '0682154', '北海道', 'ホッカイドウ', '三笠市', 'ミカサシ', '高美町', 'タカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道三笠市榊町', '01', '01222', '0682155', '北海道', 'ホッカイドウ', '三笠市', 'ミカサシ', '榊町', 'サカキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道三笠市宮本町', '01', '01222', '0682156', '北海道', 'ホッカイドウ', '三笠市', 'ミカサシ', '宮本町', 'ミヤモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道三笠市若松町', '01', '01222', '0682157', '北海道', 'ホッカイドウ', '三笠市', 'ミカサシ', '若松町', 'ワカマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道三笠市堤町', '01', '01222', '0682158', '北海道', 'ホッカイドウ', '三笠市', 'ミカサシ', '堤町', 'ツツミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道三笠市本郷町', '01', '01222', '0682161', '北海道', 'ホッカイドウ', '三笠市', 'ミカサシ', '本郷町', 'ホンゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道三笠市川内', '01', '01222', '0682162', '北海道', 'ホッカイドウ', '三笠市', 'ミカサシ', '川内', 'カワナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道三笠市達布', '01', '01222', '0682163', '北海道', 'ホッカイドウ', '三笠市', 'ミカサシ', '達布', 'タップ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道三笠市いちきしり', '01', '01222', '0682164', '北海道', 'ホッカイドウ', '三笠市', 'ミカサシ', 'いちきしり', 'イチキシリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道三笠市岡山', '01', '01222', '0682165', '北海道', 'ホッカイドウ', '三笠市', 'ミカサシ', '岡山', 'オカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道三笠市萱野', '01', '01222', '0682166', '北海道', 'ホッカイドウ', '三笠市', 'ミカサシ', '萱野', 'カヤノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道三笠市大里', '01', '01222', '0682167', '北海道', 'ホッカイドウ', '三笠市', 'ミカサシ', '大里', 'オオサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道三笠市美和', '01', '01222', '0682168', '北海道', 'ホッカイドウ', '三笠市', 'ミカサシ', '美和', 'ミワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市光珠内町南', '01', '01215', '0682181', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '光珠内町南', 'コウシュナイチョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市', '31', '31202', '6830000', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('84064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市皆生温泉', '31', '31202', '6830001', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '皆生温泉', 'カイケオンセン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市皆生新田', '31', '31202', '6830002', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '皆生新田', 'カイケシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市皆生', '31', '31202', '6830003', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '皆生', 'カイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市上福原', '31', '31202', '6830004', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '上福原', 'カミフクバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市中島', '31', '31202', '6830005', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '中島', 'ナカシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市車尾', '31', '31202', '6830006', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '車尾', 'クズモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市観音寺', '31', '31202', '6830007', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '観音寺', 'カンノンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市車尾南', '31', '31202', '6830008', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '車尾南', 'クズモミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市観音寺新町', '31', '31202', '6830009', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '観音寺新町', 'カンノンジシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市福市', '31', '31202', '6830011', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '福市', 'フクイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市八幡', '31', '31202', '6830012', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '八幡', 'ヤワタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市諏訪', '31', '31202', '6830013', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '諏訪', 'スワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市永江', '31', '31202', '6830014', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '永江', 'ナガエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市日原', '31', '31202', '6830015', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '日原', 'ヒバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市奥谷', '31', '31202', '6830016', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '奥谷', 'オクノタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市宗像', '31', '31202', '6830017', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '宗像', 'ムナカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市石井', '31', '31202', '6830021', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '石井', 'イシイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市奈喜良', '31', '31202', '6830022', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '奈喜良', 'ナギラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市橋本', '31', '31202', '6830023', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '橋本', 'ハシモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市吉谷', '31', '31202', '6830024', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '吉谷', 'ヨシタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市古市', '31', '31202', '6830025', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '古市', 'フルイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市新山', '31', '31202', '6830026', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '新山', 'ニイヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市陰田町', '31', '31202', '6830027', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '陰田町', 'インダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市東山町', '31', '31202', '6830031', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '東山町', 'ヒガシヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市陽田町', '31', '31202', '6830032', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '陽田町', 'ヨウデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市長砂町', '31', '31202', '6830033', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '長砂町', 'ナガスナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市美吉', '31', '31202', '6830034', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '美吉', 'ミヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市目久美町', '31', '31202', '6830035', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '目久美町', 'メグミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市弥生町', '31', '31202', '6830036', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '弥生町', 'ヤヨイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市昭和町', '31', '31202', '6830037', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '昭和町', 'ショウワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市茶町', '31', '31202', '6830041', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '茶町', 'チャマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市塩町', '31', '31202', '6830042', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '塩町', 'シオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市末広町', '31', '31202', '6830043', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '末広町', 'スエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市大工町', '31', '31202', '6830044', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '大工町', 'ダイクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市大谷町', '31', '31202', '6830045', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '大谷町', 'オオダニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市愛宕町', '31', '31202', '6830046', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '愛宕町', 'アタゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市祇園町', '31', '31202', '6830047', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '祇園町', 'ギオンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市勝田町', '31', '31202', '6830051', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '勝田町', 'カンダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市博労町', '31', '31202', '6830052', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '博労町', 'バクロウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市明治町', '31', '31202', '6830053', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '明治町', 'メイジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市糀町', '31', '31202', '6830054', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '糀町', 'コウジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市冨士見町', '31', '31202', '6830055', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '冨士見町', 'フジミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市四日市町', '31', '31202', '6830061', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '四日市町', 'ヨッカイチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市紺屋町', '31', '31202', '6830062', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '紺屋町', 'コウヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市法勝寺町', '31', '31202', '6830063', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '法勝寺町', 'ホツショウジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市道笑町', '31', '31202', '6830064', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '道笑町', 'ドウショウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市万能町', '31', '31202', '6830065', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '万能町', 'マンノウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市日野町', '31', '31202', '6830066', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '日野町', 'ヒノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市東町', '31', '31202', '6830067', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '東町', 'ヒガシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市大篠津町', '31', '31202', '6830101', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '大篠津町', 'オオシノヅチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市和田町', '31', '31202', '6830102', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '和田町', 'ワダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市富益町', '31', '31202', '6830103', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '富益町', 'トミマスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市大崎', '31', '31202', '6830104', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '大崎', 'オオザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市葭津', '31', '31202', '6830105', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '葭津', 'ヨシヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡南部町天万', '31', '31389', '6830201', '鳥取県', 'トットリケン', '西伯郡南部町', 'サイハクグンナンブチョウ', '天万', 'テンマン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡南部町寺内', '31', '31389', '6830202', '鳥取県', 'トットリケン', '西伯郡南部町', 'サイハクグンナンブチョウ', '寺内', 'テラウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡南部町三崎', '31', '31389', '6830203', '鳥取県', 'トットリケン', '西伯郡南部町', 'サイハクグンナンブチョウ', '三崎', 'ミサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡南部町福里', '31', '31389', '6830204', '鳥取県', 'トットリケン', '西伯郡南部町', 'サイハクグンナンブチョウ', '福里', 'フクサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡南部町円山', '31', '31389', '6830211', '鳥取県', 'トットリケン', '西伯郡南部町', 'サイハクグンナンブチョウ', '円山', 'マルヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡南部町諸木', '31', '31389', '6830212', '鳥取県', 'トットリケン', '西伯郡南部町', 'サイハクグンナンブチョウ', '諸木', 'モロギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡南部町西原', '31', '31389', '6830213', '鳥取県', 'トットリケン', '西伯郡南部町', 'サイハクグンナンブチョウ', '西原', 'ニシバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡南部町田住', '31', '31389', '6830214', '鳥取県', 'トットリケン', '西伯郡南部町', 'サイハクグンナンブチョウ', '田住', 'タスミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡南部町荻名', '31', '31389', '6830215', '鳥取県', 'トットリケン', '西伯郡南部町', 'サイハクグンナンブチョウ', '荻名', 'オギナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡南部町朝金', '31', '31389', '6830216', '鳥取県', 'トットリケン', '西伯郡南部町', 'サイハクグンナンブチョウ', '朝金', 'アサカネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡南部町鶴田', '31', '31389', '6830217', '鳥取県', 'トットリケン', '西伯郡南部町', 'サイハクグンナンブチョウ', '鶴田', 'ツルダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡南部町池野', '31', '31389', '6830218', '鳥取県', 'トットリケン', '西伯郡南部町', 'サイハクグンナンブチョウ', '池野', 'イケノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡南部町宮前', '31', '31389', '6830221', '鳥取県', 'トットリケン', '西伯郡南部町', 'サイハクグンナンブチョウ', '宮前', 'ミヤマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡南部町市山', '31', '31389', '6830222', '鳥取県', 'トットリケン', '西伯郡南部町', 'サイハクグンナンブチョウ', '市山', 'イチヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡南部町井上', '31', '31389', '6830223', '鳥取県', 'トットリケン', '西伯郡南部町', 'サイハクグンナンブチョウ', '井上', 'イノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡南部町金田', '31', '31389', '6830224', '鳥取県', 'トットリケン', '西伯郡南部町', 'サイハクグンナンブチョウ', '金田', 'カネダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡南部町御内谷', '31', '31389', '6830225', '鳥取県', 'トットリケン', '西伯郡南部町', 'サイハクグンナンブチョウ', '御内谷', 'ミウチダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡南部町高姫', '31', '31389', '6830226', '鳥取県', 'トットリケン', '西伯郡南部町', 'サイハクグンナンブチョウ', '高姫', 'タカヒメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡南部町浅井', '31', '31389', '6830227', '鳥取県', 'トットリケン', '西伯郡南部町', 'サイハクグンナンブチョウ', '浅井', 'アサイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市兼久', '31', '31202', '6830251', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '兼久', 'カネヒサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市青木', '31', '31202', '6830252', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '青木', 'アオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市下安曇', '31', '31202', '6830253', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '下安曇', 'シモアズマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市別所', '31', '31202', '6830254', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '別所', 'ベッシヨ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市上安曇', '31', '31202', '6830255', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '上安曇', 'カミアズマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市大袋', '31', '31202', '6830256', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '大袋', 'オオブクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市榎原', '31', '31202', '6830257', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '榎原', 'エノキハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡南部町', '31', '31389', '6830300', '鳥取県', 'トットリケン', '西伯郡南部町', 'サイハクグンナンブチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('84145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡南部町東町', '31', '31389', '6830301', '鳥取県', 'トットリケン', '西伯郡南部町', 'サイハクグンナンブチョウ', '東町', 'ヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡南部町西町', '31', '31389', '6830302', '鳥取県', 'トットリケン', '西伯郡南部町', 'サイハクグンナンブチョウ', '西町', 'ニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡南部町境', '31', '31389', '6830311', '鳥取県', 'トットリケン', '西伯郡南部町', 'サイハクグンナンブチョウ', '境', 'サカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡南部町福成', '31', '31389', '6830312', '鳥取県', 'トットリケン', '西伯郡南部町', 'サイハクグンナンブチョウ', '福成', 'フクナリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡南部町清水川', '31', '31389', '6830321', '鳥取県', 'トットリケン', '西伯郡南部町', 'サイハクグンナンブチョウ', '清水川', 'シミズガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡南部町阿賀', '31', '31389', '6830322', '鳥取県', 'トットリケン', '西伯郡南部町', 'サイハクグンナンブチョウ', '阿賀', 'アガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡南部町倭', '31', '31389', '6830323', '鳥取県', 'トットリケン', '西伯郡南部町', 'サイハクグンナンブチョウ', '倭', 'ヤマト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡南部町掛相', '31', '31389', '6830331', '鳥取県', 'トットリケン', '西伯郡南部町', 'サイハクグンナンブチョウ', '掛相', 'カケアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡南部町馬佐良', '31', '31389', '6830332', '鳥取県', 'トットリケン', '西伯郡南部町', 'サイハクグンナンブチョウ', '馬佐良', 'バサラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡南部町八金', '31', '31389', '6830333', '鳥取県', 'トットリケン', '西伯郡南部町', 'サイハクグンナンブチョウ', '八金', 'ヤカネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡南部町東上', '31', '31389', '6830334', '鳥取県', 'トットリケン', '西伯郡南部町', 'サイハクグンナンブチョウ', '東上', 'トウジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡南部町中', '31', '31389', '6830335', '鳥取県', 'トットリケン', '西伯郡南部町', 'サイハクグンナンブチョウ', '中', 'ナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡南部町福頼', '31', '31389', '6830336', '鳥取県', 'トットリケン', '西伯郡南部町', 'サイハクグンナンブチョウ', '福頼', 'フクヨリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡南部町落合', '31', '31389', '6830337', '鳥取県', 'トットリケン', '西伯郡南部町', 'サイハクグンナンブチョウ', '落合', 'オチアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡南部町鴨部', '31', '31389', '6830341', '鳥取県', 'トットリケン', '西伯郡南部町', 'サイハクグンナンブチョウ', '鴨部', 'カモベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡南部町能竹', '31', '31389', '6830342', '鳥取県', 'トットリケン', '西伯郡南部町', 'サイハクグンナンブチョウ', '能竹', 'ノウジク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡南部町下中谷', '31', '31389', '6830343', '鳥取県', 'トットリケン', '西伯郡南部町', 'サイハクグンナンブチョウ', '下中谷', 'シモナカタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡南部町上中谷', '31', '31389', '6830344', '鳥取県', 'トットリケン', '西伯郡南部町', 'サイハクグンナンブチョウ', '上中谷', 'カミナカタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡南部町大木屋', '31', '31389', '6830345', '鳥取県', 'トットリケン', '西伯郡南部町', 'サイハクグンナンブチョウ', '大木屋', 'オオキヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡南部町法勝寺', '31', '31389', '6830351', '鳥取県', 'トットリケン', '西伯郡南部町', 'サイハクグンナンブチョウ', '法勝寺', 'ホッショウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡南部町馬場', '31', '31389', '6830352', '鳥取県', 'トットリケン', '西伯郡南部町', 'サイハクグンナンブチョウ', '馬場', 'ババ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡南部町徳長', '31', '31389', '6830353', '鳥取県', 'トットリケン', '西伯郡南部町', 'サイハクグンナンブチョウ', '徳長', 'トクナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡南部町武信', '31', '31389', '6830354', '鳥取県', 'トットリケン', '西伯郡南部町', 'サイハクグンナンブチョウ', '武信', 'タケノブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡南部町道河内', '31', '31389', '6830355', '鳥取県', 'トットリケン', '西伯郡南部町', 'サイハクグンナンブチョウ', '道河内', 'ドウガワウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡南部町伐株', '31', '31389', '6830356', '鳥取県', 'トットリケン', '西伯郡南部町', 'サイハクグンナンブチョウ', '伐株', 'キリクイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡南部町北方', '31', '31389', '6830361', '鳥取県', 'トットリケン', '西伯郡南部町', 'サイハクグンナンブチョウ', '北方', 'キタガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡南部町原', '31', '31389', '6830362', '鳥取県', 'トットリケン', '西伯郡南部町', 'サイハクグンナンブチョウ', '原', 'ハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡南部町西', '31', '31389', '6830363', '鳥取県', 'トットリケン', '西伯郡南部町', 'サイハクグンナンブチョウ', '西', 'ニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡南部町絹屋', '31', '31389', '6830364', '鳥取県', 'トットリケン', '西伯郡南部町', 'サイハクグンナンブチョウ', '絹屋', 'キヌヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡南部町鍋倉', '31', '31389', '6830365', '鳥取県', 'トットリケン', '西伯郡南部町', 'サイハクグンナンブチョウ', '鍋倉', 'ナベクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡南部町与一谷', '31', '31389', '6830366', '鳥取県', 'トットリケン', '西伯郡南部町', 'サイハクグンナンブチョウ', '与一谷', 'ヨイチダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡南部町猪小路', '31', '31389', '6830367', '鳥取県', 'トットリケン', '西伯郡南部町', 'サイハクグンナンブチョウ', '猪小路', 'イノコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市新開', '31', '31202', '6830801', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '新開', 'シンカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市東福原', '31', '31202', '6830802', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '東福原', 'ヒガシフクバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市日ノ出町', '31', '31202', '6830803', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '日ノ出町', 'ヒノデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市米原', '31', '31202', '6830804', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '米原', 'ヨネハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市西福原', '31', '31202', '6830805', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '西福原', 'ニシフクバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市錦町', '31', '31202', '6830811', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '錦町', 'ニシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市角盤町', '31', '31202', '6830812', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '角盤町', 'カクバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市朝日町', '31', '31202', '6830813', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '朝日町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市尾高町', '31', '31202', '6830814', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '尾高町', 'オダカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市東倉吉町', '31', '31202', '6830815', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '東倉吉町', 'ヒガシクラヨシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市西倉吉町', '31', '31202', '6830816', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '西倉吉町', 'ニシクラヨシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市天神町', '31', '31202', '6830821', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '天神町', 'テンジンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市中町', '31', '31202', '6830822', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '中町', 'ナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市加茂町', '31', '31202', '6830823', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '加茂町', 'カモチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市久米町', '31', '31202', '6830824', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '久米町', 'クメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市錦海町', '31', '31202', '6830825', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '錦海町', 'キンカイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市西町', '31', '31202', '6830826', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '西町', 'ニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市寺町', '31', '31202', '6830831', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '寺町', 'テラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市立町', '31', '31202', '6830832', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '立町', 'タテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市岩倉町', '31', '31202', '6830833', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '岩倉町', 'イワクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市内町', '31', '31202', '6830834', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '内町', 'ウチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市灘町', '31', '31202', '6830835', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '灘町', 'ナダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市花園町', '31', '31202', '6830836', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '花園町', 'ハナゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市上後藤', '31', '31202', '6830841', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '上後藤', 'カミゴトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市三本松', '31', '31202', '6830842', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '三本松', 'サンボンマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市三旗町', '31', '31202', '6830843', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '三旗町', 'ミハタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市義方町', '31', '31202', '6830844', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '義方町', 'ギホウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市旗ケ崎', '31', '31202', '6830845', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '旗ケ崎', 'ハタガサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市安倍', '31', '31202', '6830846', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '安倍', 'アベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市夜見町', '31', '31202', '6830851', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '夜見町', 'ヨミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市河崎', '31', '31202', '6830852', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '河崎', 'カワサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市両三柳', '31', '31202', '6830853', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '両三柳', 'リョウミツヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市彦名町', '31', '31202', '6830854', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '彦名町', 'ヒコナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市彦名新田', '31', '31202', '6830855', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '彦名新田', 'ヒコナシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市栗沢町万字大平', '01', '01210', '0683151', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '栗沢町万字大平', 'クリサワチョウマンジオオタイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市栗沢町万字幸町', '01', '01210', '0683152', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '栗沢町万字幸町', 'クリサワチョウマンジサイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市栗沢町万字仲町', '01', '01210', '0683153', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '栗沢町万字仲町', 'クリサワチョウマンジナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市栗沢町万字曙町', '01', '01210', '0683154', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '栗沢町万字曙町', 'クリサワチョウマンジアケボノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市栗沢町万字寿町', '01', '01210', '0683155', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '栗沢町万字寿町', 'クリサワチョウマンジコトブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市栗沢町万字英町', '01', '01210', '0683156', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '栗沢町万字英町', 'クリサワチョウマンジハナブサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市栗沢町万字睦町', '01', '01210', '0683157', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '栗沢町万字睦町', 'クリサワチョウマンジムツミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市栗沢町万字巴町', '01', '01210', '0683158', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '栗沢町万字巴町', 'クリサワチョウマンジトモエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市栗沢町万字二見町', '01', '01210', '0683159', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '栗沢町万字二見町', 'クリサワチョウマンジフタミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市栗沢町宮村', '01', '01210', '0683161', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '栗沢町宮村', 'クリサワチョウミヤムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市栗沢町万字旭町', '01', '01210', '0683162', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '栗沢町万字旭町', 'クリサワチョウマンジアサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市栗沢町万字西原町', '01', '01210', '0683163', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '栗沢町万字西原町', 'クリサワチョウマンジニシハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市栗沢町万字錦町', '01', '01210', '0683164', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '栗沢町万字錦町', 'クリサワチョウマンジニシキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市栗沢町西万字', '01', '01210', '0683165', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '栗沢町西万字', 'クリサワチョウニシマンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市栗沢町美流渡本町', '01', '01210', '0683171', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '栗沢町美流渡本町', 'クリサワチョウミルトホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市栗沢町美流渡栄町', '01', '01210', '0683172', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '栗沢町美流渡栄町', 'クリサワチョウミルトサカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市栗沢町美流渡若葉町', '01', '01210', '0683173', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '栗沢町美流渡若葉町', 'クリサワチョウミルトワカバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市栗沢町美流渡吉野町', '01', '01210', '0683174', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '栗沢町美流渡吉野町', 'クリサワチョウミルトヨシノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市栗沢町美流渡西町', '01', '01210', '0683175', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '栗沢町美流渡西町', 'クリサワチョウミルトニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市栗沢町美流渡東栄町', '01', '01210', '0683176', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '栗沢町美流渡東栄町', 'クリサワチョウミルトトウエイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市栗沢町美流渡末広町', '01', '01210', '0683177', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '栗沢町美流渡末広町', 'クリサワチョウミルトスエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市栗沢町美流渡錦町', '01', '01210', '0683178', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '栗沢町美流渡錦町', 'クリサワチョウミルトニシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市栗沢町美流渡桜町', '01', '01210', '0683179', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '栗沢町美流渡桜町', 'クリサワチョウミルトサクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市栗沢町美流渡東町', '01', '01210', '0683180', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '栗沢町美流渡東町', 'クリサワチョウミルトヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市栗沢町美流渡南町', '01', '01210', '0683181', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '栗沢町美流渡南町', 'クリサワチョウミルトミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市栗沢町美流渡緑町', '01', '01210', '0683182', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '栗沢町美流渡緑町', 'クリサワチョウミルトミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市栗沢町美流渡楓町', '01', '01210', '0683183', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '栗沢町美流渡楓町', 'クリサワチョウミルトカエデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市朝日町', '01', '01210', '0683185', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '朝日町', 'アサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市清水町', '01', '01210', '0683186', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '清水町', 'シミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市奈良町', '01', '01210', '0683187', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '奈良町', 'ナラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市毛陽町', '01', '01210', '0683188', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '毛陽町', 'モウヨウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県境港市', '31', '31204', '6840000', '鳥取県', 'トットリケン', '境港市', 'サカイミナトシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('84264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県境港市清水町', '31', '31204', '6840001', '鳥取県', 'トットリケン', '境港市', 'サカイミナトシ', '清水町', 'シミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県境港市弥生町', '31', '31204', '6840002', '鳥取県', 'トットリケン', '境港市', 'サカイミナトシ', '弥生町', 'ヤヨイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県境港市浜ノ町', '31', '31204', '6840003', '鳥取県', 'トットリケン', '境港市', 'サカイミナトシ', '浜ノ町', 'ハマノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県境港市大正町', '31', '31204', '6840004', '鳥取県', 'トットリケン', '境港市', 'サカイミナトシ', '大正町', 'タイショウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県境港市松ケ枝町', '31', '31204', '6840005', '鳥取県', 'トットリケン', '境港市', 'サカイミナトシ', '松ケ枝町', 'マツガエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県境港市栄町', '31', '31204', '6840006', '鳥取県', 'トットリケン', '境港市', 'サカイミナトシ', '栄町', 'エイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県境港市相生町', '31', '31204', '6840011', '鳥取県', 'トットリケン', '境港市', 'サカイミナトシ', '相生町', 'アイオイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県境港市中町', '31', '31204', '6840012', '鳥取県', 'トットリケン', '境港市', 'サカイミナトシ', '中町', 'ナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県境港市朝日町', '31', '31204', '6840013', '鳥取県', 'トットリケン', '境港市', 'サカイミナトシ', '朝日町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県境港市入船町', '31', '31204', '6840014', '鳥取県', 'トットリケン', '境港市', 'サカイミナトシ', '入船町', 'ニュウセンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県境港市東雲町', '31', '31204', '6840015', '鳥取県', 'トットリケン', '境港市', 'サカイミナトシ', '東雲町', 'シノノメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県境港市花町', '31', '31204', '6840016', '鳥取県', 'トットリケン', '境港市', 'サカイミナトシ', '花町', 'ハナマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県境港市岬町', '31', '31204', '6840017', '鳥取県', 'トットリケン', '境港市', 'サカイミナトシ', '岬町', 'ミサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県境港市馬場崎町', '31', '31204', '6840021', '鳥取県', 'トットリケン', '境港市', 'サカイミナトシ', '馬場崎町', 'ババサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県境港市明治町', '31', '31204', '6840022', '鳥取県', 'トットリケン', '境港市', 'サカイミナトシ', '明治町', 'メイジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県境港市京町', '31', '31204', '6840023', '鳥取県', 'トットリケン', '境港市', 'サカイミナトシ', '京町', 'キョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県境港市日ノ出町', '31', '31204', '6840024', '鳥取県', 'トットリケン', '境港市', 'サカイミナトシ', '日ノ出町', 'ヒノデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県境港市本町', '31', '31204', '6840025', '鳥取県', 'トットリケン', '境港市', 'サカイミナトシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県境港市末広町', '31', '31204', '6840026', '鳥取県', 'トットリケン', '境港市', 'サカイミナトシ', '末広町', 'スエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県境港市東本町', '31', '31204', '6840027', '鳥取県', 'トットリケン', '境港市', 'サカイミナトシ', '東本町', 'ヒガシホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県境港市湊町', '31', '31204', '6840031', '鳥取県', 'トットリケン', '境港市', 'サカイミナトシ', '湊町', 'ミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県境港市元町', '31', '31204', '6840032', '鳥取県', 'トットリケン', '境港市', 'サカイミナトシ', '元町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県境港市上道町', '31', '31204', '6840033', '鳥取県', 'トットリケン', '境港市', 'サカイミナトシ', '上道町', 'アガリミチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県境港市昭和町', '31', '31204', '6840034', '鳥取県', 'トットリケン', '境港市', 'サカイミナトシ', '昭和町', 'ショウワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県境港市中野町', '31', '31204', '6840041', '鳥取県', 'トットリケン', '境港市', 'サカイミナトシ', '中野町', 'ナカノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県境港市福定町', '31', '31204', '6840042', '鳥取県', 'トットリケン', '境港市', 'サカイミナトシ', '福定町', 'フクサダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県境港市竹内町', '31', '31204', '6840043', '鳥取県', 'トットリケン', '境港市', 'サカイミナトシ', '竹内町', 'タケノウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県境港市美保町', '31', '31204', '6840044', '鳥取県', 'トットリケン', '境港市', 'サカイミナトシ', '美保町', 'ミホチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県境港市高松町', '31', '31204', '6840045', '鳥取県', 'トットリケン', '境港市', 'サカイミナトシ', '高松町', 'タカマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県境港市竹内団地', '31', '31204', '6840046', '鳥取県', 'トットリケン', '境港市', 'サカイミナトシ', '竹内団地', 'タケノウチダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県境港市新屋町', '31', '31204', '6840051', '鳥取県', 'トットリケン', '境港市', 'サカイミナトシ', '新屋町', 'ニイヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県境港市麦垣町', '31', '31204', '6840052', '鳥取県', 'トットリケン', '境港市', 'サカイミナトシ', '麦垣町', 'ムギカキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県境港市小篠津町', '31', '31204', '6840053', '鳥取県', 'トットリケン', '境港市', 'サカイミナトシ', '小篠津町', 'コシノヅチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県境港市財ノ木町', '31', '31204', '6840054', '鳥取県', 'トットリケン', '境港市', 'サカイミナトシ', '財ノ木町', 'サイノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県境港市佐斐神町', '31', '31204', '6840055', '鳥取県', 'トットリケン', '境港市', 'サカイミナトシ', '佐斐神町', 'サイノカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県境港市幸神町', '31', '31204', '6840056', '鳥取県', 'トットリケン', '境港市', 'サカイミナトシ', '幸神町', 'コウジンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県境港市米川町', '31', '31204', '6840061', '鳥取県', 'トットリケン', '境港市', 'サカイミナトシ', '米川町', 'ヨネガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県境港市蓮池町', '31', '31204', '6840062', '鳥取県', 'トットリケン', '境港市', 'サカイミナトシ', '蓮池町', 'ハスイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県境港市誠道町', '31', '31204', '6840063', '鳥取県', 'トットリケン', '境港市', 'サカイミナトシ', '誠道町', 'セイドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県境港市三軒屋町', '31', '31204', '6840064', '鳥取県', 'トットリケン', '境港市', 'サカイミナトシ', '三軒屋町', 'サンゲンヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県境港市森岡町', '31', '31204', '6840065', '鳥取県', 'トットリケン', '境港市', 'サカイミナトシ', '森岡町', 'モリオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県境港市芝町', '31', '31204', '6840066', '鳥取県', 'トットリケン', '境港市', 'サカイミナトシ', '芝町', 'シバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県境港市外江町', '31', '31204', '6840071', '鳥取県', 'トットリケン', '境港市', 'サカイミナトシ', '外江町', 'トノエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県境港市渡町', '31', '31204', '6840072', '鳥取県', 'トットリケン', '境港市', 'サカイミナトシ', '渡町', 'ワタリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県境港市中海干拓地', '31', '31204', '6840073', '鳥取県', 'トットリケン', '境港市', 'サカイミナトシ', '中海干拓地', 'ナカウミカンタクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県境港市潮見町', '31', '31204', '6840074', '鳥取県', 'トットリケン', '境港市', 'サカイミナトシ', '潮見町', 'シオミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県境港市西工業団地', '31', '31204', '6840075', '鳥取県', 'トットリケン', '境港市', 'サカイミナトシ', '西工業団地', 'ニシコウギョウダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県境港市夕日ケ丘', '31', '31204', '6840076', '鳥取県', 'トットリケン', '境港市', 'サカイミナトシ', '夕日ケ丘', 'ユウヒガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県隠岐郡知夫村', '32', '32527', '6840100', '島根県', 'シマネケン', '隠岐郡知夫村', 'オキグンチブムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('84313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県隠岐郡知夫村大江', '32', '32527', '6840101', '島根県', 'シマネケン', '隠岐郡知夫村', 'オキグンチブムラ', '大江', 'オオエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県隠岐郡知夫村郡', '32', '32527', '6840102', '島根県', 'シマネケン', '隠岐郡知夫村', 'オキグンチブムラ', '郡', 'コオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県隠岐郡知夫村多沢', '32', '32527', '6840103', '島根県', 'シマネケン', '隠岐郡知夫村', 'オキグンチブムラ', '多沢', 'タタク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県隠岐郡知夫村薄毛', '32', '32527', '6840104', '島根県', 'シマネケン', '隠岐郡知夫村', 'オキグンチブムラ', '薄毛', 'ウスゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県隠岐郡知夫村仁夫', '32', '32527', '6840105', '島根県', 'シマネケン', '隠岐郡知夫村', 'オキグンチブムラ', '仁夫', 'ニブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県隠岐郡知夫村来居', '32', '32527', '6840106', '島根県', 'シマネケン', '隠岐郡知夫村', 'オキグンチブムラ', '来居', 'クリイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県隠岐郡知夫村古海', '32', '32527', '6840107', '島根県', 'シマネケン', '隠岐郡知夫村', 'オキグンチブムラ', '古海', 'ウルミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県隠岐郡西ノ島町浦郷', '32', '32526', '6840211', '島根県', 'シマネケン', '隠岐郡西ノ島町', 'オキグンニシノシマチョウ', '浦郷', 'ウラゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県隠岐郡西ノ島町', '32', '32526', '6840300', '島根県', 'シマネケン', '隠岐郡西ノ島町', 'オキグンニシノシマチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('84322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県隠岐郡西ノ島町宇賀', '32', '32526', '6840301', '島根県', 'シマネケン', '隠岐郡西ノ島町', 'オキグンニシノシマチョウ', '宇賀', 'ウカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県隠岐郡西ノ島町別府', '32', '32526', '6840302', '島根県', 'シマネケン', '隠岐郡西ノ島町', 'オキグンニシノシマチョウ', '別府', 'ベップ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県隠岐郡西ノ島町美田', '32', '32526', '6840303', '島根県', 'シマネケン', '隠岐郡西ノ島町', 'オキグンニシノシマチョウ', '美田', 'ミタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県隠岐郡海士町', '32', '32525', '6840400', '島根県', 'シマネケン', '隠岐郡海士町', 'オキグンアマチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('84326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県隠岐郡海士町宇受賀', '32', '32525', '6840401', '島根県', 'シマネケン', '隠岐郡海士町', 'オキグンアマチョウ', '宇受賀', 'ウズカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県隠岐郡海士町豊田', '32', '32525', '6840402', '島根県', 'シマネケン', '隠岐郡海士町', 'オキグンアマチョウ', '豊田', 'トヨダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県隠岐郡海士町海士', '32', '32525', '6840403', '島根県', 'シマネケン', '隠岐郡海士町', 'オキグンアマチョウ', '海士', 'アマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県隠岐郡海士町福井', '32', '32525', '6840404', '島根県', 'シマネケン', '隠岐郡海士町', 'オキグンアマチョウ', '福井', 'フクイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県隠岐郡海士町知々井', '32', '32525', '6840411', '島根県', 'シマネケン', '隠岐郡海士町', 'オキグンアマチョウ', '知々井', 'チチイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県隠岐郡海士町御波', '32', '32525', '6840412', '島根県', 'シマネケン', '隠岐郡海士町', 'オキグンアマチョウ', '御波', 'ミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県隠岐郡海士町崎', '32', '32525', '6840413', '島根県', 'シマネケン', '隠岐郡海士町', 'オキグンアマチョウ', '崎', 'サキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県隠岐郡隠岐の島町', '32', '32528', '6850000', '島根県', 'シマネケン', '隠岐郡隠岐の島町', 'オキグンオキノシマチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('84340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県隠岐郡隠岐の島町大久', '32', '32528', '6850001', '島根県', 'シマネケン', '隠岐郡隠岐の島町', 'オキグンオキノシマチョウ', '大久', 'オオク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県隠岐郡隠岐の島町釜', '32', '32528', '6850002', '島根県', 'シマネケン', '隠岐郡隠岐の島町', 'オキグンオキノシマチョウ', '釜', 'カマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県隠岐郡隠岐の島町犬来', '32', '32528', '6850003', '島根県', 'シマネケン', '隠岐郡隠岐の島町', 'オキグンオキノシマチョウ', '犬来', 'イヌグ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県隠岐郡隠岐の島町飯田', '32', '32528', '6850004', '島根県', 'シマネケン', '隠岐郡隠岐の島町', 'オキグンオキノシマチョウ', '飯田', 'イイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県隠岐郡隠岐の島町東郷', '32', '32528', '6850005', '島根県', 'シマネケン', '隠岐郡隠岐の島町', 'オキグンオキノシマチョウ', '東郷', 'トウゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県隠岐郡隠岐の島町有木', '32', '32528', '6850006', '島根県', 'シマネケン', '隠岐郡隠岐の島町', 'オキグンオキノシマチョウ', '有木', 'アラキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県隠岐郡隠岐の島町池田', '32', '32528', '6850007', '島根県', 'シマネケン', '隠岐郡隠岐の島町', 'オキグンオキノシマチョウ', '池田', 'イケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県隠岐郡隠岐の島町栄町', '32', '32528', '6850011', '島根県', 'シマネケン', '隠岐郡隠岐の島町', 'オキグンオキノシマチョウ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県隠岐郡隠岐の島町東町', '32', '32528', '6850012', '島根県', 'シマネケン', '隠岐郡隠岐の島町', 'オキグンオキノシマチョウ', '東町', 'ヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県隠岐郡隠岐の島町中町', '32', '32528', '6850013', '島根県', 'シマネケン', '隠岐郡隠岐の島町', 'オキグンオキノシマチョウ', '中町', 'ナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県隠岐郡隠岐の島町西町', '32', '32528', '6850014', '島根県', 'シマネケン', '隠岐郡隠岐の島町', 'オキグンオキノシマチョウ', '西町', 'ニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県隠岐郡隠岐の島町港町', '32', '32528', '6850015', '島根県', 'シマネケン', '隠岐郡隠岐の島町', 'オキグンオキノシマチョウ', '港町', 'ミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県隠岐郡隠岐の島町城北町', '32', '32528', '6850016', '島根県', 'シマネケン', '隠岐郡隠岐の島町', 'オキグンオキノシマチョウ', '城北町', 'ジョウホクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県隠岐郡隠岐の島町下西', '32', '32528', '6850017', '島根県', 'シマネケン', '隠岐郡隠岐の島町', 'オキグンオキノシマチョウ', '下西', 'シモニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県隠岐郡隠岐の島町岬町', '32', '32528', '6850021', '島根県', 'シマネケン', '隠岐郡隠岐の島町', 'オキグンオキノシマチョウ', '岬町', 'ミサキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県隠岐郡隠岐の島町今津', '32', '32528', '6850022', '島根県', 'シマネケン', '隠岐郡隠岐の島町', 'オキグンオキノシマチョウ', '今津', 'イマヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県隠岐郡隠岐の島町西田', '32', '32528', '6850023', '島根県', 'シマネケン', '隠岐郡隠岐の島町', 'オキグンオキノシマチョウ', '西田', 'ニシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県隠岐郡隠岐の島町加茂', '32', '32528', '6850024', '島根県', 'シマネケン', '隠岐郡隠岐の島町', 'オキグンオキノシマチョウ', '加茂', 'カモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県隠岐郡隠岐の島町平', '32', '32528', '6850025', '島根県', 'シマネケン', '隠岐郡隠岐の島町', 'オキグンオキノシマチョウ', '平', 'ヘイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県隠岐郡隠岐の島町上西', '32', '32528', '6850026', '島根県', 'シマネケン', '隠岐郡隠岐の島町', 'オキグンオキノシマチョウ', '上西', 'カミニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県隠岐郡隠岐の島町原田', '32', '32528', '6850027', '島根県', 'シマネケン', '隠岐郡隠岐の島町', 'オキグンオキノシマチョウ', '原田', 'ハラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県隠岐郡隠岐の島町蔵田', '32', '32528', '6850101', '島根県', 'シマネケン', '隠岐郡隠岐の島町', 'オキグンオキノシマチョウ', '蔵田', 'クラタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県隠岐郡隠岐の島町油井', '32', '32528', '6850102', '島根県', 'シマネケン', '隠岐郡隠岐の島町', 'オキグンオキノシマチョウ', '油井', 'ユイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県隠岐郡隠岐の島町那久', '32', '32528', '6850103', '島根県', 'シマネケン', '隠岐郡隠岐の島町', 'オキグンオキノシマチョウ', '那久', 'ナグ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県隠岐郡隠岐の島町都万', '32', '32528', '6850104', '島根県', 'シマネケン', '隠岐郡隠岐の島町', 'オキグンオキノシマチョウ', '都万', 'ツマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県隠岐郡隠岐の島町津戸', '32', '32528', '6850105', '島根県', 'シマネケン', '隠岐郡隠岐の島町', 'オキグンオキノシマチョウ', '津戸', 'ツド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県隠岐郡隠岐の島町蛸木', '32', '32528', '6850106', '島根県', 'シマネケン', '隠岐郡隠岐の島町', 'オキグンオキノシマチョウ', '蛸木', 'タクギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県隠岐郡隠岐の島町北方', '32', '32528', '6850301', '島根県', 'シマネケン', '隠岐郡隠岐の島町', 'オキグンオキノシマチョウ', '北方', 'キタガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県隠岐郡隠岐の島町苗代田', '32', '32528', '6850302', '島根県', 'シマネケン', '隠岐郡隠岐の島町', 'オキグンオキノシマチョウ', '苗代田', 'ナワシロダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県隠岐郡隠岐の島町南方', '32', '32528', '6850303', '島根県', 'シマネケン', '隠岐郡隠岐の島町', 'オキグンオキノシマチョウ', '南方', 'ミナミガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県隠岐郡隠岐の島町代', '32', '32528', '6850304', '島根県', 'シマネケン', '隠岐郡隠岐の島町', 'オキグンオキノシマチョウ', '代', 'シロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県隠岐郡隠岐の島町久見', '32', '32528', '6850305', '島根県', 'シマネケン', '隠岐郡隠岐の島町', 'オキグンオキノシマチョウ', '久見', 'クミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県隠岐郡隠岐の島町伊後向ケ丘', '32', '32528', '6850306', '島根県', 'シマネケン', '隠岐郡隠岐の島町', 'オキグンオキノシマチョウ', '伊後', 'イゴ', null, null, '向ケ丘', 'ムコウガオカ');
INSERT INTO `ms_addresses` VALUES ('84373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県隠岐郡隠岐の島町郡', '32', '32528', '6850311', '島根県', 'シマネケン', '隠岐郡隠岐の島町', 'オキグンオキノシマチョウ', '郡', 'コオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県隠岐郡隠岐の島町小路', '32', '32528', '6850312', '島根県', 'シマネケン', '隠岐郡隠岐の島町', 'オキグンオキノシマチョウ', '小路', 'コウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県隠岐郡隠岐の島町那久路', '32', '32528', '6850313', '島根県', 'シマネケン', '隠岐郡隠岐の島町', 'オキグンオキノシマチョウ', '那久路', 'ナグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県隠岐郡隠岐の島町山田', '32', '32528', '6850314', '島根県', 'シマネケン', '隠岐郡隠岐の島町', 'オキグンオキノシマチョウ', '山田', 'ヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県隠岐郡隠岐の島町飯美', '32', '32528', '6850411', '島根県', 'シマネケン', '隠岐郡隠岐の島町', 'オキグンオキノシマチョウ', '飯美', 'イイビ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県隠岐郡隠岐の島町布施', '32', '32528', '6850412', '島根県', 'シマネケン', '隠岐郡隠岐の島町', 'オキグンオキノシマチョウ', '布施', 'フセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県隠岐郡隠岐の島町卯敷', '32', '32528', '6850413', '島根県', 'シマネケン', '隠岐郡隠岐の島町', 'オキグンオキノシマチョウ', '卯敷', 'ウズキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県隠岐郡隠岐の島町伊後', '32', '32528', '6850431', '島根県', 'シマネケン', '隠岐郡隠岐の島町', 'オキグンオキノシマチョウ', '伊後', 'イゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県隠岐郡隠岐の島町西村', '32', '32528', '6850432', '島根県', 'シマネケン', '隠岐郡隠岐の島町', 'オキグンオキノシマチョウ', '西村', 'ニシムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県隠岐郡隠岐の島町湊', '32', '32528', '6850433', '島根県', 'シマネケン', '隠岐郡隠岐の島町', 'オキグンオキノシマチョウ', '湊', 'ミナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県隠岐郡隠岐の島町中村', '32', '32528', '6850434', '島根県', 'シマネケン', '隠岐郡隠岐の島町', 'オキグンオキノシマチョウ', '中村', 'ナカムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県隠岐郡隠岐の島町元屋', '32', '32528', '6850435', '島根県', 'シマネケン', '隠岐郡隠岐の島町', 'オキグンオキノシマチョウ', '元屋', 'ガンヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市福部町岩戸', '31', '31201', '6890101', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '福部町岩戸', 'フクベチョウイワド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市福部町細川', '31', '31201', '6890102', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '福部町細川', 'フクベチョウホソガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市福部町高江', '31', '31201', '6890103', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '福部町高江', 'フクベチョウタカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市福部町箭渓', '31', '31201', '6890104', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '福部町箭渓', 'フクベチョウヤダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市福部町湯山', '31', '31201', '6890105', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '福部町湯山', 'フクベチョウユヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市福部町海士', '31', '31201', '6890106', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '福部町海士', 'フクベチョウアモウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市福部町栗谷', '31', '31201', '6890111', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '福部町栗谷', 'フクベチョウクリタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市福部町蔵見', '31', '31201', '6890112', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '福部町蔵見', 'フクベチョウクラミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市福部町久志羅', '31', '31201', '6890113', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '福部町久志羅', 'フクベチョウクジラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市福部町左近', '31', '31201', '6890114', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '福部町左近', 'フクベチョウサコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市福部町八重原', '31', '31201', '6890115', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '福部町八重原', 'フクベチョウヤエバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市福部町中', '31', '31201', '6890116', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '福部町中', 'フクベチョウナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市福部町南田', '31', '31201', '6890117', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '福部町南田', 'フクベチョウノウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市伏野', '31', '31201', '6890201', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '伏野', 'フシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市美萩野', '31', '31201', '6890202', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '美萩野', 'ミハギノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市三津', '31', '31201', '6890203', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '三津', 'ミツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市御熊', '31', '31201', '6890204', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '御熊', 'ミクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市内海中', '31', '31201', '6890205', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '内海中', 'ウツミナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市白兎', '31', '31201', '6890206', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '白兎', 'ハクト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市小沢見', '31', '31201', '6890207', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '小沢見', 'コゾミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市気高町奥沢見', '31', '31201', '6890211', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '気高町奥沢見', 'ケタカチョウオクゾウミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市気高町常松', '31', '31201', '6890212', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '気高町常松', 'ケタカチョウツネマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市気高町下光元', '31', '31201', '6890213', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '気高町下光元', 'ケタカチョウシモミツモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市気高町上光', '31', '31201', '6890214', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '気高町上光', 'ケタカチョウカミミツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市気高町冨吉', '31', '31201', '6890215', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '気高町冨吉', 'ケタカチョウトミヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市気高町宝木', '31', '31201', '6890216', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '気高町宝木', 'ケタカチョウホウギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市気高町酒津', '31', '31201', '6890217', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '気高町酒津', 'ケタカチョウサケノツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市気高町下坂本', '31', '31201', '6890221', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '気高町下坂本', 'ケタカチョウシモサカモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市気高町日光', '31', '31201', '6890222', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '気高町日光', 'ケタカチョウニッコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市気高町二本木', '31', '31201', '6890223', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '気高町二本木', 'ケタカチョウニホンギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市気高町重高', '31', '31201', '6890224', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '気高町重高', 'ケタカチョウシゲタカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市気高町土居', '31', '31201', '6890225', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '気高町土居', 'ケタカチョウドイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市気高町宿', '31', '31201', '6890226', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '気高町宿', 'ケタカチョウシュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市気高町浜村', '31', '31201', '6890331', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '気高町浜村', 'ケタカチョウハマムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市気高町勝見', '31', '31201', '6890332', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '気高町勝見', 'ケタカチョウカチミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市気高町新町', '31', '31201', '6890333', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '気高町新町', 'ケタカチョウシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市気高町北浜', '31', '31201', '6890334', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '気高町北浜', 'ケタカチョウキタハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市気高町下石', '31', '31201', '6890341', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '気高町下石', 'ケタカチョウオロジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市気高町殿', '31', '31201', '6890342', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '気高町殿', 'ケタカチョウトノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市気高町飯里', '31', '31201', '6890343', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '気高町飯里', 'ケタカチョウイイザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市気高町上原', '31', '31201', '6890344', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '気高町上原', 'ケタカチョウカンバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市気高町山宮', '31', '31201', '6890345', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '気高町山宮', 'ケタカチョウヤマミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市気高町八幡', '31', '31201', '6890351', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '気高町八幡', 'ケタカチョウヤワタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市気高町高江', '31', '31201', '6890352', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '気高町高江', 'ケタカチョウタカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市気高町郡家', '31', '31201', '6890353', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '気高町郡家', 'ケタカチョウコウゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市気高町睦逢', '31', '31201', '6890354', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '気高町睦逢', 'ケタカチョウムツオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市気高町会下', '31', '31201', '6890355', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '気高町会下', 'ケタカチョウエゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市気高町下原', '31', '31201', '6890356', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '気高町下原', 'ケタカチョウシモバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市気高町八束水', '31', '31201', '6890357', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '気高町八束水', 'ケタカチョウヤツカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市鹿野町広木', '31', '31201', '6890401', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '鹿野町広木', 'シカノチョウヒロギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市鹿野町閉野', '31', '31201', '6890402', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '鹿野町閉野', 'シカノチョウトジノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市鹿野町末用', '31', '31201', '6890403', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '鹿野町末用', 'シカノチョウスエモチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市鹿野町水谷', '31', '31201', '6890404', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '鹿野町水谷', 'シカノチョウミズタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市鹿野町鹿野', '31', '31201', '6890405', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '鹿野町鹿野', 'シカノチョウシカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市鹿野町鷲峯', '31', '31201', '6890411', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '鹿野町鷲峯', 'シカノチョウジュウボウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市鹿野町河内', '31', '31201', '6890412', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '鹿野町河内', 'シカノチョウコウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市鹿野町小別所', '31', '31201', '6890413', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '鹿野町小別所', 'シカノチョウコベツシヨ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市鹿野町乙亥正', '31', '31201', '6890421', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '鹿野町乙亥正', 'シカノチョウオツガセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市鹿野町岡木', '31', '31201', '6890422', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '鹿野町岡木', 'シカノチョウオカキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市鹿野町中園', '31', '31201', '6890423', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '鹿野町中園', 'シカノチョウナカゾノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市鹿野町宮方', '31', '31201', '6890424', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '鹿野町宮方', 'シカノチョウミヤカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市鹿野町今市', '31', '31201', '6890425', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '鹿野町今市', 'シカノチョウイマイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市鹿野町寺内', '31', '31201', '6890426', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '鹿野町寺内', 'シカノチョウテラウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市青谷町青谷', '31', '31201', '6890501', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '青谷町青谷', 'アオヤチョウアオヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市青谷町善田', '31', '31201', '6890511', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '青谷町善田', 'アオヤチョウヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市青谷町養郷', '31', '31201', '6890512', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '青谷町養郷', 'アオヤチョウヨウゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市青谷町蔵内', '31', '31201', '6890513', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '青谷町蔵内', 'アオヤチョウクラウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市青谷町山根', '31', '31201', '6890514', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '青谷町山根', 'アオヤチョウヤマネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市青谷町河原', '31', '31201', '6890515', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '青谷町河原', 'アオヤチョウカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市青谷町小畑', '31', '31201', '6890516', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '青谷町小畑', 'アオヤチョウオバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市青谷町早牛', '31', '31201', '6890517', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '青谷町早牛', 'アオヤチョウハヤウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市青谷町大坪', '31', '31201', '6890518', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '青谷町大坪', 'アオヤチョウオオツボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市青谷町奥崎', '31', '31201', '6890519', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '青谷町奥崎', 'アオヤチョウオクザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市青谷町露谷', '31', '31201', '6890521', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '青谷町露谷', 'アオヤチョウツユダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市青谷町亀尻', '31', '31201', '6890522', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '青谷町亀尻', 'アオヤチョウカメジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市青谷町山田', '31', '31201', '6890523', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '青谷町山田', 'アオヤチョウヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市青谷町八葉寺', '31', '31201', '6890524', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '青谷町八葉寺', 'アオヤチョウハツショウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市青谷町田原谷', '31', '31201', '6890525', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '青谷町田原谷', 'アオヤチョウタワラダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市青谷町紙屋', '31', '31201', '6890526', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '青谷町紙屋', 'アオヤチョウカミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市青谷町楠根', '31', '31201', '6890527', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '青谷町楠根', 'アオヤチョウクスネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市青谷町澄水', '31', '31201', '6890528', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '青谷町澄水', 'アオヤチョウスンズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市青谷町桑原', '31', '31201', '6890529', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '青谷町桑原', 'アオヤチョウクワバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市青谷町鳴滝', '31', '31201', '6890531', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '青谷町鳴滝', 'アオヤチョウナルタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市青谷町北河原', '31', '31201', '6890532', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '青谷町北河原', 'アオヤチョウキタガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市青谷町絹見', '31', '31201', '6890533', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '青谷町絹見', 'アオヤチョウキヌミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市青谷町吉川', '31', '31201', '6890534', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '青谷町吉川', 'アオヤチョウヨシカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市青谷町井手', '31', '31201', '6890535', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '青谷町井手', 'アオヤチョウイデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市青谷町長和瀬', '31', '31201', '6890536', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '青谷町長和瀬', 'アオヤチョウナガワセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市青谷町栄町', '31', '31201', '6890537', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '青谷町栄町', 'アオヤチョウサカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡湯梨浜町泊', '31', '31370', '6890601', '鳥取県', 'トットリケン', '東伯郡湯梨浜町', 'トウハクグンユリハマチョウ', '泊', 'トマリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡湯梨浜町石脇', '31', '31370', '6890602', '鳥取県', 'トットリケン', '東伯郡湯梨浜町', 'トウハクグンユリハマチョウ', '石脇', 'イシワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡湯梨浜町小浜', '31', '31370', '6890603', '鳥取県', 'トットリケン', '東伯郡湯梨浜町', 'トウハクグンユリハマチョウ', '小浜', 'コバマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡湯梨浜町筒地', '31', '31370', '6890604', '鳥取県', 'トットリケン', '東伯郡湯梨浜町', 'トウハクグンユリハマチョウ', '筒地', 'ツツジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡湯梨浜町園', '31', '31370', '6890605', '鳥取県', 'トットリケン', '東伯郡湯梨浜町', 'トウハクグンユリハマチョウ', '園', 'ソノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡湯梨浜町原', '31', '31370', '6890606', '鳥取県', 'トットリケン', '東伯郡湯梨浜町', 'トウハクグンユリハマチョウ', '原', 'ハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡湯梨浜町宇谷', '31', '31370', '6890607', '鳥取県', 'トットリケン', '東伯郡湯梨浜町', 'トウハクグンユリハマチョウ', '宇谷', 'ウタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡湯梨浜町北福', '31', '31370', '6890701', '鳥取県', 'トットリケン', '東伯郡湯梨浜町', 'トウハクグンユリハマチョウ', '北福', 'キタフク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡湯梨浜町漆原', '31', '31370', '6890702', '鳥取県', 'トットリケン', '東伯郡湯梨浜町', 'トウハクグンユリハマチョウ', '漆原', 'ウルシバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡湯梨浜町方地', '31', '31370', '6890703', '鳥取県', 'トットリケン', '東伯郡湯梨浜町', 'トウハクグンユリハマチョウ', '方地', 'ホウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡湯梨浜町白石', '31', '31370', '6890704', '鳥取県', 'トットリケン', '東伯郡湯梨浜町', 'トウハクグンユリハマチョウ', '白石', 'シライシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡湯梨浜町野方', '31', '31370', '6890705', '鳥取県', 'トットリケン', '東伯郡湯梨浜町', 'トウハクグンユリハマチョウ', '野方', 'ノカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡湯梨浜町藤津', '31', '31370', '6890706', '鳥取県', 'トットリケン', '東伯郡湯梨浜町', 'トウハクグンユリハマチョウ', '藤津', 'フジツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡湯梨浜町宮内', '31', '31370', '6890707', '鳥取県', 'トットリケン', '東伯郡湯梨浜町', 'トウハクグンユリハマチョウ', '宮内', 'ミヤウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡湯梨浜町松崎', '31', '31370', '6890711', '鳥取県', 'トットリケン', '東伯郡湯梨浜町', 'トウハクグンユリハマチョウ', '松崎', 'マツザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡湯梨浜町中興寺', '31', '31370', '6890712', '鳥取県', 'トットリケン', '東伯郡湯梨浜町', 'トウハクグンユリハマチョウ', '中興寺', 'チュウコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡湯梨浜町旭', '31', '31370', '6890713', '鳥取県', 'トットリケン', '東伯郡湯梨浜町', 'トウハクグンユリハマチョウ', '旭', 'アサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡湯梨浜町龍島', '31', '31370', '6890714', '鳥取県', 'トットリケン', '東伯郡湯梨浜町', 'トウハクグンユリハマチョウ', '龍島', 'リュウトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡湯梨浜町引地', '31', '31370', '6890715', '鳥取県', 'トットリケン', '東伯郡湯梨浜町', 'トウハクグンユリハマチョウ', '引地', 'ヒキジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡湯梨浜町麻畑', '31', '31370', '6890721', '鳥取県', 'トットリケン', '東伯郡湯梨浜町', 'トウハクグンユリハマチョウ', '麻畑', 'アサバタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡湯梨浜町川上', '31', '31370', '6890722', '鳥取県', 'トットリケン', '東伯郡湯梨浜町', 'トウハクグンユリハマチョウ', '川上', 'カワカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡湯梨浜町高辻', '31', '31370', '6890723', '鳥取県', 'トットリケン', '東伯郡湯梨浜町', 'トウハクグンユリハマチョウ', '高辻', 'タカツジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡湯梨浜町方面', '31', '31370', '6890724', '鳥取県', 'トットリケン', '東伯郡湯梨浜町', 'トウハクグンユリハマチョウ', '方面', 'カタモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡湯梨浜町別所', '31', '31370', '6890725', '鳥取県', 'トットリケン', '東伯郡湯梨浜町', 'トウハクグンユリハマチョウ', '別所', 'ベッショ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡湯梨浜町国信', '31', '31370', '6890726', '鳥取県', 'トットリケン', '東伯郡湯梨浜町', 'トウハクグンユリハマチョウ', '国信', 'クニノブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡湯梨浜町田畑', '31', '31370', '6890727', '鳥取県', 'トットリケン', '東伯郡湯梨浜町', 'トウハクグンユリハマチョウ', '田畑', 'タバタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡湯梨浜町久見', '31', '31370', '6890728', '鳥取県', 'トットリケン', '東伯郡湯梨浜町', 'トウハクグンユリハマチョウ', '久見', 'ヒサミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡湯梨浜町小鹿谷', '31', '31370', '6890729', '鳥取県', 'トットリケン', '東伯郡湯梨浜町', 'トウハクグンユリハマチョウ', '小鹿谷', 'オシカダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡湯梨浜町野花', '31', '31370', '6890731', '鳥取県', 'トットリケン', '東伯郡湯梨浜町', 'トウハクグンユリハマチョウ', '野花', 'ノキョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡湯梨浜町長和田', '31', '31370', '6890732', '鳥取県', 'トットリケン', '東伯郡湯梨浜町', 'トウハクグンユリハマチョウ', '長和田', 'ナゴウタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡湯梨浜町羽衣石', '31', '31370', '6890733', '鳥取県', 'トットリケン', '東伯郡湯梨浜町', 'トウハクグンユリハマチョウ', '羽衣石', 'ウエシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡湯梨浜町埴見', '31', '31370', '6890734', '鳥取県', 'トットリケン', '東伯郡湯梨浜町', 'トウハクグンユリハマチョウ', '埴見', 'ハナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡湯梨浜町佐美', '31', '31370', '6890735', '鳥取県', 'トットリケン', '東伯郡湯梨浜町', 'トウハクグンユリハマチョウ', '佐美', 'サビ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡湯梨浜町門田', '31', '31370', '6890736', '鳥取県', 'トットリケン', '東伯郡湯梨浜町', 'トウハクグンユリハマチョウ', '門田', 'カドタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡湯梨浜町長江', '31', '31370', '6890737', '鳥取県', 'トットリケン', '東伯郡湯梨浜町', 'トウハクグンユリハマチョウ', '長江', 'ナガエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市杉崎', '31', '31201', '6891101', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '杉崎', 'スギザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市津ノ井', '31', '31201', '6891102', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '津ノ井', 'ツノイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市生山', '31', '31201', '6891103', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '生山', 'ショウザン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市桂木', '31', '31201', '6891104', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '桂木', 'カツラギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市東大路', '31', '31201', '6891105', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '東大路', 'ヒガシオオロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市中大路', '31', '31201', '6891106', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '中大路', 'ナカオオロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市西大路', '31', '31201', '6891107', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '西大路', 'ニシオオロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市若葉台北', '31', '31201', '6891111', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '若葉台北', 'ワカバダイキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市若葉台南', '31', '31201', '6891112', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '若葉台南', 'ワカバダイミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市祢宜谷', '31', '31201', '6891113', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '祢宜谷', 'ネギダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市香取', '31', '31201', '6891114', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '香取', 'カトリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市紙子谷', '31', '31201', '6891115', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '紙子谷', 'カゴダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市広岡', '31', '31201', '6891116', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '広岡', 'ヒロオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市海蔵寺', '31', '31201', '6891117', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '海蔵寺', 'カイゾウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市南栄町', '31', '31201', '6891121', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '南栄町', 'ナンエイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市船木', '31', '31201', '6891122', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '船木', 'フナキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市久末', '31', '31201', '6891123', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '久末', 'ヒサスエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市越路', '31', '31201', '6891124', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '越路', 'コイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市古郡家', '31', '31201', '6891125', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '古郡家', 'ココオゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市美和', '31', '31201', '6891126', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '美和', 'ミワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市用瀬町用瀬', '31', '31201', '6891201', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '用瀬町用瀬', 'モチガセチョウモチガセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市用瀬町別府', '31', '31201', '6891211', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '用瀬町別府', 'モチガセチョウベフ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市用瀬町美成', '31', '31201', '6891212', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '用瀬町美成', 'モチガセチョウミナリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市用瀬町鷹狩', '31', '31201', '6891213', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '用瀬町鷹狩', 'モチガセチョウタカガリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市用瀬町旭ケ丘', '31', '31201', '6891214', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '用瀬町旭ケ丘', 'モチガセチョウアサヒガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市用瀬町赤波', '31', '31201', '6891215', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '用瀬町赤波', 'モチガセチョウアガナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市用瀬町古用瀬', '31', '31201', '6891221', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '用瀬町古用瀬', 'モチガセチョウフルモチガセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市用瀬町家奥', '31', '31201', '6891222', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '用瀬町家奥', 'モチガセチョウイエオク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市用瀬町金屋', '31', '31201', '6891223', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '用瀬町金屋', 'モチガセチョウカナヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市用瀬町樟原', '31', '31201', '6891224', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '用瀬町樟原', 'モチガセチョウクヌギワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市用瀬町宮原', '31', '31201', '6891225', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '用瀬町宮原', 'モチガセチョウミヤバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市用瀬町川中', '31', '31201', '6891226', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '用瀬町川中', 'モチガセチョウカワナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市用瀬町安蔵', '31', '31201', '6891227', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '用瀬町安蔵', 'モチガセチョウアゾウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市用瀬町屋住', '31', '31201', '6891228', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '用瀬町屋住', 'モチガセチョウヤズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市用瀬町江波', '31', '31201', '6891229', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '用瀬町江波', 'モチガセチョウエナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市佐治町葛谷', '31', '31201', '6891301', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '佐治町葛谷', 'サジチョウカズラタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市佐治町小原', '31', '31201', '6891302', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '佐治町小原', 'サジチョウコバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市佐治町刈地', '31', '31201', '6891303', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '佐治町刈地', 'サジチョウカルチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市佐治町大井', '31', '31201', '6891304', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '佐治町大井', 'サジチョウオオイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市佐治町森坪', '31', '31201', '6891305', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '佐治町森坪', 'サジチョウモリツボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市佐治町古市', '31', '31201', '6891306', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '佐治町古市', 'サジチョウフルイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市佐治町津無', '31', '31201', '6891307', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '佐治町津無', 'サジチョウツナシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市佐治町津野', '31', '31201', '6891311', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '佐治町津野', 'サジチョウツノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市佐治町高山', '31', '31201', '6891312', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '佐治町高山', 'サジチョウタカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市佐治町加瀬木', '31', '31201', '6891313', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '佐治町加瀬木', 'サジチョウカセギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市佐治町加茂', '31', '31201', '6891314', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '佐治町加茂', 'サジチョウカモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市佐治町畑', '31', '31201', '6891315', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '佐治町畑', 'サジチョウハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市佐治町福園', '31', '31201', '6891316', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '佐治町福園', 'サジチョウフクゾノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市佐治町河本', '31', '31201', '6891321', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '佐治町河本', 'サジチョウカワモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市佐治町つく谷', '31', '31201', '6891322', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '佐治町つく谷', 'サジチョウツクダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市佐治町余戸', '31', '31201', '6891323', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '佐治町余戸', 'サジチョウヨド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市佐治町尾際', '31', '31201', '6891324', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '佐治町尾際', 'サジチョウオワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市佐治町中', '31', '31201', '6891325', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '佐治町中', 'サジチョウナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県鳥取市佐治町栃原', '31', '31201', '6891326', '鳥取県', 'トットリケン', '鳥取市', 'トットリシ', '佐治町栃原', 'サジチョウトチワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡智頭町', '31', '31328', '6891400', '鳥取県', 'トットリケン', '八頭郡智頭町', 'ヤズグンチヅチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('84591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡智頭町市瀬', '31', '31328', '6891401', '鳥取県', 'トットリケン', '八頭郡智頭町', 'ヤズグンチヅチョウ', '市瀬', 'イチノセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡智頭町智頭', '31', '31328', '6891402', '鳥取県', 'トットリケン', '八頭郡智頭町', 'ヤズグンチヅチョウ', '智頭', 'チズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡智頭町南方', '31', '31328', '6891403', '鳥取県', 'トットリケン', '八頭郡智頭町', 'ヤズグンチヅチョウ', '南方', 'ミナミガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡智頭町岩神', '31', '31328', '6891404', '鳥取県', 'トットリケン', '八頭郡智頭町', 'ヤズグンチヅチョウ', '岩神', 'イワガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡智頭町八河谷', '31', '31328', '6891411', '鳥取県', 'トットリケン', '八頭郡智頭町', 'ヤズグンチヅチョウ', '八河谷', 'ヤコウダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡智頭町芦津', '31', '31328', '6891412', '鳥取県', 'トットリケン', '八頭郡智頭町', 'ヤズグンチヅチョウ', '芦津', 'アシヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡智頭町大呂', '31', '31328', '6891413', '鳥取県', 'トットリケン', '八頭郡智頭町', 'ヤズグンチヅチョウ', '大呂', 'オオロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡智頭町西野', '31', '31328', '6891414', '鳥取県', 'トットリケン', '八頭郡智頭町', 'ヤズグンチヅチョウ', '西野', 'ニシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡智頭町郷原', '31', '31328', '6891415', '鳥取県', 'トットリケン', '八頭郡智頭町', 'ヤズグンチヅチョウ', '郷原', 'ゴウバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡智頭町毛谷', '31', '31328', '6891416', '鳥取県', 'トットリケン', '八頭郡智頭町', 'ヤズグンチヅチョウ', '毛谷', 'ケダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡智頭町篠坂', '31', '31328', '6891417', '鳥取県', 'トットリケン', '八頭郡智頭町', 'ヤズグンチヅチョウ', '篠坂', 'シノザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡智頭町大内', '31', '31328', '6891421', '鳥取県', 'トットリケン', '八頭郡智頭町', 'ヤズグンチヅチョウ', '大内', 'オオチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡智頭町尾見', '31', '31328', '6891422', '鳥取県', 'トットリケン', '八頭郡智頭町', 'ヤズグンチヅチョウ', '尾見', 'オミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡智頭町中原', '31', '31328', '6891423', '鳥取県', 'トットリケン', '八頭郡智頭町', 'ヤズグンチヅチョウ', '中原', 'ナカバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡智頭町駒帰', '31', '31328', '6891424', '鳥取県', 'トットリケン', '八頭郡智頭町', 'ヤズグンチヅチョウ', '駒帰', 'コマガエリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡智頭町福原', '31', '31328', '6891425', '鳥取県', 'トットリケン', '八頭郡智頭町', 'ヤズグンチヅチョウ', '福原', 'フクワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡智頭町西谷', '31', '31328', '6891426', '鳥取県', 'トットリケン', '八頭郡智頭町', 'ヤズグンチヅチョウ', '西谷', 'ニシダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡智頭町山根', '31', '31328', '6891431', '鳥取県', 'トットリケン', '八頭郡智頭町', 'ヤズグンチヅチョウ', '山根', 'ヤマネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡智頭町穂見', '31', '31328', '6891432', '鳥取県', 'トットリケン', '八頭郡智頭町', 'ヤズグンチヅチョウ', '穂見', 'ホノミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡智頭町埴師', '31', '31328', '6891433', '鳥取県', 'トットリケン', '八頭郡智頭町', 'ヤズグンチヅチョウ', '埴師', 'ハニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡智頭町三吉', '31', '31328', '6891434', '鳥取県', 'トットリケン', '八頭郡智頭町', 'ヤズグンチヅチョウ', '三吉', 'ミヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡智頭町横田', '31', '31328', '6891435', '鳥取県', 'トットリケン', '八頭郡智頭町', 'ヤズグンチヅチョウ', '横田', 'ヨコタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡智頭町木原', '31', '31328', '6891436', '鳥取県', 'トットリケン', '八頭郡智頭町', 'ヤズグンチヅチョウ', '木原', 'キハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡智頭町三田', '31', '31328', '6891437', '鳥取県', 'トットリケン', '八頭郡智頭町', 'ヤズグンチヅチョウ', '三田', 'ミタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡智頭町慶所', '31', '31328', '6891441', '鳥取県', 'トットリケン', '八頭郡智頭町', 'ヤズグンチヅチョウ', '慶所', 'ケイジョ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡智頭町大屋', '31', '31328', '6891442', '鳥取県', 'トットリケン', '八頭郡智頭町', 'ヤズグンチヅチョウ', '大屋', 'オオヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡智頭町真鹿野', '31', '31328', '6891443', '鳥取県', 'トットリケン', '八頭郡智頭町', 'ヤズグンチヅチョウ', '真鹿野', 'マガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡智頭町野原', '31', '31328', '6891444', '鳥取県', 'トットリケン', '八頭郡智頭町', 'ヤズグンチヅチョウ', '野原', 'ノバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡智頭町早瀬', '31', '31328', '6891445', '鳥取県', 'トットリケン', '八頭郡智頭町', 'ヤズグンチヅチョウ', '早瀬', 'ハヤセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡智頭町大背', '31', '31328', '6891451', '鳥取県', 'トットリケン', '八頭郡智頭町', 'ヤズグンチヅチョウ', '大背', 'オオセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡智頭町奥本', '31', '31328', '6891452', '鳥取県', 'トットリケン', '八頭郡智頭町', 'ヤズグンチヅチョウ', '奥本', 'オクモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡智頭町東宇塚', '31', '31328', '6891453', '鳥取県', 'トットリケン', '八頭郡智頭町', 'ヤズグンチヅチョウ', '東宇塚', 'ヒガシウヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡智頭町河津原', '31', '31328', '6891454', '鳥取県', 'トットリケン', '八頭郡智頭町', 'ヤズグンチヅチョウ', '河津原', 'コウヅワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡智頭町西宇塚', '31', '31328', '6891455', '鳥取県', 'トットリケン', '八頭郡智頭町', 'ヤズグンチヅチョウ', '西宇塚', 'ニシウヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡智頭町坂原', '31', '31328', '6891461', '鳥取県', 'トットリケン', '八頭郡智頭町', 'ヤズグンチヅチョウ', '坂原', 'サカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡智頭町中田', '31', '31328', '6891462', '鳥取県', 'トットリケン', '八頭郡智頭町', 'ヤズグンチヅチョウ', '中田', 'ナカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡智頭町新見', '31', '31328', '6891463', '鳥取県', 'トットリケン', '八頭郡智頭町', 'ヤズグンチヅチョウ', '新見', 'ニイミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡智頭町口宇波', '31', '31328', '6891464', '鳥取県', 'トットリケン', '八頭郡智頭町', 'ヤズグンチヅチョウ', '口宇波', 'クチウナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡智頭町宇波', '31', '31328', '6891465', '鳥取県', 'トットリケン', '八頭郡智頭町', 'ヤズグンチヅチョウ', '宇波', 'ウナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡智頭町波多', '31', '31328', '6891466', '鳥取県', 'トットリケン', '八頭郡智頭町', 'ヤズグンチヅチョウ', '波多', 'ハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡智頭町口波多', '31', '31328', '6891467', '鳥取県', 'トットリケン', '八頭郡智頭町', 'ヤズグンチヅチョウ', '口波多', 'クチハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県八頭郡智頭町惣地', '31', '31328', '6891468', '鳥取県', 'トットリケン', '八頭郡智頭町', 'ヤズグンチヅチョウ', '惣地', 'ソウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡北栄町江北', '31', '31372', '6892101', '鳥取県', 'トットリケン', '東伯郡北栄町', 'トウハクグンホクエイチョウ', '江北', 'エキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡北栄町国坂', '31', '31372', '6892102', '鳥取県', 'トットリケン', '東伯郡北栄町', 'トウハクグンホクエイチョウ', '国坂', 'クニサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡北栄町田井', '31', '31372', '6892103', '鳥取県', 'トットリケン', '東伯郡北栄町', 'トウハクグンホクエイチョウ', '田井', 'タイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡北栄町弓原', '31', '31372', '6892104', '鳥取県', 'トットリケン', '東伯郡北栄町', 'トウハクグンホクエイチョウ', '弓原', 'ユミハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡北栄町下神', '31', '31372', '6892105', '鳥取県', 'トットリケン', '東伯郡北栄町', 'トウハクグンホクエイチョウ', '下神', 'シモツワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡北栄町松神', '31', '31372', '6892106', '鳥取県', 'トットリケン', '東伯郡北栄町', 'トウハクグンホクエイチョウ', '松神', 'マツガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡北栄町土下', '31', '31372', '6892111', '鳥取県', 'トットリケン', '東伯郡北栄町', 'トウハクグンホクエイチョウ', '土下', 'ハシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡北栄町北条島', '31', '31372', '6892112', '鳥取県', 'トットリケン', '東伯郡北栄町', 'トウハクグンホクエイチョウ', '北条島', 'ホウジョウシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡北栄町米里', '31', '31372', '6892113', '鳥取県', 'トットリケン', '東伯郡北栄町', 'トウハクグンホクエイチョウ', '米里', 'ヨネサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡北栄町北尾', '31', '31372', '6892114', '鳥取県', 'トットリケン', '東伯郡北栄町', 'トウハクグンホクエイチョウ', '北尾', 'キタオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡北栄町曲', '31', '31372', '6892115', '鳥取県', 'トットリケン', '東伯郡北栄町', 'トウハクグンホクエイチョウ', '曲', 'マガリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡北栄町', '31', '31372', '6892200', '鳥取県', 'トットリケン', '東伯郡北栄町', 'トウハクグンホクエイチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('84645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡北栄町西園', '31', '31372', '6892201', '鳥取県', 'トットリケン', '東伯郡北栄町', 'トウハクグンホクエイチョウ', '西園', 'ニシソノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡北栄町東園', '31', '31372', '6892202', '鳥取県', 'トットリケン', '東伯郡北栄町', 'トウハクグンホクエイチョウ', '東園', 'ヒガシソノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡北栄町原', '31', '31372', '6892203', '鳥取県', 'トットリケン', '東伯郡北栄町', 'トウハクグンホクエイチョウ', '原', 'ハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡北栄町穂波', '31', '31372', '6892204', '鳥取県', 'トットリケン', '東伯郡北栄町', 'トウハクグンホクエイチョウ', '穂波', 'ホナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡北栄町瀬戸', '31', '31372', '6892205', '鳥取県', 'トットリケン', '東伯郡北栄町', 'トウハクグンホクエイチョウ', '瀬戸', 'セト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡北栄町大島', '31', '31372', '6892206', '鳥取県', 'トットリケン', '東伯郡北栄町', 'トウハクグンホクエイチョウ', '大島', 'オオシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡北栄町西穂波', '31', '31372', '6892207', '鳥取県', 'トットリケン', '東伯郡北栄町', 'トウハクグンホクエイチョウ', '西穂波', 'ニシホナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡北栄町六尾', '31', '31372', '6892208', '鳥取県', 'トットリケン', '東伯郡北栄町', 'トウハクグンホクエイチョウ', '六尾', 'ムツオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡北栄町亀谷', '31', '31372', '6892211', '鳥取県', 'トットリケン', '東伯郡北栄町', 'トウハクグンホクエイチョウ', '亀谷', 'カメダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡北栄町下種', '31', '31372', '6892212', '鳥取県', 'トットリケン', '東伯郡北栄町', 'トウハクグンホクエイチョウ', '下種', 'シモダネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡北栄町上種', '31', '31372', '6892213', '鳥取県', 'トットリケン', '東伯郡北栄町', 'トウハクグンホクエイチョウ', '上種', 'カミダネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡北栄町東高尾', '31', '31372', '6892214', '鳥取県', 'トットリケン', '東伯郡北栄町', 'トウハクグンホクエイチョウ', '東高尾', 'ヒガシタカオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡北栄町西高尾', '31', '31372', '6892215', '鳥取県', 'トットリケン', '東伯郡北栄町', 'トウハクグンホクエイチョウ', '西高尾', 'ニシタカオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡北栄町岩坪', '31', '31372', '6892216', '鳥取県', 'トットリケン', '東伯郡北栄町', 'トウハクグンホクエイチョウ', '岩坪', 'イワツボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡北栄町由良宿', '31', '31372', '6892221', '鳥取県', 'トットリケン', '東伯郡北栄町', 'トウハクグンホクエイチョウ', '由良宿', 'ユラシュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡北栄町大谷', '31', '31372', '6892223', '鳥取県', 'トットリケン', '東伯郡北栄町', 'トウハクグンホクエイチョウ', '大谷', 'オオダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡北栄町妻波', '31', '31372', '6892224', '鳥取県', 'トットリケン', '東伯郡北栄町', 'トウハクグンホクエイチョウ', '妻波', 'ツマナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡琴浦町', '31', '31371', '6892300', '鳥取県', 'トットリケン', '東伯郡琴浦町', 'トウハクグンコトウラチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('84667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡琴浦町八橋', '31', '31371', '6892301', '鳥取県', 'トットリケン', '東伯郡琴浦町', 'トウハクグンコトウラチョウ', '八橋', 'ヤバセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡琴浦町丸尾', '31', '31371', '6892302', '鳥取県', 'トットリケン', '東伯郡琴浦町', 'トウハクグンコトウラチョウ', '丸尾', 'マルオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡琴浦町徳万', '31', '31371', '6892303', '鳥取県', 'トットリケン', '東伯郡琴浦町', 'トウハクグンコトウラチョウ', '徳万', 'トクマン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡琴浦町逢束', '31', '31371', '6892304', '鳥取県', 'トットリケン', '東伯郡琴浦町', 'トウハクグンコトウラチョウ', '逢束', 'オオツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡琴浦町槻下', '31', '31371', '6892305', '鳥取県', 'トットリケン', '東伯郡琴浦町', 'トウハクグンコトウラチョウ', '槻下', 'ツキノシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡琴浦町笠見', '31', '31371', '6892306', '鳥取県', 'トットリケン', '東伯郡琴浦町', 'トウハクグンコトウラチョウ', '笠見', 'カサミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡琴浦町中尾', '31', '31371', '6892311', '鳥取県', 'トットリケン', '東伯郡琴浦町', 'トウハクグンコトウラチョウ', '中尾', 'ナカオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡琴浦町金屋', '31', '31371', '6892312', '鳥取県', 'トットリケン', '東伯郡琴浦町', 'トウハクグンコトウラチョウ', '金屋', 'カナヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡琴浦町杉下', '31', '31371', '6892313', '鳥取県', 'トットリケン', '東伯郡琴浦町', 'トウハクグンコトウラチョウ', '杉下', 'スギシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡琴浦町下大江', '31', '31371', '6892314', '鳥取県', 'トットリケン', '東伯郡琴浦町', 'トウハクグンコトウラチョウ', '下大江', 'シモオオエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡琴浦町上伊勢', '31', '31371', '6892315', '鳥取県', 'トットリケン', '東伯郡琴浦町', 'トウハクグンコトウラチョウ', '上伊勢', 'カミイセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡琴浦町下伊勢', '31', '31371', '6892316', '鳥取県', 'トットリケン', '東伯郡琴浦町', 'トウハクグンコトウラチョウ', '下伊勢', 'シモイセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡琴浦町森藤', '31', '31371', '6892321', '鳥取県', 'トットリケン', '東伯郡琴浦町', 'トウハクグンコトウラチョウ', '森藤', 'モリトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡琴浦町八反田', '31', '31371', '6892322', '鳥取県', 'トットリケン', '東伯郡琴浦町', 'トウハクグンコトウラチョウ', '八反田', 'ハッタンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡琴浦町宮場', '31', '31371', '6892323', '鳥取県', 'トットリケン', '東伯郡琴浦町', 'トウハクグンコトウラチョウ', '宮場', 'ミヤバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡琴浦町矢下', '31', '31371', '6892324', '鳥取県', 'トットリケン', '東伯郡琴浦町', 'トウハクグンコトウラチョウ', '矢下', 'ヤジタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡琴浦町法万', '31', '31371', '6892325', '鳥取県', 'トットリケン', '東伯郡琴浦町', 'トウハクグンコトウラチョウ', '法万', 'ホウマン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡琴浦町光好', '31', '31371', '6892326', '鳥取県', 'トットリケン', '東伯郡琴浦町', 'トウハクグンコトウラチョウ', '光好', 'ミツヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡琴浦町杉地', '31', '31371', '6892331', '鳥取県', 'トットリケン', '東伯郡琴浦町', 'トウハクグンコトウラチョウ', '杉地', 'スギジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡琴浦町古長', '31', '31371', '6892332', '鳥取県', 'トットリケン', '東伯郡琴浦町', 'トウハクグンコトウラチョウ', '古長', 'フルナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡琴浦町別宮', '31', '31371', '6892333', '鳥取県', 'トットリケン', '東伯郡琴浦町', 'トウハクグンコトウラチョウ', '別宮', 'ベツミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡琴浦町三本杉', '31', '31371', '6892334', '鳥取県', 'トットリケン', '東伯郡琴浦町', 'トウハクグンコトウラチョウ', '三本杉', 'サンボンスギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡琴浦町中津原', '31', '31371', '6892335', '鳥取県', 'トットリケン', '東伯郡琴浦町', 'トウハクグンコトウラチョウ', '中津原', 'ナカツハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡琴浦町野井倉', '31', '31371', '6892336', '鳥取県', 'トットリケン', '東伯郡琴浦町', 'トウハクグンコトウラチョウ', '野井倉', 'ノイグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡琴浦町倉坂', '31', '31371', '6892341', '鳥取県', 'トットリケン', '東伯郡琴浦町', 'トウハクグンコトウラチョウ', '倉坂', 'クラサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡琴浦町公文', '31', '31371', '6892342', '鳥取県', 'トットリケン', '東伯郡琴浦町', 'トウハクグンコトウラチョウ', '公文', 'クモン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡琴浦町山田', '31', '31371', '6892343', '鳥取県', 'トットリケン', '東伯郡琴浦町', 'トウハクグンコトウラチョウ', '山田', 'ヤマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡琴浦町大杉', '31', '31371', '6892344', '鳥取県', 'トットリケン', '東伯郡琴浦町', 'トウハクグンコトウラチョウ', '大杉', 'オオスギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡琴浦町福永', '31', '31371', '6892345', '鳥取県', 'トットリケン', '東伯郡琴浦町', 'トウハクグンコトウラチョウ', '福永', 'フクナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡琴浦町野田', '31', '31371', '6892346', '鳥取県', 'トットリケン', '東伯郡琴浦町', 'トウハクグンコトウラチョウ', '野田', 'ノタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡琴浦町保', '31', '31371', '6892351', '鳥取県', 'トットリケン', '東伯郡琴浦町', 'トウハクグンコトウラチョウ', '保', 'ホウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡琴浦町浦安', '31', '31371', '6892352', '鳥取県', 'トットリケン', '東伯郡琴浦町', 'トウハクグンコトウラチョウ', '浦安', 'ウラヤス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡琴浦町三保', '31', '31371', '6892353', '鳥取県', 'トットリケン', '東伯郡琴浦町', 'トウハクグンコトウラチョウ', '三保', 'ミホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡琴浦町美好', '31', '31371', '6892354', '鳥取県', 'トットリケン', '東伯郡琴浦町', 'トウハクグンコトウラチョウ', '美好', 'ミヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡琴浦町釛', '31', '31371', '6892355', '鳥取県', 'トットリケン', '東伯郡琴浦町', 'トウハクグンコトウラチョウ', '釛', 'コガネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡琴浦町田越', '31', '31371', '6892356', '鳥取県', 'トットリケン', '東伯郡琴浦町', 'トウハクグンコトウラチョウ', '田越', 'タコエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡琴浦町赤碕', '31', '31371', '6892501', '鳥取県', 'トットリケン', '東伯郡琴浦町', 'トウハクグンコトウラチョウ', '赤碕', 'アカサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡琴浦町別所', '31', '31371', '6892502', '鳥取県', 'トットリケン', '東伯郡琴浦町', 'トウハクグンコトウラチョウ', '別所', 'ベッショ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡琴浦町松谷', '31', '31371', '6892503', '鳥取県', 'トットリケン', '東伯郡琴浦町', 'トウハクグンコトウラチョウ', '松谷', 'マツダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡琴浦町出上', '31', '31371', '6892511', '鳥取県', 'トットリケン', '東伯郡琴浦町', 'トウハクグンコトウラチョウ', '出上', 'イデカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡琴浦町勝田', '31', '31371', '6892512', '鳥取県', 'トットリケン', '東伯郡琴浦町', 'トウハクグンコトウラチョウ', '勝田', 'カツタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡琴浦町西宮', '31', '31371', '6892513', '鳥取県', 'トットリケン', '東伯郡琴浦町', 'トウハクグンコトウラチョウ', '西宮', 'ニシミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡琴浦町竹内', '31', '31371', '6892521', '鳥取県', 'トットリケン', '東伯郡琴浦町', 'トウハクグンコトウラチョウ', '竹内', 'タケウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡琴浦町宮木', '31', '31371', '6892522', '鳥取県', 'トットリケン', '東伯郡琴浦町', 'トウハクグンコトウラチョウ', '宮木', 'ミヤキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡琴浦町高岡', '31', '31371', '6892523', '鳥取県', 'トットリケン', '東伯郡琴浦町', 'トウハクグンコトウラチョウ', '高岡', 'タカオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡琴浦町大父', '31', '31371', '6892524', '鳥取県', 'トットリケン', '東伯郡琴浦町', 'トウハクグンコトウラチョウ', '大父', 'オオブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡琴浦町山川', '31', '31371', '6892525', '鳥取県', 'トットリケン', '東伯郡琴浦町', 'トウハクグンコトウラチョウ', '山川', 'ヤマガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡琴浦町佐崎', '31', '31371', '6892531', '鳥取県', 'トットリケン', '東伯郡琴浦町', 'トウハクグンコトウラチョウ', '佐崎', 'サザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡琴浦町太一垣', '31', '31371', '6892532', '鳥取県', 'トットリケン', '東伯郡琴浦町', 'トウハクグンコトウラチョウ', '太一垣', 'タイチガキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡琴浦町中村', '31', '31371', '6892533', '鳥取県', 'トットリケン', '東伯郡琴浦町', 'トウハクグンコトウラチョウ', '中村', 'ナカムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡琴浦町光', '31', '31371', '6892534', '鳥取県', 'トットリケン', '東伯郡琴浦町', 'トウハクグンコトウラチョウ', '光', 'ミツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡琴浦町尾張', '31', '31371', '6892535', '鳥取県', 'トットリケン', '東伯郡琴浦町', 'トウハクグンコトウラチョウ', '尾張', 'オワリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡琴浦町八幡', '31', '31371', '6892541', '鳥取県', 'トットリケン', '東伯郡琴浦町', 'トウハクグンコトウラチョウ', '八幡', 'ヤワタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡琴浦町湯坂', '31', '31371', '6892542', '鳥取県', 'トットリケン', '東伯郡琴浦町', 'トウハクグンコトウラチョウ', '湯坂', 'ユザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡琴浦町梅田', '31', '31371', '6892543', '鳥取県', 'トットリケン', '東伯郡琴浦町', 'トウハクグンコトウラチョウ', '梅田', 'ウメダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県東伯郡琴浦町箆津', '31', '31371', '6892544', '鳥取県', 'トットリケン', '東伯郡琴浦町', 'トウハクグンコトウラチョウ', '箆津', 'ノツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡大山町潮音寺', '31', '31386', '6893101', '鳥取県', 'トットリケン', '西伯郡大山町', 'サイハクグンダイセンチョウ', '潮音寺', 'チョウオンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡大山町石井垣', '31', '31386', '6893102', '鳥取県', 'トットリケン', '西伯郡大山町', 'サイハクグンダイセンチョウ', '石井垣', 'イワイガキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡大山町樋口', '31', '31386', '6893103', '鳥取県', 'トットリケン', '西伯郡大山町', 'サイハクグンダイセンチョウ', '樋口', 'ヒノクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡大山町八重', '31', '31386', '6893104', '鳥取県', 'トットリケン', '西伯郡大山町', 'サイハクグンダイセンチョウ', '八重', 'ヤエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡大山町束積', '31', '31386', '6893105', '鳥取県', 'トットリケン', '西伯郡大山町', 'サイハクグンダイセンチョウ', '束積', 'ツカヅミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡大山町羽田井', '31', '31386', '6893106', '鳥取県', 'トットリケン', '西伯郡大山町', 'サイハクグンダイセンチョウ', '羽田井', 'ハタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡大山町赤坂', '31', '31386', '6893111', '鳥取県', 'トットリケン', '西伯郡大山町', 'サイハクグンダイセンチョウ', '赤坂', 'アカザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡大山町下甲', '31', '31386', '6893112', '鳥取県', 'トットリケン', '西伯郡大山町', 'サイハクグンダイセンチョウ', '下甲', 'シモギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡大山町御崎', '31', '31386', '6893113', '鳥取県', 'トットリケン', '西伯郡大山町', 'サイハクグンダイセンチョウ', '御崎', 'ミサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡大山町田中', '31', '31386', '6893114', '鳥取県', 'トットリケン', '西伯郡大山町', 'サイハクグンダイセンチョウ', '田中', 'タナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡大山町栄田', '31', '31386', '6893115', '鳥取県', 'トットリケン', '西伯郡大山町', 'サイハクグンダイセンチョウ', '栄田', 'サカエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡大山町岡', '31', '31386', '6893121', '鳥取県', 'トットリケン', '西伯郡大山町', 'サイハクグンダイセンチョウ', '岡', 'オカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡大山町塩津', '31', '31386', '6893122', '鳥取県', 'トットリケン', '西伯郡大山町', 'サイハクグンダイセンチョウ', '塩津', 'シオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡大山町住吉', '31', '31386', '6893123', '鳥取県', 'トットリケン', '西伯郡大山町', 'サイハクグンダイセンチョウ', '住吉', 'スミヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡大山町上市', '31', '31386', '6893124', '鳥取県', 'トットリケン', '西伯郡大山町', 'サイハクグンダイセンチョウ', '上市', 'ウワイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡大山町下市', '31', '31386', '6893125', '鳥取県', 'トットリケン', '西伯郡大山町', 'サイハクグンダイセンチョウ', '下市', 'シモイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡大山町松河原', '31', '31386', '6893132', '鳥取県', 'トットリケン', '西伯郡大山町', 'サイハクグンダイセンチョウ', '松河原', 'マツガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡大山町退休寺', '31', '31386', '6893133', '鳥取県', 'トットリケン', '西伯郡大山町', 'サイハクグンダイセンチョウ', '退休寺', 'タイキュウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡大山町高橋', '31', '31386', '6893134', '鳥取県', 'トットリケン', '西伯郡大山町', 'サイハクグンダイセンチョウ', '高橋', 'タカハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡大山町殿河内', '31', '31386', '6893135', '鳥取県', 'トットリケン', '西伯郡大山町', 'サイハクグンダイセンチョウ', '殿河内', 'トノガワチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡大山町長野', '31', '31386', '6893136', '鳥取県', 'トットリケン', '西伯郡大山町', 'サイハクグンダイセンチョウ', '長野', 'ナガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡大山町', '31', '31386', '6893200', '鳥取県', 'トットリケン', '西伯郡大山町', 'サイハクグンダイセンチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('84748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡大山町豊成', '31', '31386', '6893201', '鳥取県', 'トットリケン', '西伯郡大山町', 'サイハクグンダイセンチョウ', '豊成', 'トヨシゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡大山町倉谷', '31', '31386', '6893202', '鳥取県', 'トットリケン', '西伯郡大山町', 'サイハクグンダイセンチョウ', '倉谷', 'クラダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡大山町小竹', '31', '31386', '6893203', '鳥取県', 'トットリケン', '西伯郡大山町', 'サイハクグンダイセンチョウ', '小竹', 'コダケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡大山町東坪', '31', '31386', '6893204', '鳥取県', 'トットリケン', '西伯郡大山町', 'サイハクグンダイセンチョウ', '東坪', 'ヒガシツボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡大山町西坪', '31', '31386', '6893205', '鳥取県', 'トットリケン', '西伯郡大山町', 'サイハクグンダイセンチョウ', '西坪', 'ニシツボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡大山町御来屋', '31', '31386', '6893211', '鳥取県', 'トットリケン', '西伯郡大山町', 'サイハクグンダイセンチョウ', '御来屋', 'ミクリヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡大山町名和', '31', '31386', '6893212', '鳥取県', 'トットリケン', '西伯郡大山町', 'サイハクグンダイセンチョウ', '名和', 'ナワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡大山町門前', '31', '31386', '6893213', '鳥取県', 'トットリケン', '西伯郡大山町', 'サイハクグンダイセンチョウ', '門前', 'モンゼン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡大山町加茂', '31', '31386', '6893214', '鳥取県', 'トットリケン', '西伯郡大山町', 'サイハクグンダイセンチョウ', '加茂', 'カモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡大山町富長', '31', '31386', '6893221', '鳥取県', 'トットリケン', '西伯郡大山町', 'サイハクグンダイセンチョウ', '富長', 'トミナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡大山町古御堂', '31', '31386', '6893222', '鳥取県', 'トットリケン', '西伯郡大山町', 'サイハクグンダイセンチョウ', '古御堂', 'コミドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡大山町茶畑', '31', '31386', '6893223', '鳥取県', 'トットリケン', '西伯郡大山町', 'サイハクグンダイセンチョウ', '茶畑', 'チャバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡大山町高田', '31', '31386', '6893224', '鳥取県', 'トットリケン', '西伯郡大山町', 'サイハクグンダイセンチョウ', '高田', 'タカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡大山町押平', '31', '31386', '6893225', '鳥取県', 'トットリケン', '西伯郡大山町', 'サイハクグンダイセンチョウ', '押平', 'オシナラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡大山町大塚', '31', '31386', '6893226', '鳥取県', 'トットリケン', '西伯郡大山町', 'サイハクグンダイセンチョウ', '大塚', 'オオツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡大山町福尾', '31', '31386', '6893301', '鳥取県', 'トットリケン', '西伯郡大山町', 'サイハクグンダイセンチョウ', '福尾', 'フクオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡大山町上野', '31', '31386', '6893302', '鳥取県', 'トットリケン', '西伯郡大山町', 'サイハクグンダイセンチョウ', '上野', 'ウエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡大山町所子', '31', '31386', '6893303', '鳥取県', 'トットリケン', '西伯郡大山町', 'サイハクグンダイセンチョウ', '所子', 'トコロゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡大山町平木', '31', '31386', '6893304', '鳥取県', 'トットリケン', '西伯郡大山町', 'サイハクグンダイセンチョウ', '平木', 'ヒラギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡大山町神原', '31', '31386', '6893305', '鳥取県', 'トットリケン', '西伯郡大山町', 'サイハクグンダイセンチョウ', '神原', 'カンバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡大山町中高', '31', '31386', '6893306', '鳥取県', 'トットリケン', '西伯郡大山町', 'サイハクグンダイセンチョウ', '中高', 'ナカダカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡大山町野田', '31', '31386', '6893307', '鳥取県', 'トットリケン', '西伯郡大山町', 'サイハクグンダイセンチョウ', '野田', 'ノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡大山町清原', '31', '31386', '6893308', '鳥取県', 'トットリケン', '西伯郡大山町', 'サイハクグンダイセンチョウ', '清原', 'キヨハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡大山町国信', '31', '31386', '6893309', '鳥取県', 'トットリケン', '西伯郡大山町', 'サイハクグンダイセンチョウ', '国信', 'クニノブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡大山町宮内', '31', '31386', '6893311', '鳥取県', 'トットリケン', '西伯郡大山町', 'サイハクグンダイセンチョウ', '宮内', 'ミヤウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡大山町坊領', '31', '31386', '6893312', '鳥取県', 'トットリケン', '西伯郡大山町', 'サイハクグンダイセンチョウ', '坊領', 'ボウリョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡大山町佐摩', '31', '31386', '6893313', '鳥取県', 'トットリケン', '西伯郡大山町', 'サイハクグンダイセンチョウ', '佐摩', 'サマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡大山町今在家', '31', '31386', '6893314', '鳥取県', 'トットリケン', '西伯郡大山町', 'サイハクグンダイセンチョウ', '今在家', 'イマザイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡大山町前', '31', '31386', '6893315', '鳥取県', 'トットリケン', '西伯郡大山町', 'サイハクグンダイセンチョウ', '前', 'マエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡大山町豊房', '31', '31386', '6893316', '鳥取県', 'トットリケン', '西伯郡大山町', 'サイハクグンダイセンチョウ', '豊房', 'トヨフサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡大山町鈑戸', '31', '31386', '6893317', '鳥取県', 'トットリケン', '西伯郡大山町', 'サイハクグンダイセンチョウ', '鈑戸', 'タタラド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡大山町大山', '31', '31386', '6893318', '鳥取県', 'トットリケン', '西伯郡大山町', 'サイハクグンダイセンチョウ', '大山', 'ダイセン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡大山町赤松', '31', '31386', '6893319', '鳥取県', 'トットリケン', '西伯郡大山町', 'サイハクグンダイセンチョウ', '赤松', 'アカマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡大山町平', '31', '31386', '6893321', '鳥取県', 'トットリケン', '西伯郡大山町', 'サイハクグンダイセンチョウ', '平', 'ヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡大山町長田', '31', '31386', '6893322', '鳥取県', 'トットリケン', '西伯郡大山町', 'サイハクグンダイセンチョウ', '長田', 'ナガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡大山町荘田', '31', '31386', '6893323', '鳥取県', 'トットリケン', '西伯郡大山町', 'サイハクグンダイセンチョウ', '荘田', 'ショウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡大山町妻木', '31', '31386', '6893324', '鳥取県', 'トットリケン', '西伯郡大山町', 'サイハクグンダイセンチョウ', '妻木', 'ムキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡大山町富岡', '31', '31386', '6893325', '鳥取県', 'トットリケン', '西伯郡大山町', 'サイハクグンダイセンチョウ', '富岡', 'トミオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡大山町安原', '31', '31386', '6893326', '鳥取県', 'トットリケン', '西伯郡大山町', 'サイハクグンダイセンチョウ', '安原', 'ヤスハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡大山町保田', '31', '31386', '6893327', '鳥取県', 'トットリケン', '西伯郡大山町', 'サイハクグンダイセンチョウ', '保田', 'ヤスダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡大山町末吉', '31', '31386', '6893331', '鳥取県', 'トットリケン', '西伯郡大山町', 'サイハクグンダイセンチョウ', '末吉', 'スエヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡大山町末長', '31', '31386', '6893332', '鳥取県', 'トットリケン', '西伯郡大山町', 'サイハクグンダイセンチョウ', '末長', 'スエナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡大山町唐王', '31', '31386', '6893333', '鳥取県', 'トットリケン', '西伯郡大山町', 'サイハクグンダイセンチョウ', '唐王', 'トウノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡大山町稲光', '31', '31386', '6893334', '鳥取県', 'トットリケン', '西伯郡大山町', 'サイハクグンダイセンチョウ', '稲光', 'イナミツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡大山町上万', '31', '31386', '6893335', '鳥取県', 'トットリケン', '西伯郡大山町', 'サイハクグンダイセンチョウ', '上万', 'ジョウマン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡大山町平田', '31', '31386', '6893336', '鳥取県', 'トットリケン', '西伯郡大山町', 'サイハクグンダイセンチョウ', '平田', 'ヒラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市淀江町今津', '31', '31202', '6893401', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '淀江町今津', 'ヨドエチョウイマヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市淀江町淀江', '31', '31202', '6893402', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '淀江町淀江', 'ヨドエチョウヨドエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市淀江町西原', '31', '31202', '6893403', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '淀江町西原', 'ヨドエチョウニシバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市淀江町福岡', '31', '31202', '6893411', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '淀江町福岡', 'ヨドエチョウフクオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市淀江町稲吉', '31', '31202', '6893412', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '淀江町稲吉', 'ヨドエチョウイナヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市淀江町本宮', '31', '31202', '6893413', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '淀江町本宮', 'ヨドエチョウホングウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市淀江町西尾原', '31', '31202', '6893414', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '淀江町西尾原', 'ヨドエチョウニシオハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市淀江町富繁', '31', '31202', '6893415', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '淀江町富繁', 'ヨドエチョウトミシゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市淀江町福井', '31', '31202', '6893416', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '淀江町福井', 'ヨドエチョウフクイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市淀江町中西尾', '31', '31202', '6893417', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '淀江町中西尾', 'ヨドエチョウナカニシオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市淀江町高井谷', '31', '31202', '6893418', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '淀江町高井谷', 'ヨドエチョウタカイダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市淀江町福頼', '31', '31202', '6893421', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '淀江町福頼', 'ヨドエチョウフクヨリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市淀江町平岡', '31', '31202', '6893422', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '淀江町平岡', 'ヨドエチョウヒラオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市淀江町小波', '31', '31202', '6893423', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '淀江町小波', 'ヨドエチョウコナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市淀江町中間', '31', '31202', '6893424', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '淀江町中間', 'ヨドエチョウナカマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市淀江町佐陀', '31', '31202', '6893425', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '淀江町佐陀', 'ヨドエチョウサダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡日吉津村', '31', '31384', '6893500', '鳥取県', 'トットリケン', '西伯郡日吉津村', 'サイハクグンヒエヅソン', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('84812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市下郷', '31', '31202', '6893511', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '下郷', 'シモノゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市泉', '31', '31202', '6893512', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '泉', 'イズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市岡成', '31', '31202', '6893513', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '岡成', 'オカナリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市尾高', '31', '31202', '6893514', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '尾高', 'オダカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市赤井手', '31', '31202', '6893515', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '赤井手', 'アカイデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市河岡', '31', '31202', '6893521', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '河岡', 'カワオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市日下', '31', '31202', '6893522', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '日下', 'クサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市福万', '31', '31202', '6893523', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '福万', 'フクマン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市石州府', '31', '31202', '6893524', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '石州府', 'セキシュウフ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市下新印', '31', '31202', '6893531', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '下新印', 'シモシイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市上新印', '31', '31202', '6893532', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '上新印', 'カミシイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市一部', '31', '31202', '6893533', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '一部', 'イチブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市水浜', '31', '31202', '6893534', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '水浜', 'ミズハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市東八幡', '31', '31202', '6893535', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '東八幡', 'ヒガシヤワタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市高島', '31', '31202', '6893536', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '高島', 'タカシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市古豊千', '31', '31202', '6893537', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '古豊千', 'コホウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市二本木', '31', '31202', '6893541', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '二本木', 'ニホンギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市今在家', '31', '31202', '6893542', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '今在家', 'イマザイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市蚊屋', '31', '31202', '6893543', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '蚊屋', 'カヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市浦津', '31', '31202', '6893544', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '浦津', 'ウラツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市吉岡', '31', '31202', '6893545', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '吉岡', 'ヨシオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市熊党', '31', '31202', '6893546', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '熊党', 'クマントウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県米子市流通町', '31', '31202', '6893547', '鳥取県', 'トットリケン', '米子市', 'ヨナゴシ', '流通町', 'リュウツウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡日吉津村今吉', '31', '31384', '6893551', '鳥取県', 'トットリケン', '西伯郡日吉津村', 'サイハクグンヒエヅソン', '今吉', 'イマヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡日吉津村富吉', '31', '31384', '6893552', '鳥取県', 'トットリケン', '西伯郡日吉津村', 'サイハクグンヒエヅソン', '富吉', 'トミヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡日吉津村日吉津', '31', '31384', '6893553', '鳥取県', 'トットリケン', '西伯郡日吉津村', 'サイハクグンヒエヅソン', '日吉津', 'ヒエヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡伯耆町', '31', '31390', '6894100', '鳥取県', 'トットリケン', '西伯郡伯耆町', 'サイハクグンホウキチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('84840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡伯耆町小林', '31', '31390', '6894101', '鳥取県', 'トットリケン', '西伯郡伯耆町', 'サイハクグンホウキチョウ', '小林', 'コバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡伯耆町大原', '31', '31390', '6894102', '鳥取県', 'トットリケン', '西伯郡伯耆町', 'サイハクグンホウキチョウ', '大原', 'オオハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡伯耆町真野', '31', '31390', '6894103', '鳥取県', 'トットリケン', '西伯郡伯耆町', 'サイハクグンホウキチョウ', '真野', 'マノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡伯耆町番原', '31', '31390', '6894104', '鳥取県', 'トットリケン', '西伯郡伯耆町', 'サイハクグンホウキチョウ', '番原', 'バンバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡伯耆町久古', '31', '31390', '6894105', '鳥取県', 'トットリケン', '西伯郡伯耆町', 'サイハクグンホウキチョウ', '久古', 'クゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡伯耆町口別所', '31', '31390', '6894106', '鳥取県', 'トットリケン', '西伯郡伯耆町', 'サイハクグンホウキチョウ', '口別所', 'クチベッシヨ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡伯耆町須村', '31', '31390', '6894107', '鳥取県', 'トットリケン', '西伯郡伯耆町', 'サイハクグンホウキチョウ', '須村', 'スムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡伯耆町丸山', '31', '31390', '6894108', '鳥取県', 'トットリケン', '西伯郡伯耆町', 'サイハクグンホウキチョウ', '丸山', 'マルヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡伯耆町清原', '31', '31390', '6894111', '鳥取県', 'トットリケン', '西伯郡伯耆町', 'サイハクグンホウキチョウ', '清原', 'キヨハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡伯耆町上細見', '31', '31390', '6894112', '鳥取県', 'トットリケン', '西伯郡伯耆町', 'サイハクグンホウキチョウ', '上細見', 'カミホソミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡伯耆町小野', '31', '31390', '6894113', '鳥取県', 'トットリケン', '西伯郡伯耆町', 'サイハクグンホウキチョウ', '小野', 'オノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡伯耆町立岩', '31', '31390', '6894114', '鳥取県', 'トットリケン', '西伯郡伯耆町', 'サイハクグンホウキチョウ', '立岩', 'タテイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡伯耆町小町', '31', '31390', '6894115', '鳥取県', 'トットリケン', '西伯郡伯耆町', 'サイハクグンホウキチョウ', '小町', 'コマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡伯耆町大殿', '31', '31390', '6894121', '鳥取県', 'トットリケン', '西伯郡伯耆町', 'サイハクグンホウキチョウ', '大殿', 'オオトノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡伯耆町坂長', '31', '31390', '6894122', '鳥取県', 'トットリケン', '西伯郡伯耆町', 'サイハクグンホウキチョウ', '坂長', 'サカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡伯耆町岩屋谷', '31', '31390', '6894123', '鳥取県', 'トットリケン', '西伯郡伯耆町', 'サイハクグンホウキチョウ', '岩屋谷', 'イワヤダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡伯耆町吉定', '31', '31390', '6894131', '鳥取県', 'トットリケン', '西伯郡伯耆町', 'サイハクグンホウキチョウ', '吉定', 'ヨシサダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡伯耆町岸本', '31', '31390', '6894132', '鳥取県', 'トットリケン', '西伯郡伯耆町', 'サイハクグンホウキチョウ', '岸本', 'キシモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡伯耆町吉長', '31', '31390', '6894133', '鳥取県', 'トットリケン', '西伯郡伯耆町', 'サイハクグンホウキチョウ', '吉長', 'ヨシナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡伯耆町遠藤', '31', '31390', '6894134', '鳥取県', 'トットリケン', '西伯郡伯耆町', 'サイハクグンホウキチョウ', '遠藤', 'エンドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡伯耆町押口', '31', '31390', '6894135', '鳥取県', 'トットリケン', '西伯郡伯耆町', 'サイハクグンホウキチョウ', '押口', 'オサエグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡伯耆町福岡原', '31', '31390', '6894136', '鳥取県', 'トットリケン', '西伯郡伯耆町', 'サイハクグンホウキチョウ', '福岡原', 'フクオカハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡伯耆町溝口', '31', '31390', '6894201', '鳥取県', 'トットリケン', '西伯郡伯耆町', 'サイハクグンホウキチョウ', '溝口', 'ミゾクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡伯耆町長山', '31', '31390', '6894202', '鳥取県', 'トットリケン', '西伯郡伯耆町', 'サイハクグンホウキチョウ', '長山', 'ナガヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡伯耆町貴住', '31', '31390', '6894203', '鳥取県', 'トットリケン', '西伯郡伯耆町', 'サイハクグンホウキチョウ', '貴住', 'キズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡伯耆町谷川', '31', '31390', '6894204', '鳥取県', 'トットリケン', '西伯郡伯耆町', 'サイハクグンホウキチョウ', '谷川', 'タニガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡伯耆町大倉', '31', '31390', '6894205', '鳥取県', 'トットリケン', '西伯郡伯耆町', 'サイハクグンホウキチョウ', '大倉', 'オオクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡伯耆町宮原', '31', '31390', '6894206', '鳥取県', 'トットリケン', '西伯郡伯耆町', 'サイハクグンホウキチョウ', '宮原', 'ミヤバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡伯耆町宇代', '31', '31390', '6894207', '鳥取県', 'トットリケン', '西伯郡伯耆町', 'サイハクグンホウキチョウ', '宇代', 'ウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡伯耆町大江', '31', '31390', '6894211', '鳥取県', 'トットリケン', '西伯郡伯耆町', 'サイハクグンホウキチョウ', '大江', 'オオエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡伯耆町上野', '31', '31390', '6894212', '鳥取県', 'トットリケン', '西伯郡伯耆町', 'サイハクグンホウキチョウ', '上野', 'ウエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡伯耆町金屋谷', '31', '31390', '6894213', '鳥取県', 'トットリケン', '西伯郡伯耆町', 'サイハクグンホウキチョウ', '金屋谷', 'カナヤダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡伯耆町岩立', '31', '31390', '6894214', '鳥取県', 'トットリケン', '西伯郡伯耆町', 'サイハクグンホウキチョウ', '岩立', 'イワタテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡伯耆町大内', '31', '31390', '6894215', '鳥取県', 'トットリケン', '西伯郡伯耆町', 'サイハクグンホウキチョウ', '大内', 'オオウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡伯耆町福兼', '31', '31390', '6894216', '鳥取県', 'トットリケン', '西伯郡伯耆町', 'サイハクグンホウキチョウ', '福兼', 'フクカネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡伯耆町添谷', '31', '31390', '6894217', '鳥取県', 'トットリケン', '西伯郡伯耆町', 'サイハクグンホウキチョウ', '添谷', 'ソエダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡伯耆町富江', '31', '31390', '6894221', '鳥取県', 'トットリケン', '西伯郡伯耆町', 'サイハクグンホウキチョウ', '富江', 'トミエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡伯耆町大滝', '31', '31390', '6894222', '鳥取県', 'トットリケン', '西伯郡伯耆町', 'サイハクグンホウキチョウ', '大滝', 'オオタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡伯耆町栃原', '31', '31390', '6894223', '鳥取県', 'トットリケン', '西伯郡伯耆町', 'サイハクグンホウキチョウ', '栃原', 'トチバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡伯耆町根雨原', '31', '31390', '6894224', '鳥取県', 'トットリケン', '西伯郡伯耆町', 'サイハクグンホウキチョウ', '根雨原', 'ネウバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡伯耆町白水', '31', '31390', '6894225', '鳥取県', 'トットリケン', '西伯郡伯耆町', 'サイハクグンホウキチョウ', '白水', 'シラミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡伯耆町大坂', '31', '31390', '6894226', '鳥取県', 'トットリケン', '西伯郡伯耆町', 'サイハクグンホウキチョウ', '大坂', 'オオサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡伯耆町船越', '31', '31390', '6894231', '鳥取県', 'トットリケン', '西伯郡伯耆町', 'サイハクグンホウキチョウ', '船越', 'フナコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡伯耆町福島', '31', '31390', '6894232', '鳥取県', 'トットリケン', '西伯郡伯耆町', 'サイハクグンホウキチョウ', '福島', 'フクジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡伯耆町二部', '31', '31390', '6894233', '鳥取県', 'トットリケン', '西伯郡伯耆町', 'サイハクグンホウキチョウ', '二部', 'ニブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡伯耆町畑池', '31', '31390', '6894234', '鳥取県', 'トットリケン', '西伯郡伯耆町', 'サイハクグンホウキチョウ', '畑池', 'ハタイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡伯耆町福岡', '31', '31390', '6894235', '鳥取県', 'トットリケン', '西伯郡伯耆町', 'サイハクグンホウキチョウ', '福岡', 'フクオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡伯耆町焼杉', '31', '31390', '6894236', '鳥取県', 'トットリケン', '西伯郡伯耆町', 'サイハクグンホウキチョウ', '焼杉', 'ヤケスギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡伯耆町福居', '31', '31390', '6894237', '鳥取県', 'トットリケン', '西伯郡伯耆町', 'サイハクグンホウキチョウ', '福居', 'フクイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡伯耆町中祖', '31', '31390', '6894241', '鳥取県', 'トットリケン', '西伯郡伯耆町', 'サイハクグンホウキチョウ', '中祖', 'ナカゾ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡伯耆町古市', '31', '31390', '6894242', '鳥取県', 'トットリケン', '西伯郡伯耆町', 'サイハクグンホウキチョウ', '古市', 'フルイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡伯耆町荘', '31', '31390', '6894243', '鳥取県', 'トットリケン', '西伯郡伯耆町', 'サイハクグンホウキチョウ', '荘', 'ショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡伯耆町父原', '31', '31390', '6894244', '鳥取県', 'トットリケン', '西伯郡伯耆町', 'サイハクグンホウキチョウ', '父原', 'チチバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡伯耆町福吉', '31', '31390', '6894245', '鳥取県', 'トットリケン', '西伯郡伯耆町', 'サイハクグンホウキチョウ', '福吉', 'フクヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県西伯郡伯耆町三部', '31', '31390', '6894246', '鳥取県', 'トットリケン', '西伯郡伯耆町', 'サイハクグンホウキチョウ', '三部', 'サンブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県日野郡江府町', '31', '31403', '6894400', '鳥取県', 'トットリケン', '日野郡江府町', 'ヒノグンコウフチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('84897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県日野郡江府町江尾', '31', '31403', '6894401', '鳥取県', 'トットリケン', '日野郡江府町', 'ヒノグンコウフチョウ', '江尾', 'エビ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県日野郡江府町小江尾', '31', '31403', '6894402', '鳥取県', 'トットリケン', '日野郡江府町', 'ヒノグンコウフチョウ', '小江尾', 'コエビ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県日野郡江府町久連', '31', '31403', '6894403', '鳥取県', 'トットリケン', '日野郡江府町', 'ヒノグンコウフチョウ', '久連', 'クレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県日野郡江府町武庫', '31', '31403', '6894411', '鳥取県', 'トットリケン', '日野郡江府町', 'ヒノグンコウフチョウ', '武庫', 'ムコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県日野郡江府町下安井', '31', '31403', '6894412', '鳥取県', 'トットリケン', '日野郡江府町', 'ヒノグンコウフチョウ', '下安井', 'シモヤスイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県日野郡江府町洲河崎', '31', '31403', '6894413', '鳥取県', 'トットリケン', '日野郡江府町', 'ヒノグンコウフチョウ', '洲河崎', 'スガサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県日野郡江府町俣野', '31', '31403', '6894414', '鳥取県', 'トットリケン', '日野郡江府町', 'ヒノグンコウフチョウ', '俣野', 'マタノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県日野郡江府町宮市', '31', '31403', '6894421', '鳥取県', 'トットリケン', '日野郡江府町', 'ヒノグンコウフチョウ', '宮市', 'ミヤイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県日野郡江府町杉谷', '31', '31403', '6894422', '鳥取県', 'トットリケン', '日野郡江府町', 'ヒノグンコウフチョウ', '杉谷', 'スギタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県日野郡江府町美用', '31', '31403', '6894423', '鳥取県', 'トットリケン', '日野郡江府町', 'ヒノグンコウフチョウ', '美用', 'ミヨウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県日野郡江府町御机', '31', '31403', '6894424', '鳥取県', 'トットリケン', '日野郡江府町', 'ヒノグンコウフチョウ', '御机', 'ミツクエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県日野郡江府町下蚊屋', '31', '31403', '6894425', '鳥取県', 'トットリケン', '日野郡江府町', 'ヒノグンコウフチョウ', '下蚊屋', 'サガリカヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県日野郡江府町助沢', '31', '31403', '6894426', '鳥取県', 'トットリケン', '日野郡江府町', 'ヒノグンコウフチョウ', '助沢', 'スケサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県日野郡江府町佐川', '31', '31403', '6894431', '鳥取県', 'トットリケン', '日野郡江府町', 'ヒノグンコウフチョウ', '佐川', 'サガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県日野郡江府町柿原', '31', '31403', '6894432', '鳥取県', 'トットリケン', '日野郡江府町', 'ヒノグンコウフチョウ', '柿原', 'カキバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県日野郡江府町吉原', '31', '31403', '6894433', '鳥取県', 'トットリケン', '日野郡江府町', 'ヒノグンコウフチョウ', '吉原', 'ヨシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県日野郡江府町大河原', '31', '31403', '6894434', '鳥取県', 'トットリケン', '日野郡江府町', 'ヒノグンコウフチョウ', '大河原', 'オオカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県日野郡江府町貝田', '31', '31403', '6894435', '鳥取県', 'トットリケン', '日野郡江府町', 'ヒノグンコウフチョウ', '貝田', 'カイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県日野郡日野町', '31', '31402', '6894500', '鳥取県', 'トットリケン', '日野郡日野町', 'ヒノグンヒノチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('84916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県日野郡日野町貝原', '31', '31402', '6894501', '鳥取県', 'トットリケン', '日野郡日野町', 'ヒノグンヒノチョウ', '貝原', 'カイハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県日野郡日野町三谷', '31', '31402', '6894502', '鳥取県', 'トットリケン', '日野郡日野町', 'ヒノグンヒノチョウ', '三谷', 'ミタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県日野郡日野町根雨', '31', '31402', '6894503', '鳥取県', 'トットリケン', '日野郡日野町', 'ヒノグンヒノチョウ', '根雨', 'ネウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県日野郡日野町野田', '31', '31402', '6894504', '鳥取県', 'トットリケン', '日野郡日野町', 'ヒノグンヒノチョウ', '野田', 'ノタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県日野郡日野町舟場', '31', '31402', '6894505', '鳥取県', 'トットリケン', '日野郡日野町', 'ヒノグンヒノチョウ', '舟場', 'フナバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県日野郡日野町高尾', '31', '31402', '6894511', '鳥取県', 'トットリケン', '日野郡日野町', 'ヒノグンヒノチョウ', '高尾', 'コオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県日野郡日野町金持', '31', '31402', '6894512', '鳥取県', 'トットリケン', '日野郡日野町', 'ヒノグンヒノチョウ', '金持', 'カモチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県日野郡日野町板井原', '31', '31402', '6894513', '鳥取県', 'トットリケン', '日野郡日野町', 'ヒノグンヒノチョウ', '板井原', 'イタイバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県日野郡日野町三土', '31', '31402', '6894514', '鳥取県', 'トットリケン', '日野郡日野町', 'ヒノグンヒノチョウ', '三土', 'ミツチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県日野郡日野町秋縄', '31', '31402', '6894515', '鳥取県', 'トットリケン', '日野郡日野町', 'ヒノグンヒノチョウ', '秋縄', 'アキツナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県日野郡日野町門谷', '31', '31402', '6894516', '鳥取県', 'トットリケン', '日野郡日野町', 'ヒノグンヒノチョウ', '門谷', 'カドタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県日野郡日野町濁谷', '31', '31402', '6894517', '鳥取県', 'トットリケン', '日野郡日野町', 'ヒノグンヒノチョウ', '濁谷', 'ニゴタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県日野郡日野町津地', '31', '31402', '6894521', '鳥取県', 'トットリケン', '日野郡日野町', 'ヒノグンヒノチョウ', '津地', 'ツチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県日野郡日野町本郷', '31', '31402', '6894522', '鳥取県', 'トットリケン', '日野郡日野町', 'ヒノグンヒノチョウ', '本郷', 'ホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県日野郡日野町榎市', '31', '31402', '6894523', '鳥取県', 'トットリケン', '日野郡日野町', 'ヒノグンヒノチョウ', '榎市', 'エノキイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県日野郡日野町別所', '31', '31402', '6894524', '鳥取県', 'トットリケン', '日野郡日野町', 'ヒノグンヒノチョウ', '別所', 'ベッショ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県日野郡日野町小原', '31', '31402', '6894525', '鳥取県', 'トットリケン', '日野郡日野町', 'ヒノグンヒノチョウ', '小原', 'コバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県日野郡日野町下榎', '31', '31402', '6894526', '鳥取県', 'トットリケン', '日野郡日野町', 'ヒノグンヒノチョウ', '下榎', 'シモエノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県日野郡日野町安原', '31', '31402', '6894527', '鳥取県', 'トットリケン', '日野郡日野町', 'ヒノグンヒノチョウ', '安原', 'ヤスハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県日野郡日野町黒坂', '31', '31402', '6895131', '鳥取県', 'トットリケン', '日野郡日野町', 'ヒノグンヒノチョウ', '黒坂', 'クロサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県日野郡日野町久住', '31', '31402', '6895132', '鳥取県', 'トットリケン', '日野郡日野町', 'ヒノグンヒノチョウ', '久住', 'クスミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県日野郡日野町下黒坂', '31', '31402', '6895133', '鳥取県', 'トットリケン', '日野郡日野町', 'ヒノグンヒノチョウ', '下黒坂', 'シモグロサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県日野郡日野町下菅', '31', '31402', '6895134', '鳥取県', 'トットリケン', '日野郡日野町', 'ヒノグンヒノチョウ', '下菅', 'シモスゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県日野郡日野町中菅', '31', '31402', '6895135', '鳥取県', 'トットリケン', '日野郡日野町', 'ヒノグンヒノチョウ', '中菅', 'ナカスゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県日野郡日野町小河内', '31', '31402', '6895136', '鳥取県', 'トットリケン', '日野郡日野町', 'ヒノグンヒノチョウ', '小河内', 'オゴウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県日野郡日野町上菅', '31', '31402', '6895137', '鳥取県', 'トットリケン', '日野郡日野町', 'ヒノグンヒノチョウ', '上菅', 'カミスゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県日野郡日野町福長', '31', '31402', '6895137', '鳥取県', 'トットリケン', '日野郡日野町', 'ヒノグンヒノチョウ', '福長', 'フクナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県日野郡日南町', '31', '31401', '6895200', '鳥取県', 'トットリケン', '日野郡日南町', 'ヒノグンニチナンチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('84944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県日野郡日南町生山', '31', '31401', '6895211', '鳥取県', 'トットリケン', '日野郡日南町', 'ヒノグンニチナンチョウ', '生山', 'ショウヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県日野郡日南町霞', '31', '31401', '6895212', '鳥取県', 'トットリケン', '日野郡日南町', 'ヒノグンニチナンチョウ', '霞', 'カスミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県日野郡日南町丸山', '31', '31401', '6895213', '鳥取県', 'トットリケン', '日野郡日南町', 'ヒノグンニチナンチョウ', '丸山', 'マルヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県日野郡日南町三栄', '31', '31401', '6895214', '鳥取県', 'トットリケン', '日野郡日南町', 'ヒノグンニチナンチョウ', '三栄', 'ミサカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県日野郡日南町矢戸', '31', '31401', '6895215', '鳥取県', 'トットリケン', '日野郡日南町', 'ヒノグンニチナンチョウ', '矢戸', 'ヤト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県日野郡日南町宮内', '31', '31401', '6895216', '鳥取県', 'トットリケン', '日野郡日南町', 'ヒノグンニチナンチョウ', '宮内', 'ミヤウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県日野郡日南町河上', '31', '31401', '6895221', '鳥取県', 'トットリケン', '日野郡日南町', 'ヒノグンニチナンチョウ', '河上', 'カワカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県日野郡日南町萩原', '31', '31401', '6895222', '鳥取県', 'トットリケン', '日野郡日南町', 'ヒノグンニチナンチョウ', '萩原', 'ハギハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県日野郡日南町上萩山', '31', '31401', '6895223', '鳥取県', 'トットリケン', '日野郡日南町', 'ヒノグンニチナンチョウ', '上萩山', 'カミハギヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県日野郡日南町多里', '31', '31401', '6895224', '鳥取県', 'トットリケン', '日野郡日南町', 'ヒノグンニチナンチョウ', '多里', 'タリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県日野郡日南町新屋', '31', '31401', '6895225', '鳥取県', 'トットリケン', '日野郡日南町', 'ヒノグンニチナンチョウ', '新屋', 'ニイヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県日野郡日南町湯河', '31', '31401', '6895226', '鳥取県', 'トットリケン', '日野郡日南町', 'ヒノグンニチナンチョウ', '湯河', 'ユカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県日野郡日南町印賀', '31', '31401', '6895531', '鳥取県', 'トットリケン', '日野郡日南町', 'ヒノグンニチナンチョウ', '印賀', 'インガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県日野郡日南町菅沢', '31', '31401', '6895532', '鳥取県', 'トットリケン', '日野郡日南町', 'ヒノグンニチナンチョウ', '菅沢', 'スゲザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県日野郡日南町宝谷', '31', '31401', '6895533', '鳥取県', 'トットリケン', '日野郡日南町', 'ヒノグンニチナンチョウ', '宝谷', 'タカラダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県日野郡日南町折渡', '31', '31401', '6895534', '鳥取県', 'トットリケン', '日野郡日南町', 'ヒノグンニチナンチョウ', '折渡', 'オリワタリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県日野郡日南町佐木谷', '31', '31401', '6895541', '鳥取県', 'トットリケン', '日野郡日南町', 'ヒノグンニチナンチョウ', '佐木谷', 'サギダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県日野郡日南町福万来', '31', '31401', '6895542', '鳥取県', 'トットリケン', '日野郡日南町', 'ヒノグンニチナンチョウ', '福万来', 'フクマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県日野郡日南町笠木', '31', '31401', '6895543', '鳥取県', 'トットリケン', '日野郡日南町', 'ヒノグンニチナンチョウ', '笠木', 'カサギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県日野郡日南町茶屋', '31', '31401', '6895544', '鳥取県', 'トットリケン', '日野郡日南町', 'ヒノグンニチナンチョウ', '茶屋', 'チャヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県日野郡日南町福寿実', '31', '31401', '6895545', '鳥取県', 'トットリケン', '日野郡日南町', 'ヒノグンニチナンチョウ', '福寿実', 'フクスミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県日野郡日南町阿毘縁', '31', '31401', '6895551', '鳥取県', 'トットリケン', '日野郡日南町', 'ヒノグンニチナンチョウ', '阿毘縁', 'アビレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県日野郡日南町下阿毘縁', '31', '31401', '6895552', '鳥取県', 'トットリケン', '日野郡日南町', 'ヒノグンニチナンチョウ', '下阿毘縁', 'シモアビレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県日野郡日南町花口', '31', '31401', '6895661', '鳥取県', 'トットリケン', '日野郡日南町', 'ヒノグンニチナンチョウ', '花口', 'ハナグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県日野郡日南町神戸上', '31', '31401', '6895662', '鳥取県', 'トットリケン', '日野郡日南町', 'ヒノグンニチナンチョウ', '神戸上', 'カドノカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県日野郡日南町上石見', '31', '31401', '6895663', '鳥取県', 'トットリケン', '日野郡日南町', 'ヒノグンニチナンチョウ', '上石見', 'カミイワミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県日野郡日南町中石見', '31', '31401', '6895664', '鳥取県', 'トットリケン', '日野郡日南町', 'ヒノグンニチナンチョウ', '中石見', 'ナカイワミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県日野郡日南町下石見', '31', '31401', '6895665', '鳥取県', 'トットリケン', '日野郡日南町', 'ヒノグンニチナンチョウ', '下石見', 'シモイワミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県日野郡日南町三吉', '31', '31401', '6895666', '鳥取県', 'トットリケン', '日野郡日南町', 'ヒノグンニチナンチョウ', '三吉', 'ミヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県日野郡日南町福塚', '31', '31401', '6895671', '鳥取県', 'トットリケン', '日野郡日南町', 'ヒノグンニチナンチョウ', '福塚', 'フクヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県日野郡日南町神福', '31', '31401', '6895672', '鳥取県', 'トットリケン', '日野郡日南町', 'ヒノグンニチナンチョウ', '神福', 'カミフク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鳥取県日野郡日南町豊栄', '31', '31401', '6895673', '鳥取県', 'トットリケン', '日野郡日南町', 'ヒノグンニチナンチョウ', '豊栄', 'トヨサカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市', '32', '32201', '6900000', '島根県', 'シマネケン', '松江市', 'マツエシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('84978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市東朝日町', '32', '32201', '6900001', '島根県', 'シマネケン', '松江市', 'マツエシ', '東朝日町', 'ヒガシアサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市大正町', '32', '32201', '6900002', '島根県', 'シマネケン', '松江市', 'マツエシ', '大正町', 'タイショウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市朝日町', '32', '32201', '6900003', '島根県', 'シマネケン', '松江市', 'マツエシ', '朝日町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市八軒屋町', '32', '32201', '6900004', '島根県', 'シマネケン', '松江市', 'マツエシ', '八軒屋町', 'ハチケンヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市和多見町', '32', '32201', '6900005', '島根県', 'シマネケン', '松江市', 'マツエシ', '和多見町', 'ワダミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市伊勢宮町', '32', '32201', '6900006', '島根県', 'シマネケン', '松江市', 'マツエシ', '伊勢宮町', 'イセミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市御手船場町', '32', '32201', '6900007', '島根県', 'シマネケン', '松江市', 'マツエシ', '御手船場町', 'オテセンバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市東津田町', '32', '32201', '6900011', '島根県', 'シマネケン', '松江市', 'マツエシ', '東津田町', 'ヒガシツダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市古志原', '32', '32201', '6900012', '島根県', 'シマネケン', '松江市', 'マツエシ', '古志原', 'コシバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市古志原町', '32', '32201', '6900013', '島根県', 'シマネケン', '松江市', 'マツエシ', '古志原町', 'コシバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市八雲台', '32', '32201', '6900014', '島根県', 'シマネケン', '松江市', 'マツエシ', '八雲台', 'ヤクモダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市上乃木', '32', '32201', '6900015', '島根県', 'シマネケン', '松江市', 'マツエシ', '上乃木', 'アゲノギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市西津田', '32', '32201', '6900017', '島根県', 'シマネケン', '松江市', 'マツエシ', '西津田', 'ニシツダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市矢田町', '32', '32201', '6900021', '島根県', 'シマネケン', '松江市', 'マツエシ', '矢田町', 'ヤダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市青葉台', '32', '32201', '6900022', '島根県', 'シマネケン', '松江市', 'マツエシ', '青葉台', 'アオバダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市竹矢町', '32', '32201', '6900023', '島根県', 'シマネケン', '松江市', 'マツエシ', '竹矢町', 'チクヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市馬潟町', '32', '32201', '6900024', '島根県', 'シマネケン', '松江市', 'マツエシ', '馬潟町', 'マカタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市八幡町', '32', '32201', '6900025', '島根県', 'シマネケン', '松江市', 'マツエシ', '八幡町', 'ヤワタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市富士見町', '32', '32201', '6900026', '島根県', 'シマネケン', '松江市', 'マツエシ', '富士見町', 'フジミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市意宇町', '32', '32201', '6900027', '島根県', 'シマネケン', '松江市', 'マツエシ', '意宇町', 'イウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('84999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市山代町', '32', '32201', '6900031', '島根県', 'シマネケン', '松江市', 'マツエシ', '山代町', 'ヤマシロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市大草町', '32', '32201', '6900032', '島根県', 'シマネケン', '松江市', 'マツエシ', '大草町', 'オオクサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市大庭町', '32', '32201', '6900033', '島根県', 'シマネケン', '松江市', 'マツエシ', '大庭町', 'オオバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市一の谷町', '32', '32201', '6900034', '島根県', 'シマネケン', '松江市', 'マツエシ', '一の谷町', 'イチノタニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市佐草町', '32', '32201', '6900035', '島根県', 'シマネケン', '松江市', 'マツエシ', '佐草町', 'サクサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市東忌部町', '32', '32201', '6900036', '島根県', 'シマネケン', '松江市', 'マツエシ', '東忌部町', 'ヒガシインベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市西忌部町', '32', '32201', '6900037', '島根県', 'シマネケン', '松江市', 'マツエシ', '西忌部町', 'ニシインベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市平成町', '32', '32201', '6900038', '島根県', 'シマネケン', '松江市', 'マツエシ', '平成町', 'ヘイセイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市幸町', '32', '32201', '6900041', '島根県', 'シマネケン', '松江市', 'マツエシ', '幸町', 'サイワイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市栄町', '32', '32201', '6900042', '島根県', 'シマネケン', '松江市', 'マツエシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市松尾町', '32', '32201', '6900043', '島根県', 'シマネケン', '松江市', 'マツエシ', '松尾町', 'マツオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市浜乃木', '32', '32201', '6900044', '島根県', 'シマネケン', '松江市', 'マツエシ', '浜乃木', 'ハマノギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市乃白町', '32', '32201', '6900045', '島根県', 'シマネケン', '松江市', 'マツエシ', '乃白町', 'ノシラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市乃木福富町', '32', '32201', '6900046', '島根県', 'シマネケン', '松江市', 'マツエシ', '乃木福富町', 'ノギフクトミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市嫁島町', '32', '32201', '6900047', '島根県', 'シマネケン', '松江市', 'マツエシ', '嫁島町', 'ヨメシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市西嫁島', '32', '32201', '6900048', '島根県', 'シマネケン', '松江市', 'マツエシ', '西嫁島', 'ニシヨメシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市袖師町', '32', '32201', '6900049', '島根県', 'シマネケン', '松江市', 'マツエシ', '袖師町', 'ソデシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市横浜町', '32', '32201', '6900051', '島根県', 'シマネケン', '松江市', 'マツエシ', '横浜町', 'ヨコバマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市竪町', '32', '32201', '6900052', '島根県', 'シマネケン', '松江市', 'マツエシ', '竪町', 'タテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市本郷町', '32', '32201', '6900053', '島根県', 'シマネケン', '松江市', 'マツエシ', '本郷町', 'ホンゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市新雑賀町', '32', '32201', '6900054', '島根県', 'シマネケン', '松江市', 'マツエシ', '新雑賀町', 'シンサイカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市津田町', '32', '32201', '6900055', '島根県', 'シマネケン', '松江市', 'マツエシ', '津田町', 'ツダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市雑賀町', '32', '32201', '6900056', '島根県', 'シマネケン', '松江市', 'マツエシ', '雑賀町', 'サイカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市新町', '32', '32201', '6900057', '島根県', 'シマネケン', '松江市', 'マツエシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市田和山町', '32', '32201', '6900058', '島根県', 'シマネケン', '松江市', 'マツエシ', '田和山町', 'タワヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市白潟本町', '32', '32201', '6900061', '島根県', 'シマネケン', '松江市', 'マツエシ', '白潟本町', 'シラカタホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市魚町', '32', '32201', '6900062', '島根県', 'シマネケン', '松江市', 'マツエシ', '魚町', 'ウオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市寺町', '32', '32201', '6900063', '島根県', 'シマネケン', '松江市', 'マツエシ', '寺町', 'テラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市天神町', '32', '32201', '6900064', '島根県', 'シマネケン', '松江市', 'マツエシ', '天神町', 'テンジンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市灘町', '32', '32201', '6900065', '島根県', 'シマネケン', '松江市', 'マツエシ', '灘町', 'ナダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市古志町', '32', '32201', '6900121', '島根県', 'シマネケン', '松江市', 'マツエシ', '古志町', 'コシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市西浜佐陀町', '32', '32201', '6900122', '島根県', 'シマネケン', '松江市', 'マツエシ', '西浜佐陀町', 'ニシハマサダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市打出町', '32', '32201', '6900131', '島根県', 'シマネケン', '松江市', 'マツエシ', '打出町', 'ウチデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市西長江町', '32', '32201', '6900132', '島根県', 'シマネケン', '松江市', 'マツエシ', '西長江町', 'ニシナガエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市東長江町', '32', '32201', '6900133', '島根県', 'シマネケン', '松江市', 'マツエシ', '東長江町', 'ヒガシナガエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市荘成町', '32', '32201', '6900141', '島根県', 'シマネケン', '松江市', 'マツエシ', '荘成町', 'ショウジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市西谷町', '32', '32201', '6900142', '島根県', 'シマネケン', '松江市', 'マツエシ', '西谷町', 'ニシダニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市古曽志町', '32', '32201', '6900151', '島根県', 'シマネケン', '松江市', 'マツエシ', '古曽志町', 'コソシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市秋鹿町', '32', '32201', '6900261', '島根県', 'シマネケン', '松江市', 'マツエシ', '秋鹿町', 'アイカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市岡本町', '32', '32201', '6900262', '島根県', 'シマネケン', '松江市', 'マツエシ', '岡本町', 'オカモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市大垣町', '32', '32201', '6900263', '島根県', 'シマネケン', '松江市', 'マツエシ', '大垣町', 'オオガキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市大野町', '32', '32201', '6900264', '島根県', 'シマネケン', '松江市', 'マツエシ', '大野町', 'オオノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市上大野町', '32', '32201', '6900265', '島根県', 'シマネケン', '松江市', 'マツエシ', '上大野町', 'カミオオノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市魚瀬町', '32', '32201', '6900266', '島根県', 'シマネケン', '松江市', 'マツエシ', '魚瀬町', 'オノゼチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市鹿島町武代', '32', '32201', '6900321', '島根県', 'シマネケン', '松江市', 'マツエシ', '鹿島町武代', 'カシマチョウタケダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市鹿島町恵曇', '32', '32201', '6900322', '島根県', 'シマネケン', '松江市', 'マツエシ', '鹿島町恵曇', 'カシマチョウエトモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市鹿島町手結', '32', '32201', '6900323', '島根県', 'シマネケン', '松江市', 'マツエシ', '鹿島町手結', 'カシマチョウタユ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市鹿島町片句', '32', '32201', '6900324', '島根県', 'シマネケン', '松江市', 'マツエシ', '鹿島町片句', 'カシマチョウカタク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市鹿島町佐陀宮内', '32', '32201', '6900331', '島根県', 'シマネケン', '松江市', 'マツエシ', '鹿島町佐陀宮内', 'カシマチョウサダミヤウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市鹿島町佐陀本郷', '32', '32201', '6900332', '島根県', 'シマネケン', '松江市', 'マツエシ', '鹿島町佐陀本郷', 'カシマチョウサダホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市鹿島町古浦', '32', '32201', '6900333', '島根県', 'シマネケン', '松江市', 'マツエシ', '鹿島町古浦', 'カシマチョウコウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市島根町加賀', '32', '32201', '6900401', '島根県', 'シマネケン', '松江市', 'マツエシ', '島根町加賀', 'シマネチョウカカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市島根町大芦', '32', '32201', '6900402', '島根県', 'シマネケン', '松江市', 'マツエシ', '島根町大芦', 'シマネチョウオワシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市鹿島町御津', '32', '32201', '6900411', '島根県', 'シマネケン', '松江市', 'マツエシ', '鹿島町御津', 'カシマチョウミツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市鹿島町上講武', '32', '32201', '6900801', '島根県', 'シマネケン', '松江市', 'マツエシ', '鹿島町上講武', 'カシマチョウカミコウブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市鹿島町南講武', '32', '32201', '6900802', '島根県', 'シマネケン', '松江市', 'マツエシ', '鹿島町南講武', 'カシマチョウミナミコウブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市鹿島町名分', '32', '32201', '6900803', '島根県', 'シマネケン', '松江市', 'マツエシ', '鹿島町名分', 'カシマチョウミョウブン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市鹿島町北講武', '32', '32201', '6900804', '島根県', 'シマネケン', '松江市', 'マツエシ', '鹿島町北講武', 'カシマチョウキタコウブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市福原町', '32', '32201', '6900811', '島根県', 'シマネケン', '松江市', 'マツエシ', '福原町', 'フクハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市川原町', '32', '32201', '6900812', '島根県', 'シマネケン', '松江市', 'マツエシ', '川原町', 'カワハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市坂本町', '32', '32201', '6900813', '島根県', 'シマネケン', '松江市', 'マツエシ', '坂本町', 'サカモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市東持田町', '32', '32201', '6900814', '島根県', 'シマネケン', '松江市', 'マツエシ', '東持田町', 'ヒガシモチダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市西持田町', '32', '32201', '6900815', '島根県', 'シマネケン', '松江市', 'マツエシ', '西持田町', 'ニシモチダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市北陵町', '32', '32201', '6900816', '島根県', 'シマネケン', '松江市', 'マツエシ', '北陵町', 'ホクリョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市上東川津町', '32', '32201', '6900821', '島根県', 'シマネケン', '松江市', 'マツエシ', '上東川津町', 'カミヒガシカワツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市下東川津町', '32', '32201', '6900822', '島根県', 'シマネケン', '松江市', 'マツエシ', '下東川津町', 'シモヒガシカワツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市西川津町', '32', '32201', '6900823', '島根県', 'シマネケン', '松江市', 'マツエシ', '西川津町', 'ニシカワツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市菅田町', '32', '32201', '6900824', '島根県', 'シマネケン', '松江市', 'マツエシ', '菅田町', 'スガタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市学園', '32', '32201', '6900825', '島根県', 'シマネケン', '松江市', 'マツエシ', '学園', 'ガクエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市学園南', '32', '32201', '6900826', '島根県', 'シマネケン', '松江市', 'マツエシ', '学園南', 'ガクエンミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市大海崎町', '32', '32201', '6900831', '島根県', 'シマネケン', '松江市', 'マツエシ', '大海崎町', 'オオミサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市大井町', '32', '32201', '6900832', '島根県', 'シマネケン', '松江市', 'マツエシ', '大井町', 'オオイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市福富町', '32', '32201', '6900833', '島根県', 'シマネケン', '松江市', 'マツエシ', '福富町', 'フクトミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市朝酌町', '32', '32201', '6900834', '島根県', 'シマネケン', '松江市', 'マツエシ', '朝酌町', 'アサクミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市西尾町', '32', '32201', '6900835', '島根県', 'シマネケン', '松江市', 'マツエシ', '西尾町', 'ニシオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市向島町', '32', '32201', '6900841', '島根県', 'シマネケン', '松江市', 'マツエシ', '向島町', 'ムコウジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市東本町', '32', '32201', '6900842', '島根県', 'シマネケン', '松江市', 'マツエシ', '東本町', 'ヒガシホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市末次本町', '32', '32201', '6900843', '島根県', 'シマネケン', '松江市', 'マツエシ', '末次本町', 'スエツグホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市東茶町', '32', '32201', '6900844', '島根県', 'シマネケン', '松江市', 'マツエシ', '東茶町', 'ヒガシチャマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市西茶町', '32', '32201', '6900845', '島根県', 'シマネケン', '松江市', 'マツエシ', '西茶町', 'ニシチャマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市末次町', '32', '32201', '6900846', '島根県', 'シマネケン', '松江市', 'マツエシ', '末次町', 'スエツグチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市片原町', '32', '32201', '6900847', '島根県', 'シマネケン', '松江市', 'マツエシ', '片原町', 'カタハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市苧町', '32', '32201', '6900848', '島根県', 'シマネケン', '松江市', 'マツエシ', '苧町', 'オマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市堂形町', '32', '32201', '6900851', '島根県', 'シマネケン', '松江市', 'マツエシ', '堂形町', 'ドウガタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市千鳥町', '32', '32201', '6900852', '島根県', 'シマネケン', '松江市', 'マツエシ', '千鳥町', 'チドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市南平台', '32', '32201', '6900854', '島根県', 'シマネケン', '松江市', 'マツエシ', '南平台', 'ナンペイダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市浜佐田町', '32', '32201', '6900855', '島根県', 'シマネケン', '松江市', 'マツエシ', '浜佐田町', 'ハマサダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市薦津町', '32', '32201', '6900856', '島根県', 'シマネケン', '松江市', 'マツエシ', '薦津町', 'コモヅチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市国屋町', '32', '32201', '6900859', '島根県', 'シマネケン', '松江市', 'マツエシ', '国屋町', 'クヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市西法吉町', '32', '32201', '6900860', '島根県', 'シマネケン', '松江市', 'マツエシ', '西法吉町', 'ニシホッキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市法吉町', '32', '32201', '6900861', '島根県', 'シマネケン', '松江市', 'マツエシ', '法吉町', 'ホッキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市比津が丘', '32', '32201', '6900862', '島根県', 'シマネケン', '松江市', 'マツエシ', '比津が丘', 'ヒツガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市比津町', '32', '32201', '6900863', '島根県', 'シマネケン', '松江市', 'マツエシ', '比津町', 'ヒツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市東生馬町', '32', '32201', '6900864', '島根県', 'シマネケン', '松江市', 'マツエシ', '東生馬町', 'ヒガシイクマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市西生馬町', '32', '32201', '6900865', '島根県', 'シマネケン', '松江市', 'マツエシ', '西生馬町', 'ニシイクマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市下佐陀町', '32', '32201', '6900866', '島根県', 'シマネケン', '松江市', 'マツエシ', '下佐陀町', 'シモサダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市上佐陀町', '32', '32201', '6900867', '島根県', 'シマネケン', '松江市', 'マツエシ', '上佐陀町', 'カミサダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市淞北台', '32', '32201', '6900868', '島根県', 'シマネケン', '松江市', 'マツエシ', '淞北台', 'ショウホクダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市うぐいす台', '32', '32201', '6900869', '島根県', 'シマネケン', '松江市', 'マツエシ', 'うぐいす台', 'ウグイスダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市東奥谷町', '32', '32201', '6900871', '島根県', 'シマネケン', '松江市', 'マツエシ', '東奥谷町', 'ヒガシオクダニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市奥谷町', '32', '32201', '6900872', '島根県', 'シマネケン', '松江市', 'マツエシ', '奥谷町', 'オクダニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市内中原町', '32', '32201', '6900873', '島根県', 'シマネケン', '松江市', 'マツエシ', '内中原町', 'ウチナカバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市中原町', '32', '32201', '6900874', '島根県', 'シマネケン', '松江市', 'マツエシ', '中原町', 'ナカハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市外中原町', '32', '32201', '6900875', '島根県', 'シマネケン', '松江市', 'マツエシ', '外中原町', 'ソトナカバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市黒田町', '32', '32201', '6900876', '島根県', 'シマネケン', '松江市', 'マツエシ', '黒田町', 'クロダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市春日町', '32', '32201', '6900877', '島根県', 'シマネケン', '松江市', 'マツエシ', '春日町', 'カスガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市砂子町', '32', '32201', '6900878', '島根県', 'シマネケン', '松江市', 'マツエシ', '砂子町', 'スナゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市石橋町', '32', '32201', '6900881', '島根県', 'シマネケン', '松江市', 'マツエシ', '石橋町', 'イシバシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市大輪町', '32', '32201', '6900882', '島根県', 'シマネケン', '松江市', 'マツエシ', '大輪町', 'ダイリンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市北田町', '32', '32201', '6900883', '島根県', 'シマネケン', '松江市', 'マツエシ', '北田町', 'キタタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市南田町', '32', '32201', '6900884', '島根県', 'シマネケン', '松江市', 'マツエシ', '南田町', 'ミナミタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市米子町', '32', '32201', '6900885', '島根県', 'シマネケン', '松江市', 'マツエシ', '米子町', 'ヨナゴマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市母衣町', '32', '32201', '6900886', '島根県', 'シマネケン', '松江市', 'マツエシ', '母衣町', 'ホロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市殿町', '32', '32201', '6900887', '島根県', 'シマネケン', '松江市', 'マツエシ', '殿町', 'トノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市北堀町', '32', '32201', '6900888', '島根県', 'シマネケン', '松江市', 'マツエシ', '北堀町', 'キタホリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市本庄町', '32', '32201', '6901101', '島根県', 'シマネケン', '松江市', 'マツエシ', '本庄町', 'ホンジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市上本庄町', '32', '32201', '6901102', '島根県', 'シマネケン', '松江市', 'マツエシ', '上本庄町', 'カミホンジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市新庄町', '32', '32201', '6901103', '島根県', 'シマネケン', '松江市', 'マツエシ', '新庄町', 'シンジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市上宇部尾町', '32', '32201', '6901104', '島根県', 'シマネケン', '松江市', 'マツエシ', '上宇部尾町', 'カミウベオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市枕木町', '32', '32201', '6901111', '島根県', 'シマネケン', '松江市', 'マツエシ', '枕木町', 'マクラギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市長海町', '32', '32201', '6901112', '島根県', 'シマネケン', '松江市', 'マツエシ', '長海町', 'ナガミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市手角町', '32', '32201', '6901113', '島根県', 'シマネケン', '松江市', 'マツエシ', '手角町', 'タスミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市野原町', '32', '32201', '6901114', '島根県', 'シマネケン', '松江市', 'マツエシ', '野原町', 'ノバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市邑生町', '32', '32201', '6901115', '島根県', 'シマネケン', '松江市', 'マツエシ', '邑生町', 'オウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市島根町野井', '32', '32201', '6901211', '島根県', 'シマネケン', '松江市', 'マツエシ', '島根町野井', 'シマネチョウノイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市島根町野波', '32', '32201', '6901212', '島根県', 'シマネケン', '松江市', 'マツエシ', '島根町野波', 'シマネチョウノナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市島根町多古', '32', '32201', '6901213', '島根県', 'シマネケン', '松江市', 'マツエシ', '島根町多古', 'シマネチョウタコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市美保関町北浦', '32', '32201', '6901221', '島根県', 'シマネケン', '松江市', 'マツエシ', '美保関町北浦', 'ミホノセキチョウキタウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市美保関町千酌', '32', '32201', '6901222', '島根県', 'シマネケン', '松江市', 'マツエシ', '美保関町千酌', 'ミホノセキチョウチクミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市美保関町笠浦', '32', '32201', '6901223', '島根県', 'シマネケン', '松江市', 'マツエシ', '美保関町笠浦', 'ミホノセキチョウカサウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市美保関町七類', '32', '32201', '6901311', '島根県', 'シマネケン', '松江市', 'マツエシ', '美保関町七類', 'ミホノセキチョウシチルイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市美保関町森山', '32', '32201', '6901312', '島根県', 'シマネケン', '松江市', 'マツエシ', '美保関町森山', 'ミホノセキチョウモリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市美保関町下宇部尾', '32', '32201', '6901313', '島根県', 'シマネケン', '松江市', 'マツエシ', '美保関町下宇部尾', 'ミホノセキチョウシモウベオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市美保関町菅浦', '32', '32201', '6901314', '島根県', 'シマネケン', '松江市', 'マツエシ', '美保関町菅浦', 'ミホノセキチョウスゲウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市美保関町片江', '32', '32201', '6901315', '島根県', 'シマネケン', '松江市', 'マツエシ', '美保関町片江', 'ミホノセキチョウカタエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市八束町江島', '32', '32201', '6901401', '島根県', 'シマネケン', '松江市', 'マツエシ', '八束町江島', 'ヤツカチョウエシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市八束町馬渡', '32', '32201', '6901402', '島根県', 'シマネケン', '松江市', 'マツエシ', '八束町馬渡', 'ヤツカチョウマワタシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市八束町遅江', '32', '32201', '6901403', '島根県', 'シマネケン', '松江市', 'マツエシ', '八束町遅江', 'ヤツカチョウオソエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市八束町波入', '32', '32201', '6901404', '島根県', 'シマネケン', '松江市', 'マツエシ', '八束町波入', 'ヤツカチョウハニュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市八束町入江', '32', '32201', '6901405', '島根県', 'シマネケン', '松江市', 'マツエシ', '八束町入江', 'ヤツカチョウニュウコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市八束町二子', '32', '32201', '6901406', '島根県', 'シマネケン', '松江市', 'マツエシ', '八束町二子', 'ヤツカチョウフタゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市八束町寺津', '32', '32201', '6901407', '島根県', 'シマネケン', '松江市', 'マツエシ', '八束町寺津', 'ヤツカチョウテラヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市八束町亀尻', '32', '32201', '6901408', '島根県', 'シマネケン', '松江市', 'マツエシ', '八束町亀尻', 'ヤツカチョウカメシリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市美保関町美保関', '32', '32201', '6901501', '島根県', 'シマネケン', '松江市', 'マツエシ', '美保関町美保関', 'ミホノセキチョウミホノセキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市美保関町雲津', '32', '32201', '6901502', '島根県', 'シマネケン', '松江市', 'マツエシ', '美保関町雲津', 'ミホノセキチョウクモヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市美保関町諸喰', '32', '32201', '6901503', '島根県', 'シマネケン', '松江市', 'マツエシ', '美保関町諸喰', 'ミホノセキチョウモロクイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市美保関町福浦', '32', '32201', '6901504', '島根県', 'シマネケン', '松江市', 'マツエシ', '美保関町福浦', 'ミホノセキチョウフクウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市美保関町森山古金崎', '32', '32201', '6901505', '島根県', 'シマネケン', '松江市', 'マツエシ', '美保関町森山', 'ミホノセキチョウモリヤマ', null, null, '古金崎', 'コガネザキ');
INSERT INTO `ms_addresses` VALUES ('85150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡南幌町', '01', '01423', '0690200', '北海道', 'ホッカイドウ', '空知郡南幌町', 'ソラチグンナンポロチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('85151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡南幌町南7線西', '01', '01423', '0690207', '北海道', 'ホッカイドウ', '空知郡南幌町', 'ソラチグンナンポロチョウ', '南7線西', 'ミナミ07センニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡南幌町南8線西', '01', '01423', '0690208', '北海道', 'ホッカイドウ', '空知郡南幌町', 'ソラチグンナンポロチョウ', '南8線西', 'ミナミ08センニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡南幌町南9線西', '01', '01423', '0690209', '北海道', 'ホッカイドウ', '空知郡南幌町', 'ソラチグンナンポロチョウ', '南9線西', 'ミナミ09センニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡南幌町南10線西', '01', '01423', '0690210', '北海道', 'ホッカイドウ', '空知郡南幌町', 'ソラチグンナンポロチョウ', '南10線西', 'ミナミ10センニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市八雲町日吉', '32', '32201', '6902101', '島根県', 'シマネケン', '松江市', 'マツエシ', '八雲町日吉', 'ヤクモチョウヒヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市八雲町東岩坂', '32', '32201', '6902102', '島根県', 'シマネケン', '松江市', 'マツエシ', '八雲町東岩坂', 'ヤクモチョウヒガシイワサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市八雲町西岩坂', '32', '32201', '6902103', '島根県', 'シマネケン', '松江市', 'マツエシ', '八雲町西岩坂', 'ヤクモチョウニシイワサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市八雲町熊野', '32', '32201', '6902104', '島根県', 'シマネケン', '松江市', 'マツエシ', '八雲町熊野', 'ヤクモチョウクマノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市八雲町平原', '32', '32201', '6902105', '島根県', 'シマネケン', '松江市', 'マツエシ', '八雲町平原', 'ヤクモチョウヒラハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡南幌町南11線西', '01', '01423', '0690211', '北海道', 'ホッカイドウ', '空知郡南幌町', 'ソラチグンナンポロチョウ', '南11線西', 'ミナミ11センニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡南幌町南12線西', '01', '01423', '0690212', '北海道', 'ホッカイドウ', '空知郡南幌町', 'ソラチグンナンポロチョウ', '南12線西', 'ミナミ12センニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡南幌町南13線西', '01', '01423', '0690213', '北海道', 'ホッカイドウ', '空知郡南幌町', 'ソラチグンナンポロチョウ', '南13線西', 'ミナミ13センニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡南幌町南14線西', '01', '01423', '0690214', '北海道', 'ホッカイドウ', '空知郡南幌町', 'ソラチグンナンポロチョウ', '南14線西', 'ミナミ14センニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡南幌町南15線西', '01', '01423', '0690215', '北海道', 'ホッカイドウ', '空知郡南幌町', 'ソラチグンナンポロチョウ', '南15線西', 'ミナミ15センニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡南幌町南16線西', '01', '01423', '0690216', '北海道', 'ホッカイドウ', '空知郡南幌町', 'ソラチグンナンポロチョウ', '南16線西', 'ミナミ16センニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡南幌町南17線西', '01', '01423', '0690217', '北海道', 'ホッカイドウ', '空知郡南幌町', 'ソラチグンナンポロチョウ', '南17線西', 'ミナミ17センニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡南幌町南18線西', '01', '01423', '0690218', '北海道', 'ホッカイドウ', '空知郡南幌町', 'ソラチグンナンポロチョウ', '南18線西', 'ミナミ18センニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡南幌町南19線西', '01', '01423', '0690219', '北海道', 'ホッカイドウ', '空知郡南幌町', 'ソラチグンナンポロチョウ', '南19線西', 'ミナミ19センニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡南幌町南20線西', '01', '01423', '0690220', '北海道', 'ホッカイドウ', '空知郡南幌町', 'ソラチグンナンポロチョウ', '南20線西', 'ミナミ20センニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡南幌町南21線西', '01', '01423', '0690221', '北海道', 'ホッカイドウ', '空知郡南幌町', 'ソラチグンナンポロチョウ', '南21線西', 'ミナミ21センニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡南幌町北町', '01', '01423', '0690231', '北海道', 'ホッカイドウ', '空知郡南幌町', 'ソラチグンナンポロチョウ', '北町', 'キタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県雲南市吉田町上山', '32', '32209', '6902311', '島根県', 'シマネケン', '雲南市', 'ウンナンシ', '吉田町上山', 'ヨシダチョウウエヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県雲南市吉田町曽木', '32', '32209', '6902312', '島根県', 'シマネケン', '雲南市', 'ウンナンシ', '吉田町曽木', 'ヨシダチョウソギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県雲南市吉田町深野', '32', '32209', '6902313', '島根県', 'シマネケン', '雲南市', 'ウンナンシ', '吉田町深野', 'ヨシダチョウフカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県雲南市吉田町川手', '32', '32209', '6902314', '島根県', 'シマネケン', '雲南市', 'ウンナンシ', '吉田町川手', 'ヨシダチョウカワテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡南幌町緑町', '01', '01423', '0690232', '北海道', 'ホッカイドウ', '空知郡南幌町', 'ソラチグンナンポロチョウ', '緑町', 'ミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡南幌町東町', '01', '01423', '0690233', '北海道', 'ホッカイドウ', '空知郡南幌町', 'ソラチグンナンポロチョウ', '東町', 'ヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡南幌町美園', '01', '01423', '0690234', '北海道', 'ホッカイドウ', '空知郡南幌町', 'ソラチグンナンポロチョウ', '美園', 'ミソノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡南幌町中央', '01', '01423', '0690235', '北海道', 'ホッカイドウ', '空知郡南幌町', 'ソラチグンナンポロチョウ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡南幌町西町', '01', '01423', '0690236', '北海道', 'ホッカイドウ', '空知郡南幌町', 'ソラチグンナンポロチョウ', '西町', 'ニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡南幌町栄町', '01', '01423', '0690237', '北海道', 'ホッカイドウ', '空知郡南幌町', 'ソラチグンナンポロチョウ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡南幌町元町', '01', '01423', '0690238', '北海道', 'ホッカイドウ', '空知郡南幌町', 'ソラチグンナンポロチョウ', '元町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡南幌町稲穂', '01', '01423', '0690239', '北海道', 'ホッカイドウ', '空知郡南幌町', 'ソラチグンナンポロチョウ', '稲穂', 'イナホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県雲南市', '32', '32209', '6902400', '島根県', 'シマネケン', '雲南市', 'ウンナンシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('85187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県雲南市三刀屋町伊萱', '32', '32209', '6902401', '島根県', 'シマネケン', '雲南市', 'ウンナンシ', '三刀屋町伊萱', 'ミトヤチョウイガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県雲南市三刀屋町給下', '32', '32209', '6902402', '島根県', 'シマネケン', '雲南市', 'ウンナンシ', '三刀屋町給下', 'ミトヤチョウキュウシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県雲南市三刀屋町下熊谷', '32', '32209', '6902403', '島根県', 'シマネケン', '雲南市', 'ウンナンシ', '三刀屋町下熊谷', 'ミトヤチョウシモクマタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県雲南市三刀屋町三刀屋', '32', '32209', '6902404', '島根県', 'シマネケン', '雲南市', 'ウンナンシ', '三刀屋町三刀屋', 'ミトヤチョウミトヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県雲南市三刀屋町古城', '32', '32209', '6902405', '島根県', 'シマネケン', '雲南市', 'ウンナンシ', '三刀屋町古城', 'ミトヤチョウコジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県雲南市三刀屋町高窪', '32', '32209', '6902406', '島根県', 'シマネケン', '雲南市', 'ウンナンシ', '三刀屋町高窪', 'ミトヤチョウタカクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県雲南市三刀屋町上熊谷', '32', '32209', '6902511', '島根県', 'シマネケン', '雲南市', 'ウンナンシ', '三刀屋町上熊谷', 'ミトヤチョウカミクマタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県雲南市三刀屋町多久和', '32', '32209', '6902512', '島根県', 'シマネケン', '雲南市', 'ウンナンシ', '三刀屋町多久和', 'ミトヤチョウタクワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県雲南市三刀屋町粟谷', '32', '32209', '6902513', '島根県', 'シマネケン', '雲南市', 'ウンナンシ', '三刀屋町粟谷', 'ミトヤチョウアワダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県雲南市三刀屋町神代', '32', '32209', '6902521', '島根県', 'シマネケン', '雲南市', 'ウンナンシ', '三刀屋町神代', 'ミトヤチョウコウジロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県雲南市三刀屋町六重', '32', '32209', '6902522', '島根県', 'シマネケン', '雲南市', 'ウンナンシ', '三刀屋町六重', 'ミトヤチョウムエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県雲南市三刀屋町中野', '32', '32209', '6902523', '島根県', 'シマネケン', '雲南市', 'ウンナンシ', '三刀屋町中野', 'ミトヤチョウナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県雲南市三刀屋町須所', '32', '32209', '6902524', '島根県', 'シマネケン', '雲南市', 'ウンナンシ', '三刀屋町須所', 'ミトヤチョウスゾ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県雲南市三刀屋町坂本森谷', '32', '32209', '6902525', '島根県', 'シマネケン', '雲南市', 'ウンナンシ', '三刀屋町坂本', 'ミトヤチョウサカモト', null, null, '森谷', 'モリダニ');
INSERT INTO `ms_addresses` VALUES ('85201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県雲南市三刀屋町坂本', '32', '32209', '6902625', '島根県', 'シマネケン', '雲南市', 'ウンナンシ', '三刀屋町坂本', 'ミトヤチョウサカモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県雲南市三刀屋町根波別所', '32', '32209', '6902631', '島根県', 'シマネケン', '雲南市', 'ウンナンシ', '三刀屋町根波別所', 'ミトヤチョウネバベッシヨ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県雲南市三刀屋町里坊', '32', '32209', '6902632', '島根県', 'シマネケン', '雲南市', 'ウンナンシ', '三刀屋町里坊', 'ミトヤチョウサトボウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県雲南市三刀屋町殿河内', '32', '32209', '6902633', '島根県', 'シマネケン', '雲南市', 'ウンナンシ', '三刀屋町殿河内', 'ミトヤチョウトノゴウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県雲南市三刀屋町乙加宮', '32', '32209', '6902634', '島根県', 'シマネケン', '雲南市', 'ウンナンシ', '三刀屋町乙加宮', 'ミトヤチョウオツカミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県雲南市掛合町掛合', '32', '32209', '6902701', '島根県', 'シマネケン', '雲南市', 'ウンナンシ', '掛合町掛合', 'カケヤチョウカケヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県雲南市掛合町入間', '32', '32209', '6902702', '島根県', 'シマネケン', '雲南市', 'ウンナンシ', '掛合町入間', 'カケヤチョウイルマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県雲南市掛合町波多', '32', '32209', '6902703', '島根県', 'シマネケン', '雲南市', 'ウンナンシ', '掛合町波多', 'カケヤチョウハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県雲南市掛合町穴見', '32', '32209', '6902704', '島根県', 'シマネケン', '雲南市', 'ウンナンシ', '掛合町穴見', 'カケヤチョウアナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県雲南市掛合町松笠', '32', '32209', '6902705', '島根県', 'シマネケン', '雲南市', 'ウンナンシ', '掛合町松笠', 'カケヤチョウマツカサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県雲南市掛合町多根', '32', '32209', '6902706', '島根県', 'シマネケン', '雲南市', 'ウンナンシ', '掛合町多根', 'カケヤチョウタネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県雲南市吉田町吉田', '32', '32209', '6902801', '島根県', 'シマネケン', '雲南市', 'ウンナンシ', '吉田町吉田', 'ヨシダチョウヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県雲南市吉田町民谷', '32', '32209', '6902802', '島根県', 'シマネケン', '雲南市', 'ウンナンシ', '吉田町民谷', 'ヨシダチョウミンダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県飯石郡飯南町', '32', '32386', '6903200', '島根県', 'シマネケン', '飯石郡飯南町', 'イイシグンイイナンチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('85217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県飯石郡飯南町都加賀', '32', '32386', '6903203', '島根県', 'シマネケン', '飯石郡飯南町', 'イイシグンイイナンチョウ', '都加賀', 'ツガカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県飯石郡飯南町佐見', '32', '32386', '6903204', '島根県', 'シマネケン', '飯石郡飯南町', 'イイシグンイイナンチョウ', '佐見', 'サミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県飯石郡飯南町長谷', '32', '32386', '6903205', '島根県', 'シマネケン', '飯石郡飯南町', 'イイシグンイイナンチョウ', '長谷', 'ナガタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県飯石郡飯南町花栗', '32', '32386', '6903206', '島根県', 'シマネケン', '飯石郡飯南町', 'イイシグンイイナンチョウ', '花栗', 'ハナグリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県飯石郡飯南町頓原', '32', '32386', '6903207', '島根県', 'シマネケン', '飯石郡飯南町', 'イイシグンイイナンチョウ', '頓原', 'トンバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県飯石郡飯南町獅子', '32', '32386', '6903311', '島根県', 'シマネケン', '飯石郡飯南町', 'イイシグンイイナンチョウ', '獅子', 'シシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県飯石郡飯南町八神', '32', '32386', '6903312', '島根県', 'シマネケン', '飯石郡飯南町', 'イイシグンイイナンチョウ', '八神', 'ハカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県飯石郡飯南町志津見', '32', '32386', '6903313', '島根県', 'シマネケン', '飯石郡飯南町', 'イイシグンイイナンチョウ', '志津見', 'シツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県飯石郡飯南町角井', '32', '32386', '6903314', '島根県', 'シマネケン', '飯石郡飯南町', 'イイシグンイイナンチョウ', '角井', 'ツノイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県飯石郡飯南町野萱', '32', '32386', '6903401', '島根県', 'シマネケン', '飯石郡飯南町', 'イイシグンイイナンチョウ', '野萱', 'ノガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県飯石郡飯南町下来島', '32', '32386', '6903402', '島根県', 'シマネケン', '飯石郡飯南町', 'イイシグンイイナンチョウ', '下来島', 'シモキジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県飯石郡飯南町小田', '32', '32386', '6903403', '島根県', 'シマネケン', '飯石郡飯南町', 'イイシグンイイナンチョウ', '小田', 'オダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県飯石郡飯南町真木', '32', '32386', '6903404', '島根県', 'シマネケン', '飯石郡飯南町', 'イイシグンイイナンチョウ', '真木', 'マキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県飯石郡飯南町上来島', '32', '32386', '6903405', '島根県', 'シマネケン', '飯石郡飯南町', 'イイシグンイイナンチョウ', '上来島', 'カミキジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市北村砂浜', '01', '01210', '0690351', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '北村砂浜', 'キタムラスナハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県飯石郡飯南町赤名', '32', '32386', '6903511', '島根県', 'シマネケン', '飯石郡飯南町', 'イイシグンイイナンチョウ', '赤名', 'アカナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県飯石郡飯南町上赤名', '32', '32386', '6903512', '島根県', 'シマネケン', '飯石郡飯南町', 'イイシグンイイナンチョウ', '上赤名', 'カミアカナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県飯石郡飯南町下赤名', '32', '32386', '6903513', '島根県', 'シマネケン', '飯石郡飯南町', 'イイシグンイイナンチョウ', '下赤名', 'シモアカナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県飯石郡飯南町井戸谷', '32', '32386', '6903514', '島根県', 'シマネケン', '飯石郡飯南町', 'イイシグンイイナンチョウ', '井戸谷', 'イドダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県飯石郡飯南町塩谷', '32', '32386', '6903515', '島根県', 'シマネケン', '飯石郡飯南町', 'イイシグンイイナンチョウ', '塩谷', 'シオダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県飯石郡飯南町畑田', '32', '32386', '6903516', '島根県', 'シマネケン', '飯石郡飯南町', 'イイシグンイイナンチョウ', '畑田', 'ハタタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市上幌向北1条', '01', '01210', '0690361', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '上幌向北1条', 'カミホロムイキタ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市上幌向南1条', '01', '01210', '0690362', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '上幌向南1条', 'カミホロムイミナミ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市上幌向南2条', '01', '01210', '0690363', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '上幌向南2条', 'カミホロムイミナミ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市上幌向南3条', '01', '01210', '0690364', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '上幌向南3条', 'カミホロムイミナミ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市上幌向町', '01', '01210', '0690365', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '上幌向町', 'カミホロムイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市双葉町', '01', '01210', '0690366', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '双葉町', 'フタバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市幌向南1条', '01', '01210', '0690371', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '幌向南1条', 'ホロムイミナミ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市幌向南2条', '01', '01210', '0690372', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '幌向南2条', 'ホロムイミナミ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市幌向南3条', '01', '01210', '0690373', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '幌向南3条', 'ホロムイミナミ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市幌向南4条', '01', '01210', '0690374', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '幌向南4条', 'ホロムイミナミ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市幌向南5条', '01', '01210', '0690375', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '幌向南5条', 'ホロムイミナミ05ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市中幌向町', '01', '01210', '0690376', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '中幌向町', 'ナカホロムイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市幌向北1条', '01', '01210', '0690381', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '幌向北1条', 'ホロムイキタ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市幌向北2条', '01', '01210', '0690382', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '幌向北2条', 'ホロムイキタ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市幌向町', '01', '01210', '0690383', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '幌向町', 'ホロムイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市御茶の水町', '01', '01210', '0690384', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '御茶の水町', 'オチャノミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道江別市中央町', '01', '01217', '0690801', '北海道', 'ホッカイドウ', '江別市', 'エベツシ', '中央町', 'チュウオウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道江別市野幌寿町', '01', '01217', '0690802', '北海道', 'ホッカイドウ', '江別市', 'エベツシ', '野幌寿町', 'ノッポロコトブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道江別市野幌屯田町', '01', '01217', '0690803', '北海道', 'ホッカイドウ', '江別市', 'エベツシ', '野幌屯田町', 'ノッポロトンデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道江別市野幌美幸町', '01', '01217', '0690804', '北海道', 'ホッカイドウ', '江別市', 'エベツシ', '野幌美幸町', 'ノッポロミユキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道江別市元野幌', '01', '01217', '0690805', '北海道', 'ホッカイドウ', '江別市', 'エベツシ', '元野幌', 'モトノッポロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道江別市新栄台', '01', '01217', '0690806', '北海道', 'ホッカイドウ', '江別市', 'エベツシ', '新栄台', 'シンエイダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道江別市錦町', '01', '01217', '0690811', '北海道', 'ホッカイドウ', '江別市', 'エベツシ', '錦町', 'ニシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道江別市幸町', '01', '01217', '0690812', '北海道', 'ホッカイドウ', '江別市', 'エベツシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道江別市野幌町', '01', '01217', '0690813', '北海道', 'ホッカイドウ', '江別市', 'エベツシ', '野幌町', 'ノッポロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道江別市野幌松並町', '01', '01217', '0690814', '北海道', 'ホッカイドウ', '江別市', 'エベツシ', '野幌松並町', 'ノッポロマツナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道江別市野幌末広町', '01', '01217', '0690815', '北海道', 'ホッカイドウ', '江別市', 'エベツシ', '野幌末広町', 'ノッポロスエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道江別市野幌住吉町', '01', '01217', '0690816', '北海道', 'ホッカイドウ', '江別市', 'エベツシ', '野幌住吉町', 'ノッポロスミヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道江別市野幌代々木町', '01', '01217', '0690817', '北海道', 'ホッカイドウ', '江別市', 'エベツシ', '野幌代々木町', 'ノッポロヨヨギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道江別市東野幌町', '01', '01217', '0690821', '北海道', 'ホッカイドウ', '江別市', 'エベツシ', '東野幌町', 'ヒガシノッポロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道江別市東野幌', '01', '01217', '0690822', '北海道', 'ホッカイドウ', '江別市', 'エベツシ', '東野幌', 'ヒガシノッポロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道江別市緑ケ丘', '01', '01217', '0690823', '北海道', 'ホッカイドウ', '江別市', 'エベツシ', '緑ケ丘', 'ミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道江別市東野幌本町', '01', '01217', '0690824', '北海道', 'ホッカイドウ', '江別市', 'エベツシ', '東野幌本町', 'ヒガシノッポロホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道江別市野幌東町', '01', '01217', '0690825', '北海道', 'ホッカイドウ', '江別市', 'エベツシ', '野幌東町', 'ノッポロヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道江別市あさひが丘', '01', '01217', '0690826', '北海道', 'ホッカイドウ', '江別市', 'エベツシ', 'あさひが丘', 'アサヒガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道江別市野幌若葉町', '01', '01217', '0690831', '北海道', 'ホッカイドウ', '江別市', 'エベツシ', '野幌若葉町', 'ノッポロワカバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道江別市西野幌', '01', '01217', '0690832', '北海道', 'ホッカイドウ', '江別市', 'エベツシ', '西野幌', 'ニシノッポロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道江別市文京台', '01', '01217', '0690833', '北海道', 'ホッカイドウ', '江別市', 'エベツシ', '文京台', 'ブンキョウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道江別市文京台東町', '01', '01217', '0690834', '北海道', 'ホッカイドウ', '江別市', 'エベツシ', '文京台東町', 'ブンキョウダイヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道江別市文京台南町', '01', '01217', '0690835', '北海道', 'ホッカイドウ', '江別市', 'エベツシ', '文京台南町', 'ブンキョウダイミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道江別市文京台緑町', '01', '01217', '0690836', '北海道', 'ホッカイドウ', '江別市', 'エベツシ', '文京台緑町', 'ブンキョウダイミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道江別市大麻元町', '01', '01217', '0690841', '北海道', 'ホッカイドウ', '江別市', 'エベツシ', '大麻元町', 'オオアサモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道江別市大麻沢町', '01', '01217', '0690842', '北海道', 'ホッカイドウ', '江別市', 'エベツシ', '大麻沢町', 'オオアササワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道江別市大麻扇町', '01', '01217', '0690843', '北海道', 'ホッカイドウ', '江別市', 'エベツシ', '大麻扇町', 'オオアサオウギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道江別市大麻西町', '01', '01217', '0690844', '北海道', 'ホッカイドウ', '江別市', 'エベツシ', '大麻西町', 'オオアサニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道江別市大麻', '01', '01217', '0690845', '北海道', 'ホッカイドウ', '江別市', 'エベツシ', '大麻', 'オオアサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道江別市大麻桜木町', '01', '01217', '0690846', '北海道', 'ホッカイドウ', '江別市', 'エベツシ', '大麻桜木町', 'オオアササクラギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道江別市大麻ひかり町', '01', '01217', '0690847', '北海道', 'ホッカイドウ', '江別市', 'エベツシ', '大麻ひかり町', 'オオアサヒカリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道江別市大麻園町', '01', '01217', '0690851', '北海道', 'ホッカイドウ', '江別市', 'エベツシ', '大麻園町', 'オオアサソノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道江別市大麻東町', '01', '01217', '0690852', '北海道', 'ホッカイドウ', '江別市', 'エベツシ', '大麻東町', 'オオアサヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道江別市大麻高町', '01', '01217', '0690853', '北海道', 'ホッカイドウ', '江別市', 'エベツシ', '大麻高町', 'オオアサタカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道江別市大麻中町', '01', '01217', '0690854', '北海道', 'ホッカイドウ', '江別市', 'エベツシ', '大麻中町', 'オオアサナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道江別市大麻宮町', '01', '01217', '0690855', '北海道', 'ホッカイドウ', '江別市', 'エベツシ', '大麻宮町', 'オオアサミヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道江別市大麻北町', '01', '01217', '0690861', '北海道', 'ホッカイドウ', '江別市', 'エベツシ', '大麻北町', 'オオアサキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道江別市大麻栄町', '01', '01217', '0690862', '北海道', 'ホッカイドウ', '江別市', 'エベツシ', '大麻栄町', 'オオアササカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道江別市大麻新町', '01', '01217', '0690863', '北海道', 'ホッカイドウ', '江別市', 'エベツシ', '大麻新町', 'オオアサシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道江別市大麻泉町', '01', '01217', '0690864', '北海道', 'ホッカイドウ', '江別市', 'エベツシ', '大麻泉町', 'オオアサイズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道江別市大麻南樹町', '01', '01217', '0690865', '北海道', 'ホッカイドウ', '江別市', 'エベツシ', '大麻南樹町', 'オオアサミナキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道江別市大麻晴美町', '01', '01217', '0690866', '北海道', 'ホッカイドウ', '江別市', 'エベツシ', '大麻晴美町', 'オオアサハルミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道江別市元野幌', '01', '01217', '0690867', '北海道', 'ホッカイドウ', '江別市', 'エベツシ', '元野幌', 'モトノッポロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市平田町', '32', '32203', '6910001', '島根県', 'シマネケン', '出雲市', 'イズモシ', '平田町', 'ヒラタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市西平田町', '32', '32203', '6910002', '島根県', 'シマネケン', '出雲市', 'イズモシ', '西平田町', 'ニシヒラタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市灘分町', '32', '32203', '6910003', '島根県', 'シマネケン', '出雲市', 'イズモシ', '灘分町', 'ナダブンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市島村町', '32', '32203', '6910004', '島根県', 'シマネケン', '出雲市', 'イズモシ', '島村町', 'シマムラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市国富町', '32', '32203', '6910011', '島根県', 'シマネケン', '出雲市', 'イズモシ', '国富町', 'クンドミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市西代町', '32', '32203', '6910012', '島根県', 'シマネケン', '出雲市', 'イズモシ', '西代町', 'ニシダイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市美談町', '32', '32203', '6910013', '島根県', 'シマネケン', '出雲市', 'イズモシ', '美談町', 'ミダミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市口宇賀町', '32', '32203', '6910014', '島根県', 'シマネケン', '出雲市', 'イズモシ', '口宇賀町', 'クチウガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市西郷町', '32', '32203', '6910015', '島根県', 'シマネケン', '出雲市', 'イズモシ', '西郷町', 'サイゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市奥宇賀町', '32', '32203', '6910021', '島根県', 'シマネケン', '出雲市', 'イズモシ', '奥宇賀町', 'オクウガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市別所町', '32', '32203', '6910022', '島根県', 'シマネケン', '出雲市', 'イズモシ', '別所町', 'ベッシヨチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市唐川町', '32', '32203', '6910023', '島根県', 'シマネケン', '出雲市', 'イズモシ', '唐川町', 'カラカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市猪目町', '32', '32203', '6910024', '島根県', 'シマネケン', '出雲市', 'イズモシ', '猪目町', 'イノメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市河下町', '32', '32203', '6910025', '島根県', 'シマネケン', '出雲市', 'イズモシ', '河下町', 'カワシモチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市東福町', '32', '32203', '6910031', '島根県', 'シマネケン', '出雲市', 'イズモシ', '東福町', 'トウフクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市本庄町', '32', '32203', '6910032', '島根県', 'シマネケン', '出雲市', 'イズモシ', '本庄町', 'ホンジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市万田町', '32', '32203', '6910033', '島根県', 'シマネケン', '出雲市', 'イズモシ', '万田町', 'マンダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市久多見町', '32', '32203', '6910034', '島根県', 'シマネケン', '出雲市', 'イズモシ', '久多見町', 'クタミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市小津町', '32', '32203', '6910041', '島根県', 'シマネケン', '出雲市', 'イズモシ', '小津町', 'コヅチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市十六島町', '32', '32203', '6910042', '島根県', 'シマネケン', '出雲市', 'イズモシ', '十六島町', 'ウップルイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市釜浦町', '32', '32203', '6910043', '島根県', 'シマネケン', '出雲市', 'イズモシ', '釜浦町', 'カマウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市塩津町', '32', '32203', '6910044', '島根県', 'シマネケン', '出雲市', 'イズモシ', '塩津町', 'シオツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市美保町', '32', '32203', '6910045', '島根県', 'シマネケン', '出雲市', 'イズモシ', '美保町', 'ミホチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市坂浦町', '32', '32203', '6910051', '島根県', 'シマネケン', '出雲市', 'イズモシ', '坂浦町', 'サカウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市小伊津町', '32', '32203', '6910052', '島根県', 'シマネケン', '出雲市', 'イズモシ', '小伊津町', 'コイヅチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市三津町', '32', '32203', '6910053', '島根県', 'シマネケン', '出雲市', 'イズモシ', '三津町', 'ミツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市多久町', '32', '32203', '6910061', '島根県', 'シマネケン', '出雲市', 'イズモシ', '多久町', 'タクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市多久谷町', '32', '32203', '6910062', '島根県', 'シマネケン', '出雲市', 'イズモシ', '多久谷町', 'タクダニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市岡田町', '32', '32203', '6910063', '島根県', 'シマネケン', '出雲市', 'イズモシ', '岡田町', 'オカダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市上岡田町', '32', '32203', '6910064', '島根県', 'シマネケン', '出雲市', 'イズモシ', '上岡田町', 'カミオカダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市東郷町', '32', '32203', '6910065', '島根県', 'シマネケン', '出雲市', 'イズモシ', '東郷町', 'トウゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市野石谷町', '32', '32203', '6910066', '島根県', 'シマネケン', '出雲市', 'イズモシ', '野石谷町', 'ノイシダニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市地合町', '32', '32203', '6910071', '島根県', 'シマネケン', '出雲市', 'イズモシ', '地合町', 'チゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市野郷町', '32', '32203', '6910072', '島根県', 'シマネケン', '出雲市', 'イズモシ', '野郷町', 'ノザトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市美野町', '32', '32203', '6910073', '島根県', 'シマネケン', '出雲市', 'イズモシ', '美野町', 'ヨシノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市小境町', '32', '32203', '6910074', '島根県', 'シマネケン', '出雲市', 'イズモシ', '小境町', 'コザカイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市鹿園寺町', '32', '32203', '6910075', '島根県', 'シマネケン', '出雲市', 'イズモシ', '鹿園寺町', 'ロクオンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市園町', '32', '32203', '6910076', '島根県', 'シマネケン', '出雲市', 'イズモシ', '園町', 'ソノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡由仁町三川泉町', '01', '01427', '0691131', '北海道', 'ホッカイドウ', '夕張郡由仁町', 'ユウバリグンユニチョウ', '三川泉町', 'ミカワイズミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡由仁町三川錦町', '01', '01427', '0691132', '北海道', 'ホッカイドウ', '夕張郡由仁町', 'ユウバリグンユニチョウ', '三川錦町', 'ミカワニシキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡由仁町三川旭町', '01', '01427', '0691133', '北海道', 'ホッカイドウ', '夕張郡由仁町', 'ユウバリグンユニチョウ', '三川旭町', 'ミカワアサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡由仁町三川緑町', '01', '01427', '0691134', '北海道', 'ホッカイドウ', '夕張郡由仁町', 'ユウバリグンユニチョウ', '三川緑町', 'ミカワミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡由仁町西三川', '01', '01427', '0691135', '北海道', 'ホッカイドウ', '夕張郡由仁町', 'ユウバリグンユニチョウ', '西三川', 'ニシミカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡由仁町熊本', '01', '01427', '0691136', '北海道', 'ホッカイドウ', '夕張郡由仁町', 'ユウバリグンユニチョウ', '熊本', 'クマモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡由仁町川端', '01', '01427', '0691141', '北海道', 'ホッカイドウ', '夕張郡由仁町', 'ユウバリグンユニチョウ', '川端', 'カワバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡由仁町東三川', '01', '01427', '0691142', '北海道', 'ホッカイドウ', '夕張郡由仁町', 'ユウバリグンユニチョウ', '東三川', 'ヒガシミカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡由仁町中三川', '01', '01427', '0691143', '北海道', 'ホッカイドウ', '夕張郡由仁町', 'ユウバリグンユニチョウ', '中三川', 'ナカミカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡由仁町本三川', '01', '01427', '0691144', '北海道', 'ホッカイドウ', '夕張郡由仁町', 'ユウバリグンユニチョウ', '本三川', 'モトミカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道千歳市東丘', '01', '01224', '0691181', '北海道', 'ホッカイドウ', '千歳市', 'チトセシ', '東丘', 'ヒガシオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道千歳市協和', '01', '01224', '0691182', '北海道', 'ホッカイドウ', '千歳市', 'チトセシ', '協和', 'キョウワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道千歳市幌加', '01', '01224', '0691183', '北海道', 'ホッカイドウ', '千歳市', 'チトセシ', '幌加', 'ホロカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道千歳市新川', '01', '01224', '0691184', '北海道', 'ホッカイドウ', '千歳市', 'チトセシ', '新川', 'ニイカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡由仁町', '01', '01427', '0691200', '北海道', 'ホッカイドウ', '夕張郡由仁町', 'ユウバリグンユニチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('85399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡由仁町北栄', '01', '01427', '0691201', '北海道', 'ホッカイドウ', '夕張郡由仁町', 'ユウバリグンユニチョウ', '北栄', 'ホクエイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡由仁町古川', '01', '01427', '0691202', '北海道', 'ホッカイドウ', '夕張郡由仁町', 'ユウバリグンユニチョウ', '古川', 'フルカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡由仁町東栄', '01', '01427', '0691203', '北海道', 'ホッカイドウ', '夕張郡由仁町', 'ユウバリグンユニチョウ', '東栄', 'トウエイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡由仁町新光', '01', '01427', '0691204', '北海道', 'ホッカイドウ', '夕張郡由仁町', 'ユウバリグンユニチョウ', '新光', 'シンコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡由仁町中央', '01', '01427', '0691205', '北海道', 'ホッカイドウ', '夕張郡由仁町', 'ユウバリグンユニチョウ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡由仁町本町', '01', '01427', '0691206', '北海道', 'ホッカイドウ', '夕張郡由仁町', 'ユウバリグンユニチョウ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡由仁町馬追', '01', '01427', '0691207', '北海道', 'ホッカイドウ', '夕張郡由仁町', 'ユウバリグンユニチョウ', '馬追', 'ウマオイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡由仁町山形', '01', '01427', '0691208', '北海道', 'ホッカイドウ', '夕張郡由仁町', 'ユウバリグンユニチョウ', '山形', 'ヤマガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡由仁町岩内', '01', '01427', '0691211', '北海道', 'ホッカイドウ', '夕張郡由仁町', 'ユウバリグンユニチョウ', '岩内', 'イワナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡由仁町山桝', '01', '01427', '0691212', '北海道', 'ホッカイドウ', '夕張郡由仁町', 'ユウバリグンユニチョウ', '山桝', 'ヤママス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡由仁町本三川', '01', '01427', '0691213', '北海道', 'ホッカイドウ', '夕張郡由仁町', 'ユウバリグンユニチョウ', '本三川', 'モトミカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡由仁町西三川', '01', '01427', '0691214', '北海道', 'ホッカイドウ', '夕張郡由仁町', 'ユウバリグンユニチョウ', '西三川', 'ニシミカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡由仁町熊本', '01', '01427', '0691215', '北海道', 'ホッカイドウ', '夕張郡由仁町', 'ユウバリグンユニチョウ', '熊本', 'クマモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡由仁町古山', '01', '01427', '0691216', '北海道', 'ホッカイドウ', '夕張郡由仁町', 'ユウバリグンユニチョウ', '古山', 'フルサン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡由仁町光栄', '01', '01427', '0691217', '北海道', 'ホッカイドウ', '夕張郡由仁町', 'ユウバリグンユニチョウ', '光栄', 'コウエイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡由仁町伏見', '01', '01427', '0691218', '北海道', 'ホッカイドウ', '夕張郡由仁町', 'ユウバリグンユニチョウ', '伏見', 'フシミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡由仁町東光', '01', '01427', '0691219', '北海道', 'ホッカイドウ', '夕張郡由仁町', 'ユウバリグンユニチョウ', '東光', 'トウコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡長沼町', '01', '01428', '0691300', '北海道', 'ホッカイドウ', '夕張郡長沼町', 'ユウバリグンナガヌマチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('85423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡長沼町1区', '01', '01428', '0691301', '北海道', 'ホッカイドウ', '夕張郡長沼町', 'ユウバリグンナガヌマチョウ', '1区', '01ク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡長沼町2区', '01', '01428', '0691302', '北海道', 'ホッカイドウ', '夕張郡長沼町', 'ユウバリグンナガヌマチョウ', '2区', '02ク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡長沼町3区', '01', '01428', '0691303', '北海道', 'ホッカイドウ', '夕張郡長沼町', 'ユウバリグンナガヌマチョウ', '3区', '03ク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡長沼町4区', '01', '01428', '0691304', '北海道', 'ホッカイドウ', '夕張郡長沼町', 'ユウバリグンナガヌマチョウ', '4区', '04ク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡長沼町北市区', '01', '01428', '0691304', '北海道', 'ホッカイドウ', '夕張郡長沼町', 'ユウバリグンナガヌマチョウ', '北市区', 'キタイチク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡長沼町5区', '01', '01428', '0691305', '北海道', 'ホッカイドウ', '夕張郡長沼町', 'ユウバリグンナガヌマチョウ', '5区', '05ク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡長沼町6区', '01', '01428', '0691306', '北海道', 'ホッカイドウ', '夕張郡長沼町', 'ユウバリグンナガヌマチョウ', '6区', '06ク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡長沼町7区', '01', '01428', '0691307', '北海道', 'ホッカイドウ', '夕張郡長沼町', 'ユウバリグンナガヌマチョウ', '7区', '07ク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡長沼町8区', '01', '01428', '0691308', '北海道', 'ホッカイドウ', '夕張郡長沼町', 'ユウバリグンナガヌマチョウ', '8区', '08ク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡長沼町9区', '01', '01428', '0691309', '北海道', 'ホッカイドウ', '夕張郡長沼町', 'ユウバリグンナガヌマチョウ', '9区', '09ク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡長沼町10区', '01', '01428', '0691310', '北海道', 'ホッカイドウ', '夕張郡長沼町', 'ユウバリグンナガヌマチョウ', '10区', '10ク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡長沼町11区', '01', '01428', '0691311', '北海道', 'ホッカイドウ', '夕張郡長沼町', 'ユウバリグンナガヌマチョウ', '11区', '11ク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡長沼町フシコ', '01', '01428', '0691311', '北海道', 'ホッカイドウ', '夕張郡長沼町', 'ユウバリグンナガヌマチョウ', 'フシコ', 'フシコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡長沼町12区', '01', '01428', '0691312', '北海道', 'ホッカイドウ', '夕張郡長沼町', 'ユウバリグンナガヌマチョウ', '12区', '12ク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡長沼町13区', '01', '01428', '0691313', '北海道', 'ホッカイドウ', '夕張郡長沼町', 'ユウバリグンナガヌマチョウ', '13区', '13ク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡長沼町14区', '01', '01428', '0691314', '北海道', 'ホッカイドウ', '夕張郡長沼町', 'ユウバリグンナガヌマチョウ', '14区', '14ク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡長沼町15区', '01', '01428', '0691315', '北海道', 'ホッカイドウ', '夕張郡長沼町', 'ユウバリグンナガヌマチョウ', '15区', '15ク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡長沼町南町', '01', '01428', '0691315', '北海道', 'ホッカイドウ', '夕張郡長沼町', 'ユウバリグンナガヌマチョウ', '南町', 'ミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡長沼町16区', '01', '01428', '0691316', '北海道', 'ホッカイドウ', '夕張郡長沼町', 'ユウバリグンナガヌマチョウ', '16区', '16ク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡長沼町加賀団体', '01', '01428', '0691316', '北海道', 'ホッカイドウ', '夕張郡長沼町', 'ユウバリグンナガヌマチョウ', '加賀団体', 'カガダンタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡長沼町東1線北', '01', '01428', '0691317', '北海道', 'ホッカイドウ', '夕張郡長沼町', 'ユウバリグンナガヌマチョウ', '東1線北', 'ヒガシ01センキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡長沼町東2線北', '01', '01428', '0691317', '北海道', 'ホッカイドウ', '夕張郡長沼町', 'ユウバリグンナガヌマチョウ', '東2線北', 'ヒガシ02センキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡長沼町東3線北', '01', '01428', '0691317', '北海道', 'ホッカイドウ', '夕張郡長沼町', 'ユウバリグンナガヌマチョウ', '東3線北', 'ヒガシ03センキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡長沼町東4線北', '01', '01428', '0691317', '北海道', 'ホッカイドウ', '夕張郡長沼町', 'ユウバリグンナガヌマチョウ', '東4線北', 'ヒガシ04センキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡長沼町東5線北', '01', '01428', '0691317', '北海道', 'ホッカイドウ', '夕張郡長沼町', 'ユウバリグンナガヌマチョウ', '東5線北', 'ヒガシ05センキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡長沼町東6線北', '01', '01428', '0691317', '北海道', 'ホッカイドウ', '夕張郡長沼町', 'ユウバリグンナガヌマチョウ', '東6線北', 'ヒガシ06センキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡長沼町東7線北', '01', '01428', '0691317', '北海道', 'ホッカイドウ', '夕張郡長沼町', 'ユウバリグンナガヌマチョウ', '東7線北', 'ヒガシ07センキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡長沼町東8線北', '01', '01428', '0691317', '北海道', 'ホッカイドウ', '夕張郡長沼町', 'ユウバリグンナガヌマチョウ', '東8線北', 'ヒガシ08センキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡長沼町東9線北', '01', '01428', '0691317', '北海道', 'ホッカイドウ', '夕張郡長沼町', 'ユウバリグンナガヌマチョウ', '東9線北', 'ヒガシ09センキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡長沼町東10線北', '01', '01428', '0691317', '北海道', 'ホッカイドウ', '夕張郡長沼町', 'ユウバリグンナガヌマチョウ', '東10線北', 'ヒガシ10センキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡長沼町東11線北', '01', '01428', '0691317', '北海道', 'ホッカイドウ', '夕張郡長沼町', 'ユウバリグンナガヌマチョウ', '東11線北', 'ヒガシ11センキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡長沼町西1線北', '01', '01428', '0691318', '北海道', 'ホッカイドウ', '夕張郡長沼町', 'ユウバリグンナガヌマチョウ', '西1線北', 'ニシ01センキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡長沼町西2線北', '01', '01428', '0691318', '北海道', 'ホッカイドウ', '夕張郡長沼町', 'ユウバリグンナガヌマチョウ', '西2線北', 'ニシ02センキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡長沼町西3線北', '01', '01428', '0691318', '北海道', 'ホッカイドウ', '夕張郡長沼町', 'ユウバリグンナガヌマチョウ', '西3線北', 'ニシ03センキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡長沼町西4線北', '01', '01428', '0691318', '北海道', 'ホッカイドウ', '夕張郡長沼町', 'ユウバリグンナガヌマチョウ', '西4線北', 'ニシ04センキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡長沼町西5線北', '01', '01428', '0691318', '北海道', 'ホッカイドウ', '夕張郡長沼町', 'ユウバリグンナガヌマチョウ', '西5線北', 'ニシ05センキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡長沼町西6線北', '01', '01428', '0691318', '北海道', 'ホッカイドウ', '夕張郡長沼町', 'ユウバリグンナガヌマチョウ', '西6線北', 'ニシ06センキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡長沼町西7線北', '01', '01428', '0691318', '北海道', 'ホッカイドウ', '夕張郡長沼町', 'ユウバリグンナガヌマチョウ', '西7線北', 'ニシ07センキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡長沼町西8線北', '01', '01428', '0691318', '北海道', 'ホッカイドウ', '夕張郡長沼町', 'ユウバリグンナガヌマチョウ', '西8線北', 'ニシ08センキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡長沼町市街地', '01', '01428', '0691320', '北海道', 'ホッカイドウ', '夕張郡長沼町', 'ユウバリグンナガヌマチョウ', '市街地', 'シガイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡長沼町馬追', '01', '01428', '0691321', '北海道', 'ホッカイドウ', '夕張郡長沼町', 'ユウバリグンナガヌマチョウ', '馬追', 'ウマオイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡長沼町馬追原野', '01', '01428', '0691322', '北海道', 'ホッカイドウ', '夕張郡長沼町', 'ユウバリグンナガヌマチョウ', '馬追原野', 'ウマオイゲンヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡長沼町29区', '01', '01428', '0691329', '北海道', 'ホッカイドウ', '夕張郡長沼町', 'ユウバリグンナガヌマチョウ', '29区', '29ク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡長沼町木詰', '01', '01428', '0691329', '北海道', 'ホッカイドウ', '夕張郡長沼町', 'ユウバリグンナガヌマチョウ', '木詰', 'キヅマリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡長沼町幌向原野', '01', '01428', '0691329', '北海道', 'ホッカイドウ', '夕張郡長沼町', 'ユウバリグンナガヌマチョウ', '幌向原野', 'ホロムイゲンヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡長沼町銀座', '01', '01428', '0691331', '北海道', 'ホッカイドウ', '夕張郡長沼町', 'ユウバリグンナガヌマチョウ', '銀座', 'ギンザ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡長沼町中央', '01', '01428', '0691332', '北海道', 'ホッカイドウ', '夕張郡長沼町', 'ユウバリグンナガヌマチョウ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡長沼町本町', '01', '01428', '0691333', '北海道', 'ホッカイドウ', '夕張郡長沼町', 'ユウバリグンナガヌマチョウ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡長沼町錦町北', '01', '01428', '0691334', '北海道', 'ホッカイドウ', '夕張郡長沼町', 'ユウバリグンナガヌマチョウ', '錦町北', 'ニシキマチキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡長沼町錦町南', '01', '01428', '0691334', '北海道', 'ホッカイドウ', '夕張郡長沼町', 'ユウバリグンナガヌマチョウ', '錦町南', 'ニシキマチミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡長沼町あかね', '01', '01428', '0691335', '北海道', 'ホッカイドウ', '夕張郡長沼町', 'ユウバリグンナガヌマチョウ', 'あかね', 'アカネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡長沼町川沿', '01', '01428', '0691336', '北海道', 'ホッカイドウ', '夕張郡長沼町', 'ユウバリグンナガヌマチョウ', '川沿', 'カワゾイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡長沼町栄町', '01', '01428', '0691336', '北海道', 'ホッカイドウ', '夕張郡長沼町', 'ユウバリグンナガヌマチョウ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡長沼町宮下', '01', '01428', '0691341', '北海道', 'ホッカイドウ', '夕張郡長沼町', 'ユウバリグンナガヌマチョウ', '宮下', 'ミヤシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡長沼町東町', '01', '01428', '0691342', '北海道', 'ホッカイドウ', '夕張郡長沼町', 'ユウバリグンナガヌマチョウ', '東町', 'ヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡長沼町旭町', '01', '01428', '0691343', '北海道', 'ホッカイドウ', '夕張郡長沼町', 'ユウバリグンナガヌマチョウ', '旭町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡長沼町曙町', '01', '01428', '0691344', '北海道', 'ホッカイドウ', '夕張郡長沼町', 'ユウバリグンナガヌマチョウ', '曙町', 'アケボノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡長沼町しらかば', '01', '01428', '0691345', '北海道', 'ホッカイドウ', '夕張郡長沼町', 'ユウバリグンナガヌマチョウ', 'しらかば', 'シラカバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡長沼町西町', '01', '01428', '0691346', '北海道', 'ホッカイドウ', '夕張郡長沼町', 'ユウバリグンナガヌマチョウ', '西町', 'ニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡長沼町北町', '01', '01428', '0691347', '北海道', 'ホッカイドウ', '夕張郡長沼町', 'ユウバリグンナガヌマチョウ', '北町', 'キタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡長沼町東1線南', '01', '01428', '0691451', '北海道', 'ホッカイドウ', '夕張郡長沼町', 'ユウバリグンナガヌマチョウ', '東1線南', 'ヒガシ01センミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡長沼町東2線南', '01', '01428', '0691452', '北海道', 'ホッカイドウ', '夕張郡長沼町', 'ユウバリグンナガヌマチョウ', '東2線南', 'ヒガシ02センミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡長沼町東3線南', '01', '01428', '0691453', '北海道', 'ホッカイドウ', '夕張郡長沼町', 'ユウバリグンナガヌマチョウ', '東3線南', 'ヒガシ03センミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡長沼町東4線南', '01', '01428', '0691454', '北海道', 'ホッカイドウ', '夕張郡長沼町', 'ユウバリグンナガヌマチョウ', '東4線南', 'ヒガシ04センミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡長沼町東5線南', '01', '01428', '0691455', '北海道', 'ホッカイドウ', '夕張郡長沼町', 'ユウバリグンナガヌマチョウ', '東5線南', 'ヒガシ05センミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡長沼町東6線南', '01', '01428', '0691456', '北海道', 'ホッカイドウ', '夕張郡長沼町', 'ユウバリグンナガヌマチョウ', '東6線南', 'ヒガシ06センミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡長沼町東7線南', '01', '01428', '0691457', '北海道', 'ホッカイドウ', '夕張郡長沼町', 'ユウバリグンナガヌマチョウ', '東7線南', 'ヒガシ07センミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡長沼町東8線南', '01', '01428', '0691458', '北海道', 'ホッカイドウ', '夕張郡長沼町', 'ユウバリグンナガヌマチョウ', '東8線南', 'ヒガシ08センミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡長沼町東9線南', '01', '01428', '0691459', '北海道', 'ホッカイドウ', '夕張郡長沼町', 'ユウバリグンナガヌマチョウ', '東9線南', 'ヒガシ09センミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡長沼町東10線南', '01', '01428', '0691460', '北海道', 'ホッカイドウ', '夕張郡長沼町', 'ユウバリグンナガヌマチョウ', '東10線南', 'ヒガシ10センミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡長沼町東11線南', '01', '01428', '0691461', '北海道', 'ホッカイドウ', '夕張郡長沼町', 'ユウバリグンナガヌマチョウ', '東11線南', 'ヒガシ11センミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡長沼町東12線南', '01', '01428', '0691462', '北海道', 'ホッカイドウ', '夕張郡長沼町', 'ユウバリグンナガヌマチョウ', '東12線南', 'ヒガシ12センミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡長沼町東13線南', '01', '01428', '0691463', '北海道', 'ホッカイドウ', '夕張郡長沼町', 'ユウバリグンナガヌマチョウ', '東13線南', 'ヒガシ13センミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡長沼町幌内', '01', '01428', '0691464', '北海道', 'ホッカイドウ', '夕張郡長沼町', 'ユウバリグンナガヌマチョウ', '幌内', 'ホロナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡長沼町西1線南', '01', '01428', '0691471', '北海道', 'ホッカイドウ', '夕張郡長沼町', 'ユウバリグンナガヌマチョウ', '西1線南', 'ニシ01センミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡長沼町西2線南', '01', '01428', '0691472', '北海道', 'ホッカイドウ', '夕張郡長沼町', 'ユウバリグンナガヌマチョウ', '西2線南', 'ニシ02センミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡長沼町西3線南', '01', '01428', '0691473', '北海道', 'ホッカイドウ', '夕張郡長沼町', 'ユウバリグンナガヌマチョウ', '西3線南', 'ニシ03センミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡長沼町西4線南', '01', '01428', '0691474', '北海道', 'ホッカイドウ', '夕張郡長沼町', 'ユウバリグンナガヌマチョウ', '西4線南', 'ニシ04センミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡長沼町西5線南', '01', '01428', '0691475', '北海道', 'ホッカイドウ', '夕張郡長沼町', 'ユウバリグンナガヌマチョウ', '西5線南', 'ニシ05センミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡長沼町西6線南', '01', '01428', '0691476', '北海道', 'ホッカイドウ', '夕張郡長沼町', 'ユウバリグンナガヌマチョウ', '西6線南', 'ニシ06センミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡長沼町西7線南', '01', '01428', '0691477', '北海道', 'ホッカイドウ', '夕張郡長沼町', 'ユウバリグンナガヌマチョウ', '西7線南', 'ニシ07センミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡長沼町西8線南', '01', '01428', '0691478', '北海道', 'ホッカイドウ', '夕張郡長沼町', 'ユウバリグンナガヌマチョウ', '西8線南', 'ニシ08センミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡長沼町西9線南', '01', '01428', '0691479', '北海道', 'ホッカイドウ', '夕張郡長沼町', 'ユウバリグンナガヌマチョウ', '西9線南', 'ニシ09センミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡長沼町西10線南', '01', '01428', '0691480', '北海道', 'ホッカイドウ', '夕張郡長沼町', 'ユウバリグンナガヌマチョウ', '西10線南', 'ニシ10センミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡長沼町西11線南', '01', '01428', '0691481', '北海道', 'ホッカイドウ', '夕張郡長沼町', 'ユウバリグンナガヌマチョウ', '西11線南', 'ニシ11センミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡長沼町西12線南', '01', '01428', '0691482', '北海道', 'ホッカイドウ', '夕張郡長沼町', 'ユウバリグンナガヌマチョウ', '西12線南', 'ニシ12センミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡長沼町西13線南', '01', '01428', '0691483', '北海道', 'ホッカイドウ', '夕張郡長沼町', 'ユウバリグンナガヌマチョウ', '西13線南', 'ニシ13センミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡長沼町西14線南', '01', '01428', '0691484', '北海道', 'ホッカイドウ', '夕張郡長沼町', 'ユウバリグンナガヌマチョウ', '西14線南', 'ニシ14センミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡長沼町30区', '01', '01428', '0691485', '北海道', 'ホッカイドウ', '夕張郡長沼町', 'ユウバリグンナガヌマチョウ', '30区', '30ク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡栗山町', '01', '01429', '0691500', '北海道', 'ホッカイドウ', '夕張郡栗山町', 'ユウバリグンクリヤマチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('85517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡栗山町桜丘', '01', '01429', '0691501', '北海道', 'ホッカイドウ', '夕張郡栗山町', 'ユウバリグンクリヤマチョウ', '桜丘', 'サクラオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡栗山町鳩山', '01', '01429', '0691502', '北海道', 'ホッカイドウ', '夕張郡栗山町', 'ユウバリグンクリヤマチョウ', '鳩山', 'ハトヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡栗山町森', '01', '01429', '0691502', '北海道', 'ホッカイドウ', '夕張郡栗山町', 'ユウバリグンクリヤマチョウ', '森', 'モリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡栗山町雨煙別', '01', '01429', '0691503', '北海道', 'ホッカイドウ', '夕張郡栗山町', 'ユウバリグンクリヤマチョウ', '雨煙別', 'ウエンベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡栗山町緑丘', '01', '01429', '0691503', '北海道', 'ホッカイドウ', '夕張郡栗山町', 'ユウバリグンクリヤマチョウ', '緑丘', 'ミドリオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡栗山町北学田', '01', '01429', '0691504', '北海道', 'ホッカイドウ', '夕張郡栗山町', 'ユウバリグンクリヤマチョウ', '北学田', 'キタガクデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡栗山町桜山', '01', '01429', '0691505', '北海道', 'ホッカイドウ', '夕張郡栗山町', 'ユウバリグンクリヤマチョウ', '桜山', 'サクラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡栗山町本沢', '01', '01429', '0691505', '北海道', 'ホッカイドウ', '夕張郡栗山町', 'ユウバリグンクリヤマチョウ', '本沢', 'ホンサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡栗山町杵臼', '01', '01429', '0691506', '北海道', 'ホッカイドウ', '夕張郡栗山町', 'ユウバリグンクリヤマチョウ', '杵臼', 'キナウス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡栗山町旭台', '01', '01429', '0691507', '北海道', 'ホッカイドウ', '夕張郡栗山町', 'ユウバリグンクリヤマチョウ', '旭台', 'アサヒダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡栗山町湯地', '01', '01429', '0691508', '北海道', 'ホッカイドウ', '夕張郡栗山町', 'ユウバリグンクリヤマチョウ', '湯地', 'ユチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡栗山町中央', '01', '01429', '0691511', '北海道', 'ホッカイドウ', '夕張郡栗山町', 'ユウバリグンクリヤマチョウ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡栗山町松風', '01', '01429', '0691512', '北海道', 'ホッカイドウ', '夕張郡栗山町', 'ユウバリグンクリヤマチョウ', '松風', 'マツカゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡栗山町朝日', '01', '01429', '0691513', '北海道', 'ホッカイドウ', '夕張郡栗山町', 'ユウバリグンクリヤマチョウ', '朝日', 'アサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡栗山町錦', '01', '01429', '0691521', '北海道', 'ホッカイドウ', '夕張郡栗山町', 'ユウバリグンクリヤマチョウ', '錦', 'ニシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡栗山町中里', '01', '01429', '0691522', '北海道', 'ホッカイドウ', '夕張郡栗山町', 'ユウバリグンクリヤマチョウ', '中里', 'ナカサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡栗山町共和', '01', '01429', '0691523', '北海道', 'ホッカイドウ', '夕張郡栗山町', 'ユウバリグンクリヤマチョウ', '共和', 'キョウワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡栗山町角田', '01', '01429', '0691524', '北海道', 'ホッカイドウ', '夕張郡栗山町', 'ユウバリグンクリヤマチョウ', '角田', 'カクタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡栗山町三日月', '01', '01429', '0691525', '北海道', 'ホッカイドウ', '夕張郡栗山町', 'ユウバリグンクリヤマチョウ', '三日月', 'ミカヅキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道夕張郡栗山町富士', '01', '01429', '0691526', '北海道', 'ホッカイドウ', '夕張郡栗山町', 'ユウバリグンクリヤマチョウ', '富士', 'フジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県安来市', '32', '32206', '6920000', '島根県', 'シマネケン', '安来市', 'ヤスギシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('85540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県安来市赤江町', '32', '32206', '6920001', '島根県', 'シマネケン', '安来市', 'ヤスギシ', '赤江町', 'アカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県安来市上坂田町', '32', '32206', '6920002', '島根県', 'シマネケン', '安来市', 'ヤスギシ', '上坂田町', 'カミサカダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県安来市西赤江町', '32', '32206', '6920003', '島根県', 'シマネケン', '安来市', 'ヤスギシ', '西赤江町', 'ニシアカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県安来市久白町', '32', '32206', '6920004', '島根県', 'シマネケン', '安来市', 'ヤスギシ', '久白町', 'クジラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県安来市日白町', '32', '32206', '6920005', '島根県', 'シマネケン', '安来市', 'ヤスギシ', '日白町', 'ヒジラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県安来市西荒島町', '32', '32206', '6920006', '島根県', 'シマネケン', '安来市', 'ヤスギシ', '西荒島町', 'ニシアラシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県安来市荒島町', '32', '32206', '6920007', '島根県', 'シマネケン', '安来市', 'ヤスギシ', '荒島町', 'アラシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県安来市安来町', '32', '32206', '6920011', '島根県', 'シマネケン', '安来市', 'ヤスギシ', '安来町', 'ヤスギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県安来市宮内町', '32', '32206', '6920012', '島根県', 'シマネケン', '安来市', 'ヤスギシ', '宮内町', 'ミヤウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県安来市月坂町', '32', '32206', '6920013', '島根県', 'シマネケン', '安来市', 'ヤスギシ', '月坂町', 'ツキザカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県安来市飯島町', '32', '32206', '6920014', '島根県', 'シマネケン', '安来市', 'ヤスギシ', '飯島町', 'ハシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県安来市今津町', '32', '32206', '6920015', '島根県', 'シマネケン', '安来市', 'ヤスギシ', '今津町', 'イマヅチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県安来市東赤江町', '32', '32206', '6920016', '島根県', 'シマネケン', '安来市', 'ヤスギシ', '東赤江町', 'ヒガシアカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県安来市下坂田町', '32', '32206', '6920017', '島根県', 'シマネケン', '安来市', 'ヤスギシ', '下坂田町', 'シモサカダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県安来市新十神町', '32', '32206', '6920021', '島根県', 'シマネケン', '安来市', 'ヤスギシ', '新十神町', 'シントカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県安来市南十神町', '32', '32206', '6920022', '島根県', 'シマネケン', '安来市', 'ヤスギシ', '南十神町', 'ミナミトカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県安来市黒井田町', '32', '32206', '6920023', '島根県', 'シマネケン', '安来市', 'ヤスギシ', '黒井田町', 'クロイダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県安来市島田町', '32', '32206', '6920024', '島根県', 'シマネケン', '安来市', 'ヤスギシ', '島田町', 'シマタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県安来市穂日島町', '32', '32206', '6920025', '島根県', 'シマネケン', '安来市', 'ヤスギシ', '穂日島町', 'ホヒジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県安来市吉佐町', '32', '32206', '6920026', '島根県', 'シマネケン', '安来市', 'ヤスギシ', '吉佐町', 'キサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県安来市門生町', '32', '32206', '6920027', '島根県', 'シマネケン', '安来市', 'ヤスギシ', '門生町', 'カドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県安来市汐手が丘', '32', '32206', '6920028', '島根県', 'シマネケン', '安来市', 'ヤスギシ', '汐手が丘', 'シオデガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県安来市佐久保町', '32', '32206', '6920031', '島根県', 'シマネケン', '安来市', 'ヤスギシ', '佐久保町', 'サクボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県安来市九重町', '32', '32206', '6920032', '島根県', 'シマネケン', '安来市', 'ヤスギシ', '九重町', 'クノウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県安来市清水町', '32', '32206', '6920033', '島根県', 'シマネケン', '安来市', 'ヤスギシ', '清水町', 'キヨミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県安来市宇賀荘町', '32', '32206', '6920034', '島根県', 'シマネケン', '安来市', 'ヤスギシ', '宇賀荘町', 'ウカショウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県安来市清瀬町', '32', '32206', '6920035', '島根県', 'シマネケン', '安来市', 'ヤスギシ', '清瀬町', 'キヨセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県安来市野方町', '32', '32206', '6920036', '島根県', 'シマネケン', '安来市', 'ヤスギシ', '野方町', 'ノカタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県安来市吉岡町', '32', '32206', '6920037', '島根県', 'シマネケン', '安来市', 'ヤスギシ', '吉岡町', 'ヨシオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県安来市鳥木町', '32', '32206', '6920041', '島根県', 'シマネケン', '安来市', 'ヤスギシ', '鳥木町', 'トリギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県安来市大塚町', '32', '32206', '6920042', '島根県', 'シマネケン', '安来市', 'ヤスギシ', '大塚町', 'オオツカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県安来市上吉田町', '32', '32206', '6920043', '島根県', 'シマネケン', '安来市', 'ヤスギシ', '上吉田町', 'カミヨシダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県安来市下吉田町', '32', '32206', '6920044', '島根県', 'シマネケン', '安来市', 'ヤスギシ', '下吉田町', 'シモヨシダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県安来市柿谷町', '32', '32206', '6920045', '島根県', 'シマネケン', '安来市', 'ヤスギシ', '柿谷町', 'カキダニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県安来市折坂町', '32', '32206', '6920046', '島根県', 'シマネケン', '安来市', 'ヤスギシ', '折坂町', 'オリサカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県安来市早田町', '32', '32206', '6920047', '島根県', 'シマネケン', '安来市', 'ヤスギシ', '早田町', 'ソウダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県安来市切川町', '32', '32206', '6920051', '島根県', 'シマネケン', '安来市', 'ヤスギシ', '切川町', 'キレカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県安来市赤崎町', '32', '32206', '6920052', '島根県', 'シマネケン', '安来市', 'ヤスギシ', '赤崎町', 'アカサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県安来市沢町', '32', '32206', '6920053', '島根県', 'シマネケン', '安来市', 'ヤスギシ', '沢町', 'サワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県安来市利弘町', '32', '32206', '6920054', '島根県', 'シマネケン', '安来市', 'ヤスギシ', '利弘町', 'トシヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県安来市飯生町', '32', '32206', '6920055', '島根県', 'シマネケン', '安来市', 'ヤスギシ', '飯生町', 'イナリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県安来市清井町', '32', '32206', '6920056', '島根県', 'シマネケン', '安来市', 'ヤスギシ', '清井町', 'キヨイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県安来市恵乃島町', '32', '32206', '6920057', '島根県', 'シマネケン', '安来市', 'ヤスギシ', '恵乃島町', 'エノシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県安来市中津町', '32', '32206', '6920061', '島根県', 'シマネケン', '安来市', 'ヤスギシ', '中津町', 'ナカヅチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県安来市実松町', '32', '32206', '6920062', '島根県', 'シマネケン', '安来市', 'ヤスギシ', '実松町', 'サネマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県安来市植田町', '32', '32206', '6920063', '島根県', 'シマネケン', '安来市', 'ヤスギシ', '植田町', 'ウエダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県安来市古川町', '32', '32206', '6920064', '島根県', 'シマネケン', '安来市', 'ヤスギシ', '古川町', 'フルカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県安来市岩舟町', '32', '32206', '6920065', '島根県', 'シマネケン', '安来市', 'ヤスギシ', '岩舟町', 'イワフネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県安来市飯梨町', '32', '32206', '6920066', '島根県', 'シマネケン', '安来市', 'ヤスギシ', '飯梨町', 'イイナシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県安来市田頼町', '32', '32206', '6920067', '島根県', 'シマネケン', '安来市', 'ヤスギシ', '田頼町', 'タヨリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県安来市亀島町', '32', '32206', '6920071', '島根県', 'シマネケン', '安来市', 'ヤスギシ', '亀島町', 'カメシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県安来市能義町', '32', '32206', '6920072', '島根県', 'シマネケン', '安来市', 'ヤスギシ', '能義町', 'ノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県安来市矢田町', '32', '32206', '6920073', '島根県', 'シマネケン', '安来市', 'ヤスギシ', '矢田町', 'ヤタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県安来市中海町', '32', '32206', '6920074', '島根県', 'シマネケン', '安来市', 'ヤスギシ', '中海町', 'ナカウミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県安来市神庭町', '32', '32206', '6920075', '島根県', 'シマネケン', '安来市', 'ヤスギシ', '神庭町', 'カンバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県安来市西松井町', '32', '32206', '6920077', '島根県', 'シマネケン', '安来市', 'ヤスギシ', '西松井町', 'ニシマツイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県安来市伯太町安田山形', '32', '32206', '6920201', '島根県', 'シマネケン', '安来市', 'ヤスギシ', '伯太町安田山形', 'ハクタチョウヤスダヤマガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県安来市伯太町安田関', '32', '32206', '6920202', '島根県', 'シマネケン', '安来市', 'ヤスギシ', '伯太町安田関', 'ハクタチョウヤスダセキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県安来市伯太町未明', '32', '32206', '6920203', '島根県', 'シマネケン', '安来市', 'ヤスギシ', '伯太町未明', 'ハクタチョウホノカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県安来市伯太町安田宮内', '32', '32206', '6920204', '島根県', 'シマネケン', '安来市', 'ヤスギシ', '伯太町安田宮内', 'ハクタチョウヤスダミヤウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県安来市伯太町安田中', '32', '32206', '6920205', '島根県', 'シマネケン', '安来市', 'ヤスギシ', '伯太町安田中', 'ハクタチョウヤスダナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県安来市伯太町安田', '32', '32206', '6920206', '島根県', 'シマネケン', '安来市', 'ヤスギシ', '伯太町安田', 'ハクタチョウヤスダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県安来市伯太町東母里', '32', '32206', '6920207', '島根県', 'シマネケン', '安来市', 'ヤスギシ', '伯太町東母里', 'ハクタチョウヒガシモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県安来市伯太町母里', '32', '32206', '6920211', '島根県', 'シマネケン', '安来市', 'ヤスギシ', '伯太町母里', 'ハクタチョウモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県安来市伯太町西母里', '32', '32206', '6920212', '島根県', 'シマネケン', '安来市', 'ヤスギシ', '伯太町西母里', 'ハクタチョウニシモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県安来市伯太町井尻', '32', '32206', '6920213', '島根県', 'シマネケン', '安来市', 'ヤスギシ', '伯太町井尻', 'ハクタチョウイジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県安来市伯太町須山福冨', '32', '32206', '6920214', '島根県', 'シマネケン', '安来市', 'ヤスギシ', '伯太町須山福冨', 'ハクタチョウスヤマフクドメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県安来市伯太町高江寸次', '32', '32206', '6920215', '島根県', 'シマネケン', '安来市', 'ヤスギシ', '伯太町高江寸次', 'ハクタチョウタカエスンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県安来市伯太町日次', '32', '32206', '6920216', '島根県', 'シマネケン', '安来市', 'ヤスギシ', '伯太町日次', 'ハクタチョウヒナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県安来市伯太町横屋', '32', '32206', '6920217', '島根県', 'シマネケン', '安来市', 'ヤスギシ', '伯太町横屋', 'ハクタチョウヨコヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県安来市伯太町峠之内', '32', '32206', '6920218', '島根県', 'シマネケン', '安来市', 'ヤスギシ', '伯太町峠之内', 'ハクタチョウタワノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県安来市伯太町赤屋', '32', '32206', '6920321', '島根県', 'シマネケン', '安来市', 'ヤスギシ', '伯太町赤屋', 'ハクタチョウアカヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県安来市伯太町上小竹', '32', '32206', '6920322', '島根県', 'シマネケン', '安来市', 'ヤスギシ', '伯太町上小竹', 'ハクタチョウカミオダケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県安来市伯太町下小竹', '32', '32206', '6920323', '島根県', 'シマネケン', '安来市', 'ヤスギシ', '伯太町下小竹', 'ハクタチョウシモオダケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県安来市伯太町草野', '32', '32206', '6920324', '島根県', 'シマネケン', '安来市', 'ヤスギシ', '伯太町草野', 'ハクタチョウクサノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県安来市伯太町上十年畑', '32', '32206', '6920325', '島根県', 'シマネケン', '安来市', 'ヤスギシ', '伯太町上十年畑', 'ハクタチョウカミジュウネンバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県安来市伯太町下十年畑', '32', '32206', '6920326', '島根県', 'シマネケン', '安来市', 'ヤスギシ', '伯太町下十年畑', 'ハクタチョウシモジュウネンバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県安来市広瀬町石原', '32', '32206', '6920401', '島根県', 'シマネケン', '安来市', 'ヤスギシ', '広瀬町石原', 'ヒロセチョウイシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県安来市広瀬町町帳', '32', '32206', '6920402', '島根県', 'シマネケン', '安来市', 'ヤスギシ', '広瀬町町帳', 'ヒロセチョウマチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県安来市広瀬町富田', '32', '32206', '6920403', '島根県', 'シマネケン', '安来市', 'ヤスギシ', '広瀬町富田', 'ヒロセチョウトダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県安来市広瀬町広瀬', '32', '32206', '6920404', '島根県', 'シマネケン', '安来市', 'ヤスギシ', '広瀬町広瀬', 'ヒロセチョウヒロセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県安来市広瀬町祖父谷', '32', '32206', '6920405', '島根県', 'シマネケン', '安来市', 'ヤスギシ', '広瀬町祖父谷', 'ヒロセチョウオジダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県安来市広瀬町菅原下田原', '32', '32206', '6920411', '島根県', 'シマネケン', '安来市', 'ヤスギシ', '広瀬町菅原', 'ヒロセチョウスガハラ', null, null, '下田原', 'シモタワラ');
INSERT INTO `ms_addresses` VALUES ('85623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県安来市広瀬町下山佐', '32', '32206', '6920412', '島根県', 'シマネケン', '安来市', 'ヤスギシ', '広瀬町下山佐', 'ヒロセチョウシモヤマサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県安来市広瀬町上山佐', '32', '32206', '6920413', '島根県', 'シマネケン', '安来市', 'ヤスギシ', '広瀬町上山佐', 'ヒロセチョウカミヤマサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県安来市広瀬町菅原', '32', '32206', '6920621', '島根県', 'シマネケン', '安来市', 'ヤスギシ', '広瀬町菅原', 'ヒロセチョウスガハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県安来市広瀬町宇波', '32', '32206', '6920622', '島根県', 'シマネケン', '安来市', 'ヤスギシ', '広瀬町宇波', 'ヒロセチョウウナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県安来市広瀬町布部', '32', '32206', '6920623', '島根県', 'シマネケン', '安来市', 'ヤスギシ', '広瀬町布部', 'ヒロセチョウフベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県安来市広瀬町西谷', '32', '32206', '6920624', '島根県', 'シマネケン', '安来市', 'ヤスギシ', '広瀬町西谷', 'ヒロセチョウニシダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県安来市広瀬町奥田原', '32', '32206', '6920625', '島根県', 'シマネケン', '安来市', 'ヤスギシ', '広瀬町奥田原', 'ヒロセチョウオクタワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県安来市広瀬町西比田', '32', '32206', '6920731', '島根県', 'シマネケン', '安来市', 'ヤスギシ', '広瀬町西比田', 'ヒロセチョウニシヒダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県安来市広瀬町梶福留', '32', '32206', '6920732', '島根県', 'シマネケン', '安来市', 'ヤスギシ', '広瀬町梶福留', 'ヒロセチョウカジフクドメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県安来市広瀬町東比田', '32', '32206', '6920733', '島根県', 'シマネケン', '安来市', 'ヤスギシ', '広瀬町東比田', 'ヒロセチョウヒガシヒダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市', '32', '32203', '6930000', '島根県', 'シマネケン', '出雲市', 'イズモシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('85639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市今市町', '32', '32203', '6930001', '島根県', 'シマネケン', '出雲市', 'イズモシ', '今市町', 'イマイチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市今市町北本町', '32', '32203', '6930002', '島根県', 'シマネケン', '出雲市', 'イズモシ', '今市町北本町', 'イマイチチョウキタホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市今市町南本町', '32', '32203', '6930003', '島根県', 'シマネケン', '出雲市', 'イズモシ', '今市町南本町', 'イマイチチョウミナミホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市渡橋町', '32', '32203', '6930004', '島根県', 'シマネケン', '出雲市', 'イズモシ', '渡橋町', 'ワタリハシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市天神町', '32', '32203', '6930005', '島根県', 'シマネケン', '出雲市', 'イズモシ', '天神町', 'テンジンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市白枝町', '32', '32203', '6930006', '島根県', 'シマネケン', '出雲市', 'イズモシ', '白枝町', 'シロエダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市駅北町', '32', '32203', '6930007', '島根県', 'シマネケン', '出雲市', 'イズモシ', '駅北町', 'エキキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市駅南町', '32', '32203', '6930008', '島根県', 'シマネケン', '出雲市', 'イズモシ', '駅南町', 'エキミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市大津町', '32', '32203', '6930011', '島根県', 'シマネケン', '出雲市', 'イズモシ', '大津町', 'オオツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市大津新崎町', '32', '32203', '6930012', '島根県', 'シマネケン', '出雲市', 'イズモシ', '大津新崎町', 'オオツシンザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市荻杼町', '32', '32203', '6930013', '島根県', 'シマネケン', '出雲市', 'イズモシ', '荻杼町', 'オギトチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市武志町', '32', '32203', '6930014', '島根県', 'シマネケン', '出雲市', 'イズモシ', '武志町', 'タケシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市大津朝倉', '32', '32203', '6930015', '島根県', 'シマネケン', '出雲市', 'イズモシ', '大津朝倉', 'オオツアサクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市枝大津町', '32', '32203', '6930017', '島根県', 'シマネケン', '出雲市', 'イズモシ', '枝大津町', 'エダオオツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市塩冶町', '32', '32203', '6930021', '島根県', 'シマネケン', '出雲市', 'イズモシ', '塩冶町', 'エンヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市上塩冶町', '32', '32203', '6930022', '島根県', 'シマネケン', '出雲市', 'イズモシ', '上塩冶町', 'カミエンヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市塩冶有原町', '32', '32203', '6930023', '島根県', 'シマネケン', '出雲市', 'イズモシ', '塩冶有原町', 'エンヤアリハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市塩冶神前', '32', '32203', '6930024', '島根県', 'シマネケン', '出雲市', 'イズモシ', '塩冶神前', 'エンヤカンマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市塩冶町南町', '32', '32203', '6930025', '島根県', 'シマネケン', '出雲市', 'イズモシ', '塩冶町南町', 'エンヤチョウミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市塩冶原町', '32', '32203', '6930026', '島根県', 'シマネケン', '出雲市', 'イズモシ', '塩冶原町', 'エンヤハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市医大南町', '32', '32203', '6930027', '島根県', 'シマネケン', '出雲市', 'イズモシ', '医大南町', 'イダイミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市塩冶善行町', '32', '32203', '6930028', '島根県', 'シマネケン', '出雲市', 'イズモシ', '塩冶善行町', 'エンヤゼンコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市古志町', '32', '32203', '6930031', '島根県', 'シマネケン', '出雲市', 'イズモシ', '古志町', 'コシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市下古志町', '32', '32203', '6930032', '島根県', 'シマネケン', '出雲市', 'イズモシ', '下古志町', 'シモコシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市知井宮町', '32', '32203', '6930033', '島根県', 'シマネケン', '出雲市', 'イズモシ', '知井宮町', 'チイミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市神門町', '32', '32203', '6930034', '島根県', 'シマネケン', '出雲市', 'イズモシ', '神門町', 'カンドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市芦渡町', '32', '32203', '6930035', '島根県', 'シマネケン', '出雲市', 'イズモシ', '芦渡町', 'アシワタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市平成町', '32', '32203', '6930036', '島根県', 'シマネケン', '出雲市', 'イズモシ', '平成町', 'ヘイセイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市西新町', '32', '32203', '6930037', '島根県', 'シマネケン', '出雲市', 'イズモシ', '西新町', 'ニシシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市西園町', '32', '32203', '6930041', '島根県', 'シマネケン', '出雲市', 'イズモシ', '西園町', 'ニシゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市外園町', '32', '32203', '6930042', '島根県', 'シマネケン', '出雲市', 'イズモシ', '外園町', 'ソトゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市長浜町', '32', '32203', '6930043', '島根県', 'シマネケン', '出雲市', 'イズモシ', '長浜町', 'ナガハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市荒茅町', '32', '32203', '6930044', '島根県', 'シマネケン', '出雲市', 'イズモシ', '荒茅町', 'アラカヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市東園町', '32', '32203', '6930045', '島根県', 'シマネケン', '出雲市', 'イズモシ', '東園町', 'ヒガシゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市下横町', '32', '32203', '6930046', '島根県', 'シマネケン', '出雲市', 'イズモシ', '下横町', 'シモヨコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市小山町', '32', '32203', '6930051', '島根県', 'シマネケン', '出雲市', 'イズモシ', '小山町', 'オヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市松寄下町', '32', '32203', '6930052', '島根県', 'シマネケン', '出雲市', 'イズモシ', '松寄下町', 'マツヨリシモチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市高松町', '32', '32203', '6930053', '島根県', 'シマネケン', '出雲市', 'イズモシ', '高松町', 'タカマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市浜町', '32', '32203', '6930054', '島根県', 'シマネケン', '出雲市', 'イズモシ', '浜町', 'ハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市八島町', '32', '32203', '6930055', '島根県', 'シマネケン', '出雲市', 'イズモシ', '八島町', 'ヤシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市江田町', '32', '32203', '6930056', '島根県', 'シマネケン', '出雲市', 'イズモシ', '江田町', 'エタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市常松町', '32', '32203', '6930057', '島根県', 'シマネケン', '出雲市', 'イズモシ', '常松町', 'ツネマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市矢野町', '32', '32203', '6930058', '島根県', 'シマネケン', '出雲市', 'イズモシ', '矢野町', 'ヤノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市姫原町', '32', '32203', '6930061', '島根県', 'シマネケン', '出雲市', 'イズモシ', '姫原町', 'ヒメバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市中野町', '32', '32203', '6930062', '島根県', 'シマネケン', '出雲市', 'イズモシ', '中野町', 'ナカノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市大塚町', '32', '32203', '6930063', '島根県', 'シマネケン', '出雲市', 'イズモシ', '大塚町', 'オオツカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市里方町', '32', '32203', '6930064', '島根県', 'シマネケン', '出雲市', 'イズモシ', '里方町', 'サトカタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市平野町', '32', '32203', '6930065', '島根県', 'シマネケン', '出雲市', 'イズモシ', '平野町', 'ヒラノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市高岡町', '32', '32203', '6930066', '島根県', 'シマネケン', '出雲市', 'イズモシ', '高岡町', 'タカオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市矢尾町', '32', '32203', '6930067', '島根県', 'シマネケン', '出雲市', 'イズモシ', '矢尾町', 'ヤビチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市姫原1丁目', '32', '32203', '6930068', '島根県', 'シマネケン', '出雲市', 'イズモシ', '姫原', 'ヒメバラ', null, null, '1丁目', '01チョウメ');
INSERT INTO `ms_addresses` VALUES ('85690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市姫原2丁目', '32', '32203', '6930068', '島根県', 'シマネケン', '出雲市', 'イズモシ', '姫原', 'ヒメバラ', null, null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('85691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市姫原3丁目', '32', '32203', '6930068', '島根県', 'シマネケン', '出雲市', 'イズモシ', '姫原', 'ヒメバラ', null, null, '3丁目', '03チョウメ');
INSERT INTO `ms_addresses` VALUES ('85692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市姫原4丁目', '32', '32203', '6930068', '島根県', 'シマネケン', '出雲市', 'イズモシ', '姫原', 'ヒメバラ', null, null, '4丁目', '04チョウメ');
INSERT INTO `ms_addresses` VALUES ('85693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市稲岡町', '32', '32203', '6930071', '島根県', 'シマネケン', '出雲市', 'イズモシ', '稲岡町', 'イナオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市日下町', '32', '32203', '6930072', '島根県', 'シマネケン', '出雲市', 'イズモシ', '日下町', 'クサカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市西林木町', '32', '32203', '6930073', '島根県', 'シマネケン', '出雲市', 'イズモシ', '西林木町', 'ニシハヤシギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市東林木町', '32', '32203', '6930074', '島根県', 'シマネケン', '出雲市', 'イズモシ', '東林木町', 'ヒガシハヤシギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市中野美保北', '32', '32203', '6930081', '島根県', 'シマネケン', '出雲市', 'イズモシ', '中野美保北', 'ナカノミホキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市中野美保南', '32', '32203', '6930082', '島根県', 'シマネケン', '出雲市', 'イズモシ', '中野美保南', 'ナカノミホミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市上島町', '32', '32203', '6930101', '島根県', 'シマネケン', '出雲市', 'イズモシ', '上島町', 'カミシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市西谷町', '32', '32203', '6930102', '島根県', 'シマネケン', '出雲市', 'イズモシ', '西谷町', 'ニシダニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市野尻町', '32', '32203', '6930103', '島根県', 'シマネケン', '出雲市', 'イズモシ', '野尻町', 'ノジリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市稗原町', '32', '32203', '6930104', '島根県', 'シマネケン', '出雲市', 'イズモシ', '稗原町', 'ヒエバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市宇那手町', '32', '32203', '6930105', '島根県', 'シマネケン', '出雲市', 'イズモシ', '宇那手町', 'ウナテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市船津町', '32', '32203', '6930106', '島根県', 'シマネケン', '出雲市', 'イズモシ', '船津町', 'フナツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市馬木北町', '32', '32203', '6930211', '島根県', 'シマネケン', '出雲市', 'イズモシ', '馬木北町', 'マキキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市馬木町', '32', '32203', '6930212', '島根県', 'シマネケン', '出雲市', 'イズモシ', '馬木町', 'マキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市朝山町', '32', '32203', '6930213', '島根県', 'シマネケン', '出雲市', 'イズモシ', '朝山町', 'アサヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市所原町', '32', '32203', '6930214', '島根県', 'シマネケン', '出雲市', 'イズモシ', '所原町', 'トコロハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市見々久町', '32', '32203', '6930215', '島根県', 'シマネケン', '出雲市', 'イズモシ', '見々久町', 'ミミクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市乙立町', '32', '32203', '6930216', '島根県', 'シマネケン', '出雲市', 'イズモシ', '乙立町', 'オッタチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市佐田町朝原', '32', '32203', '6930501', '島根県', 'シマネケン', '出雲市', 'イズモシ', '佐田町朝原', 'サダチョウアザバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市佐田町原田', '32', '32203', '6930502', '島根県', 'シマネケン', '出雲市', 'イズモシ', '佐田町原田', 'サダチョウハラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市佐田町須佐', '32', '32203', '6930503', '島根県', 'シマネケン', '出雲市', 'イズモシ', '佐田町須佐', 'サダチョウスサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市佐田町大呂', '32', '32203', '6930504', '島根県', 'シマネケン', '出雲市', 'イズモシ', '佐田町大呂', 'サダチョウオオロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市佐田町吉野', '32', '32203', '6930505', '島根県', 'シマネケン', '出雲市', 'イズモシ', '佐田町吉野', 'サダチョウヨシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市佐田町反辺', '32', '32203', '6930506', '島根県', 'シマネケン', '出雲市', 'イズモシ', '佐田町反辺', 'サダチョウタンベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市佐田町八幡原', '32', '32203', '6930511', '島根県', 'シマネケン', '出雲市', 'イズモシ', '佐田町八幡原', 'サダチョウヤワタバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市佐田町東村', '32', '32203', '6930512', '島根県', 'シマネケン', '出雲市', 'イズモシ', '佐田町東村', 'サダチョウヒガシムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市佐田町毛津', '32', '32203', '6930521', '島根県', 'シマネケン', '出雲市', 'イズモシ', '佐田町毛津', 'サダチョウケヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市佐田町一窪田', '32', '32203', '6930522', '島根県', 'シマネケン', '出雲市', 'イズモシ', '佐田町一窪田', 'サダチョウヒトクボタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市佐田町佐津目', '32', '32203', '6930523', '島根県', 'シマネケン', '出雲市', 'イズモシ', '佐田町佐津目', 'サダチョウサツメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市佐田町高津屋', '32', '32203', '6930524', '島根県', 'シマネケン', '出雲市', 'イズモシ', '佐田町高津屋', 'サダチョウタカツヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市佐田町下橋波', '32', '32203', '6930525', '島根県', 'シマネケン', '出雲市', 'イズモシ', '佐田町下橋波', 'サダチョウシモハシナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市佐田町上橋波', '32', '32203', '6930526', '島根県', 'シマネケン', '出雲市', 'イズモシ', '佐田町上橋波', 'サダチョウカミハシナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県大田市', '32', '32205', '6940000', '島根県', 'シマネケン', '大田市', 'オオダシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('85741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県大田市山口町佐津目', '32', '32205', '6940001', '島根県', 'シマネケン', '大田市', 'オオダシ', '山口町佐津目', 'ヤマグチチョウサツメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県大田市山口町山口', '32', '32205', '6940002', '島根県', 'シマネケン', '大田市', 'オオダシ', '山口町山口', 'ヤマグチチョウヤマグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県大田市三瓶町多根', '32', '32205', '6940003', '島根県', 'シマネケン', '大田市', 'オオダシ', '三瓶町多根', 'サンベチョウタネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県大田市三瓶町野城', '32', '32205', '6940004', '島根県', 'シマネケン', '大田市', 'オオダシ', '三瓶町野城', 'サンベチョウノジロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県大田市川合町川合', '32', '32205', '6940011', '島根県', 'シマネケン', '大田市', 'オオダシ', '川合町川合', 'カワイチョウカワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県大田市川合町忍原', '32', '32205', '6940012', '島根県', 'シマネケン', '大田市', 'オオダシ', '川合町忍原', 'カワイチョウオシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県大田市川合町吉永', '32', '32205', '6940013', '島根県', 'シマネケン', '大田市', 'オオダシ', '川合町吉永', 'カワイチョウヨシナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県大田市久利町行恒', '32', '32205', '6940021', '島根県', 'シマネケン', '大田市', 'オオダシ', '久利町行恒', 'クリチョウユキツネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県大田市久利町市原', '32', '32205', '6940022', '島根県', 'シマネケン', '大田市', 'オオダシ', '久利町市原', 'クリチョウイチハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県大田市久利町佐摩', '32', '32205', '6940023', '島根県', 'シマネケン', '大田市', 'オオダシ', '久利町佐摩', 'クリチョウサマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県大田市久利町久利', '32', '32205', '6940024', '島根県', 'シマネケン', '大田市', 'オオダシ', '久利町久利', 'クリチョウクリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県大田市久利町松代', '32', '32205', '6940025', '島根県', 'シマネケン', '大田市', 'オオダシ', '久利町松代', 'クリチョウマツシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県大田市静間町', '32', '32205', '6940031', '島根県', 'シマネケン', '大田市', 'オオダシ', '静間町', 'シズマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県大田市大屋町鬼村', '32', '32205', '6940032', '島根県', 'シマネケン', '大田市', 'オオダシ', '大屋町鬼村', 'オオヤチョウオニムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県大田市大屋町大国', '32', '32205', '6940033', '島根県', 'シマネケン', '大田市', 'オオダシ', '大屋町大国', 'オオヤチョウオオグニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県大田市大屋町大屋', '32', '32205', '6940034', '島根県', 'シマネケン', '大田市', 'オオダシ', '大屋町大屋', 'オオヤチョウオオヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県大田市五十猛町', '32', '32205', '6940035', '島根県', 'シマネケン', '大田市', 'オオダシ', '五十猛町', 'イソタケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県大田市長久町長久', '32', '32205', '6940041', '島根県', 'シマネケン', '大田市', 'オオダシ', '長久町長久', 'ナガヒサチョウナガヒサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県大田市長久町稲用', '32', '32205', '6940042', '島根県', 'シマネケン', '大田市', 'オオダシ', '長久町稲用', 'ナガヒサチョウイナモチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県大田市長久町延里', '32', '32205', '6940043', '島根県', 'シマネケン', '大田市', 'オオダシ', '長久町延里', 'ナガヒサチョウノブサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県大田市長久町土江', '32', '32205', '6940044', '島根県', 'シマネケン', '大田市', 'オオダシ', '長久町土江', 'ナガヒサチョウツチエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県大田市久手町波根西', '32', '32205', '6940051', '島根県', 'シマネケン', '大田市', 'オオダシ', '久手町波根西', 'クテチョウハネニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県大田市久手町刺鹿', '32', '32205', '6940052', '島根県', 'シマネケン', '大田市', 'オオダシ', '久手町刺鹿', 'クテチョウサツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県大田市鳥井町鳥越', '32', '32205', '6940053', '島根県', 'シマネケン', '大田市', 'オオダシ', '鳥井町鳥越', 'トリイチョウトリゴエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県大田市鳥井町鳥井', '32', '32205', '6940054', '島根県', 'シマネケン', '大田市', 'オオダシ', '鳥井町鳥井', 'トリイチョウトリイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県大田市富山町山中押ケ峠', '32', '32205', '6940061', '島根県', 'シマネケン', '大田市', 'オオダシ', '富山町山中', 'トミヤマチョウヤマナカ', null, null, '押ケ峠', 'オシガト');
INSERT INTO `ms_addresses` VALUES ('85767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県大田市大田町野城', '32', '32205', '6940062', '島根県', 'シマネケン', '大田市', 'オオダシ', '大田町野城', 'オオダチョウノジロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県大田市大田町吉永', '32', '32205', '6940063', '島根県', 'シマネケン', '大田市', 'オオダシ', '大田町吉永', 'オオダチョウヨシナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県大田市大田町大田', '32', '32205', '6940064', '島根県', 'シマネケン', '大田市', 'オオダシ', '大田町大田', 'オオダチョウオオダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県大田市三瓶町上山', '32', '32205', '6940221', '島根県', 'シマネケン', '大田市', 'オオダシ', '三瓶町上山', 'サンベチョウウヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県大田市三瓶町志学', '32', '32205', '6940222', '島根県', 'シマネケン', '大田市', 'オオダシ', '三瓶町志学', 'サンベチョウシガク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県大田市三瓶町池田', '32', '32205', '6940223', '島根県', 'シマネケン', '大田市', 'オオダシ', '三瓶町池田', 'サンベチョウイケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県大田市三瓶町小屋原', '32', '32205', '6940224', '島根県', 'シマネケン', '大田市', 'オオダシ', '三瓶町小屋原', 'サンベチョウコヤハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県大田市水上町荻原', '32', '32205', '6940301', '島根県', 'シマネケン', '大田市', 'オオダシ', '水上町荻原', 'ミナカミチョウオギハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県大田市水上町福原', '32', '32205', '6940302', '島根県', 'シマネケン', '大田市', 'オオダシ', '水上町福原', 'ミナカミチョウフクハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県大田市水上町白坏', '32', '32205', '6940303', '島根県', 'シマネケン', '大田市', 'オオダシ', '水上町白坏', 'ミナカミチョウシロツキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県大田市水上町三久須', '32', '32205', '6940304', '島根県', 'シマネケン', '大田市', 'オオダシ', '水上町三久須', 'ミナカミチョウミクス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県大田市大森町', '32', '32205', '6940305', '島根県', 'シマネケン', '大田市', 'オオダシ', '大森町', 'オオモリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県大田市祖式町', '32', '32205', '6940431', '島根県', 'シマネケン', '大田市', 'オオダシ', '祖式町', 'ソジキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県大田市大代町新屋', '32', '32205', '6940432', '島根県', 'シマネケン', '大田市', 'オオダシ', '大代町新屋', 'オオシロチョウニイヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県大田市大代町大家', '32', '32205', '6940433', '島根県', 'シマネケン', '大田市', 'オオダシ', '大代町大家', 'オオシロチョウオオエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県江津市', '32', '32207', '6950000', '島根県', 'シマネケン', '江津市', 'ゴウツシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('85784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県江津市渡津町', '32', '32207', '6950001', '島根県', 'シマネケン', '江津市', 'ゴウツシ', '渡津町', 'ワタヅチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県江津市浅利町', '32', '32207', '6950002', '島根県', 'シマネケン', '江津市', 'ゴウツシ', '浅利町', 'アサリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県江津市松川町下河戸', '32', '32207', '6950003', '島根県', 'シマネケン', '江津市', 'ゴウツシ', '松川町下河戸', 'マツカワチョウシモカワド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県江津市松川町市村', '32', '32207', '6950004', '島根県', 'シマネケン', '江津市', 'ゴウツシ', '松川町市村', 'マツカワチョウイチムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県江津市松川町長良', '32', '32207', '6950005', '島根県', 'シマネケン', '江津市', 'ゴウツシ', '松川町長良', 'マツカワチョウナガラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県江津市松川町八神', '32', '32207', '6950006', '島根県', 'シマネケン', '江津市', 'ゴウツシ', '松川町八神', 'マツカワチョウヤカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県江津市松川町太田', '32', '32207', '6950007', '島根県', 'シマネケン', '江津市', 'ゴウツシ', '松川町太田', 'マツカワチョウオオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県江津市江津町', '32', '32207', '6950011', '島根県', 'シマネケン', '江津市', 'ゴウツシ', '江津町', 'ゴウツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県江津市金田町', '32', '32207', '6950012', '島根県', 'シマネケン', '江津市', 'ゴウツシ', '金田町', 'カネタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県江津市川平町南川上', '32', '32207', '6950013', '島根県', 'シマネケン', '江津市', 'ゴウツシ', '川平町南川上', 'カワヒラチョウミナミカワノボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県江津市川平町平田', '32', '32207', '6950014', '島根県', 'シマネケン', '江津市', 'ゴウツシ', '川平町平田', 'カワヒラチョウヒラタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県江津市島の星町', '32', '32207', '6950015', '島根県', 'シマネケン', '江津市', 'ゴウツシ', '島の星町', 'シマノホシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県江津市嘉久志町', '32', '32207', '6950016', '島根県', 'シマネケン', '江津市', 'ゴウツシ', '嘉久志町', 'カクシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県江津市和木町', '32', '32207', '6950017', '島根県', 'シマネケン', '江津市', 'ゴウツシ', '和木町', 'ワキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県江津市都野津町', '32', '32207', '6950021', '島根県', 'シマネケン', '江津市', 'ゴウツシ', '都野津町', 'ツノヅチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県江津市二宮町羽代', '32', '32207', '6950022', '島根県', 'シマネケン', '江津市', 'ゴウツシ', '二宮町羽代', 'ニノミヤチョウハシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県江津市二宮町神村', '32', '32207', '6950023', '島根県', 'シマネケン', '江津市', 'ゴウツシ', '二宮町神村', 'ニノミヤチョウカムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県江津市二宮町神主', '32', '32207', '6950024', '島根県', 'シマネケン', '江津市', 'ゴウツシ', '二宮町神主', 'ニノミヤチョウカンヌシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市下有福町', '32', '32202', '6950101', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '下有福町', 'シモアリフクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市宇野町', '32', '32202', '6950102', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '宇野町', 'ウノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市大金町', '32', '32202', '6950103', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '大金町', 'オオガネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県江津市千田町', '32', '32207', '6950151', '島根県', 'シマネケン', '江津市', 'ゴウツシ', '千田町', 'チダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県江津市跡市町', '32', '32207', '6950152', '島根県', 'シマネケン', '江津市', 'ゴウツシ', '跡市町', 'アトイチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県江津市清見町', '32', '32207', '6950153', '島根県', 'シマネケン', '江津市', 'ゴウツシ', '清見町', 'セイミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県江津市井沢町', '32', '32207', '6950154', '島根県', 'シマネケン', '江津市', 'ゴウツシ', '井沢町', 'イソウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県江津市有福温泉町本明', '32', '32207', '6950155', '島根県', 'シマネケン', '江津市', 'ゴウツシ', '有福温泉町本明', 'アリフクオンセンチョウホンミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県江津市有福温泉町', '32', '32207', '6950156', '島根県', 'シマネケン', '江津市', 'ゴウツシ', '有福温泉町', 'アリフクオンセンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県邑智郡川本町', '32', '32441', '6960000', '島根県', 'シマネケン', '邑智郡川本町', 'オオチグンカワモトマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('85817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県邑智郡川本町川本', '32', '32441', '6960001', '島根県', 'シマネケン', '邑智郡川本町', 'オオチグンカワモトマチ', '川本', 'カワモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県邑智郡川本町都賀行', '32', '32441', '6960002', '島根県', 'シマネケン', '邑智郡川本町', 'オオチグンカワモトマチ', '都賀行', 'ツガユキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県邑智郡川本町因原', '32', '32441', '6960003', '島根県', 'シマネケン', '邑智郡川本町', 'オオチグンカワモトマチ', '因原', 'インバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県邑智郡川本町川下', '32', '32441', '6960004', '島根県', 'シマネケン', '邑智郡川本町', 'オオチグンカワモトマチ', '川下', 'カワクダリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県邑智郡川本町谷戸', '32', '32441', '6960005', '島根県', 'シマネケン', '邑智郡川本町', 'オオチグンカワモトマチ', '谷戸', 'タンド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県邑智郡川本町久座仁', '32', '32441', '6960006', '島根県', 'シマネケン', '邑智郡川本町', 'オオチグンカワモトマチ', '久座仁', 'クザニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県邑智郡川本町多田', '32', '32441', '6960007', '島根県', 'シマネケン', '邑智郡川本町', 'オオチグンカワモトマチ', '多田', 'タタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県邑智郡川本町川内', '32', '32441', '6960011', '島根県', 'シマネケン', '邑智郡川本町', 'オオチグンカワモトマチ', '川内', 'カワウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県邑智郡川本町小谷', '32', '32441', '6960012', '島根県', 'シマネケン', '邑智郡川本町', 'オオチグンカワモトマチ', '小谷', 'コタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県邑智郡川本町馬野原', '32', '32441', '6960013', '島根県', 'シマネケン', '邑智郡川本町', 'オオチグンカワモトマチ', '馬野原', 'マノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県邑智郡邑南町', '32', '32449', '6960100', '島根県', 'シマネケン', '邑智郡邑南町', 'オオチグンオオナンチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('85828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県邑智郡邑南町井原', '32', '32449', '6960101', '島根県', 'シマネケン', '邑智郡邑南町', 'オオチグンオオナンチョウ', '井原', 'イバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県邑智郡邑南町中野', '32', '32449', '6960102', '島根県', 'シマネケン', '邑智郡邑南町', 'オオチグンオオナンチョウ', '中野', 'ナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県邑智郡邑南町矢上', '32', '32449', '6960103', '島根県', 'シマネケン', '邑智郡邑南町', 'オオチグンオオナンチョウ', '矢上', 'ヤカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県邑智郡邑南町日和', '32', '32449', '6960104', '島根県', 'シマネケン', '邑智郡邑南町', 'オオチグンオオナンチョウ', '日和', 'ヒワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県邑智郡邑南町高水', '32', '32449', '6960131', '島根県', 'シマネケン', '邑智郡邑南町', 'オオチグンオオナンチョウ', '高水', 'コウズイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県邑智郡邑南町鱒渕', '32', '32449', '6960221', '島根県', 'シマネケン', '邑智郡邑南町', 'オオチグンオオナンチョウ', '鱒渕', 'マスブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県邑智郡邑南町下田所', '32', '32449', '6960222', '島根県', 'シマネケン', '邑智郡邑南町', 'オオチグンオオナンチョウ', '下田所', 'シモタドコロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県邑智郡邑南町下亀谷', '32', '32449', '6960223', '島根県', 'シマネケン', '邑智郡邑南町', 'オオチグンオオナンチョウ', '下亀谷', 'シモカメダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県邑智郡邑南町上亀谷', '32', '32449', '6960224', '島根県', 'シマネケン', '邑智郡邑南町', 'オオチグンオオナンチョウ', '上亀谷', 'カミカメダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県邑智郡邑南町上田所', '32', '32449', '6960225', '島根県', 'シマネケン', '邑智郡邑南町', 'オオチグンオオナンチョウ', '上田所', 'カミタドコロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県邑智郡邑南町三日市', '32', '32449', '6960311', '島根県', 'シマネケン', '邑智郡邑南町', 'オオチグンオオナンチョウ', '三日市', 'ミッカイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県邑智郡邑南町出羽', '32', '32449', '6960312', '島根県', 'シマネケン', '邑智郡邑南町', 'オオチグンオオナンチョウ', '出羽', 'イズハ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県邑智郡邑南町山田', '32', '32449', '6960313', '島根県', 'シマネケン', '邑智郡邑南町', 'オオチグンオオナンチョウ', '山田', 'ヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県邑智郡邑南町岩屋', '32', '32449', '6960314', '島根県', 'シマネケン', '邑智郡邑南町', 'オオチグンオオナンチョウ', '岩屋', 'イワヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県邑智郡邑南町大林', '32', '32449', '6960315', '島根県', 'シマネケン', '邑智郡邑南町', 'オオチグンオオナンチョウ', '大林', 'オオバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県邑智郡邑南町久喜', '32', '32449', '6960316', '島根県', 'シマネケン', '邑智郡邑南町', 'オオチグンオオナンチョウ', '久喜', 'クキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県邑智郡邑南町淀原', '32', '32449', '6960317', '島根県', 'シマネケン', '邑智郡邑南町', 'オオチグンオオナンチョウ', '淀原', 'ヨドハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県邑智郡邑南町布施', '32', '32449', '6960401', '島根県', 'シマネケン', '邑智郡邑南町', 'オオチグンオオナンチョウ', '布施', 'フセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県邑智郡邑南町伏谷', '32', '32449', '6960402', '島根県', 'シマネケン', '邑智郡邑南町', 'オオチグンオオナンチョウ', '伏谷', 'フシタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県邑智郡邑南町和田', '32', '32449', '6960403', '島根県', 'シマネケン', '邑智郡邑南町', 'オオチグンオオナンチョウ', '和田', 'ワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県邑智郡邑南町原村', '32', '32449', '6960404', '島根県', 'シマネケン', '邑智郡邑南町', 'オオチグンオオナンチョウ', '原村', 'ハラムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県邑智郡邑南町上原', '32', '32449', '6960405', '島根県', 'シマネケン', '邑智郡邑南町', 'オオチグンオオナンチョウ', '上原', 'カミハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県邑智郡邑南町高見', '32', '32449', '6960406', '島根県', 'シマネケン', '邑智郡邑南町', 'オオチグンオオナンチョウ', '高見', 'タカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県邑智郡邑南町八色石', '32', '32449', '6960407', '島根県', 'シマネケン', '邑智郡邑南町', 'オオチグンオオナンチョウ', '八色石', 'ヤイロイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県邑智郡邑南町阿須那', '32', '32449', '6960501', '島根県', 'シマネケン', '邑智郡邑南町', 'オオチグンオオナンチョウ', '阿須那', 'アスナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県邑智郡邑南町木須田', '32', '32449', '6960502', '島根県', 'シマネケン', '邑智郡邑南町', 'オオチグンオオナンチョウ', '木須田', 'キズタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県邑智郡邑南町宇都井', '32', '32449', '6960503', '島根県', 'シマネケン', '邑智郡邑南町', 'オオチグンオオナンチョウ', '宇都井', 'ウヅイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県邑智郡邑南町今井', '32', '32449', '6960504', '島根県', 'シマネケン', '邑智郡邑南町', 'オオチグンオオナンチョウ', '今井', 'イマイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県邑智郡邑南町戸河内', '32', '32449', '6960505', '島根県', 'シマネケン', '邑智郡邑南町', 'オオチグンオオナンチョウ', '戸河内', 'トガウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県邑智郡邑南町雪田', '32', '32449', '6960506', '島根県', 'シマネケン', '邑智郡邑南町', 'オオチグンオオナンチョウ', '雪田', 'ユキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県邑智郡邑南町上田', '32', '32449', '6960601', '島根県', 'シマネケン', '邑智郡邑南町', 'オオチグンオオナンチョウ', '上田', 'ウエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県邑智郡邑南町上口羽', '32', '32449', '6960602', '島根県', 'シマネケン', '邑智郡邑南町', 'オオチグンオオナンチョウ', '上口羽', 'カミクチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県邑智郡邑南町下口羽', '32', '32449', '6960603', '島根県', 'シマネケン', '邑智郡邑南町', 'オオチグンオオナンチョウ', '下口羽', 'シモクチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県邑智郡美郷町潮村', '32', '32448', '6960701', '島根県', 'シマネケン', '邑智郡美郷町', 'オオチグンミサトチョウ', '潮村', 'ウシオムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県邑智郡美郷町上野', '32', '32448', '6960702', '島根県', 'シマネケン', '邑智郡美郷町', 'オオチグンミサトチョウ', '上野', 'カミノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県邑智郡美郷町都賀西', '32', '32448', '6960703', '島根県', 'シマネケン', '邑智郡美郷町', 'オオチグンミサトチョウ', '都賀西', 'ツガニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県邑智郡美郷町都賀本郷', '32', '32448', '6960704', '島根県', 'シマネケン', '邑智郡美郷町', 'オオチグンミサトチョウ', '都賀本郷', 'ツガホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県邑智郡美郷町都賀行', '32', '32448', '6960705', '島根県', 'シマネケン', '邑智郡美郷町', 'オオチグンミサトチョウ', '都賀行', 'ツガユキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県邑智郡美郷町長藤', '32', '32448', '6960706', '島根県', 'シマネケン', '邑智郡美郷町', 'オオチグンミサトチョウ', '長藤', 'ナガトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県邑智郡美郷町宮内', '32', '32448', '6960711', '島根県', 'シマネケン', '邑智郡美郷町', 'オオチグンミサトチョウ', '宮内', 'ミヤウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県邑智郡美郷町比敷', '32', '32448', '6960712', '島根県', 'シマネケン', '邑智郡美郷町', 'オオチグンミサトチョウ', '比敷', 'ヒジキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県邑智郡美郷町村之郷', '32', '32448', '6960713', '島根県', 'シマネケン', '邑智郡美郷町', 'オオチグンミサトチョウ', '村之郷', 'ムラノゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県邑智郡美郷町別府', '32', '32448', '6961131', '島根県', 'シマネケン', '邑智郡美郷町', 'オオチグンミサトチョウ', '別府', 'ベップ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県邑智郡美郷町志君', '32', '32448', '6961132', '島根県', 'シマネケン', '邑智郡美郷町', 'オオチグンミサトチョウ', '志君', 'シギミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県邑智郡美郷町小林', '32', '32448', '6961133', '島根県', 'シマネケン', '邑智郡美郷町', 'オオチグンミサトチョウ', '小林', 'コバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県邑智郡美郷町惣森', '32', '32448', '6961134', '島根県', 'シマネケン', '邑智郡美郷町', 'オオチグンミサトチョウ', '惣森', 'ソウモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県邑智郡美郷町小松地', '32', '32448', '6961135', '島根県', 'シマネケン', '邑智郡美郷町', 'オオチグンミサトチョウ', '小松地', 'コマツジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県邑智郡美郷町内田', '32', '32448', '6961136', '島根県', 'シマネケン', '邑智郡美郷町', 'オオチグンミサトチョウ', '内田', 'ウチダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県邑智郡美郷町櫨谷', '32', '32448', '6961137', '島根県', 'シマネケン', '邑智郡美郷町', 'オオチグンミサトチョウ', '櫨谷', 'カタラガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県邑智郡美郷町京覧原', '32', '32448', '6961141', '島根県', 'シマネケン', '邑智郡美郷町', 'オオチグンミサトチョウ', '京覧原', 'キョランバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県邑智郡美郷町久喜原', '32', '32448', '6961142', '島根県', 'シマネケン', '邑智郡美郷町', 'オオチグンミサトチョウ', '久喜原', 'クキバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県邑智郡美郷町地頭所', '32', '32448', '6961143', '島根県', 'シマネケン', '邑智郡美郷町', 'オオチグンミサトチョウ', '地頭所', 'ジトウショ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県邑智郡美郷町小谷', '32', '32448', '6961144', '島根県', 'シマネケン', '邑智郡美郷町', 'オオチグンミサトチョウ', '小谷', 'コタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県邑智郡美郷町港', '32', '32448', '6961145', '島根県', 'シマネケン', '邑智郡美郷町', 'オオチグンミサトチョウ', '港', 'ミナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県邑智郡川本町北佐木', '32', '32441', '6961221', '島根県', 'シマネケン', '邑智郡川本町', 'オオチグンカワモトマチ', '北佐木', 'キタサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県邑智郡川本町湯谷', '32', '32441', '6961222', '島根県', 'シマネケン', '邑智郡川本町', 'オオチグンカワモトマチ', '湯谷', 'ユダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県邑智郡川本町三俣', '32', '32441', '6961223', '島根県', 'シマネケン', '邑智郡川本町', 'オオチグンカワモトマチ', '三俣', 'ミマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県邑智郡川本町三原', '32', '32441', '6961224', '島根県', 'シマネケン', '邑智郡川本町', 'オオチグンカワモトマチ', '三原', 'ミハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県邑智郡川本町南佐木', '32', '32441', '6961225', '島根県', 'シマネケン', '邑智郡川本町', 'オオチグンカワモトマチ', '南佐木', 'ミナミサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県邑智郡川本町田窪', '32', '32441', '6961226', '島根県', 'シマネケン', '邑智郡川本町', 'オオチグンカワモトマチ', '田窪', 'タクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市', '32', '32202', '6970000', '島根県', 'シマネケン', '浜田市', 'ハマダシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('85896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市外ノ浦町', '32', '32202', '6970001', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '外ノ浦町', 'トノウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市生湯町', '32', '32202', '6970002', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '生湯町', 'ウブユチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市国分町', '32', '32202', '6970003', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '国分町', 'コクブチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市久代町', '32', '32202', '6970004', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '久代町', 'クシロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市上府町', '32', '32202', '6970005', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '上府町', 'カミコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市下府町', '32', '32202', '6970006', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '下府町', 'シモコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市高佐町', '32', '32202', '6970007', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '高佐町', 'コウサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市後野町', '32', '32202', '6970011', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '後野町', 'ウシロノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市河内町', '32', '32202', '6970012', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '河内町', 'コウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市三階町', '32', '32202', '6970013', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '三階町', 'サンガイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市長見町', '32', '32202', '6970014', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '長見町', 'ナガミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市竹迫町', '32', '32202', '6970015', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '竹迫町', 'タケザコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市野原町', '32', '32202', '6970016', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '野原町', 'ノバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市原井町', '32', '32202', '6970017', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '原井町', 'ハライチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市松原町', '32', '32202', '6970021', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '松原町', 'マツバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市浅井町', '32', '32202', '6970022', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '浅井町', 'アサイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市長沢町', '32', '32202', '6970023', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '長沢町', 'ナガサワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市黒川町', '32', '32202', '6970024', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '黒川町', 'クロカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市琵琶町', '32', '32202', '6970025', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '琵琶町', 'ビワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市田町', '32', '32202', '6970026', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '田町', 'タマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市殿町', '32', '32202', '6970027', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '殿町', 'トノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市紺屋町', '32', '32202', '6970031', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '紺屋町', 'コンヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市牛市町', '32', '32202', '6970032', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '牛市町', 'ウシイチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市朝日町', '32', '32202', '6970033', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '朝日町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市相生町', '32', '32202', '6970034', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '相生町', 'アイオイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市杉戸町', '32', '32202', '6970035', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '杉戸町', 'スギドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市天満町', '32', '32202', '6970036', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '天満町', 'テンマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市新町', '32', '32202', '6970037', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市片庭町', '32', '32202', '6970041', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '片庭町', 'カタニワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市錦町', '32', '32202', '6970042', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '錦町', 'ニシキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市栄町', '32', '32202', '6970043', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市蛭子町', '32', '32202', '6970044', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '蛭子町', 'エビスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市京町', '32', '32202', '6970045', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '京町', 'キョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市真光町', '32', '32202', '6970046', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '真光町', 'シンコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市清水町', '32', '32202', '6970047', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '清水町', 'シミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市瀬戸ケ島町', '32', '32202', '6970051', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '瀬戸ケ島町', 'セトガシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市港町', '32', '32202', '6970052', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '港町', 'ミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市大辻町', '32', '32202', '6970053', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '大辻町', 'オオツジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市高田町', '32', '32202', '6970054', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '高田町', 'タカタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市元浜町', '32', '32202', '6970055', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '元浜町', 'モトハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市原町', '32', '32202', '6970056', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '原町', 'ハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市瀬戸見町', '32', '32202', '6970057', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '瀬戸見町', 'セトミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市笠柄町', '32', '32202', '6970061', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '笠柄町', 'カサガラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市熱田町', '32', '32202', '6970062', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '熱田町', 'アツタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市長浜町', '32', '32202', '6970063', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '長浜町', 'ナガハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市内田町百万騎', '32', '32202', '6970064', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '内田町', 'ウチダチョウ', null, null, '百万騎', 'ヒャクマンキ');
INSERT INTO `ms_addresses` VALUES ('85942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市内村町十文字原', '32', '32202', '6970065', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '内村町', 'ナイムラチョウ', null, null, '十文字原', 'ジュウモンジバラ');
INSERT INTO `ms_addresses` VALUES ('85943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市金城町下来原', '32', '32202', '6970121', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '金城町下来原', 'カナギチョウシモクルバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市金城町上来原', '32', '32202', '6970122', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '金城町上来原', 'カナギチョウカミクルバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市金城町七条', '32', '32202', '6970123', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '金城町七条', 'カナギチョウシチジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市金城町波佐', '32', '32202', '6970211', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '金城町波佐', 'カナギチョウハザ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市金城町長田', '32', '32202', '6970212', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '金城町長田', 'カナギチョウナガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市金城町小国', '32', '32202', '6970213', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '金城町小国', 'カナギチョウオグニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市金城町追原', '32', '32202', '6970301', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '金城町追原', 'カナギチョウオイバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市金城町今福', '32', '32202', '6970302', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '金城町今福', 'カナギチョウイマフク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市金城町久佐', '32', '32202', '6970303', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '金城町久佐', 'カナギチョウクザ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市金城町宇津井', '32', '32202', '6970304', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '金城町宇津井', 'カナギチョウウツイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市金城町入野', '32', '32202', '6970305', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '金城町入野', 'カナギチョウイリノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市佐野町', '32', '32202', '6970311', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '佐野町', 'サノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市宇津井町', '32', '32202', '6970312', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '宇津井町', 'ウツイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市旭町山ノ内', '32', '32202', '6970421', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '旭町山ノ内', 'アサヒチョウヤマノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市旭町本郷', '32', '32202', '6970422', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '旭町本郷', 'アサヒチョウホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市旭町重富', '32', '32202', '6970423', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '旭町重富', 'アサヒチョウシゲトミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市旭町和田', '32', '32202', '6970424', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '旭町和田', 'アサヒチョウワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市旭町今市', '32', '32202', '6970425', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '旭町今市', 'アサヒチョウイマイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市旭町丸原', '32', '32202', '6970426', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '旭町丸原', 'アサヒチョウマルバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市旭町木田', '32', '32202', '6970427', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '旭町木田', 'アサヒチョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市旭町坂本', '32', '32202', '6970431', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '旭町坂本', 'アサヒチョウサカモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市旭町都川', '32', '32202', '6970511', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '旭町都川', 'アサヒチョウツカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市旭町来尾', '32', '32202', '6970512', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '旭町来尾', 'アサヒチョウキタオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市旭町坂本八ツ木', '32', '32202', '6970513', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '旭町坂本', 'アサヒチョウサカモト', null, null, '八ツ木', 'ヤツギ');
INSERT INTO `ms_addresses` VALUES ('85968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市旭町市木', '32', '32202', '6970514', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '旭町市木', 'アサヒチョウイチギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県邑智郡邑南町市木', '32', '32449', '6970631', '島根県', 'シマネケン', '邑智郡邑南町', 'オオチグンオオナンチョウ', '市木', 'イチギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市弥栄町野坂', '32', '32202', '6971121', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '弥栄町野坂', 'ヤサカチョウノサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市弥栄町木都賀', '32', '32202', '6971122', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '弥栄町木都賀', 'ヤサカチョウキツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市弥栄町田野原', '32', '32202', '6971123', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '弥栄町田野原', 'ヤサカチョウタノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市弥栄町栃木', '32', '32202', '6971201', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '弥栄町栃木', 'ヤサカチョウトチギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市弥栄町小坂', '32', '32202', '6971202', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '弥栄町小坂', 'ヤサカチョウオサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市弥栄町高内', '32', '32202', '6971203', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '弥栄町高内', 'ヤサカチョウタカウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市弥栄町門田', '32', '32202', '6971204', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '弥栄町門田', 'ヤサカチョウカドタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市弥栄町長安本郷', '32', '32202', '6971211', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '弥栄町長安本郷', 'ヤサカチョウナガヤスホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市弥栄町三里', '32', '32202', '6971212', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '弥栄町三里', 'ヤサカチョウミサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市弥栄町程原', '32', '32202', '6971213', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '弥栄町程原', 'ヤサカチョウホドハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市弥栄町大坪', '32', '32202', '6971214', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '弥栄町大坪', 'ヤサカチョウオオツボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市弥栄町稲代', '32', '32202', '6971215', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '弥栄町稲代', 'ヤサカチョウイナシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市周布町', '32', '32202', '6971321', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '周布町', 'スフチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市日脚町', '32', '32202', '6971322', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '日脚町', 'ヒナシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市内田町', '32', '32202', '6971323', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '内田町', 'ウチダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市穂出町', '32', '32202', '6971324', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '穂出町', 'ホノデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市吉地町', '32', '32202', '6971325', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '吉地町', 'ヨシジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市治和町', '32', '32202', '6971326', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '治和町', 'チワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市津摩町', '32', '32202', '6971327', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '津摩町', 'ツマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市内村町', '32', '32202', '6971331', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '内村町', 'ナイムラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市田橋町', '32', '32202', '6971332', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '田橋町', 'タバセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市鍋石町', '32', '32202', '6971333', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '鍋石町', 'ナベイシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市櫟田原町', '32', '32202', '6971334', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '櫟田原町', 'イチイタバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市井野町', '32', '32202', '6971335', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '井野町', 'イノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市横山町', '32', '32202', '6971336', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '横山町', 'ヨコヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市西村町', '32', '32202', '6971337', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '西村町', 'ニシムラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('85996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市折居町', '32', '32202', '6971338', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '折居町', 'オリイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県益田市', '32', '32204', '6980000', '島根県', 'シマネケン', '益田市', 'マスダシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('86003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県益田市久城町', '32', '32204', '6980001', '島根県', 'シマネケン', '益田市', 'マスダシ', '久城町', 'クシロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県益田市下本郷町', '32', '32204', '6980002', '島根県', 'シマネケン', '益田市', 'マスダシ', '下本郷町', 'シモホンゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県益田市乙吉町', '32', '32204', '6980003', '島根県', 'シマネケン', '益田市', 'マスダシ', '乙吉町', 'オトヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県益田市東町', '32', '32204', '6980004', '島根県', 'シマネケン', '益田市', 'マスダシ', '東町', 'ヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県益田市本町', '32', '32204', '6980005', '島根県', 'シマネケン', '益田市', 'マスダシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県益田市三宅町', '32', '32204', '6980006', '島根県', 'シマネケン', '益田市', 'マスダシ', '三宅町', 'ミヤケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県益田市昭和町', '32', '32204', '6980007', '島根県', 'シマネケン', '益田市', 'マスダシ', '昭和町', 'ショウワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県益田市染羽町', '32', '32204', '6980011', '島根県', 'シマネケン', '益田市', 'マスダシ', '染羽町', 'ソメバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県益田市大谷町', '32', '32204', '6980012', '島根県', 'シマネケン', '益田市', 'マスダシ', '大谷町', 'オオタニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県益田市久々茂町', '32', '32204', '6980013', '島根県', 'シマネケン', '益田市', 'マスダシ', '久々茂町', 'ククモチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県益田市岩倉町', '32', '32204', '6980014', '島根県', 'シマネケン', '益田市', 'マスダシ', '岩倉町', 'イワクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県益田市栃山町', '32', '32204', '6980015', '島根県', 'シマネケン', '益田市', 'マスダシ', '栃山町', 'トチヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県益田市土井町', '32', '32204', '6980016', '島根県', 'シマネケン', '益田市', 'マスダシ', '土井町', 'ドイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県益田市七尾町', '32', '32204', '6980017', '島根県', 'シマネケン', '益田市', 'マスダシ', '七尾町', 'ナナオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県益田市幸町', '32', '32204', '6980021', '島根県', 'シマネケン', '益田市', 'マスダシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県益田市有明町', '32', '32204', '6980022', '島根県', 'シマネケン', '益田市', 'マスダシ', '有明町', 'アリアケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県益田市常盤町', '32', '32204', '6980023', '島根県', 'シマネケン', '益田市', 'マスダシ', '常盤町', 'トキワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県益田市駅前町', '32', '32204', '6980024', '島根県', 'シマネケン', '益田市', 'マスダシ', '駅前町', 'エキマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県益田市あけぼの西町', '32', '32204', '6980025', '島根県', 'シマネケン', '益田市', 'マスダシ', 'あけぼの西町', 'アケボノニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県益田市あけぼの本町', '32', '32204', '6980026', '島根県', 'シマネケン', '益田市', 'マスダシ', 'あけぼの本町', 'アケボノホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県益田市あけぼの東町', '32', '32204', '6980027', '島根県', 'シマネケン', '益田市', 'マスダシ', 'あけぼの東町', 'アケボノヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県益田市多田町', '32', '32204', '6980031', '島根県', 'シマネケン', '益田市', 'マスダシ', '多田町', 'タダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県益田市水分町', '32', '32204', '6980032', '島根県', 'シマネケン', '益田市', 'マスダシ', '水分町', 'ミズワケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県益田市元町', '32', '32204', '6980033', '島根県', 'シマネケン', '益田市', 'マスダシ', '元町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県益田市赤城町', '32', '32204', '6980034', '島根県', 'シマネケン', '益田市', 'マスダシ', '赤城町', 'アカギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県益田市栄町', '32', '32204', '6980035', '島根県', 'シマネケン', '益田市', 'マスダシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県益田市須子町', '32', '32204', '6980036', '島根県', 'シマネケン', '益田市', 'マスダシ', '須子町', 'スコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県益田市飯田町', '32', '32204', '6980037', '島根県', 'シマネケン', '益田市', 'マスダシ', '飯田町', 'イイダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県益田市高津', '32', '32204', '6980041', '島根県', 'シマネケン', '益田市', 'マスダシ', '高津', 'タカツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県益田市高津町', '32', '32204', '6980041', '島根県', 'シマネケン', '益田市', 'マスダシ', '高津町', 'タカツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県益田市中吉田町', '32', '32204', '6980042', '島根県', 'シマネケン', '益田市', 'マスダシ', '中吉田町', 'ナカヨシダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県益田市中島町', '32', '32204', '6980043', '島根県', 'シマネケン', '益田市', 'マスダシ', '中島町', 'ナカノシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県益田市中須町', '32', '32204', '6980044', '島根県', 'シマネケン', '益田市', 'マスダシ', '中須町', 'ナカズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県益田市内田町石見空港', '32', '32204', '6980051', '島根県', 'シマネケン', '益田市', 'マスダシ', '内田町', 'ウチダチョウ', null, null, '石見空港', 'イワミクウコウ');
INSERT INTO `ms_addresses` VALUES ('86037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県益田市美都町板井川', '32', '32204', '6980201', '島根県', 'シマネケン', '益田市', 'マスダシ', '美都町板井川', 'ミトチョウイタイガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県益田市美都町宇津川', '32', '32204', '6980202', '島根県', 'シマネケン', '益田市', 'マスダシ', '美都町宇津川', 'ミトチョウウヅカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県益田市美都町都茂', '32', '32204', '6980203', '島根県', 'シマネケン', '益田市', 'マスダシ', '美都町都茂', 'ミトチョウツモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県益田市美都町山本', '32', '32204', '6980204', '島根県', 'シマネケン', '益田市', 'マスダシ', '美都町山本', 'ミトチョウヤマモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県益田市美都町三谷', '32', '32204', '6980205', '島根県', 'シマネケン', '益田市', 'マスダシ', '美都町三谷', 'ミトチョウミタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県益田市美都町久原', '32', '32204', '6980206', '島根県', 'シマネケン', '益田市', 'マスダシ', '美都町久原', 'ミトチョウクバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県益田市美都町丸茂', '32', '32204', '6980207', '島根県', 'シマネケン', '益田市', 'マスダシ', '美都町丸茂', 'ミトチョウマルモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県益田市美都町小原', '32', '32204', '6980211', '島根県', 'シマネケン', '益田市', 'マスダシ', '美都町小原', 'ミトチョウコバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県益田市美都町仙道', '32', '32204', '6980212', '島根県', 'シマネケン', '益田市', 'マスダシ', '美都町仙道', 'ミトチョウセンドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県益田市美都町朝倉', '32', '32204', '6980213', '島根県', 'シマネケン', '益田市', 'マスダシ', '美都町朝倉', 'ミトチョウアサクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県益田市美都町笹倉', '32', '32204', '6980214', '島根県', 'シマネケン', '益田市', 'マスダシ', '美都町笹倉', 'ミトチョウササクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県益田市波田町', '32', '32204', '6980411', '島根県', 'シマネケン', '益田市', 'マスダシ', '波田町', 'ハダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県益田市長沢町', '32', '32204', '6980412', '島根県', 'シマネケン', '益田市', 'マスダシ', '長沢町', 'ナガサワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県益田市馬谷町', '32', '32204', '6980413', '島根県', 'シマネケン', '益田市', 'マスダシ', '馬谷町', 'ウマダニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県益田市下波田町', '32', '32204', '6980414', '島根県', 'シマネケン', '益田市', 'マスダシ', '下波田町', 'シモハダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県益田市匹見町道川', '32', '32204', '6981201', '島根県', 'シマネケン', '益田市', 'マスダシ', '匹見町道川', 'ヒキミチョウミチカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県益田市匹見町匹見', '32', '32204', '6981211', '島根県', 'シマネケン', '益田市', 'マスダシ', '匹見町匹見', 'ヒキミチョウヒキミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県益田市匹見町紙祖', '32', '32204', '6981212', '島根県', 'シマネケン', '益田市', 'マスダシ', '匹見町紙祖', 'ヒキミチョウシソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県益田市匹見町落合', '32', '32204', '6981213', '島根県', 'シマネケン', '益田市', 'マスダシ', '匹見町落合', 'ヒキミチョウオチアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県益田市匹見町澄川', '32', '32204', '6981221', '島根県', 'シマネケン', '益田市', 'マスダシ', '匹見町澄川', 'ヒキミチョウスミカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県益田市匹見町広瀬', '32', '32204', '6981222', '島根県', 'シマネケン', '益田市', 'マスダシ', '匹見町広瀬', 'ヒキミチョウヒロセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県益田市匹見町石谷', '32', '32204', '6981223', '島根県', 'シマネケン', '益田市', 'マスダシ', '匹見町石谷', 'ヒキミチョウイシタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県益田市白上町', '32', '32204', '6982141', '島根県', 'シマネケン', '益田市', 'マスダシ', '白上町', 'シラカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県益田市市原町', '32', '32204', '6982142', '島根県', 'シマネケン', '益田市', 'マスダシ', '市原町', 'イチハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県益田市内田町', '32', '32204', '6982143', '島根県', 'シマネケン', '益田市', 'マスダシ', '内田町', 'ウチダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県益田市虫追町', '32', '32204', '6982144', '島根県', 'シマネケン', '益田市', 'マスダシ', '虫追町', 'ムソウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県益田市川登町', '32', '32204', '6982145', '島根県', 'シマネケン', '益田市', 'マスダシ', '川登町', 'カワノボリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県益田市中垣内町', '32', '32204', '6982146', '島根県', 'シマネケン', '益田市', 'マスダシ', '中垣内町', 'ナカガウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県益田市黒周町', '32', '32204', '6982251', '島根県', 'シマネケン', '益田市', 'マスダシ', '黒周町', 'クロスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県益田市柏原町', '32', '32204', '6982252', '島根県', 'シマネケン', '益田市', 'マスダシ', '柏原町', 'カシバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県益田市愛栄町', '32', '32204', '6982253', '島根県', 'シマネケン', '益田市', 'マスダシ', '愛栄町', 'アサカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県益田市桂平町', '32', '32204', '6982254', '島根県', 'シマネケン', '益田市', 'マスダシ', '桂平町', 'カツラヒラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県益田市上黒谷町', '32', '32204', '6982255', '島根県', 'シマネケン', '益田市', 'マスダシ', '上黒谷町', 'カミクロダニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県八束郡東出雲町', '32', '32304', '6990100', '島根県', 'シマネケン', '八束郡東出雲町', 'ヤツカグンヒガシイズモチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('86083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県八束郡東出雲町揖屋町', '32', '32304', '6990101', '島根県', 'シマネケン', '八束郡東出雲町', 'ヤツカグンヒガシイズモチョウ', '揖屋町', 'イヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県八束郡東出雲町下意東', '32', '32304', '6990102', '島根県', 'シマネケン', '八束郡東出雲町', 'ヤツカグンヒガシイズモチョウ', '下意東', 'シモイトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県八束郡東出雲町上意東', '32', '32304', '6990103', '島根県', 'シマネケン', '八束郡東出雲町', 'ヤツカグンヒガシイズモチョウ', '上意東', 'カミイトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県八束郡東出雲町須田', '32', '32304', '6990104', '島根県', 'シマネケン', '八束郡東出雲町', 'ヤツカグンヒガシイズモチョウ', '須田', 'スタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県八束郡東出雲町内馬', '32', '32304', '6990105', '島根県', 'シマネケン', '八束郡東出雲町', 'ヤツカグンヒガシイズモチョウ', '内馬', 'ウチウマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県八束郡東出雲町春日', '32', '32304', '6990106', '島根県', 'シマネケン', '八束郡東出雲町', 'ヤツカグンヒガシイズモチョウ', '春日', 'カスガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県八束郡東出雲町今宮', '32', '32304', '6990107', '島根県', 'シマネケン', '八束郡東出雲町', 'ヤツカグンヒガシイズモチョウ', '今宮', 'イマミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県八束郡東出雲町出雲郷', '32', '32304', '6990108', '島根県', 'シマネケン', '八束郡東出雲町', 'ヤツカグンヒガシイズモチョウ', '出雲郷', 'アダカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県八束郡東出雲町錦浜', '32', '32304', '6990109', '島根県', 'シマネケン', '八束郡東出雲町', 'ヤツカグンヒガシイズモチョウ', '錦浜', 'ニシキハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県八束郡東出雲町錦新町', '32', '32304', '6990110', '島根県', 'シマネケン', '八束郡東出雲町', 'ヤツカグンヒガシイズモチョウ', '錦新町', 'ニシキシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県八束郡東出雲町意宇南', '32', '32304', '6990111', '島根県', 'シマネケン', '八束郡東出雲町', 'ヤツカグンヒガシイズモチョウ', '意宇南', 'イウナン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市玉湯町玉造', '32', '32201', '6990201', '島根県', 'シマネケン', '松江市', 'マツエシ', '玉湯町玉造', 'タマユチョウタマツクリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市玉湯町湯町', '32', '32201', '6990202', '島根県', 'シマネケン', '松江市', 'マツエシ', '玉湯町湯町', 'タマユチョウユマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市玉湯町布志名', '32', '32201', '6990203', '島根県', 'シマネケン', '松江市', 'マツエシ', '玉湯町布志名', 'タマユチョウフジナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市玉湯町林', '32', '32201', '6990204', '島根県', 'シマネケン', '松江市', 'マツエシ', '玉湯町林', 'タマユチョウハヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市玉湯町大谷', '32', '32201', '6990205', '島根県', 'シマネケン', '松江市', 'マツエシ', '玉湯町大谷', 'タマユチョウオオダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市宍道町宍道', '32', '32201', '6990401', '島根県', 'シマネケン', '松江市', 'マツエシ', '宍道町宍道', 'シンジチョウシンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市宍道町白石', '32', '32201', '6990402', '島根県', 'シマネケン', '松江市', 'マツエシ', '宍道町白石', 'シンジチョウハクイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市宍道町西来待', '32', '32201', '6990403', '島根県', 'シマネケン', '松江市', 'マツエシ', '宍道町西来待', 'シンジチョウニシキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市宍道町東来待', '32', '32201', '6990404', '島根県', 'シマネケン', '松江市', 'マツエシ', '宍道町東来待', 'シンジチョウヒガシキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市宍道町上来待', '32', '32201', '6990405', '島根県', 'シマネケン', '松江市', 'マツエシ', '宍道町上来待', 'シンジチョウカミキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市宍道町佐々布', '32', '32201', '6990406', '島根県', 'シマネケン', '松江市', 'マツエシ', '宍道町佐々布', 'シンジチョウサソウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市宍道町伊志見', '32', '32201', '6990407', '島根県', 'シマネケン', '松江市', 'マツエシ', '宍道町伊志見', 'シンジチョウイジミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県松江市宍道町昭和', '32', '32201', '6990408', '島根県', 'シマネケン', '松江市', 'マツエシ', '宍道町昭和', 'シンジチョウショウワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県簸川郡斐川町学頭', '32', '32401', '6990501', '島根県', 'シマネケン', '簸川郡斐川町', 'ヒカワグンヒカワチョウ', '学頭', 'ガクトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県簸川郡斐川町荘原町', '32', '32401', '6990502', '島根県', 'シマネケン', '簸川郡斐川町', 'ヒカワグンヒカワチョウ', '荘原町', 'ショウバラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県簸川郡斐川町神庭', '32', '32401', '6990503', '島根県', 'シマネケン', '簸川郡斐川町', 'ヒカワグンヒカワチョウ', '神庭', 'カンバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県簸川郡斐川町三絡', '32', '32401', '6990504', '島根県', 'シマネケン', '簸川郡斐川町', 'ヒカワグンヒカワチョウ', '三絡', 'ミツガネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県簸川郡斐川町上庄原', '32', '32401', '6990505', '島根県', 'シマネケン', '簸川郡斐川町', 'ヒカワグンヒカワチョウ', '上庄原', 'カミショウバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県簸川郡斐川町沖洲', '32', '32401', '6990551', '島根県', 'シマネケン', '簸川郡斐川町', 'ヒカワグンヒカワチョウ', '沖洲', 'オキノス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県簸川郡斐川町中洲', '32', '32401', '6990552', '島根県', 'シマネケン', '簸川郡斐川町', 'ヒカワグンヒカワチョウ', '中洲', 'ナカノス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県簸川郡斐川町黒目', '32', '32401', '6990553', '島根県', 'シマネケン', '簸川郡斐川町', 'ヒカワグンヒカワチョウ', '黒目', 'クロメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県簸川郡斐川町三分市', '32', '32401', '6990554', '島根県', 'シマネケン', '簸川郡斐川町', 'ヒカワグンヒカワチョウ', '三分市', 'サンブイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県簸川郡斐川町坂田', '32', '32401', '6990555', '島根県', 'シマネケン', '簸川郡斐川町', 'ヒカワグンヒカワチョウ', '坂田', 'サカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県簸川郡斐川町', '32', '32401', '6990600', '島根県', 'シマネケン', '簸川郡斐川町', 'ヒカワグンヒカワチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('86127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県簸川郡斐川町阿宮', '32', '32401', '6990611', '島根県', 'シマネケン', '簸川郡斐川町', 'ヒカワグンヒカワチョウ', '阿宮', 'アグ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県簸川郡斐川町出西', '32', '32401', '6990612', '島根県', 'シマネケン', '簸川郡斐川町', 'ヒカワグンヒカワチョウ', '出西', 'シュツサイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県簸川郡斐川町神氷', '32', '32401', '6990613', '島根県', 'シマネケン', '簸川郡斐川町', 'ヒカワグンヒカワチョウ', '神氷', 'カンピ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県簸川郡斐川町求院', '32', '32401', '6990614', '島根県', 'シマネケン', '簸川郡斐川町', 'ヒカワグンヒカワチョウ', '求院', 'グイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県簸川郡斐川町併川', '32', '32401', '6990615', '島根県', 'シマネケン', '簸川郡斐川町', 'ヒカワグンヒカワチョウ', '併川', 'アイカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県簸川郡斐川町富村', '32', '32401', '6990621', '島根県', 'シマネケン', '簸川郡斐川町', 'ヒカワグンヒカワチョウ', '富村', 'トビムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県簸川郡斐川町名島', '32', '32401', '6990622', '島根県', 'シマネケン', '簸川郡斐川町', 'ヒカワグンヒカワチョウ', '名島', 'ナシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県簸川郡斐川町鳥井', '32', '32401', '6990623', '島根県', 'シマネケン', '簸川郡斐川町', 'ヒカワグンヒカワチョウ', '鳥井', 'トリイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県簸川郡斐川町上直江', '32', '32401', '6990624', '島根県', 'シマネケン', '簸川郡斐川町', 'ヒカワグンヒカワチョウ', '上直江', 'カミナオエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県簸川郡斐川町直江町', '32', '32401', '6990631', '島根県', 'シマネケン', '簸川郡斐川町', 'ヒカワグンヒカワチョウ', '直江町', 'ナオエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県簸川郡斐川町美南', '32', '32401', '6990641', '島根県', 'シマネケン', '簸川郡斐川町', 'ヒカワグンヒカワチョウ', '美南', 'ミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県簸川郡斐川町福富', '32', '32401', '6990642', '島根県', 'シマネケン', '簸川郡斐川町', 'ヒカワグンヒカワチョウ', '福富', 'フクドミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県簸川郡斐川町原鹿', '32', '32401', '6990643', '島根県', 'シマネケン', '簸川郡斐川町', 'ヒカワグンヒカワチョウ', '原鹿', 'ハラシカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県簸川郡斐川町今在家', '32', '32401', '6990644', '島根県', 'シマネケン', '簸川郡斐川町', 'ヒカワグンヒカワチョウ', '今在家', 'イマザイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市大社町杵築東', '32', '32203', '6990701', '島根県', 'シマネケン', '出雲市', 'イズモシ', '大社町杵築東', 'タイシャチョウキヅキヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市大社町杵築北', '32', '32203', '6990702', '島根県', 'シマネケン', '出雲市', 'イズモシ', '大社町杵築北', 'タイシャチョウキヅキキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市大社町杵築南', '32', '32203', '6990711', '島根県', 'シマネケン', '出雲市', 'イズモシ', '大社町杵築南', 'タイシャチョウキヅキミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市大社町修理免', '32', '32203', '6990721', '島根県', 'シマネケン', '出雲市', 'イズモシ', '大社町修理免', 'タイシャチョウシュウリメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市大社町北荒木', '32', '32203', '6990722', '島根県', 'シマネケン', '出雲市', 'イズモシ', '大社町北荒木', 'タイシャチョウキタアラキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市大社町遙堪', '32', '32203', '6990731', '島根県', 'シマネケン', '出雲市', 'イズモシ', '大社町遙堪', 'タイシャチョウヨウカン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市大社町入南', '32', '32203', '6990732', '島根県', 'シマネケン', '出雲市', 'イズモシ', '大社町入南', 'タイシャチョウニュウナン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市大社町菱根', '32', '32203', '6990733', '島根県', 'シマネケン', '出雲市', 'イズモシ', '大社町菱根', 'タイシャチョウヒシネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市大社町中荒木', '32', '32203', '6990741', '島根県', 'シマネケン', '出雲市', 'イズモシ', '大社町中荒木', 'タイシャチョウナカアラキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市大社町杵築西', '32', '32203', '6990751', '島根県', 'シマネケン', '出雲市', 'イズモシ', '大社町杵築西', 'タイシャチョウキヅキニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市大社町鷺浦', '32', '32203', '6990761', '島根県', 'シマネケン', '出雲市', 'イズモシ', '大社町鷺浦', 'タイシャチョウサギウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市大社町鵜峠', '32', '32203', '6990762', '島根県', 'シマネケン', '出雲市', 'イズモシ', '大社町鵜峠', 'タイシャチョウウド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市大社町日御碕', '32', '32203', '6990763', '島根県', 'シマネケン', '出雲市', 'イズモシ', '大社町日御碕', 'タイシャチョウヒノミサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市大社町宇龍', '32', '32203', '6990764', '島根県', 'シマネケン', '出雲市', 'イズモシ', '大社町宇龍', 'タイシャチョウウリュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市湖陵町差海', '32', '32203', '6990811', '島根県', 'シマネケン', '出雲市', 'イズモシ', '湖陵町差海', 'コリョウチョウサシウミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市湖陵町二部', '32', '32203', '6990812', '島根県', 'シマネケン', '出雲市', 'イズモシ', '湖陵町二部', 'コリョウチョウニブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市湖陵町三部', '32', '32203', '6990813', '島根県', 'シマネケン', '出雲市', 'イズモシ', '湖陵町三部', 'コリョウチョウサンブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市湖陵町常楽寺', '32', '32203', '6990814', '島根県', 'シマネケン', '出雲市', 'イズモシ', '湖陵町常楽寺', 'コリョウチョウジョウラクジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市湖陵町畑村', '32', '32203', '6990815', '島根県', 'シマネケン', '出雲市', 'イズモシ', '湖陵町畑村', 'コリョウチョウハタムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市湖陵町大池', '32', '32203', '6990816', '島根県', 'シマネケン', '出雲市', 'イズモシ', '湖陵町大池', 'コリョウチョウオオイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市湖陵町板津', '32', '32203', '6990817', '島根県', 'シマネケン', '出雲市', 'イズモシ', '湖陵町板津', 'コリョウチョウイタヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市大島町', '32', '32203', '6990821', '島根県', 'シマネケン', '出雲市', 'イズモシ', '大島町', 'オオジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市神西沖町', '32', '32203', '6990822', '島根県', 'シマネケン', '出雲市', 'イズモシ', '神西沖町', 'ジンザイオキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市東神西町', '32', '32203', '6990823', '島根県', 'シマネケン', '出雲市', 'イズモシ', '東神西町', 'ヒガシジンザイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市西神西町', '32', '32203', '6990824', '島根県', 'シマネケン', '出雲市', 'イズモシ', '西神西町', 'ニシジンザイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市神西新町', '32', '32203', '6990825', '島根県', 'シマネケン', '出雲市', 'イズモシ', '神西新町', 'ジンザイシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市多伎町久村', '32', '32203', '6990901', '島根県', 'シマネケン', '出雲市', 'イズモシ', '多伎町久村', 'タキチョウクムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市多伎町多岐', '32', '32203', '6990902', '島根県', 'シマネケン', '出雲市', 'イズモシ', '多伎町多岐', 'タキチョウタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市多伎町小田', '32', '32203', '6990903', '島根県', 'シマネケン', '出雲市', 'イズモシ', '多伎町小田', 'タキチョウオダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市多伎町口田儀', '32', '32203', '6990904', '島根県', 'シマネケン', '出雲市', 'イズモシ', '多伎町口田儀', 'タキチョウクチタギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市多伎町奥田儀', '32', '32203', '6990905', '島根県', 'シマネケン', '出雲市', 'イズモシ', '多伎町奥田儀', 'タキチョウオクタギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県出雲市多伎町神原', '32', '32203', '6990906', '島根県', 'シマネケン', '出雲市', 'イズモシ', '多伎町神原', 'タキチョウカンバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県雲南市加茂町大西', '32', '32209', '6991101', '島根県', 'シマネケン', '雲南市', 'ウンナンシ', '加茂町大西', 'カモチョウダイサイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県雲南市加茂町立原', '32', '32209', '6991102', '島根県', 'シマネケン', '雲南市', 'ウンナンシ', '加茂町立原', 'カモチョウタチバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県雲南市加茂町近松', '32', '32209', '6991103', '島根県', 'シマネケン', '雲南市', 'ウンナンシ', '加茂町近松', 'カモチョウチカマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県雲南市加茂町南加茂', '32', '32209', '6991104', '島根県', 'シマネケン', '雲南市', 'ウンナンシ', '加茂町南加茂', 'カモチョウミナミガモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県雲南市加茂町宇治', '32', '32209', '6991105', '島根県', 'シマネケン', '雲南市', 'ウンナンシ', '加茂町宇治', 'カモチョウウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県雲南市加茂町加茂中', '32', '32209', '6991106', '島根県', 'シマネケン', '雲南市', 'ウンナンシ', '加茂町加茂中', 'カモチョウカモナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県雲南市加茂町砂子原', '32', '32209', '6991111', '島根県', 'シマネケン', '雲南市', 'ウンナンシ', '加茂町砂子原', 'カモチョウスナゴハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県雲南市加茂町新宮', '32', '32209', '6991112', '島根県', 'シマネケン', '雲南市', 'ウンナンシ', '加茂町新宮', 'カモチョウシングウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県雲南市加茂町東谷', '32', '32209', '6991113', '島根県', 'シマネケン', '雲南市', 'ウンナンシ', '加茂町東谷', 'カモチョウヒガシダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県雲南市加茂町猪尾', '32', '32209', '6991114', '島根県', 'シマネケン', '雲南市', 'ウンナンシ', '加茂町猪尾', 'カモチョウイノオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県雲南市加茂町岩倉', '32', '32209', '6991115', '島根県', 'シマネケン', '雲南市', 'ウンナンシ', '加茂町岩倉', 'カモチョウイワクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県雲南市加茂町神原', '32', '32209', '6991121', '島根県', 'シマネケン', '雲南市', 'ウンナンシ', '加茂町神原', 'カモチョウカンバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県雲南市加茂町三代', '32', '32209', '6991122', '島根県', 'シマネケン', '雲南市', 'ウンナンシ', '加茂町三代', 'カモチョウミジロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県雲南市加茂町大竹', '32', '32209', '6991123', '島根県', 'シマネケン', '雲南市', 'ウンナンシ', '加茂町大竹', 'カモチョウオオタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県雲南市加茂町延野', '32', '32209', '6991124', '島根県', 'シマネケン', '雲南市', 'ウンナンシ', '加茂町延野', 'カモチョウノブノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県雲南市加茂町大崎', '32', '32209', '6991125', '島根県', 'シマネケン', '雲南市', 'ウンナンシ', '加茂町大崎', 'カモチョウオオサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県雲南市大東町小河内', '32', '32209', '6991201', '島根県', 'シマネケン', '雲南市', 'ウンナンシ', '大東町小河内', 'ダイトウチョウオガワウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県雲南市大東町刈畑', '32', '32209', '6991202', '島根県', 'シマネケン', '雲南市', 'ウンナンシ', '大東町刈畑', 'ダイトウチョウカリハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県雲南市大東町北村', '32', '32209', '6991203', '島根県', 'シマネケン', '雲南市', 'ウンナンシ', '大東町北村', 'ダイトウチョウキタムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県雲南市大東町薦澤', '32', '32209', '6991204', '島根県', 'シマネケン', '雲南市', 'ウンナンシ', '大東町薦澤', 'ダイトウチョウコモザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県雲南市大東町須賀', '32', '32209', '6991205', '島根県', 'シマネケン', '雲南市', 'ウンナンシ', '大東町須賀', 'ダイトウチョウスガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県雲南市大東町南村', '32', '32209', '6991206', '島根県', 'シマネケン', '雲南市', 'ウンナンシ', '大東町南村', 'ダイトウチョウミナミムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県雲南市大東町上久野', '32', '32209', '6991211', '島根県', 'シマネケン', '雲南市', 'ウンナンシ', '大東町上久野', 'ダイトウチョウカミクノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県雲南市大東町下久野', '32', '32209', '6991212', '島根県', 'シマネケン', '雲南市', 'ウンナンシ', '大東町下久野', 'ダイトウチョウシモクノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県雲南市大東町大ケ谷', '32', '32209', '6991213', '島根県', 'シマネケン', '雲南市', 'ウンナンシ', '大東町大ケ谷', 'ダイトウチョウオオカダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県雲南市大東町上佐世', '32', '32209', '6991214', '島根県', 'シマネケン', '雲南市', 'ウンナンシ', '大東町上佐世', 'ダイトウチョウカミザセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県雲南市大東町下佐世', '32', '32209', '6991215', '島根県', 'シマネケン', '雲南市', 'ウンナンシ', '大東町下佐世', 'ダイトウチョウシモザセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県雲南市大東町西阿用', '32', '32209', '6991216', '島根県', 'シマネケン', '雲南市', 'ウンナンシ', '大東町西阿用', 'ダイトウチョウニシアヨウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県雲南市大東町飯田', '32', '32209', '6991221', '島根県', 'シマネケン', '雲南市', 'ウンナンシ', '大東町飯田', 'ダイトウチョウイイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県雲南市大東町岡村', '32', '32209', '6991221', '島根県', 'シマネケン', '雲南市', 'ウンナンシ', '大東町岡村', 'ダイトウチョウオカムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県雲南市大東町川井', '32', '32209', '6991222', '島根県', 'シマネケン', '雲南市', 'ウンナンシ', '大東町川井', 'ダイトウチョウカワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県雲南市大東町下阿用', '32', '32209', '6991223', '島根県', 'シマネケン', '雲南市', 'ウンナンシ', '大東町下阿用', 'ダイトウチョウシモアヨウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県雲南市大東町東阿用', '32', '32209', '6991224', '島根県', 'シマネケン', '雲南市', 'ウンナンシ', '大東町東阿用', 'ダイトウチョウヒガシアヨウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県雲南市大東町遠所', '32', '32209', '6991231', '島根県', 'シマネケン', '雲南市', 'ウンナンシ', '大東町遠所', 'ダイトウチョウエンジョ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県雲南市大東町仁和寺', '32', '32209', '6991232', '島根県', 'シマネケン', '雲南市', 'ウンナンシ', '大東町仁和寺', 'ダイトウチョウニンナジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県雲南市大東町幡屋', '32', '32209', '6991233', '島根県', 'シマネケン', '雲南市', 'ウンナンシ', '大東町幡屋', 'ダイトウチョウハタヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県雲南市大東町前原', '32', '32209', '6991234', '島根県', 'シマネケン', '雲南市', 'ウンナンシ', '大東町前原', 'ダイトウチョウマエバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県雲南市大東町山王寺', '32', '32209', '6991241', '島根県', 'シマネケン', '雲南市', 'ウンナンシ', '大東町山王寺', 'ダイトウチョウサンノウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県雲南市大東町大東下分', '32', '32209', '6991242', '島根県', 'シマネケン', '雲南市', 'ウンナンシ', '大東町大東下分', 'ダイトウチョウダイトウシモブン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県雲南市大東町畑鵯', '32', '32209', '6991243', '島根県', 'シマネケン', '雲南市', 'ウンナンシ', '大東町畑鵯', 'ダイトウチョウハタヒヨドリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県雲南市大東町山田', '32', '32209', '6991244', '島根県', 'シマネケン', '雲南市', 'ウンナンシ', '大東町山田', 'ダイトウチョウヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県雲南市大東町養賀', '32', '32209', '6991245', '島根県', 'シマネケン', '雲南市', 'ウンナンシ', '大東町養賀', 'ダイトウチョウヨウカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県雲南市大東町新庄', '32', '32209', '6991251', '島根県', 'シマネケン', '雲南市', 'ウンナンシ', '大東町新庄', 'ダイトウチョウシンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県雲南市大東町大東', '32', '32209', '6991251', '島根県', 'シマネケン', '雲南市', 'ウンナンシ', '大東町大東', 'ダイトウチョウダイトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県雲南市大東町田中', '32', '32209', '6991252', '島根県', 'シマネケン', '雲南市', 'ウンナンシ', '大東町田中', 'ダイトウチョウタナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県雲南市大東町中湯石', '32', '32209', '6991253', '島根県', 'シマネケン', '雲南市', 'ウンナンシ', '大東町中湯石', 'ダイトウチョウナカユイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県雲南市大東町金成', '32', '32209', '6991261', '島根県', 'シマネケン', '雲南市', 'ウンナンシ', '大東町金成', 'ダイトウチョウカネナリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県雲南市大東町塩田', '32', '32209', '6991262', '島根県', 'シマネケン', '雲南市', 'ウンナンシ', '大東町塩田', 'ダイトウチョウシオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県雲南市大東町篠淵', '32', '32209', '6991263', '島根県', 'シマネケン', '雲南市', 'ウンナンシ', '大東町篠淵', 'ダイトウチョウシノブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県雲南市大東町清田', '32', '32209', '6991264', '島根県', 'シマネケン', '雲南市', 'ウンナンシ', '大東町清田', 'ダイトウチョウセイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県雲南市木次町里方', '32', '32209', '6991311', '島根県', 'シマネケン', '雲南市', 'ウンナンシ', '木次町里方', 'キスキチョウサトガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県雲南市木次町山方', '32', '32209', '6991312', '島根県', 'シマネケン', '雲南市', 'ウンナンシ', '木次町山方', 'キスキチョウヤマガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県雲南市木次町宇谷', '32', '32209', '6991321', '島根県', 'シマネケン', '雲南市', 'ウンナンシ', '木次町宇谷', 'キスキチョウウダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県雲南市木次町寺領', '32', '32209', '6991322', '島根県', 'シマネケン', '雲南市', 'ウンナンシ', '木次町寺領', 'キスキチョウジリョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県雲南市木次町東日登', '32', '32209', '6991323', '島根県', 'シマネケン', '雲南市', 'ウンナンシ', '木次町東日登', 'キスキチョウヒガシヒノボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県雲南市木次町西日登', '32', '32209', '6991324', '島根県', 'シマネケン', '雲南市', 'ウンナンシ', '木次町西日登', 'キスキチョウニシヒノボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県雲南市木次町上熊谷', '32', '32209', '6991331', '島根県', 'シマネケン', '雲南市', 'ウンナンシ', '木次町上熊谷', 'キスキチョウカミクマタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県雲南市木次町木次', '32', '32209', '6991332', '島根県', 'シマネケン', '雲南市', 'ウンナンシ', '木次町木次', 'キスキチョウキスキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県雲南市木次町下熊谷', '32', '32209', '6991333', '島根県', 'シマネケン', '雲南市', 'ウンナンシ', '木次町下熊谷', 'キスキチョウシモクマタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県雲南市木次町新市', '32', '32209', '6991334', '島根県', 'シマネケン', '雲南市', 'ウンナンシ', '木次町新市', 'キスキチョウシンイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県雲南市木次町北原', '32', '32209', '6991341', '島根県', 'シマネケン', '雲南市', 'ウンナンシ', '木次町北原', 'キスキチョウキタハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県雲南市木次町平田', '32', '32209', '6991342', '島根県', 'シマネケン', '雲南市', 'ウンナンシ', '木次町平田', 'キスキチョウヒラタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県雲南市木次町湯村', '32', '32209', '6991343', '島根県', 'シマネケン', '雲南市', 'ウンナンシ', '木次町湯村', 'キスキチョウユムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県雲南市木次町北原尾白', '32', '32209', '6991401', '島根県', 'シマネケン', '雲南市', 'ウンナンシ', '木次町北原', 'キスキチョウキタハラ', null, null, '尾白', 'オジロ');
INSERT INTO `ms_addresses` VALUES ('86247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県仁多郡奥出雲町上三所', '32', '32343', '6991431', '島根県', 'シマネケン', '仁多郡奥出雲町', 'ニタグンオクイズモチョウ', '上三所', 'カミミトコロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県仁多郡奥出雲町馬馳', '32', '32343', '6991432', '島根県', 'シマネケン', '仁多郡奥出雲町', 'ニタグンオクイズモチョウ', '馬馳', 'マバセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県仁多郡奥出雲町八代', '32', '32343', '6991433', '島根県', 'シマネケン', '仁多郡奥出雲町', 'ニタグンオクイズモチョウ', '八代', 'ヤシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県仁多郡奥出雲町佐白', '32', '32343', '6991434', '島根県', 'シマネケン', '仁多郡奥出雲町', 'ニタグンオクイズモチョウ', '佐白', 'サジロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県仁多郡奥出雲町', '32', '32343', '6991500', '島根県', 'シマネケン', '仁多郡奥出雲町', 'ニタグンオクイズモチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('86252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県仁多郡奥出雲町三成', '32', '32343', '6991511', '島根県', 'シマネケン', '仁多郡奥出雲町', 'ニタグンオクイズモチョウ', '三成', 'ミナリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県仁多郡奥出雲町高尾', '32', '32343', '6991512', '島根県', 'シマネケン', '仁多郡奥出雲町', 'ニタグンオクイズモチョウ', '高尾', 'タカオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県仁多郡奥出雲町三沢', '32', '32343', '6991513', '島根県', 'シマネケン', '仁多郡奥出雲町', 'ニタグンオクイズモチョウ', '三沢', 'ミザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県仁多郡奥出雲町河内', '32', '32343', '6991514', '島根県', 'シマネケン', '仁多郡奥出雲町', 'ニタグンオクイズモチョウ', '河内', 'カワチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県仁多郡奥出雲町鴨倉', '32', '32343', '6991515', '島根県', 'シマネケン', '仁多郡奥出雲町', 'ニタグンオクイズモチョウ', '鴨倉', 'カモクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県仁多郡奥出雲町三所', '32', '32343', '6991516', '島根県', 'シマネケン', '仁多郡奥出雲町', 'ニタグンオクイズモチョウ', '三所', 'ミトコロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県仁多郡奥出雲町下阿井宇根路', '32', '32343', '6991517', '島根県', 'シマネケン', '仁多郡奥出雲町', 'ニタグンオクイズモチョウ', '下阿井', 'シモアイ', null, null, '宇根路', 'ウネジ');
INSERT INTO `ms_addresses` VALUES ('86260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県仁多郡奥出雲町上阿井', '32', '32343', '6991621', '島根県', 'シマネケン', '仁多郡奥出雲町', 'ニタグンオクイズモチョウ', '上阿井', 'カミアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県仁多郡奥出雲町下阿井', '32', '32343', '6991622', '島根県', 'シマネケン', '仁多郡奥出雲町', 'ニタグンオクイズモチョウ', '下阿井', 'シモアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県仁多郡奥出雲町亀嵩', '32', '32343', '6991701', '島根県', 'シマネケン', '仁多郡奥出雲町', 'ニタグンオクイズモチョウ', '亀嵩', 'カメダケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県仁多郡奥出雲町郡', '32', '32343', '6991702', '島根県', 'シマネケン', '仁多郡奥出雲町', 'ニタグンオクイズモチョウ', '郡', 'コオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県仁多郡奥出雲町高田', '32', '32343', '6991703', '島根県', 'シマネケン', '仁多郡奥出雲町', 'ニタグンオクイズモチョウ', '高田', 'タカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県仁多郡奥出雲町竹崎', '32', '32343', '6991801', '島根県', 'シマネケン', '仁多郡奥出雲町', 'ニタグンオクイズモチョウ', '竹崎', 'タケザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県仁多郡奥出雲町大呂', '32', '32343', '6991802', '島根県', 'シマネケン', '仁多郡奥出雲町', 'ニタグンオクイズモチョウ', '大呂', 'オオロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県仁多郡奥出雲町八川', '32', '32343', '6991811', '島根県', 'シマネケン', '仁多郡奥出雲町', 'ニタグンオクイズモチョウ', '八川', 'ヤカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県仁多郡奥出雲町大谷', '32', '32343', '6991812', '島根県', 'シマネケン', '仁多郡奥出雲町', 'ニタグンオクイズモチョウ', '大谷', 'オオタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県仁多郡奥出雲町稲原', '32', '32343', '6991821', '島根県', 'シマネケン', '仁多郡奥出雲町', 'ニタグンオクイズモチョウ', '稲原', 'イナハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県仁多郡奥出雲町下横田', '32', '32343', '6991822', '島根県', 'シマネケン', '仁多郡奥出雲町', 'ニタグンオクイズモチョウ', '下横田', 'シモヨコタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県仁多郡奥出雲町中村', '32', '32343', '6991831', '島根県', 'シマネケン', '仁多郡奥出雲町', 'ニタグンオクイズモチョウ', '中村', 'ナカムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県仁多郡奥出雲町横田', '32', '32343', '6991832', '島根県', 'シマネケン', '仁多郡奥出雲町', 'ニタグンオクイズモチョウ', '横田', 'ヨコタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県仁多郡奥出雲町大馬木', '32', '32343', '6991941', '島根県', 'シマネケン', '仁多郡奥出雲町', 'ニタグンオクイズモチョウ', '大馬木', 'オオマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県仁多郡奥出雲町小馬木', '32', '32343', '6991942', '島根県', 'シマネケン', '仁多郡奥出雲町', 'ニタグンオクイズモチョウ', '小馬木', 'コマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県大田市波根町', '32', '32205', '6992211', '島根県', 'シマネケン', '大田市', 'オオダシ', '波根町', 'ハネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県大田市朝山町仙山', '32', '32205', '6992212', '島根県', 'シマネケン', '大田市', 'オオダシ', '朝山町仙山', 'アサヤマチョウセンヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県大田市朝山町朝倉', '32', '32205', '6992213', '島根県', 'シマネケン', '大田市', 'オオダシ', '朝山町朝倉', 'アサヤマチョウアサクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県大田市富山町神原', '32', '32205', '6992214', '島根県', 'シマネケン', '大田市', 'オオダシ', '富山町神原', 'トミヤマチョウカンバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県大田市富山町才坂', '32', '32205', '6992215', '島根県', 'シマネケン', '大田市', 'オオダシ', '富山町才坂', 'トミヤマチョウサイザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県大田市富山町山中', '32', '32205', '6992216', '島根県', 'シマネケン', '大田市', 'オオダシ', '富山町山中', 'トミヤマチョウヤマナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県大田市仁摩町仁万', '32', '32205', '6992301', '島根県', 'シマネケン', '大田市', 'オオダシ', '仁摩町仁万', 'ニマチョウニマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県大田市仁摩町宅野', '32', '32205', '6992302', '島根県', 'シマネケン', '大田市', 'オオダシ', '仁摩町宅野', 'ニマチョウタクノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県大田市仁摩町大国', '32', '32205', '6992303', '島根県', 'シマネケン', '大田市', 'オオダシ', '仁摩町大国', 'ニマチョウオオグニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県大田市仁摩町馬路', '32', '32205', '6992304', '島根県', 'シマネケン', '大田市', 'オオダシ', '仁摩町馬路', 'ニマチョウマジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県大田市仁摩町天河内', '32', '32205', '6992305', '島根県', 'シマネケン', '大田市', 'オオダシ', '仁摩町天河内', 'ニマチョウアマゴウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県大田市温泉津町温泉津', '32', '32205', '6992501', '島根県', 'シマネケン', '大田市', 'オオダシ', '温泉津町温泉津', 'ユノツチョウユノツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県大田市温泉津町湯里', '32', '32205', '6992502', '島根県', 'シマネケン', '大田市', 'オオダシ', '温泉津町湯里', 'ユノツチョウユザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県大田市温泉津町西田', '32', '32205', '6992503', '島根県', 'シマネケン', '大田市', 'オオダシ', '温泉津町西田', 'ユノツチョウニシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県大田市温泉津町荻村', '32', '32205', '6992504', '島根県', 'シマネケン', '大田市', 'オオダシ', '温泉津町荻村', 'ユノツチョウオギムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県大田市温泉津町太田', '32', '32205', '6992505', '島根県', 'シマネケン', '大田市', 'オオダシ', '温泉津町太田', 'ユノツチョウオオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県大田市温泉津町福田', '32', '32205', '6992506', '島根県', 'シマネケン', '大田市', 'オオダシ', '温泉津町福田', 'ユノツチョウフクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県大田市温泉津町井田', '32', '32205', '6992507', '島根県', 'シマネケン', '大田市', 'オオダシ', '温泉津町井田', 'ユノツチョウイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県大田市温泉津町小浜', '32', '32205', '6992511', '島根県', 'シマネケン', '大田市', 'オオダシ', '温泉津町小浜', 'ユノツチョウコハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県大田市温泉津町飯原', '32', '32205', '6992512', '島根県', 'シマネケン', '大田市', 'オオダシ', '温泉津町飯原', 'ユノツチョウハンバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県大田市温泉津町上村', '32', '32205', '6992513', '島根県', 'シマネケン', '大田市', 'オオダシ', '温泉津町上村', 'ユノツチョウカミムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県大田市温泉津町福光', '32', '32205', '6992514', '島根県', 'シマネケン', '大田市', 'オオダシ', '温泉津町福光', 'ユノツチョウフクミツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県大田市温泉津町今浦', '32', '32205', '6992515', '島根県', 'シマネケン', '大田市', 'オオダシ', '温泉津町今浦', 'ユノツチョウイマウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県大田市温泉津町吉浦', '32', '32205', '6992516', '島根県', 'シマネケン', '大田市', 'オオダシ', '温泉津町吉浦', 'ユノツチョウヨシウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県江津市黒松町', '32', '32207', '6992831', '島根県', 'シマネケン', '江津市', 'ゴウツシ', '黒松町', 'クロマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県江津市波積町北', '32', '32207', '6992832', '島根県', 'シマネケン', '江津市', 'ゴウツシ', '波積町北', 'ハヅミチョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県江津市波積町本郷', '32', '32207', '6992833', '島根県', 'シマネケン', '江津市', 'ゴウツシ', '波積町本郷', 'ハヅミチョウホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県江津市波積町南', '32', '32207', '6992834', '島根県', 'シマネケン', '江津市', 'ゴウツシ', '波積町南', 'ハヅミチョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県江津市松川町上津井', '32', '32207', '6992835', '島根県', 'シマネケン', '江津市', 'ゴウツシ', '松川町上津井', 'マツカワチョウカンヅイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県江津市松川町畑田', '32', '32207', '6992836', '島根県', 'シマネケン', '江津市', 'ゴウツシ', '松川町畑田', 'マツカワチョウハタダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県江津市松川町上河戸', '32', '32207', '6992837', '島根県', 'シマネケン', '江津市', 'ゴウツシ', '松川町上河戸', 'マツカワチョウカミカワド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県江津市後地町', '32', '32207', '6992841', '島根県', 'シマネケン', '江津市', 'ゴウツシ', '後地町', 'ウシロジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県江津市都治町', '32', '32207', '6992842', '島根県', 'シマネケン', '江津市', 'ゴウツシ', '都治町', 'ツチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県江津市波子町', '32', '32207', '6993161', '島根県', 'シマネケン', '江津市', 'ゴウツシ', '波子町', 'ハシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県江津市敬川町', '32', '32207', '6993162', '島根県', 'シマネケン', '江津市', 'ゴウツシ', '敬川町', 'ウヤガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市三隅町三隅', '32', '32202', '6993211', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '三隅町三隅', 'ミスミチョウミスミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市三隅町向野田', '32', '32202', '6993212', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '三隅町向野田', 'ミスミチョウムカイノタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市三隅町河内', '32', '32202', '6993213', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '三隅町河内', 'ミスミチョウコウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市三隅町矢原', '32', '32202', '6993214', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '三隅町矢原', 'ミスミチョウヤバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市三隅町井川', '32', '32202', '6993215', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '三隅町井川', 'ミスミチョウイガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市三隅町下古和', '32', '32202', '6993215', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '三隅町下古和', 'ミスミチョウシモコワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市三隅町上古和', '32', '32202', '6993216', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '三隅町上古和', 'ミスミチョウカミコワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市三隅町黒沢', '32', '32202', '6993217', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '三隅町黒沢', 'ミスミチョウクロサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市三隅町東平原', '32', '32202', '6993221', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '三隅町東平原', 'ミスミチョウヒガシヒラバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市三隅町折居', '32', '32202', '6993222', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '三隅町折居', 'ミスミチョウオリイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市三隅町西河内', '32', '32202', '6993223', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '三隅町西河内', 'ミスミチョウサイゴウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市三隅町湊浦', '32', '32202', '6993224', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '三隅町湊浦', 'ミスミチョウミナトウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市三隅町古市場', '32', '32202', '6993225', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '三隅町古市場', 'ミスミチョウフルイチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市三隅町岡見', '32', '32202', '6993226', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '三隅町岡見', 'ミスミチョウオカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市三隅町井野', '32', '32202', '6993301', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '三隅町井野', 'ミスミチョウイノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市三隅町芦谷', '32', '32202', '6993302', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '三隅町芦谷', 'ミスミチョウアシダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県浜田市三隅町室谷', '32', '32202', '6993303', '島根県', 'シマネケン', '浜田市', 'ハマダシ', '三隅町室谷', 'ミスミチョウムロダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県益田市金山町', '32', '32204', '6993501', '島根県', 'シマネケン', '益田市', 'マスダシ', '金山町', 'カネヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県益田市木部町', '32', '32204', '6993502', '島根県', 'シマネケン', '益田市', 'マスダシ', '木部町', 'キベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県益田市下種町', '32', '32204', '6993503', '島根県', 'シマネケン', '益田市', 'マスダシ', '下種町', 'シモタネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県益田市種村町', '32', '32204', '6993504', '島根県', 'シマネケン', '益田市', 'マスダシ', '種村町', 'タネムラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県益田市土田町', '32', '32204', '6993505', '島根県', 'シマネケン', '益田市', 'マスダシ', '土田町', 'ツチダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県益田市西平原町', '32', '32204', '6993506', '島根県', 'シマネケン', '益田市', 'マスダシ', '西平原町', 'ニシヒラバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県益田市津田町', '32', '32204', '6993671', '島根県', 'シマネケン', '益田市', 'マスダシ', '津田町', 'ツダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県益田市赤雁町', '32', '32204', '6993672', '島根県', 'シマネケン', '益田市', 'マスダシ', '赤雁町', 'アカガリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県益田市山折町', '32', '32204', '6993673', '島根県', 'シマネケン', '益田市', 'マスダシ', '山折町', 'ヤマオリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県益田市大草町', '32', '32204', '6993674', '島根県', 'シマネケン', '益田市', 'マスダシ', '大草町', 'オオクサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県益田市乙子町', '32', '32204', '6993675', '島根県', 'シマネケン', '益田市', 'マスダシ', '乙子町', 'オトコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県益田市遠田町', '32', '32204', '6993676', '島根県', 'シマネケン', '益田市', 'マスダシ', '遠田町', 'トウダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県益田市飯浦町', '32', '32204', '6993761', '島根県', 'シマネケン', '益田市', 'マスダシ', '飯浦町', 'イイノウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県益田市小浜町', '32', '32204', '6993762', '島根県', 'シマネケン', '益田市', 'マスダシ', '小浜町', 'コハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県益田市戸田町', '32', '32204', '6993763', '島根県', 'シマネケン', '益田市', 'マスダシ', '戸田町', 'トダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県益田市喜阿弥町', '32', '32204', '6993764', '島根県', 'シマネケン', '益田市', 'マスダシ', '喜阿弥町', 'キアミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県益田市有田町', '32', '32204', '6993765', '島根県', 'シマネケン', '益田市', 'マスダシ', '有田町', 'アリタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県益田市美濃地町', '32', '32204', '6993766', '島根県', 'シマネケン', '益田市', 'マスダシ', '美濃地町', 'ミノジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県江津市桜江町谷住郷', '32', '32207', '6994111', '島根県', 'シマネケン', '江津市', 'ゴウツシ', '桜江町谷住郷', 'サクラエチョウタニジュウゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県江津市桜江町市山', '32', '32207', '6994221', '島根県', 'シマネケン', '江津市', 'ゴウツシ', '桜江町市山', 'サクラエチョウイチヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県江津市桜江町今田', '32', '32207', '6994222', '島根県', 'シマネケン', '江津市', 'ゴウツシ', '桜江町今田', 'サクラエチョウイマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県江津市桜江町後山', '32', '32207', '6994223', '島根県', 'シマネケン', '江津市', 'ゴウツシ', '桜江町後山', 'サクラエチョウウシロヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県江津市桜江町江尾', '32', '32207', '6994224', '島根県', 'シマネケン', '江津市', 'ゴウツシ', '桜江町江尾', 'サクラエチョウエノオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県江津市桜江町小田', '32', '32207', '6994225', '島根県', 'シマネケン', '江津市', 'ゴウツシ', '桜江町小田', 'サクラエチョウオダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県江津市桜江町川戸', '32', '32207', '6994226', '島根県', 'シマネケン', '江津市', 'ゴウツシ', '桜江町川戸', 'サクラエチョウカワド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県邑智郡邑南町日貫', '32', '32449', '6994311', '島根県', 'シマネケン', '邑智郡邑南町', 'オオチグンオオナンチョウ', '日貫', 'ヒヌイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県江津市桜江町長谷', '32', '32207', '6994431', '島根県', 'シマネケン', '江津市', 'ゴウツシ', '桜江町長谷', 'サクラエチョウナガタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県江津市桜江町八戸', '32', '32207', '6994432', '島根県', 'シマネケン', '江津市', 'ゴウツシ', '桜江町八戸', 'サクラエチョウヤト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県江津市桜江町鹿賀', '32', '32207', '6994501', '島根県', 'シマネケン', '江津市', 'ゴウツシ', '桜江町鹿賀', 'サクラエチョウシカガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県江津市桜江町川越', '32', '32207', '6994502', '島根県', 'シマネケン', '江津市', 'ゴウツシ', '桜江町川越', 'サクラエチョウカワゴエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県江津市桜江町田津', '32', '32207', '6994503', '島根県', 'シマネケン', '江津市', 'ゴウツシ', '桜江町田津', 'サクラエチョウタヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県江津市桜江町大貫', '32', '32207', '6994504', '島根県', 'シマネケン', '江津市', 'ゴウツシ', '桜江町大貫', 'サクラエチョウオオヌキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県江津市桜江町坂本', '32', '32207', '6994505', '島根県', 'シマネケン', '江津市', 'ゴウツシ', '桜江町坂本', 'サクラエチョウサカモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県邑智郡美郷町', '32', '32448', '6994600', '島根県', 'シマネケン', '邑智郡美郷町', 'オオチグンミサトチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('86365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県邑智郡美郷町高山', '32', '32448', '6994605', '島根県', 'シマネケン', '邑智郡美郷町', 'オオチグンミサトチョウ', '高山', 'タカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県邑智郡美郷町粕渕', '32', '32448', '6994621', '島根県', 'シマネケン', '邑智郡美郷町', 'オオチグンミサトチョウ', '粕渕', 'カスブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県邑智郡美郷町久保', '32', '32448', '6994622', '島根県', 'シマネケン', '邑智郡美郷町', 'オオチグンミサトチョウ', '久保', 'クボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県邑智郡美郷町野井', '32', '32448', '6994623', '島根県', 'シマネケン', '邑智郡美郷町', 'オオチグンミサトチョウ', '野井', 'ノイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県邑智郡美郷町明塚', '32', '32448', '6994624', '島根県', 'シマネケン', '邑智郡美郷町', 'オオチグンミサトチョウ', '明塚', 'アカツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県邑智郡美郷町簗瀬', '32', '32448', '6994625', '島根県', 'シマネケン', '邑智郡美郷町', 'オオチグンミサトチョウ', '簗瀬', 'ヤナゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県邑智郡美郷町乙原', '32', '32448', '6994626', '島根県', 'シマネケン', '邑智郡美郷町', 'オオチグンミサトチョウ', '乙原', 'オンバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県邑智郡美郷町吾郷', '32', '32448', '6994627', '島根県', 'シマネケン', '邑智郡美郷町', 'オオチグンミサトチョウ', '吾郷', 'アゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県邑智郡美郷町奥山', '32', '32448', '6994631', '島根県', 'シマネケン', '邑智郡美郷町', 'オオチグンミサトチョウ', '奥山', 'オクヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県邑智郡美郷町高畑', '32', '32448', '6994632', '島根県', 'シマネケン', '邑智郡美郷町', 'オオチグンミサトチョウ', '高畑', 'タカハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県邑智郡美郷町湯抱', '32', '32448', '6994633', '島根県', 'シマネケン', '邑智郡美郷町', 'オオチグンミサトチョウ', '湯抱', 'ユガカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県邑智郡美郷町浜原', '32', '32448', '6994701', '島根県', 'シマネケン', '邑智郡美郷町', 'オオチグンミサトチョウ', '浜原', 'ハマハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県邑智郡美郷町上川戸', '32', '32448', '6994702', '島根県', 'シマネケン', '邑智郡美郷町', 'オオチグンミサトチョウ', '上川戸', 'カミカワド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県邑智郡美郷町熊見', '32', '32448', '6994703', '島根県', 'シマネケン', '邑智郡美郷町', 'オオチグンミサトチョウ', '熊見', 'クマミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県邑智郡美郷町信喜', '32', '32448', '6994704', '島根県', 'シマネケン', '邑智郡美郷町', 'オオチグンミサトチョウ', '信喜', 'シキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県邑智郡美郷町滝原', '32', '32448', '6994706', '島根県', 'シマネケン', '邑智郡美郷町', 'オオチグンミサトチョウ', '滝原', 'タキバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県邑智郡美郷町亀村', '32', '32448', '6994707', '島根県', 'シマネケン', '邑智郡美郷町', 'オオチグンミサトチョウ', '亀村', 'カメムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県邑智郡美郷町千原', '32', '32448', '6994711', '島根県', 'シマネケン', '邑智郡美郷町', 'オオチグンミサトチョウ', '千原', 'チハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県邑智郡美郷町九日市', '32', '32448', '6994712', '島根県', 'シマネケン', '邑智郡美郷町', 'オオチグンミサトチョウ', '九日市', 'ココノカイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県邑智郡美郷町酒谷', '32', '32448', '6994713', '島根県', 'シマネケン', '邑智郡美郷町', 'オオチグンミサトチョウ', '酒谷', 'サケダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県邑智郡美郷町片山', '32', '32448', '6994714', '島根県', 'シマネケン', '邑智郡美郷町', 'オオチグンミサトチョウ', '片山', 'カタヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県邑智郡美郷町石原', '32', '32448', '6994715', '島根県', 'シマネケン', '邑智郡美郷町', 'オオチグンミサトチョウ', '石原', 'イシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県益田市左ケ山町', '32', '32204', '6995121', '島根県', 'シマネケン', '益田市', 'マスダシ', '左ケ山町', 'ヒダリガヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県益田市本俣賀町', '32', '32204', '6995122', '島根県', 'シマネケン', '益田市', 'マスダシ', '本俣賀町', 'ホンマタガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県益田市猪木谷町', '32', '32204', '6995123', '島根県', 'シマネケン', '益田市', 'マスダシ', '猪木谷町', 'イノキダニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県益田市薄原町', '32', '32204', '6995124', '島根県', 'シマネケン', '益田市', 'マスダシ', '薄原町', 'ススキバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県益田市白岩町', '32', '32204', '6995125', '島根県', 'シマネケン', '益田市', 'マスダシ', '白岩町', 'シライワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県益田市隅村町', '32', '32204', '6995126', '島根県', 'シマネケン', '益田市', 'マスダシ', '隅村町', 'スミムラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県益田市梅月町', '32', '32204', '6995127', '島根県', 'シマネケン', '益田市', 'マスダシ', '梅月町', 'ウメツキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県益田市安富町', '32', '32204', '6995131', '島根県', 'シマネケン', '益田市', 'マスダシ', '安富町', 'ヤスドミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県益田市横田町', '32', '32204', '6995132', '島根県', 'シマネケン', '益田市', 'マスダシ', '横田町', 'ヨコタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県益田市神田町', '32', '32204', '6995133', '島根県', 'シマネケン', '益田市', 'マスダシ', '神田町', 'カンダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県益田市向横田町', '32', '32204', '6995134', '島根県', 'シマネケン', '益田市', 'マスダシ', '向横田町', 'ムカイヨコタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県鹿足郡津和野町商人', '32', '32501', '6995201', '島根県', 'シマネケン', '鹿足郡津和野町', 'カノアシグンツワノチョウ', '商人', 'アキンド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県鹿足郡津和野町左鐙', '32', '32501', '6995202', '島根県', 'シマネケン', '鹿足郡津和野町', 'カノアシグンツワノチョウ', '左鐙', 'サブミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県鹿足郡津和野町相撲ケ原', '32', '32501', '6995203', '島根県', 'シマネケン', '鹿足郡津和野町', 'カノアシグンツワノチョウ', '相撲ケ原', 'スモウガハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県鹿足郡津和野町須川', '32', '32501', '6995204', '島根県', 'シマネケン', '鹿足郡津和野町', 'カノアシグンツワノチョウ', '須川', 'スガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県鹿足郡津和野町瀧谷', '32', '32501', '6995205', '島根県', 'シマネケン', '鹿足郡津和野町', 'カノアシグンツワノチョウ', '瀧谷', 'タキダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県鹿足郡津和野町瀧元', '32', '32501', '6995206', '島根県', 'シマネケン', '鹿足郡津和野町', 'カノアシグンツワノチョウ', '瀧元', 'タキモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県鹿足郡津和野町枕瀬', '32', '32501', '6995207', '島根県', 'シマネケン', '鹿足郡津和野町', 'カノアシグンツワノチョウ', '枕瀬', 'マクラセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県鹿足郡津和野町青原', '32', '32501', '6995211', '島根県', 'シマネケン', '鹿足郡津和野町', 'カノアシグンツワノチョウ', '青原', 'アオハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県鹿足郡津和野町河村', '32', '32501', '6995212', '島根県', 'シマネケン', '鹿足郡津和野町', 'カノアシグンツワノチョウ', '河村', 'カワムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県鹿足郡津和野町添谷', '32', '32501', '6995213', '島根県', 'シマネケン', '鹿足郡津和野町', 'カノアシグンツワノチョウ', '添谷', 'ソエダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県鹿足郡津和野町溪村', '32', '32501', '6995214', '島根県', 'シマネケン', '鹿足郡津和野町', 'カノアシグンツワノチョウ', '溪村', 'タニムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県鹿足郡津和野町冨田', '32', '32501', '6995215', '島根県', 'シマネケン', '鹿足郡津和野町', 'カノアシグンツワノチョウ', '冨田', 'トミタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県鹿足郡津和野町池村', '32', '32501', '6995216', '島根県', 'シマネケン', '鹿足郡津和野町', 'カノアシグンツワノチョウ', '池村', 'イケムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県鹿足郡津和野町柳村', '32', '32501', '6995217', '島根県', 'シマネケン', '鹿足郡津和野町', 'カノアシグンツワノチョウ', '柳村', 'ヤナギムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県鹿足郡津和野町日原', '32', '32501', '6995221', '島根県', 'シマネケン', '鹿足郡津和野町', 'カノアシグンツワノチョウ', '日原', 'ニチハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県鹿足郡吉賀町柿木村柿木', '32', '32505', '6995301', '島根県', 'シマネケン', '鹿足郡吉賀町', 'カノアシグンヨシカチョウ', '柿木村柿木', 'カキノキムラカキノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県鹿足郡吉賀町柿木村福川', '32', '32505', '6995302', '島根県', 'シマネケン', '鹿足郡吉賀町', 'カノアシグンヨシカチョウ', '柿木村福川', 'カキノキムラフクガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県鹿足郡吉賀町柿木村椛谷', '32', '32505', '6995303', '島根県', 'シマネケン', '鹿足郡吉賀町', 'カノアシグンヨシカチョウ', '柿木村椛谷', 'カキノキムラカバタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県鹿足郡吉賀町柿木村白谷', '32', '32505', '6995304', '島根県', 'シマネケン', '鹿足郡吉賀町', 'カノアシグンヨシカチョウ', '柿木村白谷', 'カキノキムラシラタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県鹿足郡吉賀町柿木村下須', '32', '32505', '6995305', '島根県', 'シマネケン', '鹿足郡吉賀町', 'カノアシグンヨシカチョウ', '柿木村下須', 'カキノキムラシモス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県鹿足郡吉賀町柿木村大野原', '32', '32505', '6995306', '島根県', 'シマネケン', '鹿足郡吉賀町', 'カノアシグンヨシカチョウ', '柿木村大野原', 'カキノキムラオオノバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県鹿足郡吉賀町柿木村木部谷', '32', '32505', '6995307', '島根県', 'シマネケン', '鹿足郡吉賀町', 'カノアシグンヨシカチョウ', '柿木村木部谷', 'カキノキムラキベダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県鹿足郡吉賀町', '32', '32505', '6995500', '島根県', 'シマネケン', '鹿足郡吉賀町', 'カノアシグンヨシカチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('86423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県鹿足郡吉賀町上高尻', '32', '32505', '6995501', '島根県', 'シマネケン', '鹿足郡吉賀町', 'カノアシグンヨシカチョウ', '上高尻', 'カミタカジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県鹿足郡吉賀町田野原', '32', '32505', '6995502', '島根県', 'シマネケン', '鹿足郡吉賀町', 'カノアシグンヨシカチョウ', '田野原', 'タノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県鹿足郡吉賀町樋口', '32', '32505', '6995503', '島根県', 'シマネケン', '鹿足郡吉賀町', 'カノアシグンヨシカチョウ', '樋口', 'ヒグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県鹿足郡吉賀町蔵木', '32', '32505', '6995504', '島根県', 'シマネケン', '鹿足郡吉賀町', 'カノアシグンヨシカチョウ', '蔵木', 'クラギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県鹿足郡吉賀町九郎原', '32', '32505', '6995505', '島根県', 'シマネケン', '鹿足郡吉賀町', 'カノアシグンヨシカチョウ', '九郎原', 'クロウバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県鹿足郡吉賀町有飯', '32', '32505', '6995506', '島根県', 'シマネケン', '鹿足郡吉賀町', 'カノアシグンヨシカチョウ', '有飯', 'アリイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県鹿足郡吉賀町下高尻', '32', '32505', '6995507', '島根県', 'シマネケン', '鹿足郡吉賀町', 'カノアシグンヨシカチョウ', '下高尻', 'シモタカジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県鹿足郡吉賀町立戸', '32', '32505', '6995511', '島根県', 'シマネケン', '鹿足郡吉賀町', 'カノアシグンヨシカチョウ', '立戸', 'タチド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県鹿足郡吉賀町広石', '32', '32505', '6995512', '島根県', 'シマネケン', '鹿足郡吉賀町', 'カノアシグンヨシカチョウ', '広石', 'ヒロイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県鹿足郡吉賀町六日市', '32', '32505', '6995513', '島根県', 'シマネケン', '鹿足郡吉賀町', 'カノアシグンヨシカチョウ', '六日市', 'ムイカイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県鹿足郡吉賀町立河内', '32', '32505', '6995514', '島根県', 'シマネケン', '鹿足郡吉賀町', 'カノアシグンヨシカチョウ', '立河内', 'タチゴウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県鹿足郡吉賀町幸地', '32', '32505', '6995515', '島根県', 'シマネケン', '鹿足郡吉賀町', 'カノアシグンヨシカチョウ', '幸地', 'コウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県鹿足郡吉賀町沢田', '32', '32505', '6995516', '島根県', 'シマネケン', '鹿足郡吉賀町', 'カノアシグンヨシカチョウ', '沢田', 'サワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県鹿足郡吉賀町注連川', '32', '32505', '6995517', '島根県', 'シマネケン', '鹿足郡吉賀町', 'カノアシグンヨシカチョウ', '注連川', 'シメガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県鹿足郡吉賀町真田', '32', '32505', '6995521', '島根県', 'シマネケン', '鹿足郡吉賀町', 'カノアシグンヨシカチョウ', '真田', 'サナダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県鹿足郡吉賀町七日市', '32', '32505', '6995522', '島根県', 'シマネケン', '鹿足郡吉賀町', 'カノアシグンヨシカチョウ', '七日市', 'ナヌカイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県鹿足郡吉賀町朝倉', '32', '32505', '6995523', '島根県', 'シマネケン', '鹿足郡吉賀町', 'カノアシグンヨシカチョウ', '朝倉', 'アサクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県鹿足郡吉賀町蓼野', '32', '32505', '6995524', '島根県', 'シマネケン', '鹿足郡吉賀町', 'カノアシグンヨシカチョウ', '蓼野', 'タデノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県鹿足郡吉賀町抜月', '32', '32505', '6995525', '島根県', 'シマネケン', '鹿足郡吉賀町', 'カノアシグンヨシカチョウ', '抜月', 'ヌクツキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県鹿足郡津和野町', '32', '32501', '6995600', '島根県', 'シマネケン', '鹿足郡津和野町', 'カノアシグンツワノチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('86443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県鹿足郡津和野町商人', '32', '32501', '6995601', '島根県', 'シマネケン', '鹿足郡津和野町', 'カノアシグンツワノチョウ', '商人', 'アキンド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県鹿足郡津和野町直地', '32', '32501', '6995602', '島根県', 'シマネケン', '鹿足郡津和野町', 'カノアシグンツワノチョウ', '直地', 'タダチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県鹿足郡津和野町笹山', '32', '32501', '6995603', '島根県', 'シマネケン', '鹿足郡津和野町', 'カノアシグンツワノチョウ', '笹山', 'ササヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県鹿足郡津和野町森村', '32', '32501', '6995604', '島根県', 'シマネケン', '鹿足郡津和野町', 'カノアシグンツワノチョウ', '森村', 'モリムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県鹿足郡津和野町後田', '32', '32501', '6995605', '島根県', 'シマネケン', '鹿足郡津和野町', 'カノアシグンツワノチョウ', '後田', 'ウシロダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県鹿足郡津和野町寺田', '32', '32501', '6995606', '島根県', 'シマネケン', '鹿足郡津和野町', 'カノアシグンツワノチョウ', '寺田', 'テラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県鹿足郡津和野町耕田', '32', '32501', '6995607', '島根県', 'シマネケン', '鹿足郡津和野町', 'カノアシグンツワノチョウ', '耕田', 'コウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県鹿足郡津和野町町田', '32', '32501', '6995611', '島根県', 'シマネケン', '鹿足郡津和野町', 'カノアシグンツワノチョウ', '町田', 'マチダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県鹿足郡津和野町中座', '32', '32501', '6995612', '島根県', 'シマネケン', '鹿足郡津和野町', 'カノアシグンツワノチョウ', '中座', 'ナカザ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県鹿足郡津和野町鷲原', '32', '32501', '6995613', '島根県', 'シマネケン', '鹿足郡津和野町', 'カノアシグンツワノチョウ', '鷲原', 'ワシバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県鹿足郡津和野町高峯', '32', '32501', '6995614', '島根県', 'シマネケン', '鹿足郡津和野町', 'カノアシグンツワノチョウ', '高峯', 'タカミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県鹿足郡津和野町名賀', '32', '32501', '6995615', '島根県', 'シマネケン', '鹿足郡津和野町', 'カノアシグンツワノチョウ', '名賀', 'ナヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県鹿足郡津和野町部栄', '32', '32501', '6995616', '島根県', 'シマネケン', '鹿足郡津和野町', 'カノアシグンツワノチョウ', '部栄', 'ブサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県鹿足郡津和野町田二穂', '32', '32501', '6995617', '島根県', 'シマネケン', '鹿足郡津和野町', 'カノアシグンツワノチョウ', '田二穂', 'タニホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県鹿足郡津和野町内美', '32', '32501', '6995621', '島根県', 'シマネケン', '鹿足郡津和野町', 'カノアシグンツワノチョウ', '内美', 'ナイミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県鹿足郡津和野町邑輝', '32', '32501', '6995622', '島根県', 'シマネケン', '鹿足郡津和野町', 'カノアシグンツワノチョウ', '邑輝', 'ムラキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県鹿足郡津和野町中山', '32', '32501', '6995631', '島根県', 'シマネケン', '鹿足郡津和野町', 'カノアシグンツワノチョウ', '中山', 'ナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県鹿足郡津和野町豊稼', '32', '32501', '6995632', '島根県', 'シマネケン', '鹿足郡津和野町', 'カノアシグンツワノチョウ', '豊稼', 'トヨカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県鹿足郡津和野町長福', '32', '32501', '6995633', '島根県', 'シマネケン', '鹿足郡津和野町', 'カノアシグンツワノチョウ', '長福', 'ナガフク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県鹿足郡津和野町中川', '32', '32501', '6995634', '島根県', 'シマネケン', '鹿足郡津和野町', 'カノアシグンツワノチョウ', '中川', 'ナカガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県鹿足郡津和野町山下', '32', '32501', '6995635', '島根県', 'シマネケン', '鹿足郡津和野町', 'カノアシグンツワノチョウ', '山下', 'ヤマシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県鹿足郡津和野町中曽野', '32', '32501', '6995636', '島根県', 'シマネケン', '鹿足郡津和野町', 'カノアシグンツワノチョウ', '中曽野', 'ナカソノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '島根県鹿足郡津和野町吹野', '32', '32501', '6995637', '島根県', 'シマネケン', '鹿足郡津和野町', 'カノアシグンツワノチョウ', '吹野', 'フキノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市', '01', '01204', '0700000', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('86468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市', '33', '33201', '7000000', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('86469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市宿', '33', '33201', '7000001', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '宿', 'シュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市宿本町', '33', '33201', '7000002', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '宿本町', 'シュクホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市半田町', '33', '33201', '7000003', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '半田町', 'ハンダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市法界院', '33', '33201', '7000004', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '法界院', 'ホウカイイン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市理大町', '33', '33201', '7000005', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '理大町', 'リダイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市新富1条', '01', '01204', '0700001', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '新富1条', 'シントミ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市学南町', '33', '33201', '7000011', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '学南町', 'ガクナンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市いずみ町', '33', '33201', '7000012', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', 'いずみ町', 'イズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市伊福町', '33', '33201', '7000013', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '伊福町', 'イフクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市津倉町', '33', '33201', '7000014', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '津倉町', 'ツクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市京山', '33', '33201', '7000015', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '京山', 'キョウヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市伊島町', '33', '33201', '7000016', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '伊島町', 'イシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市伊島北町', '33', '33201', '7000017', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '伊島北町', 'イシマキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市新富2条', '01', '01204', '0700002', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '新富2条', 'シントミ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市国体町', '33', '33201', '7000021', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '国体町', 'コクタイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市岩田町', '33', '33201', '7000022', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '岩田町', 'イワタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市駅前町', '33', '33201', '7000023', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '駅前町', 'エキマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市駅元町', '33', '33201', '7000024', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '駅元町', 'エキモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市寿町', '33', '33201', '7000025', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '寿町', 'コトブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市奉還町', '33', '33201', '7000026', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '奉還町', 'ホウカンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市清心町', '33', '33201', '7000027', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '清心町', 'セイシンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市絵図町', '33', '33201', '7000028', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '絵図町', 'エズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市新富3条', '01', '01204', '0700003', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '新富3条', 'シントミ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市富町', '33', '33201', '7000031', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '富町', 'トミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市昭和町', '33', '33201', '7000032', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '昭和町', 'ショウワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市島田本町', '33', '33201', '7000033', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '島田本町', 'シマダホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市高柳東町', '33', '33201', '7000034', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '高柳東町', 'タカヤナギヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市高柳西町', '33', '33201', '7000035', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '高柳西町', 'タカヤナギニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市岩井宮裏', '33', '33201', '7000041', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '岩井宮裏', 'イワイミヤウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市三門東町', '33', '33201', '7000042', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '三門東町', 'ミカドヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市三門中町', '33', '33201', '7000043', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '三門中町', 'ミカドナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市三門西町', '33', '33201', '7000044', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '三門西町', 'ミカドニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市葵町', '33', '33201', '7000045', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '葵町', 'アオイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市岩井', '33', '33201', '7000046', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '岩井', 'イワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市関西町', '33', '33201', '7000047', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '関西町', 'カンゼイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市下伊福上町', '33', '33201', '7000051', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '下伊福上町', 'シモイフクカミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市下伊福', '33', '33201', '7000052', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '下伊福', 'シモイフク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市下伊福本町', '33', '33201', '7000053', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '下伊福本町', 'シモイフクホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市下伊福西町', '33', '33201', '7000054', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '下伊福西町', 'シモイフクニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市西崎', '33', '33201', '7000055', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '西崎', 'ニシザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市西崎本町', '33', '33201', '7000056', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '西崎本町', 'ニシザキホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市大安寺西町', '33', '33201', '7000061', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '大安寺西町', 'ダイアンジニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市大安寺中町', '33', '33201', '7000062', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '大安寺中町', 'ダイアンジナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市大安寺東町', '33', '33201', '7000063', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '大安寺東町', 'ダイアンジヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市大安寺南町', '33', '33201', '7000064', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '大安寺南町', 'ダイアンジミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市野殿東町', '33', '33201', '7000065', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '野殿東町', 'ノドノヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市野殿西町', '33', '33201', '7000066', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '野殿西町', 'ノドノニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市西野山町', '33', '33201', '7000067', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '西野山町', 'ニシノヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市東野山町', '33', '33201', '7000068', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '東野山町', 'ヒガシノヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市谷万成', '33', '33201', '7000071', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '谷万成', 'タニマンナリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市万成東町', '33', '33201', '7000072', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '万成東町', 'マンナリヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市万成西町', '33', '33201', '7000073', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '万成西町', 'マンナリニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市矢坂東町', '33', '33201', '7000074', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '矢坂東町', 'ヤサカヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市矢坂本町', '33', '33201', '7000075', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '矢坂本町', 'ヤサカホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市矢坂西町', '33', '33201', '7000076', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '矢坂西町', 'ヤサカニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市津島福居', '33', '33201', '7000080', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '津島福居', 'ツシマフクイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市津島東', '33', '33201', '7000081', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '津島東', 'ツシマヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市津島中', '33', '33201', '7000082', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '津島中', 'ツシマナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市津島新野', '33', '33201', '7000083', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '津島新野', 'ツシマニイノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市津島桑の木町', '33', '33201', '7000084', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '津島桑の木町', 'ツシマクワノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市津島南', '33', '33201', '7000085', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '津島南', 'ツシマミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市津島西坂', '33', '33201', '7000086', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '津島西坂', 'ツシマニシザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市津島京町', '33', '33201', '7000087', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '津島京町', 'ツシマキョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市津島笹が瀬', '33', '33201', '7000088', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '津島笹が瀬', 'ツシマササガセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市津島本町', '33', '33201', '7000089', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '津島本町', 'ツシマホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区中沼1条', '01', '01103', '0070001', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '中沼1条', 'ナカヌマ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市大雪通', '01', '01204', '0700010', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '大雪通', 'タイセツドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市パルプ町1条', '01', '01204', '0700011', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', 'パルプ町1条', 'パルプチョウ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市パルプ町2条', '01', '01204', '0700012', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', 'パルプ町2条', 'パルプチョウ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市パルプ町', '01', '01204', '0700013', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', 'パルプ町', 'パルプチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市新星町', '01', '01204', '0700014', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '新星町', 'シンセイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区中沼2条', '01', '01103', '0070002', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '中沼2条', 'ナカヌマ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市東1条', '01', '01204', '0700021', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '東1条', 'ヒガシ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市東2条', '01', '01204', '0700022', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '東2条', 'ヒガシ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市東3条', '01', '01204', '0700023', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '東3条', 'ヒガシ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市東4条', '01', '01204', '0700024', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '東4条', 'ヒガシ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市東5条', '01', '01204', '0700025', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '東5条', 'ヒガシ05ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市東6条', '01', '01204', '0700026', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '東6条', 'ヒガシ06ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市東7条', '01', '01204', '0700027', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '東7条', 'ヒガシ07ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市東8条', '01', '01204', '0700028', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '東8条', 'ヒガシ08ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市金星町', '01', '01204', '0700029', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '金星町', 'キンセイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区中沼3条', '01', '01103', '0070003', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '中沼3条', 'ナカヌマ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市宮下通1丁目', '01', '01204', '0700030', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '宮下通', 'ミヤシタドオリ', null, null, '1丁目', '01チョウメ');
INSERT INTO `ms_addresses` VALUES ('86552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市宮下通2丁目', '01', '01204', '0700030', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '宮下通', 'ミヤシタドオリ', null, null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('86553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市宮下通3丁目', '01', '01204', '0700030', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '宮下通', 'ミヤシタドオリ', null, null, '3丁目', '03チョウメ');
INSERT INTO `ms_addresses` VALUES ('86554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市宮下通4丁目', '01', '01204', '0700030', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '宮下通', 'ミヤシタドオリ', null, null, '4丁目', '04チョウメ');
INSERT INTO `ms_addresses` VALUES ('86555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市宮下通5丁目', '01', '01204', '0700030', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '宮下通', 'ミヤシタドオリ', null, null, '5丁目', '05チョウメ');
INSERT INTO `ms_addresses` VALUES ('86556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市宮下通6丁目', '01', '01204', '0700030', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '宮下通', 'ミヤシタドオリ', null, null, '6丁目', '06チョウメ');
INSERT INTO `ms_addresses` VALUES ('86557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市宮下通7丁目', '01', '01204', '0700030', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '宮下通', 'ミヤシタドオリ', null, null, '7丁目', '07チョウメ');
INSERT INTO `ms_addresses` VALUES ('86558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市宮下通8丁目', '01', '01204', '0700030', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '宮下通', 'ミヤシタドオリ', null, null, '8丁目', '08チョウメ');
INSERT INTO `ms_addresses` VALUES ('86559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市宮下通9丁目', '01', '01204', '0700030', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '宮下通', 'ミヤシタドオリ', null, null, '9丁目', '09チョウメ');
INSERT INTO `ms_addresses` VALUES ('86560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市宮下通10丁目', '01', '01204', '0700030', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '宮下通', 'ミヤシタドオリ', null, null, '10丁目', '10チョウメ');
INSERT INTO `ms_addresses` VALUES ('86561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市宮下通11丁目', '01', '01204', '0700030', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '宮下通', 'ミヤシタドオリ', null, null, '11丁目', '11チョウメ');
INSERT INTO `ms_addresses` VALUES ('86562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市宮下通12丁目', '01', '01204', '0700030', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '宮下通', 'ミヤシタドオリ', null, null, '12丁目', '12チョウメ');
INSERT INTO `ms_addresses` VALUES ('86563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市宮下通13丁目', '01', '01204', '0700030', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '宮下通', 'ミヤシタドオリ', null, null, '13丁目', '13チョウメ');
INSERT INTO `ms_addresses` VALUES ('86564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市宮下通14丁目', '01', '01204', '0700030', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '宮下通', 'ミヤシタドオリ', null, null, '14丁目', '14チョウメ');
INSERT INTO `ms_addresses` VALUES ('86565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市宮下通15丁目', '01', '01204', '0700030', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '宮下通', 'ミヤシタドオリ', null, null, '15丁目', '15チョウメ');
INSERT INTO `ms_addresses` VALUES ('86566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市宮下通16丁目', '01', '01204', '0700030', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '宮下通', 'ミヤシタドオリ', null, null, '16丁目', '16チョウメ');
INSERT INTO `ms_addresses` VALUES ('86567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市宮下通17丁目', '01', '01204', '0700030', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '宮下通', 'ミヤシタドオリ', null, null, '17丁目', '17チョウメ');
INSERT INTO `ms_addresses` VALUES ('86568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市1条通1丁目', '01', '01204', '0700031', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '1条通', '01ジョウドオリ', null, null, '1丁目', '01チョウメ');
INSERT INTO `ms_addresses` VALUES ('86569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市1条通2丁目', '01', '01204', '0700031', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '1条通', '01ジョウドオリ', null, null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('86570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市1条通3丁目', '01', '01204', '0700031', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '1条通', '01ジョウドオリ', null, null, '3丁目', '03チョウメ');
INSERT INTO `ms_addresses` VALUES ('86571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市1条通4丁目', '01', '01204', '0700031', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '1条通', '01ジョウドオリ', null, null, '4丁目', '04チョウメ');
INSERT INTO `ms_addresses` VALUES ('86572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市1条通5丁目', '01', '01204', '0700031', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '1条通', '01ジョウドオリ', null, null, '5丁目', '05チョウメ');
INSERT INTO `ms_addresses` VALUES ('86573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市1条通6丁目', '01', '01204', '0700031', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '1条通', '01ジョウドオリ', null, null, '6丁目', '06チョウメ');
INSERT INTO `ms_addresses` VALUES ('86574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市1条通7丁目', '01', '01204', '0700031', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '1条通', '01ジョウドオリ', null, null, '7丁目', '07チョウメ');
INSERT INTO `ms_addresses` VALUES ('86575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市1条通8丁目', '01', '01204', '0700031', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '1条通', '01ジョウドオリ', null, null, '8丁目', '08チョウメ');
INSERT INTO `ms_addresses` VALUES ('86576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市1条通9丁目', '01', '01204', '0700031', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '1条通', '01ジョウドオリ', null, null, '9丁目', '09チョウメ');
INSERT INTO `ms_addresses` VALUES ('86577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市1条通10丁目', '01', '01204', '0700031', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '1条通', '01ジョウドオリ', null, null, '10丁目', '10チョウメ');
INSERT INTO `ms_addresses` VALUES ('86578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市1条通11丁目', '01', '01204', '0700031', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '1条通', '01ジョウドオリ', null, null, '11丁目', '11チョウメ');
INSERT INTO `ms_addresses` VALUES ('86579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市1条通12丁目', '01', '01204', '0700031', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '1条通', '01ジョウドオリ', null, null, '12丁目', '12チョウメ');
INSERT INTO `ms_addresses` VALUES ('86580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市1条通13丁目', '01', '01204', '0700031', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '1条通', '01ジョウドオリ', null, null, '13丁目', '13チョウメ');
INSERT INTO `ms_addresses` VALUES ('86581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市1条通14丁目', '01', '01204', '0700031', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '1条通', '01ジョウドオリ', null, null, '14丁目', '14チョウメ');
INSERT INTO `ms_addresses` VALUES ('86582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市1条通15丁目', '01', '01204', '0700031', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '1条通', '01ジョウドオリ', null, null, '15丁目', '15チョウメ');
INSERT INTO `ms_addresses` VALUES ('86583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市1条通16丁目', '01', '01204', '0700031', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '1条通', '01ジョウドオリ', null, null, '16丁目', '16チョウメ');
INSERT INTO `ms_addresses` VALUES ('86584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市1条通17丁目', '01', '01204', '0700031', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '1条通', '01ジョウドオリ', null, null, '17丁目', '17チョウメ');
INSERT INTO `ms_addresses` VALUES ('86585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市2条通1丁目', '01', '01204', '0700032', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '2条通', '02ジョウドオリ', null, null, '1丁目', '01チョウメ');
INSERT INTO `ms_addresses` VALUES ('86586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市2条通2丁目', '01', '01204', '0700032', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '2条通', '02ジョウドオリ', null, null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('86587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市2条通3丁目', '01', '01204', '0700032', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '2条通', '02ジョウドオリ', null, null, '3丁目', '03チョウメ');
INSERT INTO `ms_addresses` VALUES ('86588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市2条通4丁目', '01', '01204', '0700032', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '2条通', '02ジョウドオリ', null, null, '4丁目', '04チョウメ');
INSERT INTO `ms_addresses` VALUES ('86589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市2条通5丁目', '01', '01204', '0700032', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '2条通', '02ジョウドオリ', null, null, '5丁目', '05チョウメ');
INSERT INTO `ms_addresses` VALUES ('86590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市2条通6丁目', '01', '01204', '0700032', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '2条通', '02ジョウドオリ', null, null, '6丁目', '06チョウメ');
INSERT INTO `ms_addresses` VALUES ('86591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市2条通7丁目', '01', '01204', '0700032', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '2条通', '02ジョウドオリ', null, null, '7丁目', '07チョウメ');
INSERT INTO `ms_addresses` VALUES ('86592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市2条通8丁目', '01', '01204', '0700032', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '2条通', '02ジョウドオリ', null, null, '8丁目', '08チョウメ');
INSERT INTO `ms_addresses` VALUES ('86593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市2条通9丁目', '01', '01204', '0700032', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '2条通', '02ジョウドオリ', null, null, '9丁目', '09チョウメ');
INSERT INTO `ms_addresses` VALUES ('86594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市2条通10丁目', '01', '01204', '0700032', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '2条通', '02ジョウドオリ', null, null, '10丁目', '10チョウメ');
INSERT INTO `ms_addresses` VALUES ('86595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市2条通11丁目', '01', '01204', '0700032', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '2条通', '02ジョウドオリ', null, null, '11丁目', '11チョウメ');
INSERT INTO `ms_addresses` VALUES ('86596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市2条通12丁目', '01', '01204', '0700032', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '2条通', '02ジョウドオリ', null, null, '12丁目', '12チョウメ');
INSERT INTO `ms_addresses` VALUES ('86597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市2条通13丁目', '01', '01204', '0700032', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '2条通', '02ジョウドオリ', null, null, '13丁目', '13チョウメ');
INSERT INTO `ms_addresses` VALUES ('86598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市2条通14丁目', '01', '01204', '0700032', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '2条通', '02ジョウドオリ', null, null, '14丁目', '14チョウメ');
INSERT INTO `ms_addresses` VALUES ('86599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市2条通15丁目', '01', '01204', '0700032', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '2条通', '02ジョウドオリ', null, null, '15丁目', '15チョウメ');
INSERT INTO `ms_addresses` VALUES ('86600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市2条通16丁目', '01', '01204', '0700032', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '2条通', '02ジョウドオリ', null, null, '16丁目', '16チョウメ');
INSERT INTO `ms_addresses` VALUES ('86601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市2条通17丁目', '01', '01204', '0700032', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '2条通', '02ジョウドオリ', null, null, '17丁目', '17チョウメ');
INSERT INTO `ms_addresses` VALUES ('86602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市3条通1丁目', '01', '01204', '0700033', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '3条通', '03ジョウドオリ', null, null, '1丁目', '01チョウメ');
INSERT INTO `ms_addresses` VALUES ('86603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市3条通2丁目', '01', '01204', '0700033', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '3条通', '03ジョウドオリ', null, null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('86604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市3条通3丁目', '01', '01204', '0700033', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '3条通', '03ジョウドオリ', null, null, '3丁目', '03チョウメ');
INSERT INTO `ms_addresses` VALUES ('86605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市3条通4丁目', '01', '01204', '0700033', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '3条通', '03ジョウドオリ', null, null, '4丁目', '04チョウメ');
INSERT INTO `ms_addresses` VALUES ('86606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市3条通5丁目', '01', '01204', '0700033', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '3条通', '03ジョウドオリ', null, null, '5丁目', '05チョウメ');
INSERT INTO `ms_addresses` VALUES ('86607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市3条通6丁目', '01', '01204', '0700033', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '3条通', '03ジョウドオリ', null, null, '6丁目', '06チョウメ');
INSERT INTO `ms_addresses` VALUES ('86608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市3条通7丁目', '01', '01204', '0700033', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '3条通', '03ジョウドオリ', null, null, '7丁目', '07チョウメ');
INSERT INTO `ms_addresses` VALUES ('86609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市3条通8丁目', '01', '01204', '0700033', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '3条通', '03ジョウドオリ', null, null, '8丁目', '08チョウメ');
INSERT INTO `ms_addresses` VALUES ('86610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市3条通9丁目', '01', '01204', '0700033', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '3条通', '03ジョウドオリ', null, null, '9丁目', '09チョウメ');
INSERT INTO `ms_addresses` VALUES ('86611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市3条通10丁目', '01', '01204', '0700033', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '3条通', '03ジョウドオリ', null, null, '10丁目', '10チョウメ');
INSERT INTO `ms_addresses` VALUES ('86612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市3条通11丁目', '01', '01204', '0700033', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '3条通', '03ジョウドオリ', null, null, '11丁目', '11チョウメ');
INSERT INTO `ms_addresses` VALUES ('86613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市3条通12丁目', '01', '01204', '0700033', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '3条通', '03ジョウドオリ', null, null, '12丁目', '12チョウメ');
INSERT INTO `ms_addresses` VALUES ('86614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市3条通13丁目', '01', '01204', '0700033', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '3条通', '03ジョウドオリ', null, null, '13丁目', '13チョウメ');
INSERT INTO `ms_addresses` VALUES ('86615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市3条通14丁目', '01', '01204', '0700033', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '3条通', '03ジョウドオリ', null, null, '14丁目', '14チョウメ');
INSERT INTO `ms_addresses` VALUES ('86616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市3条通15丁目', '01', '01204', '0700033', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '3条通', '03ジョウドオリ', null, null, '15丁目', '15チョウメ');
INSERT INTO `ms_addresses` VALUES ('86617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市3条通16丁目', '01', '01204', '0700033', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '3条通', '03ジョウドオリ', null, null, '16丁目', '16チョウメ');
INSERT INTO `ms_addresses` VALUES ('86618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市3条通17丁目', '01', '01204', '0700033', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '3条通', '03ジョウドオリ', null, null, '17丁目', '17チョウメ');
INSERT INTO `ms_addresses` VALUES ('86619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市4条通1丁目', '01', '01204', '0700034', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '4条通', '04ジョウドオリ', null, null, '1丁目', '01チョウメ');
INSERT INTO `ms_addresses` VALUES ('86620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市4条通2丁目', '01', '01204', '0700034', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '4条通', '04ジョウドオリ', null, null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('86621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市4条通3丁目', '01', '01204', '0700034', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '4条通', '04ジョウドオリ', null, null, '3丁目', '03チョウメ');
INSERT INTO `ms_addresses` VALUES ('86622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市4条通4丁目', '01', '01204', '0700034', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '4条通', '04ジョウドオリ', null, null, '4丁目', '04チョウメ');
INSERT INTO `ms_addresses` VALUES ('86623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市4条通5丁目', '01', '01204', '0700034', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '4条通', '04ジョウドオリ', null, null, '5丁目', '05チョウメ');
INSERT INTO `ms_addresses` VALUES ('86624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市4条通6丁目', '01', '01204', '0700034', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '4条通', '04ジョウドオリ', null, null, '6丁目', '06チョウメ');
INSERT INTO `ms_addresses` VALUES ('86625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市4条通7丁目', '01', '01204', '0700034', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '4条通', '04ジョウドオリ', null, null, '7丁目', '07チョウメ');
INSERT INTO `ms_addresses` VALUES ('86626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市4条通8丁目', '01', '01204', '0700034', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '4条通', '04ジョウドオリ', null, null, '8丁目', '08チョウメ');
INSERT INTO `ms_addresses` VALUES ('86627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市4条通9丁目', '01', '01204', '0700034', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '4条通', '04ジョウドオリ', null, null, '9丁目', '09チョウメ');
INSERT INTO `ms_addresses` VALUES ('86628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市4条通10丁目', '01', '01204', '0700034', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '4条通', '04ジョウドオリ', null, null, '10丁目', '10チョウメ');
INSERT INTO `ms_addresses` VALUES ('86629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市4条通11丁目', '01', '01204', '0700034', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '4条通', '04ジョウドオリ', null, null, '11丁目', '11チョウメ');
INSERT INTO `ms_addresses` VALUES ('86630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市4条通12丁目', '01', '01204', '0700034', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '4条通', '04ジョウドオリ', null, null, '12丁目', '12チョウメ');
INSERT INTO `ms_addresses` VALUES ('86631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市4条通13丁目', '01', '01204', '0700034', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '4条通', '04ジョウドオリ', null, null, '13丁目', '13チョウメ');
INSERT INTO `ms_addresses` VALUES ('86632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市4条通14丁目', '01', '01204', '0700034', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '4条通', '04ジョウドオリ', null, null, '14丁目', '14チョウメ');
INSERT INTO `ms_addresses` VALUES ('86633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市4条通15丁目', '01', '01204', '0700034', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '4条通', '04ジョウドオリ', null, null, '15丁目', '15チョウメ');
INSERT INTO `ms_addresses` VALUES ('86634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市4条通16丁目', '01', '01204', '0700034', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '4条通', '04ジョウドオリ', null, null, '16丁目', '16チョウメ');
INSERT INTO `ms_addresses` VALUES ('86635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市4条通17丁目', '01', '01204', '0700034', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '4条通', '04ジョウドオリ', null, null, '17丁目', '17チョウメ');
INSERT INTO `ms_addresses` VALUES ('86636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市5条通1丁目', '01', '01204', '0700035', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '5条通', '05ジョウドオリ', null, null, '1丁目', '01チョウメ');
INSERT INTO `ms_addresses` VALUES ('86637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市5条通2丁目', '01', '01204', '0700035', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '5条通', '05ジョウドオリ', null, null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('86638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市5条通3丁目', '01', '01204', '0700035', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '5条通', '05ジョウドオリ', null, null, '3丁目', '03チョウメ');
INSERT INTO `ms_addresses` VALUES ('86639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市5条通4丁目', '01', '01204', '0700035', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '5条通', '05ジョウドオリ', null, null, '4丁目', '04チョウメ');
INSERT INTO `ms_addresses` VALUES ('86640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市5条通5丁目', '01', '01204', '0700035', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '5条通', '05ジョウドオリ', null, null, '5丁目', '05チョウメ');
INSERT INTO `ms_addresses` VALUES ('86641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市5条通6丁目', '01', '01204', '0700035', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '5条通', '05ジョウドオリ', null, null, '6丁目', '06チョウメ');
INSERT INTO `ms_addresses` VALUES ('86642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市5条通7丁目', '01', '01204', '0700035', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '5条通', '05ジョウドオリ', null, null, '7丁目', '07チョウメ');
INSERT INTO `ms_addresses` VALUES ('86643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市5条通8丁目', '01', '01204', '0700035', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '5条通', '05ジョウドオリ', null, null, '8丁目', '08チョウメ');
INSERT INTO `ms_addresses` VALUES ('86644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市5条通9丁目', '01', '01204', '0700035', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '5条通', '05ジョウドオリ', null, null, '9丁目', '09チョウメ');
INSERT INTO `ms_addresses` VALUES ('86645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市5条通10丁目', '01', '01204', '0700035', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '5条通', '05ジョウドオリ', null, null, '10丁目', '10チョウメ');
INSERT INTO `ms_addresses` VALUES ('86646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市5条通11丁目', '01', '01204', '0700035', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '5条通', '05ジョウドオリ', null, null, '11丁目', '11チョウメ');
INSERT INTO `ms_addresses` VALUES ('86647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市5条通12丁目', '01', '01204', '0700035', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '5条通', '05ジョウドオリ', null, null, '12丁目', '12チョウメ');
INSERT INTO `ms_addresses` VALUES ('86648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市5条通13丁目', '01', '01204', '0700035', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '5条通', '05ジョウドオリ', null, null, '13丁目', '13チョウメ');
INSERT INTO `ms_addresses` VALUES ('86649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市5条通14丁目', '01', '01204', '0700035', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '5条通', '05ジョウドオリ', null, null, '14丁目', '14チョウメ');
INSERT INTO `ms_addresses` VALUES ('86650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市5条通15丁目', '01', '01204', '0700035', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '5条通', '05ジョウドオリ', null, null, '15丁目', '15チョウメ');
INSERT INTO `ms_addresses` VALUES ('86651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市5条通16丁目', '01', '01204', '0700035', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '5条通', '05ジョウドオリ', null, null, '16丁目', '16チョウメ');
INSERT INTO `ms_addresses` VALUES ('86652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市5条通17丁目', '01', '01204', '0700035', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '5条通', '05ジョウドオリ', null, null, '17丁目', '17チョウメ');
INSERT INTO `ms_addresses` VALUES ('86653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市6条通1丁目', '01', '01204', '0700036', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '6条通', '06ジョウドオリ', null, null, '1丁目', '01チョウメ');
INSERT INTO `ms_addresses` VALUES ('86654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市6条通2丁目', '01', '01204', '0700036', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '6条通', '06ジョウドオリ', null, null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('86655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市6条通3丁目', '01', '01204', '0700036', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '6条通', '06ジョウドオリ', null, null, '3丁目', '03チョウメ');
INSERT INTO `ms_addresses` VALUES ('86656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市6条通4丁目', '01', '01204', '0700036', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '6条通', '06ジョウドオリ', null, null, '4丁目', '04チョウメ');
INSERT INTO `ms_addresses` VALUES ('86657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市6条通5丁目', '01', '01204', '0700036', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '6条通', '06ジョウドオリ', null, null, '5丁目', '05チョウメ');
INSERT INTO `ms_addresses` VALUES ('86658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市6条通6丁目', '01', '01204', '0700036', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '6条通', '06ジョウドオリ', null, null, '6丁目', '06チョウメ');
INSERT INTO `ms_addresses` VALUES ('86659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市6条通7丁目', '01', '01204', '0700036', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '6条通', '06ジョウドオリ', null, null, '7丁目', '07チョウメ');
INSERT INTO `ms_addresses` VALUES ('86660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市6条通8丁目', '01', '01204', '0700036', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '6条通', '06ジョウドオリ', null, null, '8丁目', '08チョウメ');
INSERT INTO `ms_addresses` VALUES ('86661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市6条通9丁目', '01', '01204', '0700036', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '6条通', '06ジョウドオリ', null, null, '9丁目', '09チョウメ');
INSERT INTO `ms_addresses` VALUES ('86662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市6条通10丁目', '01', '01204', '0700036', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '6条通', '06ジョウドオリ', null, null, '10丁目', '10チョウメ');
INSERT INTO `ms_addresses` VALUES ('86663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市6条通11丁目', '01', '01204', '0700036', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '6条通', '06ジョウドオリ', null, null, '11丁目', '11チョウメ');
INSERT INTO `ms_addresses` VALUES ('86664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市6条通12丁目', '01', '01204', '0700036', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '6条通', '06ジョウドオリ', null, null, '12丁目', '12チョウメ');
INSERT INTO `ms_addresses` VALUES ('86665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市6条通13丁目', '01', '01204', '0700036', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '6条通', '06ジョウドオリ', null, null, '13丁目', '13チョウメ');
INSERT INTO `ms_addresses` VALUES ('86666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市6条通14丁目', '01', '01204', '0700036', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '6条通', '06ジョウドオリ', null, null, '14丁目', '14チョウメ');
INSERT INTO `ms_addresses` VALUES ('86667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市6条通15丁目', '01', '01204', '0700036', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '6条通', '06ジョウドオリ', null, null, '15丁目', '15チョウメ');
INSERT INTO `ms_addresses` VALUES ('86668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市6条通16丁目', '01', '01204', '0700036', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '6条通', '06ジョウドオリ', null, null, '16丁目', '16チョウメ');
INSERT INTO `ms_addresses` VALUES ('86669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市6条通17丁目', '01', '01204', '0700036', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '6条通', '06ジョウドオリ', null, null, '17丁目', '17チョウメ');
INSERT INTO `ms_addresses` VALUES ('86670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市7条通1丁目', '01', '01204', '0700037', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '7条通', '07ジョウドオリ', null, null, '1丁目', '01チョウメ');
INSERT INTO `ms_addresses` VALUES ('86671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市7条通2丁目', '01', '01204', '0700037', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '7条通', '07ジョウドオリ', null, null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('86672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市7条通3丁目', '01', '01204', '0700037', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '7条通', '07ジョウドオリ', null, null, '3丁目', '03チョウメ');
INSERT INTO `ms_addresses` VALUES ('86673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市7条通4丁目', '01', '01204', '0700037', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '7条通', '07ジョウドオリ', null, null, '4丁目', '04チョウメ');
INSERT INTO `ms_addresses` VALUES ('86674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市7条通5丁目', '01', '01204', '0700037', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '7条通', '07ジョウドオリ', null, null, '5丁目', '05チョウメ');
INSERT INTO `ms_addresses` VALUES ('86675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市7条通6丁目', '01', '01204', '0700037', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '7条通', '07ジョウドオリ', null, null, '6丁目', '06チョウメ');
INSERT INTO `ms_addresses` VALUES ('86676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市7条通7丁目', '01', '01204', '0700037', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '7条通', '07ジョウドオリ', null, null, '7丁目', '07チョウメ');
INSERT INTO `ms_addresses` VALUES ('86677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市7条通8丁目', '01', '01204', '0700037', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '7条通', '07ジョウドオリ', null, null, '8丁目', '08チョウメ');
INSERT INTO `ms_addresses` VALUES ('86678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市7条通9丁目', '01', '01204', '0700037', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '7条通', '07ジョウドオリ', null, null, '9丁目', '09チョウメ');
INSERT INTO `ms_addresses` VALUES ('86679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市7条通10丁目', '01', '01204', '0700037', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '7条通', '07ジョウドオリ', null, null, '10丁目', '10チョウメ');
INSERT INTO `ms_addresses` VALUES ('86680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市7条通11丁目', '01', '01204', '0700037', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '7条通', '07ジョウドオリ', null, null, '11丁目', '11チョウメ');
INSERT INTO `ms_addresses` VALUES ('86681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市7条通12丁目', '01', '01204', '0700037', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '7条通', '07ジョウドオリ', null, null, '12丁目', '12チョウメ');
INSERT INTO `ms_addresses` VALUES ('86682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市7条通13丁目', '01', '01204', '0700037', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '7条通', '07ジョウドオリ', null, null, '13丁目', '13チョウメ');
INSERT INTO `ms_addresses` VALUES ('86683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市7条通14丁目', '01', '01204', '0700037', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '7条通', '07ジョウドオリ', null, null, '14丁目', '14チョウメ');
INSERT INTO `ms_addresses` VALUES ('86684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市7条通15丁目', '01', '01204', '0700037', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '7条通', '07ジョウドオリ', null, null, '15丁目', '15チョウメ');
INSERT INTO `ms_addresses` VALUES ('86685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市7条通16丁目', '01', '01204', '0700037', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '7条通', '07ジョウドオリ', null, null, '16丁目', '16チョウメ');
INSERT INTO `ms_addresses` VALUES ('86686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市7条通17丁目', '01', '01204', '0700037', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '7条通', '07ジョウドオリ', null, null, '17丁目', '17チョウメ');
INSERT INTO `ms_addresses` VALUES ('86687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市8条通1丁目', '01', '01204', '0700038', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '8条通', '08ジョウドオリ', null, null, '1丁目', '01チョウメ');
INSERT INTO `ms_addresses` VALUES ('86688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市8条通2丁目', '01', '01204', '0700038', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '8条通', '08ジョウドオリ', null, null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('86689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市8条通3丁目', '01', '01204', '0700038', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '8条通', '08ジョウドオリ', null, null, '3丁目', '03チョウメ');
INSERT INTO `ms_addresses` VALUES ('86690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市8条通4丁目', '01', '01204', '0700038', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '8条通', '08ジョウドオリ', null, null, '4丁目', '04チョウメ');
INSERT INTO `ms_addresses` VALUES ('86691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市8条通5丁目', '01', '01204', '0700038', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '8条通', '08ジョウドオリ', null, null, '5丁目', '05チョウメ');
INSERT INTO `ms_addresses` VALUES ('86692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市8条通6丁目', '01', '01204', '0700038', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '8条通', '08ジョウドオリ', null, null, '6丁目', '06チョウメ');
INSERT INTO `ms_addresses` VALUES ('86693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市8条通7丁目', '01', '01204', '0700038', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '8条通', '08ジョウドオリ', null, null, '7丁目', '07チョウメ');
INSERT INTO `ms_addresses` VALUES ('86694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市8条通8丁目', '01', '01204', '0700038', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '8条通', '08ジョウドオリ', null, null, '8丁目', '08チョウメ');
INSERT INTO `ms_addresses` VALUES ('86695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市8条通9丁目', '01', '01204', '0700038', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '8条通', '08ジョウドオリ', null, null, '9丁目', '09チョウメ');
INSERT INTO `ms_addresses` VALUES ('86696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市8条通10丁目', '01', '01204', '0700038', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '8条通', '08ジョウドオリ', null, null, '10丁目', '10チョウメ');
INSERT INTO `ms_addresses` VALUES ('86697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市8条通11丁目', '01', '01204', '0700038', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '8条通', '08ジョウドオリ', null, null, '11丁目', '11チョウメ');
INSERT INTO `ms_addresses` VALUES ('86698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市8条通12丁目', '01', '01204', '0700038', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '8条通', '08ジョウドオリ', null, null, '12丁目', '12チョウメ');
INSERT INTO `ms_addresses` VALUES ('86699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市8条通13丁目', '01', '01204', '0700038', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '8条通', '08ジョウドオリ', null, null, '13丁目', '13チョウメ');
INSERT INTO `ms_addresses` VALUES ('86700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市8条通14丁目', '01', '01204', '0700038', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '8条通', '08ジョウドオリ', null, null, '14丁目', '14チョウメ');
INSERT INTO `ms_addresses` VALUES ('86701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市8条通15丁目', '01', '01204', '0700038', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '8条通', '08ジョウドオリ', null, null, '15丁目', '15チョウメ');
INSERT INTO `ms_addresses` VALUES ('86702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市8条通16丁目', '01', '01204', '0700038', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '8条通', '08ジョウドオリ', null, null, '16丁目', '16チョウメ');
INSERT INTO `ms_addresses` VALUES ('86703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市8条通17丁目', '01', '01204', '0700038', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '8条通', '08ジョウドオリ', null, null, '17丁目', '17チョウメ');
INSERT INTO `ms_addresses` VALUES ('86704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市9条通1丁目', '01', '01204', '0700039', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '9条通', '09ジョウドオリ', null, null, '1丁目', '01チョウメ');
INSERT INTO `ms_addresses` VALUES ('86705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市9条通2丁目', '01', '01204', '0700039', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '9条通', '09ジョウドオリ', null, null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('86706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市9条通3丁目', '01', '01204', '0700039', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '9条通', '09ジョウドオリ', null, null, '3丁目', '03チョウメ');
INSERT INTO `ms_addresses` VALUES ('86707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市9条通4丁目', '01', '01204', '0700039', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '9条通', '09ジョウドオリ', null, null, '4丁目', '04チョウメ');
INSERT INTO `ms_addresses` VALUES ('86708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市9条通5丁目', '01', '01204', '0700039', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '9条通', '09ジョウドオリ', null, null, '5丁目', '05チョウメ');
INSERT INTO `ms_addresses` VALUES ('86709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市9条通6丁目', '01', '01204', '0700039', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '9条通', '09ジョウドオリ', null, null, '6丁目', '06チョウメ');
INSERT INTO `ms_addresses` VALUES ('86710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市9条通7丁目', '01', '01204', '0700039', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '9条通', '09ジョウドオリ', null, null, '7丁目', '07チョウメ');
INSERT INTO `ms_addresses` VALUES ('86711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市9条通8丁目', '01', '01204', '0700039', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '9条通', '09ジョウドオリ', null, null, '8丁目', '08チョウメ');
INSERT INTO `ms_addresses` VALUES ('86712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市9条通9丁目', '01', '01204', '0700039', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '9条通', '09ジョウドオリ', null, null, '9丁目', '09チョウメ');
INSERT INTO `ms_addresses` VALUES ('86713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市9条通10丁目', '01', '01204', '0700039', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '9条通', '09ジョウドオリ', null, null, '10丁目', '10チョウメ');
INSERT INTO `ms_addresses` VALUES ('86714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市9条通11丁目', '01', '01204', '0700039', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '9条通', '09ジョウドオリ', null, null, '11丁目', '11チョウメ');
INSERT INTO `ms_addresses` VALUES ('86715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市9条通12丁目', '01', '01204', '0700039', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '9条通', '09ジョウドオリ', null, null, '12丁目', '12チョウメ');
INSERT INTO `ms_addresses` VALUES ('86716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市9条通13丁目', '01', '01204', '0700039', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '9条通', '09ジョウドオリ', null, null, '13丁目', '13チョウメ');
INSERT INTO `ms_addresses` VALUES ('86717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市9条通14丁目', '01', '01204', '0700039', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '9条通', '09ジョウドオリ', null, null, '14丁目', '14チョウメ');
INSERT INTO `ms_addresses` VALUES ('86718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市9条通15丁目', '01', '01204', '0700039', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '9条通', '09ジョウドオリ', null, null, '15丁目', '15チョウメ');
INSERT INTO `ms_addresses` VALUES ('86719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市9条通16丁目', '01', '01204', '0700039', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '9条通', '09ジョウドオリ', null, null, '16丁目', '16チョウメ');
INSERT INTO `ms_addresses` VALUES ('86720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市9条通17丁目', '01', '01204', '0700039', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '9条通', '09ジョウドオリ', null, null, '17丁目', '17チョウメ');
INSERT INTO `ms_addresses` VALUES ('86721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区中沼4条', '01', '01103', '0070004', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '中沼4条', 'ナカヌマ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市10条通8丁目', '01', '01204', '0700040', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '10条通', '10ジョウドオリ', null, null, '8丁目', '08チョウメ');
INSERT INTO `ms_addresses` VALUES ('86723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市10条通9丁目', '01', '01204', '0700040', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '10条通', '10ジョウドオリ', null, null, '9丁目', '09チョウメ');
INSERT INTO `ms_addresses` VALUES ('86724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市10条通10丁目', '01', '01204', '0700040', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '10条通', '10ジョウドオリ', null, null, '10丁目', '10チョウメ');
INSERT INTO `ms_addresses` VALUES ('86725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市10条通11丁目', '01', '01204', '0700040', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '10条通', '10ジョウドオリ', null, null, '11丁目', '11チョウメ');
INSERT INTO `ms_addresses` VALUES ('86726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市10条通12丁目', '01', '01204', '0700040', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '10条通', '10ジョウドオリ', null, null, '12丁目', '12チョウメ');
INSERT INTO `ms_addresses` VALUES ('86727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市10条通13丁目', '01', '01204', '0700040', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '10条通', '10ジョウドオリ', null, null, '13丁目', '13チョウメ');
INSERT INTO `ms_addresses` VALUES ('86728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市10条通14丁目', '01', '01204', '0700040', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '10条通', '10ジョウドオリ', null, null, '14丁目', '14チョウメ');
INSERT INTO `ms_addresses` VALUES ('86729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市10条通15丁目', '01', '01204', '0700040', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '10条通', '10ジョウドオリ', null, null, '15丁目', '15チョウメ');
INSERT INTO `ms_addresses` VALUES ('86730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市10条通16丁目', '01', '01204', '0700040', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '10条通', '10ジョウドオリ', null, null, '16丁目', '16チョウメ');
INSERT INTO `ms_addresses` VALUES ('86731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市10条通17丁目', '01', '01204', '0700040', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '10条通', '10ジョウドオリ', null, null, '17丁目', '17チョウメ');
INSERT INTO `ms_addresses` VALUES ('86732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市上常盤町', '01', '01204', '0700041', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '上常盤町', 'カミトキワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市中常盤町', '01', '01204', '0700042', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '中常盤町', 'ナカトキワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市常盤通', '01', '01204', '0700043', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '常盤通', 'トキワドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市常磐公園', '01', '01204', '0700044', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '常磐公園', 'トキワコウエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区中沼5条', '01', '01103', '0070005', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '中沼5条', 'ナカヌマ05ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市2条西', '01', '01204', '0700052', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '2条西', '02ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市3条西', '01', '01204', '0700053', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '3条西', '03ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市4条西', '01', '01204', '0700054', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '4条西', '04ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市5条西', '01', '01204', '0700055', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '5条西', '05ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市6条西', '01', '01204', '0700056', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '6条西', '06ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市7条西', '01', '01204', '0700057', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '7条西', '07ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市8条西', '01', '01204', '0700058', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '8条西', '08ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市9条西', '01', '01204', '0700059', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '9条西', '09ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区中沼6条', '01', '01103', '0070006', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '中沼6条', 'ナカヌマ06ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市曙1条', '01', '01204', '0700061', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '曙1条', 'アケボノ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市曙2条', '01', '01204', '0700062', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '曙2条', 'アケボノ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市曙3条', '01', '01204', '0700063', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '曙3条', 'アケボノ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市曙北2条', '01', '01204', '0700072', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '曙北2条', 'アケボノキタ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市曙北3条', '01', '01204', '0700073', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '曙北3条', 'アケボノキタ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市三野本町', '33', '33201', '7000801', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '三野本町', 'ミノホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市三野', '33', '33201', '7000802', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '三野', 'ミノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市北方', '33', '33201', '7000803', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '北方', 'キタガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市中井町', '33', '33201', '7000804', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '中井町', 'ナカイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市兵団', '33', '33201', '7000805', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '兵団', 'ヘイダン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市広瀬町', '33', '33201', '7000806', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '広瀬町', 'ヒロセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市南方', '33', '33201', '7000807', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '南方', 'ミナミガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市大和町', '33', '33201', '7000808', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '大和町', 'ヤマトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市亀吉1条', '01', '01204', '0700081', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '亀吉1条', 'カメキチ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市番町', '33', '33201', '7000811', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '番町', 'バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市出石町', '33', '33201', '7000812', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '出石町', 'イズシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市石関町', '33', '33201', '7000813', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '石関町', 'イシゼキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市天神町', '33', '33201', '7000814', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '天神町', 'テンジンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市野田屋町', '33', '33201', '7000815', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '野田屋町', 'ノダヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市富田町', '33', '33201', '7000816', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '富田町', 'トンダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市弓之町', '33', '33201', '7000817', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '弓之町', 'ユミノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市蕃山町', '33', '33201', '7000818', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '蕃山町', 'バンザンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市亀吉2条', '01', '01204', '0700082', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '亀吉2条', 'カメキチ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市中山下', '33', '33201', '7000821', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '中山下', 'ナカサンゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市表町', '33', '33201', '7000822', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '表町', 'オモテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市丸の内', '33', '33201', '7000823', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '丸の内', 'マルノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市内山下', '33', '33201', '7000824', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '内山下', 'ウチサンゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市田町', '33', '33201', '7000825', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '田町', 'タマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市磨屋町', '33', '33201', '7000826', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '磨屋町', 'トギヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市平和町', '33', '33201', '7000827', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '平和町', 'ヘイワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市亀吉3条', '01', '01204', '0700083', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '亀吉3条', 'カメキチ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市京橋町', '33', '33201', '7000831', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '京橋町', 'キョウバシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市京橋南町', '33', '33201', '7000832', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '京橋南町', 'キョウバシミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市天瀬', '33', '33201', '7000833', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '天瀬', 'アマセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市天瀬南町', '33', '33201', '7000834', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '天瀬南町', 'アマセミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市東中央町', '33', '33201', '7000835', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '東中央町', 'ヒガシチュウオウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市中央町', '33', '33201', '7000836', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '中央町', 'チュウオウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市南中央町', '33', '33201', '7000837', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '南中央町', 'ミナミチュウオウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市京町', '33', '33201', '7000838', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '京町', 'キョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市舟橋町', '33', '33201', '7000841', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '舟橋町', 'フナバシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市船頭町', '33', '33201', '7000842', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '船頭町', 'センドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市二日市町', '33', '33201', '7000843', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '二日市町', 'フツカイチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市御舟入町', '33', '33201', '7000844', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '御舟入町', 'オフナイリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市浜野', '33', '33201', '7000845', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '浜野', 'ハマノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市下内田町', '33', '33201', '7000846', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '下内田町', 'シモウチダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市山科町', '33', '33201', '7000847', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '山科町', 'ヤマシナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市七日市西町', '33', '33201', '7000851', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '七日市西町', 'ナノカイチニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市七日市東町', '33', '33201', '7000852', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '七日市東町', 'ナノカイチヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市豊浜町', '33', '33201', '7000853', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '豊浜町', 'トヨハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市十日市東町', '33', '33201', '7000854', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '十日市東町', 'トオカイチヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市十日市中町', '33', '33201', '7000855', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '十日市中町', 'トオカイチナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市十日市西町', '33', '33201', '7000856', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '十日市西町', 'トオカイチニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市清輝橋', '33', '33201', '7000861', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '清輝橋', 'セイキバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市清輝本町', '33', '33201', '7000862', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '清輝本町', 'セイキホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市新道', '33', '33201', '7000863', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '新道', 'シンミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市旭町', '33', '33201', '7000864', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '旭町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市旭本町', '33', '33201', '7000865', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '旭本町', 'アサヒホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市岡南町', '33', '33201', '7000866', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '岡南町', 'コウナンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市岡町', '33', '33201', '7000867', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '岡町', 'オカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市本町', '33', '33201', '7000901', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市錦町', '33', '33201', '7000902', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '錦町', 'ニシキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市幸町', '33', '33201', '7000903', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市柳町', '33', '33201', '7000904', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '柳町', 'ヤナギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市春日町', '33', '33201', '7000905', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '春日町', 'カスガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市大学町', '33', '33201', '7000906', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '大学町', 'ダイガクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市下石井', '33', '33201', '7000907', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '下石井', 'シモイシイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市大供本町', '33', '33201', '7000911', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '大供本町', 'ダイクホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市大供表町', '33', '33201', '7000912', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '大供表町', 'ダイクオモテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市大供', '33', '33201', '7000913', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '大供', 'ダイク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市鹿田町', '33', '33201', '7000914', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '鹿田町', 'シカタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市鹿田本町', '33', '33201', '7000915', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '鹿田本町', 'シカタホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市西之町', '33', '33201', '7000916', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '西之町', 'ニシノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市東古松', '33', '33201', '7000921', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '東古松', 'ヒガシフルマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市東古松南町', '33', '33201', '7000922', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '東古松南町', 'ヒガシフルマツミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市大元駅前', '33', '33201', '7000923', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '大元駅前', 'オオモトエキマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市大元', '33', '33201', '7000924', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '大元', 'オオモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市大元上町', '33', '33201', '7000925', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '大元上町', 'オオモトカミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市西古松西町', '33', '33201', '7000926', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '西古松西町', 'ニシフルマツニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市西古松', '33', '33201', '7000927', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '西古松', 'ニシフルマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市奥田西町', '33', '33201', '7000931', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '奥田西町', 'オクダニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市奥田本町', '33', '33201', '7000932', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '奥田本町', 'オクダホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市奥田', '33', '33201', '7000933', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '奥田', 'オクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市奥田南町', '33', '33201', '7000934', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '奥田南町', 'オクダミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市神田町', '33', '33201', '7000935', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '神田町', 'カンダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市富田', '33', '33201', '7000936', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '富田', 'トミタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市青江', '33', '33201', '7000941', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '青江', 'アオエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市豊成', '33', '33201', '7000942', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '豊成', 'トヨナリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市新福', '33', '33201', '7000943', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '新福', 'シンプク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市泉田', '33', '33201', '7000944', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '泉田', 'イズミダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市新保', '33', '33201', '7000945', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '新保', 'シンボウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市田中', '33', '33201', '7000951', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '田中', 'タナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市平田', '33', '33201', '7000952', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '平田', 'ヒラタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市西市', '33', '33201', '7000953', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '西市', 'ニシイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市米倉', '33', '33201', '7000954', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '米倉', 'ヨネグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市万倍', '33', '33201', '7000955', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '万倍', 'マンバイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市当新田', '33', '33201', '7000956', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '当新田', 'トウシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市北長瀬本町', '33', '33201', '7000961', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '北長瀬本町', 'キタナガセホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市北長瀬表町', '33', '33201', '7000962', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '北長瀬表町', 'キタナガセオモテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市北長瀬', '33', '33201', '7000963', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '北長瀬', 'キタナガセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市中仙道', '33', '33201', '7000964', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '中仙道', 'ナカセンドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市西長瀬', '33', '33201', '7000965', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '西長瀬', 'ニシナガセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市日吉町', '33', '33201', '7000966', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '日吉町', 'ヒヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市野田', '33', '33201', '7000971', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '野田', 'ノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市上中野', '33', '33201', '7000972', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '上中野', 'カミナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市下中野', '33', '33201', '7000973', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '下中野', 'シモナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市今村', '33', '33201', '7000974', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '今村', 'イマムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市今', '33', '33201', '7000975', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '今', 'イマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市辰巳', '33', '33201', '7000976', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '辰巳', 'タツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市問屋町', '33', '33201', '7000977', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '問屋町', 'トイヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市西島田町', '33', '33201', '7000981', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '西島田町', 'ニシシマダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市中島田町', '33', '33201', '7000982', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '中島田町', 'ナカシマダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市東島田町', '33', '33201', '7000983', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '東島田町', 'ヒガシシマダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市桑田町', '33', '33201', '7000984', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '桑田町', 'クワダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市厚生町', '33', '33201', '7000985', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '厚生町', 'コウセイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市新屋敷町', '33', '33201', '7000986', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '新屋敷町', 'シンヤシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区モエレ沼公園', '01', '01103', '0070011', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', 'モエレ沼公園', 'モエレヌマコウエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区東雁来10条', '01', '01103', '0070030', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '東雁来10条', 'ヒガシカリキ10ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区東雁来11条', '01', '01103', '0070031', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '東雁来11条', 'ヒガシカリキ11ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区東雁来12条', '01', '01103', '0070032', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '東雁来12条', 'ヒガシカリキ12ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区東雁来13条', '01', '01103', '0070033', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '東雁来13条', 'ヒガシカリキ13ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区東雁来14条', '01', '01103', '0070034', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '東雁来14条', 'ヒガシカリキ14ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市本町', '01', '01204', '0700810', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '本町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市川端町1条', '01', '01204', '0700811', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '川端町1条', 'カワバタチョウ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市川端町2条', '01', '01204', '0700812', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '川端町2条', 'カワバタチョウ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市川端町3条', '01', '01204', '0700813', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '川端町3条', 'カワバタチョウ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市川端町4条', '01', '01204', '0700814', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '川端町4条', 'カワバタチョウ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市川端町5条', '01', '01204', '0700815', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '川端町5条', 'カワバタチョウ05ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市川端町6条', '01', '01204', '0700816', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '川端町6条', 'カワバタチョウ06ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市川端町7条', '01', '01204', '0700817', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '川端町7条', 'カワバタチョウ07ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市近文町', '01', '01204', '0700821', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '近文町', 'チカブミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市旭岡', '01', '01204', '0700822', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '旭岡', 'アサヒガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市緑町', '01', '01204', '0700823', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '緑町', 'ミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市錦町', '01', '01204', '0700824', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '錦町', 'ニシキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市北門町', '01', '01204', '0700825', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '北門町', 'ホクモンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市旭町1条', '01', '01204', '0700831', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '旭町1条', 'アサヒマチ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市旭町2条', '01', '01204', '0700832', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '旭町2条', 'アサヒマチ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市大町1条', '01', '01204', '0700841', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '大町1条', 'オオマチ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市大町2条', '01', '01204', '0700842', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '大町2条', 'オオマチ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市大町3条', '01', '01204', '0700843', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '大町3条', 'オオマチ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市住吉4条', '01', '01204', '0700864', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '住吉4条', 'スミヨシ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市住吉5条', '01', '01204', '0700865', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '住吉5条', 'スミヨシ05ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市住吉6条', '01', '01204', '0700866', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '住吉6条', 'スミヨシ06ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市住吉7条', '01', '01204', '0700867', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '住吉7条', 'スミヨシ07ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市春光1条', '01', '01204', '0700871', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '春光1条', 'シュンコウ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市春光2条', '01', '01204', '0700872', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '春光2条', 'シュンコウ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市春光3条', '01', '01204', '0700873', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '春光3条', 'シュンコウ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市春光4条', '01', '01204', '0700874', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '春光4条', 'シュンコウ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市春光5条', '01', '01204', '0700875', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '春光5条', 'シュンコウ05ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市春光6条', '01', '01204', '0700876', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '春光6条', 'シュンコウ06ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市春光7条', '01', '01204', '0700877', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '春光7条', 'シュンコウ07ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市花咲町', '01', '01204', '0700901', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '花咲町', 'ハナサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市春光町', '01', '01204', '0700902', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '春光町', 'シュンコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市4区1条', '01', '01204', '0700971', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '4区1条', '04ク1ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市4区2条', '01', '01204', '0700972', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '4区2条', '04ク2ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('86995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市4区3条', '01', '01204', '0700973', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '4区3条', '04ク3ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市日畑', '33', '33202', '7010101', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '日畑', 'ヒバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市庄新町', '33', '33202', '7010102', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '庄新町', 'ショウシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市西尾', '33', '33202', '7010103', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '西尾', 'ニシオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市山地', '33', '33202', '7010104', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '山地', 'ヤマジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市矢部', '33', '33202', '7010105', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '矢部', 'ヤベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市上東', '33', '33202', '7010111', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '上東', 'ジョウトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市下庄', '33', '33202', '7010112', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '下庄', 'シモショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市栗坂', '33', '33202', '7010113', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '栗坂', 'クリサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市松島', '33', '33202', '7010114', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '松島', 'マツシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市二子', '33', '33202', '7010115', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '二子', 'フタゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市花尻みどり町', '33', '33201', '7010131', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '花尻みどり町', 'ハナジリミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市花尻ききょう町', '33', '33201', '7010132', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '花尻ききょう町', 'ハナジリキキョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市花尻あかね町', '33', '33201', '7010133', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '花尻あかね町', 'ハナジリアカネマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市花尻', '33', '33201', '7010134', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '花尻', 'ハナジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市東花尻', '33', '33201', '7010135', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '東花尻', 'ヒガシハナジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市西花尻', '33', '33201', '7010136', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '西花尻', 'ニシハナジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市白石東新町', '33', '33201', '7010141', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '白石東新町', 'シライシヒガシシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市白石西新町', '33', '33201', '7010142', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '白石西新町', 'シライシニシシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市白石', '33', '33201', '7010143', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '白石', 'シライシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市久米', '33', '33201', '7010144', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '久米', 'クメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市今保', '33', '33201', '7010145', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '今保', 'イマボウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市平野', '33', '33201', '7010151', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '平野', 'ヒラノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市延友', '33', '33201', '7010152', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '延友', 'ノブトモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市庭瀬', '33', '33201', '7010153', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '庭瀬', 'ニワセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市川入', '33', '33201', '7010161', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '川入', 'カワイリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市納所', '33', '33201', '7010162', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '納所', 'ノウソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市中撫川', '33', '33201', '7010163', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '中撫川', 'ナカナツカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市撫川', '33', '33201', '7010164', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '撫川', 'ナツカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市大内田', '33', '33201', '7010165', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '大内田', 'オオウチダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市妹尾崎', '33', '33201', '7010201', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '妹尾崎', 'セノオザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市山田', '33', '33201', '7010202', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '山田', 'ヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市古新田', '33', '33201', '7010203', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '古新田', 'コシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市大福', '33', '33201', '7010204', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '大福', 'オオフク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市妹尾', '33', '33201', '7010205', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '妹尾', 'セノオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市箕島', '33', '33201', '7010206', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '箕島', 'ミシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市東畦', '33', '33201', '7010211', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '東畦', 'ヒガシウネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市内尾', '33', '33201', '7010212', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '内尾', 'ウチオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市中畦', '33', '33201', '7010213', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '中畦', 'ナカウネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市曽根', '33', '33201', '7010214', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '曽根', 'ソネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市西畦', '33', '33201', '7010215', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '西畦', 'ニシウネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市藤田', '33', '33201', '7010221', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '藤田', 'フジタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県都窪郡早島町', '33', '33423', '7010300', '岡山県', 'オカヤマケン', '都窪郡早島町', 'ツクボグンハヤシマチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('87052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県都窪郡早島町矢尾', '33', '33423', '7010301', '岡山県', 'オカヤマケン', '都窪郡早島町', 'ツクボグンハヤシマチョウ', '矢尾', 'ヤオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県都窪郡早島町若宮', '33', '33423', '7010302', '岡山県', 'オカヤマケン', '都窪郡早島町', 'ツクボグンハヤシマチョウ', '若宮', 'ワカミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県都窪郡早島町前潟', '33', '33423', '7010303', '岡山県', 'オカヤマケン', '都窪郡早島町', 'ツクボグンハヤシマチョウ', '前潟', 'マエガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県都窪郡早島町早島', '33', '33423', '7010304', '岡山県', 'オカヤマケン', '都窪郡早島町', 'ツクボグンハヤシマチョウ', '早島', 'ハヤシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市日応寺', '33', '33201', '7011131', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '日応寺', 'ニチオウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市田原', '33', '33201', '7011132', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '田原', 'タバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市富吉', '33', '33201', '7011133', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '富吉', 'トミヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市三和', '33', '33201', '7011134', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '三和', 'ミト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市菅野', '33', '33201', '7011141', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '菅野', 'スガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市高野', '33', '33201', '7011142', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '高野', 'タカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市吉宗', '33', '33201', '7011143', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '吉宗', 'ヨシムネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市栢谷', '33', '33201', '7011144', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '栢谷', 'カイダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市横井上', '33', '33201', '7011145', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '横井上', 'ヨコイカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市津高台', '33', '33201', '7011151', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '津高台', 'ツダカダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市津高', '33', '33201', '7011152', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '津高', 'ツダカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市富原', '33', '33201', '7011153', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '富原', 'トミハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市田益', '33', '33201', '7011154', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '田益', 'タマス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市首部', '33', '33201', '7011201', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '首部', 'コウベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市楢津', '33', '33201', '7011202', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '楢津', 'ナラヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市一宮山崎', '33', '33201', '7011203', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '一宮山崎', 'イチノミヤヤマサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市今岡', '33', '33201', '7011204', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '今岡', 'イマオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市佐山', '33', '33201', '7011205', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '佐山', 'サヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市一宮', '33', '33201', '7011211', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '一宮', 'イチノミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市尾上', '33', '33201', '7011212', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '尾上', 'オノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市西辛川', '33', '33201', '7011213', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '西辛川', 'ニシカラカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市辛川市場', '33', '33201', '7011214', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '辛川市場', 'カラカワイチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市芳賀', '33', '33201', '7011221', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '芳賀', 'ハガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市松尾', '33', '33201', '7011222', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '松尾', 'マツオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市大窪', '33', '33201', '7011223', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '大窪', 'オオクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市長野', '33', '33201', '7011224', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '長野', 'ナガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市福谷', '33', '33201', '7011225', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '福谷', 'フクタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市横尾', '33', '33201', '7011226', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '横尾', 'ヨコオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市高松稲荷', '33', '33201', '7011331', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '高松稲荷', 'タカマツイナリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市平山', '33', '33201', '7011332', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '平山', 'ヒラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市立田', '33', '33201', '7011333', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '立田', 'タツタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市高松原古才', '33', '33201', '7011334', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '高松原古才', 'タカマツハラコサイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市高松', '33', '33201', '7011335', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '高松', 'タカマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市大崎', '33', '33201', '7011336', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '大崎', 'オオザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市和井元', '33', '33201', '7011337', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '和井元', 'ワイモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市吉備津', '33', '33201', '7011341', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '吉備津', 'キビツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市加茂', '33', '33201', '7011342', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '加茂', 'カモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市惣爪', '33', '33201', '7011343', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '惣爪', 'ソウヅメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市新庄下', '33', '33201', '7011344', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '新庄下', 'シンジョウシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市新庄上', '33', '33201', '7011345', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '新庄上', 'シンジョウカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市津寺', '33', '33201', '7011346', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '津寺', 'ツデラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市門前', '33', '33201', '7011351', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '門前', 'モンゼン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市小山', '33', '33201', '7011352', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '小山', 'コヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市三手', '33', '33201', '7011353', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '三手', 'ミテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市高塚', '33', '33201', '7011354', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '高塚', 'タカツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市高松田中', '33', '33201', '7011355', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '高松田中', 'タカマツタナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市下土田', '33', '33201', '7011356', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '下土田', 'シモツチダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市福崎', '33', '33201', '7011357', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '福崎', 'フクザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市粟井', '33', '33201', '7011461', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '粟井', 'アワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市大井', '33', '33201', '7011462', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '大井', 'オオイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市足守', '33', '33201', '7011463', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '足守', 'アシモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市下足守', '33', '33201', '7011464', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '下足守', 'シモアシモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市上土田', '33', '33201', '7011465', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '上土田', 'カミツチダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市日近', '33', '33201', '7011521', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '日近', 'ヒジカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市杉谷', '33', '33201', '7011522', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '杉谷', 'スギタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市吉', '33', '33201', '7011523', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '吉', 'ヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市下高田', '33', '33201', '7011524', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '下高田', 'シモタカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市上高田', '33', '33201', '7011525', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '上高田', 'カミタカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市山上', '33', '33201', '7011526', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '山上', 'ヤマノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市石妻', '33', '33201', '7011527', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '石妻', 'イシヅマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市掛畑', '33', '33201', '7011601', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '掛畑', 'カケハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市真星', '33', '33201', '7011602', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '真星', 'マナボシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市庄田', '33', '33201', '7011603', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '庄田', 'ショウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市苔山', '33', '33201', '7011604', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '苔山', 'コケヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市河原', '33', '33201', '7011605', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '河原', 'カワハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市東山内', '33', '33201', '7011611', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '東山内', 'ヒガシヤマノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市西山内', '33', '33201', '7011612', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '西山内', 'ニシヤマノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市間倉', '33', '33201', '7011613', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '間倉', 'マグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市牟佐', '33', '33201', '7012141', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '牟佐', 'ムサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市玉柏', '33', '33201', '7012142', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '玉柏', 'タマガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市下牧', '33', '33201', '7012143', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '下牧', 'シモマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市中牧', '33', '33201', '7012144', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '中牧', 'ナカマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市金山寺', '33', '33201', '7012151', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '金山寺', 'カナヤマジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市高野尻', '33', '33201', '7012152', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '高野尻', 'コウヤジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市畑鮎', '33', '33201', '7012153', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '畑鮎', 'ハタアユ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市原', '33', '33201', '7012154', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '原', 'ハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市中原', '33', '33201', '7012155', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '中原', 'ナカハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県赤磐市小原', '33', '33213', '7012201', '岡山県', 'オカヤマケン', '赤磐市', 'アカイワシ', '小原', 'コバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県赤磐市坂辺', '33', '33213', '7012202', '岡山県', 'オカヤマケン', '赤磐市', 'アカイワシ', '坂辺', 'サカナベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県赤磐市惣分', '33', '33213', '7012203', '岡山県', 'オカヤマケン', '赤磐市', 'アカイワシ', '惣分', 'ソウブン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県赤磐市山手', '33', '33213', '7012204', '岡山県', 'オカヤマケン', '赤磐市', 'アカイワシ', '山手', 'ヤマテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県赤磐市大屋', '33', '33213', '7012205', '岡山県', 'オカヤマケン', '赤磐市', 'アカイワシ', '大屋', 'オオヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県赤磐市北佐古田', '33', '33213', '7012211', '岡山県', 'オカヤマケン', '赤磐市', 'アカイワシ', '北佐古田', 'キタサコダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県赤磐市南佐古田', '33', '33213', '7012212', '岡山県', 'オカヤマケン', '赤磐市', 'アカイワシ', '南佐古田', 'ミナミサコダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県赤磐市今井', '33', '33213', '7012213', '岡山県', 'オカヤマケン', '赤磐市', 'アカイワシ', '今井', 'イマイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県赤磐市東軽部', '33', '33213', '7012214', '岡山県', 'オカヤマケン', '赤磐市', 'アカイワシ', '東軽部', 'ヒガシカルベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県赤磐市西軽部', '33', '33213', '7012215', '岡山県', 'オカヤマケン', '赤磐市', 'アカイワシ', '西軽部', 'ニシカルベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県赤磐市多賀', '33', '33213', '7012216', '岡山県', 'オカヤマケン', '赤磐市', 'アカイワシ', '多賀', 'タガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県赤磐市大苅田', '33', '33213', '7012221', '岡山県', 'オカヤマケン', '赤磐市', 'アカイワシ', '大苅田', 'オオカンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県赤磐市町苅田', '33', '33213', '7012222', '岡山県', 'オカヤマケン', '赤磐市', 'アカイワシ', '町苅田', 'マチカンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県赤磐市東窪田', '33', '33213', '7012223', '岡山県', 'オカヤマケン', '赤磐市', 'アカイワシ', '東窪田', 'ヒガシクボタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県赤磐市西窪田', '33', '33213', '7012224', '岡山県', 'オカヤマケン', '赤磐市', 'アカイワシ', '西窪田', 'ニシクボタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県赤磐市山口', '33', '33213', '7012225', '岡山県', 'オカヤマケン', '赤磐市', 'アカイワシ', '山口', 'ヤマグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県赤磐市由津里', '33', '33213', '7012226', '岡山県', 'オカヤマケン', '赤磐市', 'アカイワシ', '由津里', 'ユヅリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県赤磐市戸津野', '33', '33213', '7012431', '岡山県', 'オカヤマケン', '赤磐市', 'アカイワシ', '戸津野', 'トツノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県赤磐市塩木', '33', '33213', '7012432', '岡山県', 'オカヤマケン', '赤磐市', 'アカイワシ', '塩木', 'シオギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県赤磐市平山', '33', '33213', '7012433', '岡山県', 'オカヤマケン', '赤磐市', 'アカイワシ', '平山', 'ヒラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県赤磐市仁堀東', '33', '33213', '7012434', '岡山県', 'オカヤマケン', '赤磐市', 'アカイワシ', '仁堀東', 'ニボリヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県赤磐市仁堀中', '33', '33213', '7012435', '岡山県', 'オカヤマケン', '赤磐市', 'アカイワシ', '仁堀中', 'ニボリナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県赤磐市仁堀西', '33', '33213', '7012436', '岡山県', 'オカヤマケン', '赤磐市', 'アカイワシ', '仁堀西', 'ニボリニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県赤磐市中勢実', '33', '33213', '7012437', '岡山県', 'オカヤマケン', '赤磐市', 'アカイワシ', '中勢実', 'ナカセイジツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県赤磐市西勢実', '33', '33213', '7012441', '岡山県', 'オカヤマケン', '赤磐市', 'アカイワシ', '西勢実', 'ニシセイジツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県赤磐市広戸', '33', '33213', '7012442', '岡山県', 'オカヤマケン', '赤磐市', 'アカイワシ', '広戸', 'ヒロド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県赤磐市合田', '33', '33213', '7012443', '岡山県', 'オカヤマケン', '赤磐市', 'アカイワシ', '合田', 'アイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県赤磐市中畑', '33', '33213', '7012444', '岡山県', 'オカヤマケン', '赤磐市', 'アカイワシ', '中畑', 'ナカハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県赤磐市石上', '33', '33213', '7012445', '岡山県', 'オカヤマケン', '赤磐市', 'アカイワシ', '石上', 'イシカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県赤磐市小鎌', '33', '33213', '7012446', '岡山県', 'オカヤマケン', '赤磐市', 'アカイワシ', '小鎌', 'オガモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県赤磐市河原屋', '33', '33213', '7012501', '岡山県', 'オカヤマケン', '赤磐市', 'アカイワシ', '河原屋', 'カワラヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県赤磐市草生', '33', '33213', '7012502', '岡山県', 'オカヤマケン', '赤磐市', 'アカイワシ', '草生', 'クソウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県赤磐市周匝', '33', '33213', '7012503', '岡山県', 'オカヤマケン', '赤磐市', 'アカイワシ', '周匝', 'スサイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県赤磐市福田', '33', '33213', '7012504', '岡山県', 'オカヤマケン', '赤磐市', 'アカイワシ', '福田', 'フクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県赤磐市稲蒔', '33', '33213', '7012511', '岡山県', 'オカヤマケン', '赤磐市', 'アカイワシ', '稲蒔', 'イナマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県赤磐市暮田', '33', '33213', '7012512', '岡山県', 'オカヤマケン', '赤磐市', 'アカイワシ', '暮田', 'クレダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県赤磐市八島田', '33', '33213', '7012513', '岡山県', 'オカヤマケン', '赤磐市', 'アカイワシ', '八島田', 'ヤシマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県赤磐市石', '33', '33213', '7012514', '岡山県', 'オカヤマケン', '赤磐市', 'アカイワシ', '石', 'イシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県赤磐市光木', '33', '33213', '7012515', '岡山県', 'オカヤマケン', '赤磐市', 'アカイワシ', '光木', 'コウキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県赤磐市黒本', '33', '33213', '7012521', '岡山県', 'オカヤマケン', '赤磐市', 'アカイワシ', '黒本', 'クロモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県赤磐市黒沢', '33', '33213', '7012522', '岡山県', 'オカヤマケン', '赤磐市', 'アカイワシ', '黒沢', 'クロサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県赤磐市中山', '33', '33213', '7012523', '岡山県', 'オカヤマケン', '赤磐市', 'アカイワシ', '中山', 'ナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県赤磐市滝山', '33', '33213', '7012524', '岡山県', 'オカヤマケン', '赤磐市', 'アカイワシ', '滝山', 'タキヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県赤磐市是里', '33', '33213', '7012525', '岡山県', 'オカヤマケン', '赤磐市', 'アカイワシ', '是里', 'コレサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市尾谷', '33', '33215', '7012601', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '尾谷', 'オタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市真神', '33', '33215', '7012602', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '真神', 'マガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市三保原', '33', '33215', '7012603', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '三保原', 'ミホバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市福本', '33', '33215', '7012604', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '福本', 'フクモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市奥', '33', '33215', '7012605', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '奥', 'オク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市井口', '33', '33215', '7012606', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '井口', 'イグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市北', '33', '33215', '7012611', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '北', 'キタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市滝宮', '33', '33215', '7012612', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '滝宮', 'タキミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市横尾', '33', '33215', '7012613', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '横尾', 'ヨコオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市上山', '33', '33215', '7012614', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '上山', 'ウエヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市中川', '33', '33215', '7012615', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '中川', 'ナカガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市南', '33', '33215', '7012616', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '南', 'ミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市下山', '33', '33215', '7012621', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '下山', 'シモヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市鳥渕', '33', '33215', '7012622', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '鳥渕', 'トリブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市英田青野', '33', '33215', '7012623', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '英田青野', 'アイダアオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市中河内', '33', '33215', '7012624', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '中河内', 'ナカゴウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市城田', '33', '33215', '7012625', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '城田', 'ジョウデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県備前市日生町寺山', '33', '33211', '7013201', '岡山県', 'オカヤマケン', '備前市', 'ビゼンシ', '日生町寺山', 'ヒナセチョウテラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県備前市日生町寒河', '33', '33211', '7013202', '岡山県', 'オカヤマケン', '備前市', 'ビゼンシ', '日生町寒河', 'ヒナセチョウソウゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県備前市日生町大多府', '33', '33211', '7013203', '岡山県', 'オカヤマケン', '備前市', 'ビゼンシ', '日生町大多府', 'ヒナセチョウオオタブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県備前市日生町日生', '33', '33211', '7013204', '岡山県', 'オカヤマケン', '備前市', 'ビゼンシ', '日生町日生', 'ヒナセチョウヒナセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県瀬戸内市', '33', '33212', '7014200', '岡山県', 'オカヤマケン', '瀬戸内市', 'セトウチシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('87207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県瀬戸内市邑久町庄田', '33', '33212', '7014211', '岡山県', 'オカヤマケン', '瀬戸内市', 'セトウチシ', '邑久町庄田', 'オクチョウショウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県瀬戸内市邑久町尻海', '33', '33212', '7014212', '岡山県', 'オカヤマケン', '瀬戸内市', 'セトウチシ', '邑久町尻海', 'オクチョウシリミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県瀬戸内市邑久町山手', '33', '33212', '7014213', '岡山県', 'オカヤマケン', '瀬戸内市', 'セトウチシ', '邑久町山手', 'オクチョウヤマテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県瀬戸内市邑久町本庄', '33', '33212', '7014214', '岡山県', 'オカヤマケン', '瀬戸内市', 'セトウチシ', '邑久町本庄', 'オクチョウホンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県瀬戸内市邑久町上山田', '33', '33212', '7014215', '岡山県', 'オカヤマケン', '瀬戸内市', 'セトウチシ', '邑久町上山田', 'オクチョウカミヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県瀬戸内市邑久町下山田', '33', '33212', '7014216', '岡山県', 'オカヤマケン', '瀬戸内市', 'セトウチシ', '邑久町下山田', 'オクチョウシモヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県瀬戸内市邑久町尾張', '33', '33212', '7014221', '岡山県', 'オカヤマケン', '瀬戸内市', 'セトウチシ', '邑久町尾張', 'オクチョウオワリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県瀬戸内市邑久町豊安', '33', '33212', '7014222', '岡山県', 'オカヤマケン', '瀬戸内市', 'セトウチシ', '邑久町豊安', 'オクチョウトヨヤス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県瀬戸内市邑久町豊原', '33', '33212', '7014223', '岡山県', 'オカヤマケン', '瀬戸内市', 'セトウチシ', '邑久町豊原', 'オクチョウトヨハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県瀬戸内市邑久町東谷', '33', '33212', '7014224', '岡山県', 'オカヤマケン', '瀬戸内市', 'セトウチシ', '邑久町東谷', 'オクチョウヒガシダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県瀬戸内市邑久町大窪', '33', '33212', '7014231', '岡山県', 'オカヤマケン', '瀬戸内市', 'セトウチシ', '邑久町大窪', 'オクチョウオオクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県瀬戸内市邑久町北島', '33', '33212', '7014232', '岡山県', 'オカヤマケン', '瀬戸内市', 'セトウチシ', '邑久町北島', 'オクチョウキタシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県瀬戸内市邑久町向山', '33', '33212', '7014233', '岡山県', 'オカヤマケン', '瀬戸内市', 'セトウチシ', '邑久町向山', 'オクチョウムコウヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県瀬戸内市邑久町大富', '33', '33212', '7014234', '岡山県', 'オカヤマケン', '瀬戸内市', 'セトウチシ', '邑久町大富', 'オクチョウオオドミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県瀬戸内市邑久町福元', '33', '33212', '7014241', '岡山県', 'オカヤマケン', '瀬戸内市', 'セトウチシ', '邑久町福元', 'オクチョウフクモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県瀬戸内市邑久町宗三', '33', '33212', '7014243', '岡山県', 'オカヤマケン', '瀬戸内市', 'セトウチシ', '邑久町宗三', 'オクチョウソウサン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県瀬戸内市邑久町福中', '33', '33212', '7014244', '岡山県', 'オカヤマケン', '瀬戸内市', 'セトウチシ', '邑久町福中', 'オクチョウフクナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県瀬戸内市邑久町福山', '33', '33212', '7014245', '岡山県', 'オカヤマケン', '瀬戸内市', 'セトウチシ', '邑久町福山', 'オクチョウフクヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県瀬戸内市邑久町山田庄', '33', '33212', '7014246', '岡山県', 'オカヤマケン', '瀬戸内市', 'セトウチシ', '邑久町山田庄', 'オクチョウヤマダノショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県瀬戸内市邑久町下笠加', '33', '33212', '7014247', '岡山県', 'オカヤマケン', '瀬戸内市', 'セトウチシ', '邑久町下笠加', 'オクチョウシモガサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県瀬戸内市邑久町百田', '33', '33212', '7014248', '岡山県', 'オカヤマケン', '瀬戸内市', 'セトウチシ', '邑久町百田', 'オクチョウモモダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県瀬戸内市邑久町北池', '33', '33212', '7014251', '岡山県', 'オカヤマケン', '瀬戸内市', 'セトウチシ', '邑久町北池', 'オクチョウキタイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県瀬戸内市邑久町上笠加', '33', '33212', '7014252', '岡山県', 'オカヤマケン', '瀬戸内市', 'セトウチシ', '邑久町上笠加', 'オクチョウカミガサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県瀬戸内市邑久町箕輪', '33', '33212', '7014253', '岡山県', 'オカヤマケン', '瀬戸内市', 'セトウチシ', '邑久町箕輪', 'オクチョウミノワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県瀬戸内市邑久町豆田', '33', '33212', '7014254', '岡山県', 'オカヤマケン', '瀬戸内市', 'セトウチシ', '邑久町豆田', 'オクチョウマメダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県瀬戸内市長船町飯井', '33', '33212', '7014261', '岡山県', 'オカヤマケン', '瀬戸内市', 'セトウチシ', '長船町飯井', 'オサフネチョウイイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県瀬戸内市長船町東須恵', '33', '33212', '7014262', '岡山県', 'オカヤマケン', '瀬戸内市', 'セトウチシ', '長船町東須恵', 'オサフネチョウヒガシスエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県瀬戸内市長船町西須恵', '33', '33212', '7014263', '岡山県', 'オカヤマケン', '瀬戸内市', 'セトウチシ', '長船町西須恵', 'オサフネチョウニシスエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県瀬戸内市長船町土師', '33', '33212', '7014264', '岡山県', 'オカヤマケン', '瀬戸内市', 'セトウチシ', '長船町土師', 'オサフネチョウハジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県瀬戸内市長船町福岡', '33', '33212', '7014265', '岡山県', 'オカヤマケン', '瀬戸内市', 'セトウチシ', '長船町福岡', 'オサフネチョウフクオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県瀬戸内市長船町長船', '33', '33212', '7014271', '岡山県', 'オカヤマケン', '瀬戸内市', 'セトウチシ', '長船町長船', 'オサフネチョウオサフネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県瀬戸内市長船町八日市', '33', '33212', '7014272', '岡山県', 'オカヤマケン', '瀬戸内市', 'セトウチシ', '長船町八日市', 'オサフネチョウヨウカイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県瀬戸内市長船町磯上', '33', '33212', '7014273', '岡山県', 'オカヤマケン', '瀬戸内市', 'セトウチシ', '長船町磯上', 'オサフネチョウイソカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県瀬戸内市長船町牛文', '33', '33212', '7014274', '岡山県', 'オカヤマケン', '瀬戸内市', 'セトウチシ', '長船町牛文', 'オサフネチョウウシフミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県瀬戸内市長船町福里', '33', '33212', '7014275', '岡山県', 'オカヤマケン', '瀬戸内市', 'セトウチシ', '長船町福里', 'オサフネチョウフクサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県瀬戸内市長船町服部', '33', '33212', '7014276', '岡山県', 'オカヤマケン', '瀬戸内市', 'セトウチシ', '長船町服部', 'オサフネチョウハットリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県瀬戸内市牛窓町長浜', '33', '33212', '7014301', '岡山県', 'オカヤマケン', '瀬戸内市', 'セトウチシ', '牛窓町長浜', 'ウシマドチョウナガハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県瀬戸内市牛窓町牛窓', '33', '33212', '7014302', '岡山県', 'オカヤマケン', '瀬戸内市', 'セトウチシ', '牛窓町牛窓', 'ウシマドチョウウシマド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県瀬戸内市牛窓町鹿忍', '33', '33212', '7014303', '岡山県', 'オカヤマケン', '瀬戸内市', 'セトウチシ', '牛窓町鹿忍', 'ウシマドチョウカシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県瀬戸内市牛窓町千手', '33', '33212', '7014304', '岡山県', 'オカヤマケン', '瀬戸内市', 'セトウチシ', '牛窓町千手', 'ウシマドチョウセンズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県瀬戸内市邑久町虫明', '33', '33212', '7014501', '岡山県', 'オカヤマケン', '瀬戸内市', 'セトウチシ', '邑久町虫明', 'オクチョウムシアケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県瀬戸内市邑久町福谷', '33', '33212', '7014502', '岡山県', 'オカヤマケン', '瀬戸内市', 'セトウチシ', '邑久町福谷', 'オクチョウフクタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市沖元', '33', '33201', '7028001', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '沖元', 'オキモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市桑野', '33', '33201', '7028002', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '桑野', 'クワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市新築港', '33', '33201', '7028003', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '新築港', 'シンチッコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市江並', '33', '33201', '7028004', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '江並', 'エナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市江崎', '33', '33201', '7028005', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '江崎', 'エザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市藤崎', '33', '33201', '7028006', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '藤崎', 'フジサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市郡', '33', '33201', '7028011', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '郡', 'コオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市北浦', '33', '33201', '7028012', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '北浦', 'キタウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市飽浦', '33', '33201', '7028013', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '飽浦', 'アクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市宮浦', '33', '33201', '7028014', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '宮浦', 'ミヤウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市阿津', '33', '33201', '7028015', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '阿津', 'アツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市小串', '33', '33201', '7028016', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '小串', 'コグシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市福田', '33', '33201', '7028021', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '福田', 'フクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市福成', '33', '33201', '7028022', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '福成', 'フクナリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市南輝', '33', '33201', '7028023', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '南輝', 'ナンキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市浦安南町', '33', '33201', '7028024', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '浦安南町', 'ウラヤスミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市浦安西町', '33', '33201', '7028025', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '浦安西町', 'ウラヤスニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市浦安本町', '33', '33201', '7028026', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '浦安本町', 'ウラヤスホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市福富西', '33', '33201', '7028031', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '福富西', 'フクトミニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市福富中', '33', '33201', '7028032', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '福富中', 'フクトミナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市福富東', '33', '33201', '7028033', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '福富東', 'フクトミヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市福浜西町', '33', '33201', '7028034', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '福浜西町', 'フクハマニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市福浜町', '33', '33201', '7028035', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '福浜町', 'フクハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市三浜町', '33', '33201', '7028036', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '三浜町', 'ミハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市千鳥町', '33', '33201', '7028037', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '千鳥町', 'チドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市松浜町', '33', '33201', '7028038', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '松浜町', 'マツハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市富浜町', '33', '33201', '7028041', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '富浜町', 'トミハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市洲崎', '33', '33201', '7028042', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '洲崎', 'スザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市平福', '33', '33201', '7028043', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '平福', 'ヒラフク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市福島', '33', '33201', '7028044', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '福島', 'フクシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市海岸通', '33', '33201', '7028045', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '海岸通', 'カイガンドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市立川町', '33', '33201', '7028046', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '立川町', 'タチカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市若葉町', '33', '33201', '7028047', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '若葉町', 'ワカバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市福吉町', '33', '33201', '7028048', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '福吉町', 'フクヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市築港元町', '33', '33201', '7028051', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '築港元町', 'チッコウモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市市場', '33', '33201', '7028052', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '市場', 'シジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市築港栄町', '33', '33201', '7028053', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '築港栄町', 'チッコウサカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市築港ひかり町', '33', '33201', '7028054', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '築港ひかり町', 'チッコウヒカリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市築港緑町', '33', '33201', '7028055', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '築港緑町', 'チッコウミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市築港新町', '33', '33201', '7028056', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '築港新町', 'チッコウシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市あけぼの町', '33', '33201', '7028057', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', 'あけぼの町', 'アケボノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市並木町', '33', '33201', '7028058', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '並木町', 'ナミキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市四御神', '33', '33201', '7038201', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '四御神', 'シノゴゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市湯迫', '33', '33201', '7038202', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '湯迫', 'ユバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市国府市場', '33', '33201', '7038203', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '国府市場', 'コクフイチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市雄町', '33', '33201', '7038204', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '雄町', 'オマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市中井', '33', '33201', '7038205', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '中井', 'ナカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市賞田', '33', '33201', '7038206', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '賞田', 'ショウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市祇園', '33', '33201', '7038207', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '祇園', 'ギオン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市今在家', '33', '33201', '7038208', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '今在家', 'イマザイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市矢津', '33', '33201', '7038211', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '矢津', 'ヤヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市古都宿', '33', '33201', '7038212', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '古都宿', 'コズシュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市藤井', '33', '33201', '7038213', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '藤井', 'フジイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市鉄', '33', '33201', '7038214', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '鉄', 'クロガネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市古都南方', '33', '33201', '7038215', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '古都南方', 'コズミナミガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市宍甘', '33', '33201', '7038216', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '宍甘', 'シジカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市土田', '33', '33201', '7038217', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '土田', 'ツチダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市長岡', '33', '33201', '7038221', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '長岡', 'ナガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市下', '33', '33201', '7038222', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '下', 'シモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市長利', '33', '33201', '7038223', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '長利', 'ナガトシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市米田', '33', '33201', '7038224', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '米田', 'ヨネダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市神下', '33', '33201', '7038225', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '神下', 'コウジタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市今谷', '33', '33201', '7038226', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '今谷', 'イマダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市兼基', '33', '33201', '7038227', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '兼基', 'カネモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市乙多見', '33', '33201', '7038228', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '乙多見', 'オタミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市赤田', '33', '33201', '7038231', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '赤田', 'アコダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市関', '33', '33201', '7038232', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '関', 'セキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市高屋', '33', '33201', '7038233', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '高屋', 'タカヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市沢田', '33', '33201', '7038234', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '沢田', 'サワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市原尾島', '33', '33201', '7038235', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '原尾島', 'ハラオシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市国富', '33', '33201', '7038236', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '国富', 'クニトミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市森下町', '33', '33201', '7038237', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '森下町', 'モリシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市住吉町', '33', '33201', '7038238', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '住吉町', 'スミヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市高島新屋敷', '33', '33201', '7038241', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '高島新屋敷', 'タカシマシンヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市高島', '33', '33201', '7038242', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '高島', 'タカシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市清水', '33', '33201', '7038243', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '清水', 'シミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市藤原西町', '33', '33201', '7038244', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '藤原西町', 'フジワラニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市藤原', '33', '33201', '7038245', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '藤原', 'フジワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市藤原光町', '33', '33201', '7038246', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '藤原光町', 'フジワラヒカリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市さい東町', '33', '33201', '7038247', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', 'さい東町', 'サイヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市さい', '33', '33201', '7038248', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', 'さい', 'サイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市竹田', '33', '33201', '7038251', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '竹田', 'タケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市中島', '33', '33201', '7038252', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '中島', 'ナカシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市八幡東町', '33', '33201', '7038253', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '八幡東町', 'ヤハタヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市八幡', '33', '33201', '7038254', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '八幡', 'ヤハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市東川原', '33', '33201', '7038255', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '東川原', 'ヒガシガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市浜', '33', '33201', '7038256', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '浜', 'ハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市後楽園', '33', '33201', '7038257', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '後楽園', 'コウラクエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市西川原', '33', '33201', '7038258', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '西川原', 'ニシガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市海吉', '33', '33201', '7038261', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '海吉', 'ミヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市福泊', '33', '33201', '7038262', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '福泊', 'フクドマリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市倉益', '33', '33201', '7038263', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '倉益', 'クラマス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市倉富', '33', '33201', '7038264', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '倉富', 'クラトミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市倉田', '33', '33201', '7038265', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '倉田', 'クラタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市湊', '33', '33201', '7038266', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '湊', 'ミナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市山崎', '33', '33201', '7038267', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '山崎', 'ヤマサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市円山', '33', '33201', '7038271', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '円山', 'マルヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市奥市', '33', '33201', '7038272', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '奥市', 'オクイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市門田文化町', '33', '33201', '7038273', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '門田文化町', 'カドタブンカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市門田本町', '33', '33201', '7038274', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '門田本町', 'カドタホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市門田屋敷', '33', '33201', '7038275', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '門田屋敷', 'カドタヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市門田屋敷本町', '33', '33201', '7038276', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '門田屋敷本町', 'カドタヤシキホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市御成町', '33', '33201', '7038277', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '御成町', 'オナリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市古京町', '33', '33201', '7038278', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '古京町', 'フルギョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市東山', '33', '33201', '7038281', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '東山', 'ヒガシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市平井', '33', '33201', '7038282', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '平井', 'ヒライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市赤坂南新町', '33', '33201', '7038283', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '赤坂南新町', 'アカサカミナミシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市網浜', '33', '33201', '7038284', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '網浜', 'アミノハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市桜橋', '33', '33201', '7038285', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '桜橋', 'サクラバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市旭東町', '33', '33201', '7038286', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '旭東町', 'キョクトウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市赤坂台', '33', '33201', '7038287', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '赤坂台', 'アカサカダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市赤坂本町', '33', '33201', '7038288', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '赤坂本町', 'アカサカホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市徳吉町', '33', '33201', '7038291', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '徳吉町', 'トクヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市中納言町', '33', '33201', '7038292', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '中納言町', 'チュウナゴンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市小橋町', '33', '33201', '7038293', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '小橋町', 'コバシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市新京橋', '33', '33201', '7038294', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '新京橋', 'シンキョウバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市御幸町', '33', '33201', '7038295', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '御幸町', 'ミユキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市さくら住座', '33', '33201', '7038296', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', 'さくら住座', 'サクラジュウザ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市東中島町', '33', '33201', '7038297', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '東中島町', 'ヒガシナカジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市西中島町', '33', '33201', '7038298', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '西中島町', 'ニシナカジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市西隆寺', '33', '33201', '7048101', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '西隆寺', 'サイリュウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市久保', '33', '33201', '7048102', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '久保', 'クボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市河本町', '33', '33201', '7048103', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '河本町', 'コウモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市富崎', '33', '33201', '7048104', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '富崎', 'トミサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市吉原', '33', '33201', '7048105', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '吉原', 'ヨシワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市西庄', '33', '33201', '7048106', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '西庄', 'ニシショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市福治', '33', '33201', '7048107', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '福治', 'フクジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市西大寺北', '33', '33201', '7048111', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '西大寺北', 'サイダイジキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市西大寺上', '33', '33201', '7048112', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '西大寺上', 'サイダイジカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市西大寺', '33', '33201', '7048113', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '西大寺', 'サイダイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市西大寺東', '33', '33201', '7048114', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '西大寺東', 'サイダイジヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市向州', '33', '33201', '7048115', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '向州', 'ムコウス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市西大寺中', '33', '33201', '7048116', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '西大寺中', 'サイダイジナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市西大寺南', '33', '33201', '7048117', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '西大寺南', 'サイダイジミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市西大寺射越', '33', '33201', '7048121', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '西大寺射越', 'サイダイジイコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市西大寺新地', '33', '33201', '7048122', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '西大寺新地', 'サイダイジシンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市西大寺門前', '33', '33201', '7048123', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '西大寺門前', 'サイダイジモンゼン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市西大寺五明', '33', '33201', '7048124', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '西大寺五明', 'サイダイジゴミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市西大寺川口', '33', '33201', '7048125', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '西大寺川口', 'サイダイジカワグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市西大寺浜', '33', '33201', '7048126', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '西大寺浜', 'サイダイジハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市西大寺新', '33', '33201', '7048127', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '西大寺新', 'サイダイジシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市長沼', '33', '33201', '7048131', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '長沼', 'ナガヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市邑久郷', '33', '33201', '7048132', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '邑久郷', 'オクノゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市宿毛', '33', '33201', '7048133', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '宿毛', 'シュクモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市北幸田', '33', '33201', '7048134', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '北幸田', 'キタコウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市東幸西', '33', '33201', '7048135', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '東幸西', 'ヒガシコウザイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市西幸西', '33', '33201', '7048136', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '西幸西', 'ニシコウザイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市乙子', '33', '33201', '7048137', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '乙子', 'オトゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市神崎町', '33', '33201', '7048138', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '神崎町', 'カンザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市下阿知', '33', '33201', '7048141', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '下阿知', 'シモアチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市上阿知', '33', '33201', '7048142', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '上阿知', 'カミアチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市千手', '33', '33201', '7048143', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '千手', 'センジュ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市西大寺一宮', '33', '33201', '7048144', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '西大寺一宮', 'サイダイジイチノミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市東幸崎', '33', '33201', '7048145', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '東幸崎', 'ヒガシコウザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市南水門町', '33', '33201', '7048146', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '南水門町', 'ミナミスイモンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市正儀', '33', '33201', '7048147', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '正儀', 'マサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市水門町', '33', '33201', '7048148', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '水門町', 'スイモンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市幸地崎町', '33', '33201', '7048149', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '幸地崎町', 'コウチザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市東片岡', '33', '33201', '7048151', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '東片岡', 'ヒガシカタオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市宝伝', '33', '33201', '7048152', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '宝伝', 'ホウデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市犬島', '33', '33201', '7048153', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '犬島', 'イヌジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市久々井', '33', '33201', '7048154', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '久々井', 'クグイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市西片岡', '33', '33201', '7048155', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '西片岡', 'ニシカタオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市九蟠', '33', '33201', '7048161', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '九蟠', 'クバン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市豊田', '33', '33201', '7048162', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '豊田', 'トヨタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市升田', '33', '33201', '7048163', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '升田', 'マスダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市光津', '33', '33201', '7048164', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '光津', 'コウツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市政津', '33', '33201', '7048165', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '政津', 'マサツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市君津', '33', '33201', '7048166', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '君津', 'キミツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市目黒町', '33', '33201', '7048171', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '目黒町', 'メグロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市大多羅町', '33', '33201', '7048172', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '大多羅町', 'オオダラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市可知', '33', '33201', '7048173', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '可知', 'カチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市松新町', '33', '33201', '7048174', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '松新町', 'マツシンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市益野町', '33', '33201', '7048175', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '益野町', 'マスノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市中川町', '33', '33201', '7048176', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '中川町', 'ナカガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市浅越', '33', '33201', '7048181', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '浅越', 'アサゴエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市広谷', '33', '33201', '7048182', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '広谷', 'ヒロタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市西大寺松崎', '33', '33201', '7048183', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '西大寺松崎', 'サイダイジマツザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市富士見町', '33', '33201', '7048184', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '富士見町', 'フジミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市西大寺中野', '33', '33201', '7048191', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '西大寺中野', 'サイダイジナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市西大寺中野本町', '33', '33201', '7048192', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '西大寺中野本町', 'サイダイジナカノホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市金岡西町', '33', '33201', '7048193', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '金岡西町', 'カナオカニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市金岡東町', '33', '33201', '7048194', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '金岡東町', 'カナオカヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市西大寺金岡', '33', '33201', '7048195', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '西大寺金岡', 'サイダイジカナオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市金田', '33', '33201', '7048196', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '金田', 'カナダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県備前市', '33', '33211', '7050000', '岡山県', 'オカヤマケン', '備前市', 'ビゼンシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('87491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県備前市伊部', '33', '33211', '7050001', '岡山県', 'オカヤマケン', '備前市', 'ビゼンシ', '伊部', 'インベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県備前市浦伊部', '33', '33211', '7050002', '岡山県', 'オカヤマケン', '備前市', 'ビゼンシ', '浦伊部', 'ウラインベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県備前市大内', '33', '33211', '7050003', '岡山県', 'オカヤマケン', '備前市', 'ビゼンシ', '大内', 'オオチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県備前市香登西', '33', '33211', '7050011', '岡山県', 'オカヤマケン', '備前市', 'ビゼンシ', '香登西', 'カガトニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県備前市香登本', '33', '33211', '7050012', '岡山県', 'オカヤマケン', '備前市', 'ビゼンシ', '香登本', 'カガトモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県備前市福田', '33', '33211', '7050013', '岡山県', 'オカヤマケン', '備前市', 'ビゼンシ', '福田', 'フクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県備前市新庄', '33', '33211', '7050014', '岡山県', 'オカヤマケン', '備前市', 'ビゼンシ', '新庄', 'シンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県備前市畠田', '33', '33211', '7050015', '岡山県', 'オカヤマケン', '備前市', 'ビゼンシ', '畠田', 'ハタケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県備前市坂根', '33', '33211', '7050016', '岡山県', 'オカヤマケン', '備前市', 'ビゼンシ', '坂根', 'サカネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県備前市西片上', '33', '33211', '7050021', '岡山県', 'オカヤマケン', '備前市', 'ビゼンシ', '西片上', 'ニシカタカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県備前市東片上', '33', '33211', '7050022', '岡山県', 'オカヤマケン', '備前市', 'ビゼンシ', '東片上', 'ヒガシカタカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県備前市伊里中', '33', '33211', '7050023', '岡山県', 'オカヤマケン', '備前市', 'ビゼンシ', '伊里中', 'イリナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県備前市久々井', '33', '33211', '7050024', '岡山県', 'オカヤマケン', '備前市', 'ビゼンシ', '久々井', 'クグイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県備前市鶴海', '33', '33211', '7050025', '岡山県', 'オカヤマケン', '備前市', 'ビゼンシ', '鶴海', 'ツルミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県備前市佐山', '33', '33211', '7050026', '岡山県', 'オカヤマケン', '備前市', 'ビゼンシ', '佐山', 'サヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県備前市蕃山', '33', '33211', '7050031', '岡山県', 'オカヤマケン', '備前市', 'ビゼンシ', '蕃山', 'シゲヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県備前市麻宇那', '33', '33211', '7050032', '岡山県', 'オカヤマケン', '備前市', 'ビゼンシ', '麻宇那', 'アソウナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県備前市穂浪', '33', '33211', '7050033', '岡山県', 'オカヤマケン', '備前市', 'ビゼンシ', '穂浪', 'ホナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県備前市友延', '33', '33211', '7050034', '岡山県', 'オカヤマケン', '備前市', 'ビゼンシ', '友延', 'トモノブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県備前市木谷', '33', '33211', '7050035', '岡山県', 'オカヤマケン', '備前市', 'ビゼンシ', '木谷', 'キダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県備前市閑谷', '33', '33211', '7050036', '岡山県', 'オカヤマケン', '備前市', 'ビゼンシ', '閑谷', 'シズタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県備前市野谷', '33', '33211', '7050131', '岡山県', 'オカヤマケン', '備前市', 'ビゼンシ', '野谷', 'ノダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県備前市三石', '33', '33211', '7050132', '岡山県', 'オカヤマケン', '備前市', 'ビゼンシ', '三石', 'ミツイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県備前市八木山', '33', '33211', '7050133', '岡山県', 'オカヤマケン', '備前市', 'ビゼンシ', '八木山', 'ヤキヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県玉野市', '33', '33204', '7060000', '岡山県', 'オカヤマケン', '玉野市', 'タマノシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('87531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県玉野市田井', '33', '33204', '7060001', '岡山県', 'オカヤマケン', '玉野市', 'タマノシ', '田井', 'タイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県玉野市築港', '33', '33204', '7060002', '岡山県', 'オカヤマケン', '玉野市', 'タマノシ', '築港', 'チッコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県玉野市宇野', '33', '33204', '7060011', '岡山県', 'オカヤマケン', '玉野市', 'タマノシ', '宇野', 'ウノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県玉野市玉', '33', '33204', '7060012', '岡山県', 'オカヤマケン', '玉野市', 'タマノシ', '玉', 'タマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県玉野市奥玉', '33', '33204', '7060013', '岡山県', 'オカヤマケン', '玉野市', 'タマノシ', '奥玉', 'オクタマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県玉野市玉原', '33', '33204', '7060014', '岡山県', 'オカヤマケン', '玉野市', 'タマノシ', '玉原', 'タマハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県玉野市和田', '33', '33204', '7060021', '岡山県', 'オカヤマケン', '玉野市', 'タマノシ', '和田', 'ワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県玉野市向日比', '33', '33204', '7060022', '岡山県', 'オカヤマケン', '玉野市', 'タマノシ', '向日比', 'ムカイヒビ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県玉野市深井町', '33', '33204', '7060023', '岡山県', 'オカヤマケン', '玉野市', 'タマノシ', '深井町', 'フカイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県玉野市御崎', '33', '33204', '7060024', '岡山県', 'オカヤマケン', '玉野市', 'タマノシ', '御崎', 'オンザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県玉野市明神町', '33', '33204', '7060025', '岡山県', 'オカヤマケン', '玉野市', 'タマノシ', '明神町', 'ミョウジンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県玉野市羽根崎町', '33', '33204', '7060026', '岡山県', 'オカヤマケン', '玉野市', 'タマノシ', '羽根崎町', 'ハネザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県玉野市日比', '33', '33204', '7060027', '岡山県', 'オカヤマケン', '玉野市', 'タマノシ', '日比', 'ヒビ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県玉野市渋川', '33', '33204', '7060028', '岡山県', 'オカヤマケン', '玉野市', 'タマノシ', '渋川', 'シブカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県玉野市東紅陽台', '33', '33204', '7060131', '岡山県', 'オカヤマケン', '玉野市', 'タマノシ', '東紅陽台', 'ヒガシコウヨウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県玉野市用吉', '33', '33204', '7060132', '岡山県', 'オカヤマケン', '玉野市', 'タマノシ', '用吉', 'モチヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県玉野市宇藤木', '33', '33204', '7060133', '岡山県', 'オカヤマケン', '玉野市', 'タマノシ', '宇藤木', 'ウトウギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県玉野市東高崎', '33', '33204', '7060134', '岡山県', 'オカヤマケン', '玉野市', 'タマノシ', '東高崎', 'ヒガシタカサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県玉野市槌ケ原', '33', '33204', '7060141', '岡山県', 'オカヤマケン', '玉野市', 'タマノシ', '槌ケ原', 'ツチガハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県玉野市迫間', '33', '33204', '7060142', '岡山県', 'オカヤマケン', '玉野市', 'タマノシ', '迫間', 'ハザマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県玉野市木目', '33', '33204', '7060143', '岡山県', 'オカヤマケン', '玉野市', 'タマノシ', '木目', 'モクメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県玉野市小島地', '33', '33204', '7060144', '岡山県', 'オカヤマケン', '玉野市', 'タマノシ', '小島地', 'コシマジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県玉野市長尾', '33', '33204', '7060151', '岡山県', 'オカヤマケン', '玉野市', 'タマノシ', '長尾', 'ナガオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県玉野市永井', '33', '33204', '7060152', '岡山県', 'オカヤマケン', '玉野市', 'タマノシ', '永井', 'ナガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県玉野市滝', '33', '33204', '7060153', '岡山県', 'オカヤマケン', '玉野市', 'タマノシ', '滝', 'タキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県玉野市広岡', '33', '33204', '7060154', '岡山県', 'オカヤマケン', '玉野市', 'タマノシ', '広岡', 'ヒロオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県玉野市八浜町八浜', '33', '33204', '7060221', '岡山県', 'オカヤマケン', '玉野市', 'タマノシ', '八浜町八浜', 'ハチハマチョウハチハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県玉野市八浜町見石', '33', '33204', '7060222', '岡山県', 'オカヤマケン', '玉野市', 'タマノシ', '八浜町見石', 'ハチハマチョウミイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県玉野市八浜町波知', '33', '33204', '7060223', '岡山県', 'オカヤマケン', '玉野市', 'タマノシ', '八浜町波知', 'ハチハマチョウハチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県玉野市八浜町大崎', '33', '33204', '7060224', '岡山県', 'オカヤマケン', '玉野市', 'タマノシ', '八浜町大崎', 'ハチハマチョウオオサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県玉野市南七区', '33', '33204', '7060225', '岡山県', 'オカヤマケン', '玉野市', 'タマノシ', '南七区', 'ミナミナナク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県玉野市東七区', '33', '33204', '7060226', '岡山県', 'オカヤマケン', '玉野市', 'タマノシ', '東七区', 'ヒガシナナク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県玉野市北方', '33', '33204', '7060301', '岡山県', 'オカヤマケン', '玉野市', 'タマノシ', '北方', 'キタガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県玉野市下山坂', '33', '33204', '7060302', '岡山県', 'オカヤマケン', '玉野市', 'タマノシ', '下山坂', 'シモヤマサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県玉野市上山坂', '33', '33204', '7060303', '岡山県', 'オカヤマケン', '玉野市', 'タマノシ', '上山坂', 'カミヤマサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県玉野市番田', '33', '33204', '7060304', '岡山県', 'オカヤマケン', '玉野市', 'タマノシ', '番田', 'バンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県玉野市胸上', '33', '33204', '7060305', '岡山県', 'オカヤマケン', '玉野市', 'タマノシ', '胸上', 'ムネアゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県玉野市石島', '33', '33204', '7060306', '岡山県', 'オカヤマケン', '玉野市', 'タマノシ', '石島', 'イシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県玉野市梶岡', '33', '33204', '7060311', '岡山県', 'オカヤマケン', '玉野市', 'タマノシ', '梶岡', 'カジオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県玉野市東田井地', '33', '33204', '7060312', '岡山県', 'オカヤマケン', '玉野市', 'タマノシ', '東田井地', 'ヒガシタイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県玉野市西田井地', '33', '33204', '7060313', '岡山県', 'オカヤマケン', '玉野市', 'タマノシ', '西田井地', 'ニシタイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県玉野市東野崎', '33', '33204', '7060314', '岡山県', 'オカヤマケン', '玉野市', 'タマノシ', '東野崎', 'ヒガシノザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県玉野市山田', '33', '33204', '7060314', '岡山県', 'オカヤマケン', '玉野市', 'タマノシ', '山田', 'ヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県玉野市後閑', '33', '33204', '7060315', '岡山県', 'オカヤマケン', '玉野市', 'タマノシ', '後閑', 'ゴカン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県玉野市沼', '33', '33204', '7060316', '岡山県', 'オカヤマケン', '玉野市', 'タマノシ', '沼', 'ヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県玉野市大薮', '33', '33204', '7060317', '岡山県', 'オカヤマケン', '玉野市', 'タマノシ', '大薮', 'オオヤブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市', '33', '33215', '7070000', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('87586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市上相', '33', '33215', '7070001', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '上相', 'カミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市中尾', '33', '33215', '7070002', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '中尾', 'ナカオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市明見', '33', '33215', '7070003', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '明見', 'ミョウケン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市入田', '33', '33215', '7070004', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '入田', 'ニュウタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市大井が丘', '33', '33215', '7070005', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '大井が丘', 'オオイガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市和田', '33', '33215', '7070011', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '和田', 'ワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市田殿', '33', '33215', '7070012', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '田殿', 'タドノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市吉', '33', '33215', '7070013', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '吉', 'ヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市北山', '33', '33215', '7070014', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '北山', 'キタヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市豊国原', '33', '33215', '7070015', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '豊国原', 'トヨクニハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市下香山', '33', '33215', '7070016', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '下香山', 'シモカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市楢原中', '33', '33215', '7070021', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '楢原中', 'ナラハラナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市楢原上', '33', '33215', '7070022', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '楢原上', 'ナラハラカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市平福', '33', '33215', '7070023', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '平福', 'ヒラフク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市楢原下', '33', '33215', '7070024', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '楢原下', 'ナラハラシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市栄町', '33', '33215', '7070025', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市山口', '33', '33215', '7070031', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '山口', 'ヤマグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市山外野', '33', '33215', '7070032', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '山外野', 'ヤマトノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市大原', '33', '33215', '7070033', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '大原', 'オオバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市猪臥', '33', '33215', '7070034', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '猪臥', 'イブシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市平田', '33', '33215', '7070035', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '平田', 'ヒラタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市北原', '33', '33215', '7070036', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '北原', 'キタバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市友野', '33', '33215', '7070037', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '友野', 'トモノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市林野', '33', '33215', '7070041', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '林野', 'ハヤシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市朽木', '33', '33215', '7070042', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '朽木', 'クツギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市海内', '33', '33215', '7070043', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '海内', 'ミウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市海田', '33', '33215', '7070044', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '海田', 'カイタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市巨勢', '33', '33215', '7070045', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '巨勢', 'コセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市三倉田', '33', '33215', '7070046', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '三倉田', 'ミクラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市稲穂', '33', '33215', '7070051', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '稲穂', 'イナホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市位田', '33', '33215', '7070052', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '位田', 'イデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市安蘇', '33', '33215', '7070053', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '安蘇', 'アソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市岩見田', '33', '33215', '7070054', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '岩見田', 'イワミダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市金原', '33', '33215', '7070055', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '金原', 'カナハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市長内', '33', '33215', '7070056', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '長内', 'ナガウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市則平', '33', '33215', '7070057', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '則平', 'ノリヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市中山', '33', '33215', '7070061', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '中山', 'ナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市湯郷', '33', '33215', '7070062', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '湯郷', 'ユノゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市北坂', '33', '33215', '7070063', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '北坂', 'キタサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市殿所', '33', '33215', '7070064', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '殿所', 'トノドコロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市青木', '33', '33215', '7070065', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '青木', 'アオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市下大谷', '33', '33215', '7070066', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '下大谷', 'シモオオタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市奥大谷', '33', '33215', '7070067', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '奥大谷', 'オクオオタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市久賀', '33', '33215', '7070111', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '久賀', 'クガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市余野', '33', '33215', '7070112', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '余野', 'ヨノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市真加部', '33', '33215', '7070113', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '真加部', 'マカベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市長谷内', '33', '33215', '7070121', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '長谷内', 'ハセウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市馬形', '33', '33215', '7070122', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '馬形', 'マガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市宗掛', '33', '33215', '7070123', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '宗掛', 'ムナカケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市大町', '33', '33215', '7070124', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '大町', 'オオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市河内', '33', '33215', '7070131', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '河内', 'コウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市小畑', '33', '33215', '7070132', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '小畑', 'オバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市杉原', '33', '33215', '7070133', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '杉原', 'スギハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市矢田', '33', '33215', '7070134', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '矢田', 'ヤタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市梶並', '33', '33215', '7070201', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '梶並', 'カジナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市楮', '33', '33215', '7070202', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '楮', 'コウゾ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市真殿', '33', '33215', '7070203', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '真殿', 'マトノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市右手', '33', '33215', '7070204', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '右手', 'ウテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市東谷上', '33', '33215', '7070205', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '東谷上', 'ヒガシダニカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市東谷下', '33', '33215', '7070206', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '東谷下', 'ヒガシダニシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市後山', '33', '33215', '7070401', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '後山', 'ウシロヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市中谷', '33', '33215', '7070402', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '中谷', 'ナカダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市東青野', '33', '33215', '7070403', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '東青野', 'ヒガシアオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市太田', '33', '33215', '7070404', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '太田', 'オオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市野原', '33', '33215', '7070405', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '野原', 'ノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市東吉田', '33', '33215', '7070406', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '東吉田', 'ヒガシヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市川東', '33', '33215', '7070407', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '川東', 'カワヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市江ノ原', '33', '33215', '7070411', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '江ノ原', 'エノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市古町', '33', '33215', '7070412', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '古町', 'フルマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市中町', '33', '33215', '7070413', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '中町', 'ナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市西町', '33', '33215', '7070414', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '西町', 'ニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市宮本', '33', '33215', '7070415', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '宮本', 'ミヤモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市今岡', '33', '33215', '7070416', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '今岡', 'イマオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市下町', '33', '33215', '7070417', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '下町', 'シモマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市川上', '33', '33215', '7070421', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '川上', 'カワカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市笹岡', '33', '33215', '7070422', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '笹岡', 'ササオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市小原田', '33', '33215', '7070423', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '小原田', 'オハラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市野形', '33', '33215', '7070424', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '野形', 'ノガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市下庄町', '33', '33215', '7070425', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '下庄町', 'シモショウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市桂坪', '33', '33215', '7070426', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '桂坪', 'カツラツボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市滝', '33', '33215', '7070427', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '滝', 'タキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市田井', '33', '33215', '7070431', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '田井', 'タイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市赤田', '33', '33215', '7070432', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '赤田', 'アカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市立石', '33', '33215', '7070433', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '立石', 'タテイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市壬生', '33', '33215', '7070434', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '壬生', 'ミブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市沢田', '33', '33215', '7070435', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '沢田', 'サワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市川戸', '33', '33215', '7070436', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '川戸', 'カワト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市粟野', '33', '33215', '7070437', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '粟野', 'アワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県英田郡西粟倉村', '33', '33643', '7070500', '岡山県', 'オカヤマケン', '英田郡西粟倉村', 'アイダグンニシアワクラソン', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('87675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県英田郡西粟倉村大茅', '33', '33643', '7070501', '岡山県', 'オカヤマケン', '英田郡西粟倉村', 'アイダグンニシアワクラソン', '大茅', 'オオガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県英田郡西粟倉村坂根', '33', '33643', '7070502', '岡山県', 'オカヤマケン', '英田郡西粟倉村', 'アイダグンニシアワクラソン', '坂根', 'サカネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県英田郡西粟倉村影石', '33', '33643', '7070503', '岡山県', 'オカヤマケン', '英田郡西粟倉村', 'アイダグンニシアワクラソン', '影石', 'カゲイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県英田郡西粟倉村長尾', '33', '33643', '7070504', '岡山県', 'オカヤマケン', '英田郡西粟倉村', 'アイダグンニシアワクラソン', '長尾', 'ナガオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県英田郡西粟倉村筏津', '33', '33643', '7070505', '岡山県', 'オカヤマケン', '英田郡西粟倉村', 'アイダグンニシアワクラソン', '筏津', 'イカダツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県英田郡西粟倉村知社', '33', '33643', '7070506', '岡山県', 'オカヤマケン', '英田郡西粟倉村', 'アイダグンニシアワクラソン', '知社', 'チシャ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市', '33', '33203', '7080000', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('87685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市小原', '33', '33203', '7080001', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '小原', 'オバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市上河原', '33', '33203', '7080002', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '上河原', 'カミガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市北園町', '33', '33203', '7080003', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '北園町', 'キタゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市山北', '33', '33203', '7080004', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '山北', 'ヤマキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市城代町', '33', '33203', '7080005', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '城代町', 'ジョウダイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市小田中', '33', '33203', '7080006', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '小田中', 'オダナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市総社', '33', '33203', '7080007', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '総社', 'ソウジャ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市神楽1条', '01', '01204', '0708001', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '神楽1条', 'カグラ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市上田邑', '33', '33203', '7080011', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '上田邑', 'カミタノムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市下田邑', '33', '33203', '7080012', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '下田邑', 'シモタノムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市二宮', '33', '33203', '7080013', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '二宮', 'ニノミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市院庄', '33', '33203', '7080014', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '院庄', 'インノショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市神戸', '33', '33203', '7080015', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '神戸', 'ジンゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市戸島', '33', '33203', '7080016', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '戸島', 'トシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市神楽2条', '01', '01204', '0708002', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '神楽2条', 'カグラ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市北町', '33', '33203', '7080021', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '北町', 'キタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市山下', '33', '33203', '7080022', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '山下', 'サンゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市大手町', '33', '33203', '7080023', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '大手町', 'オオテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市二階町', '33', '33203', '7080024', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '二階町', 'ニカイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市神楽3条', '01', '01204', '0708003', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '神楽3条', 'カグラ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市材木町', '33', '33203', '7080031', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '材木町', 'ザイモクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市伏見町', '33', '33203', '7080032', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '伏見町', 'フシミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市河原町', '33', '33203', '7080033', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '河原町', 'カワラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市船頭町', '33', '33203', '7080034', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '船頭町', 'センドウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市吹屋町', '33', '33203', '7080035', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '吹屋町', 'フキヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市南新座', '33', '33203', '7080036', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '南新座', 'ミナミシンザ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市戸川町', '33', '33203', '7080037', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '戸川町', 'トガワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市神楽4条', '01', '01204', '0708004', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '神楽4条', 'カグラ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市鉄砲町', '33', '33203', '7080041', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '鉄砲町', 'テッポウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市新茅町', '33', '33203', '7080042', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '新茅町', 'シンカヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市茅町', '33', '33203', '7080043', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '茅町', 'カヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市安岡町', '33', '33203', '7080044', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '安岡町', 'ヤスオカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市西寺町', '33', '33203', '7080045', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '西寺町', 'ニシテラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市西今町', '33', '33203', '7080046', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '西今町', 'ニシイママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市宮脇町', '33', '33203', '7080047', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '宮脇町', 'ミヤワキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市神楽5条', '01', '01204', '0708005', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '神楽5条', 'カグラ05ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市椿高下', '33', '33203', '7080051', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '椿高下', 'ツバキコウゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市田町', '33', '33203', '7080052', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '田町', 'タマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市細工町', '33', '33203', '7080053', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '細工町', 'サイクノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市神楽6条', '01', '01204', '0708006', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '神楽6条', 'カグラ06ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市元魚町', '33', '33203', '7080061', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '元魚町', 'モトウオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市京町', '33', '33203', '7080062', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '京町', 'キョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市小性町', '33', '33203', '7080063', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '小性町', 'コショウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市堺町', '33', '33203', '7080064', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '堺町', 'サカイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市新魚町', '33', '33203', '7080065', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '新魚町', 'シンウオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市桶屋町', '33', '33203', '7080066', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '桶屋町', 'オケヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市新職人町', '33', '33203', '7080067', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '新職人町', 'シンショクニンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市神楽7条', '01', '01204', '0708007', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '神楽7条', 'カグラ07ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市下紺屋町', '33', '33203', '7080071', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '下紺屋町', 'シモコウヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市美濃町', '33', '33203', '7080072', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '美濃町', 'ミノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市本町', '33', '33203', '7080073', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市福渡町', '33', '33203', '7080074', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '福渡町', 'フクワタリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市坪井町', '33', '33203', '7080075', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '坪井町', 'ツボイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市上紺屋町', '33', '33203', '7080076', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '上紺屋町', 'カミコウヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市鍛治町', '33', '33203', '7080077', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '鍛治町', 'カジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区東苗穂1条', '01', '01103', '0070801', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '東苗穂1条', 'ヒガシナエボ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市神居1条', '01', '01204', '0708011', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '神居1条', 'カムイ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市神居2条', '01', '01204', '0708012', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '神居2条', 'カムイ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市神居3条', '01', '01204', '0708013', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '神居3条', 'カムイ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市神居4条', '01', '01204', '0708014', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '神居4条', 'カムイ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市神居5条', '01', '01204', '0708015', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '神居5条', 'カムイ05ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市神居6条', '01', '01204', '0708016', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '神居6条', 'カムイ06ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市神居7条', '01', '01204', '0708017', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '神居7条', 'カムイ07ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市神居8条', '01', '01204', '0708018', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '神居8条', 'カムイ08ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市神居9条', '01', '01204', '0708019', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '神居9条', 'カムイ09ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区東苗穂2条', '01', '01103', '0070802', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '東苗穂2条', 'ヒガシナエボ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市神居町忠和', '01', '01204', '0708021', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '神居町忠和', 'カムイチョウチュウワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市神居町台場', '01', '01204', '0708022', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '神居町台場', 'カムイチョウダイバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市神居町春志内', '01', '01204', '0708023', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '神居町春志内', 'カムイチョウハルシナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市神居町富沢', '01', '01204', '0708024', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '神居町富沢', 'カムイチョウトミサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市神居町富岡', '01', '01204', '0708025', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '神居町富岡', 'カムイチョウトミオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市神居町神岡', '01', '01204', '0708026', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '神居町神岡', 'カムイチョウカミオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市台場東', '01', '01204', '0708027', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '台場東', 'ダイバヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市南が丘', '01', '01204', '0708028', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '南が丘', 'ミナミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区東苗穂3条', '01', '01103', '0070803', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '東苗穂3条', 'ヒガシナエボ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県苫田郡鏡野町', '33', '33606', '7080300', '岡山県', 'オカヤマケン', '苫田郡鏡野町', 'トマタグンカガミノチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('87761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県苫田郡鏡野町越畑', '33', '33606', '7080301', '岡山県', 'オカヤマケン', '苫田郡鏡野町', 'トマタグンカガミノチョウ', '越畑', 'コシワタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県苫田郡鏡野町岩屋', '33', '33606', '7080302', '岡山県', 'オカヤマケン', '苫田郡鏡野町', 'トマタグンカガミノチョウ', '岩屋', 'イワヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県苫田郡鏡野町大町', '33', '33606', '7080303', '岡山県', 'オカヤマケン', '苫田郡鏡野町', 'トマタグンカガミノチョウ', '大町', 'オオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県苫田郡鏡野町真経', '33', '33606', '7080304', '岡山県', 'オカヤマケン', '苫田郡鏡野町', 'トマタグンカガミノチョウ', '真経', 'サネツネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県苫田郡鏡野町百谷', '33', '33606', '7080305', '岡山県', 'オカヤマケン', '苫田郡鏡野町', 'トマタグンカガミノチョウ', '百谷', 'モモダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市神居町神華', '01', '01204', '0708031', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '神居町神華', 'カムイチョウシンカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県苫田郡鏡野町寺和田', '33', '33606', '7080311', '岡山県', 'オカヤマケン', '苫田郡鏡野町', 'トマタグンカガミノチョウ', '寺和田', 'テラワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県苫田郡鏡野町香々美', '33', '33606', '7080312', '岡山県', 'オカヤマケン', '苫田郡鏡野町', 'トマタグンカガミノチョウ', '香々美', 'カガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県苫田郡鏡野町公保田', '33', '33606', '7080313', '岡山県', 'オカヤマケン', '苫田郡鏡野町', 'トマタグンカガミノチョウ', '公保田', 'クホウデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県苫田郡鏡野町沢田', '33', '33606', '7080314', '岡山県', 'オカヤマケン', '苫田郡鏡野町', 'トマタグンカガミノチョウ', '沢田', 'サワタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県苫田郡鏡野町市場', '33', '33606', '7080315', '岡山県', 'オカヤマケン', '苫田郡鏡野町', 'トマタグンカガミノチョウ', '市場', 'イチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県苫田郡鏡野町和田', '33', '33606', '7080316', '岡山県', 'オカヤマケン', '苫田郡鏡野町', 'トマタグンカガミノチョウ', '和田', 'ワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県苫田郡鏡野町土居', '33', '33606', '7080317', '岡山県', 'オカヤマケン', '苫田郡鏡野町', 'トマタグンカガミノチョウ', '土居', 'ドイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市神居町共栄', '01', '01204', '0708032', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '神居町共栄', 'カムイチョウキョウエイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県苫田郡鏡野町円宗寺', '33', '33606', '7080321', '岡山県', 'オカヤマケン', '苫田郡鏡野町', 'トマタグンカガミノチョウ', '円宗寺', 'エンジュウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県苫田郡鏡野町沖', '33', '33606', '7080322', '岡山県', 'オカヤマケン', '苫田郡鏡野町', 'トマタグンカガミノチョウ', '沖', 'オキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県苫田郡鏡野町寺元', '33', '33606', '7080323', '岡山県', 'オカヤマケン', '苫田郡鏡野町', 'トマタグンカガミノチョウ', '寺元', 'テラモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県苫田郡鏡野町竹田', '33', '33606', '7080324', '岡山県', 'オカヤマケン', '苫田郡鏡野町', 'トマタグンカガミノチョウ', '竹田', 'タケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県苫田郡鏡野町瀬戸', '33', '33606', '7080325', '岡山県', 'オカヤマケン', '苫田郡鏡野町', 'トマタグンカガミノチョウ', '瀬戸', 'セト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市神居町雨紛', '01', '01204', '0708033', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '神居町雨紛', 'カムイチョウウブン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県苫田郡鏡野町布原', '33', '33606', '7080331', '岡山県', 'オカヤマケン', '苫田郡鏡野町', 'トマタグンカガミノチョウ', '布原', 'ヌノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県苫田郡鏡野町吉原', '33', '33606', '7080332', '岡山県', 'オカヤマケン', '苫田郡鏡野町', 'トマタグンカガミノチョウ', '吉原', 'ヨシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県苫田郡鏡野町古川', '33', '33606', '7080333', '岡山県', 'オカヤマケン', '苫田郡鏡野町', 'トマタグンカガミノチョウ', '古川', 'フルカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県苫田郡鏡野町宗枝', '33', '33606', '7080334', '岡山県', 'オカヤマケン', '苫田郡鏡野町', 'トマタグンカガミノチョウ', '宗枝', 'ムネダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県苫田郡鏡野町真加部', '33', '33606', '7080335', '岡山県', 'オカヤマケン', '苫田郡鏡野町', 'トマタグンカガミノチョウ', '真加部', 'マカベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市神居町上雨紛', '01', '01204', '0708034', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '神居町上雨紛', 'カムイチョウカミウブン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県苫田郡鏡野町下原', '33', '33606', '7080341', '岡山県', 'オカヤマケン', '苫田郡鏡野町', 'トマタグンカガミノチョウ', '下原', 'シモバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県苫田郡鏡野町薪森原', '33', '33606', '7080342', '岡山県', 'オカヤマケン', '苫田郡鏡野町', 'トマタグンカガミノチョウ', '薪森原', 'タキギモリバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県苫田郡鏡野町河本', '33', '33606', '7080343', '岡山県', 'オカヤマケン', '苫田郡鏡野町', 'トマタグンカガミノチョウ', '河本', 'コウモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県苫田郡鏡野町原', '33', '33606', '7080344', '岡山県', 'オカヤマケン', '苫田郡鏡野町', 'トマタグンカガミノチョウ', '原', 'ハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県苫田郡鏡野町高山', '33', '33606', '7080345', '岡山県', 'オカヤマケン', '苫田郡鏡野町', 'トマタグンカガミノチョウ', '高山', 'タカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県苫田郡鏡野町入', '33', '33606', '7080351', '岡山県', 'オカヤマケン', '苫田郡鏡野町', 'トマタグンカガミノチョウ', '入', 'イリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県苫田郡鏡野町山城', '33', '33606', '7080352', '岡山県', 'オカヤマケン', '苫田郡鏡野町', 'トマタグンカガミノチョウ', '山城', 'ヤマシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県苫田郡鏡野町中谷', '33', '33606', '7080353', '岡山県', 'オカヤマケン', '苫田郡鏡野町', 'トマタグンカガミノチョウ', '中谷', 'ナカダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県苫田郡鏡野町上森原', '33', '33606', '7080361', '岡山県', 'オカヤマケン', '苫田郡鏡野町', 'トマタグンカガミノチョウ', '上森原', 'カミモリバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県苫田郡鏡野町貞永寺', '33', '33606', '7080362', '岡山県', 'オカヤマケン', '苫田郡鏡野町', 'トマタグンカガミノチョウ', '貞永寺', 'テエジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県苫田郡鏡野町小座', '33', '33606', '7080363', '岡山県', 'オカヤマケン', '苫田郡鏡野町', 'トマタグンカガミノチョウ', '小座', 'オザ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県苫田郡鏡野町下森原', '33', '33606', '7080364', '岡山県', 'オカヤマケン', '苫田郡鏡野町', 'トマタグンカガミノチョウ', '下森原', 'シモモリバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県苫田郡鏡野町塚谷', '33', '33606', '7080365', '岡山県', 'オカヤマケン', '苫田郡鏡野町', 'トマタグンカガミノチョウ', '塚谷', 'ツカダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県苫田郡鏡野町馬場', '33', '33606', '7080366', '岡山県', 'オカヤマケン', '苫田郡鏡野町', 'トマタグンカガミノチョウ', '馬場', 'ババ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区東苗穂4条', '01', '01103', '0070804', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '東苗穂4条', 'ヒガシナエボ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市忠和1条', '01', '01204', '0708041', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '忠和1条', 'チュウワ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市忠和2条', '01', '01204', '0708042', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '忠和2条', 'チュウワ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県苫田郡鏡野町井坂', '33', '33606', '7080421', '岡山県', 'オカヤマケン', '苫田郡鏡野町', 'トマタグンカガミノチョウ', '井坂', 'イザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県苫田郡鏡野町養野', '33', '33606', '7080422', '岡山県', 'オカヤマケン', '苫田郡鏡野町', 'トマタグンカガミノチョウ', '養野', 'ヨウノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県苫田郡鏡野町女原', '33', '33606', '7080423', '岡山県', 'オカヤマケン', '苫田郡鏡野町', 'トマタグンカガミノチョウ', '女原', 'オナバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県苫田郡鏡野町杉', '33', '33606', '7080424', '岡山県', 'オカヤマケン', '苫田郡鏡野町', 'トマタグンカガミノチョウ', '杉', 'スギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県苫田郡鏡野町箱', '33', '33606', '7080425', '岡山県', 'オカヤマケン', '苫田郡鏡野町', 'トマタグンカガミノチョウ', '箱', 'ハコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県苫田郡鏡野町西屋', '33', '33606', '7080426', '岡山県', 'オカヤマケン', '苫田郡鏡野町', 'トマタグンカガミノチョウ', '西屋', 'ニシヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県苫田郡鏡野町至孝農', '33', '33606', '7080427', '岡山県', 'オカヤマケン', '苫田郡鏡野町', 'トマタグンカガミノチョウ', '至孝農', 'シコウノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市忠和3条', '01', '01204', '0708043', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '忠和3条', 'チュウワ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県苫田郡鏡野町河内', '33', '33606', '7080431', '岡山県', 'オカヤマケン', '苫田郡鏡野町', 'トマタグンカガミノチョウ', '河内', 'コウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県苫田郡鏡野町久田上原', '33', '33606', '7080432', '岡山県', 'オカヤマケン', '苫田郡鏡野町', 'トマタグンカガミノチョウ', '久田上原', 'クタカミノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県苫田郡鏡野町久田下原', '33', '33606', '7080433', '岡山県', 'オカヤマケン', '苫田郡鏡野町', 'トマタグンカガミノチョウ', '久田下原', 'クタシモノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県苫田郡鏡野町土生', '33', '33606', '7080434', '岡山県', 'オカヤマケン', '苫田郡鏡野町', 'トマタグンカガミノチョウ', '土生', 'ハブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県苫田郡鏡野町黒木', '33', '33606', '7080435', '岡山県', 'オカヤマケン', '苫田郡鏡野町', 'トマタグンカガミノチョウ', '黒木', 'クロギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市忠和4条', '01', '01204', '0708044', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '忠和4条', 'チュウワ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市忠和5条', '01', '01204', '0708045', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '忠和5条', 'チュウワ05ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市忠和6条', '01', '01204', '0708046', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '忠和6条', 'チュウワ06ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市忠和7条', '01', '01204', '0708047', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '忠和7条', 'チュウワ07ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市忠和8条', '01', '01204', '0708048', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '忠和8条', 'チュウワ08ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市忠和9条', '01', '01204', '0708049', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '忠和9条', 'チュウワ09ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区東苗穂5条', '01', '01103', '0070805', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '東苗穂5条', 'ヒガシナエボ05ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県苫田郡鏡野町下斎原', '33', '33606', '7080501', '岡山県', 'オカヤマケン', '苫田郡鏡野町', 'トマタグンカガミノチョウ', '下斎原', 'シモサイバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県苫田郡鏡野町長藤', '33', '33606', '7080502', '岡山県', 'オカヤマケン', '苫田郡鏡野町', 'トマタグンカガミノチョウ', '長藤', 'ナガトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県苫田郡鏡野町奥津', '33', '33606', '7080503', '岡山県', 'オカヤマケン', '苫田郡鏡野町', 'トマタグンカガミノチョウ', '奥津', 'オクツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県苫田郡鏡野町奥津川西', '33', '33606', '7080504', '岡山県', 'オカヤマケン', '苫田郡鏡野町', 'トマタグンカガミノチョウ', '奥津川西', 'オクツカワニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市江丹別町嵐山', '01', '01204', '0708051', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '江丹別町嵐山', 'エタンベツチョウアラシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県苫田郡鏡野町羽出', '33', '33606', '7080511', '岡山県', 'オカヤマケン', '苫田郡鏡野町', 'トマタグンカガミノチョウ', '羽出', 'ハデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県苫田郡鏡野町羽出西谷', '33', '33606', '7080512', '岡山県', 'オカヤマケン', '苫田郡鏡野町', 'トマタグンカガミノチョウ', '羽出西谷', 'ハデニシダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市江丹別町春日', '01', '01204', '0708052', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '江丹別町春日', 'エタンベツチョウカスガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市江丹別町共和', '01', '01204', '0708053', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '江丹別町共和', 'エタンベツチョウキョウワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区東苗穂6条', '01', '01103', '0070806', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '東苗穂6条', 'ヒガシナエボ06ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県苫田郡鏡野町上齋原', '33', '33606', '7080601', '岡山県', 'オカヤマケン', '苫田郡鏡野町', 'トマタグンカガミノチョウ', '上齋原', 'カミサイバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市高砂台', '01', '01204', '0708061', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '高砂台', 'タカサゴダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区東苗穂7条', '01', '01103', '0070807', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '東苗穂7条', 'ヒガシナエボ07ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県苫田郡鏡野町富西谷', '33', '33606', '7080701', '岡山県', 'オカヤマケン', '苫田郡鏡野町', 'トマタグンカガミノチョウ', '富西谷', 'トミニシダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県苫田郡鏡野町富東谷', '33', '33606', '7080702', '岡山県', 'オカヤマケン', '苫田郡鏡野町', 'トマタグンカガミノチョウ', '富東谷', 'トミヒガシダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県苫田郡鏡野町富仲間', '33', '33606', '7080703', '岡山県', 'オカヤマケン', '苫田郡鏡野町', 'トマタグンカガミノチョウ', '富仲間', 'トミナカマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県苫田郡鏡野町大', '33', '33606', '7080704', '岡山県', 'オカヤマケン', '苫田郡鏡野町', 'トマタグンカガミノチョウ', '大', 'オオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県苫田郡鏡野町楠', '33', '33606', '7080705', '岡山県', 'オカヤマケン', '苫田郡鏡野町', 'トマタグンカガミノチョウ', '楠', 'クス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市台場1条', '01', '01204', '0708071', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '台場1条', 'ダイバ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市台場2条', '01', '01204', '0708072', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '台場2条', 'ダイバ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市台場3条', '01', '01204', '0708073', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '台場3条', 'ダイバ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市台場4条', '01', '01204', '0708074', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '台場4条', 'ダイバ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区東苗穂8条', '01', '01103', '0070808', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '東苗穂8条', 'ヒガシナエボ08ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市上横野', '33', '33203', '7080801', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '上横野', 'カミヨコノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市大篠', '33', '33203', '7080802', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '大篠', 'オオササ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市籾保', '33', '33203', '7080803', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '籾保', 'モミホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市勝部', '33', '33203', '7080804', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '勝部', 'カツベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市紫保井', '33', '33203', '7080805', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '紫保井', 'シボイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市大田', '33', '33203', '7080806', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '大田', 'オオダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市下横野', '33', '33203', '7080807', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '下横野', 'シモヨコノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市西田辺', '33', '33203', '7080811', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '西田辺', 'ニシタナベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市東田辺', '33', '33203', '7080812', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '東田辺', 'ヒガシタナベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市山方', '33', '33203', '7080813', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '山方', 'ヤマガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市東一宮', '33', '33203', '7080814', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '東一宮', 'ヒガシイチノミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市一宮', '33', '33203', '7080815', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '一宮', 'イチノミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市野介代', '33', '33203', '7080821', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '野介代', 'ノケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市林田', '33', '33203', '7080822', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '林田', 'ハイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市弥生町', '33', '33203', '7080823', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '弥生町', 'ヤヨイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市沼', '33', '33203', '7080824', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '沼', 'ヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市志戸部', '33', '33203', '7080825', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '志戸部', 'シトベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市上之町', '33', '33203', '7080831', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '上之町', 'ウエノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市東新町', '33', '33203', '7080832', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '東新町', 'ヒガシシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市西新町', '33', '33203', '7080833', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '西新町', 'ニシシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市中之町', '33', '33203', '7080834', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '中之町', 'ナカノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市勝間田町', '33', '33203', '7080835', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '勝間田町', 'カツマダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市林田町', '33', '33203', '7080836', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '林田町', 'ハイダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市橋本町', '33', '33203', '7080837', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '橋本町', 'ハシモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市川崎', '33', '33203', '7080841', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '川崎', 'カワサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市河辺', '33', '33203', '7080842', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '河辺', 'カワナベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市国分寺', '33', '33203', '7080843', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '国分寺', 'コクブンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市瓜生原', '33', '33203', '7080844', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '瓜生原', 'ウリュウバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市日上', '33', '33203', '7080845', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '日上', 'ヒカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市新田', '33', '33203', '7080851', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '新田', 'ニイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市池ケ原', '33', '33203', '7080852', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '池ケ原', 'イケガハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市堂尾', '33', '33203', '7080853', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '堂尾', 'ドウノオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市中原', '33', '33203', '7080854', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '中原', 'ナカバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市金井', '33', '33203', '7080855', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '金井', 'カナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市西吉田', '33', '33203', '7080856', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '西吉田', 'ニシヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市福力', '33', '33203', '7080857', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '福力', 'フクリキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市八出', '33', '33203', '7080861', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '八出', 'ヤイデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市横山', '33', '33203', '7080862', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '横山', 'ヨコヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市小桁', '33', '33203', '7080863', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '小桁', 'オゲタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市金屋', '33', '33203', '7080864', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '金屋', 'カナヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市押渕', '33', '33203', '7080865', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '押渕', 'オシブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市荒神山', '33', '33203', '7080866', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '荒神山', 'コウジンヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市中島', '33', '33203', '7080871', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '中島', 'ナカシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市平福', '33', '33203', '7080872', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '平福', 'ヒラフク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市皿', '33', '33203', '7080873', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '皿', 'サラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市種', '33', '33203', '7080874', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '種', 'タネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市福田', '33', '33203', '7080875', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '福田', 'フクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市高尾', '33', '33203', '7080876', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '高尾', 'タカオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市南町', '33', '33203', '7080881', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '南町', 'ミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市大谷', '33', '33203', '7080882', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '大谷', 'オオタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市一方', '33', '33203', '7080883', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '一方', 'イッポウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市津山口', '33', '33203', '7080884', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '津山口', 'ツヤマグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市井口', '33', '33203', '7080885', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '井口', 'イノクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市昭和町', '33', '33203', '7080886', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '昭和町', 'ショウワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区東苗穂9条', '01', '01103', '0070809', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '東苗穂9条', 'ヒガシナエボ09ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区東苗穂10条', '01', '01103', '0070810', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '東苗穂10条', 'ヒガシナエボ10ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区東苗穂11条', '01', '01103', '0070811', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '東苗穂11条', 'ヒガシナエボ11ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市三浦', '33', '33203', '7081101', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '三浦', 'ミウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市妙原', '33', '33203', '7081102', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '妙原', 'ミョウバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市堀坂', '33', '33203', '7081103', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '堀坂', 'ホリサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市綾部', '33', '33203', '7081104', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '綾部', 'アヤベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市吉見', '33', '33203', '7081105', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '吉見', 'ヨシミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市楢', '33', '33203', '7081111', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '楢', 'ナラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市近長', '33', '33203', '7081112', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '近長', 'チカナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市田熊', '33', '33203', '7081113', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '田熊', 'タノクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市福井', '33', '33203', '7081114', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '福井', 'フクイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市河面', '33', '33203', '7081115', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '河面', 'コウモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市野村', '33', '33203', '7081116', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '野村', 'ノムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市草加部', '33', '33203', '7081117', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '草加部', 'クサカベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市上高倉', '33', '33203', '7081121', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '上高倉', 'カミタカクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市下高倉東', '33', '33203', '7081122', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '下高倉東', 'シモタカクラヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市下高倉西', '33', '33203', '7081123', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '下高倉西', 'シモタカクラニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市高野山西', '33', '33203', '7081124', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '高野山西', 'タカノヤマニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市高野本郷', '33', '33203', '7081125', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '高野本郷', 'タカノホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市押入', '33', '33203', '7081126', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '押入', 'オシイレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区東苗穂12条', '01', '01103', '0070812', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '東苗穂12条', 'ヒガシナエボ12ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市奥津川', '33', '33203', '7081201', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '奥津川', 'オクツガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市加茂町下津川奥津川', '33', '33203', '7081201', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '加茂町下津川', 'カモチョウシモツガワ', null, null, '奥津川', 'オクツガワ');
INSERT INTO `ms_addresses` VALUES ('87930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市大岩', '33', '33203', '7081202', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '大岩', 'オオイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市大吉', '33', '33203', '7081203', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '大吉', 'オオヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市日本原', '33', '33203', '7081204', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '日本原', 'ニホンバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市新野東', '33', '33203', '7081205', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '新野東', 'ニイノヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市市場', '33', '33203', '7081206', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '市場', 'イチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市原', '33', '33203', '7081211', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '原', 'ハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市安井', '33', '33203', '7081212', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '安井', 'ヤスイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市下野田', '33', '33203', '7081213', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '下野田', 'シモノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市上野田', '33', '33203', '7081214', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '上野田', 'カミノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市杉宮', '33', '33203', '7081215', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '杉宮', 'スギノミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市中村', '33', '33203', '7081216', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '中村', 'ナカムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市西上', '33', '33203', '7081221', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '西上', 'ニシカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市西中', '33', '33203', '7081222', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '西中', 'ニシナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市坂上', '33', '33203', '7081223', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '坂上', 'サカウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市上村', '33', '33203', '7081224', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '上村', 'カミムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市西下', '33', '33203', '7081225', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '西下', 'ニシシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市新野山形', '33', '33203', '7081226', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '新野山形', 'ニイノヤマガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区東苗穂13条', '01', '01103', '0070813', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '東苗穂13条', 'ヒガシナエボ13ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県勝田郡奈義町', '33', '33623', '7081300', '岡山県', 'オカヤマケン', '勝田郡奈義町', 'カツタグンナギチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('87949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県勝田郡奈義町馬桑', '33', '33623', '7081301', '岡山県', 'オカヤマケン', '勝田郡奈義町', 'カツタグンナギチョウ', '馬桑', 'マグワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県勝田郡奈義町小坂', '33', '33623', '7081302', '岡山県', 'オカヤマケン', '勝田郡奈義町', 'カツタグンナギチョウ', '小坂', 'オサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県勝田郡奈義町皆木', '33', '33623', '7081303', '岡山県', 'オカヤマケン', '勝田郡奈義町', 'カツタグンナギチョウ', '皆木', 'ミナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県勝田郡奈義町関本', '33', '33623', '7081304', '岡山県', 'オカヤマケン', '勝田郡奈義町', 'カツタグンナギチョウ', '関本', 'セキモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県勝田郡奈義町行方', '33', '33623', '7081305', '岡山県', 'オカヤマケン', '勝田郡奈義町', 'カツタグンナギチョウ', '行方', 'ギョウホウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県勝田郡奈義町西原', '33', '33623', '7081306', '岡山県', 'オカヤマケン', '勝田郡奈義町', 'カツタグンナギチョウ', '西原', 'ニシバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県勝田郡奈義町高円', '33', '33623', '7081307', '岡山県', 'オカヤマケン', '勝田郡奈義町', 'カツタグンナギチョウ', '高円', 'コウエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県勝田郡奈義町久常', '33', '33623', '7081311', '岡山県', 'オカヤマケン', '勝田郡奈義町', 'カツタグンナギチョウ', '久常', 'ヒサツネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県勝田郡奈義町柿', '33', '33623', '7081312', '岡山県', 'オカヤマケン', '勝田郡奈義町', 'カツタグンナギチョウ', '柿', 'カキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県勝田郡奈義町中島東', '33', '33623', '7081313', '岡山県', 'オカヤマケン', '勝田郡奈義町', 'カツタグンナギチョウ', '中島東', 'ナカシマヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県勝田郡奈義町荒内西', '33', '33623', '7081314', '岡山県', 'オカヤマケン', '勝田郡奈義町', 'カツタグンナギチョウ', '荒内西', 'アラウチニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県勝田郡奈義町中島西', '33', '33623', '7081315', '岡山県', 'オカヤマケン', '勝田郡奈義町', 'カツタグンナギチョウ', '中島西', 'ナカシマニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県勝田郡奈義町宮内', '33', '33623', '7081321', '岡山県', 'オカヤマケン', '勝田郡奈義町', 'カツタグンナギチョウ', '宮内', 'ミヤウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県勝田郡奈義町成松', '33', '33623', '7081322', '岡山県', 'オカヤマケン', '勝田郡奈義町', 'カツタグンナギチョウ', '成松', 'ナリマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県勝田郡奈義町豊沢', '33', '33623', '7081323', '岡山県', 'オカヤマケン', '勝田郡奈義町', 'カツタグンナギチョウ', '豊沢', 'トヨサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県勝田郡奈義町広岡', '33', '33623', '7081324', '岡山県', 'オカヤマケン', '勝田郡奈義町', 'カツタグンナギチョウ', '広岡', 'ヒロオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県勝田郡奈義町滝本', '33', '33623', '7081325', '岡山県', 'オカヤマケン', '勝田郡奈義町', 'カツタグンナギチョウ', '滝本', 'タキモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県勝田郡奈義町上町川', '33', '33623', '7081326', '岡山県', 'オカヤマケン', '勝田郡奈義町', 'カツタグンナギチョウ', '上町川', 'カミマチガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区東苗穂14条', '01', '01103', '0070814', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '東苗穂14条', 'ヒガシナエボ14ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区東苗穂15条', '01', '01103', '0070815', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '東苗穂15条', 'ヒガシナエボ15ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県久米郡美咲町安井', '33', '33666', '7081501', '岡山県', 'オカヤマケン', '久米郡美咲町', 'クメグンミサキチョウ', '安井', 'ヤスイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県久米郡美咲町宮山', '33', '33666', '7081502', '岡山県', 'オカヤマケン', '久米郡美咲町', 'クメグンミサキチョウ', '宮山', 'ミヤヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県久米郡美咲町塩気', '33', '33666', '7081503', '岡山県', 'オカヤマケン', '久米郡美咲町', 'クメグンミサキチョウ', '塩気', 'シオケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県久米郡美咲町吉留', '33', '33666', '7081504', '岡山県', 'オカヤマケン', '久米郡美咲町', 'クメグンミサキチョウ', '吉留', 'ヨシドメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県久米郡美咲町重藤', '33', '33666', '7081505', '岡山県', 'オカヤマケン', '久米郡美咲町', 'クメグンミサキチョウ', '重藤', 'シゲトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県久米郡美咲町上間', '33', '33666', '7081506', '岡山県', 'オカヤマケン', '久米郡美咲町', 'クメグンミサキチョウ', '上間', 'ウワマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県久米郡美咲町百々', '33', '33666', '7081507', '岡山県', 'オカヤマケン', '久米郡美咲町', 'クメグンミサキチョウ', '百々', 'ドウドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県久米郡美咲町行信', '33', '33666', '7081511', '岡山県', 'オカヤマケン', '久米郡美咲町', 'クメグンミサキチョウ', '行信', 'ユキノブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県久米郡美咲町松尾', '33', '33666', '7081512', '岡山県', 'オカヤマケン', '久米郡美咲町', 'クメグンミサキチョウ', '松尾', 'マツオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県久米郡美咲町藤田下', '33', '33666', '7081513', '岡山県', 'オカヤマケン', '久米郡美咲町', 'クメグンミサキチョウ', '藤田下', 'フジタシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県久米郡美咲町藤田上', '33', '33666', '7081514', '岡山県', 'オカヤマケン', '久米郡美咲町', 'クメグンミサキチョウ', '藤田上', 'フジタカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県久米郡美咲町下谷', '33', '33666', '7081515', '岡山県', 'オカヤマケン', '久米郡美咲町', 'クメグンミサキチョウ', '下谷', 'シモダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県久米郡美咲町連石', '33', '33666', '7081516', '岡山県', 'オカヤマケン', '久米郡美咲町', 'クメグンミサキチョウ', '連石', 'レンジャク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県久米郡美咲町休石', '33', '33666', '7081521', '岡山県', 'オカヤマケン', '久米郡美咲町', 'クメグンミサキチョウ', '休石', 'ヤスミイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県久米郡美咲町惣田', '33', '33666', '7081522', '岡山県', 'オカヤマケン', '久米郡美咲町', 'クメグンミサキチョウ', '惣田', 'ソウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県久米郡美咲町吉ケ原', '33', '33666', '7081523', '岡山県', 'オカヤマケン', '久米郡美咲町', 'クメグンミサキチョウ', '吉ケ原', 'キチガハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県久米郡美咲町飯岡', '33', '33666', '7081524', '岡山県', 'オカヤマケン', '久米郡美咲町', 'クメグンミサキチョウ', '飯岡', 'ユウカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県久米郡美咲町王子', '33', '33666', '7081525', '岡山県', 'オカヤマケン', '久米郡美咲町', 'クメグンミサキチョウ', '王子', 'オオジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県久米郡美咲町高下', '33', '33666', '7081526', '岡山県', 'オカヤマケン', '久米郡美咲町', 'クメグンミサキチョウ', '高下', 'コウゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県久米郡美咲町柵原', '33', '33666', '7081527', '岡山県', 'オカヤマケン', '久米郡美咲町', 'クメグンミサキチョウ', '柵原', 'ヤナハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県久米郡美咲町栗子', '33', '33666', '7081531', '岡山県', 'オカヤマケン', '久米郡美咲町', 'クメグンミサキチョウ', '栗子', 'クリゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県久米郡美咲町小瀬', '33', '33666', '7081532', '岡山県', 'オカヤマケン', '久米郡美咲町', 'クメグンミサキチョウ', '小瀬', 'コセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県久米郡美咲町久木', '33', '33666', '7081533', '岡山県', 'オカヤマケン', '久米郡美咲町', 'クメグンミサキチョウ', '久木', 'ヒサギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県久米郡美咲町藤原', '33', '33666', '7081534', '岡山県', 'オカヤマケン', '久米郡美咲町', 'クメグンミサキチョウ', '藤原', 'フジワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県久米郡美咲町高城', '33', '33666', '7081535', '岡山県', 'オカヤマケン', '久米郡美咲町', 'クメグンミサキチョウ', '高城', 'タカシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県久米郡美咲町定宗', '33', '33666', '7081536', '岡山県', 'オカヤマケン', '久米郡美咲町', 'クメグンミサキチョウ', '定宗', 'サダムネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県久米郡美咲町塚角', '33', '33666', '7081541', '岡山県', 'オカヤマケン', '久米郡美咲町', 'クメグンミサキチョウ', '塚角', 'ツカツノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県久米郡美咲町羽仁', '33', '33666', '7081542', '岡山県', 'オカヤマケン', '久米郡美咲町', 'クメグンミサキチョウ', '羽仁', 'ハニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('87999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県久米郡美咲町書副', '33', '33666', '7081543', '岡山県', 'オカヤマケン', '久米郡美咲町', 'クメグンミサキチョウ', '書副', 'カイゾエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県久米郡美咲町周佐', '33', '33666', '7081544', '岡山県', 'オカヤマケン', '久米郡美咲町', 'クメグンミサキチョウ', '周佐', 'スサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県久米郡美咲町大戸上', '33', '33666', '7081545', '岡山県', 'オカヤマケン', '久米郡美咲町', 'クメグンミサキチョウ', '大戸上', 'ダイトカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県久米郡美咲町大戸下', '33', '33666', '7081546', '岡山県', 'オカヤマケン', '久米郡美咲町', 'クメグンミサキチョウ', '大戸下', 'ダイトシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県久米郡美咲町八神', '33', '33666', '7081547', '岡山県', 'オカヤマケン', '久米郡美咲町', 'クメグンミサキチョウ', '八神', 'ネリガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区東苗穂町', '01', '01103', '0070819', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '東苗穂町', 'ヒガシナエボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区東雁来町', '01', '01103', '0070820', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '東雁来町', 'ヒガシカリキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区東雁来1条', '01', '01103', '0070821', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '東雁来1条', 'ヒガシカリキ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区東雁来2条', '01', '01103', '0070822', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '東雁来2条', 'ヒガシカリキ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区東雁来3条', '01', '01103', '0070823', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '東雁来3条', 'ヒガシカリキ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区東雁来4条', '01', '01103', '0070824', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '東雁来4条', 'ヒガシカリキ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区東雁来5条', '01', '01103', '0070825', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '東雁来5条', 'ヒガシカリキ05ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区東雁来6条', '01', '01103', '0070826', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '東雁来6条', 'ヒガシカリキ06ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区東雁来7条', '01', '01103', '0070827', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '東雁来7条', 'ヒガシカリキ07ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区東雁来8条', '01', '01103', '0070828', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '東雁来8条', 'ヒガシカリキ08ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区東雁来9条', '01', '01103', '0070829', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '東雁来9条', 'ヒガシカリキ09ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北34条東', '01', '01103', '0070834', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北34条東', 'キタ34ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北35条東', '01', '01103', '0070835', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北35条東', 'キタ35ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北36条東', '01', '01103', '0070836', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北36条東', 'キタ36ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北37条東', '01', '01103', '0070837', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北37条東', 'キタ37ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北38条東', '01', '01103', '0070838', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北38条東', 'キタ38ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北39条東', '01', '01103', '0070839', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北39条東', 'キタ39ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北40条東', '01', '01103', '0070840', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北40条東', 'キタ40ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北41条東', '01', '01103', '0070841', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北41条東', 'キタ41ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北42条東', '01', '01103', '0070842', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北42条東', 'キタ42ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北43条東', '01', '01103', '0070843', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北43条東', 'キタ43ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北44条東', '01', '01103', '0070844', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北44条東', 'キタ44ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北45条東', '01', '01103', '0070845', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北45条東', 'キタ45ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北46条東', '01', '01103', '0070846', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北46条東', 'キタ46ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北47条東', '01', '01103', '0070847', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北47条東', 'キタ47ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北48条東', '01', '01103', '0070848', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北48条東', 'キタ48ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北49条東', '01', '01103', '0070849', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北49条東', 'キタ49ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北50条東', '01', '01103', '0070850', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北50条東', 'キタ50ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北51条東', '01', '01103', '0070851', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北51条東', 'キタ51ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区栄町', '01', '01103', '0070852', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区伏古1条', '01', '01103', '0070861', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '伏古1条', 'フシコ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区伏古2条', '01', '01103', '0070862', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '伏古2条', 'フシコ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区伏古3条', '01', '01103', '0070863', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '伏古3条', 'フシコ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区伏古4条', '01', '01103', '0070864', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '伏古4条', 'フシコ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区伏古5条', '01', '01103', '0070865', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '伏古5条', 'フシコ05ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区伏古6条', '01', '01103', '0070866', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '伏古6条', 'フシコ06ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区伏古7条', '01', '01103', '0070867', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '伏古7条', 'フシコ07ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区伏古8条', '01', '01103', '0070868', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '伏古8条', 'フシコ08ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区伏古9条', '01', '01103', '0070869', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '伏古9条', 'フシコ09ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区伏古10条', '01', '01103', '0070870', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '伏古10条', 'フシコ10ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区伏古11条', '01', '01103', '0070871', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '伏古11条', 'フシコ11ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区伏古12条', '01', '01103', '0070872', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '伏古12条', 'フシコ12ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区伏古13条', '01', '01103', '0070873', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '伏古13条', 'フシコ13ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区伏古14条', '01', '01103', '0070874', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '伏古14条', 'フシコ14ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区丘珠町', '01', '01103', '0070880', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '丘珠町', 'オカダマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北丘珠1条', '01', '01103', '0070881', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北丘珠1条', 'キタオカダマ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北丘珠2条', '01', '01103', '0070882', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北丘珠2条', 'キタオカダマ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北丘珠3条', '01', '01103', '0070883', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北丘珠3条', 'キタオカダマ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北丘珠4条', '01', '01103', '0070884', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北丘珠4条', 'キタオカダマ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北丘珠5条', '01', '01103', '0070885', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北丘珠5条', 'キタオカダマ05ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区北丘珠6条', '01', '01103', '0070886', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '北丘珠6条', 'キタオカダマ06ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区中沼町', '01', '01103', '0070890', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '中沼町', 'ナカヌマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区中沼西1条', '01', '01103', '0070891', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '中沼西1条', 'ナカヌマニシ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区中沼西2条', '01', '01103', '0070892', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '中沼西2条', 'ナカヌマニシ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区中沼西3条', '01', '01103', '0070893', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '中沼西3条', 'ナカヌマニシ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区中沼西4条', '01', '01103', '0070894', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '中沼西4条', 'ナカヌマニシ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道札幌市東区中沼西5条', '01', '01103', '0070895', '北海道', 'ホッカイドウ', '札幌市東区', 'サッポロシヒガシク', '中沼西5条', 'ナカヌマニシ05ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県備前市吉永町高田', '33', '33211', '7090211', '岡山県', 'オカヤマケン', '備前市', 'ビゼンシ', '吉永町高田', 'ヨシナガチョウタカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県備前市吉永町神根本', '33', '33211', '7090212', '岡山県', 'オカヤマケン', '備前市', 'ビゼンシ', '吉永町神根本', 'ヨシナガチョウコウネホン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県備前市吉永町今崎', '33', '33211', '7090213', '岡山県', 'オカヤマケン', '備前市', 'ビゼンシ', '吉永町今崎', 'ヨシナガチョウイマサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県備前市吉永町和意谷', '33', '33211', '7090214', '岡山県', 'オカヤマケン', '備前市', 'ビゼンシ', '吉永町和意谷', 'ヨシナガチョウワイダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県備前市吉永町金谷', '33', '33211', '7090221', '岡山県', 'オカヤマケン', '備前市', 'ビゼンシ', '吉永町金谷', 'ヨシナガチョウカナダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県備前市吉永町福満', '33', '33211', '7090222', '岡山県', 'オカヤマケン', '備前市', 'ビゼンシ', '吉永町福満', 'ヨシナガチョウフクミツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県備前市吉永町南方', '33', '33211', '7090223', '岡山県', 'オカヤマケン', '備前市', 'ビゼンシ', '吉永町南方', 'ヨシナガチョウミナミガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県備前市吉永町吉永中', '33', '33211', '7090224', '岡山県', 'オカヤマケン', '備前市', 'ビゼンシ', '吉永町吉永中', 'ヨシナガチョウヨシナガナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県備前市吉永町三股', '33', '33211', '7090225', '岡山県', 'オカヤマケン', '備前市', 'ビゼンシ', '吉永町三股', 'ヨシナガチョウミツマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県備前市吉永町岩崎', '33', '33211', '7090226', '岡山県', 'オカヤマケン', '備前市', 'ビゼンシ', '吉永町岩崎', 'ヨシナガチョウイワサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県備前市吉永町加賀美', '33', '33211', '7090301', '岡山県', 'オカヤマケン', '備前市', 'ビゼンシ', '吉永町加賀美', 'ヨシナガチョウカガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県備前市吉永町多麻', '33', '33211', '7090302', '岡山県', 'オカヤマケン', '備前市', 'ビゼンシ', '吉永町多麻', 'ヨシナガチョウタマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県備前市吉永町都留岐', '33', '33211', '7090303', '岡山県', 'オカヤマケン', '備前市', 'ビゼンシ', '吉永町都留岐', 'ヨシナガチョウツルギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県備前市吉永町笹目', '33', '33211', '7090304', '岡山県', 'オカヤマケン', '備前市', 'ビゼンシ', '吉永町笹目', 'ヨシナガチョウササメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県和気郡和気町', '33', '33346', '7090400', '岡山県', 'オカヤマケン', '和気郡和気町', 'ワケグンワケチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('88147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県和気郡和気町保曽', '33', '33346', '7090401', '岡山県', 'オカヤマケン', '和気郡和気町', 'ワケグンワケチョウ', '保曽', 'ホソウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県和気郡和気町日笠上', '33', '33346', '7090402', '岡山県', 'オカヤマケン', '和気郡和気町', 'ワケグンワケチョウ', '日笠上', 'ヒカサカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県和気郡和気町日笠下', '33', '33346', '7090403', '岡山県', 'オカヤマケン', '和気郡和気町', 'ワケグンワケチョウ', '日笠下', 'ヒカサシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県和気郡和気町木倉', '33', '33346', '7090404', '岡山県', 'オカヤマケン', '和気郡和気町', 'ワケグンワケチョウ', '木倉', 'キノクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県和気郡和気町吉田', '33', '33346', '7090411', '岡山県', 'オカヤマケン', '和気郡和気町', 'ワケグンワケチョウ', '吉田', 'ヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県和気郡和気町藤野', '33', '33346', '7090412', '岡山県', 'オカヤマケン', '和気郡和気町', 'ワケグンワケチョウ', '藤野', 'フジノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県和気郡和気町泉', '33', '33346', '7090413', '岡山県', 'オカヤマケン', '和気郡和気町', 'ワケグンワケチョウ', '泉', 'イズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県和気郡和気町大田原', '33', '33346', '7090414', '岡山県', 'オカヤマケン', '和気郡和気町', 'ワケグンワケチョウ', '大田原', 'オオタワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県和気郡和気町日室', '33', '33346', '7090421', '岡山県', 'オカヤマケン', '和気郡和気町', 'ワケグンワケチョウ', '日室', 'ヒムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県和気郡和気町尺所', '33', '33346', '7090422', '岡山県', 'オカヤマケン', '和気郡和気町', 'ワケグンワケチョウ', '尺所', 'シャクソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県和気郡和気町清水', '33', '33346', '7090431', '岡山県', 'オカヤマケン', '和気郡和気町', 'ワケグンワケチョウ', '清水', 'シミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県和気郡和気町大中山', '33', '33346', '7090432', '岡山県', 'オカヤマケン', '和気郡和気町', 'ワケグンワケチョウ', '大中山', 'オオナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県和気郡和気町衣笠', '33', '33346', '7090441', '岡山県', 'オカヤマケン', '和気郡和気町', 'ワケグンワケチョウ', '衣笠', 'キヌガサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県和気郡和気町福富', '33', '33346', '7090442', '岡山県', 'オカヤマケン', '和気郡和気町', 'ワケグンワケチョウ', '福富', 'フクトミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県和気郡和気町和気', '33', '33346', '7090451', '岡山県', 'オカヤマケン', '和気郡和気町', 'ワケグンワケチョウ', '和気', 'ワケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県和気郡和気町益原', '33', '33346', '7090452', '岡山県', 'オカヤマケン', '和気郡和気町', 'ワケグンワケチョウ', '益原', 'マスバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県和気郡和気町原', '33', '33346', '7090461', '岡山県', 'オカヤマケン', '和気郡和気町', 'ワケグンワケチョウ', '原', 'ハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県和気郡和気町本', '33', '33346', '7090462', '岡山県', 'オカヤマケン', '和気郡和気町', 'ワケグンワケチョウ', '本', 'ホン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県和気郡和気町田原上', '33', '33346', '7090463', '岡山県', 'オカヤマケン', '和気郡和気町', 'ワケグンワケチョウ', '田原上', 'タワラカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県和気郡和気町田原下', '33', '33346', '7090464', '岡山県', 'オカヤマケン', '和気郡和気町', 'ワケグンワケチョウ', '田原下', 'タワラシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県和気郡和気町奥塩田', '33', '33346', '7090501', '岡山県', 'オカヤマケン', '和気郡和気町', 'ワケグンワケチョウ', '奥塩田', 'オクシオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県和気郡和気町丸山', '33', '33346', '7090502', '岡山県', 'オカヤマケン', '和気郡和気町', 'ワケグンワケチョウ', '丸山', 'マルヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県和気郡和気町南山方', '33', '33346', '7090503', '岡山県', 'オカヤマケン', '和気郡和気町', 'ワケグンワケチョウ', '南山方', 'ミナミヤマガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県和気郡和気町北山方', '33', '33346', '7090504', '岡山県', 'オカヤマケン', '和気郡和気町', 'ワケグンワケチョウ', '北山方', 'キタヤマガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県和気郡和気町苦木', '33', '33346', '7090505', '岡山県', 'オカヤマケン', '和気郡和気町', 'ワケグンワケチョウ', '苦木', 'ニガキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県和気郡和気町塩田', '33', '33346', '7090506', '岡山県', 'オカヤマケン', '和気郡和気町', 'ワケグンワケチョウ', '塩田', 'シオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県和気郡和気町矢田', '33', '33346', '7090511', '岡山県', 'オカヤマケン', '和気郡和気町', 'ワケグンワケチョウ', '矢田', 'ヤタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県和気郡和気町田土', '33', '33346', '7090512', '岡山県', 'オカヤマケン', '和気郡和気町', 'ワケグンワケチョウ', '田土', 'タド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県和気郡和気町岩戸', '33', '33346', '7090513', '岡山県', 'オカヤマケン', '和気郡和気町', 'ワケグンワケチョウ', '岩戸', 'イワト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県和気郡和気町佐伯', '33', '33346', '7090514', '岡山県', 'オカヤマケン', '和気郡和気町', 'ワケグンワケチョウ', '佐伯', 'サエキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県和気郡和気町米沢', '33', '33346', '7090515', '岡山県', 'オカヤマケン', '和気郡和気町', 'ワケグンワケチョウ', '米沢', 'ヨネザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県和気郡和気町津瀬', '33', '33346', '7090516', '岡山県', 'オカヤマケン', '和気郡和気町', 'ワケグンワケチョウ', '津瀬', 'ツゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県和気郡和気町父井原', '33', '33346', '7090521', '岡山県', 'オカヤマケン', '和気郡和気町', 'ワケグンワケチョウ', '父井原', 'チチイバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県和気郡和気町加三方', '33', '33346', '7090522', '岡山県', 'オカヤマケン', '和気郡和気町', 'ワケグンワケチョウ', '加三方', 'カミガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県和気郡和気町小坂', '33', '33346', '7090523', '岡山県', 'オカヤマケン', '和気郡和気町', 'ワケグンワケチョウ', '小坂', 'コザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県和気郡和気町田賀', '33', '33346', '7090524', '岡山県', 'オカヤマケン', '和気郡和気町', 'ワケグンワケチョウ', '田賀', 'タガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県和気郡和気町宇生', '33', '33346', '7090525', '岡山県', 'オカヤマケン', '和気郡和気町', 'ワケグンワケチョウ', '宇生', 'ウブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県和気郡和気町矢田部', '33', '33346', '7090526', '岡山県', 'オカヤマケン', '和気郡和気町', 'ワケグンワケチョウ', '矢田部', 'ヤタベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市吉井', '33', '33201', '7090601', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '吉井', 'ヨシイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市一日市', '33', '33201', '7090602', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '一日市', 'ヒトイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市西祖', '33', '33201', '7090603', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '西祖', 'セイソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市寺山', '33', '33201', '7090604', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '寺山', 'テラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市浅川', '33', '33201', '7090605', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '浅川', 'アサカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市矢井', '33', '33201', '7090606', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '矢井', 'ヤイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市浦間', '33', '33201', '7090607', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '浦間', 'ウラマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市楢原', '33', '33201', '7090611', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '楢原', 'ナラバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市内ケ原', '33', '33201', '7090612', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '内ケ原', 'ウチガハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市百枝月', '33', '33201', '7090613', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '百枝月', 'モモエヅキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市竹原', '33', '33201', '7090614', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '竹原', 'タケワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市才崎', '33', '33201', '7090615', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '才崎', 'サイザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市沼', '33', '33201', '7090621', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '沼', 'ヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市城東台東', '33', '33201', '7090622', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '城東台東', 'ジョウトウダイヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市城東台南', '33', '33201', '7090623', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '城東台南', 'ジョウトウダイミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市城東台西', '33', '33201', '7090624', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '城東台西', 'ジョウトウダイニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市上道北方', '33', '33201', '7090625', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '上道北方', 'ジョウトウキタガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市中尾', '33', '33201', '7090626', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '中尾', 'ナカオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市東平島', '33', '33201', '7090631', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '東平島', 'ヒガシヒラジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市南古都', '33', '33201', '7090632', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '南古都', 'ミナミコズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市西平島', '33', '33201', '7090633', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '西平島', 'ニシヒラジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市砂場', '33', '33201', '7090634', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '砂場', 'スナバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市草ケ部', '33', '33201', '7090635', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '草ケ部', 'クサカベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市谷尻', '33', '33201', '7090636', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '谷尻', 'タニシリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県赤磐市酌田', '33', '33213', '7090701', '岡山県', 'オカヤマケン', '赤磐市', 'アカイワシ', '酌田', 'シャクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県赤磐市岡', '33', '33213', '7090702', '岡山県', 'オカヤマケン', '赤磐市', 'アカイワシ', '岡', 'オカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県赤磐市殿谷', '33', '33213', '7090703', '岡山県', 'オカヤマケン', '赤磐市', 'アカイワシ', '殿谷', 'トノダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県赤磐市沢原', '33', '33213', '7090704', '岡山県', 'オカヤマケン', '赤磐市', 'アカイワシ', '沢原', 'サワハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県赤磐市松木', '33', '33213', '7090705', '岡山県', 'オカヤマケン', '赤磐市', 'アカイワシ', '松木', 'マツキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県赤磐市佐古', '33', '33213', '7090706', '岡山県', 'オカヤマケン', '赤磐市', 'アカイワシ', '佐古', 'サコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県赤磐市円光寺', '33', '33213', '7090711', '岡山県', 'オカヤマケン', '赤磐市', 'アカイワシ', '円光寺', 'エンコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県赤磐市吉原', '33', '33213', '7090712', '岡山県', 'オカヤマケン', '赤磐市', 'アカイワシ', '吉原', 'ヨシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県赤磐市奥吉原', '33', '33213', '7090713', '岡山県', 'オカヤマケン', '赤磐市', 'アカイワシ', '奥吉原', 'オクヨシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県赤磐市千躰', '33', '33213', '7090714', '岡山県', 'オカヤマケン', '赤磐市', 'アカイワシ', '千躰', 'センダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県赤磐市勢力', '33', '33213', '7090715', '岡山県', 'オカヤマケン', '赤磐市', 'アカイワシ', '勢力', 'セイリキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県赤磐市徳富', '33', '33213', '7090716', '岡山県', 'オカヤマケン', '赤磐市', 'アカイワシ', '徳富', 'トクドミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県赤磐市小瀬木', '33', '33213', '7090717', '岡山県', 'オカヤマケン', '赤磐市', 'アカイワシ', '小瀬木', 'オセギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県赤磐市釣井', '33', '33213', '7090718', '岡山県', 'オカヤマケン', '赤磐市', 'アカイワシ', '釣井', 'ツルイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県赤磐市河田原', '33', '33213', '7090719', '岡山県', 'オカヤマケン', '赤磐市', 'アカイワシ', '河田原', 'カワタハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県赤磐市桜が丘東', '33', '33213', '7090721', '岡山県', 'オカヤマケン', '赤磐市', 'アカイワシ', '桜が丘東', 'サクラガオカヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県赤磐市石蓮寺', '33', '33213', '7090731', '岡山県', 'オカヤマケン', '赤磐市', 'アカイワシ', '石蓮寺', 'シャクレンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県赤磐市可真下', '33', '33213', '7090732', '岡山県', 'オカヤマケン', '赤磐市', 'アカイワシ', '可真下', 'カマシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県赤磐市可真上', '33', '33213', '7090733', '岡山県', 'オカヤマケン', '赤磐市', 'アカイワシ', '可真上', 'カマカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県赤磐市弥上', '33', '33213', '7090734', '岡山県', 'オカヤマケン', '赤磐市', 'アカイワシ', '弥上', 'ヤガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県赤磐市野間', '33', '33213', '7090735', '岡山県', 'オカヤマケン', '赤磐市', 'アカイワシ', '野間', 'ノマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県赤磐市稗田', '33', '33213', '7090736', '岡山県', 'オカヤマケン', '赤磐市', 'アカイワシ', '稗田', 'ヒエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県赤磐市', '33', '33213', '7090800', '岡山県', 'オカヤマケン', '赤磐市', 'アカイワシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('88239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県赤磐市神田', '33', '33213', '7090801', '岡山県', 'オカヤマケン', '赤磐市', 'アカイワシ', '神田', 'コウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県赤磐市桜が丘西', '33', '33213', '7090802', '岡山県', 'オカヤマケン', '赤磐市', 'アカイワシ', '桜が丘西', 'サクラガオカニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県赤磐市中島', '33', '33213', '7090803', '岡山県', 'オカヤマケン', '赤磐市', 'アカイワシ', '中島', 'ナカシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県赤磐市日古木', '33', '33213', '7090804', '岡山県', 'オカヤマケン', '赤磐市', 'アカイワシ', '日古木', 'ヒコギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県赤磐市二井', '33', '33213', '7090805', '岡山県', 'オカヤマケン', '赤磐市', 'アカイワシ', '二井', 'フタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県赤磐市尾谷', '33', '33213', '7090806', '岡山県', 'オカヤマケン', '赤磐市', 'アカイワシ', '尾谷', 'オダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県赤磐市津崎', '33', '33213', '7090807', '岡山県', 'オカヤマケン', '赤磐市', 'アカイワシ', '津崎', 'ツザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県赤磐市高屋', '33', '33213', '7090811', '岡山県', 'オカヤマケン', '赤磐市', 'アカイワシ', '高屋', 'タカヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県赤磐市沼田', '33', '33213', '7090812', '岡山県', 'オカヤマケン', '赤磐市', 'アカイワシ', '沼田', 'ヌタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県赤磐市斎富', '33', '33213', '7090813', '岡山県', 'オカヤマケン', '赤磐市', 'アカイワシ', '斎富', 'サイドミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県赤磐市南方', '33', '33213', '7090814', '岡山県', 'オカヤマケン', '赤磐市', 'アカイワシ', '南方', 'ミナミガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県赤磐市立川', '33', '33213', '7090815', '岡山県', 'オカヤマケン', '赤磐市', 'アカイワシ', '立川', 'タツカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県赤磐市下市', '33', '33213', '7090816', '岡山県', 'オカヤマケン', '赤磐市', 'アカイワシ', '下市', 'シモイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県赤磐市上市', '33', '33213', '7090817', '岡山県', 'オカヤマケン', '赤磐市', 'アカイワシ', '上市', 'カミイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県赤磐市河本', '33', '33213', '7090821', '岡山県', 'オカヤマケン', '赤磐市', 'アカイワシ', '河本', 'コウモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県赤磐市岩田', '33', '33213', '7090822', '岡山県', 'オカヤマケン', '赤磐市', 'アカイワシ', '岩田', 'イワタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県赤磐市長尾', '33', '33213', '7090823', '岡山県', 'オカヤマケン', '赤磐市', 'アカイワシ', '長尾', 'ナガオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県赤磐市穂崎', '33', '33213', '7090824', '岡山県', 'オカヤマケン', '赤磐市', 'アカイワシ', '穂崎', 'ホサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県赤磐市馬屋', '33', '33213', '7090825', '岡山県', 'オカヤマケン', '赤磐市', 'アカイワシ', '馬屋', 'マヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県赤磐市和田', '33', '33213', '7090826', '岡山県', 'オカヤマケン', '赤磐市', 'アカイワシ', '和田', 'ワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県赤磐市山陽', '33', '33213', '7090827', '岡山県', 'オカヤマケン', '赤磐市', 'アカイワシ', '山陽', 'サンヨウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県赤磐市五日市', '33', '33213', '7090831', '岡山県', 'オカヤマケン', '赤磐市', 'アカイワシ', '五日市', 'イツカイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県赤磐市正崎', '33', '33213', '7090832', '岡山県', 'オカヤマケン', '赤磐市', 'アカイワシ', '正崎', 'ショウザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県赤磐市熊崎', '33', '33213', '7090833', '岡山県', 'オカヤマケン', '赤磐市', 'アカイワシ', '熊崎', 'クマザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県赤磐市鴨前', '33', '33213', '7090834', '岡山県', 'オカヤマケン', '赤磐市', 'アカイワシ', '鴨前', 'カモサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県赤磐市西中', '33', '33213', '7090835', '岡山県', 'オカヤマケン', '赤磐市', 'アカイワシ', '西中', 'ニシナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県赤磐市下仁保', '33', '33213', '7090836', '岡山県', 'オカヤマケン', '赤磐市', 'アカイワシ', '下仁保', 'シモニボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県赤磐市上仁保', '33', '33213', '7090837', '岡山県', 'オカヤマケン', '赤磐市', 'アカイワシ', '上仁保', 'カミニボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県赤磐市斗有', '33', '33213', '7090838', '岡山県', 'オカヤマケン', '赤磐市', 'アカイワシ', '斗有', 'トアリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市瀬戸町万富', '33', '33201', '7090841', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '瀬戸町万富', 'セトチョウマントミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市瀬戸町二日市', '33', '33201', '7090842', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '瀬戸町二日市', 'セトチョウフツカイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市瀬戸町弓削', '33', '33201', '7090843', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '瀬戸町弓削', 'セトチョウユゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市瀬戸町南方', '33', '33201', '7090844', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '瀬戸町南方', 'セトチョウミナミガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市瀬戸町鍛冶屋', '33', '33201', '7090845', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '瀬戸町鍛冶屋', 'セトチョウカジヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市瀬戸町大井', '33', '33201', '7090846', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '瀬戸町大井', 'セトチョウダイイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市瀬戸町大内', '33', '33201', '7090851', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '瀬戸町大内', 'セトチョウオオチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市瀬戸町肩脊', '33', '33201', '7090852', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '瀬戸町肩脊', 'セトチョウカタセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市瀬戸町旭ヶ丘', '33', '33201', '7090853', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '瀬戸町旭ヶ丘', 'セトチョウアサヒガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市瀬戸町江尻', '33', '33201', '7090854', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '瀬戸町江尻', 'セトチョウエジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市瀬戸町沖', '33', '33201', '7090855', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '瀬戸町沖', 'セトチョウオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市瀬戸町下', '33', '33201', '7090856', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '瀬戸町下', 'セトチョウシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市瀬戸町瀬戸', '33', '33201', '7090861', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '瀬戸町瀬戸', 'セトチョウセト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市瀬戸町笹岡', '33', '33201', '7090862', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '瀬戸町笹岡', 'セトチョウササオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市瀬戸町観音寺', '33', '33201', '7090863', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '瀬戸町観音寺', 'セトチョウカンオンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市瀬戸町宿奥', '33', '33201', '7090864', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '瀬戸町宿奥', 'セトチョウシュクオク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市瀬戸町菊山', '33', '33201', '7090865', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '瀬戸町菊山', 'セトチョウキクヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市瀬戸町塩納', '33', '33201', '7090871', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '瀬戸町塩納', 'セトチョウシオノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市瀬戸町宗堂', '33', '33201', '7090872', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '瀬戸町宗堂', 'セトチョウソウドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市瀬戸町坂根', '33', '33201', '7090873', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '瀬戸町坂根', 'セトチョウサカネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市瀬戸町森末', '33', '33201', '7090874', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '瀬戸町森末', 'セトチョウモリスエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市瀬戸町寺地', '33', '33201', '7090875', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '瀬戸町寺地', 'セトチョウテラジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市瀬戸町光明谷', '33', '33201', '7090876', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '瀬戸町光明谷', 'セトチョウコウミョウタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市灘崎町北七区', '33', '33201', '7091201', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '灘崎町北七区', 'ナダサキチョウキタナナク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市灘崎町西七区', '33', '33201', '7091202', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '灘崎町西七区', 'ナダサキチョウニシナナク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市灘崎町西紅陽台', '33', '33201', '7091203', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '灘崎町西紅陽台', 'ナダサキチョウニシコウヨウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市灘崎町西高崎', '33', '33201', '7091204', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '灘崎町西高崎', 'ナダサキチョウニシタカサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市灘崎町迫川', '33', '33201', '7091211', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '灘崎町迫川', 'ナダサキチョウハザカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市灘崎町奥迫川', '33', '33201', '7091212', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '灘崎町奥迫川', 'ナダサキチョウオクハザカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市灘崎町彦崎', '33', '33201', '7091213', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '灘崎町彦崎', 'ナダサキチョウヒコサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市灘崎町川張', '33', '33201', '7091214', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '灘崎町川張', 'ナダサキチョウカワハリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市灘崎町片岡', '33', '33201', '7091215', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '灘崎町片岡', 'ナダサキチョウカタオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市灘崎町宗津', '33', '33201', '7091216', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '灘崎町宗津', 'ナダサキチョウソウヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市御津石上', '33', '33201', '7092101', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '御津石上', 'ミツイシカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市御津中畑', '33', '33201', '7092102', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '御津中畑', 'ミツナカハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市御津矢知', '33', '33201', '7092103', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '御津矢知', 'ミツヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市御津平岡西', '33', '33201', '7092104', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '御津平岡西', 'ミツヒラオカニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市御津伊田', '33', '33201', '7092105', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '御津伊田', 'ミツイタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市御津新庄', '33', '33201', '7092106', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '御津新庄', 'ミツシンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市御津矢原', '33', '33201', '7092107', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '御津矢原', 'ミツヤバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市御津川高', '33', '33201', '7092111', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '御津川高', 'ミツカワタカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市御津国ケ原', '33', '33201', '7092112', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '御津国ケ原', 'ミツクニガハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市御津芳谷', '33', '33201', '7092113', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '御津芳谷', 'ミツヨシタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市御津中牧', '33', '33201', '7092114', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '御津中牧', 'ミツナカマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市御津北野', '33', '33201', '7092115', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '御津北野', 'ミツキタノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市御津中山', '33', '33201', '7092116', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '御津中山', 'ミツナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市御津野々口', '33', '33201', '7092117', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '御津野々口', 'ミツノノクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市御津宇垣', '33', '33201', '7092121', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '御津宇垣', 'ミツウガキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市御津吉尾', '33', '33201', '7092122', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '御津吉尾', 'ミツヨシオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市御津河内', '33', '33201', '7092123', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '御津河内', 'ミツコウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市御津高津', '33', '33201', '7092124', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '御津高津', 'ミツタカヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市御津宇甘', '33', '33201', '7092125', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '御津宇甘', 'ミツウカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市御津勝尾', '33', '33201', '7092126', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '御津勝尾', 'ミツカツオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市御津鹿瀬', '33', '33201', '7092131', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '御津鹿瀬', 'ミツカセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市御津草生', '33', '33201', '7092132', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '御津草生', 'ミツクソウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市御津金川', '33', '33201', '7092133', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '御津金川', 'ミツカナガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市御津下田', '33', '33201', '7092134', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '御津下田', 'ミツシモダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市御津中泉', '33', '33201', '7092135', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '御津中泉', 'ミツナカイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市御津紙工', '33', '33201', '7092136', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '御津紙工', 'ミツシトリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市御津虎倉', '33', '33201', '7092137', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '御津虎倉', 'ミツコグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県加賀郡吉備中央町下加茂', '33', '33681', '7092331', '岡山県', 'オカヤマケン', '加賀郡吉備中央町', 'カガグンキビチュウオウチョウ', '下加茂', 'シモガモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県加賀郡吉備中央町高谷', '33', '33681', '7092332', '岡山県', 'オカヤマケン', '加賀郡吉備中央町', 'カガグンキビチュウオウチョウ', '高谷', 'タカヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県加賀郡吉備中央町加茂市場', '33', '33681', '7092333', '岡山県', 'オカヤマケン', '加賀郡吉備中央町', 'カガグンキビチュウオウチョウ', '加茂市場', 'カモイチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県加賀郡吉備中央町美原', '33', '33681', '7092334', '岡山県', 'オカヤマケン', '加賀郡吉備中央町', 'カガグンキビチュウオウチョウ', '美原', 'ミハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県加賀郡吉備中央町上加茂', '33', '33681', '7092341', '岡山県', 'オカヤマケン', '加賀郡吉備中央町', 'カガグンキビチュウオウチョウ', '上加茂', 'カミガモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県加賀郡吉備中央町広面', '33', '33681', '7092342', '岡山県', 'オカヤマケン', '加賀郡吉備中央町', 'カガグンキビチュウオウチョウ', '広面', 'ヒロモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県加賀郡吉備中央町竹部', '33', '33681', '7092343', '岡山県', 'オカヤマケン', '加賀郡吉備中央町', 'カガグンキビチュウオウチョウ', '竹部', 'タケベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県加賀郡吉備中央町上野', '33', '33681', '7092344', '岡山県', 'オカヤマケン', '加賀郡吉備中央町', 'カガグンキビチュウオウチョウ', '上野', 'ウエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県加賀郡吉備中央町平岡', '33', '33681', '7092345', '岡山県', 'オカヤマケン', '加賀郡吉備中央町', 'カガグンキビチュウオウチョウ', '平岡', 'ヒラオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県加賀郡吉備中央町神瀬', '33', '33681', '7092401', '岡山県', 'オカヤマケン', '加賀郡吉備中央町', 'カガグンキビチュウオウチョウ', '神瀬', 'カンセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県加賀郡吉備中央町高富', '33', '33681', '7092402', '岡山県', 'オカヤマケン', '加賀郡吉備中央町', 'カガグンキビチュウオウチョウ', '高富', 'タカトミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県加賀郡吉備中央町案田', '33', '33681', '7092403', '岡山県', 'オカヤマケン', '加賀郡吉備中央町', 'カガグンキビチュウオウチョウ', '案田', 'アンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県加賀郡吉備中央町小森', '33', '33681', '7092404', '岡山県', 'オカヤマケン', '加賀郡吉備中央町', 'カガグンキビチュウオウチョウ', '小森', 'コモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県加賀郡吉備中央町上田東', '33', '33681', '7092411', '岡山県', 'オカヤマケン', '加賀郡吉備中央町', 'カガグンキビチュウオウチョウ', '上田東', 'ウエダヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県加賀郡吉備中央町円城', '33', '33681', '7092412', '岡山県', 'オカヤマケン', '加賀郡吉備中央町', 'カガグンキビチュウオウチョウ', '円城', 'エンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県加賀郡吉備中央町上田西', '33', '33681', '7092413', '岡山県', 'オカヤマケン', '加賀郡吉備中央町', 'カガグンキビチュウオウチョウ', '上田西', 'ウエダニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県加賀郡吉備中央町細田', '33', '33681', '7092421', '岡山県', 'オカヤマケン', '加賀郡吉備中央町', 'カガグンキビチュウオウチョウ', '細田', 'ホソダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県加賀郡吉備中央町三納谷', '33', '33681', '7092422', '岡山県', 'オカヤマケン', '加賀郡吉備中央町', 'カガグンキビチュウオウチョウ', '三納谷', 'ミノウタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県加賀郡吉備中央町下土井', '33', '33681', '7092551', '岡山県', 'オカヤマケン', '加賀郡吉備中央町', 'カガグンキビチュウオウチョウ', '下土井', 'シモドイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県加賀郡吉備中央町井原', '33', '33681', '7092552', '岡山県', 'オカヤマケン', '加賀郡吉備中央町', 'カガグンキビチュウオウチョウ', '井原', 'イハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県加賀郡吉備中央町富永', '33', '33681', '7092553', '岡山県', 'オカヤマケン', '加賀郡吉備中央町', 'カガグンキビチュウオウチョウ', '富永', 'トミナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県加賀郡吉備中央町和田', '33', '33681', '7092554', '岡山県', 'オカヤマケン', '加賀郡吉備中央町', 'カガグンキビチュウオウチョウ', '和田', 'ワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県加賀郡吉備中央町豊岡下', '33', '33681', '7092661', '岡山県', 'オカヤマケン', '加賀郡吉備中央町', 'カガグンキビチュウオウチョウ', '豊岡下', 'トヨオカシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県加賀郡吉備中央町三谷', '33', '33681', '7092662', '岡山県', 'オカヤマケン', '加賀郡吉備中央町', 'カガグンキビチュウオウチョウ', '三谷', 'ミタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県加賀郡吉備中央町大木', '33', '33681', '7092663', '岡山県', 'オカヤマケン', '加賀郡吉備中央町', 'カガグンキビチュウオウチョウ', '大木', 'オオギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県加賀郡吉備中央町豊岡上', '33', '33681', '7092664', '岡山県', 'オカヤマケン', '加賀郡吉備中央町', 'カガグンキビチュウオウチョウ', '豊岡上', 'トヨオカカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県加賀郡吉備中央町杉谷', '33', '33681', '7092671', '岡山県', 'オカヤマケン', '加賀郡吉備中央町', 'カガグンキビチュウオウチョウ', '杉谷', 'スギタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県加賀郡吉備中央町粟井谷', '33', '33681', '7092672', '岡山県', 'オカヤマケン', '加賀郡吉備中央町', 'カガグンキビチュウオウチョウ', '粟井谷', 'アワイタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県加賀郡吉備中央町尾原', '33', '33681', '7092673', '岡山県', 'オカヤマケン', '加賀郡吉備中央町', 'カガグンキビチュウオウチョウ', '尾原', 'オバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県加賀郡吉備中央町笹目', '33', '33681', '7092674', '岡山県', 'オカヤマケン', '加賀郡吉備中央町', 'カガグンキビチュウオウチョウ', '笹目', 'ササメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県加賀郡吉備中央町福沢', '33', '33681', '7092675', '岡山県', 'オカヤマケン', '加賀郡吉備中央町', 'カガグンキビチュウオウチョウ', '福沢', 'フクザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県加賀郡吉備中央町溝部', '33', '33681', '7092676', '岡山県', 'オカヤマケン', '加賀郡吉備中央町', 'カガグンキビチュウオウチョウ', '溝部', 'ミゾベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市建部町鶴田', '33', '33201', '7093101', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '建部町鶴田', 'タケベチョウタヅタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市建部町和田南', '33', '33201', '7093102', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '建部町和田南', 'タケベチョウワダミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市建部町角石畝', '33', '33201', '7093103', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '建部町角石畝', 'タケベチョウツイシウネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市建部町角石谷', '33', '33201', '7093104', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '建部町角石谷', 'タケベチョウツイシタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市建部町三明寺', '33', '33201', '7093105', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '建部町三明寺', 'タケベチョウサンミョウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市建部町福渡', '33', '33201', '7093111', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '建部町福渡', 'タケベチョウフクワタリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市建部町川口', '33', '33201', '7093112', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '建部町川口', 'タケベチョウカワグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市建部町下神目', '33', '33201', '7093113', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '建部町下神目', 'タケベチョウシモコウメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市建部町豊楽寺', '33', '33201', '7093114', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '建部町豊楽寺', 'タケベチョウブラクジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市建部町大田', '33', '33201', '7093121', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '建部町大田', 'タケベチョウオオダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市建部町吉田', '33', '33201', '7093122', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '建部町吉田', 'タケベチョウヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市建部町土師方', '33', '33201', '7093123', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '建部町土師方', 'タケベチョウハジカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市建部町小倉', '33', '33201', '7093124', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '建部町小倉', 'タケベチョウオグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市建部町市場', '33', '33201', '7093131', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '建部町市場', 'タケベチョウイチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市建部町中田', '33', '33201', '7093132', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '建部町中田', 'タケベチョウナカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市建部町西原', '33', '33201', '7093133', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '建部町西原', 'タケベチョウニシバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市建部町桜', '33', '33201', '7093134', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '建部町桜', 'タケベチョウサクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市建部町品田', '33', '33201', '7093141', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '建部町品田', 'タケベチョウシナダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市建部町建部上', '33', '33201', '7093142', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '建部町建部上', 'タケベチョウタケベカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市建部町宮地', '33', '33201', '7093143', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '建部町宮地', 'タケベチョウミヤジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市建部町富沢', '33', '33201', '7093144', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '建部町富沢', 'タケベチョウトミサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市建部町田地子', '33', '33201', '7093145', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '建部町田地子', 'タケベチョウタジコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県久米郡美咲町北', '33', '33666', '7093401', '岡山県', 'オカヤマケン', '久米郡美咲町', 'クメグンミサキチョウ', '北', 'キタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県久米郡美咲町南', '33', '33666', '7093402', '岡山県', 'オカヤマケン', '久米郡美咲町', 'クメグンミサキチョウ', '南', 'ミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県久米郡美咲町里', '33', '33666', '7093403', '岡山県', 'オカヤマケン', '久米郡美咲町', 'クメグンミサキチョウ', '里', 'サト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県久米郡美咲町西川', '33', '33666', '7093404', '岡山県', 'オカヤマケン', '久米郡美咲町', 'クメグンミサキチョウ', '西川', 'ニシガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県久米郡美咲町西', '33', '33666', '7093405', '岡山県', 'オカヤマケン', '久米郡美咲町', 'クメグンミサキチョウ', '西', 'ニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県久米郡美咲町西川上', '33', '33666', '7093406', '岡山県', 'オカヤマケン', '久米郡美咲町', 'クメグンミサキチョウ', '西川上', 'ニシガワカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県久米郡美咲町中', '33', '33666', '7093407', '岡山県', 'オカヤマケン', '久米郡美咲町', 'クメグンミサキチョウ', '中', 'ナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県久米郡美咲町上口', '33', '33666', '7093411', '岡山県', 'オカヤマケン', '久米郡美咲町', 'クメグンミサキチョウ', '上口', 'ウエクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県久米郡美咲町小山', '33', '33666', '7093412', '岡山県', 'オカヤマケン', '久米郡美咲町', 'クメグンミサキチョウ', '小山', 'コヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県久米郡美咲町栃原', '33', '33666', '7093413', '岡山県', 'オカヤマケン', '久米郡美咲町', 'クメグンミサキチョウ', '栃原', 'トチバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県久米郡美咲町西垪和', '33', '33666', '7093414', '岡山県', 'オカヤマケン', '久米郡美咲町', 'クメグンミサキチョウ', '西垪和', 'ニシハガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県久米郡美咲町江与味', '33', '33666', '7093415', '岡山県', 'オカヤマケン', '久米郡美咲町', 'クメグンミサキチョウ', '江与味', 'エヨミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県久米郡美咲町東垪和', '33', '33666', '7093416', '岡山県', 'オカヤマケン', '久米郡美咲町', 'クメグンミサキチョウ', '東垪和', 'ヒガシハガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県久米郡美咲町中垪和', '33', '33666', '7093417', '岡山県', 'オカヤマケン', '久米郡美咲町', 'クメグンミサキチョウ', '中垪和', 'ナカハガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県久米郡久米南町', '33', '33663', '7093600', '岡山県', 'オカヤマケン', '久米郡久米南町', 'クメグンクメナンチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('88412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県久米郡久米南町北庄', '33', '33663', '7093601', '岡山県', 'オカヤマケン', '久米郡久米南町', 'クメグンクメナンチョウ', '北庄', 'キタショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県久米郡久米南町里方', '33', '33663', '7093602', '岡山県', 'オカヤマケン', '久米郡久米南町', 'クメグンクメナンチョウ', '里方', 'サトガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県久米郡久米南町山ノ城', '33', '33663', '7093603', '岡山県', 'オカヤマケン', '久米郡久米南町', 'クメグンクメナンチョウ', '山ノ城', 'ヤマノジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県久米郡久米南町南庄', '33', '33663', '7093604', '岡山県', 'オカヤマケン', '久米郡久米南町', 'クメグンクメナンチョウ', '南庄', 'ミナミショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県久米郡久米南町塩之内', '33', '33663', '7093605', '岡山県', 'オカヤマケン', '久米郡久米南町', 'クメグンクメナンチョウ', '塩之内', 'シオノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県久米郡久米南町羽出木', '33', '33663', '7093606', '岡山県', 'オカヤマケン', '久米郡久米南町', 'クメグンクメナンチョウ', '羽出木', 'ハデギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県久米郡久米南町松', '33', '33663', '7093611', '岡山県', 'オカヤマケン', '久米郡久米南町', 'クメグンクメナンチョウ', '松', 'マツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県久米郡久米南町上弓削', '33', '33663', '7093612', '岡山県', 'オカヤマケン', '久米郡久米南町', 'クメグンクメナンチョウ', '上弓削', 'カミユゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県久米郡久米南町西山寺', '33', '33663', '7093613', '岡山県', 'オカヤマケン', '久米郡久米南町', 'クメグンクメナンチョウ', '西山寺', 'ニシヤマジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県久米郡久米南町下弓削', '33', '33663', '7093614', '岡山県', 'オカヤマケン', '久米郡久米南町', 'クメグンクメナンチョウ', '下弓削', 'シモユゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県久米郡久米南町上二ケ', '33', '33663', '7093615', '岡山県', 'オカヤマケン', '久米郡久米南町', 'クメグンクメナンチョウ', '上二ケ', 'カミニカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県久米郡久米南町全間', '33', '33663', '7093616', '岡山県', 'オカヤマケン', '久米郡久米南町', 'クメグンクメナンチョウ', '全間', 'マタマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県久米郡久米南町下二ケ', '33', '33663', '7093617', '岡山県', 'オカヤマケン', '久米郡久米南町', 'クメグンクメナンチョウ', '下二ケ', 'シモニカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県久米郡久米南町上籾', '33', '33663', '7093621', '岡山県', 'オカヤマケン', '久米郡久米南町', 'クメグンクメナンチョウ', '上籾', 'カミモミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県久米郡久米南町仏教寺', '33', '33663', '7093622', '岡山県', 'オカヤマケン', '久米郡久米南町', 'クメグンクメナンチョウ', '仏教寺', 'ブツキョウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県久米郡久米南町中籾', '33', '33663', '7093623', '岡山県', 'オカヤマケン', '久米郡久米南町', 'クメグンクメナンチョウ', '中籾', 'ナカモミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県久米郡久米南町下籾', '33', '33663', '7093624', '岡山県', 'オカヤマケン', '久米郡久米南町', 'クメグンクメナンチョウ', '下籾', 'シモモミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県久米郡久米南町別所', '33', '33663', '7093625', '岡山県', 'オカヤマケン', '久米郡久米南町', 'クメグンクメナンチョウ', '別所', 'ベッシヨ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県久米郡久米南町上神目', '33', '33663', '7093626', '岡山県', 'オカヤマケン', '久米郡久米南町', 'クメグンクメナンチョウ', '上神目', 'カミコウメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県久米郡久米南町神目中', '33', '33663', '7093627', '岡山県', 'オカヤマケン', '久米郡久米南町', 'クメグンクメナンチョウ', '神目中', 'コウメナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県久米郡久米南町宮地', '33', '33663', '7093631', '岡山県', 'オカヤマケン', '久米郡久米南町', 'クメグンクメナンチョウ', '宮地', 'ミヤジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県久米郡久米南町山手', '33', '33663', '7093632', '岡山県', 'オカヤマケン', '久米郡久米南町', 'クメグンクメナンチョウ', '山手', 'ヤマテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県久米郡久米南町峠', '33', '33663', '7093633', '岡山県', 'オカヤマケン', '久米郡久米南町', 'クメグンクメナンチョウ', '峠', 'トウゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県久米郡久米南町京尾', '33', '33663', '7093634', '岡山県', 'オカヤマケン', '久米郡久米南町', 'クメグンクメナンチョウ', '京尾', 'キョウノオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県久米郡久米南町南畑', '33', '33663', '7093635', '岡山県', 'オカヤマケン', '久米郡久米南町', 'クメグンクメナンチョウ', '南畑', 'ミナミハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県久米郡久米南町安ケ乢', '33', '33663', '7093636', '岡山県', 'オカヤマケン', '久米郡久米南町', 'クメグンクメナンチョウ', '安ケ乢', 'ヤスガタワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県久米郡美咲町', '33', '33666', '7093700', '岡山県', 'オカヤマケン', '久米郡美咲町', 'クメグンミサキチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('88439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県久米郡美咲町錦織', '33', '33666', '7093701', '岡山県', 'オカヤマケン', '久米郡美咲町', 'クメグンミサキチョウ', '錦織', 'ニシコリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県久米郡美咲町打穴下', '33', '33666', '7093702', '岡山県', 'オカヤマケン', '久米郡美咲町', 'クメグンミサキチョウ', '打穴下', 'ウタノシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県久米郡美咲町打穴中', '33', '33666', '7093703', '岡山県', 'オカヤマケン', '久米郡美咲町', 'クメグンミサキチョウ', '打穴中', 'ウタノナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県久米郡美咲町打穴里', '33', '33666', '7093704', '岡山県', 'オカヤマケン', '久米郡美咲町', 'クメグンミサキチョウ', '打穴里', 'ウタノサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県久米郡美咲町打穴上', '33', '33666', '7093705', '岡山県', 'オカヤマケン', '久米郡美咲町', 'クメグンミサキチョウ', '打穴上', 'ウタノカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県久米郡美咲町打穴北', '33', '33666', '7093706', '岡山県', 'オカヤマケン', '久米郡美咲町', 'クメグンミサキチョウ', '打穴北', 'ウタノキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県久米郡美咲町打穴西', '33', '33666', '7093707', '岡山県', 'オカヤマケン', '久米郡美咲町', 'クメグンミサキチョウ', '打穴西', 'ウタノニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県久米郡美咲町越尾', '33', '33666', '7093711', '岡山県', 'オカヤマケン', '久米郡美咲町', 'クメグンミサキチョウ', '越尾', 'コヨオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県久米郡美咲町金堀', '33', '33666', '7093712', '岡山県', 'オカヤマケン', '久米郡美咲町', 'クメグンミサキチョウ', '金堀', 'カナボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県久米郡美咲町新城', '33', '33666', '7093713', '岡山県', 'オカヤマケン', '久米郡美咲町', 'クメグンミサキチョウ', '新城', 'シンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県久米郡美咲町小原', '33', '33666', '7093714', '岡山県', 'オカヤマケン', '久米郡美咲町', 'クメグンミサキチョウ', '小原', 'オバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県久米郡美咲町西幸', '33', '33666', '7093715', '岡山県', 'オカヤマケン', '久米郡美咲町', 'クメグンミサキチョウ', '西幸', 'サイコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県久米郡美咲町頼元', '33', '33666', '7093716', '岡山県', 'オカヤマケン', '久米郡美咲町', 'クメグンミサキチョウ', '頼元', 'ヨリモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県久米郡美咲町原田', '33', '33666', '7093717', '岡山県', 'オカヤマケン', '久米郡美咲町', 'クメグンミサキチョウ', '原田', 'ハラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県久米郡美咲町両山寺', '33', '33666', '7093721', '岡山県', 'オカヤマケン', '久米郡美咲町', 'クメグンミサキチョウ', '両山寺', 'リョウサンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県久米郡美咲町大垪和東', '33', '33666', '7093722', '岡山県', 'オカヤマケン', '久米郡美咲町', 'クメグンミサキチョウ', '大垪和東', 'オオハガヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県久米郡美咲町境', '33', '33666', '7093723', '岡山県', 'オカヤマケン', '久米郡美咲町', 'クメグンミサキチョウ', '境', 'サカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県久米郡美咲町角石祖母', '33', '33666', '7093724', '岡山県', 'オカヤマケン', '久米郡美咲町', 'クメグンミサキチョウ', '角石祖母', 'ツイシソボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県久米郡美咲町和田北', '33', '33666', '7093725', '岡山県', 'オカヤマケン', '久米郡美咲町', 'クメグンミサキチョウ', '和田北', 'ワダキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県久米郡美咲町大垪和西', '33', '33666', '7093726', '岡山県', 'オカヤマケン', '久米郡美咲町', 'クメグンミサキチョウ', '大垪和西', 'オオハガニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市加茂町倉見', '33', '33203', '7093901', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '加茂町倉見', 'カモチョウクラミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市加茂町黒木', '33', '33203', '7093902', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '加茂町黒木', 'カモチョウクロギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市加茂町戸賀', '33', '33203', '7093903', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '加茂町戸賀', 'カモチョウトカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市加茂町斉野谷', '33', '33203', '7093904', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '加茂町斉野谷', 'カモチョウサイノタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市加茂町塔中', '33', '33203', '7093905', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '加茂町塔中', 'カモチョウタツチュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市加茂町小中原', '33', '33203', '7093906', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '加茂町小中原', 'カモチョウコナカバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市加茂町宇野', '33', '33203', '7093907', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '加茂町宇野', 'カモチョウウノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市加茂町原口', '33', '33203', '7093908', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '加茂町原口', 'カモチョウハラグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市加茂町物見', '33', '33203', '7093911', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '加茂町物見', 'カモチョウモノミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市加茂町河井', '33', '33203', '7093912', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '加茂町河井', 'カモチョウカワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市加茂町山下', '33', '33203', '7093913', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '加茂町山下', 'カモチョウサンゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市加茂町知和', '33', '33203', '7093914', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '加茂町知和', 'カモチョウチワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市加茂町青柳', '33', '33203', '7093915', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '加茂町青柳', 'カモチョウアオヤギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市加茂町公郷', '33', '33203', '7093921', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '加茂町公郷', 'カモチョウクゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市加茂町下津川', '33', '33203', '7093922', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '加茂町下津川', 'カモチョウシモツガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市加茂町桑原', '33', '33203', '7093923', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '加茂町桑原', 'カモチョウクワバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市加茂町小渕', '33', '33203', '7093924', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '加茂町小渕', 'カモチョウオブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市加茂町中原', '33', '33203', '7093931', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '加茂町中原', 'カモチョウナカバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市加茂町成安', '33', '33203', '7093932', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '加茂町成安', 'カモチョウナリヤス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市加茂町行重', '33', '33203', '7093933', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '加茂町行重', 'カモチョウユキシゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市加茂町楢井', '33', '33203', '7093934', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '加茂町楢井', 'カモチョウナライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市加茂町百々', '33', '33203', '7093935', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '加茂町百々', 'カモチョウドウドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市阿波', '33', '33203', '7093951', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '阿波', 'アバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市小房', '33', '33215', '7094201', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '小房', 'オブサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市梶原', '33', '33215', '7094202', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '梶原', 'カジワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市小野', '33', '33215', '7094203', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '小野', 'オノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市鷺巣', '33', '33215', '7094204', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '鷺巣', 'サギス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市粟井中', '33', '33215', '7094205', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '粟井中', 'アワイナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市五名', '33', '33215', '7094211', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '五名', 'ゴミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市宮原', '33', '33215', '7094212', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '宮原', 'ミヤバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市大聖寺', '33', '33215', '7094213', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '大聖寺', 'ダイショウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市豆田', '33', '33215', '7094214', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '豆田', 'マメダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市小ノ谷', '33', '33215', '7094215', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '小ノ谷', 'オノタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市山手', '33', '33215', '7094216', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '山手', 'ヤマテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市瀬戸', '33', '33215', '7094221', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '瀬戸', 'セト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市岩辺', '33', '33215', '7094222', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '岩辺', 'イワナベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市大内谷', '33', '33215', '7094223', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '大内谷', 'オオウチダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市豊野', '33', '33215', '7094224', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '豊野', 'トヨノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市松脇', '33', '33215', '7094225', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '松脇', 'マツワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市鯰', '33', '33215', '7094226', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '鯰', 'ナマズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市江見吉田', '33', '33215', '7094227', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '江見吉田', 'エミヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市南海', '33', '33215', '7094231', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '南海', 'ナンガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市芦河内', '33', '33215', '7094232', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '芦河内', 'アシゴウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市藤生', '33', '33215', '7094233', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '藤生', 'フジュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市江見', '33', '33215', '7094234', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '江見', 'エミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市原', '33', '33215', '7094235', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '原', 'ハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市川北', '33', '33215', '7094236', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '川北', 'カワギタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市日指', '33', '33215', '7094241', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '日指', 'ヒサシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市田原', '33', '33215', '7094242', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '田原', 'タワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市蓮花寺', '33', '33215', '7094243', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '蓮花寺', 'レンゲジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市土居', '33', '33215', '7094244', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '土居', 'ドイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市竹田', '33', '33215', '7094245', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '竹田', 'タケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市上福原', '33', '33215', '7094246', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '上福原', 'カミフクハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市山城', '33', '33215', '7094247', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '山城', 'ヤマシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市白水', '33', '33215', '7094251', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '白水', 'シラミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市角南', '33', '33215', '7094252', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '角南', 'スナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市柿ケ原', '33', '33215', '7094253', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '柿ケ原', 'カキガハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市万善', '33', '33215', '7094254', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '万善', 'マンゼン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市国貞', '33', '33215', '7094255', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '国貞', 'クニサダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市鈴家', '33', '33215', '7094256', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '鈴家', 'スズケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県美作市田渕', '33', '33215', '7094257', '岡山県', 'オカヤマケン', '美作市', 'ミマサカシ', '田渕', 'タブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県勝田郡勝央町', '33', '33622', '7094300', '岡山県', 'オカヤマケン', '勝田郡勝央町', 'カツタグンショウオウチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('88522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県勝田郡勝央町下町川', '33', '33622', '7094301', '岡山県', 'オカヤマケン', '勝田郡勝央町', 'カツタグンショウオウチョウ', '下町川', 'シモマチガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県勝田郡勝央町河原', '33', '33622', '7094302', '岡山県', 'オカヤマケン', '勝田郡勝央町', 'カツタグンショウオウチョウ', '河原', 'カワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県勝田郡勝央町豊久田', '33', '33622', '7094303', '岡山県', 'オカヤマケン', '勝田郡勝央町', 'カツタグンショウオウチョウ', '豊久田', 'トヨクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県勝田郡勝央町上香山', '33', '33622', '7094304', '岡山県', 'オカヤマケン', '勝田郡勝央町', 'カツタグンショウオウチョウ', '上香山', 'カミガヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県勝田郡勝央町曽井', '33', '33622', '7094305', '岡山県', 'オカヤマケン', '勝田郡勝央町', 'カツタグンショウオウチョウ', '曽井', 'ソイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県勝田郡勝央町美野', '33', '33622', '7094306', '岡山県', 'オカヤマケン', '勝田郡勝央町', 'カツタグンショウオウチョウ', '美野', 'ミノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県勝田郡勝央町石生', '33', '33622', '7094307', '岡山県', 'オカヤマケン', '勝田郡勝央町', 'カツタグンショウオウチョウ', '石生', 'イシュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県勝田郡勝央町岡', '33', '33622', '7094311', '岡山県', 'オカヤマケン', '勝田郡勝央町', 'カツタグンショウオウチョウ', '岡', 'オカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県勝田郡勝央町黒土', '33', '33622', '7094312', '岡山県', 'オカヤマケン', '勝田郡勝央町', 'カツタグンショウオウチョウ', '黒土', 'クロツチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県勝田郡勝央町小矢田', '33', '33622', '7094313', '岡山県', 'オカヤマケン', '勝田郡勝央町', 'カツタグンショウオウチョウ', '小矢田', 'オヤタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県勝田郡勝央町東吉田', '33', '33622', '7094314', '岡山県', 'オカヤマケン', '勝田郡勝央町', 'カツタグンショウオウチョウ', '東吉田', 'ヒガシヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県勝田郡勝央町畑屋', '33', '33622', '7094315', '岡山県', 'オカヤマケン', '勝田郡勝央町', 'カツタグンショウオウチョウ', '畑屋', 'ハタヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県勝田郡勝央町勝間田', '33', '33622', '7094316', '岡山県', 'オカヤマケン', '勝田郡勝央町', 'カツタグンショウオウチョウ', '勝間田', 'カツマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県勝田郡勝央町太平台', '33', '33622', '7094321', '岡山県', 'オカヤマケン', '勝田郡勝央町', 'カツタグンショウオウチョウ', '太平台', 'タイヘイダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県勝田郡勝央町福吉', '33', '33622', '7094322', '岡山県', 'オカヤマケン', '勝田郡勝央町', 'カツタグンショウオウチョウ', '福吉', 'フクヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県勝田郡勝央町黒坂', '33', '33622', '7094323', '岡山県', 'オカヤマケン', '勝田郡勝央町', 'カツタグンショウオウチョウ', '黒坂', 'クロサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県勝田郡勝央町為本', '33', '33622', '7094324', '岡山県', 'オカヤマケン', '勝田郡勝央町', 'カツタグンショウオウチョウ', '為本', 'タメモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県勝田郡勝央町植月北', '33', '33622', '7094331', '岡山県', 'オカヤマケン', '勝田郡勝央町', 'カツタグンショウオウチョウ', '植月北', 'ウエツキキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県勝田郡勝央町植月東', '33', '33622', '7094332', '岡山県', 'オカヤマケン', '勝田郡勝央町', 'カツタグンショウオウチョウ', '植月東', 'ウエツキヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県勝田郡勝央町田井', '33', '33622', '7094333', '岡山県', 'オカヤマケン', '勝田郡勝央町', 'カツタグンショウオウチョウ', '田井', 'タイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県勝田郡勝央町平', '33', '33622', '7094334', '岡山県', 'オカヤマケン', '勝田郡勝央町', 'カツタグンショウオウチョウ', '平', 'タイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県勝田郡勝央町植月中', '33', '33622', '7094335', '岡山県', 'オカヤマケン', '勝田郡勝央町', 'カツタグンショウオウチョウ', '植月中', 'ウエツキナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市宮部上', '33', '33203', '7094601', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '宮部上', 'ミヤベカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市宮部下', '33', '33203', '7094602', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '宮部下', 'ミヤベシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市中北下', '33', '33203', '7094603', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '中北下', 'ナカギタシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市坪井下', '33', '33203', '7094604', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '坪井下', 'ツボイシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市坪井上', '33', '33203', '7094605', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '坪井上', 'ツボイカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市中北上', '33', '33203', '7094606', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '中北上', 'ナカギタカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市領家', '33', '33203', '7094611', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '領家', 'リョウケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市くめ', '33', '33203', '7094612', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', 'くめ', 'クメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市宮尾', '33', '33203', '7094613', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '宮尾', 'ミヤオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市久米川南', '33', '33203', '7094614', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '久米川南', 'クメカワミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市一色', '33', '33203', '7094615', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '一色', 'イシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市南方中', '33', '33203', '7094616', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '南方中', 'ミナミガタナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市神代', '33', '33203', '7094621', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '神代', 'コウジロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市戸脇', '33', '33203', '7094622', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '戸脇', 'トワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市桑下', '33', '33203', '7094623', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '桑下', 'クワシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市桑上', '33', '33203', '7094624', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '桑上', 'クワカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市里公文', '33', '33203', '7094625', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '里公文', 'サトクモン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市里公文上', '33', '33203', '7094626', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '里公文上', 'サトクモンカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市福田下', '33', '33203', '7094631', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '福田下', 'フクダシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市八社', '33', '33203', '7094632', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '八社', 'ヤサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市油木上', '33', '33203', '7094633', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '油木上', 'ユキカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市油木下', '33', '33203', '7094634', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '油木下', 'ユキシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県津山市油木北', '33', '33203', '7094635', '岡山県', 'オカヤマケン', '津山市', 'ツヤマシ', '油木北', 'ユキキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市', '33', '33202', '7100000', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('88569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市三田', '33', '33202', '7100001', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '三田', 'ミツダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市生坂', '33', '33202', '7100002', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '生坂', 'イクサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市平田', '33', '33202', '7100003', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '平田', 'ヒラタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市西坂', '33', '33202', '7100004', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '西坂', 'ニシザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市西岡', '33', '33202', '7100005', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '西岡', 'ニシオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市祐安', '33', '33202', '7100006', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '祐安', 'スケヤス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市浅原', '33', '33202', '7100007', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '浅原', 'アサバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市徳芳', '33', '33202', '7100011', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '徳芳', 'トクボウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市鳥羽', '33', '33202', '7100012', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '鳥羽', 'トバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市中帯江', '33', '33202', '7100013', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '中帯江', 'ナカオビエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市黒崎', '33', '33202', '7100014', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '黒崎', 'クロサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市中庄団地', '33', '33202', '7100015', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '中庄団地', 'ナカショウダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市中庄', '33', '33202', '7100016', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '中庄', 'ナカショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市高須賀', '33', '33202', '7100021', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '高須賀', 'タカスカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市早高', '33', '33202', '7100022', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '早高', 'ハヤタカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市帯高', '33', '33202', '7100023', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '帯高', 'オビタカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市亀山', '33', '33202', '7100024', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '亀山', 'カメヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市倉敷ハイツ', '33', '33202', '7100025', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '倉敷ハイツ', 'クラシキハイツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市加須山', '33', '33202', '7100026', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '加須山', 'カスヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市西田', '33', '33202', '7100027', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '西田', 'ニシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市有城', '33', '33202', '7100031', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '有城', 'アルキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市東粒浦', '33', '33202', '7100032', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '東粒浦', 'ヒガシツブウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市粒江団地', '33', '33202', '7100033', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '粒江団地', 'ツブエダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市粒江', '33', '33202', '7100034', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '粒江', 'ツブエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市黒石', '33', '33202', '7100035', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '黒石', 'クロイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市粒浦', '33', '33202', '7100036', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '粒浦', 'ツブウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市八軒屋', '33', '33202', '7100037', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '八軒屋', 'ハチケンヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市新田', '33', '33202', '7100038', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '新田', 'シンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市五日市', '33', '33202', '7100041', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '五日市', 'イツカイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市二日市', '33', '33202', '7100042', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '二日市', 'フツカイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市羽島', '33', '33202', '7100043', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '羽島', 'ハシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市向山', '33', '33202', '7100044', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '向山', 'ムコウヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市船倉町', '33', '33202', '7100045', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '船倉町', 'フナグラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市中央', '33', '33202', '7100046', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市大島', '33', '33202', '7100047', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '大島', 'オオジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市福島', '33', '33202', '7100048', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '福島', 'フクシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市幸町', '33', '33202', '7100051', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市美和', '33', '33202', '7100052', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '美和', 'ミワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市東町', '33', '33202', '7100053', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '東町', 'ヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市本町', '33', '33202', '7100054', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市阿知', '33', '33202', '7100055', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '阿知', 'アチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市鶴形', '33', '33202', '7100056', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '鶴形', 'ツルガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市昭和', '33', '33202', '7100057', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '昭和', 'ショウワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市浜ノ茶屋', '33', '33202', '7100061', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '浜ノ茶屋', 'ハマノチャヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市浜町', '33', '33202', '7100062', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '浜町', 'ハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市日ノ出町', '33', '33202', '7100063', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '日ノ出町', 'ヒノデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市青江', '33', '33202', '7100064', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '青江', 'アオエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市宮前', '33', '33202', '7100065', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '宮前', 'ミヤマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市天城台', '33', '33202', '7100131', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '天城台', 'アマキダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市藤戸町天城', '33', '33202', '7100132', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '藤戸町天城', 'フジトチョウアマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市藤戸町藤戸', '33', '33202', '7100133', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '藤戸町藤戸', 'フジトチョウフジト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市串田', '33', '33202', '7100141', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '串田', 'クシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市林', '33', '33202', '7100142', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '林', 'ハヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市木見', '33', '33202', '7100143', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '木見', 'キミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市尾原', '33', '33202', '7100144', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '尾原', 'オバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市福江', '33', '33202', '7100145', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '福江', 'フクエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市曽原', '33', '33202', '7100146', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '曽原', 'ソバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県岡山市灘崎町植松', '33', '33201', '7100151', '岡山県', 'オカヤマケン', '岡山市', 'オカヤマシ', '灘崎町植松', 'ナダサキチョウウエマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市玉島長尾', '33', '33202', '7100251', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '玉島長尾', 'タマシマナガオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市玉島爪崎', '33', '33202', '7100252', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '玉島爪崎', 'タマシマツマサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市新倉敷駅前', '33', '33202', '7100253', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '新倉敷駅前', 'シンクラシキエキマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市船穂町船穂', '33', '33202', '7100261', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '船穂町船穂', 'フナオチョウフナオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市船穂町水江', '33', '33202', '7100262', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '船穂町水江', 'フナオチョウミズエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市船穂町柳井原', '33', '33202', '7100263', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '船穂町柳井原', 'フナオチョウヤナイハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市酒津', '33', '33202', '7100801', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '酒津', 'サカヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市水江', '33', '33202', '7100802', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '水江', 'ミズエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市中島', '33', '33202', '7100803', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '中島', 'ナカシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市西阿知町新田', '33', '33202', '7100804', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '西阿知町新田', 'ニシアチチョウシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市片島町', '33', '33202', '7100805', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '片島町', 'カタシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市西阿知町西原', '33', '33202', '7100806', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '西阿知町西原', 'ニシアチチョウニシバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市西阿知町', '33', '33202', '7100807', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '西阿知町', 'ニシアチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市川入', '33', '33202', '7100811', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '川入', 'カワイリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市北浜町', '33', '33202', '7100812', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '北浜町', 'キタハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市寿町', '33', '33202', '7100813', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '寿町', 'コトブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市石見町', '33', '33202', '7100814', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '石見町', 'イワミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市日吉町', '33', '33202', '7100815', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '日吉町', 'ヒヨセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市八王寺町', '33', '33202', '7100816', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '八王寺町', 'ハチオウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市大内', '33', '33202', '7100817', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '大内', 'オオウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市川西町', '33', '33202', '7100821', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '川西町', 'カワニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市稲荷町', '33', '33202', '7100822', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '稲荷町', 'イナリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市南町', '33', '33202', '7100823', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '南町', 'ミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市白楽町', '33', '33202', '7100824', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '白楽町', 'バクロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市安江', '33', '33202', '7100825', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '安江', 'ヤスエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市老松町', '33', '33202', '7100826', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '老松町', 'オイマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市田ノ上', '33', '33202', '7100831', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '田ノ上', 'タノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市田ノ上新町', '33', '33202', '7100832', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '田ノ上新町', 'タノウエシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市西中新田', '33', '33202', '7100833', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '西中新田', 'ニシナカシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市笹沖', '33', '33202', '7100834', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '笹沖', 'ササオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市四十瀬', '33', '33202', '7100835', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '四十瀬', 'シジュウセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市沖', '33', '33202', '7100836', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '沖', 'オキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市沖新町', '33', '33202', '7100837', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '沖新町', 'オキシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市堀南', '33', '33202', '7100841', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '堀南', 'ホリナン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市吉岡', '33', '33202', '7100842', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '吉岡', 'ヨシオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市浦田', '33', '33202', '7100843', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '浦田', 'ウラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市福井', '33', '33202', '7100844', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '福井', 'フクイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市西富井', '33', '33202', '7100845', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '西富井', 'ニシトミイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市上富井', '33', '33202', '7100846', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '上富井', 'カミトミイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市東富井', '33', '33202', '7100847', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '東富井', 'ヒガシトミイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市茶屋町', '33', '33202', '7101101', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '茶屋町', 'チャヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市茶屋町早沖', '33', '33202', '7101102', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '茶屋町早沖', 'チャヤマチハヤオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県総社市久代', '33', '33208', '7101201', '岡山県', 'オカヤマケン', '総社市', 'ソウジャシ', '久代', 'クシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県総社市山田', '33', '33208', '7101202', '岡山県', 'オカヤマケン', '総社市', 'ソウジャシ', '山田', 'ヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県総社市新本', '33', '33208', '7101203', '岡山県', 'オカヤマケン', '総社市', 'ソウジャシ', '新本', 'シンポン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市真備町箭田', '33', '33202', '7101301', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '真備町箭田', 'マビチョウヤタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市真備町服部', '33', '33202', '7101302', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '真備町服部', 'マビチョウハットリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市真備町妹', '33', '33202', '7101303', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '真備町妹', 'マビチョウセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市真備町尾崎', '33', '33202', '7101304', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '真備町尾崎', 'マビチョウオサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市真備町市場', '33', '33202', '7101305', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '真備町市場', 'マビチョウイチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市真備町有井', '33', '33202', '7101306', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '真備町有井', 'マビチョウアリイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市真備町岡田', '33', '33202', '7101311', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '真備町岡田', 'マビチョウオカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市真備町辻田', '33', '33202', '7101312', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '真備町辻田', 'マビチョウツジタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市真備町川辺', '33', '33202', '7101313', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '真備町川辺', 'マビチョウカワベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市真備町下二万', '33', '33202', '7101314', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '真備町下二万', 'マビチョウシモニマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市真備町上二万', '33', '33202', '7101315', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '真備町上二万', 'マビチョウカミニマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市西神楽南1条', '01', '01204', '0710171', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '西神楽南1条', 'ニシカグラミナミ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市西神楽南2条', '01', '01204', '0710172', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '西神楽南2条', 'ニシカグラミナミ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市西神楽北1条', '01', '01204', '0710173', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '西神楽北1条', 'ニシカグラキタ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市西神楽北2条', '01', '01204', '0710174', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '西神楽北2条', 'ニシカグラキタ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市西神楽4線', '01', '01204', '0710184', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '西神楽4線', 'ニシカグラ04セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市西神楽5線', '01', '01204', '0710185', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '西神楽5線', 'ニシカグラ05セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市西神楽南', '01', '01204', '0710186', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '西神楽南', 'ニシカグラミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡美瑛町', '01', '01459', '0710200', '北海道', 'ホッカイドウ', '上川郡美瑛町', 'カミカワグンビエイチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('88698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡美瑛町丸山', '01', '01459', '0710201', '北海道', 'ホッカイドウ', '上川郡美瑛町', 'カミカワグンビエイチョウ', '丸山', 'マルヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡美瑛町南町', '01', '01459', '0710202', '北海道', 'ホッカイドウ', '上川郡美瑛町', 'カミカワグンビエイチョウ', '南町', 'ミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡美瑛町西町', '01', '01459', '0710203', '北海道', 'ホッカイドウ', '上川郡美瑛町', 'カミカワグンビエイチョウ', '西町', 'ニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡美瑛町大町', '01', '01459', '0710204', '北海道', 'ホッカイドウ', '上川郡美瑛町', 'カミカワグンビエイチョウ', '大町', 'オオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡美瑛町栄町', '01', '01459', '0710205', '北海道', 'ホッカイドウ', '上川郡美瑛町', 'カミカワグンビエイチョウ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡美瑛町北町', '01', '01459', '0710206', '北海道', 'ホッカイドウ', '上川郡美瑛町', 'カミカワグンビエイチョウ', '北町', 'キタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡美瑛町中町', '01', '01459', '0710207', '北海道', 'ホッカイドウ', '上川郡美瑛町', 'カミカワグンビエイチョウ', '中町', 'ナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡美瑛町本町', '01', '01459', '0710208', '北海道', 'ホッカイドウ', '上川郡美瑛町', 'カミカワグンビエイチョウ', '本町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡美瑛町寿町', '01', '01459', '0710209', '北海道', 'ホッカイドウ', '上川郡美瑛町', 'カミカワグンビエイチョウ', '寿町', 'コトブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡美瑛町錦町', '01', '01459', '0710211', '北海道', 'ホッカイドウ', '上川郡美瑛町', 'カミカワグンビエイチョウ', '錦町', 'ニシキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡美瑛町旭町', '01', '01459', '0710212', '北海道', 'ホッカイドウ', '上川郡美瑛町', 'カミカワグンビエイチョウ', '旭町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡美瑛町東町', '01', '01459', '0710213', '北海道', 'ホッカイドウ', '上川郡美瑛町', 'カミカワグンビエイチョウ', '東町', 'ヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡美瑛町幸町', '01', '01459', '0710214', '北海道', 'ホッカイドウ', '上川郡美瑛町', 'カミカワグンビエイチョウ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡美瑛町扇町', '01', '01459', '0710215', '北海道', 'ホッカイドウ', '上川郡美瑛町', 'カミカワグンビエイチョウ', '扇町', 'オウギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡美瑛町大村大久保', '01', '01459', '0710216', '北海道', 'ホッカイドウ', '上川郡美瑛町', 'カミカワグンビエイチョウ', '大村', 'オオムラ', null, null, '大久保', 'オオクボ');
INSERT INTO `ms_addresses` VALUES ('88713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡美瑛町大村石山', '01', '01459', '0710217', '北海道', 'ホッカイドウ', '上川郡美瑛町', 'カミカワグンビエイチョウ', '大村', 'オオムラ', null, null, '石山', 'イシヤマ');
INSERT INTO `ms_addresses` VALUES ('88714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡美瑛町大村村山', '01', '01459', '0710218', '北海道', 'ホッカイドウ', '上川郡美瑛町', 'カミカワグンビエイチョウ', '大村', 'オオムラ', null, null, '村山', 'ムラヤマ');
INSERT INTO `ms_addresses` VALUES ('88715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡美瑛町大村中本', '01', '01459', '0710219', '北海道', 'ホッカイドウ', '上川郡美瑛町', 'カミカワグンビエイチョウ', '大村', 'オオムラ', null, null, '中本', 'ナカモト');
INSERT INTO `ms_addresses` VALUES ('88716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡美瑛町美田夕張', '01', '01459', '0710221', '北海道', 'ホッカイドウ', '上川郡美瑛町', 'カミカワグンビエイチョウ', '美田', 'ミタ', null, null, '夕張', 'ユウバリ');
INSERT INTO `ms_addresses` VALUES ('88717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡美瑛町美田', '01', '01459', '0710222', '北海道', 'ホッカイドウ', '上川郡美瑛町', 'カミカワグンビエイチョウ', '美田', 'ミタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡美瑛町五稜', '01', '01459', '0710223', '北海道', 'ホッカイドウ', '上川郡美瑛町', 'カミカワグンビエイチョウ', '五稜', 'ゴリョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡美瑛町北瑛', '01', '01459', '0710224', '北海道', 'ホッカイドウ', '上川郡美瑛町', 'カミカワグンビエイチョウ', '北瑛', 'ホクエイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡美瑛町明治大三', '01', '01459', '0710225', '北海道', 'ホッカイドウ', '上川郡美瑛町', 'カミカワグンビエイチョウ', '明治', 'メイジ', null, null, '大三', 'ダイサン');
INSERT INTO `ms_addresses` VALUES ('88721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡美瑛町下宇莫別', '01', '01459', '0710226', '北海道', 'ホッカイドウ', '上川郡美瑛町', 'カミカワグンビエイチョウ', '下宇莫別', 'シモウバクベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡美瑛町中宇莫別赤羽', '01', '01459', '0710227', '北海道', 'ホッカイドウ', '上川郡美瑛町', 'カミカワグンビエイチョウ', '中宇莫別', 'ナカウバクベツ', null, null, '赤羽', 'アカバネ');
INSERT INTO `ms_addresses` VALUES ('88723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡美瑛町中宇莫別', '01', '01459', '0710228', '北海道', 'ホッカイドウ', '上川郡美瑛町', 'カミカワグンビエイチョウ', '中宇莫別', 'ナカウバクベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡美瑛町上宇莫別', '01', '01459', '0710229', '北海道', 'ホッカイドウ', '上川郡美瑛町', 'カミカワグンビエイチョウ', '上宇莫別', 'カミウバクベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡美瑛町明治', '01', '01459', '0710231', '北海道', 'ホッカイドウ', '上川郡美瑛町', 'カミカワグンビエイチョウ', '明治', 'メイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡美瑛町明治沼崎', '01', '01459', '0710232', '北海道', 'ホッカイドウ', '上川郡美瑛町', 'カミカワグンビエイチョウ', '明治', 'メイジ', null, null, '沼崎', 'ヌマザキ');
INSERT INTO `ms_addresses` VALUES ('88727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡美瑛町新区画', '01', '01459', '0710233', '北海道', 'ホッカイドウ', '上川郡美瑛町', 'カミカワグンビエイチョウ', '新区画', 'シンクカク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡美瑛町置杵牛', '01', '01459', '0710234', '北海道', 'ホッカイドウ', '上川郡美瑛町', 'カミカワグンビエイチョウ', '置杵牛', 'オキキネウシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡美瑛町白金', '01', '01459', '0710235', '北海道', 'ホッカイドウ', '上川郡美瑛町', 'カミカワグンビエイチョウ', '白金', 'シロガネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡美瑛町美沢', '01', '01459', '0710236', '北海道', 'ホッカイドウ', '上川郡美瑛町', 'カミカワグンビエイチョウ', '美沢', 'ミサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡美瑛町福富豊栄', '01', '01459', '0710237', '北海道', 'ホッカイドウ', '上川郡美瑛町', 'カミカワグンビエイチョウ', '福富', 'フクトミ', null, null, '豊栄', 'ホウエイ');
INSERT INTO `ms_addresses` VALUES ('88732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡美瑛町藤野', '01', '01459', '0710238', '北海道', 'ホッカイドウ', '上川郡美瑛町', 'カミカワグンビエイチョウ', '藤野', 'フジノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡美瑛町美瑛原野原野', '01', '01459', '0710239', '北海道', 'ホッカイドウ', '上川郡美瑛町', 'カミカワグンビエイチョウ', '美瑛原野', 'ビエイゲンヤ', null, null, '原野', 'ゲンヤ');
INSERT INTO `ms_addresses` VALUES ('88734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡美瑛町三愛緑', '01', '01459', '0710240', '北海道', 'ホッカイドウ', '上川郡美瑛町', 'カミカワグンビエイチョウ', '三愛', 'サンアイ', null, null, '緑', 'ミドリ');
INSERT INTO `ms_addresses` VALUES ('88735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡美瑛町水沢水上', '01', '01459', '0710241', '北海道', 'ホッカイドウ', '上川郡美瑛町', 'カミカワグンビエイチョウ', '水沢', 'ミズサワ', null, null, '水上', 'ミズカミ');
INSERT INTO `ms_addresses` VALUES ('88736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡美瑛町水沢', '01', '01459', '0710242', '北海道', 'ホッカイドウ', '上川郡美瑛町', 'カミカワグンビエイチョウ', '水沢', 'ミズサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡美瑛町福富間宮', '01', '01459', '0710243', '北海道', 'ホッカイドウ', '上川郡美瑛町', 'カミカワグンビエイチョウ', '福富', 'フクトミ', null, null, '間宮', 'マミヤ');
INSERT INTO `ms_addresses` VALUES ('88738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡美瑛町福富福美沢', '01', '01459', '0710244', '北海道', 'ホッカイドウ', '上川郡美瑛町', 'カミカワグンビエイチョウ', '福富', 'フクトミ', null, null, '福美沢', 'フクミザワ');
INSERT INTO `ms_addresses` VALUES ('88739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡美瑛町福富福富瑛進', '01', '01459', '0710245', '北海道', 'ホッカイドウ', '上川郡美瑛町', 'カミカワグンビエイチョウ', '福富', 'フクトミ', null, null, '福富瑛進', 'フクトミエイシン');
INSERT INTO `ms_addresses` VALUES ('88740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡美瑛町福富福富憩', '01', '01459', '0710246', '北海道', 'ホッカイドウ', '上川郡美瑛町', 'カミカワグンビエイチョウ', '福富', 'フクトミ', null, null, '福富憩', 'フクトミイコイ');
INSERT INTO `ms_addresses` VALUES ('88741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡美瑛町三愛大曲', '01', '01459', '0710247', '北海道', 'ホッカイドウ', '上川郡美瑛町', 'カミカワグンビエイチョウ', '三愛', 'サンアイ', null, null, '大曲', 'オオマガリ');
INSERT INTO `ms_addresses` VALUES ('88742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡美瑛町花園', '01', '01459', '0710248', '北海道', 'ホッカイドウ', '上川郡美瑛町', 'カミカワグンビエイチョウ', '花園', 'ハナゾノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡美瑛町憩町', '01', '01459', '0710249', '北海道', 'ホッカイドウ', '上川郡美瑛町', 'カミカワグンビエイチョウ', '憩町', 'イコイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡美瑛町憩が丘', '01', '01459', '0710251', '北海道', 'ホッカイドウ', '上川郡美瑛町', 'カミカワグンビエイチョウ', '憩が丘', 'イコイガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡美瑛町旭', '01', '01459', '0710261', '北海道', 'ホッカイドウ', '上川郡美瑛町', 'カミカワグンビエイチョウ', '旭', 'アサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡美瑛町横牛', '01', '01459', '0710351', '北海道', 'ホッカイドウ', '上川郡美瑛町', 'カミカワグンビエイチョウ', '横牛', 'ヨコウシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡美瑛町朗根内', '01', '01459', '0710352', '北海道', 'ホッカイドウ', '上川郡美瑛町', 'カミカワグンビエイチョウ', '朗根内', 'ロウネナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡美瑛町俵真布', '01', '01459', '0710353', '北海道', 'ホッカイドウ', '上川郡美瑛町', 'カミカワグンビエイチョウ', '俵真布', 'タワラマップ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡美瑛町天人峡', '01', '01459', '0710355', '北海道', 'ホッカイドウ', '上川郡美瑛町', 'カミカワグンビエイチョウ', '天人峡', 'テンニンキョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡美瑛町美馬牛', '01', '01459', '0710471', '北海道', 'ホッカイドウ', '上川郡美瑛町', 'カミカワグンビエイチョウ', '美馬牛', 'ビバウシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡美瑛町美馬牛市街地', '01', '01459', '0710472', '北海道', 'ホッカイドウ', '上川郡美瑛町', 'カミカワグンビエイチョウ', '美馬牛市街地', 'ビバウシシガイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡美瑛町新星', '01', '01459', '0710473', '北海道', 'ホッカイドウ', '上川郡美瑛町', 'カミカワグンビエイチョウ', '新星', 'シンセイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡美瑛町拓進', '01', '01459', '0710474', '北海道', 'ホッカイドウ', '上川郡美瑛町', 'カミカワグンビエイチョウ', '拓進', 'タクシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡美瑛町常盤', '01', '01459', '0710475', '北海道', 'ホッカイドウ', '上川郡美瑛町', 'カミカワグンビエイチョウ', '常盤', 'トキワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡美瑛町御牧', '01', '01459', '0710476', '北海道', 'ホッカイドウ', '上川郡美瑛町', 'カミカワグンビエイチョウ', '御牧', 'ミマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡美瑛町二股', '01', '01459', '0710477', '北海道', 'ホッカイドウ', '上川郡美瑛町', 'カミカワグンビエイチョウ', '二股', 'フタマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡美瑛町瑠辺蘂', '01', '01459', '0710478', '北海道', 'ホッカイドウ', '上川郡美瑛町', 'カミカワグンビエイチョウ', '瑠辺蘂', 'ルベシベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡美瑛町美園', '01', '01459', '0710479', '北海道', 'ホッカイドウ', '上川郡美瑛町', 'カミカワグンビエイチョウ', '美園', 'ミソノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡上富良野町', '01', '01460', '0710500', '北海道', 'ホッカイドウ', '空知郡上富良野町', 'ソラチグンカミフラノチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('88762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡上富良野町西1線北', '01', '01460', '0710501', '北海道', 'ホッカイドウ', '空知郡上富良野町', 'ソラチグンカミフラノチョウ', '西1線北', 'ニシ01センキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡上富良野町西2線北', '01', '01460', '0710502', '北海道', 'ホッカイドウ', '空知郡上富良野町', 'ソラチグンカミフラノチョウ', '西2線北', 'ニシ02センキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡上富良野町西3線北', '01', '01460', '0710503', '北海道', 'ホッカイドウ', '空知郡上富良野町', 'ソラチグンカミフラノチョウ', '西3線北', 'ニシ03センキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡上富良野町西4線北', '01', '01460', '0710504', '北海道', 'ホッカイドウ', '空知郡上富良野町', 'ソラチグンカミフラノチョウ', '西4線北', 'ニシ04センキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡上富良野町西5線北', '01', '01460', '0710505', '北海道', 'ホッカイドウ', '空知郡上富良野町', 'ソラチグンカミフラノチョウ', '西5線北', 'ニシ05センキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡上富良野町西6線北', '01', '01460', '0710506', '北海道', 'ホッカイドウ', '空知郡上富良野町', 'ソラチグンカミフラノチョウ', '西6線北', 'ニシ06センキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡上富良野町西7線北', '01', '01460', '0710507', '北海道', 'ホッカイドウ', '空知郡上富良野町', 'ソラチグンカミフラノチョウ', '西7線北', 'ニシ07センキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡上富良野町西8線北', '01', '01460', '0710508', '北海道', 'ホッカイドウ', '空知郡上富良野町', 'ソラチグンカミフラノチョウ', '西8線北', 'ニシ08センキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡上富良野町西9線北', '01', '01460', '0710509', '北海道', 'ホッカイドウ', '空知郡上富良野町', 'ソラチグンカミフラノチョウ', '西9線北', 'ニシ09センキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡上富良野町西10線北', '01', '01460', '0710510', '北海道', 'ホッカイドウ', '空知郡上富良野町', 'ソラチグンカミフラノチョウ', '西10線北', 'ニシ10センキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡上富良野町西11線北', '01', '01460', '0710511', '北海道', 'ホッカイドウ', '空知郡上富良野町', 'ソラチグンカミフラノチョウ', '西11線北', 'ニシ11センキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡上富良野町西12線北', '01', '01460', '0710512', '北海道', 'ホッカイドウ', '空知郡上富良野町', 'ソラチグンカミフラノチョウ', '西12線北', 'ニシ12センキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡上富良野町西13線北', '01', '01460', '0710513', '北海道', 'ホッカイドウ', '空知郡上富良野町', 'ソラチグンカミフラノチョウ', '西13線北', 'ニシ13センキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡上富良野町西14線北', '01', '01460', '0710514', '北海道', 'ホッカイドウ', '空知郡上富良野町', 'ソラチグンカミフラノチョウ', '西14線北', 'ニシ14センキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡上富良野町西15線北', '01', '01460', '0710515', '北海道', 'ホッカイドウ', '空知郡上富良野町', 'ソラチグンカミフラノチョウ', '西15線北', 'ニシ15センキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡上富良野町西16線北', '01', '01460', '0710516', '北海道', 'ホッカイドウ', '空知郡上富良野町', 'ソラチグンカミフラノチョウ', '西16線北', 'ニシ16センキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡上富良野町沼崎農場', '01', '01460', '0710517', '北海道', 'ホッカイドウ', '空知郡上富良野町', 'ソラチグンカミフラノチョウ', '沼崎農場', 'ヌマザキノウジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡上富良野町基線北', '01', '01460', '0710520', '北海道', 'ホッカイドウ', '空知郡上富良野町', 'ソラチグンカミフラノチョウ', '基線北', 'キセンキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡上富良野町東1線北', '01', '01460', '0710521', '北海道', 'ホッカイドウ', '空知郡上富良野町', 'ソラチグンカミフラノチョウ', '東1線北', 'ヒガシ01センキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡上富良野町東2線北', '01', '01460', '0710522', '北海道', 'ホッカイドウ', '空知郡上富良野町', 'ソラチグンカミフラノチョウ', '東2線北', 'ヒガシ02センキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡上富良野町東3線北', '01', '01460', '0710523', '北海道', 'ホッカイドウ', '空知郡上富良野町', 'ソラチグンカミフラノチョウ', '東3線北', 'ヒガシ03センキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡上富良野町東4線北', '01', '01460', '0710524', '北海道', 'ホッカイドウ', '空知郡上富良野町', 'ソラチグンカミフラノチョウ', '東4線北', 'ヒガシ04センキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡上富良野町東5線北', '01', '01460', '0710525', '北海道', 'ホッカイドウ', '空知郡上富良野町', 'ソラチグンカミフラノチョウ', '東5線北', 'ヒガシ05センキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡上富良野町東6線北', '01', '01460', '0710526', '北海道', 'ホッカイドウ', '空知郡上富良野町', 'ソラチグンカミフラノチョウ', '東6線北', 'ヒガシ06センキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡上富良野町東7線北', '01', '01460', '0710527', '北海道', 'ホッカイドウ', '空知郡上富良野町', 'ソラチグンカミフラノチョウ', '東7線北', 'ヒガシ07センキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡上富良野町東8線北', '01', '01460', '0710528', '北海道', 'ホッカイドウ', '空知郡上富良野町', 'ソラチグンカミフラノチョウ', '東8線北', 'ヒガシ08センキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡上富良野町東9線北', '01', '01460', '0710529', '北海道', 'ホッカイドウ', '空知郡上富良野町', 'ソラチグンカミフラノチョウ', '東9線北', 'ヒガシ09センキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡上富良野町東10線北', '01', '01460', '0710530', '北海道', 'ホッカイドウ', '空知郡上富良野町', 'ソラチグンカミフラノチョウ', '東10線北', 'ヒガシ10センキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡上富良野町東11線北', '01', '01460', '0710531', '北海道', 'ホッカイドウ', '空知郡上富良野町', 'ソラチグンカミフラノチョウ', '東11線北', 'ヒガシ11センキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡上富良野町東12線北', '01', '01460', '0710532', '北海道', 'ホッカイドウ', '空知郡上富良野町', 'ソラチグンカミフラノチョウ', '東12線北', 'ヒガシ12センキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡上富良野町倍本農場', '01', '01460', '0710533', '北海道', 'ホッカイドウ', '空知郡上富良野町', 'ソラチグンカミフラノチョウ', '倍本農場', 'バイホンノウジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡上富良野町西谷牧場', '01', '01460', '0710534', '北海道', 'ホッカイドウ', '空知郡上富良野町', 'ソラチグンカミフラノチョウ', '西谷牧場', 'ニシタニボクジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡上富良野町富町', '01', '01460', '0710541', '北海道', 'ホッカイドウ', '空知郡上富良野町', 'ソラチグンカミフラノチョウ', '富町', 'トミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡上富良野町錦町', '01', '01460', '0710542', '北海道', 'ホッカイドウ', '空知郡上富良野町', 'ソラチグンカミフラノチョウ', '錦町', 'ニシキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡上富良野町中町', '01', '01460', '0710543', '北海道', 'ホッカイドウ', '空知郡上富良野町', 'ソラチグンカミフラノチョウ', '中町', 'ナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡上富良野町栄町', '01', '01460', '0710544', '北海道', 'ホッカイドウ', '空知郡上富良野町', 'ソラチグンカミフラノチョウ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡上富良野町光町', '01', '01460', '0710545', '北海道', 'ホッカイドウ', '空知郡上富良野町', 'ソラチグンカミフラノチョウ', '光町', 'ヒカリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡上富良野町西町', '01', '01460', '0710546', '北海道', 'ホッカイドウ', '空知郡上富良野町', 'ソラチグンカミフラノチョウ', '西町', 'ニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡上富良野町泉町', '01', '01460', '0710547', '北海道', 'ホッカイドウ', '空知郡上富良野町', 'ソラチグンカミフラノチョウ', '泉町', 'イズミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡上富良野町扇町', '01', '01460', '0710548', '北海道', 'ホッカイドウ', '空知郡上富良野町', 'ソラチグンカミフラノチョウ', '扇町', 'オウギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡上富良野町北町', '01', '01460', '0710549', '北海道', 'ホッカイドウ', '空知郡上富良野町', 'ソラチグンカミフラノチョウ', '北町', 'キタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡上富良野町本町', '01', '01460', '0710551', '北海道', 'ホッカイドウ', '空知郡上富良野町', 'ソラチグンカミフラノチョウ', '本町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡上富良野町宮町', '01', '01460', '0710552', '北海道', 'ホッカイドウ', '空知郡上富良野町', 'ソラチグンカミフラノチョウ', '宮町', 'ミヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡上富良野町旭町', '01', '01460', '0710553', '北海道', 'ホッカイドウ', '空知郡上富良野町', 'ソラチグンカミフラノチョウ', '旭町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡上富良野町新町', '01', '01460', '0710554', '北海道', 'ホッカイドウ', '空知郡上富良野町', 'ソラチグンカミフラノチョウ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡上富良野町東町', '01', '01460', '0710555', '北海道', 'ホッカイドウ', '空知郡上富良野町', 'ソラチグンカミフラノチョウ', '東町', 'ヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡上富良野町大町', '01', '01460', '0710561', '北海道', 'ホッカイドウ', '空知郡上富良野町', 'ソラチグンカミフラノチョウ', '大町', 'オオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡上富良野町南町', '01', '01460', '0710562', '北海道', 'ホッカイドウ', '空知郡上富良野町', 'ソラチグンカミフラノチョウ', '南町', 'ミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡上富良野町緑町', '01', '01460', '0710563', '北海道', 'ホッカイドウ', '空知郡上富良野町', 'ソラチグンカミフラノチョウ', '緑町', 'ミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡上富良野町桜町', '01', '01460', '0710564', '北海道', 'ホッカイドウ', '空知郡上富良野町', 'ソラチグンカミフラノチョウ', '桜町', 'サクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡上富良野町丘町', '01', '01460', '0710565', '北海道', 'ホッカイドウ', '空知郡上富良野町', 'ソラチグンカミフラノチョウ', '丘町', 'オカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡上富良野町向町', '01', '01460', '0710566', '北海道', 'ホッカイドウ', '空知郡上富良野町', 'ソラチグンカミフラノチョウ', '向町', 'ムカイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡上富良野町新井牧場', '01', '01460', '0710571', '北海道', 'ホッカイドウ', '空知郡上富良野町', 'ソラチグンカミフラノチョウ', '新井牧場', 'アライボクジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡上富良野町細野農場', '01', '01460', '0710572', '北海道', 'ホッカイドウ', '空知郡上富良野町', 'ソラチグンカミフラノチョウ', '細野農場', 'ホソノノウジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡上富良野町松井牧場', '01', '01460', '0710573', '北海道', 'ホッカイドウ', '空知郡上富良野町', 'ソラチグンカミフラノチョウ', '松井牧場', 'マツイボクジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡上富良野町第1安井牧場', '01', '01460', '0710574', '北海道', 'ホッカイドウ', '空知郡上富良野町', 'ソラチグンカミフラノチョウ', '第1安井牧場', 'ダイ01ヤスイボクジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡上富良野町第2安井牧場', '01', '01460', '0710575', '北海道', 'ホッカイドウ', '空知郡上富良野町', 'ソラチグンカミフラノチョウ', '第2安井牧場', 'ダイ02ヤスイボクジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡上富良野町十人牧場', '01', '01460', '0710576', '北海道', 'ホッカイドウ', '空知郡上富良野町', 'ソラチグンカミフラノチョウ', '十人牧場', 'ジュウニンボクジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡上富良野町中の沢', '01', '01460', '0710577', '北海道', 'ホッカイドウ', '空知郡上富良野町', 'ソラチグンカミフラノチョウ', '中の沢', 'ナカノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡上富良野町山加農場', '01', '01460', '0710578', '北海道', 'ホッカイドウ', '空知郡上富良野町', 'ソラチグンカミフラノチョウ', '山加農場', 'ヤマカノウジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡上富良野町吹上', '01', '01460', '0710579', '北海道', 'ホッカイドウ', '空知郡上富良野町', 'ソラチグンカミフラノチョウ', '吹上', 'フキアゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡上富良野町津郷農場', '01', '01460', '0710583', '北海道', 'ホッカイドウ', '空知郡上富良野町', 'ソラチグンカミフラノチョウ', '津郷農場', 'ツゴウノウジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡中富良野町', '01', '01461', '0710700', '北海道', 'ホッカイドウ', '空知郡中富良野町', 'ソラチグンナカフラノチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('88827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡中富良野町基線北', '01', '01461', '0710704', '北海道', 'ホッカイドウ', '空知郡中富良野町', 'ソラチグンナカフラノチョウ', '基線北', 'キセンキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡中富良野町西1線北', '01', '01461', '0710705', '北海道', 'ホッカイドウ', '空知郡中富良野町', 'ソラチグンナカフラノチョウ', '西1線北', 'ニシ01センキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡中富良野町西2線北', '01', '01461', '0710706', '北海道', 'ホッカイドウ', '空知郡中富良野町', 'ソラチグンナカフラノチョウ', '西2線北', 'ニシ02センキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡中富良野町西3線北', '01', '01461', '0710707', '北海道', 'ホッカイドウ', '空知郡中富良野町', 'ソラチグンナカフラノチョウ', '西3線北', 'ニシ03センキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡中富良野町ベベルイ', '01', '01461', '0710711', '北海道', 'ホッカイドウ', '空知郡中富良野町', 'ソラチグンナカフラノチョウ', 'ベベルイ', 'ベベルイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡中富良野町宮町', '01', '01461', '0710714', '北海道', 'ホッカイドウ', '空知郡中富良野町', 'ソラチグンナカフラノチョウ', '宮町', 'ミヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡中富良野町東町', '01', '01461', '0710726', '北海道', 'ホッカイドウ', '空知郡中富良野町', 'ソラチグンナカフラノチョウ', '東町', 'ヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡中富良野町新田中農場', '01', '01461', '0710731', '北海道', 'ホッカイドウ', '空知郡中富良野町', 'ソラチグンナカフラノチョウ', '新田中農場', 'シンタナカノウジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡中富良野町田中農場', '01', '01461', '0710732', '北海道', 'ホッカイドウ', '空知郡中富良野町', 'ソラチグンナカフラノチョウ', '田中農場', 'タナカノウジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡中富良野町伊藤農場', '01', '01461', '0710733', '北海道', 'ホッカイドウ', '空知郡中富良野町', 'ソラチグンナカフラノチョウ', '伊藤農場', 'イトウノウジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡中富良野町鹿討農場', '01', '01461', '0710734', '北海道', 'ホッカイドウ', '空知郡中富良野町', 'ソラチグンナカフラノチョウ', '鹿討農場', 'シカウチノウジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡中富良野町日進', '01', '01461', '0710735', '北海道', 'ホッカイドウ', '空知郡中富良野町', 'ソラチグンナカフラノチョウ', '日進', 'ニッシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡中富良野町吉井農場', '01', '01461', '0710736', '北海道', 'ホッカイドウ', '空知郡中富良野町', 'ソラチグンナカフラノチョウ', '吉井農場', 'ヨシイノウジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡中富良野町奈江', '01', '01461', '0710737', '北海道', 'ホッカイドウ', '空知郡中富良野町', 'ソラチグンナカフラノチョウ', '奈江', 'ナエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡中富良野町福原農場', '01', '01461', '0710742', '北海道', 'ホッカイドウ', '空知郡中富良野町', 'ソラチグンナカフラノチョウ', '福原農場', 'フクハラノウジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡中富良野町北町', '01', '01461', '0710751', '北海道', 'ホッカイドウ', '空知郡中富良野町', 'ソラチグンナカフラノチョウ', '北町', 'キタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡中富良野町本町', '01', '01461', '0710752', '北海道', 'ホッカイドウ', '空知郡中富良野町', 'ソラチグンナカフラノチョウ', '本町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡中富良野町南町', '01', '01461', '0710753', '北海道', 'ホッカイドウ', '空知郡中富良野町', 'ソラチグンナカフラノチョウ', '南町', 'ミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡中富良野町新町', '01', '01461', '0710754', '北海道', 'ホッカイドウ', '空知郡中富良野町', 'ソラチグンナカフラノチョウ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡中富良野町旭町', '01', '01461', '0710755', '北海道', 'ホッカイドウ', '空知郡中富良野町', 'ソラチグンナカフラノチョウ', '旭町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡中富良野町西町', '01', '01461', '0710761', '北海道', 'ホッカイドウ', '空知郡中富良野町', 'ソラチグンナカフラノチョウ', '西町', 'ニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡中富良野町丘町', '01', '01461', '0710762', '北海道', 'ホッカイドウ', '空知郡中富良野町', 'ソラチグンナカフラノチョウ', '丘町', 'オカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡中富良野町暁町', '01', '01461', '0710770', '北海道', 'ホッカイドウ', '空知郡中富良野町', 'ソラチグンナカフラノチョウ', '暁町', 'アカツキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡中富良野町東1線北', '01', '01461', '0710771', '北海道', 'ホッカイドウ', '空知郡中富良野町', 'ソラチグンナカフラノチョウ', '東1線北', 'ヒガシ01センキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡中富良野町東2線北', '01', '01461', '0710772', '北海道', 'ホッカイドウ', '空知郡中富良野町', 'ソラチグンナカフラノチョウ', '東2線北', 'ヒガシ02センキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡中富良野町東3線北', '01', '01461', '0710773', '北海道', 'ホッカイドウ', '空知郡中富良野町', 'ソラチグンナカフラノチョウ', '東3線北', 'ヒガシ03センキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡中富良野町東4線北', '01', '01461', '0710774', '北海道', 'ホッカイドウ', '空知郡中富良野町', 'ソラチグンナカフラノチョウ', '東4線北', 'ヒガシ04センキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡中富良野町東5線北', '01', '01461', '0710775', '北海道', 'ホッカイドウ', '空知郡中富良野町', 'ソラチグンナカフラノチョウ', '東5線北', 'ヒガシ05センキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡中富良野町東6線北', '01', '01461', '0710776', '北海道', 'ホッカイドウ', '空知郡中富良野町', 'ソラチグンナカフラノチョウ', '東6線北', 'ヒガシ06センキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡中富良野町東7線北', '01', '01461', '0710777', '北海道', 'ホッカイドウ', '空知郡中富良野町', 'ソラチグンナカフラノチョウ', '東7線北', 'ヒガシ07センキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡中富良野町東8線北', '01', '01461', '0710778', '北海道', 'ホッカイドウ', '空知郡中富良野町', 'ソラチグンナカフラノチョウ', '東8線北', 'ヒガシ08センキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡中富良野町東9線北', '01', '01461', '0710779', '北海道', 'ホッカイドウ', '空知郡中富良野町', 'ソラチグンナカフラノチョウ', '東9線北', 'ヒガシ09センキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡中富良野町東10線北', '01', '01461', '0710780', '北海道', 'ホッカイドウ', '空知郡中富良野町', 'ソラチグンナカフラノチョウ', '東10線北', 'ヒガシ10センキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡中富良野町東11線北', '01', '01461', '0710781', '北海道', 'ホッカイドウ', '空知郡中富良野町', 'ソラチグンナカフラノチョウ', '東11線北', 'ヒガシ11センキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市児島由加', '33', '33202', '7110901', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '児島由加', 'コジマユガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市児島白尾', '33', '33202', '7110902', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '児島白尾', 'コジマシロオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市児島田の口', '33', '33202', '7110903', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '児島田の口', 'コジマタノクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市児島唐琴', '33', '33202', '7110904', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '児島唐琴', 'コジマカラコト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市児島唐琴町', '33', '33202', '7110905', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '児島唐琴町', 'コジマカラコトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市児島下の町', '33', '33202', '7110906', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '児島下の町', 'コジマシモノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市児島上の町', '33', '33202', '7110907', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '児島上の町', 'コジマカミノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市児島小川', '33', '33202', '7110911', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '児島小川', 'コジマオガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市児島小川町', '33', '33202', '7110912', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '児島小川町', 'コジマオガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市児島味野', '33', '33202', '7110913', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '児島味野', 'コジマアジノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市児島味野城', '33', '33202', '7110914', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '児島味野城', 'コジマアジノジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市児島味野山田町', '33', '33202', '7110915', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '児島味野山田町', 'コジマアジノヤマダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市児島味野城山', '33', '33202', '7110916', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '児島味野城山', 'コジマアジノシロヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市児島味野上', '33', '33202', '7110917', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '児島味野上', 'コジマアジノカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市児島駅前', '33', '33202', '7110921', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '児島駅前', 'コジマエキマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市児島元浜町', '33', '33202', '7110922', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '児島元浜町', 'コジマモトハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市児島阿津', '33', '33202', '7110923', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '児島阿津', 'コジマアツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市大畠', '33', '33202', '7110924', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '大畠', 'オオバタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市下津井田之浦', '33', '33202', '7110925', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '下津井田之浦', 'シモツイタノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市下津井吹上', '33', '33202', '7110926', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '下津井吹上', 'シモツイフキアゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市下津井', '33', '33202', '7110927', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '下津井', 'シモツイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市児島赤崎', '33', '33202', '7110931', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '児島赤崎', 'コジマアカサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市菰池', '33', '33202', '7110932', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '菰池', 'コモイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市児島通生', '33', '33202', '7110933', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '児島通生', 'コジマカヨウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市児島塩生', '33', '33202', '7110934', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '児島塩生', 'コジマシオナス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市児島宇野津', '33', '33202', '7110935', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '児島宇野津', 'コジマウノツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市児島柳田町', '33', '33202', '7110936', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '児島柳田町', 'コジマヤナイダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市児島稗田町', '33', '33202', '7110937', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '児島稗田町', 'コジマヒエダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市江丹別町清水', '01', '01204', '0711171', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '江丹別町清水', 'エタンベツチョウシミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市江丹別町拓北', '01', '01204', '0711172', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '江丹別町拓北', 'エタンベツチョウタクホク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市江丹別町中央', '01', '01204', '0711173', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '江丹別町中央', 'エタンベツチョウチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市江丹別町富原', '01', '01204', '0711174', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '江丹別町富原', 'エタンベツチョウトミハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市江丹別町中園', '01', '01204', '0711175', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '江丹別町中園', 'エタンベツチョウナカゾノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市江丹別町西里', '01', '01204', '0711176', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '江丹別町西里', 'エタンベツチョウニシサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市江丹別町芳野', '01', '01204', '0711177', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '江丹別町芳野', 'エタンベツチョウヨシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡鷹栖町', '01', '01452', '0711200', '北海道', 'ホッカイドウ', '上川郡鷹栖町', 'カミカワグンタカスチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('88930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡鷹栖町南1条', '01', '01452', '0711201', '北海道', 'ホッカイドウ', '上川郡鷹栖町', 'カミカワグンタカスチョウ', '南1条', 'ミナミ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡鷹栖町南2条', '01', '01452', '0711202', '北海道', 'ホッカイドウ', '上川郡鷹栖町', 'カミカワグンタカスチョウ', '南2条', 'ミナミ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡鷹栖町北1条', '01', '01452', '0711211', '北海道', 'ホッカイドウ', '上川郡鷹栖町', 'カミカワグンタカスチョウ', '北1条', 'キタ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡鷹栖町北野東1条', '01', '01452', '0711221', '北海道', 'ホッカイドウ', '上川郡鷹栖町', 'カミカワグンタカスチョウ', '北野東1条', 'キタノヒガシ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡鷹栖町北野東2条', '01', '01452', '0711222', '北海道', 'ホッカイドウ', '上川郡鷹栖町', 'カミカワグンタカスチョウ', '北野東2条', 'キタノヒガシ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡鷹栖町北野東3条', '01', '01452', '0711223', '北海道', 'ホッカイドウ', '上川郡鷹栖町', 'カミカワグンタカスチョウ', '北野東3条', 'キタノヒガシ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡鷹栖町北野東4条', '01', '01452', '0711224', '北海道', 'ホッカイドウ', '上川郡鷹栖町', 'カミカワグンタカスチョウ', '北野東4条', 'キタノヒガシ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡鷹栖町北野東5条', '01', '01452', '0711225', '北海道', 'ホッカイドウ', '上川郡鷹栖町', 'カミカワグンタカスチョウ', '北野東5条', 'キタノヒガシ05ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡鷹栖町北野西1条', '01', '01452', '0711231', '北海道', 'ホッカイドウ', '上川郡鷹栖町', 'カミカワグンタカスチョウ', '北野西1条', 'キタノニシ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡鷹栖町北野西2条', '01', '01452', '0711232', '北海道', 'ホッカイドウ', '上川郡鷹栖町', 'カミカワグンタカスチョウ', '北野西2条', 'キタノニシ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡鷹栖町北野西3条', '01', '01452', '0711233', '北海道', 'ホッカイドウ', '上川郡鷹栖町', 'カミカワグンタカスチョウ', '北野西3条', 'キタノニシ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡鷹栖町北野西4条', '01', '01452', '0711234', '北海道', 'ホッカイドウ', '上川郡鷹栖町', 'カミカワグンタカスチョウ', '北野西4条', 'キタノニシ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡鷹栖町北野西5条', '01', '01452', '0711235', '北海道', 'ホッカイドウ', '上川郡鷹栖町', 'カミカワグンタカスチョウ', '北野西5条', 'キタノニシ05ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡鷹栖町7線', '01', '01452', '0711247', '北海道', 'ホッカイドウ', '上川郡鷹栖町', 'カミカワグンタカスチョウ', '7線', '07セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡鷹栖町8線', '01', '01452', '0711248', '北海道', 'ホッカイドウ', '上川郡鷹栖町', 'カミカワグンタカスチョウ', '8線', '08セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡鷹栖町9線', '01', '01452', '0711249', '北海道', 'ホッカイドウ', '上川郡鷹栖町', 'カミカワグンタカスチョウ', '9線', '09セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡鷹栖町10線', '01', '01452', '0711250', '北海道', 'ホッカイドウ', '上川郡鷹栖町', 'カミカワグンタカスチョウ', '10線', '10セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡鷹栖町11線', '01', '01452', '0711251', '北海道', 'ホッカイドウ', '上川郡鷹栖町', 'カミカワグンタカスチョウ', '11線', '11セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡鷹栖町12線', '01', '01452', '0711252', '北海道', 'ホッカイドウ', '上川郡鷹栖町', 'カミカワグンタカスチョウ', '12線', '12セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡鷹栖町13線', '01', '01452', '0711253', '北海道', 'ホッカイドウ', '上川郡鷹栖町', 'カミカワグンタカスチョウ', '13線', '13セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡鷹栖町14線', '01', '01452', '0711254', '北海道', 'ホッカイドウ', '上川郡鷹栖町', 'カミカワグンタカスチョウ', '14線', '14セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡鷹栖町15線', '01', '01452', '0711255', '北海道', 'ホッカイドウ', '上川郡鷹栖町', 'カミカワグンタカスチョウ', '15線', '15セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡鷹栖町16線', '01', '01452', '0711256', '北海道', 'ホッカイドウ', '上川郡鷹栖町', 'カミカワグンタカスチョウ', '16線', '16セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡鷹栖町17線', '01', '01452', '0711257', '北海道', 'ホッカイドウ', '上川郡鷹栖町', 'カミカワグンタカスチョウ', '17線', '17セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡鷹栖町18線', '01', '01452', '0711258', '北海道', 'ホッカイドウ', '上川郡鷹栖町', 'カミカワグンタカスチョウ', '18線', '18セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡鷹栖町19線', '01', '01452', '0711259', '北海道', 'ホッカイドウ', '上川郡鷹栖町', 'カミカワグンタカスチョウ', '19線', '19セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡鷹栖町20線', '01', '01452', '0711260', '北海道', 'ホッカイドウ', '上川郡鷹栖町', 'カミカワグンタカスチョウ', '20線', '20セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡鷹栖町21線', '01', '01452', '0711261', '北海道', 'ホッカイドウ', '上川郡鷹栖町', 'カミカワグンタカスチョウ', '21線', '21セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡鷹栖町22線', '01', '01452', '0711262', '北海道', 'ホッカイドウ', '上川郡鷹栖町', 'カミカワグンタカスチョウ', '22線', '22セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡鷹栖町23線', '01', '01452', '0711263', '北海道', 'ホッカイドウ', '上川郡鷹栖町', 'カミカワグンタカスチョウ', '23線', '23セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡鷹栖町24線', '01', '01452', '0711264', '北海道', 'ホッカイドウ', '上川郡鷹栖町', 'カミカワグンタカスチョウ', '24線', '24セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡鷹栖町25線', '01', '01452', '0711265', '北海道', 'ホッカイドウ', '上川郡鷹栖町', 'カミカワグンタカスチョウ', '25線', '25セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡鷹栖町26線', '01', '01452', '0711266', '北海道', 'ホッカイドウ', '上川郡鷹栖町', 'カミカワグンタカスチョウ', '26線', '26セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡鷹栖町27線', '01', '01452', '0711267', '北海道', 'ホッカイドウ', '上川郡鷹栖町', 'カミカワグンタカスチョウ', '27線', '27セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東川町', '01', '01458', '0711400', '北海道', 'ホッカイドウ', '上川郡東川町', 'カミカワグンヒガシカワチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('88969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東川町西2号北', '01', '01458', '0711402', '北海道', 'ホッカイドウ', '上川郡東川町', 'カミカワグンヒガシカワチョウ', '西2号北', 'ニシ02ゴウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東川町西3号北', '01', '01458', '0711403', '北海道', 'ホッカイドウ', '上川郡東川町', 'カミカワグンヒガシカワチョウ', '西3号北', 'ニシ03ゴウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東川町西4号北', '01', '01458', '0711404', '北海道', 'ホッカイドウ', '上川郡東川町', 'カミカワグンヒガシカワチョウ', '西4号北', 'ニシ04ゴウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東川町西5号北', '01', '01458', '0711405', '北海道', 'ホッカイドウ', '上川郡東川町', 'カミカワグンヒガシカワチョウ', '西5号北', 'ニシ05ゴウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東川町西6号北', '01', '01458', '0711406', '北海道', 'ホッカイドウ', '上川郡東川町', 'カミカワグンヒガシカワチョウ', '西6号北', 'ニシ06ゴウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東川町西7号北', '01', '01458', '0711407', '北海道', 'ホッカイドウ', '上川郡東川町', 'カミカワグンヒガシカワチョウ', '西7号北', 'ニシ07ゴウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東川町西8号北', '01', '01458', '0711408', '北海道', 'ホッカイドウ', '上川郡東川町', 'カミカワグンヒガシカワチョウ', '西8号北', 'ニシ08ゴウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東川町西9号北', '01', '01458', '0711409', '北海道', 'ホッカイドウ', '上川郡東川町', 'カミカワグンヒガシカワチョウ', '西9号北', 'ニシ09ゴウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東川町西10号北', '01', '01458', '0711410', '北海道', 'ホッカイドウ', '上川郡東川町', 'カミカワグンヒガシカワチョウ', '西10号北', 'ニシ10ゴウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東川町西11号北', '01', '01458', '0711411', '北海道', 'ホッカイドウ', '上川郡東川町', 'カミカワグンヒガシカワチョウ', '西11号北', 'ニシ11ゴウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東川町西12号北', '01', '01458', '0711412', '北海道', 'ホッカイドウ', '上川郡東川町', 'カミカワグンヒガシカワチョウ', '西12号北', 'ニシ12ゴウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東川町西2号南', '01', '01458', '0711422', '北海道', 'ホッカイドウ', '上川郡東川町', 'カミカワグンヒガシカワチョウ', '西2号南', 'ニシ02ゴウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東川町東町', '01', '01458', '0711423', '北海道', 'ホッカイドウ', '上川郡東川町', 'カミカワグンヒガシカワチョウ', '東町', 'ヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東川町南町', '01', '01458', '0711424', '北海道', 'ホッカイドウ', '上川郡東川町', 'カミカワグンヒガシカワチョウ', '南町', 'ミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東川町西町', '01', '01458', '0711425', '北海道', 'ホッカイドウ', '上川郡東川町', 'カミカワグンヒガシカワチョウ', '西町', 'ニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東川町北町', '01', '01458', '0711426', '北海道', 'ホッカイドウ', '上川郡東川町', 'カミカワグンヒガシカワチョウ', '北町', 'キタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東川町1号北', '01', '01458', '0711431', '北海道', 'ホッカイドウ', '上川郡東川町', 'カミカワグンヒガシカワチョウ', '1号北', '01ゴウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東川町東2号北', '01', '01458', '0711432', '北海道', 'ホッカイドウ', '上川郡東川町', 'カミカワグンヒガシカワチョウ', '東2号北', 'ヒガシ02ゴウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東川町東3号北', '01', '01458', '0711433', '北海道', 'ホッカイドウ', '上川郡東川町', 'カミカワグンヒガシカワチョウ', '東3号北', 'ヒガシ03ゴウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東川町東4号北', '01', '01458', '0711434', '北海道', 'ホッカイドウ', '上川郡東川町', 'カミカワグンヒガシカワチョウ', '東4号北', 'ヒガシ04ゴウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東川町東5号北', '01', '01458', '0711435', '北海道', 'ホッカイドウ', '上川郡東川町', 'カミカワグンヒガシカワチョウ', '東5号北', 'ヒガシ05ゴウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東川町東6号北', '01', '01458', '0711436', '北海道', 'ホッカイドウ', '上川郡東川町', 'カミカワグンヒガシカワチョウ', '東6号北', 'ヒガシ06ゴウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東川町東7号北', '01', '01458', '0711437', '北海道', 'ホッカイドウ', '上川郡東川町', 'カミカワグンヒガシカワチョウ', '東7号北', 'ヒガシ07ゴウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東川町東8号北', '01', '01458', '0711438', '北海道', 'ホッカイドウ', '上川郡東川町', 'カミカワグンヒガシカワチョウ', '東8号北', 'ヒガシ08ゴウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東川町東9号北', '01', '01458', '0711439', '北海道', 'ホッカイドウ', '上川郡東川町', 'カミカワグンヒガシカワチョウ', '東9号北', 'ヒガシ09ゴウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東川町東10号北', '01', '01458', '0711440', '北海道', 'ホッカイドウ', '上川郡東川町', 'カミカワグンヒガシカワチョウ', '東10号北', 'ヒガシ10ゴウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東川町東11号北', '01', '01458', '0711441', '北海道', 'ホッカイドウ', '上川郡東川町', 'カミカワグンヒガシカワチョウ', '東11号北', 'ヒガシ11ゴウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東川町東12号北', '01', '01458', '0711442', '北海道', 'ホッカイドウ', '上川郡東川町', 'カミカワグンヒガシカワチョウ', '東12号北', 'ヒガシ12ゴウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東川町1号南', '01', '01458', '0711451', '北海道', 'ホッカイドウ', '上川郡東川町', 'カミカワグンヒガシカワチョウ', '1号南', '01ゴウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東川町東2号南', '01', '01458', '0711452', '北海道', 'ホッカイドウ', '上川郡東川町', 'カミカワグンヒガシカワチョウ', '東2号南', 'ヒガシ02ゴウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('88999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東川町東3号南', '01', '01458', '0711453', '北海道', 'ホッカイドウ', '上川郡東川町', 'カミカワグンヒガシカワチョウ', '東3号南', 'ヒガシ03ゴウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東川町東4号南', '01', '01458', '0711454', '北海道', 'ホッカイドウ', '上川郡東川町', 'カミカワグンヒガシカワチョウ', '東4号南', 'ヒガシ04ゴウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東川町東5号南', '01', '01458', '0711455', '北海道', 'ホッカイドウ', '上川郡東川町', 'カミカワグンヒガシカワチョウ', '東5号南', 'ヒガシ05ゴウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東川町東6号南', '01', '01458', '0711456', '北海道', 'ホッカイドウ', '上川郡東川町', 'カミカワグンヒガシカワチョウ', '東6号南', 'ヒガシ06ゴウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東川町東7号南', '01', '01458', '0711457', '北海道', 'ホッカイドウ', '上川郡東川町', 'カミカワグンヒガシカワチョウ', '東7号南', 'ヒガシ07ゴウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東川町東8号南', '01', '01458', '0711458', '北海道', 'ホッカイドウ', '上川郡東川町', 'カミカワグンヒガシカワチョウ', '東8号南', 'ヒガシ08ゴウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東川町東9号南', '01', '01458', '0711459', '北海道', 'ホッカイドウ', '上川郡東川町', 'カミカワグンヒガシカワチョウ', '東9号南', 'ヒガシ09ゴウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東川町東10号南', '01', '01458', '0711460', '北海道', 'ホッカイドウ', '上川郡東川町', 'カミカワグンヒガシカワチョウ', '東10号南', 'ヒガシ10ゴウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東川町東11号南', '01', '01458', '0711461', '北海道', 'ホッカイドウ', '上川郡東川町', 'カミカワグンヒガシカワチョウ', '東11号南', 'ヒガシ11ゴウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東川町北2線東', '01', '01458', '0711462', '北海道', 'ホッカイドウ', '上川郡東川町', 'カミカワグンヒガシカワチョウ', '北2線東', 'キタ02センヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東川町北3線東', '01', '01458', '0711463', '北海道', 'ホッカイドウ', '上川郡東川町', 'カミカワグンヒガシカワチョウ', '北3線東', 'キタ03センヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東川町進化台', '01', '01458', '0711464', '北海道', 'ホッカイドウ', '上川郡東川町', 'カミカワグンヒガシカワチョウ', '進化台', 'シンカダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東川町北5線', '01', '01458', '0711465', '北海道', 'ホッカイドウ', '上川郡東川町', 'カミカワグンヒガシカワチョウ', '北5線', 'キタ05セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東川町北7線', '01', '01458', '0711466', '北海道', 'ホッカイドウ', '上川郡東川町', 'カミカワグンヒガシカワチョウ', '北7線', 'キタ07セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東川町北7線東', '01', '01458', '0711467', '北海道', 'ホッカイドウ', '上川郡東川町', 'カミカワグンヒガシカワチョウ', '北7線東', 'キタ07センヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東川町ノカナン', '01', '01458', '0711471', '北海道', 'ホッカイドウ', '上川郡東川町', 'カミカワグンヒガシカワチョウ', 'ノカナン', 'ノカナン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東川町勇駒別', '01', '01458', '0711472', '北海道', 'ホッカイドウ', '上川郡東川町', 'カミカワグンヒガシカワチョウ', '勇駒別', 'ユコマンベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東川町松山温泉', '01', '01458', '0711473', '北海道', 'ホッカイドウ', '上川郡東川町', 'カミカワグンヒガシカワチョウ', '松山温泉', 'マツヤマオンセン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡美瑛町忠別', '01', '01459', '0711474', '北海道', 'ホッカイドウ', '上川郡美瑛町', 'カミカワグンビエイチョウ', '忠別', 'チュウベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東神楽町', '01', '01453', '0711500', '北海道', 'ホッカイドウ', '上川郡東神楽町', 'カミカワグンヒガシカグラチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('89025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東神楽町南1条西', '01', '01453', '0711501', '北海道', 'ホッカイドウ', '上川郡東神楽町', 'カミカワグンヒガシカグラチョウ', '南1条西', 'ミナミ01ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東神楽町南1条東', '01', '01453', '0711502', '北海道', 'ホッカイドウ', '上川郡東神楽町', 'カミカワグンヒガシカグラチョウ', '南1条東', 'ミナミ01ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東神楽町南2条西', '01', '01453', '0711503', '北海道', 'ホッカイドウ', '上川郡東神楽町', 'カミカワグンヒガシカグラチョウ', '南2条西', 'ミナミ02ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東神楽町南2条東', '01', '01453', '0711504', '北海道', 'ホッカイドウ', '上川郡東神楽町', 'カミカワグンヒガシカグラチョウ', '南2条東', 'ミナミ02ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東神楽町南3条東', '01', '01453', '0711505', '北海道', 'ホッカイドウ', '上川郡東神楽町', 'カミカワグンヒガシカグラチョウ', '南3条東', 'ミナミ03ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東神楽町北1条西', '01', '01453', '0711511', '北海道', 'ホッカイドウ', '上川郡東神楽町', 'カミカワグンヒガシカグラチョウ', '北1条西', 'キタ01ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東神楽町北1条東', '01', '01453', '0711512', '北海道', 'ホッカイドウ', '上川郡東神楽町', 'カミカワグンヒガシカグラチョウ', '北1条東', 'キタ01ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東神楽町北2条西', '01', '01453', '0711513', '北海道', 'ホッカイドウ', '上川郡東神楽町', 'カミカワグンヒガシカグラチョウ', '北2条西', 'キタ02ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東神楽町北2条東', '01', '01453', '0711514', '北海道', 'ホッカイドウ', '上川郡東神楽町', 'カミカワグンヒガシカグラチョウ', '北2条東', 'キタ02ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東神楽町北3条東', '01', '01453', '0711515', '北海道', 'ホッカイドウ', '上川郡東神楽町', 'カミカワグンヒガシカグラチョウ', '北3条東', 'キタ03ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東神楽町ひじり野北1条', '01', '01453', '0711521', '北海道', 'ホッカイドウ', '上川郡東神楽町', 'カミカワグンヒガシカグラチョウ', 'ひじり野北1条', 'ヒジリノキタ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東神楽町ひじり野北2条', '01', '01453', '0711522', '北海道', 'ホッカイドウ', '上川郡東神楽町', 'カミカワグンヒガシカグラチョウ', 'ひじり野北2条', 'ヒジリノキタ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東神楽町ひじり野南1条', '01', '01453', '0711523', '北海道', 'ホッカイドウ', '上川郡東神楽町', 'カミカワグンヒガシカグラチョウ', 'ひじり野南1条', 'ヒジリノミナミ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東神楽町ひじり野南2条', '01', '01453', '0711524', '北海道', 'ホッカイドウ', '上川郡東神楽町', 'カミカワグンヒガシカグラチョウ', 'ひじり野南2条', 'ヒジリノミナミ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東神楽町ひじり野南3条', '01', '01453', '0711525', '北海道', 'ホッカイドウ', '上川郡東神楽町', 'カミカワグンヒガシカグラチョウ', 'ひじり野南3条', 'ヒジリノミナミ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東神楽町3号', '01', '01453', '0711533', '北海道', 'ホッカイドウ', '上川郡東神楽町', 'カミカワグンヒガシカグラチョウ', '3号', '03ゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東神楽町4号', '01', '01453', '0711534', '北海道', 'ホッカイドウ', '上川郡東神楽町', 'カミカワグンヒガシカグラチョウ', '4号', '04ゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東神楽町5号', '01', '01453', '0711535', '北海道', 'ホッカイドウ', '上川郡東神楽町', 'カミカワグンヒガシカグラチョウ', '5号', '05ゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東神楽町6号', '01', '01453', '0711536', '北海道', 'ホッカイドウ', '上川郡東神楽町', 'カミカワグンヒガシカグラチョウ', '6号', '06ゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東神楽町7号', '01', '01453', '0711537', '北海道', 'ホッカイドウ', '上川郡東神楽町', 'カミカワグンヒガシカグラチョウ', '7号', '07ゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東神楽町8号', '01', '01453', '0711538', '北海道', 'ホッカイドウ', '上川郡東神楽町', 'カミカワグンヒガシカグラチョウ', '8号', '08ゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東神楽町9号', '01', '01453', '0711539', '北海道', 'ホッカイドウ', '上川郡東神楽町', 'カミカワグンヒガシカグラチョウ', '9号', '09ゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東神楽町10号', '01', '01453', '0711540', '北海道', 'ホッカイドウ', '上川郡東神楽町', 'カミカワグンヒガシカグラチョウ', '10号', '10ゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東神楽町11号', '01', '01453', '0711541', '北海道', 'ホッカイドウ', '上川郡東神楽町', 'カミカワグンヒガシカグラチョウ', '11号', '11ゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東神楽町12号', '01', '01453', '0711542', '北海道', 'ホッカイドウ', '上川郡東神楽町', 'カミカワグンヒガシカグラチョウ', '12号', '12ゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東神楽町13号', '01', '01453', '0711543', '北海道', 'ホッカイドウ', '上川郡東神楽町', 'カミカワグンヒガシカグラチョウ', '13号', '13ゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東神楽町14号', '01', '01453', '0711544', '北海道', 'ホッカイドウ', '上川郡東神楽町', 'カミカワグンヒガシカグラチョウ', '14号', '14ゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東神楽町15号', '01', '01453', '0711545', '北海道', 'ホッカイドウ', '上川郡東神楽町', 'カミカワグンヒガシカグラチョウ', '15号', '15ゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東神楽町16号', '01', '01453', '0711546', '北海道', 'ホッカイドウ', '上川郡東神楽町', 'カミカワグンヒガシカグラチョウ', '16号', '16ゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東神楽町17号', '01', '01453', '0711547', '北海道', 'ホッカイドウ', '上川郡東神楽町', 'カミカワグンヒガシカグラチョウ', '17号', '17ゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東神楽町18号', '01', '01453', '0711548', '北海道', 'ホッカイドウ', '上川郡東神楽町', 'カミカワグンヒガシカグラチョウ', '18号', '18ゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東神楽町19号', '01', '01453', '0711549', '北海道', 'ホッカイドウ', '上川郡東神楽町', 'カミカワグンヒガシカグラチョウ', '19号', '19ゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東神楽町20号', '01', '01453', '0711550', '北海道', 'ホッカイドウ', '上川郡東神楽町', 'カミカワグンヒガシカグラチョウ', '20号', '20ゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東神楽町21号', '01', '01453', '0711551', '北海道', 'ホッカイドウ', '上川郡東神楽町', 'カミカワグンヒガシカグラチョウ', '21号', '21ゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東神楽町22号', '01', '01453', '0711552', '北海道', 'ホッカイドウ', '上川郡東神楽町', 'カミカワグンヒガシカグラチョウ', '22号', '22ゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東神楽町23号', '01', '01453', '0711553', '北海道', 'ホッカイドウ', '上川郡東神楽町', 'カミカワグンヒガシカグラチョウ', '23号', '23ゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東神楽町24号', '01', '01453', '0711554', '北海道', 'ホッカイドウ', '上川郡東神楽町', 'カミカワグンヒガシカグラチョウ', '24号', '24ゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東神楽町25号', '01', '01453', '0711555', '北海道', 'ホッカイドウ', '上川郡東神楽町', 'カミカワグンヒガシカグラチョウ', '25号', '25ゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東神楽町26号', '01', '01453', '0711556', '北海道', 'ホッカイドウ', '上川郡東神楽町', 'カミカワグンヒガシカグラチョウ', '26号', '26ゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東神楽町27号', '01', '01453', '0711557', '北海道', 'ホッカイドウ', '上川郡東神楽町', 'カミカワグンヒガシカグラチョウ', '27号', '27ゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東神楽町基線', '01', '01453', '0711560', '北海道', 'ホッカイドウ', '上川郡東神楽町', 'カミカワグンヒガシカグラチョウ', '基線', 'キセン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東神楽町東一線', '01', '01453', '0711561', '北海道', 'ホッカイドウ', '上川郡東神楽町', 'カミカワグンヒガシカグラチョウ', '東一線', 'ヒガシ01セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東神楽町東二線', '01', '01453', '0711562', '北海道', 'ホッカイドウ', '上川郡東神楽町', 'カミカワグンヒガシカグラチョウ', '東二線', 'ヒガシ02セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東神楽町東三線', '01', '01453', '0711563', '北海道', 'ホッカイドウ', '上川郡東神楽町', 'カミカワグンヒガシカグラチョウ', '東三線', 'ヒガシ03セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東神楽町東四線', '01', '01453', '0711564', '北海道', 'ホッカイドウ', '上川郡東神楽町', 'カミカワグンヒガシカグラチョウ', '東四線', 'ヒガシ04セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東神楽町東五線', '01', '01453', '0711565', '北海道', 'ホッカイドウ', '上川郡東神楽町', 'カミカワグンヒガシカグラチョウ', '東五線', 'ヒガシ05セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東神楽町南13号', '01', '01453', '0711570', '北海道', 'ホッカイドウ', '上川郡東神楽町', 'カミカワグンヒガシカグラチョウ', '南13号', 'ミナミ13ゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東神楽町南1番通', '01', '01453', '0711571', '北海道', 'ホッカイドウ', '上川郡東神楽町', 'カミカワグンヒガシカグラチョウ', '南1番通', 'ミナミ01バンドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東神楽町南2線', '01', '01453', '0711572', '北海道', 'ホッカイドウ', '上川郡東神楽町', 'カミカワグンヒガシカグラチョウ', '南2線', 'ミナミ02セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東神楽町南3線', '01', '01453', '0711573', '北海道', 'ホッカイドウ', '上川郡東神楽町', 'カミカワグンヒガシカグラチョウ', '南3線', 'ミナミ03セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東神楽町南4線', '01', '01453', '0711574', '北海道', 'ホッカイドウ', '上川郡東神楽町', 'カミカワグンヒガシカグラチョウ', '南4線', 'ミナミ04セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東神楽町南5線', '01', '01453', '0711575', '北海道', 'ホッカイドウ', '上川郡東神楽町', 'カミカワグンヒガシカグラチョウ', '南5線', 'ミナミ05セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東神楽町八千代ケ岡', '01', '01453', '0711577', '北海道', 'ホッカイドウ', '上川郡東神楽町', 'カミカワグンヒガシカグラチョウ', '八千代ケ岡', 'ヤチヨガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東神楽町栄岡', '01', '01453', '0711581', '北海道', 'ホッカイドウ', '上川郡東神楽町', 'カミカワグンヒガシカグラチョウ', '栄岡', 'サカエオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡東神楽町志比内', '01', '01453', '0711582', '北海道', 'ホッカイドウ', '上川郡東神楽町', 'カミカワグンヒガシカグラチョウ', '志比内', 'シビナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市連島町西之浦', '33', '33202', '7128001', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '連島町西之浦', 'ツラジマチョウニシノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市連島町亀島新田', '33', '33202', '7128002', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '連島町亀島新田', 'ツラジマチョウカメジマシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市水島明神町', '33', '33202', '7128003', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '水島明神町', 'ミズシマミョウジンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市水島南亀島町', '33', '33202', '7128004', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '水島南亀島町', 'ミズシマミナミカメジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市水島北亀島町', '33', '33202', '7128005', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '水島北亀島町', 'ミズシマキタカメジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市連島町鶴新田', '33', '33202', '7128006', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '連島町鶴新田', 'ツラジマチョウツルシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市鶴の浦', '33', '33202', '7128007', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '鶴の浦', 'ツルノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市連島町連島', '33', '33202', '7128011', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '連島町連島', 'ツラジマチョウツラジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市連島', '33', '33202', '7128012', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '連島', 'ツラジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市亀島', '33', '33202', '7128013', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '亀島', 'カメジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市連島中央', '33', '33202', '7128014', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '連島中央', 'ツラジマチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市連島町矢柄', '33', '33202', '7128015', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '連島町矢柄', 'ツラジマチョウヤガラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市水島東川町', '33', '33202', '7128021', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '水島東川町', 'ミズシマヒガシガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市水島北緑町', '33', '33202', '7128022', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '水島北緑町', 'ミズシマキタミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市水島南緑町', '33', '33202', '7128023', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '水島南緑町', 'ミズシマミナミミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市水島北春日町', '33', '33202', '7128024', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '水島北春日町', 'ミズシマキタカスガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市水島南春日町', '33', '33202', '7128025', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '水島南春日町', 'ミズシマミナミカスガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市水島南瑞穂町', '33', '33202', '7128026', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '水島南瑞穂町', 'ミズシマミナミミズホチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市水島北瑞穂町', '33', '33202', '7128027', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '水島北瑞穂町', 'ミズシマキタミズホチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市福田町浦田', '33', '33202', '7128031', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '福田町浦田', 'フクダチョウウラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市北畝', '33', '33202', '7128032', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '北畝', 'キタセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市水島東栄町', '33', '33202', '7128033', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '水島東栄町', 'ミズシマヒガシサカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市水島西栄町', '33', '33202', '7128034', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '水島西栄町', 'ミズシマニシサカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市水島東弥生町', '33', '33202', '7128035', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '水島東弥生町', 'ミズシマヒガシヤヨイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市水島西弥生町', '33', '33202', '7128036', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '水島西弥生町', 'ミズシマニシヤヨイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市水島東寿町', '33', '33202', '7128037', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '水島東寿町', 'ミズシマヒガシコトブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市水島西寿町', '33', '33202', '7128038', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '水島西寿町', 'ミズシマニシコトブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市水島相生町', '33', '33202', '7128039', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '水島相生町', 'ミズシマアイオイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市福田町福田', '33', '33202', '7128041', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '福田町福田', 'フクダチョウフクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市福田町広江', '33', '33202', '7128042', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '福田町広江', 'フクダチョウヒロエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市広江', '33', '33202', '7128043', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '広江', 'ヒロエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市東塚', '33', '33202', '7128044', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '東塚', 'ヒガシヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市福田町東塚', '33', '33202', '7128045', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '福田町東塚', 'フクダチョウヒガシヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市福田町古新田', '33', '33202', '7128046', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '福田町古新田', 'フクダチョウコシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市中畝', '33', '33202', '7128051', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '中畝', 'ナカセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市松江', '33', '33202', '7128052', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '松江', 'マツエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市呼松', '33', '33202', '7128053', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '呼松', 'ヨビマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市呼松町', '33', '33202', '7128053', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '呼松町', 'ヨビマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市潮通', '33', '33202', '7128054', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '潮通', 'ウシオドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市南畝', '33', '33202', '7128055', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '南畝', 'ミナミセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市水島福崎町', '33', '33202', '7128056', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '水島福崎町', 'ミズシマフクサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市水島東千鳥町', '33', '33202', '7128057', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '水島東千鳥町', 'ミズシマヒガシチドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市水島東常盤町', '33', '33202', '7128058', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '水島東常盤町', 'ミズシマヒガシトキワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市水島西常盤町', '33', '33202', '7128059', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '水島西常盤町', 'ミズシマニシトキワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市神田', '33', '33202', '7128061', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '神田', 'カンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市水島北幸町', '33', '33202', '7128062', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '水島北幸町', 'ミズシマキタサイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市水島南幸町', '33', '33202', '7128063', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '水島南幸町', 'ミズシマミナミサイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市水島青葉町', '33', '33202', '7128064', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '水島青葉町', 'ミズシマアオバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市水島西千鳥町', '33', '33202', '7128065', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '水島西千鳥町', 'ミズシマニシチドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市水島高砂町', '33', '33202', '7128066', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '水島高砂町', 'ミズシマタカサゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市水島海岸通', '33', '33202', '7128071', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '水島海岸通', 'ミズシマカイガンドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市水島中通', '33', '33202', '7128072', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '水島中通', 'ミズシマナカドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市水島西通', '33', '33202', '7128073', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '水島西通', 'ミズシマニシドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市水島川崎通', '33', '33202', '7128074', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '水島川崎通', 'ミズシマカワサキドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市玉島上成', '33', '33202', '7138101', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '玉島上成', 'タマシマウワナリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市玉島', '33', '33202', '7138102', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '玉島', 'タマシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市玉島乙島', '33', '33202', '7138103', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '玉島乙島', 'タマシマオトシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市玉島服部', '33', '33202', '7138111', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '玉島服部', 'タマシマハットリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市玉島陶', '33', '33202', '7138112', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '玉島陶', 'タマシマスエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市玉島八島', '33', '33202', '7138113', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '玉島八島', 'タマシマヤシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市玉島道越', '33', '33202', '7138114', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '玉島道越', 'タマシマミチゴエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市玉島道口', '33', '33202', '7138115', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '玉島道口', 'タマシマミチグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市玉島富', '33', '33202', '7138116', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '玉島富', 'タマシマトミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市玉島阿賀崎', '33', '33202', '7138121', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '玉島阿賀崎', 'タマシマアガサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市玉島中央町', '33', '33202', '7138122', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '玉島中央町', 'タマシマチュウオウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市玉島柏島', '33', '33202', '7138123', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '玉島柏島', 'タマシマカシワジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市玉島柏台', '33', '33202', '7138124', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '玉島柏台', 'タマシマカシワダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市玉島勇崎', '33', '33202', '7138125', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '玉島勇崎', 'タマシマユウザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市玉島黒崎', '33', '33202', '7138126', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '玉島黒崎', 'タマシマクロサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県倉敷市玉島黒崎新町', '33', '33202', '7138127', '岡山県', 'オカヤマケン', '倉敷市', 'クラシキシ', '玉島黒崎新町', 'タマシマクロサキシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県笠岡市', '33', '33205', '7140000', '岡山県', 'オカヤマケン', '笠岡市', 'カサオカシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('89198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県笠岡市走出', '33', '33205', '7140001', '岡山県', 'オカヤマケン', '笠岡市', 'カサオカシ', '走出', 'ハシリデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県笠岡市甲弩', '33', '33205', '7140002', '岡山県', 'オカヤマケン', '笠岡市', 'カサオカシ', '甲弩', 'コウノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県笠岡市尾坂', '33', '33205', '7140003', '岡山県', 'オカヤマケン', '笠岡市', 'カサオカシ', '尾坂', 'オサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県笠岡市関戸', '33', '33205', '7140004', '岡山県', 'オカヤマケン', '笠岡市', 'カサオカシ', '関戸', 'セキド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県笠岡市新賀', '33', '33205', '7140005', '岡山県', 'オカヤマケン', '笠岡市', 'カサオカシ', '新賀', 'シンガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県笠岡市みの越', '33', '33205', '7140006', '岡山県', 'オカヤマケン', '笠岡市', 'カサオカシ', 'みの越', 'ミノコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県笠岡市山口', '33', '33205', '7140007', '岡山県', 'オカヤマケン', '笠岡市', 'カサオカシ', '山口', 'ヤマグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県笠岡市吉田', '33', '33205', '7140011', '岡山県', 'オカヤマケン', '笠岡市', 'カサオカシ', '吉田', 'ヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県笠岡市小平井', '33', '33205', '7140012', '岡山県', 'オカヤマケン', '笠岡市', 'カサオカシ', '小平井', 'オビライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県笠岡市大井南', '33', '33205', '7140013', '岡山県', 'オカヤマケン', '笠岡市', 'カサオカシ', '大井南', 'オオイミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県笠岡市相生', '33', '33205', '7140014', '岡山県', 'オカヤマケン', '笠岡市', 'カサオカシ', '相生', 'アイオイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県笠岡市園井', '33', '33205', '7140021', '岡山県', 'オカヤマケン', '笠岡市', 'カサオカシ', '園井', 'ソノイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県笠岡市今立', '33', '33205', '7140022', '岡山県', 'オカヤマケン', '笠岡市', 'カサオカシ', '今立', 'イマダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県笠岡市広浜', '33', '33205', '7140023', '岡山県', 'オカヤマケン', '笠岡市', 'カサオカシ', '広浜', 'ヒロハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県笠岡市馬飼', '33', '33205', '7140024', '岡山県', 'オカヤマケン', '笠岡市', 'カサオカシ', '馬飼', 'マカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県笠岡市春日台', '33', '33205', '7140025', '岡山県', 'オカヤマケン', '笠岡市', 'カサオカシ', '春日台', 'カスガダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県笠岡市西大島新田', '33', '33205', '7140031', '岡山県', 'オカヤマケン', '笠岡市', 'カサオカシ', '西大島新田', 'ニシオオシマシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県笠岡市西大島', '33', '33205', '7140032', '岡山県', 'オカヤマケン', '笠岡市', 'カサオカシ', '西大島', 'ニシオオシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県笠岡市大島中', '33', '33205', '7140033', '岡山県', 'オカヤマケン', '笠岡市', 'カサオカシ', '大島中', 'オオシマナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県笠岡市神島外浦', '33', '33205', '7140034', '岡山県', 'オカヤマケン', '笠岡市', 'カサオカシ', '神島外浦', 'コウノシマソトウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県笠岡市高島', '33', '33205', '7140035', '岡山県', 'オカヤマケン', '笠岡市', 'カサオカシ', '高島', 'タカシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県笠岡市白石島', '33', '33205', '7140036', '岡山県', 'オカヤマケン', '笠岡市', 'カサオカシ', '白石島', 'シライシジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県笠岡市真鍋島', '33', '33205', '7140037', '岡山県', 'オカヤマケン', '笠岡市', 'カサオカシ', '真鍋島', 'マナベシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県笠岡市六島', '33', '33205', '7140038', '岡山県', 'オカヤマケン', '笠岡市', 'カサオカシ', '六島', 'ムシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県笠岡市入江', '33', '33205', '7140041', '岡山県', 'オカヤマケン', '笠岡市', 'カサオカシ', '入江', 'イリエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県笠岡市美の浜', '33', '33205', '7140042', '岡山県', 'オカヤマケン', '笠岡市', 'カサオカシ', '美の浜', 'ミノハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県笠岡市横島', '33', '33205', '7140043', '岡山県', 'オカヤマケン', '笠岡市', 'カサオカシ', '横島', 'ヨコシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県笠岡市神島', '33', '33205', '7140044', '岡山県', 'オカヤマケン', '笠岡市', 'カサオカシ', '神島', 'コウノシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県笠岡市港町', '33', '33205', '7140045', '岡山県', 'オカヤマケン', '笠岡市', 'カサオカシ', '港町', 'ミナトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県笠岡市カブト南町', '33', '33205', '7140046', '岡山県', 'オカヤマケン', '笠岡市', 'カサオカシ', 'カブト南町', 'カブトミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県笠岡市拓海町', '33', '33205', '7140047', '岡山県', 'オカヤマケン', '笠岡市', 'カサオカシ', '拓海町', 'タクミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県笠岡市緑町', '33', '33205', '7140048', '岡山県', 'オカヤマケン', '笠岡市', 'カサオカシ', '緑町', 'ミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県笠岡市カブト東町', '33', '33205', '7140051', '岡山県', 'オカヤマケン', '笠岡市', 'カサオカシ', 'カブト東町', 'カブトヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県笠岡市カブト中央町', '33', '33205', '7140052', '岡山県', 'オカヤマケン', '笠岡市', 'カサオカシ', 'カブト中央町', 'カブトチュウオウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県笠岡市カブト西町', '33', '33205', '7140053', '岡山県', 'オカヤマケン', '笠岡市', 'カサオカシ', 'カブト西町', 'カブトニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県笠岡市平成町', '33', '33205', '7140054', '岡山県', 'オカヤマケン', '笠岡市', 'カサオカシ', '平成町', 'ヘイセイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県笠岡市生江浜', '33', '33205', '7140055', '岡山県', 'オカヤマケン', '笠岡市', 'カサオカシ', '生江浜', 'オエハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県笠岡市旭が丘', '33', '33205', '7140056', '岡山県', 'オカヤマケン', '笠岡市', 'カサオカシ', '旭が丘', 'アサヒガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県笠岡市金浦', '33', '33205', '7140057', '岡山県', 'オカヤマケン', '笠岡市', 'カサオカシ', '金浦', 'カナウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県笠岡市大げ', '33', '33205', '7140061', '岡山県', 'オカヤマケン', '笠岡市', 'カサオカシ', '大げ', 'オオゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県笠岡市茂平', '33', '33205', '7140062', '岡山県', 'オカヤマケン', '笠岡市', 'カサオカシ', '茂平', 'モビラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県笠岡市鋼管町', '33', '33205', '7140063', '岡山県', 'オカヤマケン', '笠岡市', 'カサオカシ', '鋼管町', 'コウカンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県笠岡市西茂平', '33', '33205', '7140064', '岡山県', 'オカヤマケン', '笠岡市', 'カサオカシ', '西茂平', 'ニシモビラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県笠岡市城見台', '33', '33205', '7140065', '岡山県', 'オカヤマケン', '笠岡市', 'カサオカシ', '城見台', 'シロミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県笠岡市用之江', '33', '33205', '7140066', '岡山県', 'オカヤマケン', '笠岡市', 'カサオカシ', '用之江', 'モチノエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県笠岡市東大戸', '33', '33205', '7140071', '岡山県', 'オカヤマケン', '笠岡市', 'カサオカシ', '東大戸', 'ヒガシオオド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県笠岡市西大戸', '33', '33205', '7140072', '岡山県', 'オカヤマケン', '笠岡市', 'カサオカシ', '西大戸', 'ニシオオド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県笠岡市大河', '33', '33205', '7140073', '岡山県', 'オカヤマケン', '笠岡市', 'カサオカシ', '大河', 'オオコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県笠岡市吉浜', '33', '33205', '7140074', '岡山県', 'オカヤマケン', '笠岡市', 'カサオカシ', '吉浜', 'ヨシハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県笠岡市有田', '33', '33205', '7140075', '岡山県', 'オカヤマケン', '笠岡市', 'カサオカシ', '有田', 'アリダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県笠岡市押撫', '33', '33205', '7140076', '岡山県', 'オカヤマケン', '笠岡市', 'カサオカシ', '押撫', 'オシナデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県笠岡市篠坂', '33', '33205', '7140077', '岡山県', 'オカヤマケン', '笠岡市', 'カサオカシ', '篠坂', 'シノサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県笠岡市入田', '33', '33205', '7140078', '岡山県', 'オカヤマケン', '笠岡市', 'カサオカシ', '入田', 'ニュウタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県笠岡市笠岡', '33', '33205', '7140081', '岡山県', 'オカヤマケン', '笠岡市', 'カサオカシ', '笠岡', 'カサオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県笠岡市一番町', '33', '33205', '7140082', '岡山県', 'オカヤマケン', '笠岡市', 'カサオカシ', '一番町', 'イチバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県笠岡市二番町', '33', '33205', '7140083', '岡山県', 'オカヤマケン', '笠岡市', 'カサオカシ', '二番町', 'ニバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県笠岡市三番町', '33', '33205', '7140084', '岡山県', 'オカヤマケン', '笠岡市', 'カサオカシ', '三番町', 'サンバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県笠岡市四番町', '33', '33205', '7140085', '岡山県', 'オカヤマケン', '笠岡市', 'カサオカシ', '四番町', 'ヨンバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県笠岡市五番町', '33', '33205', '7140086', '岡山県', 'オカヤマケン', '笠岡市', 'カサオカシ', '五番町', 'ゴバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県笠岡市六番町', '33', '33205', '7140087', '岡山県', 'オカヤマケン', '笠岡市', 'カサオカシ', '六番町', 'ロクバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県笠岡市中央町', '33', '33205', '7140088', '岡山県', 'オカヤマケン', '笠岡市', 'カサオカシ', '中央町', 'チュウオウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県笠岡市絵師', '33', '33205', '7140091', '岡山県', 'オカヤマケン', '笠岡市', 'カサオカシ', '絵師', 'エシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県笠岡市富岡', '33', '33205', '7140092', '岡山県', 'オカヤマケン', '笠岡市', 'カサオカシ', '富岡', 'トミオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県笠岡市新横島', '33', '33205', '7140093', '岡山県', 'オカヤマケン', '笠岡市', 'カサオカシ', '新横島', 'シンヨコシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県笠岡市七番町', '33', '33205', '7140094', '岡山県', 'オカヤマケン', '笠岡市', 'カサオカシ', '七番町', 'ナナバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県笠岡市八番町', '33', '33205', '7140095', '岡山県', 'オカヤマケン', '笠岡市', 'カサオカシ', '八番町', 'ハチバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県笠岡市九番町', '33', '33205', '7140096', '岡山県', 'オカヤマケン', '笠岡市', 'カサオカシ', '九番町', 'キュウバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県笠岡市十番町', '33', '33205', '7140097', '岡山県', 'オカヤマケン', '笠岡市', 'カサオカシ', '十番町', 'ジュウバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県笠岡市十一番町', '33', '33205', '7140098', '岡山県', 'オカヤマケン', '笠岡市', 'カサオカシ', '十一番町', 'ジュウイチバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県浅口市寄島町', '33', '33216', '7140101', '岡山県', 'オカヤマケン', '浅口市', 'アサクチシ', '寄島町', 'ヨリシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県笠岡市北木島町', '33', '33205', '7140301', '岡山県', 'オカヤマケン', '笠岡市', 'カサオカシ', '北木島町', 'キタギシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県笠岡市飛島', '33', '33205', '7140302', '岡山県', 'オカヤマケン', '笠岡市', 'カサオカシ', '飛島', 'ヒシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県小田郡矢掛町', '33', '33461', '7141200', '岡山県', 'オカヤマケン', '小田郡矢掛町', 'オダグンヤカゲチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('89272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県小田郡矢掛町矢掛', '33', '33461', '7141201', '岡山県', 'オカヤマケン', '小田郡矢掛町', 'オダグンヤカゲチョウ', '矢掛', 'ヤカゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県小田郡矢掛町小林', '33', '33461', '7141202', '岡山県', 'オカヤマケン', '小田郡矢掛町', 'オダグンヤカゲチョウ', '小林', 'オバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県小田郡矢掛町上高末', '33', '33461', '7141203', '岡山県', 'オカヤマケン', '小田郡矢掛町', 'オダグンヤカゲチョウ', '上高末', 'カミコウズエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県小田郡矢掛町下高末', '33', '33461', '7141204', '岡山県', 'オカヤマケン', '小田郡矢掛町', 'オダグンヤカゲチョウ', '下高末', 'シモコウズエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県小田郡矢掛町宇角', '33', '33461', '7141205', '岡山県', 'オカヤマケン', '小田郡矢掛町', 'オダグンヤカゲチョウ', '宇角', 'ウズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県小田郡矢掛町内田', '33', '33461', '7141206', '岡山県', 'オカヤマケン', '小田郡矢掛町', 'オダグンヤカゲチョウ', '内田', 'ウチダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県小田郡矢掛町東三成', '33', '33461', '7141211', '岡山県', 'オカヤマケン', '小田郡矢掛町', 'オダグンヤカゲチョウ', '東三成', 'ヒガシミナリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県小田郡矢掛町横谷', '33', '33461', '7141212', '岡山県', 'オカヤマケン', '小田郡矢掛町', 'オダグンヤカゲチョウ', '横谷', 'ヨコダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県小田郡矢掛町里山田', '33', '33461', '7141213', '岡山県', 'オカヤマケン', '小田郡矢掛町', 'オダグンヤカゲチョウ', '里山田', 'サトヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県小田郡矢掛町南山田', '33', '33461', '7141214', '岡山県', 'オカヤマケン', '小田郡矢掛町', 'オダグンヤカゲチョウ', '南山田', 'ミナミヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県小田郡矢掛町中', '33', '33461', '7141215', '岡山県', 'オカヤマケン', '小田郡矢掛町', 'オダグンヤカゲチョウ', '中', 'ナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県小田郡矢掛町宇内', '33', '33461', '7141221', '岡山県', 'オカヤマケン', '小田郡矢掛町', 'オダグンヤカゲチョウ', '宇内', 'ウナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県小田郡矢掛町西川面', '33', '33461', '7141222', '岡山県', 'オカヤマケン', '小田郡矢掛町', 'オダグンヤカゲチョウ', '西川面', 'ニシカワモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県小田郡矢掛町東川面', '33', '33461', '7141223', '岡山県', 'オカヤマケン', '小田郡矢掛町', 'オダグンヤカゲチョウ', '東川面', 'ヒガシカワモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県小田郡矢掛町本堀', '33', '33461', '7141224', '岡山県', 'オカヤマケン', '小田郡矢掛町', 'オダグンヤカゲチョウ', '本堀', 'モトホリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県小田郡矢掛町浅海', '33', '33461', '7141225', '岡山県', 'オカヤマケン', '小田郡矢掛町', 'オダグンヤカゲチョウ', '浅海', 'アスミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県小田郡矢掛町江良', '33', '33461', '7141226', '岡山県', 'オカヤマケン', '小田郡矢掛町', 'オダグンヤカゲチョウ', '江良', 'エラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県小田郡矢掛町小田', '33', '33461', '7141227', '岡山県', 'オカヤマケン', '小田郡矢掛町', 'オダグンヤカゲチョウ', '小田', 'オダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県井原市美星町明治', '33', '33207', '7141401', '岡山県', 'オカヤマケン', '井原市', 'イバラシ', '美星町明治', 'ビセイチョウメイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県井原市美星町宇戸谷', '33', '33207', '7141402', '岡山県', 'オカヤマケン', '井原市', 'イバラシ', '美星町宇戸谷', 'ビセイチョウウトダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県井原市美星町上高末', '33', '33207', '7141403', '岡山県', 'オカヤマケン', '井原市', 'イバラシ', '美星町上高末', 'ビセイチョウカミコウズエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県井原市美星町烏頭', '33', '33207', '7141404', '岡山県', 'オカヤマケン', '井原市', 'イバラシ', '美星町烏頭', 'ビセイチョウウトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県井原市美星町宇戸', '33', '33207', '7141405', '岡山県', 'オカヤマケン', '井原市', 'イバラシ', '美星町宇戸', 'ビセイチョウウト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県井原市美星町三山', '33', '33207', '7141406', '岡山県', 'オカヤマケン', '井原市', 'イバラシ', '美星町三山', 'ビセイチョウミヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県井原市美星町黒忠', '33', '33207', '7141407', '岡山県', 'オカヤマケン', '井原市', 'イバラシ', '美星町黒忠', 'ビセイチョウクロタダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県井原市美星町大倉', '33', '33207', '7141411', '岡山県', 'オカヤマケン', '井原市', 'イバラシ', '美星町大倉', 'ビセイチョウオオクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県井原市美星町東水砂', '33', '33207', '7141412', '岡山県', 'オカヤマケン', '井原市', 'イバラシ', '美星町東水砂', 'ビセイチョウヒガシミズスナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県井原市美星町西水砂', '33', '33207', '7141413', '岡山県', 'オカヤマケン', '井原市', 'イバラシ', '美星町西水砂', 'ビセイチョウニシミズスナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県井原市美星町黒木', '33', '33207', '7141414', '岡山県', 'オカヤマケン', '井原市', 'イバラシ', '美星町黒木', 'ビセイチョウクロギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県井原市美星町星田', '33', '33207', '7141415', '岡山県', 'オカヤマケン', '井原市', 'イバラシ', '美星町星田', 'ビセイチョウホシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県井原市芳井町梶江', '33', '33207', '7142101', '岡山県', 'オカヤマケン', '井原市', 'イバラシ', '芳井町梶江', 'ヨシイチョウカジエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県井原市芳井町与井', '33', '33207', '7142102', '岡山県', 'オカヤマケン', '井原市', 'イバラシ', '芳井町与井', 'ヨシイチョウヨイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県井原市芳井町宇戸川', '33', '33207', '7142103', '岡山県', 'オカヤマケン', '井原市', 'イバラシ', '芳井町宇戸川', 'ヨシイチョウウトガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県井原市芳井町花滝', '33', '33207', '7142104', '岡山県', 'オカヤマケン', '井原市', 'イバラシ', '芳井町花滝', 'ヨシイチョウハナダキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県井原市芳井町吉井', '33', '33207', '7142111', '岡山県', 'オカヤマケン', '井原市', 'イバラシ', '芳井町吉井', 'ヨシイチョウヨシイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県井原市芳井町簗瀬', '33', '33207', '7142112', '岡山県', 'オカヤマケン', '井原市', 'イバラシ', '芳井町簗瀬', 'ヨシイチョウヤナセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県井原市芳井町天神山', '33', '33207', '7142113', '岡山県', 'オカヤマケン', '井原市', 'イバラシ', '芳井町天神山', 'ヨシイチョウテンジンヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県井原市芳井町川相', '33', '33207', '7142114', '岡山県', 'オカヤマケン', '井原市', 'イバラシ', '芳井町川相', 'ヨシイチョウカワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県井原市芳井町佐屋', '33', '33207', '7142121', '岡山県', 'オカヤマケン', '井原市', 'イバラシ', '芳井町佐屋', 'ヨシイチョウサヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県井原市芳井町種', '33', '33207', '7142122', '岡山県', 'オカヤマケン', '井原市', 'イバラシ', '芳井町種', 'ヨシイチョウタネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県井原市芳井町片塚', '33', '33207', '7142123', '岡山県', 'オカヤマケン', '井原市', 'イバラシ', '芳井町片塚', 'ヨシイチョウカタヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県井原市芳井町井山', '33', '33207', '7142124', '岡山県', 'オカヤマケン', '井原市', 'イバラシ', '芳井町井山', 'ヨシイチョウイヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県井原市芳井町池谷', '33', '33207', '7142125', '岡山県', 'オカヤマケン', '井原市', 'イバラシ', '芳井町池谷', 'ヨシイチョウイケダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県井原市芳井町下鴫', '33', '33207', '7142231', '岡山県', 'オカヤマケン', '井原市', 'イバラシ', '芳井町下鴫', 'ヨシイチョウシモシギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県井原市芳井町上鴫', '33', '33207', '7142232', '岡山県', 'オカヤマケン', '井原市', 'イバラシ', '芳井町上鴫', 'ヨシイチョウカミシギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県井原市芳井町山村', '33', '33207', '7142233', '岡山県', 'オカヤマケン', '井原市', 'イバラシ', '芳井町山村', 'ヨシイチョウヤマムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県井原市芳井町西三原', '33', '33207', '7142234', '岡山県', 'オカヤマケン', '井原市', 'イバラシ', '芳井町西三原', 'ヨシイチョウニシミハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県井原市芳井町東三原', '33', '33207', '7142341', '岡山県', 'オカヤマケン', '井原市', 'イバラシ', '芳井町東三原', 'ヨシイチョウヒガシミハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県井原市', '33', '33207', '7150000', '岡山県', 'オカヤマケン', '井原市', 'イバラシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('89325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県井原市野上町', '33', '33207', '7150001', '岡山県', 'オカヤマケン', '井原市', 'イバラシ', '野上町', 'ノガミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県井原市神代町', '33', '33207', '7150002', '岡山県', 'オカヤマケン', '井原市', 'イバラシ', '神代町', 'コウジロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県井原市東江原町', '33', '33207', '7150003', '岡山県', 'オカヤマケン', '井原市', 'イバラシ', '東江原町', 'ヒガシエバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県井原市木之子町', '33', '33207', '7150004', '岡山県', 'オカヤマケン', '井原市', 'イバラシ', '木之子町', 'キノコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県井原市門田町', '33', '33207', '7150005', '岡山県', 'オカヤマケン', '井原市', 'イバラシ', '門田町', 'モンデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県井原市西江原町', '33', '33207', '7150006', '岡山県', 'オカヤマケン', '井原市', 'イバラシ', '西江原町', 'ニシエバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県井原市稗原町', '33', '33207', '7150011', '岡山県', 'オカヤマケン', '井原市', 'イバラシ', '稗原町', 'ヒエハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県井原市青野町', '33', '33207', '7150012', '岡山県', 'オカヤマケン', '井原市', 'イバラシ', '青野町', 'アオノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県井原市北山町', '33', '33207', '7150013', '岡山県', 'オカヤマケン', '井原市', 'イバラシ', '北山町', 'キタヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県井原市七日市町', '33', '33207', '7150014', '岡山県', 'オカヤマケン', '井原市', 'イバラシ', '七日市町', 'ナヌカイチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県井原市西方町', '33', '33207', '7150015', '岡山県', 'オカヤマケン', '井原市', 'イバラシ', '西方町', 'ニシガタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県井原市岩倉町', '33', '33207', '7150016', '岡山県', 'オカヤマケン', '井原市', 'イバラシ', '岩倉町', 'イワクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県井原市下稲木町', '33', '33207', '7150017', '岡山県', 'オカヤマケン', '井原市', 'イバラシ', '下稲木町', 'シモイナギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県井原市上稲木町', '33', '33207', '7150018', '岡山県', 'オカヤマケン', '井原市', 'イバラシ', '上稲木町', 'カミイナギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県井原市井原町', '33', '33207', '7150019', '岡山県', 'オカヤマケン', '井原市', 'イバラシ', '井原町', 'イバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県井原市上出部町', '33', '33207', '7150021', '岡山県', 'オカヤマケン', '井原市', 'イバラシ', '上出部町', 'カミイズエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県井原市下出部町', '33', '33207', '7150022', '岡山県', 'オカヤマケン', '井原市', 'イバラシ', '下出部町', 'シモイズエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県井原市大江町', '33', '33207', '7150023', '岡山県', 'オカヤマケン', '井原市', 'イバラシ', '大江町', 'オオエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県井原市高屋町', '33', '33207', '7150024', '岡山県', 'オカヤマケン', '井原市', 'イバラシ', '高屋町', 'タカヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県井原市笹賀町', '33', '33207', '7150025', '岡山県', 'オカヤマケン', '井原市', 'イバラシ', '笹賀町', 'ササカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県井原市上出部町四季が丘', '33', '33207', '7150026', '岡山県', 'オカヤマケン', '井原市', 'イバラシ', '上出部町四季が丘', 'カミイズエチョウシキガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県高梁市', '33', '33209', '7160000', '岡山県', 'オカヤマケン', '高梁市', 'タカハシシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('89353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県高梁市津川町八川', '33', '33209', '7160001', '岡山県', 'オカヤマケン', '高梁市', 'タカハシシ', '津川町八川', 'ツガワチョウヤガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県高梁市津川町今津', '33', '33209', '7160002', '岡山県', 'オカヤマケン', '高梁市', 'タカハシシ', '津川町今津', 'ツガワチョウイマヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県高梁市高倉町大瀬八長', '33', '33209', '7160003', '岡山県', 'オカヤマケン', '高梁市', 'タカハシシ', '高倉町大瀬八長', 'タカクラチョウオオセオナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県高梁市内山下', '33', '33209', '7160004', '岡山県', 'オカヤマケン', '高梁市', 'タカハシシ', '内山下', 'ウチサンゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県高梁市川端町', '33', '33209', '7160005', '岡山県', 'オカヤマケン', '高梁市', 'タカハシシ', '川端町', 'カワバタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県高梁市小高下町', '33', '33209', '7160006', '岡山県', 'オカヤマケン', '高梁市', 'タカハシシ', '小高下町', 'ココウゲチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県高梁市奥万田町', '33', '33209', '7160007', '岡山県', 'オカヤマケン', '高梁市', 'タカハシシ', '奥万田町', 'オクマンダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県高梁市和田町', '33', '33209', '7160008', '岡山県', 'オカヤマケン', '高梁市', 'タカハシシ', '和田町', 'ワダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県高梁市間之町', '33', '33209', '7160009', '岡山県', 'オカヤマケン', '高梁市', 'タカハシシ', '間之町', 'アイノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県高梁市本町', '33', '33209', '7160011', '岡山県', 'オカヤマケン', '高梁市', 'タカハシシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県高梁市新町', '33', '33209', '7160012', '岡山県', 'オカヤマケン', '高梁市', 'タカハシシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県高梁市片原町', '33', '33209', '7160013', '岡山県', 'オカヤマケン', '高梁市', 'タカハシシ', '片原町', 'カタハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県高梁市中之町', '33', '33209', '7160014', '岡山県', 'オカヤマケン', '高梁市', 'タカハシシ', '中之町', 'ナカノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県高梁市石火矢町', '33', '33209', '7160015', '岡山県', 'オカヤマケン', '高梁市', 'タカハシシ', '石火矢町', 'イシビヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県高梁市頼久寺町', '33', '33209', '7160016', '岡山県', 'オカヤマケン', '高梁市', 'タカハシシ', '頼久寺町', 'ライキュウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県高梁市御前町', '33', '33209', '7160017', '岡山県', 'オカヤマケン', '高梁市', 'タカハシシ', '御前町', 'オンザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県高梁市伊賀町', '33', '33209', '7160018', '岡山県', 'オカヤマケン', '高梁市', 'タカハシシ', '伊賀町', 'イガマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県高梁市寺町', '33', '33209', '7160019', '岡山県', 'オカヤマケン', '高梁市', 'タカハシシ', '寺町', 'テラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県高梁市中間町', '33', '33209', '7160021', '岡山県', 'オカヤマケン', '高梁市', 'タカハシシ', '中間町', 'チュウゲンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県高梁市下町', '33', '33209', '7160022', '岡山県', 'オカヤマケン', '高梁市', 'タカハシシ', '下町', 'シモマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県高梁市鍜冶町', '33', '33209', '7160023', '岡山県', 'オカヤマケン', '高梁市', 'タカハシシ', '鍜冶町', 'カジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県高梁市大工町', '33', '33209', '7160024', '岡山県', 'オカヤマケン', '高梁市', 'タカハシシ', '大工町', 'ダイクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県高梁市荒神町', '33', '33209', '7160025', '岡山県', 'オカヤマケン', '高梁市', 'タカハシシ', '荒神町', 'コウジンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県高梁市甲賀町', '33', '33209', '7160026', '岡山県', 'オカヤマケン', '高梁市', 'タカハシシ', '甲賀町', 'コウガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県高梁市八幡町', '33', '33209', '7160027', '岡山県', 'オカヤマケン', '高梁市', 'タカハシシ', '八幡町', 'ヤハタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県高梁市柿木町', '33', '33209', '7160028', '岡山県', 'オカヤマケン', '高梁市', 'タカハシシ', '柿木町', 'カキノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県高梁市向町', '33', '33209', '7160029', '岡山県', 'オカヤマケン', '高梁市', 'タカハシシ', '向町', 'ムコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県高梁市鉄砲町', '33', '33209', '7160031', '岡山県', 'オカヤマケン', '高梁市', 'タカハシシ', '鉄砲町', 'テッポウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県高梁市弓之町', '33', '33209', '7160032', '岡山県', 'オカヤマケン', '高梁市', 'タカハシシ', '弓之町', 'ユミノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県高梁市南町', '33', '33209', '7160033', '岡山県', 'オカヤマケン', '高梁市', 'タカハシシ', '南町', 'ミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県高梁市東町', '33', '33209', '7160034', '岡山県', 'オカヤマケン', '高梁市', 'タカハシシ', '東町', 'ヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県高梁市栄町', '33', '33209', '7160035', '岡山県', 'オカヤマケン', '高梁市', 'タカハシシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県高梁市松原通', '33', '33209', '7160036', '岡山県', 'オカヤマケン', '高梁市', 'タカハシシ', '松原通', 'マツバラドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県高梁市正宗町', '33', '33209', '7160037', '岡山県', 'オカヤマケン', '高梁市', 'タカハシシ', '正宗町', 'マサムネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県高梁市浜町', '33', '33209', '7160038', '岡山県', 'オカヤマケン', '高梁市', 'タカハシシ', '浜町', 'ハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県高梁市旭町', '33', '33209', '7160039', '岡山県', 'オカヤマケン', '高梁市', 'タカハシシ', '旭町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県高梁市上谷町', '33', '33209', '7160041', '岡山県', 'オカヤマケン', '高梁市', 'タカハシシ', '上谷町', 'カミダニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県高梁市下谷町', '33', '33209', '7160042', '岡山県', 'オカヤマケン', '高梁市', 'タカハシシ', '下谷町', 'シモダニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県高梁市原田北町', '33', '33209', '7160043', '岡山県', 'オカヤマケン', '高梁市', 'タカハシシ', '原田北町', 'ハラダキタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県高梁市原田南町', '33', '33209', '7160044', '岡山県', 'オカヤマケン', '高梁市', 'タカハシシ', '原田南町', 'ハラダミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県高梁市中原町', '33', '33209', '7160045', '岡山県', 'オカヤマケン', '高梁市', 'タカハシシ', '中原町', 'ナカバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県高梁市横町', '33', '33209', '7160046', '岡山県', 'オカヤマケン', '高梁市', 'タカハシシ', '横町', 'ヨコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県高梁市段町', '33', '33209', '7160047', '岡山県', 'オカヤマケン', '高梁市', 'タカハシシ', '段町', 'ダンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県高梁市松山', '33', '33209', '7160051', '岡山県', 'オカヤマケン', '高梁市', 'タカハシシ', '松山', 'マツヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県高梁市玉川町玉', '33', '33209', '7160052', '岡山県', 'オカヤマケン', '高梁市', 'タカハシシ', '玉川町玉', 'タマガワチョウタマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県高梁市玉川町下切', '33', '33209', '7160053', '岡山県', 'オカヤマケン', '高梁市', 'タカハシシ', '玉川町下切', 'タマガワチョウシタギリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県高梁市玉川町増原', '33', '33209', '7160054', '岡山県', 'オカヤマケン', '高梁市', 'タカハシシ', '玉川町増原', 'タマガワチョウマシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県高梁市落合町阿部', '33', '33209', '7160061', '岡山県', 'オカヤマケン', '高梁市', 'タカハシシ', '落合町阿部', 'オチアイチョウアベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県高梁市落合町近似', '33', '33209', '7160062', '岡山県', 'オカヤマケン', '高梁市', 'タカハシシ', '落合町近似', 'オチアイチョウチカノリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県高梁市落合町原田', '33', '33209', '7160063', '岡山県', 'オカヤマケン', '高梁市', 'タカハシシ', '落合町原田', 'オチアイチョウハラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県高梁市落合町福地', '33', '33209', '7160064', '岡山県', 'オカヤマケン', '高梁市', 'タカハシシ', '落合町福地', 'オチアイチョウシロチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県高梁市松原町大津寄', '33', '33209', '7160065', '岡山県', 'オカヤマケン', '高梁市', 'タカハシシ', '松原町大津寄', 'マツバラチョウオオヅヨリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県高梁市松原町松岡', '33', '33209', '7160066', '岡山県', 'オカヤマケン', '高梁市', 'タカハシシ', '松原町松岡', 'マツバラチョウマツオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県高梁市松原町春木', '33', '33209', '7160067', '岡山県', 'オカヤマケン', '高梁市', 'タカハシシ', '松原町春木', 'マツバラチョウハルキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県高梁市松原町神原', '33', '33209', '7160068', '岡山県', 'オカヤマケン', '高梁市', 'タカハシシ', '松原町神原', 'マツバラチョウコウバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県高梁市成羽町下日名', '33', '33209', '7160101', '岡山県', 'オカヤマケン', '高梁市', 'タカハシシ', '成羽町下日名', 'ナリワチョウシモヒナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県高梁市成羽町上日名', '33', '33209', '7160102', '岡山県', 'オカヤマケン', '高梁市', 'タカハシシ', '成羽町上日名', 'ナリワチョウカミヒナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県高梁市成羽町下原', '33', '33209', '7160111', '岡山県', 'オカヤマケン', '高梁市', 'タカハシシ', '成羽町下原', 'ナリワチョウシモハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県高梁市成羽町星原', '33', '33209', '7160112', '岡山県', 'オカヤマケン', '高梁市', 'タカハシシ', '成羽町星原', 'ナリワチョウホシバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県高梁市成羽町佐々木', '33', '33209', '7160113', '岡山県', 'オカヤマケン', '高梁市', 'タカハシシ', '成羽町佐々木', 'ナリワチョウササキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県高梁市成羽町成羽', '33', '33209', '7160121', '岡山県', 'オカヤマケン', '高梁市', 'タカハシシ', '成羽町成羽', 'ナリワチョウナリワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県高梁市成羽町羽山', '33', '33209', '7160122', '岡山県', 'オカヤマケン', '高梁市', 'タカハシシ', '成羽町羽山', 'ナリワチョウハヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県高梁市川上町地頭', '33', '33209', '7160201', '岡山県', 'オカヤマケン', '高梁市', 'タカハシシ', '川上町地頭', 'カワカミチョウジトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県高梁市川上町七地', '33', '33209', '7160202', '岡山県', 'オカヤマケン', '高梁市', 'タカハシシ', '川上町七地', 'カワカミチョウナナチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県高梁市川上町三沢', '33', '33209', '7160203', '岡山県', 'オカヤマケン', '高梁市', 'タカハシシ', '川上町三沢', 'カワカミチョウミサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県高梁市川上町領家', '33', '33209', '7160204', '岡山県', 'オカヤマケン', '高梁市', 'タカハシシ', '川上町領家', 'カワカミチョウリョウケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県高梁市川上町臘数', '33', '33209', '7160205', '岡山県', 'オカヤマケン', '高梁市', 'タカハシシ', '川上町臘数', 'カワカミチョウシワス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県高梁市川上町吉木', '33', '33209', '7160206', '岡山県', 'オカヤマケン', '高梁市', 'タカハシシ', '川上町吉木', 'カワカミチョウヨシギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県高梁市川上町仁賀', '33', '33209', '7160207', '岡山県', 'オカヤマケン', '高梁市', 'タカハシシ', '川上町仁賀', 'カワカミチョウニカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県高梁市川上町上大竹', '33', '33209', '7160211', '岡山県', 'オカヤマケン', '高梁市', 'タカハシシ', '川上町上大竹', 'カワカミチョウカミオオタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県高梁市川上町下大竹', '33', '33209', '7160212', '岡山県', 'オカヤマケン', '高梁市', 'タカハシシ', '川上町下大竹', 'カワカミチョウシモオオタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県高梁市川上町高山市', '33', '33209', '7160221', '岡山県', 'オカヤマケン', '高梁市', 'タカハシシ', '川上町高山市', 'カワカミチョウコウヤマイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県高梁市川上町大原', '33', '33209', '7160222', '岡山県', 'オカヤマケン', '高梁市', 'タカハシシ', '川上町大原', 'カワカミチョウオオバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県高梁市川上町高山', '33', '33209', '7160223', '岡山県', 'オカヤマケン', '高梁市', 'タカハシシ', '川上町高山', 'カワカミチョウコウヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県高梁市備中町志藤用瀬', '33', '33209', '7160301', '岡山県', 'オカヤマケン', '高梁市', 'タカハシシ', '備中町志藤用瀬', 'ビッチュウチョウシトウヨウゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県高梁市備中町布瀬', '33', '33209', '7160302', '岡山県', 'オカヤマケン', '高梁市', 'タカハシシ', '備中町布瀬', 'ビッチュウチョウフセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県高梁市備中町長屋', '33', '33209', '7160303', '岡山県', 'オカヤマケン', '高梁市', 'タカハシシ', '備中町長屋', 'ビッチュウチョウナガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県高梁市備中町布賀', '33', '33209', '7160304', '岡山県', 'オカヤマケン', '高梁市', 'タカハシシ', '備中町布賀', 'ビッチュウチョウフカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県高梁市備中町平川', '33', '33209', '7160311', '岡山県', 'オカヤマケン', '高梁市', 'タカハシシ', '備中町平川', 'ビッチュウチョウヒラカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県高梁市備中町東油野', '33', '33209', '7160321', '岡山県', 'オカヤマケン', '高梁市', 'タカハシシ', '備中町東油野', 'ビッチュウチョウヒガシユノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県高梁市備中町西油野', '33', '33209', '7160322', '岡山県', 'オカヤマケン', '高梁市', 'タカハシシ', '備中町西油野', 'ビッチュウチョウニシユノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県高梁市備中町西山', '33', '33209', '7160323', '岡山県', 'オカヤマケン', '高梁市', 'タカハシシ', '備中町西山', 'ビッチュウチョウニシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県高梁市成羽町羽根', '33', '33209', '7160331', '岡山県', 'オカヤマケン', '高梁市', 'タカハシシ', '成羽町羽根', 'ナリワチョウハネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県高梁市成羽町小泉', '33', '33209', '7160332', '岡山県', 'オカヤマケン', '高梁市', 'タカハシシ', '成羽町小泉', 'ナリワチョウコイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県高梁市成羽町相坂', '33', '33209', '7160333', '岡山県', 'オカヤマケン', '高梁市', 'タカハシシ', '成羽町相坂', 'ナリワチョウアイサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県高梁市成羽町長地', '33', '33209', '7160334', '岡山県', 'オカヤマケン', '高梁市', 'タカハシシ', '成羽町長地', 'ナリワチョウオサジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県高梁市成羽町布寄', '33', '33209', '7160335', '岡山県', 'オカヤマケン', '高梁市', 'タカハシシ', '成羽町布寄', 'ナリワチョウフヨリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県加賀郡吉備中央町', '33', '33681', '7161100', '岡山県', 'オカヤマケン', '加賀郡吉備中央町', 'カガグンキビチュウオウチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('89444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県加賀郡吉備中央町豊野', '33', '33681', '7161101', '岡山県', 'オカヤマケン', '加賀郡吉備中央町', 'カガグンキビチュウオウチョウ', '豊野', 'トヨノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県加賀郡吉備中央町黒土', '33', '33681', '7161102', '岡山県', 'オカヤマケン', '加賀郡吉備中央町', 'カガグンキビチュウオウチョウ', '黒土', 'クロツチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県加賀郡吉備中央町田土', '33', '33681', '7161111', '岡山県', 'オカヤマケン', '加賀郡吉備中央町', 'カガグンキビチュウオウチョウ', '田土', 'タド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県加賀郡吉備中央町湯山', '33', '33681', '7161112', '岡山県', 'オカヤマケン', '加賀郡吉備中央町', 'カガグンキビチュウオウチョウ', '湯山', 'ユヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県加賀郡吉備中央町納地', '33', '33681', '7161121', '岡山県', 'オカヤマケン', '加賀郡吉備中央町', 'カガグンキビチュウオウチョウ', '納地', 'ノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県加賀郡吉備中央町竹荘', '33', '33681', '7161122', '岡山県', 'オカヤマケン', '加賀郡吉備中央町', 'カガグンキビチュウオウチョウ', '竹荘', 'タケショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県加賀郡吉備中央町上竹', '33', '33681', '7161131', '岡山県', 'オカヤマケン', '加賀郡吉備中央町', 'カガグンキビチュウオウチョウ', '上竹', 'カミタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県加賀郡吉備中央町吉川', '33', '33681', '7161241', '岡山県', 'オカヤマケン', '加賀郡吉備中央町', 'カガグンキビチュウオウチョウ', '吉川', 'ヨシカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県加賀郡吉備中央町黒山', '33', '33681', '7161242', '岡山県', 'オカヤマケン', '加賀郡吉備中央町', 'カガグンキビチュウオウチョウ', '黒山', 'クロヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県高梁市巨瀬町', '33', '33209', '7161311', '岡山県', 'オカヤマケン', '高梁市', 'タカハシシ', '巨瀬町', 'コセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県高梁市有漢町有漢', '33', '33209', '7161321', '岡山県', 'オカヤマケン', '高梁市', 'タカハシシ', '有漢町有漢', 'ウカンチョウウカン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県高梁市有漢町上有漢', '33', '33209', '7161322', '岡山県', 'オカヤマケン', '高梁市', 'タカハシシ', '有漢町上有漢', 'ウカンチョウカミウカン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市五名', '33', '33214', '7161401', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '五名', 'ゴミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市山田', '33', '33214', '7161402', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '山田', 'ヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市宮地', '33', '33214', '7161403', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '宮地', 'ミヤジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市上水田', '33', '33214', '7161411', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '上水田', 'カミミズタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市下中津井', '33', '33214', '7161421', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '下中津井', 'シモナカツイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市上中津井', '33', '33214', '7161422', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '上中津井', 'カミナカツイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市阿口', '33', '33214', '7161431', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '阿口', 'アクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市上呰部', '33', '33214', '7161432', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '上呰部', 'カミアザエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市下呰部', '33', '33214', '7161433', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '下呰部', 'シモアザエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県加賀郡吉備中央町北', '33', '33681', '7161551', '岡山県', 'オカヤマケン', '加賀郡吉備中央町', 'カガグンキビチュウオウチョウ', '北', 'キタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県加賀郡吉備中央町岨谷', '33', '33681', '7161552', '岡山県', 'オカヤマケン', '加賀郡吉備中央町', 'カガグンキビチュウオウチョウ', '岨谷', 'スワタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県加賀郡吉備中央町宮地', '33', '33681', '7161553', '岡山県', 'オカヤマケン', '加賀郡吉備中央町', 'カガグンキビチュウオウチョウ', '宮地', 'ミヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県加賀郡吉備中央町西', '33', '33681', '7161554', '岡山県', 'オカヤマケン', '加賀郡吉備中央町', 'カガグンキビチュウオウチョウ', '西', 'ニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市星山', '33', '33214', '7170001', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '星山', 'ホシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市菅谷', '33', '33214', '7170002', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '菅谷', 'スガタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市竹原', '33', '33214', '7170003', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '竹原', 'タケバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市神庭', '33', '33214', '7170004', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '神庭', 'カンバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市横部', '33', '33214', '7170005', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '横部', 'ヨコベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市組', '33', '33214', '7170006', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '組', 'クミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市本郷', '33', '33214', '7170007', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '本郷', 'ホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市見尾', '33', '33214', '7170011', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '見尾', 'ミオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市山久世', '33', '33214', '7170012', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '山久世', 'ヤマクセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市勝山', '33', '33214', '7170013', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '勝山', 'カツヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市柴原', '33', '33214', '7170014', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '柴原', 'シバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市岡', '33', '33214', '7170015', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '岡', 'オカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市正吉', '33', '33214', '7170016', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '正吉', 'マサヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市真賀', '33', '33214', '7170017', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '真賀', 'マガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市福谷', '33', '33214', '7170021', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '福谷', 'フクタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市三田', '33', '33214', '7170022', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '三田', 'サンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市江川', '33', '33214', '7170023', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '江川', 'エガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市月田', '33', '33214', '7170024', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '月田', 'ツキダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市後谷畝', '33', '33214', '7170025', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '後谷畝', 'ウシロダニウネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市荒田', '33', '33214', '7170026', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '荒田', 'アラタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市神代', '33', '33214', '7170027', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '神代', 'コウジロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市鉄山', '33', '33214', '7170101', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '鉄山', 'カネヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市黒田', '33', '33214', '7170102', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '黒田', 'クロダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市田口', '33', '33214', '7170103', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '田口', 'タグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市延風', '33', '33214', '7170104', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '延風', 'ノブカゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市美甘', '33', '33214', '7170105', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '美甘', 'ミカモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭郡新庄村', '33', '33586', '7170201', '岡山県', 'オカヤマケン', '真庭郡新庄村', 'マニワグンシンジョウソン', null, '　', '（全域）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('89504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市田羽根', '33', '33214', '7170401', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '田羽根', 'タバネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市湯原温泉', '33', '33214', '7170402', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '湯原温泉', 'ユバラオンセン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市下湯原', '33', '33214', '7170403', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '下湯原', 'シモユバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市社', '33', '33214', '7170404', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '社', 'ヤシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市久見', '33', '33214', '7170405', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '久見', 'ヒサミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市豊栄', '33', '33214', '7170406', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '豊栄', 'トヨサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市見明戸', '33', '33214', '7170411', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '見明戸', 'ミアケド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市本庄', '33', '33214', '7170412', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '本庄', 'ホンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市禾津', '33', '33214', '7170413', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '禾津', 'イナツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市釘貫小川', '33', '33214', '7170414', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '釘貫小川', 'クギヌキコガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市都喜足', '33', '33214', '7170415', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '都喜足', 'ツギタル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市仲間', '33', '33214', '7170416', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '仲間', 'ナカマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市粟谷', '33', '33214', '7170421', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '粟谷', 'アワダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市藤森', '33', '33214', '7170422', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '藤森', 'フジモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市黒杭', '33', '33214', '7170423', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '黒杭', 'クロクイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市種', '33', '33214', '7170424', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '種', 'タネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市小童谷', '33', '33214', '7170425', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '小童谷', 'ヒジヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市三世七原', '33', '33214', '7170426', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '三世七原', 'ミセシチバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市蒜山中福田', '33', '33214', '7170501', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '蒜山中福田', 'ヒルゼンナカフクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市蒜山富掛田', '33', '33214', '7170502', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '蒜山富掛田', 'ヒルゼントミカケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市蒜山富山根', '33', '33214', '7170503', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '蒜山富山根', 'ヒルゼントミヤマネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市蒜山下福田', '33', '33214', '7170504', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '蒜山下福田', 'ヒルゼンシモフクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市蒜山上長田', '33', '33214', '7170505', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '蒜山上長田', 'ヒルゼンカミナガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市蒜山下長田', '33', '33214', '7170506', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '蒜山下長田', 'ヒルゼンシモナガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市蒜山下見', '33', '33214', '7170507', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '蒜山下見', 'ヒルゼンシモミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市蒜山初和', '33', '33214', '7170511', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '蒜山初和', 'ヒルゼンハツワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市蒜山真加子', '33', '33214', '7170512', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '蒜山真加子', 'ヒルゼンマカゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市蒜山下和', '33', '33214', '7170513', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '蒜山下和', 'ヒルゼンシタオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市蒜山吉田', '33', '33214', '7170514', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '蒜山吉田', 'ヒルゼンヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市蒜山別所', '33', '33214', '7170515', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '蒜山別所', 'ヒルゼンベッショ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市蒜山湯船', '33', '33214', '7170601', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '蒜山湯船', 'ヒルゼンユブネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市蒜山上福田', '33', '33214', '7170602', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '蒜山上福田', 'ヒルゼンカミフクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市蒜山東茅部', '33', '33214', '7170603', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '蒜山東茅部', 'ヒルゼンヒガシカヤベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市蒜山西茅部', '33', '33214', '7170604', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '蒜山西茅部', 'ヒルゼンニシカヤベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市蒜山本茅部', '33', '33214', '7170611', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '蒜山本茅部', 'ヒルゼンホンカヤベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市蒜山上徳山', '33', '33214', '7170612', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '蒜山上徳山', 'ヒルゼンカミトクヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市蒜山下徳山', '33', '33214', '7170613', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '蒜山下徳山', 'ヒルゼンシモトクヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市曲り', '33', '33214', '7170731', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '曲り', 'マガリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市高田山上', '33', '33214', '7170732', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '高田山上', 'タカタヤマウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市若代畝', '33', '33214', '7170733', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '若代畝', 'ワカシロウネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市野', '33', '33214', '7170734', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '野', 'ノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市下岩', '33', '33214', '7170735', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '下岩', 'シモイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市古呂々尾中', '33', '33214', '7170736', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '古呂々尾中', 'コロロビナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市清谷', '33', '33214', '7170737', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '清谷', 'セイタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市若代', '33', '33214', '7170741', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '若代', 'ワカシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市後谷', '33', '33214', '7170742', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '後谷', 'ウシロダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市月田本', '33', '33214', '7170743', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '月田本', 'ツキダホン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市岩井谷', '33', '33214', '7170744', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '岩井谷', 'イワイダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市岩井畝', '33', '33214', '7170745', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '岩井畝', 'イワイウネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市上', '33', '33214', '7170746', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '上', 'カミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県新見市', '33', '33210', '7180000', '岡山県', 'オカヤマケン', '新見市', 'ニイミシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('89556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県新見市上熊谷', '33', '33210', '7180001', '岡山県', 'オカヤマケン', '新見市', 'ニイミシ', '上熊谷', 'カミクマタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県新見市下熊谷', '33', '33210', '7180002', '岡山県', 'オカヤマケン', '新見市', 'ニイミシ', '下熊谷', 'シモクマタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県新見市高尾', '33', '33210', '7180003', '岡山県', 'オカヤマケン', '新見市', 'ニイミシ', '高尾', 'タカオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県新見市馬塚', '33', '33210', '7180004', '岡山県', 'オカヤマケン', '新見市', 'ニイミシ', '馬塚', 'マヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県新見市上市', '33', '33210', '7180005', '岡山県', 'オカヤマケン', '新見市', 'ニイミシ', '上市', 'カミイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県新見市足立', '33', '33210', '7180006', '岡山県', 'オカヤマケン', '新見市', 'ニイミシ', '足立', 'アシダチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県新見市坂本', '33', '33210', '7180007', '岡山県', 'オカヤマケン', '新見市', 'ニイミシ', '坂本', 'サカモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県新見市新見', '33', '33210', '7180011', '岡山県', 'オカヤマケン', '新見市', 'ニイミシ', '新見', 'ニイミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県新見市唐松', '33', '33210', '7180012', '岡山県', 'オカヤマケン', '新見市', 'ニイミシ', '唐松', 'カラマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県新見市正田', '33', '33210', '7180013', '岡山県', 'オカヤマケン', '新見市', 'ニイミシ', '正田', 'ショウデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県新見市長屋', '33', '33210', '7180014', '岡山県', 'オカヤマケン', '新見市', 'ニイミシ', '長屋', 'ナガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県新見市石蟹', '33', '33210', '7180015', '岡山県', 'オカヤマケン', '新見市', 'ニイミシ', '石蟹', 'イシガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県新見市金谷', '33', '33210', '7180016', '岡山県', 'オカヤマケン', '新見市', 'ニイミシ', '金谷', 'カナヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県新見市西方', '33', '33210', '7180017', '岡山県', 'オカヤマケン', '新見市', 'ニイミシ', '西方', 'ニシガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県新見市千屋', '33', '33210', '7180101', '岡山県', 'オカヤマケン', '新見市', 'ニイミシ', '千屋', 'チヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県新見市千屋実', '33', '33210', '7180102', '岡山県', 'オカヤマケン', '新見市', 'ニイミシ', '千屋実', 'チヤサネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県新見市千屋井原', '33', '33210', '7180103', '岡山県', 'オカヤマケン', '新見市', 'ニイミシ', '千屋井原', 'チヤイハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県新見市千屋花見', '33', '33210', '7180104', '岡山県', 'オカヤマケン', '新見市', 'ニイミシ', '千屋花見', 'チヤハナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県新見市菅生', '33', '33210', '7180211', '岡山県', 'オカヤマケン', '新見市', 'ニイミシ', '菅生', 'スゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県新見市哲多町宮河内', '33', '33210', '7180301', '岡山県', 'オカヤマケン', '新見市', 'ニイミシ', '哲多町宮河内', 'テッタチョウミヤゴウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県新見市哲多町花木', '33', '33210', '7180302', '岡山県', 'オカヤマケン', '新見市', 'ニイミシ', '哲多町花木', 'テッタチョウハナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県新見市哲多町本郷', '33', '33210', '7180303', '岡山県', 'オカヤマケン', '新見市', 'ニイミシ', '哲多町本郷', 'テッタチョウホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県新見市哲多町成松', '33', '33210', '7180304', '岡山県', 'オカヤマケン', '新見市', 'ニイミシ', '哲多町成松', 'テッタチョウナリマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県新見市哲多町荻尾', '33', '33210', '7180305', '岡山県', 'オカヤマケン', '新見市', 'ニイミシ', '哲多町荻尾', 'テッタチョウオギョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県新見市哲多町矢戸', '33', '33210', '7180306', '岡山県', 'オカヤマケン', '新見市', 'ニイミシ', '哲多町矢戸', 'テッタチョウヤト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県新見市哲多町老栄', '33', '33210', '7180307', '岡山県', 'オカヤマケン', '新見市', 'ニイミシ', '哲多町老栄', 'テッタチョウオイザコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県新見市哲多町蚊家', '33', '33210', '7180311', '岡山県', 'オカヤマケン', '新見市', 'ニイミシ', '哲多町蚊家', 'テッタチョウコウノイエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県新見市哲多町田淵', '33', '33210', '7180312', '岡山県', 'オカヤマケン', '新見市', 'ニイミシ', '哲多町田淵', 'テッタチョウタブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県新見市哲多町大野', '33', '33210', '7180313', '岡山県', 'オカヤマケン', '新見市', 'ニイミシ', '哲多町大野', 'テッタチョウオオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市東鷹栖1条', '01', '01204', '0718101', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '東鷹栖1条', 'ヒガシタカス01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市東鷹栖2条', '01', '01204', '0718102', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '東鷹栖2条', 'ヒガシタカス02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市東鷹栖3条', '01', '01204', '0718103', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '東鷹栖3条', 'ヒガシタカス03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市東鷹栖4条', '01', '01204', '0718104', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '東鷹栖4条', 'ヒガシタカス04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市東鷹栖東1条', '01', '01204', '0718111', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '東鷹栖東1条', 'ヒガシタカスヒガシ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市東鷹栖東2条', '01', '01204', '0718112', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '東鷹栖東2条', 'ヒガシタカスヒガシ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市東鷹栖東3条', '01', '01204', '0718113', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '東鷹栖東3条', 'ヒガシタカスヒガシ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市東鷹栖東1線', '01', '01204', '0718114', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '東鷹栖東1線', 'ヒガシタカスヒガシ01セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市末広東1条', '01', '01204', '0718121', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '末広東1条', 'スエヒロヒガシ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市末広東2条', '01', '01204', '0718122', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '末広東2条', 'スエヒロヒガシ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市末広東3条', '01', '01204', '0718123', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '末広東3条', 'スエヒロヒガシ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市末広1条', '01', '01204', '0718131', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '末広1条', 'スエヒロ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市末広2条', '01', '01204', '0718132', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '末広2条', 'スエヒロ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市末広3条', '01', '01204', '0718133', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '末広3条', 'スエヒロ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市末広4条', '01', '01204', '0718134', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '末広4条', 'スエヒロ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市末広5条', '01', '01204', '0718135', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '末広5条', 'スエヒロ05ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市末広6条', '01', '01204', '0718136', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '末広6条', 'スエヒロ06ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市末広7条', '01', '01204', '0718137', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '末広7条', 'スエヒロ07ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市末広8条', '01', '01204', '0718138', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '末広8条', 'スエヒロ08ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市春光台1条', '01', '01204', '0718141', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '春光台1条', 'シュンコウダイ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市春光台2条', '01', '01204', '0718142', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '春光台2条', 'シュンコウダイ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市春光台3条', '01', '01204', '0718143', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '春光台3条', 'シュンコウダイ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市春光台4条', '01', '01204', '0718144', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '春光台4条', 'シュンコウダイ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市春光台5条', '01', '01204', '0718145', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '春光台5条', 'シュンコウダイ05ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市東鷹栖1線', '01', '01204', '0718151', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '東鷹栖1線', 'ヒガシタカス01セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市東鷹栖2線', '01', '01204', '0718152', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '東鷹栖2線', 'ヒガシタカス02セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市東鷹栖3線', '01', '01204', '0718153', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '東鷹栖3線', 'ヒガシタカス03セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市東鷹栖4線', '01', '01204', '0718154', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '東鷹栖4線', 'ヒガシタカス04セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市東鷹栖5線', '01', '01204', '0718155', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '東鷹栖5線', 'ヒガシタカス05セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市東鷹栖6線', '01', '01204', '0718156', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '東鷹栖6線', 'ヒガシタカス06セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市東鷹栖7線', '01', '01204', '0718157', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '東鷹栖7線', 'ヒガシタカス07セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市東鷹栖8線', '01', '01204', '0718158', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '東鷹栖8線', 'ヒガシタカス08セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市東鷹栖9線', '01', '01204', '0718159', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '東鷹栖9線', 'ヒガシタカス09セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市東鷹栖10線', '01', '01204', '0718160', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '東鷹栖10線', 'ヒガシタカス10セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市東鷹栖11線', '01', '01204', '0718161', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '東鷹栖11線', 'ヒガシタカス11セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市東鷹栖12線', '01', '01204', '0718162', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '東鷹栖12線', 'ヒガシタカス12セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市東鷹栖13線', '01', '01204', '0718163', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '東鷹栖13線', 'ヒガシタカス13セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市東鷹栖14線', '01', '01204', '0718164', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '東鷹栖14線', 'ヒガシタカス14セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市東鷹栖15線', '01', '01204', '0718165', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '東鷹栖15線', 'ヒガシタカス15セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市緑台', '01', '01204', '0718166', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '緑台', 'ミドリダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市東山', '01', '01204', '0718171', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '東山', 'ヒガシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県浅口市金光町上竹', '33', '33216', '7190101', '岡山県', 'オカヤマケン', '浅口市', 'アサクチシ', '金光町上竹', 'コンコウチョウカミダケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県浅口市金光町下竹', '33', '33216', '7190102', '岡山県', 'オカヤマケン', '浅口市', 'アサクチシ', '金光町下竹', 'コンコウチョウシモダケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県浅口市金光町八重', '33', '33216', '7190103', '岡山県', 'オカヤマケン', '浅口市', 'アサクチシ', '金光町八重', 'コンコウチョウヤエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県浅口市金光町占見新田', '33', '33216', '7190104', '岡山県', 'オカヤマケン', '浅口市', 'アサクチシ', '金光町占見新田', 'コンコウチョウウラミシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県浅口市金光町占見', '33', '33216', '7190105', '岡山県', 'オカヤマケン', '浅口市', 'アサクチシ', '金光町占見', 'コンコウチョウウラミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県浅口市金光町地頭下', '33', '33216', '7190106', '岡山県', 'オカヤマケン', '浅口市', 'アサクチシ', '金光町地頭下', 'コンコウチョウジトウシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県浅口市金光町大谷', '33', '33216', '7190111', '岡山県', 'オカヤマケン', '浅口市', 'アサクチシ', '金光町大谷', 'コンコウチョウオオタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県浅口市金光町須恵', '33', '33216', '7190112', '岡山県', 'オカヤマケン', '浅口市', 'アサクチシ', '金光町須恵', 'コンコウチョウスエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県浅口市金光町佐方', '33', '33216', '7190113', '岡山県', 'オカヤマケン', '浅口市', 'アサクチシ', '金光町佐方', 'コンコウチョウサガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県浅口市', '33', '33216', '7190200', '岡山県', 'オカヤマケン', '浅口市', 'アサクチシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('89645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県浅口市金光町上竹遙照山', '33', '33216', '7190221', '岡山県', 'オカヤマケン', '浅口市', 'アサクチシ', '金光町上竹', 'コンコウチョウカミダケ', null, null, '遙照山', 'ヨウショウザン');
INSERT INTO `ms_addresses` VALUES ('89646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県浅口市鴨方町小坂西', '33', '33216', '7190231', '岡山県', 'オカヤマケン', '浅口市', 'アサクチシ', '鴨方町小坂西', 'カモガタチョウコサカニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県浅口市鴨方町本庄', '33', '33216', '7190232', '岡山県', 'オカヤマケン', '浅口市', 'アサクチシ', '鴨方町本庄', 'カモガタチョウホンジョ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県浅口市鴨方町地頭上', '33', '33216', '7190233', '岡山県', 'オカヤマケン', '浅口市', 'アサクチシ', '鴨方町地頭上', 'カモガタチョウヂトウカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県浅口市鴨方町益坂', '33', '33216', '7190234', '岡山県', 'オカヤマケン', '浅口市', 'アサクチシ', '鴨方町益坂', 'カモガタチョウマスサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県浅口市鴨方町小坂東', '33', '33216', '7190241', '岡山県', 'オカヤマケン', '浅口市', 'アサクチシ', '鴨方町小坂東', 'カモガタチョウコサカヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県浅口市鴨方町みどりケ丘', '33', '33216', '7190242', '岡山県', 'オカヤマケン', '浅口市', 'アサクチシ', '鴨方町みどりケ丘', 'カモガタチョウミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県浅口市鴨方町鴨方', '33', '33216', '7190243', '岡山県', 'オカヤマケン', '浅口市', 'アサクチシ', '鴨方町鴨方', 'カモガタチョウカモガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県浅口市鴨方町深田', '33', '33216', '7190244', '岡山県', 'オカヤマケン', '浅口市', 'アサクチシ', '鴨方町深田', 'カモガタチョウフカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県浅口市鴨方町六条院西', '33', '33216', '7190251', '岡山県', 'オカヤマケン', '浅口市', 'アサクチシ', '鴨方町六条院西', 'カモガタチョウロクジョウインニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県浅口市鴨方町六条院中', '33', '33216', '7190252', '岡山県', 'オカヤマケン', '浅口市', 'アサクチシ', '鴨方町六条院中', 'カモガタチョウロクジョウインナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県浅口市鴨方町鳩ケ丘', '33', '33216', '7190253', '岡山県', 'オカヤマケン', '浅口市', 'アサクチシ', '鴨方町鳩ケ丘', 'カモガタチョウハトガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県浅口市鴨方町六条院東', '33', '33216', '7190254', '岡山県', 'オカヤマケン', '浅口市', 'アサクチシ', '鴨方町六条院東', 'カモガタチョウロクジョウインヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県浅口郡里庄町', '33', '33445', '7190300', '岡山県', 'オカヤマケン', '浅口郡里庄町', 'アサクチグンサトショウチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('89660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県浅口郡里庄町里見', '33', '33445', '7190301', '岡山県', 'オカヤマケン', '浅口郡里庄町', 'アサクチグンサトショウチョウ', '里見', 'サトミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県浅口郡里庄町新庄', '33', '33445', '7190302', '岡山県', 'オカヤマケン', '浅口郡里庄町', 'アサクチグンサトショウチョウ', '新庄', 'シンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県浅口郡里庄町浜中', '33', '33445', '7190303', '岡山県', 'オカヤマケン', '浅口郡里庄町', 'アサクチグンサトショウチョウ', '浜中', 'ハマナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県浅口郡里庄町新庄グリーンクレスト', '33', '33445', '7190304', '岡山県', 'オカヤマケン', '浅口郡里庄町', 'アサクチグンサトショウチョウ', '新庄グリーンクレスト', 'シンジョウグリーンクレスト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県総社市', '33', '33208', '7191100', '岡山県', 'オカヤマケン', '総社市', 'ソウジャシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('89668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県総社市奥坂', '33', '33208', '7191101', '岡山県', 'オカヤマケン', '総社市', 'ソウジャシ', '奥坂', 'オクサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県総社市東阿曽', '33', '33208', '7191102', '岡山県', 'オカヤマケン', '総社市', 'ソウジャシ', '東阿曽', 'ヒガシアゾ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県総社市西阿曽', '33', '33208', '7191103', '岡山県', 'オカヤマケン', '総社市', 'ソウジャシ', '西阿曽', 'ニシアゾ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県総社市久米', '33', '33208', '7191104', '岡山県', 'オカヤマケン', '総社市', 'ソウジャシ', '久米', 'クメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県総社市黒尾', '33', '33208', '7191105', '岡山県', 'オカヤマケン', '総社市', 'ソウジャシ', '黒尾', 'クロオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県総社市泉', '33', '33208', '7191106', '岡山県', 'オカヤマケン', '総社市', 'ソウジャシ', '泉', 'イズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県総社市長良', '33', '33208', '7191111', '岡山県', 'オカヤマケン', '総社市', 'ソウジャシ', '長良', 'ナガラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県総社市窪木', '33', '33208', '7191112', '岡山県', 'オカヤマケン', '総社市', 'ソウジャシ', '窪木', 'クボキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県総社市南溝手', '33', '33208', '7191113', '岡山県', 'オカヤマケン', '総社市', 'ソウジャシ', '南溝手', 'ミナミミゾテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県総社市金井戸', '33', '33208', '7191114', '岡山県', 'オカヤマケン', '総社市', 'ソウジャシ', '金井戸', 'カナイド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県総社市福井', '33', '33208', '7191115', '岡山県', 'オカヤマケン', '総社市', 'ソウジャシ', '福井', 'フクイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県総社市刑部', '33', '33208', '7191116', '岡山県', 'オカヤマケン', '総社市', 'ソウジャシ', '刑部', 'オシカベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県総社市北溝手', '33', '33208', '7191117', '岡山県', 'オカヤマケン', '総社市', 'ソウジャシ', '北溝手', 'キタミゾテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県総社市赤浜', '33', '33208', '7191121', '岡山県', 'オカヤマケン', '総社市', 'ソウジャシ', '赤浜', 'アカハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県総社市下林', '33', '33208', '7191122', '岡山県', 'オカヤマケン', '総社市', 'ソウジャシ', '下林', 'シモバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県総社市上林', '33', '33208', '7191123', '岡山県', 'オカヤマケン', '総社市', 'ソウジャシ', '上林', 'カンバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県総社市三須', '33', '33208', '7191124', '岡山県', 'オカヤマケン', '総社市', 'ソウジャシ', '三須', 'ミス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県総社市井手', '33', '33208', '7191125', '岡山県', 'オカヤマケン', '総社市', 'ソウジャシ', '井手', 'イデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県総社市総社', '33', '33208', '7191126', '岡山県', 'オカヤマケン', '総社市', 'ソウジャシ', '総社', 'ソウジャ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県総社市中央', '33', '33208', '7191131', '岡山県', 'オカヤマケン', '総社市', 'ソウジャシ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県総社市三輪', '33', '33208', '7191132', '岡山県', 'オカヤマケン', '総社市', 'ソウジャシ', '三輪', 'ミワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県総社市中原', '33', '33208', '7191133', '岡山県', 'オカヤマケン', '総社市', 'ソウジャシ', '中原', 'ナカバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県総社市真壁', '33', '33208', '7191134', '岡山県', 'オカヤマケン', '総社市', 'ソウジャシ', '真壁', 'マカベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県総社市溝口', '33', '33208', '7191135', '岡山県', 'オカヤマケン', '総社市', 'ソウジャシ', '溝口', 'ミゾクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県総社市駅前', '33', '33208', '7191136', '岡山県', 'オカヤマケン', '総社市', 'ソウジャシ', '駅前', 'エキマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県総社市福谷', '33', '33208', '7191141', '岡山県', 'オカヤマケン', '総社市', 'ソウジャシ', '福谷', 'フクタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県総社市秦', '33', '33208', '7191142', '岡山県', 'オカヤマケン', '総社市', 'ソウジャシ', '秦', 'ハダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県総社市上原', '33', '33208', '7191143', '岡山県', 'オカヤマケン', '総社市', 'ソウジャシ', '上原', 'カンバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県総社市富原', '33', '33208', '7191144', '岡山県', 'オカヤマケン', '総社市', 'ソウジャシ', '富原', 'トンバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県総社市下原', '33', '33208', '7191145', '岡山県', 'オカヤマケン', '総社市', 'ソウジャシ', '下原', 'シモバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県総社市八代', '33', '33208', '7191146', '岡山県', 'オカヤマケン', '総社市', 'ソウジャシ', '八代', 'ヤシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県総社市槇谷', '33', '33208', '7191151', '岡山県', 'オカヤマケン', '総社市', 'ソウジャシ', '槇谷', 'マキダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県総社市見延', '33', '33208', '7191152', '岡山県', 'オカヤマケン', '総社市', 'ソウジャシ', '見延', 'ミノベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県総社市宍粟', '33', '33208', '7191153', '岡山県', 'オカヤマケン', '総社市', 'ソウジャシ', '宍粟', 'シサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県総社市井尻野', '33', '33208', '7191154', '岡山県', 'オカヤマケン', '総社市', 'ソウジャシ', '井尻野', 'イジリノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県総社市小寺', '33', '33208', '7191155', '岡山県', 'オカヤマケン', '総社市', 'ソウジャシ', '小寺', 'コデラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県総社市門田', '33', '33208', '7191156', '岡山県', 'オカヤマケン', '総社市', 'ソウジャシ', '門田', 'モンデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県総社市宿', '33', '33208', '7191161', '岡山県', 'オカヤマケン', '総社市', 'ソウジャシ', '宿', 'シュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県総社市岡谷', '33', '33208', '7191162', '岡山県', 'オカヤマケン', '総社市', 'ソウジャシ', '岡谷', 'オカダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県総社市地頭片山', '33', '33208', '7191163', '岡山県', 'オカヤマケン', '総社市', 'ソウジャシ', '地頭片山', 'ジトウカタヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県総社市西郡', '33', '33208', '7191164', '岡山県', 'オカヤマケン', '総社市', 'ソウジャシ', '西郡', 'ニシゴオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県総社市西坂台', '33', '33208', '7191165', '岡山県', 'オカヤマケン', '総社市', 'ソウジャシ', '西坂台', 'ニシサカダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県総社市清音三因', '33', '33208', '7191171', '岡山県', 'オカヤマケン', '総社市', 'ソウジャシ', '清音三因', 'キヨネミヨリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県総社市清音軽部', '33', '33208', '7191172', '岡山県', 'オカヤマケン', '総社市', 'ソウジャシ', '清音軽部', 'キヨネカルベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県総社市清音黒田', '33', '33208', '7191173', '岡山県', 'オカヤマケン', '総社市', 'ソウジャシ', '清音黒田', 'キヨネクロタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県総社市清音古地', '33', '33208', '7191174', '岡山県', 'オカヤマケン', '総社市', 'ソウジャシ', '清音古地', 'キヨネコチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県総社市清音上中島', '33', '33208', '7191175', '岡山県', 'オカヤマケン', '総社市', 'ソウジャシ', '清音上中島', 'キヨネカミナカシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県総社市清音柿木', '33', '33208', '7191176', '岡山県', 'オカヤマケン', '総社市', 'ソウジャシ', '清音柿木', 'キヨネカキノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県総社市美袋', '33', '33208', '7191311', '岡山県', 'オカヤマケン', '総社市', 'ソウジャシ', '美袋', 'ミナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県総社市種井', '33', '33208', '7191312', '岡山県', 'オカヤマケン', '総社市', 'ソウジャシ', '種井', 'タネイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県総社市槁', '33', '33208', '7191313', '岡山県', 'オカヤマケン', '総社市', 'ソウジャシ', '槁', 'ケヤキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県総社市延原', '33', '33208', '7191314', '岡山県', 'オカヤマケン', '総社市', 'ソウジャシ', '延原', 'ノブハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県総社市宇山', '33', '33208', '7191315', '岡山県', 'オカヤマケン', '総社市', 'ソウジャシ', '宇山', 'ウヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県総社市日羽', '33', '33208', '7191316', '岡山県', 'オカヤマケン', '総社市', 'ソウジャシ', '日羽', 'ヒワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県総社市下倉', '33', '33208', '7191321', '岡山県', 'オカヤマケン', '総社市', 'ソウジャシ', '下倉', 'シタグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県総社市影', '33', '33208', '7191322', '岡山県', 'オカヤマケン', '総社市', 'ソウジャシ', '影', 'カゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県総社市中尾', '33', '33208', '7191323', '岡山県', 'オカヤマケン', '総社市', 'ソウジャシ', '中尾', 'ナカオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県総社市原', '33', '33208', '7191324', '岡山県', 'オカヤマケン', '総社市', 'ソウジャシ', '原', 'ハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県高梁市川面町', '33', '33209', '7192121', '岡山県', 'オカヤマケン', '高梁市', 'タカハシシ', '川面町', 'カワモチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県高梁市高倉町田井', '33', '33209', '7192122', '岡山県', 'オカヤマケン', '高梁市', 'タカハシシ', '高倉町田井', 'タカクラチョウタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県高梁市高倉町飯部', '33', '33209', '7192123', '岡山県', 'オカヤマケン', '高梁市', 'タカハシシ', '高倉町飯部', 'タカクラチョウイイベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県高梁市宇治町遠原', '33', '33209', '7192231', '岡山県', 'オカヤマケン', '高梁市', 'タカハシシ', '宇治町遠原', 'ウジチョウトオバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県高梁市宇治町宇治', '33', '33209', '7192232', '岡山県', 'オカヤマケン', '高梁市', 'タカハシシ', '宇治町宇治', 'ウジチョウウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県高梁市宇治町穴田', '33', '33209', '7192233', '岡山県', 'オカヤマケン', '高梁市', 'タカハシシ', '宇治町穴田', 'ウジチョウアナダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県高梁市宇治町本郷', '33', '33209', '7192234', '岡山県', 'オカヤマケン', '高梁市', 'タカハシシ', '宇治町本郷', 'ウジチョウホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県高梁市成羽町吹屋', '33', '33209', '7192341', '岡山県', 'オカヤマケン', '高梁市', 'タカハシシ', '成羽町吹屋', 'ナリワチョウフキヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県高梁市成羽町中野', '33', '33209', '7192342', '岡山県', 'オカヤマケン', '高梁市', 'タカハシシ', '成羽町中野', 'ナリワチョウナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県高梁市成羽町坂本', '33', '33209', '7192343', '岡山県', 'オカヤマケン', '高梁市', 'タカハシシ', '成羽町坂本', 'ナリワチョウサカモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県高梁市中井町津々', '33', '33209', '7192401', '岡山県', 'オカヤマケン', '高梁市', 'タカハシシ', '中井町津々', 'ナカイチョウツツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県高梁市中井町西方', '33', '33209', '7192402', '岡山県', 'オカヤマケン', '高梁市', 'タカハシシ', '中井町西方', 'ナカイチョウニシガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県新見市井倉', '33', '33210', '7192551', '岡山県', 'オカヤマケン', '新見市', 'ニイミシ', '井倉', 'イクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県新見市法曽', '33', '33210', '7192552', '岡山県', 'オカヤマケン', '新見市', 'ニイミシ', '法曽', 'ホウソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県新見市草間', '33', '33210', '7192641', '岡山県', 'オカヤマケン', '新見市', 'ニイミシ', '草間', 'クサマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県新見市足見', '33', '33210', '7192642', '岡山県', 'オカヤマケン', '新見市', 'ニイミシ', '足見', 'タルミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県新見市土橋', '33', '33210', '7192643', '岡山県', 'オカヤマケン', '新見市', 'ニイミシ', '土橋', 'ツチハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県新見市豊永赤馬', '33', '33210', '7192721', '岡山県', 'オカヤマケン', '新見市', 'ニイミシ', '豊永赤馬', 'トヨナガアコウマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県新見市豊永佐伏', '33', '33210', '7192722', '岡山県', 'オカヤマケン', '新見市', 'ニイミシ', '豊永佐伏', 'トヨナガサブシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県新見市豊永宇山', '33', '33210', '7192723', '岡山県', 'オカヤマケン', '新見市', 'ニイミシ', '豊永宇山', 'トヨナガウヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県新見市土橋落方', '33', '33210', '7192731', '岡山県', 'オカヤマケン', '新見市', 'ニイミシ', '土橋', 'ツチハシ', null, null, '落方', 'オチカタ');
INSERT INTO `ms_addresses` VALUES ('89752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県新見市土橋寺内', '33', '33210', '7192731', '岡山県', 'オカヤマケン', '新見市', 'ニイミシ', '土橋', 'ツチハシ', null, null, '寺内', 'テラウチ');
INSERT INTO `ms_addresses` VALUES ('89753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県新見市草間下湯川', '33', '33210', '7192732', '岡山県', 'オカヤマケン', '新見市', 'ニイミシ', '草間', 'クサマ', null, null, '下湯川', 'シモユカワ');
INSERT INTO `ms_addresses` VALUES ('89754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県新見市草間横畑', '33', '33210', '7192732', '岡山県', 'オカヤマケン', '新見市', 'ニイミシ', '草間', 'クサマ', null, null, '横畑', 'ヨコハタ');
INSERT INTO `ms_addresses` VALUES ('89755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県新見市神郷釜村', '33', '33210', '7192801', '岡山県', 'オカヤマケン', '新見市', 'ニイミシ', '神郷釜村', 'シンゴウカマムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県新見市神郷高瀬', '33', '33210', '7192802', '岡山県', 'オカヤマケン', '新見市', 'ニイミシ', '神郷高瀬', 'シンゴウタカセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市', '33', '33214', '7193100', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('89758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市赤野', '33', '33214', '7193101', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '赤野', 'アカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市大庭', '33', '33214', '7193102', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '大庭', 'オオバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市古見', '33', '33214', '7193103', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '古見', 'コミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市田原', '33', '33214', '7193104', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '田原', 'タハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市西原', '33', '33214', '7193105', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '西原', 'ニシバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市野川', '33', '33214', '7193106', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '野川', 'ノガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市平松', '33', '33214', '7193107', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '平松', 'ヒラマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市開田', '33', '33214', '7193111', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '開田', 'カイデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市影', '33', '33214', '7193112', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '影', 'カゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市杉山', '33', '33214', '7193113', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '杉山', 'スギヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市高屋', '33', '33214', '7193114', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '高屋', 'タカヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市中', '33', '33214', '7193115', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '中', 'ナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市日名', '33', '33214', '7193116', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '日名', 'ヒナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市福田', '33', '33214', '7193117', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '福田', 'フクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市上河内', '33', '33214', '7193121', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '上河内', 'カミゴウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市下河内', '33', '33214', '7193122', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '下河内', 'シモゴウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市下見', '33', '33214', '7193123', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '下見', 'シモミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市中河内', '33', '33214', '7193124', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '中河内', 'ナカゴウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市法界寺', '33', '33214', '7193125', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '法界寺', 'ホウカイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市向津矢', '33', '33214', '7193126', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '向津矢', 'ムカツヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市上山', '33', '33214', '7193131', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '上山', 'ウエヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市田原山上', '33', '33214', '7193132', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '田原山上', 'タハラサンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市旦土', '33', '33214', '7193133', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '旦土', 'ダンド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市野原', '33', '33214', '7193134', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '野原', 'ノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市舞高', '33', '33214', '7193135', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '舞高', 'マイタカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市吉', '33', '33214', '7193136', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '吉', 'ヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市上市瀬', '33', '33214', '7193141', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '上市瀬', 'カミイチゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市木山', '33', '33214', '7193142', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '木山', 'キヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市下市瀬', '33', '33214', '7193143', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '下市瀬', 'シモイチゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市落合垂水', '33', '33214', '7193144', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '落合垂水', 'オチアイタルミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市西河内', '33', '33214', '7193145', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '西河内', 'ニシゴウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市日野上', '33', '33214', '7193146', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '日野上', 'ヒノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市一色', '33', '33214', '7193151', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '一色', 'イシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市鹿田', '33', '33214', '7193152', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '鹿田', 'カツタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市栗原', '33', '33214', '7193153', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '栗原', 'クリハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市佐引', '33', '33214', '7193154', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '佐引', 'サビキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市下方', '33', '33214', '7193155', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '下方', 'シモガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市関', '33', '33214', '7193156', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '関', 'セキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市別所', '33', '33214', '7193157', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '別所', 'ベッシヨ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市久世', '33', '33214', '7193201', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '久世', 'クセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市中島', '33', '33214', '7193202', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '中島', 'ナカシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市富尾', '33', '33214', '7193203', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '富尾', 'トミノオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市惣', '33', '33214', '7193204', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '惣', 'ソウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市草加部', '33', '33214', '7193205', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '草加部', 'クサカベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市神', '33', '33214', '7193206', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '神', 'コウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市樫西', '33', '33214', '7193211', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '樫西', 'カシニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市三阪', '33', '33214', '7193212', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '三阪', 'ミサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市多田', '33', '33214', '7193213', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '多田', 'タダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市鍋屋', '33', '33214', '7193214', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '鍋屋', 'ナベヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市余野上', '33', '33214', '7193221', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '余野上', 'ヨノカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市余野下', '33', '33214', '7193222', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '余野下', 'ヨノシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市樫東', '33', '33214', '7193223', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '樫東', 'カシヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市目木', '33', '33214', '7193224', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '目木', 'メキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市中原', '33', '33214', '7193225', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '中原', 'ナカバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市三崎', '33', '33214', '7193226', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '三崎', 'ミサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市台金屋', '33', '33214', '7193227', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '台金屋', 'ダイカナヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県真庭市五反', '33', '33214', '7193228', '岡山県', 'オカヤマケン', '真庭市', 'マニワシ', '五反', 'ゴタン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県新見市大佐大井野', '33', '33210', '7193501', '岡山県', 'オカヤマケン', '新見市', 'ニイミシ', '大佐大井野', 'オオサオオイノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県新見市大佐上刑部', '33', '33210', '7193502', '岡山県', 'オカヤマケン', '新見市', 'ニイミシ', '大佐上刑部', 'オオサカミオサカベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県新見市大佐小阪部', '33', '33210', '7193503', '岡山県', 'オカヤマケン', '新見市', 'ニイミシ', '大佐小阪部', 'オオサオサカベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県新見市大佐永富', '33', '33210', '7193504', '岡山県', 'オカヤマケン', '新見市', 'ニイミシ', '大佐永富', 'オオサナガドミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県新見市大佐布瀬', '33', '33210', '7193505', '岡山県', 'オカヤマケン', '新見市', 'ニイミシ', '大佐布瀬', 'オオサフセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県新見市大佐田治部', '33', '33210', '7193506', '岡山県', 'オカヤマケン', '新見市', 'ニイミシ', '大佐田治部', 'オオサタジベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県新見市大佐小南', '33', '33210', '7193507', '岡山県', 'オカヤマケン', '新見市', 'ニイミシ', '大佐小南', 'オオサコミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県新見市神郷下神代', '33', '33210', '7193611', '岡山県', 'オカヤマケン', '新見市', 'ニイミシ', '神郷下神代', 'シンゴウシモコウジロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県新見市神郷油野', '33', '33210', '7193612', '岡山県', 'オカヤマケン', '新見市', 'ニイミシ', '神郷油野', 'シンゴウユノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県新見市哲西町矢田', '33', '33210', '7193701', '岡山県', 'オカヤマケン', '新見市', 'ニイミシ', '哲西町矢田', 'テッセイチョウヤダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県新見市哲西町上神代', '33', '33210', '7193702', '岡山県', 'オカヤマケン', '新見市', 'ニイミシ', '哲西町上神代', 'テッセイチョウカミコウジロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県新見市哲西町大竹', '33', '33210', '7193811', '岡山県', 'オカヤマケン', '新見市', 'ニイミシ', '哲西町大竹', 'テッセイチョウオオタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県新見市哲西町畑木', '33', '33210', '7193812', '岡山県', 'オカヤマケン', '新見市', 'ニイミシ', '哲西町畑木', 'テッセイチョウハタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県新見市哲西町八鳥', '33', '33210', '7193813', '岡山県', 'オカヤマケン', '新見市', 'ニイミシ', '哲西町八鳥', 'テッセイチョウハットリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '岡山県新見市哲西町大野部', '33', '33210', '7193814', '岡山県', 'オカヤマケン', '新見市', 'ニイミシ', '哲西町大野部', 'テッセイチョウオオノベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市', '01', '01215', '0720000', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('89837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市御幸町上岩成', '34', '34207', '7200001', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '御幸町上岩成', 'ミユキチョウカミイワナリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市御幸町下岩成', '34', '34207', '7200002', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '御幸町下岩成', 'ミユキチョウシモイワナリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市御幸町森脇', '34', '34207', '7200003', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '御幸町森脇', 'ミユキチョウモリワケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市御幸町中津原', '34', '34207', '7200004', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '御幸町中津原', 'ミユキチョウナカツハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市大通東1条北', '01', '01215', '0720001', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '大通東1条北', 'オオドオリヒガシ01ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市横尾町', '34', '34207', '7200011', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '横尾町', 'ヨコオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市千田町千田', '34', '34207', '7200013', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '千田町千田', 'センダチョウセンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市千田町薮路', '34', '34207', '7200014', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '千田町薮路', 'センダチョウヤブロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市千田町坂田', '34', '34207', '7200015', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '千田町坂田', 'センダチョウサカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市千田町坂田北', '34', '34207', '7200016', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '千田町坂田北', 'センダチョウサカタキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市千田町', '34', '34207', '7200017', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '千田町', 'センダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市東1条北', '01', '01215', '0720002', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '東1条北', 'ヒガシ01ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市緑陽町', '34', '34207', '7200021', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '緑陽町', 'リョクヨウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市奈良津町', '34', '34207', '7200022', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '奈良津町', 'ナラヅチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市北美台', '34', '34207', '7200023', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '北美台', 'キタミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市高美台', '34', '34207', '7200024', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '高美台', 'タカミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市清水ケ丘', '34', '34207', '7200025', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '清水ケ丘', 'シミズガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市東2条北', '01', '01215', '0720003', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '東2条北', 'ヒガシ02ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市三吉町', '34', '34207', '7200031', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '三吉町', 'ミヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市三吉町南', '34', '34207', '7200032', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '三吉町南', 'ミヨシチョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市旭町', '34', '34207', '7200033', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '旭町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市若松町', '34', '34207', '7200034', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '若松町', 'ワカマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市東3条北', '01', '01215', '0720004', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '東3条北', 'ヒガシ03ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市寺町', '34', '34207', '7200041', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '寺町', 'テラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市御船町', '34', '34207', '7200042', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '御船町', 'ミフネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市船町', '34', '34207', '7200043', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '船町', 'フナマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市笠岡町', '34', '34207', '7200044', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '笠岡町', 'カサオカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市宝町', '34', '34207', '7200045', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '宝町', 'タカラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市今町', '34', '34207', '7200046', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '今町', 'イママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市東4条北', '01', '01215', '0720005', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '東4条北', 'ヒガシ04ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市桜馬場町', '34', '34207', '7200051', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '桜馬場町', 'サクラババチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市東町', '34', '34207', '7200052', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '東町', 'ヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市大黒町', '34', '34207', '7200053', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '大黒町', 'ダイコクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市城見町', '34', '34207', '7200054', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '城見町', 'シロミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市胡町', '34', '34207', '7200055', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '胡町', 'エビスマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市本町', '34', '34207', '7200056', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市東5条北', '01', '01215', '0720006', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '東5条北', 'ヒガシ05ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市丸之内', '34', '34207', '7200061', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '丸之内', 'マルノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市伏見町', '34', '34207', '7200062', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '伏見町', 'フシミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市元町', '34', '34207', '7200063', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '元町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市延広町', '34', '34207', '7200064', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '延広町', 'ノブヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市東桜町', '34', '34207', '7200065', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '東桜町', 'ヒガシサクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市三之丸町', '34', '34207', '7200066', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '三之丸町', 'サンノマルチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市西町', '34', '34207', '7200067', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '西町', 'ニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市東6条北', '01', '01215', '0720007', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '東6条北', 'ヒガシ06ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市東吉津町', '34', '34207', '7200071', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '東吉津町', 'ヒガシヨシヅチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市吉津町', '34', '34207', '7200072', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '吉津町', 'ヨシヅチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市北吉津町', '34', '34207', '7200073', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '北吉津町', 'キタヨシヅチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市北本庄', '34', '34207', '7200074', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '北本庄', 'キタホンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市長者町', '34', '34207', '7200075', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '長者町', 'チョウジャマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市本庄町中', '34', '34207', '7200076', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '本庄町中', 'ホンジョウチョウナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市南本庄', '34', '34207', '7200077', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '南本庄', 'ミナミホンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市癸巳町奔美唄', '01', '01215', '0720008', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '癸巳町奔美唄', 'キシチョウポンビバイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市向陽町', '34', '34207', '7200081', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '向陽町', 'コウヨウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市木之庄町', '34', '34207', '7200082', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '木之庄町', 'キノショウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市久松台', '34', '34207', '7200083', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '久松台', 'ヒサマツダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市癸巳町', '01', '01215', '0720009', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '癸巳町', 'キシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市神島町', '34', '34207', '7200091', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '神島町', 'カシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市山手町', '34', '34207', '7200092', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '山手町', 'ヤマテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市郷分町', '34', '34207', '7200093', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '郷分町', 'ゴウブンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市大通東1条南', '01', '01215', '0720011', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '大通東1条南', 'オオドオリヒガシ01ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市東1条南', '01', '01215', '0720012', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '東1条南', 'ヒガシ01ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市東2条南', '01', '01215', '0720013', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '東2条南', 'ヒガシ02ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市東3条南', '01', '01215', '0720014', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '東3条南', 'ヒガシ03ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市東4条南', '01', '01215', '0720015', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '東4条南', 'ヒガシ04ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市東5条南', '01', '01215', '0720016', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '東5条南', 'ヒガシ05ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市東6条南', '01', '01215', '0720017', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '東6条南', 'ヒガシ06ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市鞆町鞆', '34', '34207', '7200201', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '鞆町鞆', 'トモチョウトモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市鞆町後地', '34', '34207', '7200202', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '鞆町後地', 'トモチョウウシロジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市田尻町', '34', '34207', '7200203', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '田尻町', 'タジリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市走島町', '34', '34207', '7200204', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '走島町', 'ハシリジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市大通西1条北', '01', '01215', '0720021', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '大通西1条北', 'オオドオリニシ01ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市西1条北', '01', '01215', '0720022', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '西1条北', 'ニシ01ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市大通西1条南', '01', '01215', '0720023', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '大通西1条南', 'オオドオリニシ01ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市西1条南', '01', '01215', '0720024', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '西1条南', 'ニシ01ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市西2条南', '01', '01215', '0720025', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '西2条南', 'ニシ02ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市西3条南', '01', '01215', '0720026', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '西3条南', 'ニシ03ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市西4条南', '01', '01215', '0720027', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '西4条南', 'ニシ04ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市西5条南', '01', '01215', '0720028', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '西5条南', 'ニシ05ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市西2条北', '01', '01215', '0720031', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '西2条北', 'ニシ02ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市沼隈町草深', '34', '34207', '7200311', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '沼隈町草深', 'ヌマクマチョウクサブカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市沼隈町能登原', '34', '34207', '7200312', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '沼隈町能登原', 'ヌマクマチョウノトハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市沼隈町常石', '34', '34207', '7200313', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '沼隈町常石', 'ヌマクマチョウツネイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市西3条北', '01', '01215', '0720032', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '西3条北', 'ニシ03ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市西4条北', '01', '01215', '0720033', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '西4条北', 'ニシ04ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市西5条北', '01', '01215', '0720034', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '西5条北', 'ニシ05ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市沼の内町中央', '01', '01215', '0720035', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '沼の内町中央', 'ヌマノウチチョウチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市沼の内町南', '01', '01215', '0720036', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '沼の内町南', 'ヌマノウチチョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市沼の内町北', '01', '01215', '0720037', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '沼の内町北', 'ヌマノウチチョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市沼の内町西', '01', '01215', '0720038', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '沼の内町西', 'ヌマノウチチョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市沼隈町上山南', '34', '34207', '7200401', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '沼隈町上山南', 'ヌマクマチョウカミサンナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市沼隈町中山南', '34', '34207', '7200402', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '沼隈町中山南', 'ヌマクマチョウナカサンナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市沼隈町下山南', '34', '34207', '7200403', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '沼隈町下山南', 'ヌマクマチョウシモサンナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市進徳町東', '01', '01215', '0720041', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '進徳町東', 'シントクチョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市熊野町', '34', '34207', '7200411', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '熊野町', 'クマノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市進徳町', '01', '01215', '0720042', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '進徳町', 'シントクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市進徳町西', '01', '01215', '0720043', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '進徳町西', 'シントクチョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市一心町', '01', '01215', '0720044', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '一心町', 'イッシンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市開発町南', '01', '01215', '0720045', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '開発町南', 'カイハツチョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市開発町北', '01', '01215', '0720046', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '開発町北', 'カイハツチョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市開発町親和', '01', '01215', '0720047', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '開発町親和', 'カイハツチョウシンワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市上美唄町', '01', '01215', '0720051', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '上美唄町', 'カミビバイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市上美唄町東', '01', '01215', '0720052', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '上美唄町東', 'カミビバイチョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市上美唄町中央', '01', '01215', '0720053', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '上美唄町中央', 'カミビバイチョウチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市上美唄町沼の端', '01', '01215', '0720054', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '上美唄町沼の端', 'カミビバイチョウヌマノハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市金江町金見', '34', '34207', '7200541', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '金江町金見', 'カナエチョウカナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市金江町藁江', '34', '34207', '7200542', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '金江町藁江', 'カナエチョウワラエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市藤江町', '34', '34207', '7200543', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '藤江町', 'フジエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市西美唄町元村', '01', '01215', '0720055', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '西美唄町元村', 'ニシビバイチョウモトムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市浦崎町', '34', '34205', '7200551', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '浦崎町', 'ウラサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市西美唄町山形', '01', '01215', '0720056', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '西美唄町山形', 'ニシビバイチョウヤマガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市西美唄町大曲', '01', '01215', '0720057', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '西美唄町大曲', 'ニシビバイチョウオオマガリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市西美唄町富樫', '01', '01215', '0720058', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '西美唄町富樫', 'ニシビバイチョウトガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市西美唄町元村美富', '01', '01215', '0720059', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '西美唄町元村美富', 'ニシビバイチョウモトムラミトミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市入船町', '34', '34207', '7200801', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '入船町', 'イリフネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市松浜町', '34', '34207', '7200802', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '松浜町', 'マツハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市花園町', '34', '34207', '7200803', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '花園町', 'ハナゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市緑町', '34', '34207', '7200804', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '緑町', 'ミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市御門町', '34', '34207', '7200805', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '御門町', 'ミカドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市南町', '34', '34207', '7200806', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '南町', 'ミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市明治町', '34', '34207', '7200807', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '明治町', 'メイジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市昭和町', '34', '34207', '7200808', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '昭和町', 'ショウワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市住吉町', '34', '34207', '7200809', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '住吉町', 'スミヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市紅葉町', '34', '34207', '7200811', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '紅葉町', 'モミジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市霞町', '34', '34207', '7200812', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '霞町', 'カスミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市道三町', '34', '34207', '7200813', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '道三町', 'ドウサンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市光南町', '34', '34207', '7200814', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '光南町', 'コウナンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市野上町', '34', '34207', '7200815', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '野上町', 'ノガミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市地吹町', '34', '34207', '7200816', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '地吹町', 'ジブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市古野上町', '34', '34207', '7200817', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '古野上町', 'フルノガミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市西桜町', '34', '34207', '7200818', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '西桜町', 'ニシサクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市東川口町', '34', '34207', '7200821', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '東川口町', 'ヒガシカワグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市川口町', '34', '34207', '7200822', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '川口町', 'カワグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市千代田町', '34', '34207', '7200823', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '千代田町', 'チヨダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市多治米町', '34', '34207', '7200824', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '多治米町', 'タジメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市沖野上町', '34', '34207', '7200825', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '沖野上町', 'オキノガミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市草戸町', '34', '34207', '7200831', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '草戸町', 'クサドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市水呑町', '34', '34207', '7200832', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '水呑町', 'ミノミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市水呑向丘', '34', '34207', '7200833', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '水呑向丘', 'ミノミムカイガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市明王台', '34', '34207', '7200834', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '明王台', 'ミョウオウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市佐波町', '34', '34207', '7200835', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '佐波町', 'サバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市瀬戸町長和', '34', '34207', '7200836', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '瀬戸町長和', 'セトチョウナガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市瀬戸町地頭分', '34', '34207', '7200837', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '瀬戸町地頭分', 'セトチョウジトウブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市瀬戸町山北', '34', '34207', '7200838', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '瀬戸町山北', 'セトチョウサボク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市東明王台', '34', '34207', '7200839', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '東明王台', 'ヒガシミョウオウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市津之郷町津之郷', '34', '34207', '7200841', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '津之郷町津之郷', 'ツノゴウチョウツノゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市津之郷町加屋', '34', '34207', '7200842', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '津之郷町加屋', 'ツノゴウチョウカヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市赤坂町赤坂', '34', '34207', '7200843', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '赤坂町赤坂', 'アカサカチョウアカサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市赤坂町早戸', '34', '34207', '7200844', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '赤坂町早戸', 'アカサカチョウハヤト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市芦田町福田', '34', '34207', '7200845', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '芦田町福田', 'アシダチョウフクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市駅家町万能倉', '34', '34207', '7201131', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '駅家町万能倉', 'エキヤチョウマナグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市駅家町倉光', '34', '34207', '7201132', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '駅家町倉光', 'エキヤチョウクラミツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市駅家町近田', '34', '34207', '7201133', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '駅家町近田', 'エキヤチョウチカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市駅家町中島', '34', '34207', '7201134', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '駅家町中島', 'エキヤチョウナカシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市駅家町弥生ケ丘', '34', '34207', '7201135', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '駅家町弥生ケ丘', 'エキヤチョウヤヨイガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市駅家町江良', '34', '34207', '7201141', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '駅家町江良', 'エキヤチョウエラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市駅家町上山守', '34', '34207', '7201142', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '駅家町上山守', 'エキヤチョウカミヤマモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市駅家町下山守', '34', '34207', '7201143', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '駅家町下山守', 'エキヤチョウシモヤマモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市駅家町坊寺', '34', '34207', '7201144', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '駅家町坊寺', 'エキヤチョウボウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('89999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市駅家町今岡', '34', '34207', '7201145', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '駅家町今岡', 'エキヤチョウイマオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市駅家町大橋', '34', '34207', '7201146', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '駅家町大橋', 'エキヤチョウオオハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市駅家町向永谷', '34', '34207', '7201147', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '駅家町向永谷', 'エキヤチョウムカイナガタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市芦田町上有地', '34', '34207', '7201261', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '芦田町上有地', 'アシダチョウカミアルジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市芦田町下有地', '34', '34207', '7201262', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '芦田町下有地', 'アシダチョウシモアルジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市芦田町柞磨', '34', '34207', '7201263', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '芦田町柞磨', 'アシダチョウタルマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市芦田町福田', '34', '34207', '7201264', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '芦田町福田', 'アシダチョウフクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市芦田町向陽台', '34', '34207', '7201265', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '芦田町向陽台', 'アシダチョウコウヨウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県神石郡神石高原町高蓋', '34', '34545', '7201410', '広島県', 'ヒロシマケン', '神石郡神石高原町', 'ジンセキグンジンセキコウゲンチョウ', '高蓋', 'タカフタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県神石郡神石高原町光信', '34', '34545', '7201411', '広島県', 'ヒロシマケン', '神石郡神石高原町', 'ジンセキグンジンセキコウゲンチョウ', '光信', 'ミツノブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県神石郡神石高原町光末', '34', '34545', '7201412', '広島県', 'ヒロシマケン', '神石郡神石高原町', 'ジンセキグンジンセキコウゲンチョウ', '光末', 'ミツスエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県神石郡神石高原町父木野', '34', '34545', '7201413', '広島県', 'ヒロシマケン', '神石郡神石高原町', 'ジンセキグンジンセキコウゲンチョウ', '父木野', 'チチキノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県神石郡神石高原町桑木', '34', '34545', '7201414', '広島県', 'ヒロシマケン', '神石郡神石高原町', 'ジンセキグンジンセキコウゲンチョウ', '桑木', 'クワギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県神石郡神石高原町階見', '34', '34545', '7201415', '広島県', 'ヒロシマケン', '神石郡神石高原町', 'ジンセキグンジンセキコウゲンチョウ', '階見', 'シナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県神石郡神石高原町木津和', '34', '34545', '7201416', '広島県', 'ヒロシマケン', '神石郡神石高原町', 'ジンセキグンジンセキコウゲンチョウ', '木津和', 'キツワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県神石郡神石高原町阿下', '34', '34545', '7201521', '広島県', 'ヒロシマケン', '神石郡神石高原町', 'ジンセキグンジンセキコウゲンチョウ', '阿下', 'アゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県神石郡神石高原町小畠', '34', '34545', '7201522', '広島県', 'ヒロシマケン', '神石郡神石高原町', 'ジンセキグンジンセキコウゲンチョウ', '小畠', 'コバタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県神石郡神石高原町亀石', '34', '34545', '7201523', '広島県', 'ヒロシマケン', '神石郡神石高原町', 'ジンセキグンジンセキコウゲンチョウ', '亀石', 'カメイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県神石郡神石高原町常光', '34', '34545', '7201524', '広島県', 'ヒロシマケン', '神石郡神石高原町', 'ジンセキグンジンセキコウゲンチョウ', '常光', 'ツネミツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県神石郡神石高原町上', '34', '34545', '7201525', '広島県', 'ヒロシマケン', '神石郡神石高原町', 'ジンセキグンジンセキコウゲンチョウ', '上', 'カミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県神石郡神石高原町大矢', '34', '34545', '7201601', '広島県', 'ヒロシマケン', '神石郡神石高原町', 'ジンセキグンジンセキコウゲンチョウ', '大矢', 'オオヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県神石郡神石高原町井関', '34', '34545', '7201602', '広島県', 'ヒロシマケン', '神石郡神石高原町', 'ジンセキグンジンセキコウゲンチョウ', '井関', 'イセキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県神石郡神石高原町時安', '34', '34545', '7201603', '広島県', 'ヒロシマケン', '神石郡神石高原町', 'ジンセキグンジンセキコウゲンチョウ', '時安', 'トキヤス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県神石郡神石高原町坂瀬川', '34', '34545', '7201604', '広島県', 'ヒロシマケン', '神石郡神石高原町', 'ジンセキグンジンセキコウゲンチョウ', '坂瀬川', 'サカセガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県神石郡神石高原町李', '34', '34545', '7201621', '広島県', 'ヒロシマケン', '神石郡神石高原町', 'ジンセキグンジンセキコウゲンチョウ', '李', 'スモモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県神石郡神石高原町近田', '34', '34545', '7201622', '広島県', 'ヒロシマケン', '神石郡神石高原町', 'ジンセキグンジンセキコウゲンチョウ', '近田', 'チカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県神石郡神石高原町花済', '34', '34545', '7201623', '広島県', 'ヒロシマケン', '神石郡神石高原町', 'ジンセキグンジンセキコウゲンチョウ', '花済', 'ハナズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県神石郡神石高原町上野', '34', '34545', '7201624', '広島県', 'ヒロシマケン', '神石郡神石高原町', 'ジンセキグンジンセキコウゲンチョウ', '上野', 'ウエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県神石郡神石高原町有木', '34', '34545', '7201701', '広島県', 'ヒロシマケン', '神石郡神石高原町', 'ジンセキグンジンセキコウゲンチョウ', '有木', 'アルギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県神石郡神石高原町上豊松', '34', '34545', '7201702', '広島県', 'ヒロシマケン', '神石郡神石高原町', 'ジンセキグンジンセキコウゲンチョウ', '上豊松', 'カミトヨマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県神石郡神石高原町笹尾', '34', '34545', '7201703', '広島県', 'ヒロシマケン', '神石郡神石高原町', 'ジンセキグンジンセキコウゲンチョウ', '笹尾', 'ササオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県神石郡神石高原町下豊松', '34', '34545', '7201704', '広島県', 'ヒロシマケン', '神石郡神石高原町', 'ジンセキグンジンセキコウゲンチョウ', '下豊松', 'シモトヨマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県神石郡神石高原町中平', '34', '34545', '7201705', '広島県', 'ヒロシマケン', '神石郡神石高原町', 'ジンセキグンジンセキコウゲンチョウ', '中平', 'ナカダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県神石郡神石高原町', '34', '34545', '7201800', '広島県', 'ヒロシマケン', '神石郡神石高原町', 'ジンセキグンジンセキコウゲンチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('90033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県神石郡神石高原町安田', '34', '34545', '7201811', '広島県', 'ヒロシマケン', '神石郡神石高原町', 'ジンセキグンジンセキコウゲンチョウ', '安田', 'ヤスダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県神石郡神石高原町油木', '34', '34545', '7201812', '広島県', 'ヒロシマケン', '神石郡神石高原町', 'ジンセキグンジンセキコウゲンチョウ', '油木', 'ユキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県神石郡神石高原町小野', '34', '34545', '7201901', '広島県', 'ヒロシマケン', '神石郡神石高原町', 'ジンセキグンジンセキコウゲンチョウ', '小野', 'オノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県神石郡神石高原町新免', '34', '34545', '7201902', '広島県', 'ヒロシマケン', '神石郡神石高原町', 'ジンセキグンジンセキコウゲンチョウ', '新免', 'シンメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市神辺町三谷', '34', '34207', '7202101', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '神辺町三谷', 'カンナベチョウミタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市神辺町東中条', '34', '34207', '7202102', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '神辺町東中条', 'カンナベチョウヒガシチュウジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市神辺町西中条', '34', '34207', '7202103', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '神辺町西中条', 'カンナベチョウニシチュウジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市神辺町道上', '34', '34207', '7202104', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '神辺町道上', 'カンナベチョウミチノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市神辺町十三軒屋', '34', '34207', '7202105', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '神辺町十三軒屋', 'カンナベチョウジュウサンゲンヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市神辺町十九軒屋', '34', '34207', '7202106', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '神辺町十九軒屋', 'カンナベチョウジュウクケンヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市神辺町新道上', '34', '34207', '7202107', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '神辺町新道上', 'カンナベチョウシンミチノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市神辺町新十九', '34', '34207', '7202108', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '神辺町新十九', 'カンナベチョウシンジュウク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市神辺町上御領', '34', '34207', '7202111', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '神辺町上御領', 'カンナベチョウカミゴリョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市神辺町八尋', '34', '34207', '7202112', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '神辺町八尋', 'カンナベチョウヤヒロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市神辺町旭丘', '34', '34207', '7202113', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '神辺町旭丘', 'カンナベチョウアサヒオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市神辺町上竹田', '34', '34207', '7202114', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '神辺町上竹田', 'カンナベチョウカミタケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市神辺町下竹田', '34', '34207', '7202115', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '神辺町下竹田', 'カンナベチョウシモタケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市神辺町平野', '34', '34207', '7202116', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '神辺町平野', 'カンナベチョウヒラノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市神辺町下御領', '34', '34207', '7202117', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '神辺町下御領', 'カンナベチョウシモゴリョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市神辺町湯野', '34', '34207', '7202121', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '神辺町湯野', 'カンナベチョウユノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市神辺町新湯野', '34', '34207', '7202122', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '神辺町新湯野', 'カンナベチョウシンユノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市神辺町川北', '34', '34207', '7202123', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '神辺町川北', 'カンナベチョウカワキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市神辺町川南', '34', '34207', '7202124', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '神辺町川南', 'カンナベチョウカワミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市神辺町新徳田', '34', '34207', '7202125', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '神辺町新徳田', 'カンナベチョウシントクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市神辺町徳田', '34', '34207', '7202126', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '神辺町徳田', 'カンナベチョウトクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市神辺町箱田', '34', '34207', '7202127', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '神辺町箱田', 'カンナベチョウハコダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市加茂町八軒屋', '34', '34207', '7202410', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '加茂町八軒屋', 'カモチョウハチケンヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市加茂町下加茂', '34', '34207', '7202412', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '加茂町下加茂', 'カモチョウシモガモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市駅家町法成寺', '34', '34207', '7202413', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '駅家町法成寺', 'エキヤチョウホウジョウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市加茂町百谷', '34', '34207', '7202414', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '加茂町百谷', 'カモチョウモモダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市加茂町北山', '34', '34207', '7202415', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '加茂町北山', 'カモチョウキタヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市加茂町粟根', '34', '34207', '7202416', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '加茂町粟根', 'カモチョウアワネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市加茂町芦原', '34', '34207', '7202417', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '加茂町芦原', 'カモチョウアシワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市加茂町中野', '34', '34207', '7202418', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '加茂町中野', 'カモチョウナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市加茂町上加茂', '34', '34207', '7202419', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '加茂町上加茂', 'カモチョウカミガモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市駅家町服部本郷', '34', '34207', '7202521', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '駅家町服部本郷', 'エキヤチョウハットリホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市駅家町服部永谷', '34', '34207', '7202522', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '駅家町服部永谷', 'エキヤチョウハットリナガタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市駅家町新山', '34', '34207', '7202523', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '駅家町新山', 'エキヤチョウニイヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市駅家町助元', '34', '34207', '7202524', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '駅家町助元', 'エキヤチョウスケモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市駅家町雨木', '34', '34207', '7202525', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '駅家町雨木', 'エキヤチョウアメギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市山野町矢川', '34', '34207', '7202601', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '山野町矢川', 'ヤマノチョウヤカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市山野町山野', '34', '34207', '7202602', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '山野町山野', 'ヤマノチョウヤマノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市東7条北', '01', '01215', '0720801', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '東7条北', 'ヒガシ07ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市東8条北', '01', '01215', '0720802', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '東8条北', 'ヒガシ08ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市東明1条', '01', '01215', '0720803', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '東明1条', 'トウメイ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市東明2条', '01', '01215', '0720804', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '東明2条', 'トウメイ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市東明3条', '01', '01215', '0720805', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '東明3条', 'トウメイ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市東明4条', '01', '01215', '0720806', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '東明4条', 'トウメイ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市東明5条', '01', '01215', '0720807', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '東明5条', 'トウメイ05ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市東明町', '01', '01215', '0720808', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '東明町', 'トウメイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市東7条南', '01', '01215', '0720811', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '東7条南', 'ヒガシ07ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市東8条南', '01', '01215', '0720812', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '東8条南', 'ヒガシ08ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市南美唄町旭町', '01', '01215', '0720813', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '南美唄町旭町', 'ミナミビバイチョウアサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市南美唄町山の手', '01', '01215', '0720814', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '南美唄町山の手', 'ミナミビバイチョウヤマノテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市南美唄町南町', '01', '01215', '0720815', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '南美唄町南町', 'ミナミビバイチョウミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市南美唄町仲町', '01', '01215', '0720816', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '南美唄町仲町', 'ミナミビバイチョウナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市南美唄町北町', '01', '01215', '0720817', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '南美唄町北町', 'ミナミビバイチョウキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市南美唄町中央通り', '01', '01215', '0720818', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '南美唄町中央通り', 'ミナミビバイチョウチュウオウドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市共練町西', '01', '01215', '0720819', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '共練町西', 'キョウレンチョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市共練町東', '01', '01215', '0720819', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '共練町東', 'キョウレンチョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市南美唄町上', '01', '01215', '0720821', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '南美唄町上', 'ミナミビバイチョウカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市南美唄町大通り', '01', '01215', '0720822', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '南美唄町大通り', 'ミナミビバイチョウオオドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市南美唄町下', '01', '01215', '0720823', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '南美唄町下', 'ミナミビバイチョウシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市南美唄町新富町', '01', '01215', '0720824', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '南美唄町新富町', 'ミナミビバイチョウシントミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市南美唄町桜井町', '01', '01215', '0720825', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '南美唄町桜井町', 'ミナミビバイチョウサクライチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市南美唄町栄町南', '01', '01215', '0720826', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '南美唄町栄町南', 'ミナミビバイチョウサカエマチミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市南美唄町栄町北', '01', '01215', '0720827', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '南美唄町栄町北', 'ミナミビバイチョウサカエマチキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市南美唄町西町', '01', '01215', '0720828', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '南美唄町西町', 'ミナミビバイチョウニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市落合町栄町', '01', '01215', '0720831', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '落合町栄町', 'オチアイチョウサカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市落合町本町', '01', '01215', '0720832', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '落合町本町', 'オチアイチョウホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市落合町緑が丘', '01', '01215', '0720833', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '落合町緑が丘', 'オチアイチョウミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市落合町住吉', '01', '01215', '0720834', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '落合町住吉', 'オチアイチョウスミヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市落合町入初', '01', '01215', '0720835', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '落合町入初', 'オチアイチョウイリソメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市盤の沢町滝の上', '01', '01215', '0720841', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '盤の沢町滝の上', 'バンノサワチョウタキノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市盤の沢町本町', '01', '01215', '0720842', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '盤の沢町本町', 'バンノサワチョウホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市盤の沢町高台', '01', '01215', '0720843', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '盤の沢町高台', 'バンノサワチョウタカダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市盤の沢町桜が丘', '01', '01215', '0720844', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '盤の沢町桜が丘', 'バンノサワチョウサクラガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市我路町1条', '01', '01215', '0720851', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '我路町1条', 'ガロチョウ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市我路町2条', '01', '01215', '0720852', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '我路町2条', 'ガロチョウ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市我路町3条', '01', '01215', '0720853', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '我路町3条', 'ガロチョウ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市我路町4条', '01', '01215', '0720854', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '我路町4条', 'ガロチョウ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市我路町公園通り', '01', '01215', '0720855', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '我路町公園通り', 'ガロチョウコウエンドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市我路町新町', '01', '01215', '0720856', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '我路町新町', 'ガロチョウシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市我路町菊水', '01', '01215', '0720857', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '我路町菊水', 'ガロチョウキクスイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市', '34', '34207', '7210000', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('90154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市春日町宇山', '34', '34207', '7210901', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '春日町宇山', 'カスガチョウウヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市春日町浦上', '34', '34207', '7210902', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '春日町浦上', 'カスガチョウウラカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市坪生町', '34', '34207', '7210903', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '坪生町', 'ツボウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市坪生町南', '34', '34207', '7210904', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '坪生町南', 'ツボウチョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市能島', '34', '34207', '7210906', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '能島', 'ノウジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市春日町', '34', '34207', '7210907', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '春日町', 'カスガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市春日町吉田', '34', '34207', '7210908', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '春日町吉田', 'カスガチョウヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市青葉台', '34', '34207', '7210911', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '青葉台', 'アオバダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市東陽台', '34', '34207', '7210912', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '東陽台', 'トウヨウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市幕山台', '34', '34207', '7210913', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '幕山台', 'マクヤマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市大谷台', '34', '34207', '7210914', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '大谷台', 'オオタニダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市伊勢丘', '34', '34207', '7210915', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '伊勢丘', 'イセガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市春日台', '34', '34207', '7210916', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '春日台', 'カスガダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市春日池', '34', '34207', '7210917', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '春日池', 'カスガイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市大門町大門', '34', '34207', '7210921', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '大門町大門', 'ダイモンチョウダイモン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市大門町日之出丘', '34', '34207', '7210922', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '大門町日之出丘', 'ダイモンチョウヒノデオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市大門町野々浜', '34', '34207', '7210923', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '大門町野々浜', 'ダイモンチョウノノハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市大門町旭', '34', '34207', '7210924', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '大門町旭', 'ダイモンチョウアサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市大門町坂里', '34', '34207', '7210925', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '大門町坂里', 'ダイモンチョウサカリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市大門町', '34', '34207', '7210926', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '大門町', 'ダイモンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市大門町津之下', '34', '34207', '7210927', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '大門町津之下', 'ダイモンチョウツノシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市城興ケ丘', '34', '34207', '7210929', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '城興ケ丘', 'ジョウコウガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市鋼管町', '34', '34207', '7210931', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '鋼管町', 'コウカンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市引野町北', '34', '34207', '7210941', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '引野町北', 'ヒキノチョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市引野町', '34', '34207', '7210942', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '引野町', 'ヒキノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市平成台', '34', '34207', '7210943', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '平成台', 'ヘイセイダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市引野町東', '34', '34207', '7210944', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '引野町東', 'ヒキノチョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市引野町南', '34', '34207', '7210945', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '引野町南', 'ヒキノチョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市新浜町', '34', '34207', '7210951', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '新浜町', 'シンハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市曙町', '34', '34207', '7210952', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '曙町', 'アケボノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市一文字町', '34', '34207', '7210953', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '一文字町', 'イチモンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市卸町', '34', '34207', '7210954', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '卸町', 'オロシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市新涯町', '34', '34207', '7210955', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '新涯町', 'シンガイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市箕沖町', '34', '34207', '7210956', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '箕沖町', 'ミノオキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市箕島町', '34', '34207', '7210957', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '箕島町', 'ミノシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市西新涯町', '34', '34207', '7210958', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '西新涯町', 'ニシシンガイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市明神町', '34', '34207', '7210961', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '明神町', 'ミョウジンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市東手城町', '34', '34207', '7210962', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '東手城町', 'ヒガシテシロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市南手城町', '34', '34207', '7210963', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '南手城町', 'ミナミテシロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市港町', '34', '34207', '7210964', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '港町', 'ミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市王子町', '34', '34207', '7210965', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '王子町', 'オウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市手城町', '34', '34207', '7210966', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '手城町', 'テシロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市蔵王町', '34', '34207', '7210971', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '蔵王町', 'ザオウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市日吉台', '34', '34207', '7210972', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '日吉台', 'ヒヨシダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市南蔵王町', '34', '34207', '7210973', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '南蔵王町', 'ミナミザオウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市東深津町', '34', '34207', '7210974', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '東深津町', 'ヒガシフカツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市西深津町', '34', '34207', '7210975', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '西深津町', 'ニシフカツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市', '34', '34205', '7220000', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('90232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市手崎町', '34', '34205', '7220001', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '手崎町', 'テサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市古浜町', '34', '34205', '7220002', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '古浜町', 'コハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市東元町', '34', '34205', '7220003', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '東元町', 'ヒガシモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市正徳町', '34', '34205', '7220004', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '正徳町', 'ショウトクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市福地町', '34', '34205', '7220005', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '福地町', 'フクチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市沖側町', '34', '34205', '7220006', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '沖側町', 'オキガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市吉和西元町', '34', '34205', '7220007', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '吉和西元町', 'ヨシワニシモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市吉和町', '34', '34205', '7220008', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '吉和町', 'ヨシワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市桜町', '34', '34205', '7220011', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '桜町', 'サクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市潮見町', '34', '34205', '7220012', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '潮見町', 'シオミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市日比崎町', '34', '34205', '7220013', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '日比崎町', 'ヒビザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市新浜', '34', '34205', '7220014', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '新浜', 'シンハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市吉浦町', '34', '34205', '7220015', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '吉浦町', 'ヨシウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市神田町', '34', '34205', '7220016', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '神田町', 'カンダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市門田町', '34', '34205', '7220017', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '門田町', 'モンデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市平原', '34', '34205', '7220018', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '平原', 'ヒラハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市久山田町', '34', '34205', '7220021', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '久山田町', 'ヒサヤマダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市栗原町', '34', '34205', '7220022', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '栗原町', 'クリハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市東則末町', '34', '34205', '7220023', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '東則末町', 'ヒガシノリスエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市西則末町', '34', '34205', '7220024', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '西則末町', 'ニシノリスエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市栗原東', '34', '34205', '7220025', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '栗原東', 'クリハラヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市栗原西', '34', '34205', '7220026', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '栗原西', 'クリハラニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市三軒家町', '34', '34205', '7220031', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '三軒家町', 'サンゲンヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市西土堂町', '34', '34205', '7220032', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '西土堂町', 'ニシツチドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市東土堂町', '34', '34205', '7220033', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '東土堂町', 'ヒガシツチドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市十四日元町', '34', '34205', '7220034', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '十四日元町', 'トヨヒモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市土堂', '34', '34205', '7220035', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '土堂', 'ツチドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市東御所町', '34', '34205', '7220036', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '東御所町', 'ヒガシゴショチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市西御所町', '34', '34205', '7220037', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '西御所町', 'ニシゴショチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市天満町', '34', '34205', '7220038', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '天満町', 'テンマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市防地町', '34', '34205', '7220041', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '防地町', 'ボウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市久保町', '34', '34205', '7220042', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '久保町', 'クボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市東久保町', '34', '34205', '7220043', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '東久保町', 'ヒガシクボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市西久保町', '34', '34205', '7220044', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '西久保町', 'ニシクボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市久保', '34', '34205', '7220045', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '久保', 'クボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市長江', '34', '34205', '7220046', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '長江', 'ナガエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市十四日町', '34', '34205', '7220047', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '十四日町', 'トヨヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市東尾道', '34', '34205', '7220051', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '東尾道', 'ヒガシオノミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市山波町', '34', '34205', '7220052', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '山波町', 'サンバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市尾崎町', '34', '34205', '7220053', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '尾崎町', 'オザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市尾崎本町', '34', '34205', '7220054', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '尾崎本町', 'オザキホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市新高山', '34', '34205', '7220055', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '新高山', 'シンタカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市百島町', '34', '34205', '7220061', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '百島町', 'モモシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市向東町', '34', '34205', '7220062', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '向東町', 'ムカイヒガシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市向島町立花', '34', '34205', '7220071', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '向島町立花', 'ムカイシマチョウタチバナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市向島町岩子島', '34', '34205', '7220072', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '向島町岩子島', 'ムカイシマチョウイワシジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市向島町', '34', '34205', '7220073', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '向島町', 'ムカイシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市原田町小原', '34', '34205', '7220201', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '原田町小原', 'ハラダチョウオバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市原田町梶山田', '34', '34205', '7220202', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '原田町梶山田', 'ハラダチョウカジヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市美ノ郷町中野', '34', '34205', '7220211', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '美ノ郷町中野', 'ミノゴウチョウナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市美ノ郷町本郷', '34', '34205', '7220212', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '美ノ郷町本郷', 'ミノゴウチョウホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市美ノ郷町白江', '34', '34205', '7220213', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '美ノ郷町白江', 'ミノゴウチョウシロエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市美ノ郷町猪子迫', '34', '34205', '7220214', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '美ノ郷町猪子迫', 'ミノゴウチョウイノコザコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市美ノ郷町三成', '34', '34205', '7220215', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '美ノ郷町三成', 'ミノゴウチョウミナリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市長者原', '34', '34205', '7220221', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '長者原', 'チョウジャバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市木ノ庄町畑', '34', '34205', '7220231', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '木ノ庄町畑', 'キノショウチョウハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市木ノ庄町木門田', '34', '34205', '7220232', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '木ノ庄町木門田', 'キノショウチョウキモンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市木ノ庄町市原', '34', '34205', '7220233', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '木ノ庄町市原', 'キノショウチョウイチバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市木ノ庄町木梨', '34', '34205', '7220234', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '木ノ庄町木梨', 'キノショウチョウキナシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市木ノ庄町木梨山方', '34', '34205', '7220235', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '木ノ庄町木梨山方', 'キノショウチョウキナシヤマガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市御調町市', '34', '34205', '7220311', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '御調町市', 'ミツギチョウイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市御調町貝ケ原', '34', '34205', '7220312', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '御調町貝ケ原', 'ミツギチョウカイガハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市御調町平', '34', '34205', '7220313', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '御調町平', 'ミツギチョウヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市御調町大町', '34', '34205', '7220314', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '御調町大町', 'ミツギチョウオオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市御調町釜窪', '34', '34205', '7220315', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '御調町釜窪', 'ミツギチョウカマクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市御調町花尻', '34', '34205', '7220316', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '御調町花尻', 'ミツギチョウハナジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市御調町本', '34', '34205', '7220321', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '御調町本', 'ミツギチョウホン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市御調町三郎丸', '34', '34205', '7220322', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '御調町三郎丸', 'ミツギチョウサブロウマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市御調町大蔵', '34', '34205', '7220323', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '御調町大蔵', 'ミツギチョウダイゾウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市御調町白太', '34', '34205', '7220324', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '御調町白太', 'ミツギチョウハカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市御調町中原', '34', '34205', '7220325', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '御調町中原', 'ミツギチョウナカバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市御調町岩根', '34', '34205', '7220326', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '御調町岩根', 'ミツギチョウイワネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市御調町仁野', '34', '34205', '7220331', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '御調町仁野', 'ミツギチョウニノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市御調町平木', '34', '34205', '7220332', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '御調町平木', 'ミツギチョウヒラギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市御調町大塔', '34', '34205', '7220333', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '御調町大塔', 'ミツギチョウダイトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市御調町菅', '34', '34205', '7220334', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '御調町菅', 'ミツギチョウスゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市御調町国守', '34', '34205', '7220335', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '御調町国守', 'ミツギチョウクニモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市御調町江田', '34', '34205', '7220336', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '御調町江田', 'ミツギチョウエタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市御調町神', '34', '34205', '7220341', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '御調町神', 'ミツギチョウカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市御調町大田', '34', '34205', '7220342', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '御調町大田', 'ミツギチョウオオダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市御調町丸河南', '34', '34205', '7220343', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '御調町丸河南', 'ミツギチョウマルカナン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市御調町丸門田', '34', '34205', '7220344', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '御調町丸門田', 'ミツギチョウマルモンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市御調町徳永', '34', '34205', '7220345', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '御調町徳永', 'ミツギチョウトクナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市御調町大原', '34', '34205', '7220351', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '御調町大原', 'ミツギチョウオオバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市御調町公文', '34', '34205', '7220352', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '御調町公文', 'ミツギチョウクモン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市御調町高尾', '34', '34205', '7220353', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '御調町高尾', 'ミツギチョウタカオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市御調町綾目', '34', '34205', '7220354', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '御調町綾目', 'ミツギチョウアヤメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市御調町山岡', '34', '34205', '7220355', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '御調町山岡', 'ミツギチョウヤマオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市御調町千堂', '34', '34205', '7220401', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '御調町千堂', 'ミツギチョウセンドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市御調町下山田', '34', '34205', '7220402', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '御調町下山田', 'ミツギチョウシモヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市御調町大山田', '34', '34205', '7220403', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '御調町大山田', 'ミツギチョウオオヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県世羅郡世羅町宇津戸', '34', '34462', '7220411', '広島県', 'ヒロシマケン', '世羅郡世羅町', 'セラグンセラチョウ', '宇津戸', 'ウヅト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県府中市諸毛町', '34', '34208', '7220431', '広島県', 'ヒロシマケン', '府中市', 'フチュウシ', '諸毛町', 'モロケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県府中市小国町', '34', '34208', '7220432', '広島県', 'ヒロシマケン', '府中市', 'フチュウシ', '小国町', 'オグニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県世羅郡世羅町', '34', '34462', '7221100', '広島県', 'ヒロシマケン', '世羅郡世羅町', 'セラグンセラチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('90329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県世羅郡世羅町寺町', '34', '34462', '7221111', '広島県', 'ヒロシマケン', '世羅郡世羅町', 'セラグンセラチョウ', '寺町', 'テラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県世羅郡世羅町本郷', '34', '34462', '7221112', '広島県', 'ヒロシマケン', '世羅郡世羅町', 'セラグンセラチョウ', '本郷', 'ホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県世羅郡世羅町井折', '34', '34462', '7221113', '広島県', 'ヒロシマケン', '世羅郡世羅町', 'セラグンセラチョウ', '井折', 'イオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県世羅郡世羅町東神崎', '34', '34462', '7221114', '広島県', 'ヒロシマケン', '世羅郡世羅町', 'セラグンセラチョウ', '東神崎', 'ヒガシカンザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県世羅郡世羅町西神崎', '34', '34462', '7221115', '広島県', 'ヒロシマケン', '世羅郡世羅町', 'セラグンセラチョウ', '西神崎', 'ニシカンザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県世羅郡世羅町青山', '34', '34462', '7221116', '広島県', 'ヒロシマケン', '世羅郡世羅町', 'セラグンセラチョウ', '青山', 'アオヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県世羅郡世羅町三郎丸', '34', '34462', '7221117', '広島県', 'ヒロシマケン', '世羅郡世羅町', 'セラグンセラチョウ', '三郎丸', 'サブロウマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県世羅郡世羅町西上原', '34', '34462', '7221121', '広島県', 'ヒロシマケン', '世羅郡世羅町', 'セラグンセラチョウ', '西上原', 'ニシウエハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県世羅郡世羅町小世良', '34', '34462', '7221122', '広島県', 'ヒロシマケン', '世羅郡世羅町', 'セラグンセラチョウ', '小世良', 'オゼラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県世羅郡世羅町甲山', '34', '34462', '7221123', '広島県', 'ヒロシマケン', '世羅郡世羅町', 'セラグンセラチョウ', '甲山', 'コウザン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県世羅郡世羅町戸張', '34', '34462', '7221201', '広島県', 'ヒロシマケン', '世羅郡世羅町', 'セラグンセラチョウ', '戸張', 'トバリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県世羅郡世羅町安田', '34', '34462', '7221202', '広島県', 'ヒロシマケン', '世羅郡世羅町', 'セラグンセラチョウ', '安田', 'ヤスダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県世羅郡世羅町徳市', '34', '34462', '7221203', '広島県', 'ヒロシマケン', '世羅郡世羅町', 'セラグンセラチョウ', '徳市', 'トクイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県世羅郡世羅町京丸石川', '34', '34462', '7221204', '広島県', 'ヒロシマケン', '世羅郡世羅町', 'セラグンセラチョウ', '京丸', 'キョウマル', null, null, '石川', 'イシカワ');
INSERT INTO `ms_addresses` VALUES ('90345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県世羅郡世羅町京丸水の別', '34', '34462', '7221204', '広島県', 'ヒロシマケン', '世羅郡世羅町', 'セラグンセラチョウ', '京丸', 'キョウマル', null, null, '水の別', 'ミズノワカレ');
INSERT INTO `ms_addresses` VALUES ('90346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市久井町莇原', '34', '34204', '7221301', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '久井町莇原', 'クイチョウアゾウバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市久井町吉田', '34', '34204', '7221302', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '久井町吉田', 'クイチョウヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市久井町下津', '34', '34204', '7221303', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '久井町下津', 'クイチョウシモツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市久井町江木', '34', '34204', '7221304', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '久井町江木', 'クイチョウエギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市本郷町船木芋堀', '34', '34204', '7221401', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '本郷町船木', 'ホンゴウチョウフナキ', null, null, '芋堀', 'イモホリ');
INSERT INTO `ms_addresses` VALUES ('90351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市久井町泉', '34', '34204', '7221411', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '久井町泉', 'クイチョウイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市久井町和草', '34', '34204', '7221412', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '久井町和草', 'クイチョウワソウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市久井町羽倉', '34', '34204', '7221413', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '久井町羽倉', 'クイチョウハグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市久井町坂井原', '34', '34204', '7221414', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '久井町坂井原', 'クイチョウサカイバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市久井町土取', '34', '34204', '7221415', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '久井町土取', 'クイチョウツチトリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市久井町山中野', '34', '34204', '7221416', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '久井町山中野', 'クイチョウヤマナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市久井町小林', '34', '34204', '7221417', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '久井町小林', 'クイチョウコバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市八幡町垣内', '34', '34204', '7221501', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '八幡町垣内', 'ヤハタチョウカイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市八幡町篝', '34', '34204', '7221511', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '八幡町篝', 'ヤハタチョウカガリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市八幡町野串', '34', '34204', '7221512', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '八幡町野串', 'ヤハタチョウノグシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市八幡町宮内', '34', '34204', '7221513', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '八幡町宮内', 'ヤハタチョウミヤウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市八幡町屋中', '34', '34204', '7221514', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '八幡町屋中', 'ヤハタチョウヤナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市八幡町美生', '34', '34204', '7221515', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '八幡町美生', 'ヤハタチョウミノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市八幡町本庄', '34', '34204', '7221516', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '八幡町本庄', 'ヤハタチョウホンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市御調町福井', '34', '34205', '7221561', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '御調町福井', 'ミツギチョウフクイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市御調町津蟹', '34', '34205', '7221562', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '御調町津蟹', 'ミツギチョウツガニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市御調町植野', '34', '34205', '7221563', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '御調町植野', 'ミツギチョウウエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市御調町今田', '34', '34205', '7221564', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '御調町今田', 'ミツギチョウイマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市御調町野間', '34', '34205', '7221565', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '御調町野間', 'ミツギチョウノマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県世羅郡世羅町京丸', '34', '34462', '7221621', '広島県', 'ヒロシマケン', '世羅郡世羅町', 'セラグンセラチョウ', '京丸', 'キョウマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県世羅郡世羅町堀越', '34', '34462', '7221622', '広島県', 'ヒロシマケン', '世羅郡世羅町', 'セラグンセラチョウ', '堀越', 'ホリコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県世羅郡世羅町中原', '34', '34462', '7221623', '広島県', 'ヒロシマケン', '世羅郡世羅町', 'セラグンセラチョウ', '中原', 'ナカバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県世羅郡世羅町田打', '34', '34462', '7221624', '広島県', 'ヒロシマケン', '世羅郡世羅町', 'セラグンセラチョウ', '田打', 'トウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県世羅郡世羅町重永', '34', '34462', '7221625', '広島県', 'ヒロシマケン', '世羅郡世羅町', 'セラグンセラチョウ', '重永', 'シゲナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県世羅郡世羅町賀茂', '34', '34462', '7221626', '広島県', 'ヒロシマケン', '世羅郡世羅町', 'セラグンセラチョウ', '賀茂', 'カモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県世羅郡世羅町青水', '34', '34462', '7221627', '広島県', 'ヒロシマケン', '世羅郡世羅町', 'セラグンセラチョウ', '青水', 'アオミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県世羅郡世羅町小国', '34', '34462', '7221701', '広島県', 'ヒロシマケン', '世羅郡世羅町', 'セラグンセラチョウ', '小国', 'オグニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県世羅郡世羅町山中福田', '34', '34462', '7221702', '広島県', 'ヒロシマケン', '世羅郡世羅町', 'セラグンセラチョウ', '山中福田', 'ヤマナカフクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県世羅郡世羅町津口', '34', '34462', '7221731', '広島県', 'ヒロシマケン', '世羅郡世羅町', 'セラグンセラチョウ', '津口', 'ツクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県世羅郡世羅町黒渕', '34', '34462', '7221732', '広島県', 'ヒロシマケン', '世羅郡世羅町', 'セラグンセラチョウ', '黒渕', 'クロブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市因島大浜町', '34', '34205', '7222101', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '因島大浜町', 'インノシマオオハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市因島重井町', '34', '34205', '7222102', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '因島重井町', 'インノシマシゲイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市因島中庄町', '34', '34205', '7222211', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '因島中庄町', 'インノシマナカノショウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市因島鏡浦町', '34', '34205', '7222212', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '因島鏡浦町', 'インノシマカガミウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市因島外浦町', '34', '34205', '7222213', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '因島外浦町', 'インノシマトノウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市因島椋浦町', '34', '34205', '7222321', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '因島椋浦町', 'インノシマムクノウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市因島三庄町', '34', '34205', '7222322', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '因島三庄町', 'インノシマミツノショウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市因島土生町', '34', '34205', '7222323', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '因島土生町', 'インノシマハブチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市因島田熊町', '34', '34205', '7222324', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '因島田熊町', 'インノシマタクマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市瀬戸田町御寺', '34', '34205', '7222401', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '瀬戸田町御寺', 'セトダチョウミテラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市瀬戸田町宮原', '34', '34205', '7222402', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '瀬戸田町宮原', 'セトダチョウミヤバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市瀬戸田町荻', '34', '34205', '7222403', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '瀬戸田町荻', 'セトダチョウオギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市瀬戸田町垂水', '34', '34205', '7222404', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '瀬戸田町垂水', 'セトダチョウタルミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市瀬戸田町福田', '34', '34205', '7222405', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '瀬戸田町福田', 'セトダチョウフクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市瀬戸田町瀬戸田', '34', '34205', '7222411', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '瀬戸田町瀬戸田', 'セトダチョウセトダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市瀬戸田町高根', '34', '34205', '7222412', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '瀬戸田町高根', 'セトダチョウコウネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市瀬戸田町沢', '34', '34205', '7222413', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '瀬戸田町沢', 'セトダチョウサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市瀬戸田町鹿田原', '34', '34205', '7222414', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '瀬戸田町鹿田原', 'セトダチョウシカタハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市瀬戸田町中野', '34', '34205', '7222415', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '瀬戸田町中野', 'セトダチョウナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市瀬戸田町林', '34', '34205', '7222416', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '瀬戸田町林', 'セトダチョウハヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市瀬戸田町名荷', '34', '34205', '7222417', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '瀬戸田町名荷', 'セトダチョウミョウガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市因島洲江町', '34', '34205', '7222431', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '因島洲江町', 'インノシマスノエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市因島原町', '34', '34205', '7222432', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '因島原町', 'インノシマハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市内海町イ', '34', '34207', '7222631', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '内海町イ', 'ウツミチョウイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市内海町ロ', '34', '34207', '7222632', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '内海町ロ', 'ウツミチョウロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市内海町ハ', '34', '34207', '7222633', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '内海町ハ', 'ウツミチョウハ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市内海町', '34', '34207', '7222641', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '内海町', 'ウツミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市', '34', '34204', '7230000', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('90430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市深町', '34', '34204', '7230001', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '深町', 'フカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市中之町南', '34', '34204', '7230002', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '中之町南', 'ナカノチョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市中之町', '34', '34204', '7230003', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '中之町', 'ナカノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市館町', '34', '34204', '7230004', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '館町', 'ヤカタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市桜山町', '34', '34204', '7230005', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '桜山町', 'サクラヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市駒ケ原町', '34', '34204', '7230006', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '駒ケ原町', 'コマガハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市中之町北', '34', '34204', '7230007', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '中之町北', 'ナカノチョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市東町', '34', '34204', '7230011', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '東町', 'ヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市旭町', '34', '34204', '7230012', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '旭町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市古浜', '34', '34204', '7230013', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '古浜', 'コハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市城町', '34', '34204', '7230014', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '城町', 'シロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市円一町', '34', '34204', '7230015', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '円一町', 'エンイチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市宮沖', '34', '34204', '7230016', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '宮沖', 'ミヤオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市港町', '34', '34204', '7230017', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '港町', 'ミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市鷺浦町須波', '34', '34204', '7230021', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '鷺浦町須波', 'サギウラチョウスナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市鷺浦町向田野浦', '34', '34204', '7230022', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '鷺浦町向田野浦', 'サギウラチョウムコウタノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市須波町', '34', '34204', '7230031', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '須波町', 'スナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市須波西町', '34', '34204', '7230032', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '須波西町', 'スナミニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市沖浦町', '34', '34204', '7230033', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '沖浦町', 'オキウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市登町', '34', '34204', '7230034', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '登町', 'ノボリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市和田', '34', '34204', '7230041', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '和田', 'ワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市和田沖町', '34', '34204', '7230042', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '和田沖町', 'ワダオキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市貝野町', '34', '34204', '7230043', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '貝野町', 'カイノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市宗郷', '34', '34204', '7230044', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '宗郷', 'ソウゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市田野浦', '34', '34204', '7230045', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '田野浦', 'タノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市明神', '34', '34204', '7230046', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '明神', 'ミョウジン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市青葉台', '34', '34204', '7230047', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '青葉台', 'アオバダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市宮浦', '34', '34204', '7230051', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '宮浦', 'ミヤウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市皆実', '34', '34204', '7230052', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '皆実', 'ミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市学園町', '34', '34204', '7230053', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '学園町', 'ガクエンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市頼兼', '34', '34204', '7230054', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '頼兼', 'ヨリカネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市八坂町', '34', '34204', '7230061', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '八坂町', 'ヤサカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市本町', '34', '34204', '7230062', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市西町', '34', '34204', '7230063', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '西町', 'ニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市西宮', '34', '34204', '7230064', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '西宮', 'ニシミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市西野', '34', '34204', '7230065', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '西野', 'ニシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市大畑町', '34', '34204', '7230066', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '大畑町', 'オオハタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市小坂町', '34', '34204', '7230131', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '小坂町', 'オサカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市長谷', '34', '34204', '7230132', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '長谷', 'ナガタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市長谷町', '34', '34204', '7230132', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '長谷町', 'ナガタニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市沼田', '34', '34204', '7230133', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '沼田', 'ヌタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市沼田町', '34', '34204', '7230133', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '沼田町', 'ヌタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市新倉', '34', '34204', '7230134', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '新倉', 'シンクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市新倉町', '34', '34204', '7230134', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '新倉町', 'シンクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市沼田東町両名', '34', '34204', '7230141', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '沼田東町両名', 'ヌタヒガシチョウリョウミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市沼田東町末光', '34', '34204', '7230142', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '沼田東町末光', 'ヌタヒガシチョウスエミツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市沼田東町釜山', '34', '34204', '7230143', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '沼田東町釜山', 'ヌタヒガシチョウカマヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市沼田東町末広', '34', '34204', '7230144', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '沼田東町末広', 'ヌタヒガシチョウスエヒロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市沼田東町片島', '34', '34204', '7230145', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '沼田東町片島', 'ヌタヒガシチョウカタシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市沼田東町納所', '34', '34204', '7230146', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '沼田東町納所', 'ヌタヒガシチョウノウソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市沼田東町本市', '34', '34204', '7230147', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '沼田東町本市', 'ヌタヒガシチョウホンイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市沼田東町七宝', '34', '34204', '7230148', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '沼田東町七宝', 'ヌタヒガシチョウシッポウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県竹原市', '34', '34203', '7250000', '広島県', 'ヒロシマケン', '竹原市', 'タケハラシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('90494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県竹原市田万里町', '34', '34203', '7250001', '広島県', 'ヒロシマケン', '竹原市', 'タケハラシ', '田万里町', 'タマリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県竹原市西野町', '34', '34203', '7250002', '広島県', 'ヒロシマケン', '竹原市', 'タケハラシ', '西野町', 'ニシノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県竹原市新庄町', '34', '34203', '7250003', '広島県', 'ヒロシマケン', '竹原市', 'タケハラシ', '新庄町', 'シンジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県竹原市東野町', '34', '34203', '7250004', '広島県', 'ヒロシマケン', '竹原市', 'タケハラシ', '東野町', 'ヒガシノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県竹原市仁賀町', '34', '34203', '7250005', '広島県', 'ヒロシマケン', '竹原市', 'タケハラシ', '仁賀町', 'ニカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県竹原市小梨町', '34', '34203', '7250011', '広島県', 'ヒロシマケン', '竹原市', 'タケハラシ', '小梨町', 'オナシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県竹原市下野町', '34', '34203', '7250012', '広島県', 'ヒロシマケン', '竹原市', 'タケハラシ', '下野町', 'シモノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県竹原市吉名町', '34', '34203', '7250013', '広島県', 'ヒロシマケン', '竹原市', 'タケハラシ', '吉名町', 'ヨシナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県竹原市竹原町', '34', '34203', '7250021', '広島県', 'ヒロシマケン', '竹原市', 'タケハラシ', '竹原町', 'タケハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県竹原市本町', '34', '34203', '7250022', '広島県', 'ヒロシマケン', '竹原市', 'タケハラシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県竹原市田ノ浦', '34', '34203', '7250023', '広島県', 'ヒロシマケン', '竹原市', 'タケハラシ', '田ノ浦', 'タノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県竹原市港町', '34', '34203', '7250024', '広島県', 'ヒロシマケン', '竹原市', 'タケハラシ', '港町', 'ミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県竹原市塩町', '34', '34203', '7250025', '広島県', 'ヒロシマケン', '竹原市', 'タケハラシ', '塩町', 'シオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県竹原市中央', '34', '34203', '7250026', '広島県', 'ヒロシマケン', '竹原市', 'タケハラシ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県豊田郡大崎上島町', '34', '34431', '7250200', '広島県', 'ヒロシマケン', '豊田郡大崎上島町', 'トヨタグンオオサキカミジマチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('90509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県豊田郡大崎上島町東野', '34', '34431', '7250231', '広島県', 'ヒロシマケン', '豊田郡大崎上島町', 'トヨタグンオオサキカミジマチョウ', '東野', 'ヒガシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県豊田郡大崎上島町中野', '34', '34431', '7250301', '広島県', 'ヒロシマケン', '豊田郡大崎上島町', 'トヨタグンオオサキカミジマチョウ', '中野', 'ナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県豊田郡大崎上島町原田', '34', '34431', '7250302', '広島県', 'ヒロシマケン', '豊田郡大崎上島町', 'トヨタグンオオサキカミジマチョウ', '原田', 'ハラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県豊田郡大崎上島町大串', '34', '34431', '7250303', '広島県', 'ヒロシマケン', '豊田郡大崎上島町', 'トヨタグンオオサキカミジマチョウ', '大串', 'オオクシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県豊田郡大崎上島町木江', '34', '34431', '7250401', '広島県', 'ヒロシマケン', '豊田郡大崎上島町', 'トヨタグンオオサキカミジマチョウ', '木江', 'キノエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県豊田郡大崎上島町沖浦', '34', '34431', '7250402', '広島県', 'ヒロシマケン', '豊田郡大崎上島町', 'トヨタグンオオサキカミジマチョウ', '沖浦', 'オキウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県豊田郡大崎上島町明石', '34', '34431', '7250403', '広島県', 'ヒロシマケン', '豊田郡大崎上島町', 'トヨタグンオオサキカミジマチョウ', '明石', 'アカシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県府中市', '34', '34208', '7260000', '広島県', 'ヒロシマケン', '府中市', 'フチュウシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('90519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県府中市本山町', '34', '34208', '7260001', '広島県', 'ヒロシマケン', '府中市', 'フチュウシ', '本山町', 'モトヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県府中市鵜飼町', '34', '34208', '7260002', '広島県', 'ヒロシマケン', '府中市', 'フチュウシ', '鵜飼町', 'ウカイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県府中市元町', '34', '34208', '7260003', '広島県', 'ヒロシマケン', '府中市', 'フチュウシ', '元町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県府中市府川町', '34', '34208', '7260004', '広島県', 'ヒロシマケン', '府中市', 'フチュウシ', '府川町', 'フカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県府中市府中町', '34', '34208', '7260005', '広島県', 'ヒロシマケン', '府中市', 'フチュウシ', '府中町', 'フチュウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県府中市桜が丘', '34', '34208', '7260006', '広島県', 'ヒロシマケン', '府中市', 'フチュウシ', '桜が丘', 'サクラガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県府中市広谷町', '34', '34208', '7260011', '広島県', 'ヒロシマケン', '府中市', 'フチュウシ', '広谷町', 'ヒロタニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県府中市中須町', '34', '34208', '7260012', '広島県', 'ヒロシマケン', '府中市', 'フチュウシ', '中須町', 'ナカズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県府中市高木町', '34', '34208', '7260013', '広島県', 'ヒロシマケン', '府中市', 'フチュウシ', '高木町', 'タカギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県府中市土生町', '34', '34208', '7260021', '広島県', 'ヒロシマケン', '府中市', 'フチュウシ', '土生町', 'ハブチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県府中市用土町', '34', '34208', '7260022', '広島県', 'ヒロシマケン', '府中市', 'フチュウシ', '用土町', 'ヨウドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県府中市栗柄町', '34', '34208', '7260023', '広島県', 'ヒロシマケン', '府中市', 'フチュウシ', '栗柄町', 'クリガラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県府中市僧殿町', '34', '34208', '7260024', '広島県', 'ヒロシマケン', '府中市', 'フチュウシ', '僧殿町', 'ソウドノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県府中市河南町', '34', '34208', '7260025', '広島県', 'ヒロシマケン', '府中市', 'フチュウシ', '河南町', 'カナンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県府中市三郎丸町', '34', '34208', '7260026', '広島県', 'ヒロシマケン', '府中市', 'フチュウシ', '三郎丸町', 'サブロウマルチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県府中市篠根町', '34', '34208', '7260027', '広島県', 'ヒロシマケン', '府中市', 'フチュウシ', '篠根町', 'シノネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県府中市荒谷町', '34', '34208', '7260031', '広島県', 'ヒロシマケン', '府中市', 'フチュウシ', '荒谷町', 'アラタニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県府中市出口町', '34', '34208', '7260032', '広島県', 'ヒロシマケン', '府中市', 'フチュウシ', '出口町', 'デグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県府中市目崎町', '34', '34208', '7260033', '広島県', 'ヒロシマケン', '府中市', 'フチュウシ', '目崎町', 'メサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県府中市上山町', '34', '34208', '7260034', '広島県', 'ヒロシマケン', '府中市', 'フチュウシ', '上山町', 'ウヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県府中市父石町', '34', '34208', '7260035', '広島県', 'ヒロシマケン', '府中市', 'フチュウシ', '父石町', 'チイシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県府中市河面町', '34', '34208', '7260036', '広島県', 'ヒロシマケン', '府中市', 'フチュウシ', '河面町', 'コウモチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市', '34', '34210', '7270000', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('90554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市大久保町', '34', '34210', '7270001', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '大久保町', 'オオクボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市高門町', '34', '34210', '7270002', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '高門町', 'タカカドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市是松町', '34', '34210', '7270003', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '是松町', 'コレマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市新庄町', '34', '34210', '7270004', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '新庄町', 'シンジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市川手町', '34', '34210', '7270005', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '川手町', 'カワテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市本町', '34', '34210', '7270006', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市宮内町', '34', '34210', '7270007', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '宮内町', 'ミヤウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市永末町', '34', '34210', '7270008', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '永末町', 'ナガスエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市東本町', '34', '34210', '7270011', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '東本町', 'ヒガシホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市中本町', '34', '34210', '7270012', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '中本町', 'ナカホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市西本町', '34', '34210', '7270013', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '西本町', 'ニシホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市板橋町', '34', '34210', '7270014', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '板橋町', 'イタバシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市実留町', '34', '34210', '7270015', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '実留町', 'サネドメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市一木町', '34', '34210', '7270016', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '一木町', 'ヒトツギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市戸郷町', '34', '34210', '7270017', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '戸郷町', 'トゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市三日市町', '34', '34210', '7270021', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '三日市町', 'ミッカイチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市上原町', '34', '34210', '7270022', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '上原町', 'カミハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市七塚町', '34', '34210', '7270023', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '七塚町', 'ナナツカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市田原町', '34', '34210', '7270024', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '田原町', 'タワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市市町', '34', '34210', '7270025', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '市町', 'イチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市掛田町', '34', '34210', '7270026', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '掛田町', 'カケダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市口和町湯木', '34', '34210', '7270111', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '口和町湯木', 'クチワチョウユキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市口和町金田', '34', '34210', '7270112', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '口和町金田', 'クチワチョウキンデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市口和町常定', '34', '34210', '7270113', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '口和町常定', 'クチワチョウツネサダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市口和町永田', '34', '34210', '7270114', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '口和町永田', 'クチワチョウナガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市門田町', '34', '34210', '7270201', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '門田町', 'モンデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市濁川町', '34', '34210', '7270202', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '濁川町', 'ニゴリカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市川北町', '34', '34210', '7270203', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '川北町', 'カワキタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市比和町比和', '34', '34210', '7270301', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '比和町比和', 'ヒワチョウヒワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市比和町古頃', '34', '34210', '7270302', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '比和町古頃', 'ヒワチョウコゴロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市比和町三河内', '34', '34210', '7270311', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '比和町三河内', 'ヒワチョウミツガイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市比和町木屋原', '34', '34210', '7270312', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '比和町木屋原', 'ヒワチョウコヤバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市比和町森脇', '34', '34210', '7270321', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '比和町森脇', 'ヒワチョウモリワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市高野町和南原', '34', '34210', '7270401', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '高野町和南原', 'タカノチョウワナンバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市高野町新市', '34', '34210', '7270402', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '高野町新市', 'タカノチョウシンイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市高野町岡大内', '34', '34210', '7270403', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '高野町岡大内', 'タカノチョウオカオオウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市高野町上湯川', '34', '34210', '7270411', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '高野町上湯川', 'タカノチョウカミユカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市高野町下湯川', '34', '34210', '7270412', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '高野町下湯川', 'タカノチョウシモユカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市高野町南', '34', '34210', '7270413', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '高野町南', 'タカノチョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市高野町中門田', '34', '34210', '7270421', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '高野町中門田', 'タカノチョウナカモンデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市高野町奥門田', '34', '34210', '7270422', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '高野町奥門田', 'タカノチョウオクモンデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市高野町下門田', '34', '34210', '7270423', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '高野町下門田', 'タカノチョウシモンデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市高野町高暮', '34', '34210', '7270424', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '高野町高暮', 'タカノチョウコウボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市高野町上里原', '34', '34210', '7270425', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '高野町上里原', 'タカノチョウアガリハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市春田町', '34', '34210', '7270621', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '春田町', 'シュンダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市峰田町', '34', '34210', '7270622', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '峰田町', 'ミネタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市本村町', '34', '34210', '7270623', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '本村町', 'ホンムラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市上谷町', '34', '34210', '7270624', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '上谷町', 'ウエダニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市', '34', '34209', '7280000', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('90604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市山家町', '34', '34209', '7280001', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '山家町', 'ヤマガマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市西河内町', '34', '34209', '7280002', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '西河内町', 'ニシコウチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市東河内町', '34', '34209', '7280003', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '東河内町', 'ヒガシコウチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市穴笠町', '34', '34209', '7280004', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '穴笠町', 'アナガサマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市後山町', '34', '34209', '7280005', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '後山町', 'ウシロヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市畠敷町', '34', '34209', '7280006', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '畠敷町', 'ハタジキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市小文町', '34', '34209', '7280007', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '小文町', 'オブミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市十日市西', '34', '34209', '7280011', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '十日市西', 'トオカイチニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市十日市中', '34', '34209', '7280012', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '十日市中', 'トオカイチナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市十日市東', '34', '34209', '7280013', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '十日市東', 'トオカイチヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市十日市南', '34', '34209', '7280014', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '十日市南', 'トオカイチミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市十日市町', '34', '34209', '7280015', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '十日市町', 'トオカイチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市四拾貫町', '34', '34209', '7280016', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '四拾貫町', 'シジツカンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市南畑敷町', '34', '34209', '7280017', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '南畑敷町', 'ミナミハタジキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市三次町', '34', '34209', '7280021', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '三次町', 'ミヨシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市西酒屋町', '34', '34209', '7280022', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '西酒屋町', 'ニシサケヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市東酒屋町', '34', '34209', '7280023', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '東酒屋町', 'ヒガシサケヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市青河町', '34', '34209', '7280024', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '青河町', 'アオガマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市粟屋町', '34', '34209', '7280025', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '粟屋町', 'アワヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市日下町', '34', '34209', '7280026', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '日下町', 'ヒゲマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市三原町', '34', '34209', '7280027', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '三原町', 'ミハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市作木町岡三渕', '34', '34209', '7280101', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '作木町岡三渕', 'サクギチョウオカミブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市作木町伊賀和志', '34', '34209', '7280111', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '作木町伊賀和志', 'サクギチョウイカワシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市作木町森山西', '34', '34209', '7280112', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '作木町森山西', 'サクギチョウモリヤマニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市作木町森山東', '34', '34209', '7280113', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '作木町森山東', 'サクギチョウモリヤマヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市作木町森山中', '34', '34209', '7280114', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '作木町森山中', 'サクギチョウモリヤマナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市作木町大津', '34', '34209', '7280115', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '作木町大津', 'サクギチョウオオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市作木町大畠', '34', '34209', '7280121', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '作木町大畠', 'サクギチョウオオバタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市作木町西野', '34', '34209', '7280122', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '作木町西野', 'サクギチョウニシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市作木町上作木', '34', '34209', '7280123', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '作木町上作木', 'サクギチョウカミサクギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市作木町下作木', '34', '34209', '7280124', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '作木町下作木', 'サクギチョウシモサクギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市作木町光守', '34', '34209', '7280125', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '作木町光守', 'サクギチョウミツモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市作木町香淀', '34', '34209', '7280131', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '作木町香淀', 'サクギチョウコウヨド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市作木町大山', '34', '34209', '7280132', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '作木町大山', 'サクギチョウオオヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市作木町門田', '34', '34209', '7280133', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '作木町門田', 'サクギチョウモンデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市布野町上布野', '34', '34209', '7280201', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '布野町上布野', 'フノチョウカミフノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市布野町下布野', '34', '34209', '7280202', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '布野町下布野', 'フノチョウシモフノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市布野町戸河内', '34', '34209', '7280203', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '布野町戸河内', 'フノチョウトゴウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市布野町横谷', '34', '34209', '7280211', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '布野町横谷', 'フノチョウヨコタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市君田町東入君', '34', '34209', '7280401', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '君田町東入君', 'キミタチョウヒガシイリギミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市君田町西入君', '34', '34209', '7280402', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '君田町西入君', 'キミタチョウニシイリギミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市君田町藤兼', '34', '34209', '7280403', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '君田町藤兼', 'キミタチョウフジカネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市君田町石原', '34', '34209', '7280404', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '君田町石原', 'キミタチョウイシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市君田町泉吉田', '34', '34209', '7280405', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '君田町泉吉田', 'キミタチョウイズミヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市君田町櫃田', '34', '34209', '7280406', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '君田町櫃田', 'キミタチョウヒツタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市君田町茂田', '34', '34209', '7280407', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '君田町茂田', 'キミタチョウモダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市口和町宮内', '34', '34210', '7280501', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '口和町宮内', 'クチワチョウミヤウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市口和町向泉', '34', '34210', '7280502', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '口和町向泉', 'クチワチョウムコウイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市口和町大月', '34', '34210', '7280503', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '口和町大月', 'クチワチョウオオツキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市口和町竹地谷', '34', '34210', '7280504', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '口和町竹地谷', 'クチワチョウタケチダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市三若町', '34', '34209', '7280621', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '三若町', 'ミワカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市海渡町', '34', '34209', '7280622', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '海渡町', 'ウトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市石原町', '34', '34209', '7280623', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '石原町', 'イシハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市上田町', '34', '34209', '7280624', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '上田町', 'ウエダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市有原町', '34', '34209', '7280625', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '有原町', 'アリハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市高西町川尻', '34', '34207', '7290101', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '高西町川尻', 'タカニシチョウカワジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市高西町真田', '34', '34207', '7290102', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '高西町真田', 'タカニシチョウサナダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市高西町南', '34', '34207', '7290103', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '高西町南', 'タカニシチョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市松永町', '34', '34207', '7290104', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '松永町', 'マツナガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市南松永町', '34', '34207', '7290105', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '南松永町', 'ミナミマツナガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市高西町', '34', '34207', '7290106', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '高西町', 'タカニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市今津町', '34', '34207', '7290111', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '今津町', 'イマヅチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市神村町', '34', '34207', '7290112', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '神村町', 'カムラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市宮前町', '34', '34207', '7290113', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '宮前町', 'ミヤマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市柳津町', '34', '34207', '7290114', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '柳津町', 'ヤナイヅチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市南今津町', '34', '34207', '7290115', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '南今津町', 'ミナミイマヅチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市高須町', '34', '34205', '7290141', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '高須町', 'タカスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県尾道市西藤町', '34', '34205', '7290142', '広島県', 'ヒロシマケン', '尾道市', 'オノミチシ', '西藤町', 'ニシフジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市東村町', '34', '34207', '7290251', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '東村町', 'ヒガシムラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市本郷町', '34', '34207', '7290252', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '本郷町', 'ホンゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市木原', '34', '34204', '7290321', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '木原', 'キハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市木原町', '34', '34204', '7290321', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '木原町', 'キハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市奥野山町', '34', '34204', '7290322', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '奥野山町', 'オクノヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市鉢ケ峰町', '34', '34204', '7290323', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '鉢ケ峰町', 'ハチガミネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市糸崎', '34', '34204', '7290324', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '糸崎', 'イトサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市糸崎南', '34', '34204', '7290329', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '糸崎南', 'イトサキミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市本郷町船木', '34', '34204', '7290411', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '本郷町船木', 'ホンゴウチョウフナキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市本郷町本郷', '34', '34204', '7290412', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '本郷町本郷', 'ホンゴウチョウホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市本郷町南方', '34', '34204', '7290413', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '本郷町南方', 'ホンゴウチョウミナミガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市本郷町下北方', '34', '34204', '7290414', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '本郷町下北方', 'ホンゴウチョウシモキタガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市本郷町上北方', '34', '34204', '7290415', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '本郷町上北方', 'ホンゴウチョウカミキタガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市本郷町善入寺', '34', '34204', '7290416', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '本郷町善入寺', 'ホンゴウチョウゼンニュウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市本郷南', '34', '34204', '7290417', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '本郷南', 'ホンゴウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市本郷北', '34', '34204', '7290418', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '本郷北', 'ホンゴウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市高坂町許山', '34', '34204', '7290471', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '高坂町許山', 'タカサカチョウモトヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市高坂町真良', '34', '34204', '7290472', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '高坂町真良', 'タカサカチョウシンラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市沼田西町小原', '34', '34204', '7290473', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '沼田西町小原', 'ヌタニシチョウオバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市沼田西町惣定', '34', '34204', '7290474', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '沼田西町惣定', 'ヌタニシチョウソウジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市沼田西町松江', '34', '34204', '7290475', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '沼田西町松江', 'ヌタニシチョウマツエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市大和町大草', '34', '34204', '7291211', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '大和町大草', 'ダイワチョウオオグサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市大和町姥ケ原', '34', '34204', '7291212', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '大和町姥ケ原', 'ダイワチョウウバガハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市大和町平坂', '34', '34204', '7291213', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '大和町平坂', 'ダイワチョウヒラサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市大和町和木', '34', '34204', '7291321', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '大和町和木', 'ダイワチョウワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市大和町箱川', '34', '34204', '7291322', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '大和町箱川', 'ダイワチョウハコガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市大和町大具', '34', '34204', '7291323', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '大和町大具', 'ダイワチョウオオグ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市大和町椋梨', '34', '34204', '7291331', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '大和町椋梨', 'ダイワチョウムクナシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市大和町上草井', '34', '34204', '7291332', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '大和町上草井', 'ダイワチョウカミグサイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市大和町下草井', '34', '34204', '7291333', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '大和町下草井', 'ダイワチョウシモグサイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市大和町蔵宗', '34', '34204', '7291401', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '大和町蔵宗', 'ダイワチョウクラムネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市大和町篠', '34', '34204', '7291402', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '大和町篠', 'ダイワチョウシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市大和町萩原', '34', '34204', '7291403', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '大和町萩原', 'ダイワチョウハイバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市大和町福田', '34', '34204', '7291404', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '大和町福田', 'ダイワチョウフクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市大和町上徳良', '34', '34204', '7291405', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '大和町上徳良', 'ダイワチョウカミトクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市大和町下徳良', '34', '34204', '7291406', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '大和町下徳良', 'ダイワチョウシモトクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市幸崎町久和喜', '34', '34204', '7292251', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '幸崎町久和喜', 'サイザキチョウクワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市幸崎町能地', '34', '34204', '7292252', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '幸崎町能地', 'サイザキチョウノウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市幸崎町渡瀬', '34', '34204', '7292253', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '幸崎町渡瀬', 'サイザキチョウワタセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県竹原市忠海町', '34', '34203', '7292311', '広島県', 'ヒロシマケン', '竹原市', 'タケハラシ', '忠海町', 'タダノウミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県竹原市福田町', '34', '34203', '7292312', '広島県', 'ヒロシマケン', '竹原市', 'タケハラシ', '福田町', 'フクダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県竹原市高崎町', '34', '34203', '7292313', '広島県', 'ヒロシマケン', '竹原市', 'タケハラシ', '高崎町', 'タカサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県竹原市忠海床浦', '34', '34203', '7292314', '広島県', 'ヒロシマケン', '竹原市', 'タケハラシ', '忠海床浦', 'タダノウミトコノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県竹原市忠海長浜', '34', '34203', '7292315', '広島県', 'ヒロシマケン', '竹原市', 'タケハラシ', '忠海長浜', 'タダノウミナガハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県竹原市忠海中町', '34', '34203', '7292316', '広島県', 'ヒロシマケン', '竹原市', 'タケハラシ', '忠海中町', 'タダノウミナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県竹原市忠海東町', '34', '34203', '7292317', '広島県', 'ヒロシマケン', '竹原市', 'タケハラシ', '忠海東町', 'タダノウミヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三原市小泉町', '34', '34204', '7292361', '広島県', 'ヒロシマケン', '三原市', 'ミハラシ', '小泉町', 'コイズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市新市町戸手', '34', '34207', '7293101', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '新市町戸手', 'シンイチチョウトデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市新市町相方', '34', '34207', '7293102', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '新市町相方', 'シンイチチョウサガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市新市町新市', '34', '34207', '7293103', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '新市町新市', 'シンイチチョウシンイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市新市町宮内', '34', '34207', '7293104', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '新市町宮内', 'シンイチチョウミヤウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市新市町下安井', '34', '34207', '7293105', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '新市町下安井', 'シンイチチョウシモヤスイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市新市町上安井', '34', '34207', '7293106', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '新市町上安井', 'シンイチチョウカミヤスイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市新市町常', '34', '34207', '7293107', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '新市町常', 'シンイチチョウツネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市新市町金丸', '34', '34207', '7293111', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '新市町金丸', 'シンイチチョウカネマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県福山市新市町藤尾', '34', '34207', '7293112', '広島県', 'ヒロシマケン', '福山市', 'フクヤマシ', '新市町藤尾', 'シンイチチョウフジオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県府中市斗升町', '34', '34208', '7293201', '広島県', 'ヒロシマケン', '府中市', 'フチュウシ', '斗升町', 'トマスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県府中市行縢町', '34', '34208', '7293202', '広島県', 'ヒロシマケン', '府中市', 'フチュウシ', '行縢町', 'ムカバキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県府中市木野山町', '34', '34208', '7293211', '広島県', 'ヒロシマケン', '府中市', 'フチュウシ', '木野山町', 'キノヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県府中市阿字町', '34', '34208', '7293212', '広島県', 'ヒロシマケン', '府中市', 'フチュウシ', '阿字町', 'アジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県府中市河佐町', '34', '34208', '7293221', '広島県', 'ヒロシマケン', '府中市', 'フチュウシ', '河佐町', 'カワサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県府中市久佐町', '34', '34208', '7293222', '広島県', 'ヒロシマケン', '府中市', 'フチュウシ', '久佐町', 'クサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県世羅郡世羅町小谷', '34', '34462', '7293301', '広島県', 'ヒロシマケン', '世羅郡世羅町', 'セラグンセラチョウ', '小谷', 'オタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県世羅郡世羅町川尻', '34', '34462', '7293302', '広島県', 'ヒロシマケン', '世羅郡世羅町', 'セラグンセラチョウ', '川尻', 'カワシリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県世羅郡世羅町東上原', '34', '34462', '7293303', '広島県', 'ヒロシマケン', '世羅郡世羅町', 'セラグンセラチョウ', '東上原', 'ヒガシウエハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県世羅郡世羅町赤屋', '34', '34462', '7293304', '広島県', 'ヒロシマケン', '世羅郡世羅町', 'セラグンセラチョウ', '赤屋', 'アカヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県世羅郡世羅町別迫', '34', '34462', '7293305', '広島県', 'ヒロシマケン', '世羅郡世羅町', 'セラグンセラチョウ', '別迫', 'ベッサコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県世羅郡世羅町青近', '34', '34462', '7293306', '広島県', 'ヒロシマケン', '世羅郡世羅町', 'セラグンセラチョウ', '青近', 'アオチカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県世羅郡世羅町伊尾', '34', '34462', '7293307', '広島県', 'ヒロシマケン', '世羅郡世羅町', 'セラグンセラチョウ', '伊尾', 'イオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県府中市上下町小塚', '34', '34208', '7293401', '広島県', 'ヒロシマケン', '府中市', 'フチュウシ', '上下町小塚', 'ジョウゲチョウオヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県府中市上下町小堀', '34', '34208', '7293402', '広島県', 'ヒロシマケン', '府中市', 'フチュウシ', '上下町小堀', 'ジョウゲチョウコホリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県府中市上下町階見', '34', '34208', '7293403', '広島県', 'ヒロシマケン', '府中市', 'フチュウシ', '上下町階見', 'ジョウゲチョウシナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県府中市上下町二森', '34', '34208', '7293404', '広島県', 'ヒロシマケン', '府中市', 'フチュウシ', '上下町二森', 'ジョウゲチョウフタモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県府中市上下町有福', '34', '34208', '7293405', '広島県', 'ヒロシマケン', '府中市', 'フチュウシ', '上下町有福', 'ジョウゲチョウアリフク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県府中市上下町井永', '34', '34208', '7293411', '広島県', 'ヒロシマケン', '府中市', 'フチュウシ', '上下町井永', 'ジョウゲチョウイナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県府中市上下町岡屋', '34', '34208', '7293412', '広島県', 'ヒロシマケン', '府中市', 'フチュウシ', '上下町岡屋', 'ジョウゲチョウオガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県府中市上下町水永', '34', '34208', '7293413', '広島県', 'ヒロシマケン', '府中市', 'フチュウシ', '上下町水永', 'ジョウゲチョウミズナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県府中市上下町佐倉', '34', '34208', '7293414', '広島県', 'ヒロシマケン', '府中市', 'フチュウシ', '上下町佐倉', 'ジョウゲチョウサクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県府中市上下町矢多田', '34', '34208', '7293415', '広島県', 'ヒロシマケン', '府中市', 'フチュウシ', '上下町矢多田', 'ジョウゲチョウヤタダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県府中市上下町深江', '34', '34208', '7293421', '広島県', 'ヒロシマケン', '府中市', 'フチュウシ', '上下町深江', 'ジョウゲチョウフカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県府中市上下町国留', '34', '34208', '7293422', '広島県', 'ヒロシマケン', '府中市', 'フチュウシ', '上下町国留', 'ジョウゲチョウクニドメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県府中市上下町矢野', '34', '34208', '7293423', '広島県', 'ヒロシマケン', '府中市', 'フチュウシ', '上下町矢野', 'ジョウゲチョウヤノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県府中市上下町松崎', '34', '34208', '7293424', '広島県', 'ヒロシマケン', '府中市', 'フチュウシ', '上下町松崎', 'ジョウゲチョウマツサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県府中市上下町上下', '34', '34208', '7293431', '広島県', 'ヒロシマケン', '府中市', 'フチュウシ', '上下町上下', 'ジョウゲチョウジョウゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県神石郡神石高原町高光', '34', '34545', '7293511', '広島県', 'ヒロシマケン', '神石郡神石高原町', 'ジンセキグンジンセキコウゲンチョウ', '高光', 'タカミツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県神石郡神石高原町草木', '34', '34545', '7293512', '広島県', 'ヒロシマケン', '神石郡神石高原町', 'ジンセキグンジンセキコウゲンチョウ', '草木', 'クサギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県神石郡神石高原町牧', '34', '34545', '7293513', '広島県', 'ヒロシマケン', '神石郡神石高原町', 'ジンセキグンジンセキコウゲンチョウ', '牧', 'マキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県神石郡神石高原町田頭', '34', '34545', '7293514', '広島県', 'ヒロシマケン', '神石郡神石高原町', 'ジンセキグンジンセキコウゲンチョウ', '田頭', 'タンドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県神石郡神石高原町福永', '34', '34545', '7293515', '広島県', 'ヒロシマケン', '神石郡神石高原町', 'ジンセキグンジンセキコウゲンチョウ', '福永', 'フクナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県神石郡神石高原町古川', '34', '34545', '7293516', '広島県', 'ヒロシマケン', '神石郡神石高原町', 'ジンセキグンジンセキコウゲンチョウ', '古川', 'フルカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県神石郡神石高原町相渡', '34', '34545', '7293601', '広島県', 'ヒロシマケン', '神石郡神石高原町', 'ジンセキグンジンセキコウゲンチョウ', '相渡', 'アイド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県神石郡神石高原町永野', '34', '34545', '7293602', '広島県', 'ヒロシマケン', '神石郡神石高原町', 'ジンセキグンジンセキコウゲンチョウ', '永野', 'ナガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市総領町黒目', '34', '34210', '7293701', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '総領町黒目', 'ソウリョウチョウクロメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市総領町亀谷', '34', '34210', '7293702', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '総領町亀谷', 'ソウリョウチョウカメダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市総領町下領家', '34', '34210', '7293703', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '総領町下領家', 'ソウリョウチョウシモリョウケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市総領町五箇', '34', '34210', '7293711', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '総領町五箇', 'ソウリョウチョウゴカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市総領町上領家', '34', '34210', '7293712', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '総領町上領家', 'ソウリョウチョウカミリョウケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市総領町中領家', '34', '34210', '7293713', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '総領町中領家', 'ソウリョウチョウナカリョウケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市総領町稲草', '34', '34210', '7293721', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '総領町稲草', 'ソウリョウチョウイナクサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市総領町木屋', '34', '34210', '7293722', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '総領町木屋', 'ソウリョウチョウキヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市甲奴町本郷', '34', '34209', '7294101', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '甲奴町本郷', 'コウヌチョウホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市甲奴町西野', '34', '34209', '7294102', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '甲奴町西野', 'コウヌチョウニシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市甲奴町小童', '34', '34209', '7294103', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '甲奴町小童', 'コウヌチョウヒチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市甲奴町宇賀', '34', '34209', '7294104', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '甲奴町宇賀', 'コウヌチョウウガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市甲奴町梶田', '34', '34209', '7294105', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '甲奴町梶田', 'コウヌチョウカジタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市甲奴町有田', '34', '34209', '7294106', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '甲奴町有田', 'コウヌチョウアリダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市甲奴町福田', '34', '34209', '7294111', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '甲奴町福田', 'コウヌチョウフクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市甲奴町抜湯', '34', '34209', '7294112', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '甲奴町抜湯', 'コウヌチョウヌクユ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市甲奴町太郎丸', '34', '34209', '7294113', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '甲奴町太郎丸', 'コウヌチョウタロウマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市吉舎町知和', '34', '34209', '7294201', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '吉舎町知和', 'キサチョウチワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市吉舎町上安田', '34', '34209', '7294202', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '吉舎町上安田', 'キサチョウカミヤスダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市吉舎町安田', '34', '34209', '7294203', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '吉舎町安田', 'キサチョウヤスダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市吉舎町三玉', '34', '34209', '7294204', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '吉舎町三玉', 'キサチョウミタマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市吉舎町海田原', '34', '34209', '7294205', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '吉舎町海田原', 'キサチョウカイダハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市吉舎町矢井', '34', '34209', '7294206', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '吉舎町矢井', 'キサチョウヤイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市吉舎町敷地', '34', '34209', '7294207', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '吉舎町敷地', 'キサチョウシキジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市吉舎町矢野地', '34', '34209', '7294208', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '吉舎町矢野地', 'キサチョウヤノチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市吉舎町吉舎', '34', '34209', '7294211', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '吉舎町吉舎', 'キサチョウキサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市吉舎町清綱', '34', '34209', '7294221', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '吉舎町清綱', 'キサチョウキヨツナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市吉舎町丸田', '34', '34209', '7294222', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '吉舎町丸田', 'キサチョウマルダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市吉舎町雲通', '34', '34209', '7294223', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '吉舎町雲通', 'キサチョウウヅイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市吉舎町辻', '34', '34209', '7294224', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '吉舎町辻', 'キサチョウツジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市吉舎町徳市', '34', '34209', '7294225', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '吉舎町徳市', 'キサチョウトクイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市吉舎町吉舎川之内', '34', '34209', '7294226', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '吉舎町吉舎川之内', 'キサチョウキサカワノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市吉舎町檜', '34', '34209', '7294227', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '吉舎町檜', 'キサチョウヒノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市三良坂町光清', '34', '34209', '7294301', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '三良坂町光清', 'ミラサカチョウミツキヨ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市三良坂町仁賀', '34', '34209', '7294302', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '三良坂町仁賀', 'ミラサカチョウニカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市三良坂町灰塚', '34', '34209', '7294303', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '三良坂町灰塚', 'ミラサカチョウハイヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市三良坂町三良坂', '34', '34209', '7294304', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '三良坂町三良坂', 'ミラサカチョウミラサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市三良坂町長田', '34', '34209', '7294305', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '三良坂町長田', 'ミラサカチョウナガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市三良坂町岡田', '34', '34209', '7294306', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '三良坂町岡田', 'ミラサカチョウオカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市三良坂町皆瀬', '34', '34209', '7294307', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '三良坂町皆瀬', 'ミラサカチョウカイゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市三良坂町田利', '34', '34209', '7294308', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '三良坂町田利', 'ミラサカチョウタリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市東城町福代', '34', '34210', '7295111', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '東城町福代', 'トウジョウチョウフクシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市東城町新福代', '34', '34210', '7295112', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '東城町新福代', 'トウジョウチョウシンフクシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市東城町川東', '34', '34210', '7295121', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '東城町川東', 'トウジョウチョウカワヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市東城町久代', '34', '34210', '7295122', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '東城町久代', 'トウジョウチョウクシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市東城町戸宇', '34', '34210', '7295123', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '東城町戸宇', 'トウジョウチョウトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市東城町東城', '34', '34210', '7295124', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '東城町東城', 'トウジョウチョウトウジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市東城町川西', '34', '34210', '7295125', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '東城町川西', 'トウジョウチョウカワニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市東城町竹森', '34', '34210', '7295126', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '東城町竹森', 'トウジョウチョウタケモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市東城町粟田', '34', '34210', '7295127', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '東城町粟田', 'トウジョウチョウアワタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市東城町受原隠地', '34', '34210', '7295128', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '東城町受原', 'トウジョウチョウウケバラ', null, null, '隠地', 'オンジ');
INSERT INTO `ms_addresses` VALUES ('90839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市東城町受原中ノ谷', '34', '34210', '7295128', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '東城町受原', 'トウジョウチョウウケバラ', null, null, '中ノ谷', 'ナカノタニ');
INSERT INTO `ms_addresses` VALUES ('90840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市東城町新免', '34', '34210', '7295131', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '東城町新免', 'トウジョウチョウシンメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市東城町三坂', '34', '34210', '7295132', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '東城町三坂', 'トウジョウチョウミサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市東城町帝釈宇山', '34', '34210', '7295241', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '東城町帝釈宇山', 'トウジョウチョウタイシャクウヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市東城町帝釈山中', '34', '34210', '7295242', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '東城町帝釈山中', 'トウジョウチョウタイシャクヤマナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市東城町帝釈始終', '34', '34210', '7295243', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '東城町帝釈始終', 'トウジョウチョウタイシャクシシュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市東城町帝釈未渡', '34', '34210', '7295244', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '東城町帝釈未渡', 'トウジョウチョウタイシャクミド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市東城町田黒', '34', '34210', '7295451', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '東城町田黒', 'トウジョウチョウタグロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市東城町菅', '34', '34210', '7295452', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '東城町菅', 'トウジョウチョウスゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市東城町受原', '34', '34210', '7295453', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '東城町受原', 'トウジョウチョウウケバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市東城町川鳥', '34', '34210', '7295454', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '東城町川鳥', 'トウジョウチョウカワトリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市東城町保田', '34', '34210', '7295455', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '東城町保田', 'トウジョウチョウヤスダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市東城町森', '34', '34210', '7295456', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '東城町森', 'トウジョウチョウモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市東城町小奴可', '34', '34210', '7295501', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '東城町小奴可', 'トウジョウチョウオヌカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市東城町内堀', '34', '34210', '7295502', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '東城町内堀', 'トウジョウチョウウツボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市東城町千鳥', '34', '34210', '7295503', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '東城町千鳥', 'トウジョウチョウチドリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市東城町小串', '34', '34210', '7295504', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '東城町小串', 'トウジョウチョウオグシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市東城町塩原', '34', '34210', '7295505', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '東城町塩原', 'トウジョウチョウシオハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市東城町加谷', '34', '34210', '7295506', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '東城町加谷', 'トウジョウチョウカダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市西城町小鳥原', '34', '34210', '7295601', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '西城町小鳥原', 'サイジョウチョウヒトトバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市西城町油木', '34', '34210', '7295602', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '西城町油木', 'サイジョウチョウユキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市西城町熊野落合', '34', '34210', '7295603', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '西城町熊野', 'サイジョウチョウクマノ', null, null, '落合', 'オチアイ');
INSERT INTO `ms_addresses` VALUES ('90861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市西城町熊野上梶谷', '34', '34210', '7295603', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '西城町熊野', 'サイジョウチョウクマノ', null, null, '上梶谷', 'カミカジダニ');
INSERT INTO `ms_addresses` VALUES ('90862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市西城町熊野下梶谷', '34', '34210', '7295603', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '西城町熊野', 'サイジョウチョウクマノ', null, null, '下梶谷', 'シモカジダニ');
INSERT INTO `ms_addresses` VALUES ('90863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市西城町熊野明賀', '34', '34210', '7295603', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '西城町熊野', 'サイジョウチョウクマノ', null, null, '明賀', 'ミョウガ');
INSERT INTO `ms_addresses` VALUES ('90864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市西城町三坂', '34', '34210', '7295611', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '西城町三坂', 'サイジョウチョウミサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市西城町高尾', '34', '34210', '7295612', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '西城町高尾', 'サイジョウチョウコウオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市西城町八鳥石塚', '34', '34210', '7295613', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '西城町八鳥', 'サイジョウチョウハットリ', null, null, '石塚', 'イシヅカ');
INSERT INTO `ms_addresses` VALUES ('90867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市西城町八鳥落合駅前', '34', '34210', '7295613', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '西城町八鳥', 'サイジョウチョウハットリ', null, null, '落合駅前', 'オチアイエキマエ');
INSERT INTO `ms_addresses` VALUES ('90868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市西城町八鳥杉ノ原', '34', '34210', '7295613', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '西城町八鳥', 'サイジョウチョウハットリ', null, null, '杉ノ原', 'スギノハラ');
INSERT INTO `ms_addresses` VALUES ('90869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市西城町八鳥二重坂', '34', '34210', '7295613', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '西城町八鳥', 'サイジョウチョウハットリ', null, null, '二重坂', 'ニジュウザカ');
INSERT INTO `ms_addresses` VALUES ('90870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市西城町八鳥明賀', '34', '34210', '7295613', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '西城町八鳥', 'サイジョウチョウハットリ', null, null, '明賀', 'ミョウガ');
INSERT INTO `ms_addresses` VALUES ('90871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市西城町八鳥', '34', '34210', '7295721', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '西城町八鳥', 'サイジョウチョウハットリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市西城町大佐', '34', '34210', '7295722', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '西城町大佐', 'サイジョウチョウオオサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市西城町平子', '34', '34210', '7295723', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '西城町平子', 'サイジョウチョウヒラコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市西城町西城', '34', '34210', '7295731', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '西城町西城', 'サイジョウチョウサイジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市西城町栗', '34', '34210', '7295732', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '西城町栗', 'サイジョウチョウクリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市西城町入江', '34', '34210', '7295733', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '西城町入江', 'サイジョウチョウイリエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市西城町熊野', '34', '34210', '7295741', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '西城町熊野', 'サイジョウチョウクマノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市西城町中野', '34', '34210', '7295742', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '西城町中野', 'サイジョウチョウナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市西城町中迫', '34', '34210', '7295743', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '西城町中迫', 'サイジョウチョウナカザコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市西城町大屋', '34', '34210', '7295744', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '西城町大屋', 'サイジョウチョウオオヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市西城町福山', '34', '34210', '7295745', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '西城町福山', 'サイジョウチョウフクヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市高町', '34', '34210', '7295811', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '高町', 'タカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市小用町', '34', '34210', '7295812', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '小用町', 'オヨウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市川西町', '34', '34210', '7295813', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '川西町', 'カワニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市山内町', '34', '34210', '7296131', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '山内町', 'ヤマノウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市本郷町', '34', '34210', '7296132', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '本郷町', 'ホンゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市殿垣内町', '34', '34210', '7296133', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '殿垣内町', 'トノゴウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市木戸町', '34', '34210', '7296134', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '木戸町', 'キドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市水越町', '34', '34210', '7296141', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '水越町', 'ミズコシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市高茂町', '34', '34210', '7296142', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '高茂町', 'コウモチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市尾引町', '34', '34210', '7296143', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '尾引町', 'オビキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県庄原市平和町', '34', '34210', '7296144', '広島県', 'ヒロシマケン', '庄原市', 'ショウバラシ', '平和町', 'ヘイワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市和知町', '34', '34209', '7296201', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '和知町', 'ワチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市向江田町', '34', '34209', '7296202', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '向江田町', 'ムコウエタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市志幸町', '34', '34209', '7296203', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '志幸町', 'シコウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市木乗町', '34', '34209', '7296204', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '木乗町', 'キノリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市塩町', '34', '34209', '7296205', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '塩町', 'シオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市大田幸町', '34', '34209', '7296211', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '大田幸町', 'オオダコウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市糸井町', '34', '34209', '7296212', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '糸井町', 'イトイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市廻神町', '34', '34209', '7296213', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '廻神町', 'メグリカミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市高杉町', '34', '34209', '7296214', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '高杉町', 'タカスギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市江田川之内町', '34', '34209', '7296215', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '江田川之内町', 'エタカワノウチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市小田幸町', '34', '34209', '7296216', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '小田幸町', 'コダコウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市下志和地町', '34', '34209', '7296331', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '下志和地町', 'シモシワチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市上志和地町', '34', '34209', '7296332', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '上志和地町', 'カミシワチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市下川立町', '34', '34209', '7296333', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '下川立町', 'シモカワタチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市上川立町', '34', '34209', '7296334', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '上川立町', 'カミカワタチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市秋町', '34', '34209', '7296335', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '秋町', 'アキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市三和町福田', '34', '34209', '7296611', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '三和町福田', 'ミワチョウフクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市三和町敷名鉾畦', '34', '34209', '7296612', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '三和町敷名', 'ミワチョウシキナ', null, null, '鉾畦', 'ホコノウネ');
INSERT INTO `ms_addresses` VALUES ('90912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市三和町下板木', '34', '34209', '7296612', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '三和町下板木', 'ミワチョウシモイタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市三和町有原', '34', '34209', '7296613', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '三和町有原', 'ミワチョウアリハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市三和町羽出庭', '34', '34209', '7296614', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '三和町羽出庭', 'ミワチョウハデニワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市三和町上板木', '34', '34209', '7296615', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '三和町上板木', 'ミワチョウカミイタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市三和町大力谷', '34', '34209', '7296616', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '三和町大力谷', 'ミワチョウダイリキダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市三和町飯田', '34', '34209', '7296701', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '三和町飯田', 'ミワチョウイイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市三和町上壱', '34', '34209', '7296701', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '三和町上壱', 'ミワチョウカミイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県三次市三和町敷名', '34', '34209', '7296702', '広島県', 'ヒロシマケン', '三次市', 'ミヨシシ', '三和町敷名', 'ミワチョウシキナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県世羅郡世羅町黒川', '34', '34462', '7296711', '広島県', 'ヒロシマケン', '世羅郡世羅町', 'セラグンセラチョウ', '黒川', 'クロガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県世羅郡世羅町吉原', '34', '34462', '7296712', '広島県', 'ヒロシマケン', '世羅郡世羅町', 'セラグンセラチョウ', '吉原', 'ヨシワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県世羅郡世羅町中', '34', '34462', '7296713', '広島県', 'ヒロシマケン', '世羅郡世羅町', 'セラグンセラチョウ', '中', 'ナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県世羅郡世羅町上津田', '34', '34462', '7296714', '広島県', 'ヒロシマケン', '世羅郡世羅町', 'セラグンセラチョウ', '上津田', 'カミヅタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県世羅郡世羅町下津田', '34', '34462', '7296715', '広島県', 'ヒロシマケン', '世羅郡世羅町', 'セラグンセラチョウ', '下津田', 'シモヅタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県世羅郡世羅町長田', '34', '34462', '7296716', '広島県', 'ヒロシマケン', '世羅郡世羅町', 'セラグンセラチョウ', '長田', 'ナガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道滝川市', '01', '01225', '0730000', '北海道', 'ホッカイドウ', '滝川市', 'タキカワシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('90927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市中区', '34', '34101', '7300000', '広島県', 'ヒロシマケン', '広島市中区', 'ヒロシマシナカク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('90928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市中区白島北町', '34', '34101', '7300001', '広島県', 'ヒロシマケン', '広島市中区', 'ヒロシマシナカク', '白島北町', 'ハクシマキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市中区白島中町', '34', '34101', '7300002', '広島県', 'ヒロシマケン', '広島市中区', 'ヒロシマシナカク', '白島中町', 'ハクシマナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市中区白島九軒町', '34', '34101', '7300003', '広島県', 'ヒロシマケン', '広島市中区', 'ヒロシマシナカク', '白島九軒町', 'ハクシマクケンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市中区東白島町', '34', '34101', '7300004', '広島県', 'ヒロシマケン', '広島市中区', 'ヒロシマシナカク', '東白島町', 'ヒガシハクシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市中区西白島町', '34', '34101', '7300005', '広島県', 'ヒロシマケン', '広島市中区', 'ヒロシマシナカク', '西白島町', 'ニシハクシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道滝川市北滝の川', '01', '01225', '0730001', '北海道', 'ホッカイドウ', '滝川市', 'タキカワシ', '北滝の川', 'キタタキノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市中区基町', '34', '34101', '7300011', '広島県', 'ヒロシマケン', '広島市中区', 'ヒロシマシナカク', '基町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市中区上八丁堀', '34', '34101', '7300012', '広島県', 'ヒロシマケン', '広島市中区', 'ヒロシマシナカク', '上八丁堀', 'カミハッチョウボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市中区八丁堀', '34', '34101', '7300013', '広島県', 'ヒロシマケン', '広島市中区', 'ヒロシマシナカク', '八丁堀', 'ハッチョウボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市中区上幟町', '34', '34101', '7300014', '広島県', 'ヒロシマケン', '広島市中区', 'ヒロシマシナカク', '上幟町', 'カミノボリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市中区橋本町', '34', '34101', '7300015', '広島県', 'ヒロシマケン', '広島市中区', 'ヒロシマシナカク', '橋本町', 'ハシモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市中区幟町', '34', '34101', '7300016', '広島県', 'ヒロシマケン', '広島市中区', 'ヒロシマシナカク', '幟町', 'ノボリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市中区鉄砲町', '34', '34101', '7300017', '広島県', 'ヒロシマケン', '広島市中区', 'ヒロシマシナカク', '鉄砲町', 'テッポウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道滝川市屯田町西', '01', '01225', '0730002', '北海道', 'ホッカイドウ', '滝川市', 'タキカワシ', '屯田町西', 'トンデンチョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市中区胡町', '34', '34101', '7300021', '広島県', 'ヒロシマケン', '広島市中区', 'ヒロシマシナカク', '胡町', 'エビスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市中区銀山町', '34', '34101', '7300022', '広島県', 'ヒロシマケン', '広島市中区', 'ヒロシマシナカク', '銀山町', 'カナヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市中区弥生町', '34', '34101', '7300023', '広島県', 'ヒロシマケン', '広島市中区', 'ヒロシマシナカク', '弥生町', 'ヤヨイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市中区西平塚町', '34', '34101', '7300024', '広島県', 'ヒロシマケン', '広島市中区', 'ヒロシマシナカク', '西平塚町', 'ニシヒラツカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市中区東平塚町', '34', '34101', '7300025', '広島県', 'ヒロシマケン', '広島市中区', 'ヒロシマシナカク', '東平塚町', 'ヒガシヒラツカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市中区田中町', '34', '34101', '7300026', '広島県', 'ヒロシマケン', '広島市中区', 'ヒロシマシナカク', '田中町', 'タナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市中区薬研堀', '34', '34101', '7300027', '広島県', 'ヒロシマケン', '広島市中区', 'ヒロシマシナカク', '薬研堀', 'ヤゲンボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市中区流川町', '34', '34101', '7300028', '広島県', 'ヒロシマケン', '広島市中区', 'ヒロシマシナカク', '流川町', 'ナガレカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市中区三川町', '34', '34101', '7300029', '広島県', 'ヒロシマケン', '広島市中区', 'ヒロシマシナカク', '三川町', 'ミカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道滝川市滝の川町西', '01', '01225', '0730003', '北海道', 'ホッカイドウ', '滝川市', 'タキカワシ', '滝の川町西', 'タキノカワチョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市中区紙屋町', '34', '34101', '7300031', '広島県', 'ヒロシマケン', '広島市中区', 'ヒロシマシナカク', '紙屋町', 'カミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市中区立町', '34', '34101', '7300032', '広島県', 'ヒロシマケン', '広島市中区', 'ヒロシマシナカク', '立町', 'タテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市中区堀川町', '34', '34101', '7300033', '広島県', 'ヒロシマケン', '広島市中区', 'ヒロシマシナカク', '堀川町', 'ホリカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市中区新天地', '34', '34101', '7300034', '広島県', 'ヒロシマケン', '広島市中区', 'ヒロシマシナカク', '新天地', 'シンテンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市中区本通', '34', '34101', '7300035', '広島県', 'ヒロシマケン', '広島市中区', 'ヒロシマシナカク', '本通', 'ホンドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市中区袋町', '34', '34101', '7300036', '広島県', 'ヒロシマケン', '広島市中区', 'ヒロシマシナカク', '袋町', 'フクロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市中区中町', '34', '34101', '7300037', '広島県', 'ヒロシマケン', '広島市中区', 'ヒロシマシナカク', '中町', 'ナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道滝川市滝の川町東', '01', '01225', '0730004', '北海道', 'ホッカイドウ', '滝川市', 'タキカワシ', '滝の川町東', 'タキノカワチョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市中区小町', '34', '34101', '7300041', '広島県', 'ヒロシマケン', '広島市中区', 'ヒロシマシナカク', '小町', 'コマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市中区国泰寺町', '34', '34101', '7300042', '広島県', 'ヒロシマケン', '広島市中区', 'ヒロシマシナカク', '国泰寺町', 'コクタイジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市中区富士見町', '34', '34101', '7300043', '広島県', 'ヒロシマケン', '広島市中区', 'ヒロシマシナカク', '富士見町', 'フジミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市中区宝町', '34', '34101', '7300044', '広島県', 'ヒロシマケン', '広島市中区', 'ヒロシマシナカク', '宝町', 'タカラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市中区鶴見町', '34', '34101', '7300045', '広島県', 'ヒロシマケン', '広島市中区', 'ヒロシマシナカク', '鶴見町', 'ツルミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市中区昭和町', '34', '34101', '7300046', '広島県', 'ヒロシマケン', '広島市中区', 'ヒロシマシナカク', '昭和町', 'ショウワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市中区平野町', '34', '34101', '7300047', '広島県', 'ヒロシマケン', '広島市中区', 'ヒロシマシナカク', '平野町', 'ヒラノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市中区竹屋町', '34', '34101', '7300048', '広島県', 'ヒロシマケン', '広島市中区', 'ヒロシマシナカク', '竹屋町', 'タケヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市中区南竹屋町', '34', '34101', '7300049', '広島県', 'ヒロシマケン', '広島市中区', 'ヒロシマシナカク', '南竹屋町', 'ミナミタケヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道滝川市二の坂町東', '01', '01225', '0730005', '北海道', 'ホッカイドウ', '滝川市', 'タキカワシ', '二の坂町東', 'ニノサカチョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市中区大手町', '34', '34101', '7300051', '広島県', 'ヒロシマケン', '広島市中区', 'ヒロシマシナカク', '大手町', 'オオテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市中区千田町', '34', '34101', '7300052', '広島県', 'ヒロシマケン', '広島市中区', 'ヒロシマシナカク', '千田町', 'センダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市中区東千田町', '34', '34101', '7300053', '広島県', 'ヒロシマケン', '広島市中区', 'ヒロシマシナカク', '東千田町', 'ヒガシセンダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市中区南千田東町', '34', '34101', '7300054', '広島県', 'ヒロシマケン', '広島市中区', 'ヒロシマシナカク', '南千田東町', 'ミナミセンダヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市中区南千田西町', '34', '34101', '7300055', '広島県', 'ヒロシマケン', '広島市中区', 'ヒロシマシナカク', '南千田西町', 'ミナミセンダニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道滝川市二の坂町西', '01', '01225', '0730006', '北海道', 'ホッカイドウ', '滝川市', 'タキカワシ', '二の坂町西', 'ニノサカチョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道滝川市黄金町西', '01', '01225', '0730011', '北海道', 'ホッカイドウ', '滝川市', 'タキカワシ', '黄金町西', 'コガネマチニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道滝川市黄金町東', '01', '01225', '0730012', '北海道', 'ホッカイドウ', '滝川市', 'タキカワシ', '黄金町東', 'コガネマチヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道滝川市南滝の川', '01', '01225', '0730013', '北海道', 'ホッカイドウ', '滝川市', 'タキカワシ', '南滝の川', 'ミナミタキノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道滝川市文京町', '01', '01225', '0730014', '北海道', 'ホッカイドウ', '滝川市', 'タキカワシ', '文京町', 'ブンキョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道滝川市朝日町東', '01', '01225', '0730015', '北海道', 'ホッカイドウ', '滝川市', 'タキカワシ', '朝日町東', 'アサヒマチヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道滝川市一の坂町東', '01', '01225', '0730016', '北海道', 'ホッカイドウ', '滝川市', 'タキカワシ', '一の坂町東', 'イチノサカチョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道滝川市一の坂町西', '01', '01225', '0730017', '北海道', 'ホッカイドウ', '滝川市', 'タキカワシ', '一の坂町西', 'イチノサカチョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道滝川市朝日町西', '01', '01225', '0730018', '北海道', 'ホッカイドウ', '滝川市', 'タキカワシ', '朝日町西', 'アサヒマチニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道滝川市本町', '01', '01225', '0730021', '北海道', 'ホッカイドウ', '滝川市', 'タキカワシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道滝川市大町', '01', '01225', '0730022', '北海道', 'ホッカイドウ', '滝川市', 'タキカワシ', '大町', 'オオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道滝川市緑町', '01', '01225', '0730023', '北海道', 'ホッカイドウ', '滝川市', 'タキカワシ', '緑町', 'ミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道滝川市東町', '01', '01225', '0730024', '北海道', 'ホッカイドウ', '滝川市', 'タキカワシ', '東町', 'ヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道滝川市流通団地', '01', '01225', '0730025', '北海道', 'ホッカイドウ', '滝川市', 'タキカワシ', '流通団地', 'リュウツウダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道滝川市東滝川', '01', '01225', '0730026', '北海道', 'ホッカイドウ', '滝川市', 'タキカワシ', '東滝川', 'ヒガシタキカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道滝川市東滝川町', '01', '01225', '0730027', '北海道', 'ホッカイドウ', '滝川市', 'タキカワシ', '東滝川町', 'ヒガシタキカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道滝川市栄町', '01', '01225', '0730031', '北海道', 'ホッカイドウ', '滝川市', 'タキカワシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道滝川市明神町', '01', '01225', '0730032', '北海道', 'ホッカイドウ', '滝川市', 'タキカワシ', '明神町', 'ミョウジンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道滝川市新町', '01', '01225', '0730033', '北海道', 'ホッカイドウ', '滝川市', 'タキカワシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道滝川市空知町', '01', '01225', '0730034', '北海道', 'ホッカイドウ', '滝川市', 'タキカワシ', '空知町', 'ソラチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道滝川市中島町', '01', '01225', '0730035', '北海道', 'ホッカイドウ', '滝川市', 'タキカワシ', '中島町', 'ナカジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道滝川市花月町', '01', '01225', '0730036', '北海道', 'ホッカイドウ', '滝川市', 'タキカワシ', '花月町', 'カゲツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道滝川市西滝川', '01', '01225', '0730041', '北海道', 'ホッカイドウ', '滝川市', 'タキカワシ', '西滝川', 'ニシタキカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道滝川市泉町', '01', '01225', '0730042', '北海道', 'ホッカイドウ', '滝川市', 'タキカワシ', '泉町', 'イズミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('90999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道滝川市幸町', '01', '01225', '0730043', '北海道', 'ホッカイドウ', '滝川市', 'タキカワシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道滝川市西町', '01', '01225', '0730044', '北海道', 'ホッカイドウ', '滝川市', 'タキカワシ', '西町', 'ニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道滝川市有明町', '01', '01225', '0730045', '北海道', 'ホッカイドウ', '滝川市', 'タキカワシ', '有明町', 'アリアケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道滝川市扇町', '01', '01225', '0730046', '北海道', 'ホッカイドウ', '滝川市', 'タキカワシ', '扇町', 'オウギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市中区寺町', '34', '34101', '7300801', '広島県', 'ヒロシマケン', '広島市中区', 'ヒロシマシナカク', '寺町', 'テラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市中区本川町', '34', '34101', '7300802', '広島県', 'ヒロシマケン', '広島市中区', 'ヒロシマシナカク', '本川町', 'ホンカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市中区広瀬北町', '34', '34101', '7300803', '広島県', 'ヒロシマケン', '広島市中区', 'ヒロシマシナカク', '広瀬北町', 'ヒロセキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市中区広瀬町', '34', '34101', '7300804', '広島県', 'ヒロシマケン', '広島市中区', 'ヒロシマシナカク', '広瀬町', 'ヒロセマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市中区十日市町', '34', '34101', '7300805', '広島県', 'ヒロシマケン', '広島市中区', 'ヒロシマシナカク', '十日市町', 'トウカイチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市中区西十日市町', '34', '34101', '7300806', '広島県', 'ヒロシマケン', '広島市中区', 'ヒロシマシナカク', '西十日市町', 'ニシトウカイチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市中区中島町', '34', '34101', '7300811', '広島県', 'ヒロシマケン', '広島市中区', 'ヒロシマシナカク', '中島町', 'ナカジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市中区加古町', '34', '34101', '7300812', '広島県', 'ヒロシマケン', '広島市中区', 'ヒロシマシナカク', '加古町', 'カコマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市中区住吉町', '34', '34101', '7300813', '広島県', 'ヒロシマケン', '広島市中区', 'ヒロシマシナカク', '住吉町', 'スミヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市中区羽衣町', '34', '34101', '7300814', '広島県', 'ヒロシマケン', '広島市中区', 'ヒロシマシナカク', '羽衣町', 'ハゴロモチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市中区吉島町', '34', '34101', '7300821', '広島県', 'ヒロシマケン', '広島市中区', 'ヒロシマシナカク', '吉島町', 'ヨシジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市中区吉島東', '34', '34101', '7300822', '広島県', 'ヒロシマケン', '広島市中区', 'ヒロシマシナカク', '吉島東', 'ヨシジマヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市中区吉島西', '34', '34101', '7300823', '広島県', 'ヒロシマケン', '広島市中区', 'ヒロシマシナカク', '吉島西', 'ヨシジマニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市中区吉島新町', '34', '34101', '7300824', '広島県', 'ヒロシマケン', '広島市中区', 'ヒロシマシナカク', '吉島新町', 'ヨシジマシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市中区光南', '34', '34101', '7300825', '広島県', 'ヒロシマケン', '広島市中区', 'ヒロシマシナカク', '光南', 'コウナン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市中区南吉島', '34', '34101', '7300826', '広島県', 'ヒロシマケン', '広島市中区', 'ヒロシマシナカク', '南吉島', 'ミナミヨシジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市中区江波西', '34', '34101', '7300831', '広島県', 'ヒロシマケン', '広島市中区', 'ヒロシマシナカク', '江波西', 'エバニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市中区江波東', '34', '34101', '7300832', '広島県', 'ヒロシマケン', '広島市中区', 'ヒロシマシナカク', '江波東', 'エバヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市中区江波本町', '34', '34101', '7300833', '広島県', 'ヒロシマケン', '広島市中区', 'ヒロシマシナカク', '江波本町', 'エバホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市中区江波二本松', '34', '34101', '7300834', '広島県', 'ヒロシマケン', '広島市中区', 'ヒロシマシナカク', '江波二本松', 'エバニホンマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市中区江波南', '34', '34101', '7300835', '広島県', 'ヒロシマケン', '広島市中区', 'ヒロシマシナカク', '江波南', 'エバミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市中区江波栄町', '34', '34101', '7300836', '広島県', 'ヒロシマケン', '広島市中区', 'ヒロシマシナカク', '江波栄町', 'エバサカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市中区江波沖町', '34', '34101', '7300837', '広島県', 'ヒロシマケン', '広島市中区', 'ヒロシマシナカク', '江波沖町', 'エバオキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市中区舟入町', '34', '34101', '7300841', '広島県', 'ヒロシマケン', '広島市中区', 'ヒロシマシナカク', '舟入町', 'フナイリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市中区舟入中町', '34', '34101', '7300842', '広島県', 'ヒロシマケン', '広島市中区', 'ヒロシマシナカク', '舟入中町', 'フナイリナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市中区舟入本町', '34', '34101', '7300843', '広島県', 'ヒロシマケン', '広島市中区', 'ヒロシマシナカク', '舟入本町', 'フナイリホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市中区舟入幸町', '34', '34101', '7300844', '広島県', 'ヒロシマケン', '広島市中区', 'ヒロシマシナカク', '舟入幸町', 'フナイリサイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市中区舟入川口町', '34', '34101', '7300845', '広島県', 'ヒロシマケン', '広島市中区', 'ヒロシマシナカク', '舟入川口町', 'フナイリカワグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市中区西川口町', '34', '34101', '7300846', '広島県', 'ヒロシマケン', '広島市中区', 'ヒロシマシナカク', '西川口町', 'ニシカワグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市中区舟入南', '34', '34101', '7300847', '広島県', 'ヒロシマケン', '広島市中区', 'ヒロシマシナカク', '舟入南', 'フナイリミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道砂川市富平', '01', '01226', '0730085', '北海道', 'ホッカイドウ', '砂川市', 'スナガワシ', '富平', 'トミヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市中区榎町', '34', '34101', '7300851', '広島県', 'ヒロシマケン', '広島市中区', 'ヒロシマシナカク', '榎町', 'エノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市中区猫屋町', '34', '34101', '7300852', '広島県', 'ヒロシマケン', '広島市中区', 'ヒロシマシナカク', '猫屋町', 'ネコヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市中区堺町', '34', '34101', '7300853', '広島県', 'ヒロシマケン', '広島市中区', 'ヒロシマシナカク', '堺町', 'サカイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市中区土橋町', '34', '34101', '7300854', '広島県', 'ヒロシマケン', '広島市中区', 'ヒロシマシナカク', '土橋町', 'ドハシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市中区小網町', '34', '34101', '7300855', '広島県', 'ヒロシマケン', '広島市中区', 'ヒロシマシナカク', '小網町', 'コアミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市中区河原町', '34', '34101', '7300856', '広島県', 'ヒロシマケン', '広島市中区', 'ヒロシマシナカク', '河原町', 'カワラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道砂川市', '01', '01226', '0730100', '北海道', 'ホッカイドウ', '砂川市', 'スナガワシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('91041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道砂川市空知太東1条', '01', '01226', '0730101', '北海道', 'ホッカイドウ', '砂川市', 'スナガワシ', '空知太東1条', 'ソラチブトヒガシ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道砂川市空知太東2条', '01', '01226', '0730102', '北海道', 'ホッカイドウ', '砂川市', 'スナガワシ', '空知太東2条', 'ソラチブトヒガシ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道砂川市空知太東3条', '01', '01226', '0730103', '北海道', 'ホッカイドウ', '砂川市', 'スナガワシ', '空知太東3条', 'ソラチブトヒガシ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道砂川市空知太東4条', '01', '01226', '0730104', '北海道', 'ホッカイドウ', '砂川市', 'スナガワシ', '空知太東4条', 'ソラチブトヒガシ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道砂川市空知太東5条', '01', '01226', '0730105', '北海道', 'ホッカイドウ', '砂川市', 'スナガワシ', '空知太東5条', 'ソラチブトヒガシ05ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道砂川市空知太', '01', '01226', '0730106', '北海道', 'ホッカイドウ', '砂川市', 'スナガワシ', '空知太', 'ソラチブト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道砂川市一の沢', '01', '01226', '0730107', '北海道', 'ホッカイドウ', '砂川市', 'スナガワシ', '一の沢', 'イチノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道砂川市北光', '01', '01226', '0730108', '北海道', 'ホッカイドウ', '砂川市', 'スナガワシ', '北光', 'ホッコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道砂川市晴見1条北', '01', '01226', '0730111', '北海道', 'ホッカイドウ', '砂川市', 'スナガワシ', '晴見1条北', 'ハルミ01ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道砂川市晴見2条北', '01', '01226', '0730112', '北海道', 'ホッカイドウ', '砂川市', 'スナガワシ', '晴見2条北', 'ハルミ02ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道砂川市晴見3条北', '01', '01226', '0730113', '北海道', 'ホッカイドウ', '砂川市', 'スナガワシ', '晴見3条北', 'ハルミ03ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道砂川市晴見4条北', '01', '01226', '0730114', '北海道', 'ホッカイドウ', '砂川市', 'スナガワシ', '晴見4条北', 'ハルミ04ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道砂川市焼山', '01', '01226', '0730115', '北海道', 'ホッカイドウ', '砂川市', 'スナガワシ', '焼山', 'ヤケヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道砂川市鶉', '01', '01226', '0730116', '北海道', 'ホッカイドウ', '砂川市', 'スナガワシ', '鶉', 'ウズラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道砂川市南吉野町', '01', '01226', '0730117', '北海道', 'ホッカイドウ', '砂川市', 'スナガワシ', '南吉野町', 'ミナミヨシノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道砂川市北吉野町', '01', '01226', '0730118', '北海道', 'ホッカイドウ', '砂川市', 'スナガワシ', '北吉野町', 'キタヨシノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道砂川市吉野1条南', '01', '01226', '0730121', '北海道', 'ホッカイドウ', '砂川市', 'スナガワシ', '吉野1条南', 'ヨシノ01ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道砂川市吉野2条南', '01', '01226', '0730122', '北海道', 'ホッカイドウ', '砂川市', 'スナガワシ', '吉野2条南', 'ヨシノ02ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道砂川市吉野3条南', '01', '01226', '0730123', '北海道', 'ホッカイドウ', '砂川市', 'スナガワシ', '吉野3条南', 'ヨシノ03ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道砂川市吉野4条南', '01', '01226', '0730124', '北海道', 'ホッカイドウ', '砂川市', 'スナガワシ', '吉野4条南', 'ヨシノ04ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道砂川市宮城の沢', '01', '01226', '0730125', '北海道', 'ホッカイドウ', '砂川市', 'スナガワシ', '宮城の沢', 'ミヤギノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道砂川市東豊沼', '01', '01226', '0730126', '北海道', 'ホッカイドウ', '砂川市', 'スナガワシ', '東豊沼', 'ヒガシトヨヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道砂川市日の出1条南', '01', '01226', '0730127', '北海道', 'ホッカイドウ', '砂川市', 'スナガワシ', '日の出1条南', 'ヒノデ01ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道砂川市東1条南', '01', '01226', '0730131', '北海道', 'ホッカイドウ', '砂川市', 'スナガワシ', '東1条南', 'ヒガシ01ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道砂川市東2条南', '01', '01226', '0730132', '北海道', 'ホッカイドウ', '砂川市', 'スナガワシ', '東2条南', 'ヒガシ02ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道砂川市東3条南', '01', '01226', '0730133', '北海道', 'ホッカイドウ', '砂川市', 'スナガワシ', '東3条南', 'ヒガシ03ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道砂川市東4条南', '01', '01226', '0730134', '北海道', 'ホッカイドウ', '砂川市', 'スナガワシ', '東4条南', 'ヒガシ04ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道砂川市東5条南', '01', '01226', '0730135', '北海道', 'ホッカイドウ', '砂川市', 'スナガワシ', '東5条南', 'ヒガシ05ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道砂川市東6条南', '01', '01226', '0730136', '北海道', 'ホッカイドウ', '砂川市', 'スナガワシ', '東6条南', 'ヒガシ06ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道砂川市東7条南', '01', '01226', '0730137', '北海道', 'ホッカイドウ', '砂川市', 'スナガワシ', '東7条南', 'ヒガシ07ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道砂川市豊沼町', '01', '01226', '0730138', '北海道', 'ホッカイドウ', '砂川市', 'スナガワシ', '豊沼町', 'トヨヌマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道砂川市西1条南', '01', '01226', '0730141', '北海道', 'ホッカイドウ', '砂川市', 'スナガワシ', '西1条南', 'ニシ01ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道砂川市西2条南', '01', '01226', '0730142', '北海道', 'ホッカイドウ', '砂川市', 'スナガワシ', '西2条南', 'ニシ02ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道砂川市西3条南', '01', '01226', '0730143', '北海道', 'ホッカイドウ', '砂川市', 'スナガワシ', '西3条南', 'ニシ03ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道砂川市西4条南', '01', '01226', '0730144', '北海道', 'ホッカイドウ', '砂川市', 'スナガワシ', '西4条南', 'ニシ04ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道砂川市西5条南', '01', '01226', '0730145', '北海道', 'ホッカイドウ', '砂川市', 'スナガワシ', '西5条南', 'ニシ05ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道砂川市西6条南', '01', '01226', '0730146', '北海道', 'ホッカイドウ', '砂川市', 'スナガワシ', '西6条南', 'ニシ06ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道砂川市西7条南', '01', '01226', '0730147', '北海道', 'ホッカイドウ', '砂川市', 'スナガワシ', '西7条南', 'ニシ07ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道砂川市西豊沼', '01', '01226', '0730148', '北海道', 'ホッカイドウ', '砂川市', 'スナガワシ', '西豊沼', 'ニシトヨヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道砂川市東1条北', '01', '01226', '0730151', '北海道', 'ホッカイドウ', '砂川市', 'スナガワシ', '東1条北', 'ヒガシ01ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道砂川市東2条北', '01', '01226', '0730152', '北海道', 'ホッカイドウ', '砂川市', 'スナガワシ', '東2条北', 'ヒガシ02ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道砂川市東3条北', '01', '01226', '0730153', '北海道', 'ホッカイドウ', '砂川市', 'スナガワシ', '東3条北', 'ヒガシ03ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道砂川市東4条北', '01', '01226', '0730154', '北海道', 'ホッカイドウ', '砂川市', 'スナガワシ', '東4条北', 'ヒガシ04ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道砂川市東5条北', '01', '01226', '0730155', '北海道', 'ホッカイドウ', '砂川市', 'スナガワシ', '東5条北', 'ヒガシ05ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道砂川市東6条北', '01', '01226', '0730156', '北海道', 'ホッカイドウ', '砂川市', 'スナガワシ', '東6条北', 'ヒガシ06ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道砂川市三砂町', '01', '01226', '0730157', '北海道', 'ホッカイドウ', '砂川市', 'スナガワシ', '三砂町', 'ミサゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道砂川市吉野1条北', '01', '01226', '0730158', '北海道', 'ホッカイドウ', '砂川市', 'スナガワシ', '吉野1条北', 'ヨシノ01ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道砂川市吉野2条北', '01', '01226', '0730159', '北海道', 'ホッカイドウ', '砂川市', 'スナガワシ', '吉野2条北', 'ヨシノ02ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道砂川市西1条北', '01', '01226', '0730161', '北海道', 'ホッカイドウ', '砂川市', 'スナガワシ', '西1条北', 'ニシ01ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道砂川市西2条北', '01', '01226', '0730162', '北海道', 'ホッカイドウ', '砂川市', 'スナガワシ', '西2条北', 'ニシ02ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道砂川市西3条北', '01', '01226', '0730163', '北海道', 'ホッカイドウ', '砂川市', 'スナガワシ', '西3条北', 'ニシ03ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道砂川市西4条北', '01', '01226', '0730164', '北海道', 'ホッカイドウ', '砂川市', 'スナガワシ', '西4条北', 'ニシ04ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道砂川市西5条北', '01', '01226', '0730165', '北海道', 'ホッカイドウ', '砂川市', 'スナガワシ', '西5条北', 'ニシ05ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道砂川市西6条北', '01', '01226', '0730166', '北海道', 'ホッカイドウ', '砂川市', 'スナガワシ', '西6条北', 'ニシ06ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道砂川市西7条北', '01', '01226', '0730167', '北海道', 'ホッカイドウ', '砂川市', 'スナガワシ', '西7条北', 'ニシ07ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道砂川市西8条北', '01', '01226', '0730168', '北海道', 'ホッカイドウ', '砂川市', 'スナガワシ', '西8条北', 'ニシ08ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道砂川市空知太西1条', '01', '01226', '0730171', '北海道', 'ホッカイドウ', '砂川市', 'スナガワシ', '空知太西1条', 'ソラチブトニシ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道砂川市空知太西2条', '01', '01226', '0730172', '北海道', 'ホッカイドウ', '砂川市', 'スナガワシ', '空知太西2条', 'ソラチブトニシ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道砂川市空知太西3条', '01', '01226', '0730173', '北海道', 'ホッカイドウ', '砂川市', 'スナガワシ', '空知太西3条', 'ソラチブトニシ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道砂川市空知太西4条', '01', '01226', '0730174', '北海道', 'ホッカイドウ', '砂川市', 'スナガワシ', '空知太西4条', 'ソラチブトニシ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道砂川市空知太西5条', '01', '01226', '0730175', '北海道', 'ホッカイドウ', '砂川市', 'スナガワシ', '空知太西5条', 'ソラチブトニシ05ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道砂川市空知太西6条', '01', '01226', '0730176', '北海道', 'ホッカイドウ', '砂川市', 'スナガワシ', '空知太西6条', 'ソラチブトニシ06ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道砂川市空知太', '01', '01226', '0730177', '北海道', 'ホッカイドウ', '砂川市', 'スナガワシ', '空知太', 'ソラチブト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道砂川市袋地', '01', '01226', '0730178', '北海道', 'ホッカイドウ', '砂川市', 'スナガワシ', '袋地', 'フクロチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道樺戸郡新十津川町弥生堤防用地', '01', '01432', '0730181', '北海道', 'ホッカイドウ', '樺戸郡新十津川町', 'カバトグンシントツカワチョウ', '弥生', 'ヤヨイ', null, null, '堤防用地', 'テイボウヨウチ');
INSERT INTO `ms_addresses` VALUES ('91109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡上砂川町', '01', '01425', '0730200', '北海道', 'ホッカイドウ', '空知郡上砂川町', 'ソラチグンカミスナガワチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('91110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡上砂川町中央', '01', '01425', '0730201', '北海道', 'ホッカイドウ', '空知郡上砂川町', 'ソラチグンカミスナガワチョウ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡上砂川町東町', '01', '01425', '0730202', '北海道', 'ホッカイドウ', '空知郡上砂川町', 'ソラチグンカミスナガワチョウ', '東町', 'ヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡上砂川町中町', '01', '01425', '0730203', '北海道', 'ホッカイドウ', '空知郡上砂川町', 'ソラチグンカミスナガワチョウ', '中町', 'ナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡上砂川町本町', '01', '01425', '0730204', '北海道', 'ホッカイドウ', '空知郡上砂川町', 'ソラチグンカミスナガワチョウ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡上砂川町朝駒', '01', '01425', '0730205', '北海道', 'ホッカイドウ', '空知郡上砂川町', 'ソラチグンカミスナガワチョウ', '朝駒', 'アサコマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡上砂川町東山', '01', '01425', '0730206', '北海道', 'ホッカイドウ', '空知郡上砂川町', 'ソラチグンカミスナガワチョウ', '東山', 'ヒガシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡上砂川町東鶉', '01', '01425', '0730211', '北海道', 'ホッカイドウ', '空知郡上砂川町', 'ソラチグンカミスナガワチョウ', '東鶉', 'ヒガシウズラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡上砂川町鶉', '01', '01425', '0730212', '北海道', 'ホッカイドウ', '空知郡上砂川町', 'ソラチグンカミスナガワチョウ', '鶉', 'ウズラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡上砂川町緑が丘', '01', '01425', '0730213', '北海道', 'ホッカイドウ', '空知郡上砂川町', 'ソラチグンカミスナガワチョウ', '緑が丘', 'ミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡上砂川町鶉本町', '01', '01425', '0730221', '北海道', 'ホッカイドウ', '空知郡上砂川町', 'ソラチグンカミスナガワチョウ', '鶉本町', 'ウズラホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡上砂川町下鶉', '01', '01425', '0730222', '北海道', 'ホッカイドウ', '空知郡上砂川町', 'ソラチグンカミスナガワチョウ', '下鶉', 'シモウズラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道歌志内市', '01', '01227', '0730400', '北海道', 'ホッカイドウ', '歌志内市', 'ウタシナイシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('91123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道歌志内市上歌', '01', '01227', '0730401', '北海道', 'ホッカイドウ', '歌志内市', 'ウタシナイシ', '上歌', 'カミウタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道歌志内市東光', '01', '01227', '0730402', '北海道', 'ホッカイドウ', '歌志内市', 'ウタシナイシ', '東光', 'トウコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道歌志内市本町', '01', '01227', '0730403', '北海道', 'ホッカイドウ', '歌志内市', 'ウタシナイシ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道歌志内市歌神', '01', '01227', '0730404', '北海道', 'ホッカイドウ', '歌志内市', 'ウタシナイシ', '歌神', 'カシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道歌志内市神威', '01', '01227', '0730405', '北海道', 'ホッカイドウ', '歌志内市', 'ウタシナイシ', '神威', 'カモイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道歌志内市中村', '01', '01227', '0730406', '北海道', 'ホッカイドウ', '歌志内市', 'ウタシナイシ', '中村', 'ナカムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道歌志内市文珠', '01', '01227', '0730407', '北海道', 'ホッカイドウ', '歌志内市', 'ウタシナイシ', '文珠', 'モンジュ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安佐南区', '34', '34105', '7310100', '広島県', 'ヒロシマケン', '広島市安佐南区', 'ヒロシマシアサミナミク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('91240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安佐南区八木', '34', '34105', '7310101', '広島県', 'ヒロシマケン', '広島市安佐南区', 'ヒロシマシアサミナミク', '八木', 'ヤギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安佐南区八木町', '34', '34105', '7310101', '広島県', 'ヒロシマケン', '広島市安佐南区', 'ヒロシマシアサミナミク', '八木町', 'ヤギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安佐南区川内', '34', '34105', '7310102', '広島県', 'ヒロシマケン', '広島市安佐南区', 'ヒロシマシアサミナミク', '川内', 'カワウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安佐南区緑井', '34', '34105', '7310103', '広島県', 'ヒロシマケン', '広島市安佐南区', 'ヒロシマシアサミナミク', '緑井', 'ミドリイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安佐南区東野', '34', '34105', '7310111', '広島県', 'ヒロシマケン', '広島市安佐南区', 'ヒロシマシアサミナミク', '東野', 'ヒガシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安佐南区東原', '34', '34105', '7310112', '広島県', 'ヒロシマケン', '広島市安佐南区', 'ヒロシマシアサミナミク', '東原', 'ヒガシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安佐南区西原', '34', '34105', '7310113', '広島県', 'ヒロシマケン', '広島市安佐南区', 'ヒロシマシアサミナミク', '西原', 'ニシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安佐南区中須', '34', '34105', '7310121', '広島県', 'ヒロシマケン', '広島市安佐南区', 'ヒロシマシアサミナミク', '中須', 'ナカス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安佐南区中筋', '34', '34105', '7310122', '広島県', 'ヒロシマケン', '広島市安佐南区', 'ヒロシマシアサミナミク', '中筋', 'ナカスジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安佐南区古市', '34', '34105', '7310123', '広島県', 'ヒロシマケン', '広島市安佐南区', 'ヒロシマシアサミナミク', '古市', 'フルイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安佐南区大町東', '34', '34105', '7310124', '広島県', 'ヒロシマケン', '広島市安佐南区', 'ヒロシマシアサミナミク', '大町東', 'オオマチヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安佐南区大町西', '34', '34105', '7310125', '広島県', 'ヒロシマケン', '広島市安佐南区', 'ヒロシマシアサミナミク', '大町西', 'オオマチニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安佐南区大町', '34', '34105', '7310126', '広島県', 'ヒロシマケン', '広島市安佐南区', 'ヒロシマシアサミナミク', '大町', 'オオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安佐南区長束', '34', '34105', '7310135', '広島県', 'ヒロシマケン', '広島市安佐南区', 'ヒロシマシアサミナミク', '長束', 'ナガツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安佐南区長束西', '34', '34105', '7310136', '広島県', 'ヒロシマケン', '広島市安佐南区', 'ヒロシマシアサミナミク', '長束西', 'ナガツカニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安佐南区山本', '34', '34105', '7310137', '広島県', 'ヒロシマケン', '広島市安佐南区', 'ヒロシマシアサミナミク', '山本', 'ヤマモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安佐南区山本町', '34', '34105', '7310137', '広島県', 'ヒロシマケン', '広島市安佐南区', 'ヒロシマシアサミナミク', '山本町', 'ヤマモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安佐南区祇園', '34', '34105', '7310138', '広島県', 'ヒロシマケン', '広島市安佐南区', 'ヒロシマシアサミナミク', '祇園', 'ギオン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安佐南区山本新町', '34', '34105', '7310139', '広島県', 'ヒロシマケン', '広島市安佐南区', 'ヒロシマシアサミナミク', '山本新町', 'ヤマモトシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安佐南区相田', '34', '34105', '7310141', '広島県', 'ヒロシマケン', '広島市安佐南区', 'ヒロシマシアサミナミク', '相田', 'アイタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安佐南区高取南', '34', '34105', '7310142', '広島県', 'ヒロシマケン', '広島市安佐南区', 'ヒロシマシアサミナミク', '高取南', 'タカトリミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安佐南区高取南町', '34', '34105', '7310142', '広島県', 'ヒロシマケン', '広島市安佐南区', 'ヒロシマシアサミナミク', '高取南町', 'タカトリミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安佐南区長楽寺', '34', '34105', '7310143', '広島県', 'ヒロシマケン', '広島市安佐南区', 'ヒロシマシアサミナミク', '長楽寺', 'チョウラクジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安佐南区長楽寺町', '34', '34105', '7310143', '広島県', 'ヒロシマケン', '広島市安佐南区', 'ヒロシマシアサミナミク', '長楽寺町', 'チョウラクジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安佐南区高取北', '34', '34105', '7310144', '広島県', 'ヒロシマケン', '広島市安佐南区', 'ヒロシマシアサミナミク', '高取北', 'タカトリキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安佐南区毘沙門台東', '34', '34105', '7310151', '広島県', 'ヒロシマケン', '広島市安佐南区', 'ヒロシマシアサミナミク', '毘沙門台東', 'ビシャモンダイヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安佐南区毘沙門台', '34', '34105', '7310152', '広島県', 'ヒロシマケン', '広島市安佐南区', 'ヒロシマシアサミナミク', '毘沙門台', 'ビシャモンダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安佐南区安東', '34', '34105', '7310153', '広島県', 'ヒロシマケン', '広島市安佐南区', 'ヒロシマシアサミナミク', '安東', 'ヤスヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安佐南区上安', '34', '34105', '7310154', '広島県', 'ヒロシマケン', '広島市安佐南区', 'ヒロシマシアサミナミク', '上安', 'カミヤス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安佐南区上安町', '34', '34105', '7310154', '広島県', 'ヒロシマケン', '広島市安佐南区', 'ヒロシマシアサミナミク', '上安町', 'カミヤスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安佐北区大林', '34', '34106', '7310201', '広島県', 'ヒロシマケン', '広島市安佐北区', 'ヒロシマシアサキタク', '大林', 'オオバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安佐北区大林町', '34', '34106', '7310202', '広島県', 'ヒロシマケン', '広島市安佐北区', 'ヒロシマシアサキタク', '大林町', 'オオバヤシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安佐北区三入', '34', '34106', '7310211', '広島県', 'ヒロシマケン', '広島市安佐北区', 'ヒロシマシアサキタク', '三入', 'ミイリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安佐北区三入東', '34', '34106', '7310212', '広島県', 'ヒロシマケン', '広島市安佐北区', 'ヒロシマシアサキタク', '三入東', 'ミイリヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安佐北区三入南', '34', '34106', '7310213', '広島県', 'ヒロシマケン', '広島市安佐北区', 'ヒロシマシアサキタク', '三入南', 'ミイリミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安佐北区可部町桐原', '34', '34106', '7310214', '広島県', 'ヒロシマケン', '広島市安佐北区', 'ヒロシマシアサキタク', '可部町桐原', 'カベチョウトゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安佐北区可部町南原', '34', '34106', '7310215', '広島県', 'ヒロシマケン', '広島市安佐北区', 'ヒロシマシアサキタク', '可部町南原', 'カベチョウナバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安佐北区可部町上町屋', '34', '34106', '7310216', '広島県', 'ヒロシマケン', '広島市安佐北区', 'ヒロシマシアサキタク', '可部町上町屋', 'カベチョウカミマチヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安佐北区可部町下町屋', '34', '34106', '7310217', '広島県', 'ヒロシマケン', '広島市安佐北区', 'ヒロシマシアサキタク', '可部町下町屋', 'カベチョウシモマチヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安佐北区可部', '34', '34106', '7310221', '広島県', 'ヒロシマケン', '広島市安佐北区', 'ヒロシマシアサキタク', '可部', 'カベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安佐北区可部東', '34', '34106', '7310222', '広島県', 'ヒロシマケン', '広島市安佐北区', 'ヒロシマシアサキタク', '可部東', 'カベヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安佐北区可部南', '34', '34106', '7310223', '広島県', 'ヒロシマケン', '広島市安佐北区', 'ヒロシマシアサキタク', '可部南', 'カベミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安佐北区可部町中島', '34', '34106', '7310224', '広島県', 'ヒロシマケン', '広島市安佐北区', 'ヒロシマシアサキタク', '可部町中島', 'カベチョウナカシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安佐北区可部町上原', '34', '34106', '7310225', '広島県', 'ヒロシマケン', '広島市安佐北区', 'ヒロシマシアサキタク', '可部町上原', 'カベチョウウエバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安佐北区亀山', '34', '34106', '7310231', '広島県', 'ヒロシマケン', '広島市安佐北区', 'ヒロシマシアサキタク', '亀山', 'カメヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安佐北区亀山南', '34', '34106', '7310232', '広島県', 'ヒロシマケン', '広島市安佐北区', 'ヒロシマシアサキタク', '亀山南', 'カメヤマミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安佐北区亀山西', '34', '34106', '7310233', '広島県', 'ヒロシマケン', '広島市安佐北区', 'ヒロシマシアサキタク', '亀山西', 'カメヤマニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安佐北区可部町今井田', '34', '34106', '7310234', '広島県', 'ヒロシマケン', '広島市安佐北区', 'ヒロシマシアサキタク', '可部町今井田', 'カベチョウイマイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安佐北区可部町勝木', '34', '34106', '7310235', '広島県', 'ヒロシマケン', '広島市安佐北区', 'ヒロシマシアサキタク', '可部町勝木', 'カベチョウカツギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安佐北区可部町綾ケ谷', '34', '34106', '7310236', '広島県', 'ヒロシマケン', '広島市安佐北区', 'ヒロシマシアサキタク', '可部町綾ケ谷', 'カベチョウアヤガタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸高田市八千代町土師', '34', '34214', '7310301', '広島県', 'ヒロシマケン', '安芸高田市', 'アキタカタシ', '八千代町土師', 'ヤチヨチョウハジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸高田市八千代町勝田', '34', '34214', '7310302', '広島県', 'ヒロシマケン', '安芸高田市', 'アキタカタシ', '八千代町勝田', 'ヤチヨチョウカッタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸高田市八千代町佐々井', '34', '34214', '7310303', '広島県', 'ヒロシマケン', '安芸高田市', 'アキタカタシ', '八千代町佐々井', 'ヤチヨチョウササイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸高田市八千代町下根', '34', '34214', '7310304', '広島県', 'ヒロシマケン', '安芸高田市', 'アキタカタシ', '八千代町下根', 'ヤチヨチョウシモネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸高田市八千代町上根', '34', '34214', '7310305', '広島県', 'ヒロシマケン', '安芸高田市', 'アキタカタシ', '八千代町上根', 'ヤチヨチョウカミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸高田市八千代町向山', '34', '34214', '7310306', '広島県', 'ヒロシマケン', '安芸高田市', 'アキタカタシ', '八千代町向山', 'ヤチヨチョウムカイヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸高田市', '34', '34214', '7310500', '広島県', 'ヒロシマケン', '安芸高田市', 'アキタカタシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('91305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸高田市吉田町吉田', '34', '34214', '7310501', '広島県', 'ヒロシマケン', '安芸高田市', 'アキタカタシ', '吉田町吉田', 'ヨシダチョウヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸高田市吉田町国司', '34', '34214', '7310502', '広島県', 'ヒロシマケン', '安芸高田市', 'アキタカタシ', '吉田町国司', 'ヨシダチョウクニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸高田市吉田町竹原', '34', '34214', '7310511', '広島県', 'ヒロシマケン', '安芸高田市', 'アキタカタシ', '吉田町竹原', 'ヨシダチョウタケハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸高田市吉田町小山', '34', '34214', '7310512', '広島県', 'ヒロシマケン', '安芸高田市', 'アキタカタシ', '吉田町小山', 'ヨシダチョウオヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸高田市吉田町福原', '34', '34214', '7310513', '広島県', 'ヒロシマケン', '安芸高田市', 'アキタカタシ', '吉田町福原', 'ヨシダチョウフクバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸高田市吉田町常友', '34', '34214', '7310521', '広島県', 'ヒロシマケン', '安芸高田市', 'アキタカタシ', '吉田町常友', 'ヨシダチョウツネトモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸高田市吉田町常楽寺', '34', '34214', '7310522', '広島県', 'ヒロシマケン', '安芸高田市', 'アキタカタシ', '吉田町常楽寺', 'ヨシダチョウジョウラクジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸高田市吉田町山手', '34', '34214', '7310523', '広島県', 'ヒロシマケン', '安芸高田市', 'アキタカタシ', '吉田町山手', 'ヨシダチョウヤマテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸高田市吉田町川本', '34', '34214', '7310524', '広島県', 'ヒロシマケン', '安芸高田市', 'アキタカタシ', '吉田町川本', 'ヨシダチョウカワモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸高田市吉田町中馬', '34', '34214', '7310525', '広島県', 'ヒロシマケン', '安芸高田市', 'アキタカタシ', '吉田町中馬', 'ヨシダチョウチュウマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸高田市吉田町下入江', '34', '34214', '7310531', '広島県', 'ヒロシマケン', '安芸高田市', 'アキタカタシ', '吉田町下入江', 'ヨシダチョウシモイリエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸高田市吉田町上入江', '34', '34214', '7310532', '広島県', 'ヒロシマケン', '安芸高田市', 'アキタカタシ', '吉田町上入江', 'ヨシダチョウカミイリエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸高田市吉田町長屋', '34', '34214', '7310533', '広島県', 'ヒロシマケン', '安芸高田市', 'アキタカタシ', '吉田町長屋', 'ヨシダチョウナガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸高田市吉田町桂', '34', '34214', '7310534', '広島県', 'ヒロシマケン', '安芸高田市', 'アキタカタシ', '吉田町桂', 'ヨシダチョウカツラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸高田市吉田町高野', '34', '34214', '7310535', '広島県', 'ヒロシマケン', '安芸高田市', 'アキタカタシ', '吉田町高野', 'ヨシダチョウコウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸高田市吉田町山部', '34', '34214', '7310541', '広島県', 'ヒロシマケン', '安芸高田市', 'アキタカタシ', '吉田町山部', 'ヨシダチョウヤンベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸高田市吉田町相合', '34', '34214', '7310542', '広島県', 'ヒロシマケン', '安芸高田市', 'アキタカタシ', '吉田町相合', 'ヨシダチョウアイオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸高田市吉田町西浦', '34', '34214', '7310543', '広島県', 'ヒロシマケン', '安芸高田市', 'アキタカタシ', '吉田町西浦', 'ヨシダチョウニシウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸高田市吉田町多治比', '34', '34214', '7310544', '広島県', 'ヒロシマケン', '安芸高田市', 'アキタカタシ', '吉田町多治比', 'ヨシダチョウタジヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸高田市美土里町横田', '34', '34214', '7310611', '広島県', 'ヒロシマケン', '安芸高田市', 'アキタカタシ', '美土里町横田', 'ミドリチョウヨコタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸高田市美土里町本郷', '34', '34214', '7310612', '広島県', 'ヒロシマケン', '安芸高田市', 'アキタカタシ', '美土里町本郷', 'ミドリチョウホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸高田市美土里町北', '34', '34214', '7310701', '広島県', 'ヒロシマケン', '安芸高田市', 'アキタカタシ', '美土里町北', 'ミドリチョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸高田市美土里町桑田', '34', '34214', '7310702', '広島県', 'ヒロシマケン', '安芸高田市', 'アキタカタシ', '美土里町桑田', 'ミドリチョウクワタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸高田市美土里町生田', '34', '34214', '7310703', '広島県', 'ヒロシマケン', '安芸高田市', 'アキタカタシ', '美土里町生田', 'ミドリチョウイケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道樺戸郡新十津川町', '01', '01432', '0731100', '北海道', 'ホッカイドウ', '樺戸郡新十津川町', 'カバトグンシントツカワチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('91334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道樺戸郡新十津川町士寸', '01', '01432', '0731101', '北海道', 'ホッカイドウ', '樺戸郡新十津川町', 'カバトグンシントツカワチョウ', '士寸', 'シスン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道樺戸郡新十津川町大和', '01', '01432', '0731102', '北海道', 'ホッカイドウ', '樺戸郡新十津川町', 'カバトグンシントツカワチョウ', '大和', 'ヤマト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道樺戸郡新十津川町中央', '01', '01432', '0731103', '北海道', 'ホッカイドウ', '樺戸郡新十津川町', 'カバトグンシントツカワチョウ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道樺戸郡新十津川町弥生', '01', '01432', '0731104', '北海道', 'ホッカイドウ', '樺戸郡新十津川町', 'カバトグンシントツカワチョウ', '弥生', 'ヤヨイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道樺戸郡新十津川町花月', '01', '01432', '0731105', '北海道', 'ホッカイドウ', '樺戸郡新十津川町', 'カバトグンシントツカワチョウ', '花月', 'カゲツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道樺戸郡新十津川町総進', '01', '01432', '0731106', '北海道', 'ホッカイドウ', '樺戸郡新十津川町', 'カバトグンシントツカワチョウ', '総進', 'ソウシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道樺戸郡新十津川町トツプ', '01', '01432', '0731107', '北海道', 'ホッカイドウ', '樺戸郡新十津川町', 'カバトグンシントツカワチョウ', 'トツプ', 'トツプ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安佐北区安佐町鈴張', '34', '34106', '7311141', '広島県', 'ヒロシマケン', '広島市安佐北区', 'ヒロシマシアサキタク', '安佐町鈴張', 'アサチョウスズハリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安佐北区安佐町飯室', '34', '34106', '7311142', '広島県', 'ヒロシマケン', '広島市安佐北区', 'ヒロシマシアサキタク', '安佐町飯室', 'アサチョウイムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安佐北区安佐町小河内', '34', '34106', '7311171', '広島県', 'ヒロシマケン', '広島市安佐北区', 'ヒロシマシアサキタク', '安佐町小河内', 'アサチョウオガウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県山県郡北広島町今吉田', '34', '34369', '7311221', '広島県', 'ヒロシマケン', '山県郡北広島町', 'ヤマガタグンキタヒロシマチョウ', '今吉田', 'イマヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県山県郡北広島町阿坂', '34', '34369', '7311222', '広島県', 'ヒロシマケン', '山県郡北広島町', 'ヤマガタグンキタヒロシマチョウ', '阿坂', 'アザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県山県郡北広島町吉木', '34', '34369', '7311223', '広島県', 'ヒロシマケン', '山県郡北広島町', 'ヤマガタグンキタヒロシマチョウ', '吉木', 'ヨシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県山県郡北広島町', '34', '34369', '7311500', '広島県', 'ヒロシマケン', '山県郡北広島町', 'ヤマガタグンキタヒロシマチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('91348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県山県郡北広島町川戸', '34', '34369', '7311501', '広島県', 'ヒロシマケン', '山県郡北広島町', 'ヤマガタグンキタヒロシマチョウ', '川戸', 'カワド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県山県郡北広島町蔵迫', '34', '34369', '7311502', '広島県', 'ヒロシマケン', '山県郡北広島町', 'ヤマガタグンキタヒロシマチョウ', '蔵迫', 'クラザコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県山県郡北広島町有間', '34', '34369', '7311503', '広島県', 'ヒロシマケン', '山県郡北広島町', 'ヤマガタグンキタヒロシマチョウ', '有間', 'アリマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県山県郡北広島町寺原', '34', '34369', '7311504', '広島県', 'ヒロシマケン', '山県郡北広島町', 'ヤマガタグンキタヒロシマチョウ', '寺原', 'テラバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県山県郡北広島町舞綱', '34', '34369', '7311505', '広島県', 'ヒロシマケン', '山県郡北広島町', 'ヤマガタグンキタヒロシマチョウ', '舞綱', 'モウツナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県山県郡北広島町中山', '34', '34369', '7311506', '広島県', 'ヒロシマケン', '山県郡北広島町', 'ヤマガタグンキタヒロシマチョウ', '中山', 'ナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県山県郡北広島町惣森', '34', '34369', '7311511', '広島県', 'ヒロシマケン', '山県郡北広島町', 'ヤマガタグンキタヒロシマチョウ', '惣森', 'ソウモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県山県郡北広島町川東', '34', '34369', '7311512', '広島県', 'ヒロシマケン', '山県郡北広島町', 'ヤマガタグンキタヒロシマチョウ', '川東', 'カワヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県山県郡北広島町川井', '34', '34369', '7311513', '広島県', 'ヒロシマケン', '山県郡北広島町', 'ヤマガタグンキタヒロシマチョウ', '川井', 'カワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県山県郡北広島町新氏神', '34', '34369', '7311514', '広島県', 'ヒロシマケン', '山県郡北広島町', 'ヤマガタグンキタヒロシマチョウ', '新氏神', 'シンウジガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県山県郡北広島町壬生', '34', '34369', '7311515', '広島県', 'ヒロシマケン', '山県郡北広島町', 'ヤマガタグンキタヒロシマチョウ', '壬生', 'ミブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県山県郡北広島町川西', '34', '34369', '7311516', '広島県', 'ヒロシマケン', '山県郡北広島町', 'ヤマガタグンキタヒロシマチョウ', '川西', 'カワニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県山県郡北広島町丁保余原', '34', '34369', '7311521', '広島県', 'ヒロシマケン', '山県郡北広島町', 'ヤマガタグンキタヒロシマチョウ', '丁保余原', 'ヨオロホヨバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県山県郡北広島町新郷', '34', '34369', '7311522', '広島県', 'ヒロシマケン', '山県郡北広島町', 'ヤマガタグンキタヒロシマチョウ', '新郷', 'シンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県山県郡北広島町南方', '34', '34369', '7311523', '広島県', 'ヒロシマケン', '山県郡北広島町', 'ヤマガタグンキタヒロシマチョウ', '南方', 'ミナミガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県山県郡北広島町木次', '34', '34369', '7311524', '広島県', 'ヒロシマケン', '山県郡北広島町', 'ヤマガタグンキタヒロシマチョウ', '木次', 'キツギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県山県郡北広島町石井谷', '34', '34369', '7311525', '広島県', 'ヒロシマケン', '山県郡北広島町', 'ヤマガタグンキタヒロシマチョウ', '石井谷', 'イシイダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県山県郡北広島町本地', '34', '34369', '7311526', '広島県', 'ヒロシマケン', '山県郡北広島町', 'ヤマガタグンキタヒロシマチョウ', '本地', 'ホンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県山県郡北広島町春木', '34', '34369', '7311531', '広島県', 'ヒロシマケン', '山県郡北広島町', 'ヤマガタグンキタヒロシマチョウ', '春木', 'ハルキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県山県郡北広島町古保利', '34', '34369', '7311532', '広島県', 'ヒロシマケン', '山県郡北広島町', 'ヤマガタグンキタヒロシマチョウ', '古保利', 'コホリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県山県郡北広島町有田', '34', '34369', '7311533', '広島県', 'ヒロシマケン', '山県郡北広島町', 'ヤマガタグンキタヒロシマチョウ', '有田', 'アリダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県山県郡北広島町後有田', '34', '34369', '7311534', '広島県', 'ヒロシマケン', '山県郡北広島町', 'ヤマガタグンキタヒロシマチョウ', '後有田', 'ウシロアリダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県山県郡北広島町今田', '34', '34369', '7311535', '広島県', 'ヒロシマケン', '山県郡北広島町', 'ヤマガタグンキタヒロシマチョウ', '今田', 'イマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県山県郡北広島町志路原', '34', '34369', '7311701', '広島県', 'ヒロシマケン', '山県郡北広島町', 'ヤマガタグンキタヒロシマチョウ', '志路原', 'シジハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県山県郡北広島町上石', '34', '34369', '7311702', '広島県', 'ヒロシマケン', '山県郡北広島町', 'ヤマガタグンキタヒロシマチョウ', '上石', 'カミイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県山県郡北広島町海応寺', '34', '34369', '7311703', '広島県', 'ヒロシマケン', '山県郡北広島町', 'ヤマガタグンキタヒロシマチョウ', '海応寺', 'カイオウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県山県郡北広島町下石', '34', '34369', '7311704', '広島県', 'ヒロシマケン', '山県郡北広島町', 'ヤマガタグンキタヒロシマチョウ', '下石', 'シモイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県山県郡北広島町西宗', '34', '34369', '7311705', '広島県', 'ヒロシマケン', '山県郡北広島町', 'ヤマガタグンキタヒロシマチョウ', '西宗', 'ニシムネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県山県郡北広島町中原', '34', '34369', '7311706', '広島県', 'ヒロシマケン', '山県郡北広島町', 'ヤマガタグンキタヒロシマチョウ', '中原', 'ナカバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県山県郡北広島町戸谷', '34', '34369', '7311711', '広島県', 'ヒロシマケン', '山県郡北広島町', 'ヤマガタグンキタヒロシマチョウ', '戸谷', 'トダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県山県郡北広島町都志見', '34', '34369', '7311712', '広島県', 'ヒロシマケン', '山県郡北広島町', 'ヤマガタグンキタヒロシマチョウ', '都志見', 'ツシミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県山県郡北広島町長笹', '34', '34369', '7311713', '広島県', 'ヒロシマケン', '山県郡北広島町', 'ヤマガタグンキタヒロシマチョウ', '長笹', 'ナガササ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県山県郡北広島町吉木水根', '34', '34369', '7311714', '広島県', 'ヒロシマケン', '山県郡北広島町', 'ヤマガタグンキタヒロシマチョウ', '吉木', 'ヨシキ', null, null, '水根', 'ミノネ');
INSERT INTO `ms_addresses` VALUES ('91384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県山県郡北広島町宮迫', '34', '34369', '7312101', '広島県', 'ヒロシマケン', '山県郡北広島町', 'ヤマガタグンキタヒロシマチョウ', '宮迫', 'ミヤザコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県山県郡北広島町岩戸', '34', '34369', '7312102', '広島県', 'ヒロシマケン', '山県郡北広島町', 'ヤマガタグンキタヒロシマチョウ', '岩戸', 'イワド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県山県郡北広島町新庄', '34', '34369', '7312103', '広島県', 'ヒロシマケン', '山県郡北広島町', 'ヤマガタグンキタヒロシマチョウ', '新庄', 'シンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県山県郡北広島町大朝', '34', '34369', '7312104', '広島県', 'ヒロシマケン', '山県郡北広島町', 'ヤマガタグンキタヒロシマチョウ', '大朝', 'オオアサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県山県郡北広島町田原', '34', '34369', '7312105', '広島県', 'ヒロシマケン', '山県郡北広島町', 'ヤマガタグンキタヒロシマチョウ', '田原', 'タワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県山県郡北広島町筏津', '34', '34369', '7312106', '広島県', 'ヒロシマケン', '山県郡北広島町', 'ヤマガタグンキタヒロシマチョウ', '筏津', 'イカダツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県山県郡北広島町大塚', '34', '34369', '7312107', '広島県', 'ヒロシマケン', '山県郡北広島町', 'ヤマガタグンキタヒロシマチョウ', '大塚', 'オオツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県山県郡北広島町高野', '34', '34369', '7312201', '広島県', 'ヒロシマケン', '山県郡北広島町', 'ヤマガタグンキタヒロシマチョウ', '高野', 'タカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県山県郡北広島町溝口', '34', '34369', '7312202', '広島県', 'ヒロシマケン', '山県郡北広島町', 'ヤマガタグンキタヒロシマチョウ', '溝口', 'ミゾグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県山県郡北広島町小原', '34', '34369', '7312203', '広島県', 'ヒロシマケン', '山県郡北広島町', 'ヤマガタグンキタヒロシマチョウ', '小原', 'コバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県山県郡北広島町大暮', '34', '34369', '7312204', '広島県', 'ヒロシマケン', '山県郡北広島町', 'ヤマガタグンキタヒロシマチョウ', '大暮', 'オオグレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県山県郡北広島町米沢', '34', '34369', '7312205', '広島県', 'ヒロシマケン', '山県郡北広島町', 'ヤマガタグンキタヒロシマチョウ', '米沢', 'ヨネザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県山県郡北広島町移原', '34', '34369', '7312206', '広島県', 'ヒロシマケン', '山県郡北広島町', 'ヤマガタグンキタヒロシマチョウ', '移原', 'ウツノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県山県郡北広島町土橋', '34', '34369', '7312311', '広島県', 'ヒロシマケン', '山県郡北広島町', 'ヤマガタグンキタヒロシマチョウ', '土橋', 'ツチハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県山県郡北広島町奥原', '34', '34369', '7312312', '広島県', 'ヒロシマケン', '山県郡北広島町', 'ヤマガタグンキタヒロシマチョウ', '奥原', 'オクハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県山県郡北広島町草安', '34', '34369', '7312313', '広島県', 'ヒロシマケン', '山県郡北広島町', 'ヤマガタグンキタヒロシマチョウ', '草安', 'クサヤス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県山県郡北広島町才乙', '34', '34369', '7312314', '広島県', 'ヒロシマケン', '山県郡北広島町', 'ヤマガタグンキタヒロシマチョウ', '才乙', 'サヨオト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県山県郡北広島町大利原', '34', '34369', '7312315', '広島県', 'ヒロシマケン', '山県郡北広島町', 'ヤマガタグンキタヒロシマチョウ', '大利原', 'オオトシバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県山県郡北広島町南門原', '34', '34369', '7312316', '広島県', 'ヒロシマケン', '山県郡北広島町', 'ヤマガタグンキタヒロシマチョウ', '南門原', 'ナモンバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県山県郡北広島町苅屋形', '34', '34369', '7312317', '広島県', 'ヒロシマケン', '山県郡北広島町', 'ヤマガタグンキタヒロシマチョウ', '苅屋形', 'カリヤガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県山県郡北広島町板村', '34', '34369', '7312321', '広島県', 'ヒロシマケン', '山県郡北広島町', 'ヤマガタグンキタヒロシマチョウ', '板村', 'イタムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県山県郡北広島町細見', '34', '34369', '7312322', '広島県', 'ヒロシマケン', '山県郡北広島町', 'ヤマガタグンキタヒロシマチョウ', '細見', 'ホソミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県山県郡北広島町川小田', '34', '34369', '7312323', '広島県', 'ヒロシマケン', '山県郡北広島町', 'ヤマガタグンキタヒロシマチョウ', '川小田', 'カワコダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県山県郡北広島町奥中原', '34', '34369', '7312324', '広島県', 'ヒロシマケン', '山県郡北広島町', 'ヤマガタグンキタヒロシマチョウ', '奥中原', 'オクナカバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県山県郡北広島町荒神原', '34', '34369', '7312431', '広島県', 'ヒロシマケン', '山県郡北広島町', 'ヤマガタグンキタヒロシマチョウ', '荒神原', 'コウジンバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県山県郡北広島町中祖', '34', '34369', '7312432', '広島県', 'ヒロシマケン', '山県郡北広島町', 'ヤマガタグンキタヒロシマチョウ', '中祖', 'ナカソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県山県郡北広島町吉見坂', '34', '34369', '7312433', '広島県', 'ヒロシマケン', '山県郡北広島町', 'ヤマガタグンキタヒロシマチョウ', '吉見坂', 'ヨシミザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県山県郡北広島町橋山', '34', '34369', '7312434', '広島県', 'ヒロシマケン', '山県郡北広島町', 'ヤマガタグンキタヒロシマチョウ', '橋山', 'ハシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県山県郡北広島町空城', '34', '34369', '7312435', '広島県', 'ヒロシマケン', '山県郡北広島町', 'ヤマガタグンキタヒロシマチョウ', '空城', 'ソラジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県山県郡北広島町政所', '34', '34369', '7312436', '広島県', 'ヒロシマケン', '山県郡北広島町', 'ヤマガタグンキタヒロシマチョウ', '政所', 'マンドコロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県山県郡北広島町大元', '34', '34369', '7312437', '広島県', 'ヒロシマケン', '山県郡北広島町', 'ヤマガタグンキタヒロシマチョウ', '大元', 'オオモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県山県郡北広島町宮地', '34', '34369', '7312441', '広島県', 'ヒロシマケン', '山県郡北広島町', 'ヤマガタグンキタヒロシマチョウ', '宮地', 'ミヤジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県山県郡北広島町雲耕', '34', '34369', '7312442', '広島県', 'ヒロシマケン', '山県郡北広島町', 'ヤマガタグンキタヒロシマチョウ', '雲耕', 'ウズノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県山県郡北広島町東八幡原', '34', '34369', '7312551', '広島県', 'ヒロシマケン', '山県郡北広島町', 'ヤマガタグンキタヒロシマチョウ', '東八幡原', 'ヒガシヤワタハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県山県郡北広島町西八幡原', '34', '34369', '7312552', '広島県', 'ヒロシマケン', '山県郡北広島町', 'ヤマガタグンキタヒロシマチョウ', '西八幡原', 'ニシヤワタハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安佐南区沼田町伴', '34', '34105', '7313161', '広島県', 'ヒロシマケン', '広島市安佐南区', 'ヒロシマシアサミナミク', '沼田町伴', 'ヌマタチョウトモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安佐南区沼田町大塚', '34', '34105', '7313162', '広島県', 'ヒロシマケン', '広島市安佐南区', 'ヒロシマシアサミナミク', '沼田町大塚', 'ヌマタチョウオオツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安佐南区伴北', '34', '34105', '7313163', '広島県', 'ヒロシマケン', '広島市安佐南区', 'ヒロシマシアサミナミク', '伴北', 'トモキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安佐南区伴東', '34', '34105', '7313164', '広島県', 'ヒロシマケン', '広島市安佐南区', 'ヒロシマシアサミナミク', '伴東', 'トモヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安佐南区大塚東', '34', '34105', '7313166', '広島県', 'ヒロシマケン', '広島市安佐南区', 'ヒロシマシアサミナミク', '大塚東', 'オオヅカヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安佐南区大塚西', '34', '34105', '7313167', '広島県', 'ヒロシマケン', '広島市安佐南区', 'ヒロシマシアサミナミク', '大塚西', 'オオヅカニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安佐南区伴南', '34', '34105', '7313168', '広島県', 'ヒロシマケン', '広島市安佐南区', 'ヒロシマシアサミナミク', '伴南', 'トモミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安佐南区伴西', '34', '34105', '7313169', '広島県', 'ヒロシマケン', '広島市安佐南区', 'ヒロシマシアサミナミク', '伴西', 'トモニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道樺戸郡新十津川町学園', '01', '01432', '0731321', '北海道', 'ホッカイドウ', '樺戸郡新十津川町', 'カバトグンシントツカワチョウ', '学園', 'ガクエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道樺戸郡新十津川町吉野', '01', '01432', '0731322', '北海道', 'ホッカイドウ', '樺戸郡新十津川町', 'カバトグンシントツカワチョウ', '吉野', 'ヨシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道樺戸郡新十津川町幌加', '01', '01432', '0731323', '北海道', 'ホッカイドウ', '樺戸郡新十津川町', 'カバトグンシントツカワチョウ', '幌加', 'ホロカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安佐南区沼田町阿戸', '34', '34105', '7313271', '広島県', 'ヒロシマケン', '広島市安佐南区', 'ヒロシマシアサミナミク', '沼田町阿戸', 'ヌマタチョウアト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安佐南区沼田町吉山', '34', '34105', '7313272', '広島県', 'ヒロシマケン', '広島市安佐南区', 'ヒロシマシアサミナミク', '沼田町吉山', 'ヌマタチョウヨシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安佐北区安佐町毛木', '34', '34106', '7313351', '広島県', 'ヒロシマケン', '広島市安佐北区', 'ヒロシマシアサキタク', '安佐町毛木', 'アサチョウケギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安佐北区安佐町後山', '34', '34106', '7313352', '広島県', 'ヒロシマケン', '広島市安佐北区', 'ヒロシマシアサキタク', '安佐町後山', 'アサチョウウシロヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安佐北区安佐町宮野', '34', '34106', '7313353', '広島県', 'ヒロシマケン', '広島市安佐北区', 'ヒロシマシアサキタク', '安佐町宮野', 'アサチョウミヤノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安佐北区安佐町筒瀬', '34', '34106', '7313354', '広島県', 'ヒロシマケン', '広島市安佐北区', 'ヒロシマシアサキタク', '安佐町筒瀬', 'アサチョウツツセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安佐北区安佐町動物園', '34', '34106', '7313355', '広島県', 'ヒロシマケン', '広島市安佐北区', 'ヒロシマシアサキタク', '安佐町動物園', 'アサチョウドウブツエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安佐北区あさひが丘', '34', '34106', '7313361', '広島県', 'ヒロシマケン', '広島市安佐北区', 'ヒロシマシアサキタク', 'あさひが丘', 'アサヒガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安佐北区安佐町久地', '34', '34106', '7313362', '広島県', 'ヒロシマケン', '広島市安佐北区', 'ヒロシマシアサキタク', '安佐町久地', 'アサチョウクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安佐北区安佐町くすの木台', '34', '34106', '7313363', '広島県', 'ヒロシマケン', '広島市安佐北区', 'ヒロシマシアサキタク', '安佐町くすの木台', 'アサチョウクスノキダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県山県郡安芸太田町穴', '34', '34368', '7313411', '広島県', 'ヒロシマケン', '山県郡安芸太田町', 'ヤマガタグンアキオオタチョウ', '穴', 'アナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県山県郡安芸太田町坪野', '34', '34368', '7313412', '広島県', 'ヒロシマケン', '山県郡安芸太田町', 'ヤマガタグンアキオオタチョウ', '坪野', 'ツボノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県山県郡安芸太田町', '34', '34368', '7313500', '広島県', 'ヒロシマケン', '山県郡安芸太田町', 'ヤマガタグンアキオオタチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('91454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県山県郡安芸太田町加計', '34', '34368', '7313501', '広島県', 'ヒロシマケン', '山県郡安芸太田町', 'ヤマガタグンアキオオタチョウ', '加計', 'カケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県山県郡安芸太田町津浪', '34', '34368', '7313502', '広島県', 'ヒロシマケン', '山県郡安芸太田町', 'ヤマガタグンアキオオタチョウ', '津浪', 'ツナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県山県郡安芸太田町観音', '34', '34368', '7313503', '広島県', 'ヒロシマケン', '山県郡安芸太田町', 'ヤマガタグンアキオオタチョウ', '観音', 'カンノン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県山県郡安芸太田町猪山', '34', '34368', '7313551', '広島県', 'ヒロシマケン', '山県郡安芸太田町', 'ヤマガタグンアキオオタチョウ', '猪山', 'イノシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県山県郡安芸太田町平見谷', '34', '34368', '7313552', '広島県', 'ヒロシマケン', '山県郡安芸太田町', 'ヤマガタグンアキオオタチョウ', '平見谷', 'ヒラミダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県山県郡北広島町細見下山', '34', '34369', '7313561', '広島県', 'ヒロシマケン', '山県郡北広島町', 'ヤマガタグンキタヒロシマチョウ', '細見', 'ホソミ', null, null, '下山', 'シモヤマ');
INSERT INTO `ms_addresses` VALUES ('91461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県山県郡安芸太田町下筒賀', '34', '34368', '7313621', '広島県', 'ヒロシマケン', '山県郡安芸太田町', 'ヤマガタグンアキオオタチョウ', '下筒賀', 'シモツツガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県山県郡安芸太田町下殿河内', '34', '34368', '7313622', '広島県', 'ヒロシマケン', '山県郡安芸太田町', 'ヤマガタグンアキオオタチョウ', '下殿河内', 'シモトノゴウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県山県郡安芸太田町上殿', '34', '34368', '7313664', '広島県', 'ヒロシマケン', '山県郡安芸太田町', 'ヤマガタグンアキオオタチョウ', '上殿', 'カミトノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県山県郡安芸太田町上筒賀', '34', '34368', '7313701', '広島県', 'ヒロシマケン', '山県郡安芸太田町', 'ヤマガタグンアキオオタチョウ', '上筒賀', 'カミツツガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県山県郡安芸太田町中筒賀', '34', '34368', '7313702', '広島県', 'ヒロシマケン', '山県郡安芸太田町', 'ヤマガタグンアキオオタチョウ', '中筒賀', 'ナカツツガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県山県郡安芸太田町横川', '34', '34368', '7313801', '広島県', 'ヒロシマケン', '山県郡安芸太田町', 'ヤマガタグンアキオオタチョウ', '横川', 'ヨコゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県山県郡安芸太田町戸河内', '34', '34368', '7313810', '広島県', 'ヒロシマケン', '山県郡安芸太田町', 'ヤマガタグンアキオオタチョウ', '戸河内', 'トゴウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県山県郡安芸太田町遊谷', '34', '34368', '7313812', '広島県', 'ヒロシマケン', '山県郡安芸太田町', 'ヤマガタグンアキオオタチョウ', '遊谷', 'アゾウダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県山県郡安芸太田町柴木', '34', '34368', '7313813', '広島県', 'ヒロシマケン', '山県郡安芸太田町', 'ヤマガタグンアキオオタチョウ', '柴木', 'シワギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県山県郡安芸太田町土居', '34', '34368', '7313821', '広島県', 'ヒロシマケン', '山県郡安芸太田町', 'ヤマガタグンアキオオタチョウ', '土居', 'ドイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県山県郡安芸太田町寺領', '34', '34368', '7313824', '広島県', 'ヒロシマケン', '山県郡安芸太田町', 'ヤマガタグンアキオオタチョウ', '寺領', 'ジリョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県山県郡安芸太田町川手', '34', '34368', '7313831', '広島県', 'ヒロシマケン', '山県郡安芸太田町', 'ヤマガタグンアキオオタチョウ', '川手', 'カワテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県山県郡安芸太田町梶ノ木', '34', '34368', '7313832', '広島県', 'ヒロシマケン', '山県郡安芸太田町', 'ヤマガタグンアキオオタチョウ', '梶ノ木', 'カジノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県山県郡安芸太田町板ケ谷', '34', '34368', '7313833', '広島県', 'ヒロシマケン', '山県郡安芸太田町', 'ヤマガタグンアキオオタチョウ', '板ケ谷', 'イタガタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県山県郡安芸太田町松原', '34', '34368', '7313834', '広島県', 'ヒロシマケン', '山県郡安芸太田町', 'ヤマガタグンアキオオタチョウ', '松原', 'マツバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県山県郡安芸太田町小板', '34', '34368', '7313835', '広島県', 'ヒロシマケン', '山県郡安芸太田町', 'ヤマガタグンアキオオタチョウ', '小板', 'コイタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県山県郡安芸太田町田吹', '34', '34368', '7313842', '広島県', 'ヒロシマケン', '山県郡安芸太田町', 'ヤマガタグンアキオオタチョウ', '田吹', 'タブキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県山県郡安芸太田町吉和郷', '34', '34368', '7313843', '広島県', 'ヒロシマケン', '山県郡安芸太田町', 'ヤマガタグンアキオオタチョウ', '吉和郷', 'ヨシワゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県山県郡安芸太田町打梨', '34', '34368', '7313844', '広島県', 'ヒロシマケン', '山県郡安芸太田町', 'ヤマガタグンアキオオタチョウ', '打梨', 'ウツナシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県山県郡安芸太田町那須', '34', '34368', '7313845', '広島県', 'ヒロシマケン', '山県郡安芸太田町', 'ヤマガタグンアキオオタチョウ', '那須', 'ナス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸郡熊野町', '34', '34307', '7314200', '広島県', 'ヒロシマケン', '安芸郡熊野町', 'アキグンクマノチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('91482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸郡熊野町新宮', '34', '34307', '7314211', '広島県', 'ヒロシマケン', '安芸郡熊野町', 'アキグンクマノチョウ', '新宮', 'シングウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸郡熊野町初神', '34', '34307', '7314212', '広島県', 'ヒロシマケン', '安芸郡熊野町', 'アキグンクマノチョウ', '初神', 'ハツカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸郡熊野町萩原', '34', '34307', '7314213', '広島県', 'ヒロシマケン', '安芸郡熊野町', 'アキグンクマノチョウ', '萩原', 'ハギワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸郡熊野町中溝', '34', '34307', '7314214', '広島県', 'ヒロシマケン', '安芸郡熊野町', 'アキグンクマノチョウ', '中溝', 'ナカミゾ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸郡熊野町城之堀', '34', '34307', '7314215', '広島県', 'ヒロシマケン', '安芸郡熊野町', 'アキグンクマノチョウ', '城之堀', 'ジョウノホリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸郡熊野町出来庭', '34', '34307', '7314221', '広島県', 'ヒロシマケン', '安芸郡熊野町', 'アキグンクマノチョウ', '出来庭', 'デキニワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸郡熊野町呉地', '34', '34307', '7314222', '広島県', 'ヒロシマケン', '安芸郡熊野町', 'アキグンクマノチョウ', '呉地', 'クレジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸郡熊野町川角', '34', '34307', '7314223', '広島県', 'ヒロシマケン', '安芸郡熊野町', 'アキグンクマノチョウ', '川角', 'カワスミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸郡熊野町神田', '34', '34307', '7314224', '広島県', 'ヒロシマケン', '安芸郡熊野町', 'アキグンクマノチョウ', '神田', 'カンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸郡熊野町石神', '34', '34307', '7314225', '広島県', 'ヒロシマケン', '安芸郡熊野町', 'アキグンクマノチョウ', '石神', 'イシガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸郡熊野町東山', '34', '34307', '7314226', '広島県', 'ヒロシマケン', '安芸郡熊野町', 'アキグンクマノチョウ', '東山', 'ヒガシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸郡熊野町貴船', '34', '34307', '7314227', '広島県', 'ヒロシマケン', '安芸郡熊野町', 'アキグンクマノチョウ', '貴船', 'キフネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸郡熊野町柿迫', '34', '34307', '7314228', '広島県', 'ヒロシマケン', '安芸郡熊野町', 'アキグンクマノチョウ', '柿迫', 'カキサコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸郡熊野町平谷', '34', '34307', '7314229', '広島県', 'ヒロシマケン', '安芸郡熊野町', 'アキグンクマノチョウ', '平谷', 'ヒラダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安芸区阿戸町', '34', '34107', '7314231', '広島県', 'ヒロシマケン', '広島市安芸区', 'ヒロシマシアキク', '阿戸町', 'アトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸郡坂町', '34', '34309', '7314300', '広島県', 'ヒロシマケン', '安芸郡坂町', 'アキグンサカチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('91501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸郡坂町', '34', '34309', '7314301', '広島県', 'ヒロシマケン', '安芸郡坂町', 'アキグンサカチョウ', null, '　', '（直番地）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('91502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸郡坂町北新地', '34', '34309', '7314311', '広島県', 'ヒロシマケン', '安芸郡坂町', 'アキグンサカチョウ', '北新地', 'キタシンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸郡坂町平成ケ浜', '34', '34309', '7314312', '広島県', 'ヒロシマケン', '安芸郡坂町', 'アキグンサカチョウ', '平成ケ浜', 'ヘイセイガハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸郡坂町坂東', '34', '34309', '7314313', '広島県', 'ヒロシマケン', '安芸郡坂町', 'アキグンサカチョウ', '坂東', 'サカヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸郡坂町坂西', '34', '34309', '7314314', '広島県', 'ヒロシマケン', '安芸郡坂町', 'アキグンサカチョウ', '坂西', 'サカニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸郡坂町植田', '34', '34309', '7314321', '広島県', 'ヒロシマケン', '安芸郡坂町', 'アキグンサカチョウ', '植田', 'ウエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸郡坂町横浜東', '34', '34309', '7314322', '広島県', 'ヒロシマケン', '安芸郡坂町', 'アキグンサカチョウ', '横浜東', 'ヨコハマヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸郡坂町横浜中央', '34', '34309', '7314323', '広島県', 'ヒロシマケン', '安芸郡坂町', 'アキグンサカチョウ', '横浜中央', 'ヨコハマチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸郡坂町横浜西', '34', '34309', '7314324', '広島県', 'ヒロシマケン', '安芸郡坂町', 'アキグンサカチョウ', '横浜西', 'ヨコハマニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸郡坂町鯛尾', '34', '34309', '7314325', '広島県', 'ヒロシマケン', '安芸郡坂町', 'アキグンサカチョウ', '鯛尾', 'タイビ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸郡坂町小屋浦', '34', '34309', '7314331', '広島県', 'ヒロシマケン', '安芸郡坂町', 'アキグンサカチョウ', '小屋浦', 'コヤウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市佐伯区', '34', '34108', '7315100', '広島県', 'ヒロシマケン', '広島市佐伯区', 'ヒロシマシサエキク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('91517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市佐伯区五月が丘', '34', '34108', '7315101', '広島県', 'ヒロシマケン', '広島市佐伯区', 'ヒロシマシサエキク', '五月が丘', 'サツキガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市佐伯区五日市町石内', '34', '34108', '7315102', '広島県', 'ヒロシマケン', '広島市佐伯区', 'ヒロシマシサエキク', '五日市町石内', 'イツカイチチョウイシウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市佐伯区藤の木', '34', '34108', '7315103', '広島県', 'ヒロシマケン', '広島市佐伯区', 'ヒロシマシサエキク', '藤の木', 'フジノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市佐伯区五日市町上小深川', '34', '34108', '7315104', '広島県', 'ヒロシマケン', '広島市佐伯区', 'ヒロシマシサエキク', '五日市町上小深川', 'イツカイチチョウカミコブカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市佐伯区五日市町下小深川', '34', '34108', '7315105', '広島県', 'ヒロシマケン', '広島市佐伯区', 'ヒロシマシサエキク', '五日市町下小深川', 'イツカイチチョウシモコブカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市佐伯区利松', '34', '34108', '7315106', '広島県', 'ヒロシマケン', '広島市佐伯区', 'ヒロシマシサエキク', '利松', 'トシマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市佐伯区石内上', '34', '34108', '7315107', '広島県', 'ヒロシマケン', '広島市佐伯区', 'ヒロシマシサエキク', '石内上', 'イシウチカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市佐伯区石内南', '34', '34108', '7315108', '広島県', 'ヒロシマケン', '広島市佐伯区', 'ヒロシマシサエキク', '石内南', 'イシウチミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市佐伯区美鈴が丘東', '34', '34108', '7315111', '広島県', 'ヒロシマケン', '広島市佐伯区', 'ヒロシマシサエキク', '美鈴が丘東', 'ミスズガオカヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市佐伯区美鈴が丘南', '34', '34108', '7315112', '広島県', 'ヒロシマケン', '広島市佐伯区', 'ヒロシマシサエキク', '美鈴が丘南', 'ミスズガオカミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市佐伯区美鈴が丘緑', '34', '34108', '7315113', '広島県', 'ヒロシマケン', '広島市佐伯区', 'ヒロシマシサエキク', '美鈴が丘緑', 'ミスズガオカミドリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市佐伯区美鈴が丘西', '34', '34108', '7315114', '広島県', 'ヒロシマケン', '広島市佐伯区', 'ヒロシマシサエキク', '美鈴が丘西', 'ミスズガオカニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市佐伯区五日市町中地', '34', '34108', '7315115', '広島県', 'ヒロシマケン', '広島市佐伯区', 'ヒロシマシサエキク', '五日市町中地', 'イツカイチチョウナカジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市佐伯区八幡東', '34', '34108', '7315115', '広島県', 'ヒロシマケン', '広島市佐伯区', 'ヒロシマシサエキク', '八幡東', 'ヤハタヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市佐伯区五日市町寺田', '34', '34108', '7315116', '広島県', 'ヒロシマケン', '広島市佐伯区', 'ヒロシマシサエキク', '五日市町寺田', 'イツカイチチョウテラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市佐伯区八幡', '34', '34108', '7315116', '広島県', 'ヒロシマケン', '広島市佐伯区', 'ヒロシマシサエキク', '八幡', 'ヤハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市佐伯区八幡が丘', '34', '34108', '7315117', '広島県', 'ヒロシマケン', '広島市佐伯区', 'ヒロシマシサエキク', '八幡が丘', 'ヤハタガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市佐伯区五日市町美鈴園', '34', '34108', '7315121', '広島県', 'ヒロシマケン', '広島市佐伯区', 'ヒロシマシサエキク', '五日市町美鈴園', 'イツカイチチョウミスズエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市佐伯区五日市町皆賀', '34', '34108', '7315122', '広島県', 'ヒロシマケン', '広島市佐伯区', 'ヒロシマシサエキク', '五日市町皆賀', 'イツカイチチョウミナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市佐伯区五日市町昭和台', '34', '34108', '7315123', '広島県', 'ヒロシマケン', '広島市佐伯区', 'ヒロシマシサエキク', '五日市町昭和台', 'イツカイチチョウショウワダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市佐伯区皆賀', '34', '34108', '7315124', '広島県', 'ヒロシマケン', '広島市佐伯区', 'ヒロシマシサエキク', '皆賀', 'ミナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市佐伯区五日市駅前', '34', '34108', '7315125', '広島県', 'ヒロシマケン', '広島市佐伯区', 'ヒロシマシサエキク', '五日市駅前', 'イツカイチエキマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市佐伯区新宮苑', '34', '34108', '7315126', '広島県', 'ヒロシマケン', '広島市佐伯区', 'ヒロシマシサエキク', '新宮苑', 'シングウエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市佐伯区五日市', '34', '34108', '7315127', '広島県', 'ヒロシマケン', '広島市佐伯区', 'ヒロシマシサエキク', '五日市', 'イツカイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市佐伯区五日市中央', '34', '34108', '7315128', '広島県', 'ヒロシマケン', '広島市佐伯区', 'ヒロシマシサエキク', '五日市中央', 'イツカイチチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市佐伯区藤垂園', '34', '34108', '7315131', '広島県', 'ヒロシマケン', '広島市佐伯区', 'ヒロシマシサエキク', '藤垂園', 'トウスイエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市佐伯区吉見園', '34', '34108', '7315132', '広島県', 'ヒロシマケン', '広島市佐伯区', 'ヒロシマシサエキク', '吉見園', 'ヨシミエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市佐伯区旭園', '34', '34108', '7315133', '広島県', 'ヒロシマケン', '広島市佐伯区', 'ヒロシマシサエキク', '旭園', 'アサヒエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市佐伯区海老山町', '34', '34108', '7315134', '広島県', 'ヒロシマケン', '広島市佐伯区', 'ヒロシマシサエキク', '海老山町', 'カイロウヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市佐伯区海老園', '34', '34108', '7315135', '広島県', 'ヒロシマケン', '広島市佐伯区', 'ヒロシマシサエキク', '海老園', 'カイロウエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市佐伯区楽々園', '34', '34108', '7315136', '広島県', 'ヒロシマケン', '広島市佐伯区', 'ヒロシマシサエキク', '楽々園', 'ラクラクエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市佐伯区美の里', '34', '34108', '7315137', '広島県', 'ヒロシマケン', '広島市佐伯区', 'ヒロシマシサエキク', '美の里', 'ミノリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市佐伯区海老山南', '34', '34108', '7315138', '広島県', 'ヒロシマケン', '広島市佐伯区', 'ヒロシマシサエキク', '海老山南', 'カイロウヤマミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市佐伯区千同', '34', '34108', '7315141', '広島県', 'ヒロシマケン', '広島市佐伯区', 'ヒロシマシサエキク', '千同', 'センドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市佐伯区坪井', '34', '34108', '7315142', '広島県', 'ヒロシマケン', '広島市佐伯区', 'ヒロシマシサエキク', '坪井', 'ツボイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市佐伯区坪井町', '34', '34108', '7315142', '広島県', 'ヒロシマケン', '広島市佐伯区', 'ヒロシマシサエキク', '坪井町', 'ツボイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市佐伯区三宅', '34', '34108', '7315143', '広島県', 'ヒロシマケン', '広島市佐伯区', 'ヒロシマシサエキク', '三宅', 'ミヤケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市佐伯区三宅町', '34', '34108', '7315143', '広島県', 'ヒロシマケン', '広島市佐伯区', 'ヒロシマシサエキク', '三宅町', 'ミヤケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市佐伯区三筋', '34', '34108', '7315144', '広島県', 'ヒロシマケン', '広島市佐伯区', 'ヒロシマシサエキク', '三筋', 'ミスジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市佐伯区隅の浜', '34', '34108', '7315145', '広島県', 'ヒロシマケン', '広島市佐伯区', 'ヒロシマシサエキク', '隅の浜', 'スミノハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市佐伯区屋代', '34', '34108', '7315146', '広島県', 'ヒロシマケン', '広島市佐伯区', 'ヒロシマシサエキク', '屋代', 'ヤシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市佐伯区屋代町', '34', '34108', '7315147', '広島県', 'ヒロシマケン', '広島市佐伯区', 'ヒロシマシサエキク', '屋代町', 'ヤシロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市佐伯区五日市町上河内', '34', '34108', '7315151', '広島県', 'ヒロシマケン', '広島市佐伯区', 'ヒロシマシサエキク', '五日市町上河内', 'イツカイチチョウカミゴウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市佐伯区五日市町下河内', '34', '34108', '7315152', '広島県', 'ヒロシマケン', '広島市佐伯区', 'ヒロシマシサエキク', '五日市町下河内', 'イツカイチチョウシモゴウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市佐伯区河内南', '34', '34108', '7315153', '広島県', 'ヒロシマケン', '広島市佐伯区', 'ヒロシマシサエキク', '河内南', 'コウチミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市佐伯区薬師が丘', '34', '34108', '7315154', '広島県', 'ヒロシマケン', '広島市佐伯区', 'ヒロシマシサエキク', '薬師が丘', 'ヤクシガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市佐伯区城山', '34', '34108', '7315155', '広島県', 'ヒロシマケン', '広島市佐伯区', 'ヒロシマシサエキク', '城山', 'ジョウヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市佐伯区倉重', '34', '34108', '7315156', '広島県', 'ヒロシマケン', '広島市佐伯区', 'ヒロシマシサエキク', '倉重', 'クラシゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市佐伯区観音台', '34', '34108', '7315157', '広島県', 'ヒロシマケン', '広島市佐伯区', 'ヒロシマシサエキク', '観音台', 'カンノンダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市佐伯区五日市港', '34', '34108', '7315161', '広島県', 'ヒロシマケン', '広島市佐伯区', 'ヒロシマシサエキク', '五日市港', 'イツカイチコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市東区', '34', '34102', '7320000', '広島県', 'ヒロシマケン', '広島市東区', 'ヒロシマシヒガシク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('91573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市東区戸坂惣田', '34', '34102', '7320001', '広島県', 'ヒロシマケン', '広島市東区', 'ヒロシマシヒガシク', '戸坂惣田', 'ヘサカソウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市東区戸坂山根', '34', '34102', '7320002', '広島県', 'ヒロシマケン', '広島市東区', 'ヒロシマシヒガシク', '戸坂山根', 'ヘサカヤマネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市東区戸坂中町', '34', '34102', '7320003', '広島県', 'ヒロシマケン', '広島市東区', 'ヒロシマシヒガシク', '戸坂中町', 'ヘサカナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市東区戸坂山崎町', '34', '34102', '7320004', '広島県', 'ヒロシマケン', '広島市東区', 'ヒロシマシヒガシク', '戸坂山崎町', 'ヘサカヤマサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市東区戸坂桜東町', '34', '34102', '7320005', '広島県', 'ヒロシマケン', '広島市東区', 'ヒロシマシヒガシク', '戸坂桜東町', 'ヘサカサクラヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市東区戸坂桜西町', '34', '34102', '7320006', '広島県', 'ヒロシマケン', '広島市東区', 'ヒロシマシヒガシク', '戸坂桜西町', 'ヘサカサクラニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市東区戸坂桜上町', '34', '34102', '7320007', '広島県', 'ヒロシマケン', '広島市東区', 'ヒロシマシヒガシク', '戸坂桜上町', 'ヘサカサクラウエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市東区戸坂くるめ木', '34', '34102', '7320008', '広島県', 'ヒロシマケン', '広島市東区', 'ヒロシマシヒガシク', '戸坂くるめ木', 'ヘサカクルメギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市東区戸坂千足', '34', '34102', '7320009', '広島県', 'ヒロシマケン', '広島市東区', 'ヒロシマシヒガシク', '戸坂千足', 'ヘサカセンゾク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市東区戸坂町', '34', '34102', '7320011', '広島県', 'ヒロシマケン', '広島市東区', 'ヒロシマシヒガシク', '戸坂町', 'ヘサカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市東区戸坂新町', '34', '34102', '7320012', '広島県', 'ヒロシマケン', '広島市東区', 'ヒロシマシヒガシク', '戸坂新町', 'ヘサカシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市東区戸坂南', '34', '34102', '7320013', '広島県', 'ヒロシマケン', '広島市東区', 'ヒロシマシヒガシク', '戸坂南', 'ヘサカミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市東区戸坂大上', '34', '34102', '7320014', '広島県', 'ヒロシマケン', '広島市東区', 'ヒロシマシヒガシク', '戸坂大上', 'ヘサカオオアゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市東区戸坂城山町', '34', '34102', '7320015', '広島県', 'ヒロシマケン', '広島市東区', 'ヒロシマシヒガシク', '戸坂城山町', 'ヘサカシロヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市東区戸坂出江', '34', '34102', '7320016', '広島県', 'ヒロシマケン', '広島市東区', 'ヒロシマシヒガシク', '戸坂出江', 'ヘサカイヅエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市東区戸坂数甲', '34', '34102', '7320017', '広島県', 'ヒロシマケン', '広島市東区', 'ヒロシマシヒガシク', '戸坂数甲', 'ヘサカカズコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市東区戸坂長尾台', '34', '34102', '7320018', '広島県', 'ヒロシマケン', '広島市東区', 'ヒロシマシヒガシク', '戸坂長尾台', 'ヘサカナガオダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市東区中山新町', '34', '34102', '7320021', '広島県', 'ヒロシマケン', '広島市東区', 'ヒロシマシヒガシク', '中山新町', 'ナカヤマシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市東区中山鏡が丘', '34', '34102', '7320022', '広島県', 'ヒロシマケン', '広島市東区', 'ヒロシマシヒガシク', '中山鏡が丘', 'ナカヤマカガミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市東区中山東', '34', '34102', '7320023', '広島県', 'ヒロシマケン', '広島市東区', 'ヒロシマシヒガシク', '中山東', 'ナカヤマヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市東区中山南', '34', '34102', '7320024', '広島県', 'ヒロシマケン', '広島市東区', 'ヒロシマシヒガシク', '中山南', 'ナカヤマミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市東区中山西', '34', '34102', '7320025', '広島県', 'ヒロシマケン', '広島市東区', 'ヒロシマシヒガシク', '中山西', 'ナカヤマニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市東区中山中町', '34', '34102', '7320026', '広島県', 'ヒロシマケン', '広島市東区', 'ヒロシマシヒガシク', '中山中町', 'ナカヤマナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市東区中山上', '34', '34102', '7320027', '広島県', 'ヒロシマケン', '広島市東区', 'ヒロシマシヒガシク', '中山上', 'ナカヤマカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市東区中山北町', '34', '34102', '7320028', '広島県', 'ヒロシマケン', '広島市東区', 'ヒロシマシヒガシク', '中山北町', 'ナカヤマキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市東区福田', '34', '34102', '7320029', '広島県', 'ヒロシマケン', '広島市東区', 'ヒロシマシヒガシク', '福田', 'フクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市東区馬木', '34', '34102', '7320031', '広島県', 'ヒロシマケン', '広島市東区', 'ヒロシマシヒガシク', '馬木', 'ウマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市東区上温品', '34', '34102', '7320032', '広島県', 'ヒロシマケン', '広島市東区', 'ヒロシマシヒガシク', '上温品', 'カミヌクシナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市東区温品', '34', '34102', '7320033', '広島県', 'ヒロシマケン', '広島市東区', 'ヒロシマシヒガシク', '温品', 'ヌクシナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市東区温品町', '34', '34102', '7320034', '広島県', 'ヒロシマケン', '広島市東区', 'ヒロシマシヒガシク', '温品町', 'ヌクシナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市東区馬木町', '34', '34102', '7320035', '広島県', 'ヒロシマケン', '広島市東区', 'ヒロシマシヒガシク', '馬木町', 'ウマキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市東区福田町', '34', '34102', '7320036', '広島県', 'ヒロシマケン', '広島市東区', 'ヒロシマシヒガシク', '福田町', 'フクダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市東区矢賀町', '34', '34102', '7320041', '広島県', 'ヒロシマケン', '広島市東区', 'ヒロシマシヒガシク', '矢賀町', 'ヤガマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市東区矢賀', '34', '34102', '7320042', '広島県', 'ヒロシマケン', '広島市東区', 'ヒロシマシヒガシク', '矢賀', 'ヤガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市東区東山町', '34', '34102', '7320043', '広島県', 'ヒロシマケン', '広島市東区', 'ヒロシマシヒガシク', '東山町', 'ヒガシヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市東区矢賀新町', '34', '34102', '7320044', '広島県', 'ヒロシマケン', '広島市東区', 'ヒロシマシヒガシク', '矢賀新町', 'ヤガシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市東区曙', '34', '34102', '7320045', '広島県', 'ヒロシマケン', '広島市東区', 'ヒロシマシヒガシク', '曙', 'アケボノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市東区尾長東', '34', '34102', '7320046', '広島県', 'ヒロシマケン', '広島市東区', 'ヒロシマシヒガシク', '尾長東', 'オナガヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市東区尾長西', '34', '34102', '7320047', '広島県', 'ヒロシマケン', '広島市東区', 'ヒロシマシヒガシク', '尾長西', 'オナガニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市東区山根町', '34', '34102', '7320048', '広島県', 'ヒロシマケン', '広島市東区', 'ヒロシマシヒガシク', '山根町', 'ヤマネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市東区尾長町', '34', '34102', '7320049', '広島県', 'ヒロシマケン', '広島市東区', 'ヒロシマシヒガシク', '尾長町', 'オナガマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市東区光が丘', '34', '34102', '7320051', '広島県', 'ヒロシマケン', '広島市東区', 'ヒロシマシヒガシク', '光が丘', 'ヒカリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市東区光町', '34', '34102', '7320052', '広島県', 'ヒロシマケン', '広島市東区', 'ヒロシマシヒガシク', '光町', 'ヒカリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市東区若草町', '34', '34102', '7320053', '広島県', 'ヒロシマケン', '広島市東区', 'ヒロシマシヒガシク', '若草町', 'ワカクサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市東区愛宕町', '34', '34102', '7320054', '広島県', 'ヒロシマケン', '広島市東区', 'ヒロシマシヒガシク', '愛宕町', 'アタゴマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市東区東蟹屋町', '34', '34102', '7320055', '広島県', 'ヒロシマケン', '広島市東区', 'ヒロシマシヒガシク', '東蟹屋町', 'ヒガシカニヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市東区上大須賀町', '34', '34102', '7320056', '広島県', 'ヒロシマケン', '広島市東区', 'ヒロシマシヒガシク', '上大須賀町', 'カミオオスガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市東区二葉の里', '34', '34102', '7320057', '広島県', 'ヒロシマケン', '広島市東区', 'ヒロシマシヒガシク', '二葉の里', 'フタバノサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市東区牛田山', '34', '34102', '7320061', '広島県', 'ヒロシマケン', '広島市東区', 'ヒロシマシヒガシク', '牛田山', 'ウシタヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市東区牛田早稲田', '34', '34102', '7320062', '広島県', 'ヒロシマケン', '広島市東区', 'ヒロシマシヒガシク', '牛田早稲田', 'ウシタワセダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市東区牛田東', '34', '34102', '7320063', '広島県', 'ヒロシマケン', '広島市東区', 'ヒロシマシヒガシク', '牛田東', 'ウシタヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市東区牛田南', '34', '34102', '7320064', '広島県', 'ヒロシマケン', '広島市東区', 'ヒロシマシヒガシク', '牛田南', 'ウシタミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市東区牛田中', '34', '34102', '7320065', '広島県', 'ヒロシマケン', '広島市東区', 'ヒロシマシヒガシク', '牛田中', 'ウシタナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市東区牛田本町', '34', '34102', '7320066', '広島県', 'ヒロシマケン', '広島市東区', 'ヒロシマシヒガシク', '牛田本町', 'ウシタホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市東区牛田旭', '34', '34102', '7320067', '広島県', 'ヒロシマケン', '広島市東区', 'ヒロシマシヒガシク', '牛田旭', 'ウシタアサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市東区牛田新町', '34', '34102', '7320068', '広島県', 'ヒロシマケン', '広島市東区', 'ヒロシマシヒガシク', '牛田新町', 'ウシタシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市南区東駅町', '34', '34103', '7320801', '広島県', 'ヒロシマケン', '広島市南区', 'ヒロシマシミナミク', '東駅町', 'ヒガシエキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市南区大州', '34', '34103', '7320802', '広島県', 'ヒロシマケン', '広島市南区', 'ヒロシマシミナミク', '大州', 'オオズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市南区南蟹屋', '34', '34103', '7320803', '広島県', 'ヒロシマケン', '広島市南区', 'ヒロシマシミナミク', '南蟹屋', 'ミナミカニヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市南区西蟹屋', '34', '34103', '7320804', '広島県', 'ヒロシマケン', '広島市南区', 'ヒロシマシミナミク', '西蟹屋', 'ニシカニヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市南区東荒神町', '34', '34103', '7320805', '広島県', 'ヒロシマケン', '広島市南区', 'ヒロシマシミナミク', '東荒神町', 'ヒガシコウジンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市南区西荒神町', '34', '34103', '7320806', '広島県', 'ヒロシマケン', '広島市南区', 'ヒロシマシミナミク', '西荒神町', 'ニシコウジンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市南区荒神町', '34', '34103', '7320807', '広島県', 'ヒロシマケン', '広島市南区', 'ヒロシマシミナミク', '荒神町', 'コウジンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市南区段原', '34', '34103', '7320811', '広島県', 'ヒロシマケン', '広島市南区', 'ヒロシマシミナミク', '段原', 'ダンバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市南区段原日出町', '34', '34103', '7320812', '広島県', 'ヒロシマケン', '広島市南区', 'ヒロシマシミナミク', '段原日出町', 'ダンバラヒノデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市南区段原山崎町', '34', '34103', '7320813', '広島県', 'ヒロシマケン', '広島市南区', 'ヒロシマシミナミク', '段原山崎町', 'ダンバラヤマサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市南区段原南', '34', '34103', '7320814', '広島県', 'ヒロシマケン', '広島市南区', 'ヒロシマシミナミク', '段原南', 'ダンバラミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市南区比治山公園', '34', '34103', '7320815', '広島県', 'ヒロシマケン', '広島市南区', 'ヒロシマシミナミク', '比治山公園', 'ヒジヤマコウエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市南区比治山本町', '34', '34103', '7320816', '広島県', 'ヒロシマケン', '広島市南区', 'ヒロシマシミナミク', '比治山本町', 'ヒジヤマホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市南区比治山町', '34', '34103', '7320817', '広島県', 'ヒロシマケン', '広島市南区', 'ヒロシマシミナミク', '比治山町', 'ヒジヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市南区段原日出', '34', '34103', '7320818', '広島県', 'ヒロシマケン', '広島市南区', 'ヒロシマシミナミク', '段原日出', 'ダンバラヒノデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市南区段原山崎', '34', '34103', '7320819', '広島県', 'ヒロシマケン', '広島市南区', 'ヒロシマシミナミク', '段原山崎', 'ダンバラヤマサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市南区大須賀町', '34', '34103', '7320821', '広島県', 'ヒロシマケン', '広島市南区', 'ヒロシマシミナミク', '大須賀町', 'オオスガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市南区松原町', '34', '34103', '7320822', '広島県', 'ヒロシマケン', '広島市南区', 'ヒロシマシミナミク', '松原町', 'マツバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市南区猿猴橋町', '34', '34103', '7320823', '広島県', 'ヒロシマケン', '広島市南区', 'ヒロシマシミナミク', '猿猴橋町', 'エンコウバシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市南区的場町', '34', '34103', '7320824', '広島県', 'ヒロシマケン', '広島市南区', 'ヒロシマシミナミク', '的場町', 'マトバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市南区金屋町', '34', '34103', '7320825', '広島県', 'ヒロシマケン', '広島市南区', 'ヒロシマシミナミク', '金屋町', 'キンヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市南区松川町', '34', '34103', '7320826', '広島県', 'ヒロシマケン', '広島市南区', 'ヒロシマシミナミク', '松川町', 'マツカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市南区稲荷町', '34', '34103', '7320827', '広島県', 'ヒロシマケン', '広島市南区', 'ヒロシマシミナミク', '稲荷町', 'イナリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市南区京橋町', '34', '34103', '7320828', '広島県', 'ヒロシマケン', '広島市南区', 'ヒロシマシミナミク', '京橋町', 'キョウバシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市西区', '34', '34104', '7330000', '広島県', 'ヒロシマケン', '広島市西区', 'ヒロシマシニシク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('91670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市西区大芝', '34', '34104', '7330001', '広島県', 'ヒロシマケン', '広島市西区', 'ヒロシマシニシク', '大芝', 'オオシバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市西区楠木町', '34', '34104', '7330002', '広島県', 'ヒロシマケン', '広島市西区', 'ヒロシマシニシク', '楠木町', 'クスノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市西区三篠町', '34', '34104', '7330003', '広島県', 'ヒロシマケン', '広島市西区', 'ヒロシマシニシク', '三篠町', 'ミササマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市西区打越町', '34', '34104', '7330004', '広島県', 'ヒロシマケン', '広島市西区', 'ヒロシマシニシク', '打越町', 'ウチコシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市西区三滝町', '34', '34104', '7330005', '広島県', 'ヒロシマケン', '広島市西区', 'ヒロシマシニシク', '三滝町', 'ミタキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市西区三篠北町', '34', '34104', '7330006', '広島県', 'ヒロシマケン', '広島市西区', 'ヒロシマシニシク', '三篠北町', 'ミササキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市西区大宮', '34', '34104', '7330007', '広島県', 'ヒロシマケン', '広島市西区', 'ヒロシマシニシク', '大宮', 'オオミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市西区横川町', '34', '34104', '7330011', '広島県', 'ヒロシマケン', '広島市西区', 'ヒロシマシニシク', '横川町', 'ヨコガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市西区中広町', '34', '34104', '7330012', '広島県', 'ヒロシマケン', '広島市西区', 'ヒロシマシニシク', '中広町', 'ナカヒロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市西区横川新町', '34', '34104', '7330013', '広島県', 'ヒロシマケン', '広島市西区', 'ヒロシマシニシク', '横川新町', 'ヨコガワシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市西区上天満町', '34', '34104', '7330021', '広島県', 'ヒロシマケン', '広島市西区', 'ヒロシマシニシク', '上天満町', 'カミテンマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市西区天満町', '34', '34104', '7330022', '広島県', 'ヒロシマケン', '広島市西区', 'ヒロシマシニシク', '天満町', 'テンマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市西区都町', '34', '34104', '7330023', '広島県', 'ヒロシマケン', '広島市西区', 'ヒロシマシニシク', '都町', 'ミヤコマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市西区福島町', '34', '34104', '7330024', '広島県', 'ヒロシマケン', '広島市西区', 'ヒロシマシニシク', '福島町', 'フクシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市西区小河内町', '34', '34104', '7330025', '広島県', 'ヒロシマケン', '広島市西区', 'ヒロシマシニシク', '小河内町', 'オガワチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市西区観音町', '34', '34104', '7330031', '広島県', 'ヒロシマケン', '広島市西区', 'ヒロシマシニシク', '観音町', 'カンオンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市西区東観音町', '34', '34104', '7330032', '広島県', 'ヒロシマケン', '広島市西区', 'ヒロシマシニシク', '東観音町', 'ヒガシカンオンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市西区観音本町', '34', '34104', '7330033', '広島県', 'ヒロシマケン', '広島市西区', 'ヒロシマシニシク', '観音本町', 'カンオンホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市西区南観音町', '34', '34104', '7330034', '広島県', 'ヒロシマケン', '広島市西区', 'ヒロシマシニシク', '南観音町', 'ミナミカンオンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市西区南観音', '34', '34104', '7330035', '広島県', 'ヒロシマケン', '広島市西区', 'ヒロシマシニシク', '南観音', 'ミナミカンオン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市西区観音新町', '34', '34104', '7330036', '広島県', 'ヒロシマケン', '広島市西区', 'ヒロシマシニシク', '観音新町', 'カンオンシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市西区西観音町', '34', '34104', '7330037', '広島県', 'ヒロシマケン', '広島市西区', 'ヒロシマシニシク', '西観音町', 'ニシカンオンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市西区新庄町', '34', '34104', '7330801', '広島県', 'ヒロシマケン', '広島市西区', 'ヒロシマシニシク', '新庄町', 'シンジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市西区三滝本町', '34', '34104', '7330802', '広島県', 'ヒロシマケン', '広島市西区', 'ヒロシマシニシク', '三滝本町', 'ミタキホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市西区竜王町', '34', '34104', '7330803', '広島県', 'ヒロシマケン', '広島市西区', 'ヒロシマシニシク', '竜王町', 'リュウオウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市西区山手町', '34', '34104', '7330804', '広島県', 'ヒロシマケン', '広島市西区', 'ヒロシマシニシク', '山手町', 'ヤマテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市西区三滝山', '34', '34104', '7330805', '広島県', 'ヒロシマケン', '広島市西区', 'ヒロシマシニシク', '三滝山', 'ミタキヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市西区己斐東', '34', '34104', '7330811', '広島県', 'ヒロシマケン', '広島市西区', 'ヒロシマシニシク', '己斐東', 'コイヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市西区己斐本町', '34', '34104', '7330812', '広島県', 'ヒロシマケン', '広島市西区', 'ヒロシマシニシク', '己斐本町', 'コイホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市西区己斐中', '34', '34104', '7330813', '広島県', 'ヒロシマケン', '広島市西区', 'ヒロシマシニシク', '己斐中', 'コイナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市西区己斐西町', '34', '34104', '7330814', '広島県', 'ヒロシマケン', '広島市西区', 'ヒロシマシニシク', '己斐西町', 'コイニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市西区己斐上', '34', '34104', '7330815', '広島県', 'ヒロシマケン', '広島市西区', 'ヒロシマシニシク', '己斐上', 'コイウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市西区己斐大迫', '34', '34104', '7330816', '広島県', 'ヒロシマケン', '広島市西区', 'ヒロシマシニシク', '己斐大迫', 'コイオオサコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市西区庚午北', '34', '34104', '7330821', '広島県', 'ヒロシマケン', '広島市西区', 'ヒロシマシニシク', '庚午北', 'コウゴキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市西区庚午中', '34', '34104', '7330822', '広島県', 'ヒロシマケン', '広島市西区', 'ヒロシマシニシク', '庚午中', 'コウゴナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市西区庚午南', '34', '34104', '7330823', '広島県', 'ヒロシマケン', '広島市西区', 'ヒロシマシニシク', '庚午南', 'コウゴミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市西区扇', '34', '34104', '7330831', '広島県', 'ヒロシマケン', '広島市西区', 'ヒロシマシニシク', '扇', 'オオギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市西区草津港', '34', '34104', '7330832', '広島県', 'ヒロシマケン', '広島市西区', 'ヒロシマシニシク', '草津港', 'クサツコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市西区商工センター', '34', '34104', '7330833', '広島県', 'ヒロシマケン', '広島市西区', 'ヒロシマシニシク', '商工センター', 'ショウコウセンター', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市西区草津新町', '34', '34104', '7330834', '広島県', 'ヒロシマケン', '広島市西区', 'ヒロシマシニシク', '草津新町', 'クサツシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市西区井口明神', '34', '34104', '7330841', '広島県', 'ヒロシマケン', '広島市西区', 'ヒロシマシニシク', '井口明神', 'イノクチミョウジン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市西区井口', '34', '34104', '7330842', '広島県', 'ヒロシマケン', '広島市西区', 'ヒロシマシニシク', '井口', 'イノクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市西区井口鈴が台', '34', '34104', '7330843', '広島県', 'ヒロシマケン', '広島市西区', 'ヒロシマシニシク', '井口鈴が台', 'イノクチスズガダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市西区井口台', '34', '34104', '7330844', '広島県', 'ヒロシマケン', '広島市西区', 'ヒロシマシニシク', '井口台', 'イノクチダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市西区井口町', '34', '34104', '7330845', '広島県', 'ヒロシマケン', '広島市西区', 'ヒロシマシニシク', '井口町', 'イノクチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市西区田方', '34', '34104', '7330851', '広島県', 'ヒロシマケン', '広島市西区', 'ヒロシマシニシク', '田方', 'タカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市西区鈴が峰町', '34', '34104', '7330852', '広島県', 'ヒロシマケン', '広島市西区', 'ヒロシマシニシク', '鈴が峰町', 'スズガミネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市西区山田新町', '34', '34104', '7330853', '広島県', 'ヒロシマケン', '広島市西区', 'ヒロシマシニシク', '山田新町', 'ヤマダシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市西区山田町', '34', '34104', '7330854', '広島県', 'ヒロシマケン', '広島市西区', 'ヒロシマシニシク', '山田町', 'ヤマダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市西区草津東', '34', '34104', '7330861', '広島県', 'ヒロシマケン', '広島市西区', 'ヒロシマシニシク', '草津東', 'クサツヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市西区草津浜町', '34', '34104', '7330862', '広島県', 'ヒロシマケン', '広島市西区', 'ヒロシマシニシク', '草津浜町', 'クサツハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市西区草津南', '34', '34104', '7330863', '広島県', 'ヒロシマケン', '広島市西区', 'ヒロシマシニシク', '草津南', 'クサツミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市西区草津梅が台', '34', '34104', '7330864', '広島県', 'ヒロシマケン', '広島市西区', 'ヒロシマシニシク', '草津梅が台', 'クサツウメガダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市西区草津本町', '34', '34104', '7330865', '広島県', 'ヒロシマケン', '広島市西区', 'ヒロシマシニシク', '草津本町', 'クサツホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市西区高須', '34', '34104', '7330871', '広島県', 'ヒロシマケン', '広島市西区', 'ヒロシマシニシク', '高須', 'タカス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市西区古江東町', '34', '34104', '7330872', '広島県', 'ヒロシマケン', '広島市西区', 'ヒロシマシニシク', '古江東町', 'フルエヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市西区古江新町', '34', '34104', '7330873', '広島県', 'ヒロシマケン', '広島市西区', 'ヒロシマシニシク', '古江新町', 'フルエシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市西区古江西町', '34', '34104', '7330874', '広島県', 'ヒロシマケン', '広島市西区', 'ヒロシマシニシク', '古江西町', 'フルエニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市西区古江上', '34', '34104', '7330875', '広島県', 'ヒロシマケン', '広島市西区', 'ヒロシマシニシク', '古江上', 'フルエウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市西区高須台', '34', '34104', '7330876', '広島県', 'ヒロシマケン', '広島市西区', 'ヒロシマシニシク', '高須台', 'タカスダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市西区古田台', '34', '34104', '7330877', '広島県', 'ヒロシマケン', '広島市西区', 'ヒロシマシニシク', '古田台', 'フルタダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市南区', '34', '34103', '7340000', '広島県', 'ヒロシマケン', '広島市南区', 'ヒロシマシミナミク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('91782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市南区出汐', '34', '34103', '7340001', '広島県', 'ヒロシマケン', '広島市南区', 'ヒロシマシミナミク', '出汐', 'デシオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市南区西旭町', '34', '34103', '7340002', '広島県', 'ヒロシマケン', '広島市南区', 'ヒロシマシミナミク', '西旭町', 'ニシアサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市南区宇品東', '34', '34103', '7340003', '広島県', 'ヒロシマケン', '広島市南区', 'ヒロシマシミナミク', '宇品東', 'ウジナヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市南区宇品神田', '34', '34103', '7340004', '広島県', 'ヒロシマケン', '広島市南区', 'ヒロシマシミナミク', '宇品神田', 'ウジナカンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市南区翠', '34', '34103', '7340005', '広島県', 'ヒロシマケン', '広島市南区', 'ヒロシマシミナミク', '翠', 'ミドリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市南区西翠町', '34', '34103', '7340006', '広島県', 'ヒロシマケン', '広島市南区', 'ヒロシマシミナミク', '西翠町', 'ニシミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市南区皆実町', '34', '34103', '7340007', '広島県', 'ヒロシマケン', '広島市南区', 'ヒロシマシミナミク', '皆実町', 'ミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市南区宇品海岸', '34', '34103', '7340011', '広島県', 'ヒロシマケン', '広島市南区', 'ヒロシマシミナミク', '宇品海岸', 'ウジナカイガン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市南区元宇品町', '34', '34103', '7340012', '広島県', 'ヒロシマケン', '広島市南区', 'ヒロシマシミナミク', '元宇品町', 'モトウジナマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市南区出島', '34', '34103', '7340013', '広島県', 'ヒロシマケン', '広島市南区', 'ヒロシマシミナミク', '出島', 'デジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市南区宇品西', '34', '34103', '7340014', '広島県', 'ヒロシマケン', '広島市南区', 'ヒロシマシミナミク', '宇品西', 'ウジナニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市南区宇品御幸', '34', '34103', '7340015', '広島県', 'ヒロシマケン', '広島市南区', 'ヒロシマシミナミク', '宇品御幸', 'ウジナミユキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市南区宇品町', '34', '34103', '7340016', '広島県', 'ヒロシマケン', '広島市南区', 'ヒロシマシミナミク', '宇品町', 'ウジナマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市南区似島町', '34', '34103', '7340017', '広島県', 'ヒロシマケン', '広島市南区', 'ヒロシマシミナミク', '似島町', 'ニノシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市南区上東雲町', '34', '34103', '7340021', '広島県', 'ヒロシマケン', '広島市南区', 'ヒロシマシミナミク', '上東雲町', 'カミシノノメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市南区東雲', '34', '34103', '7340022', '広島県', 'ヒロシマケン', '広島市南区', 'ヒロシマシミナミク', '東雲', 'シノノメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市南区東雲本町', '34', '34103', '7340023', '広島県', 'ヒロシマケン', '広島市南区', 'ヒロシマシミナミク', '東雲本町', 'シノノメホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市南区仁保新町', '34', '34103', '7340024', '広島県', 'ヒロシマケン', '広島市南区', 'ヒロシマシミナミク', '仁保新町', 'ニホシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市南区東本浦町', '34', '34103', '7340025', '広島県', 'ヒロシマケン', '広島市南区', 'ヒロシマシミナミク', '東本浦町', 'ヒガシホンウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市南区仁保', '34', '34103', '7340026', '広島県', 'ヒロシマケン', '広島市南区', 'ヒロシマシミナミク', '仁保', 'ニホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市南区仁保南', '34', '34103', '7340027', '広島県', 'ヒロシマケン', '広島市南区', 'ヒロシマシミナミク', '仁保南', 'ニホミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市南区日宇那町', '34', '34103', '7340031', '広島県', 'ヒロシマケン', '広島市南区', 'ヒロシマシミナミク', '日宇那町', 'ヒウナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市南区楠那町', '34', '34103', '7340032', '広島県', 'ヒロシマケン', '広島市南区', 'ヒロシマシミナミク', '楠那町', 'クスナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市南区丹那新町', '34', '34103', '7340033', '広島県', 'ヒロシマケン', '広島市南区', 'ヒロシマシミナミク', '丹那新町', 'タンナシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市南区丹那町', '34', '34103', '7340034', '広島県', 'ヒロシマケン', '広島市南区', 'ヒロシマシミナミク', '丹那町', 'タンナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市南区山城町', '34', '34103', '7340035', '広島県', 'ヒロシマケン', '広島市南区', 'ヒロシマシミナミク', '山城町', 'ヤマシロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市南区旭', '34', '34103', '7340036', '広島県', 'ヒロシマケン', '広島市南区', 'ヒロシマシミナミク', '旭', 'アサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市南区霞', '34', '34103', '7340037', '広島県', 'ヒロシマケン', '広島市南区', 'ヒロシマシミナミク', '霞', 'カスミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市南区黄金山町', '34', '34103', '7340041', '広島県', 'ヒロシマケン', '広島市南区', 'ヒロシマシミナミク', '黄金山町', 'オウゴンザンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市南区北大河町', '34', '34103', '7340042', '広島県', 'ヒロシマケン', '広島市南区', 'ヒロシマシミナミク', '北大河町', 'キタオオコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市南区南大河町', '34', '34103', '7340043', '広島県', 'ヒロシマケン', '広島市南区', 'ヒロシマシミナミク', '南大河町', 'ミナミオオコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市南区西霞町', '34', '34103', '7340044', '広島県', 'ヒロシマケン', '広島市南区', 'ヒロシマシミナミク', '西霞町', 'ニシカスミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市南区西本浦町', '34', '34103', '7340045', '広島県', 'ヒロシマケン', '広島市南区', 'ヒロシマシミナミク', '西本浦町', 'ニシホンウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市南区東霞町', '34', '34103', '7340046', '広島県', 'ヒロシマケン', '広島市南区', 'ヒロシマシミナミク', '東霞町', 'ヒガシカスミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市南区本浦町', '34', '34103', '7340047', '広島県', 'ヒロシマケン', '広島市南区', 'ヒロシマシミナミク', '本浦町', 'ホンウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市南区東青崎町', '34', '34103', '7340051', '広島県', 'ヒロシマケン', '広島市南区', 'ヒロシマシミナミク', '東青崎町', 'ヒガシアオサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市南区堀越', '34', '34103', '7340052', '広島県', 'ヒロシマケン', '広島市南区', 'ヒロシマシミナミク', '堀越', 'ホリコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市南区青崎', '34', '34103', '7340053', '広島県', 'ヒロシマケン', '広島市南区', 'ヒロシマシミナミク', '青崎', 'アオサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市南区月見町', '34', '34103', '7340054', '広島県', 'ヒロシマケン', '広島市南区', 'ヒロシマシミナミク', '月見町', 'ツキミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市南区向洋新町', '34', '34103', '7340055', '広島県', 'ヒロシマケン', '広島市南区', 'ヒロシマシミナミク', '向洋新町', 'ムカイナダシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市南区向洋沖町', '34', '34103', '7340056', '広島県', 'ヒロシマケン', '広島市南区', 'ヒロシマシミナミク', '向洋沖町', 'ムカイナダオキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市南区仁保沖町', '34', '34103', '7340057', '広島県', 'ヒロシマケン', '広島市南区', 'ヒロシマシミナミク', '仁保沖町', 'ニホオキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市南区向洋中町', '34', '34103', '7340061', '広島県', 'ヒロシマケン', '広島市南区', 'ヒロシマシミナミク', '向洋中町', 'ムカイナダナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市南区向洋本町', '34', '34103', '7340062', '広島県', 'ヒロシマケン', '広島市南区', 'ヒロシマシミナミク', '向洋本町', 'ムカイナダホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市南区向洋大原町', '34', '34103', '7340063', '広島県', 'ヒロシマケン', '広島市南区', 'ヒロシマシミナミク', '向洋大原町', 'ムカイナダオオハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市南区小磯町', '34', '34103', '7340064', '広島県', 'ヒロシマケン', '広島市南区', 'ヒロシマシミナミク', '小磯町', 'コイソチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市豊浜町豊島', '34', '34202', '7340101', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '豊浜町豊島', 'トヨハマチョウトヨシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市豊浜町大浜', '34', '34202', '7340102', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '豊浜町大浜', 'トヨハマチョウオオハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市豊浜町斎島', '34', '34202', '7340103', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '豊浜町斎島', 'トヨハマチョウイツキシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市豊町大長', '34', '34202', '7340301', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '豊町大長', 'ユタカマチオオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市豊町御手洗', '34', '34202', '7340302', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '豊町御手洗', 'ユタカマチミタライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市豊町沖友', '34', '34202', '7340303', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '豊町沖友', 'ユタカマチオキトモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市豊町久比', '34', '34202', '7340304', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '豊町久比', 'ユタカマチクビ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸郡府中町', '34', '34302', '7350000', '広島県', 'ヒロシマケン', '安芸郡府中町', 'アキグンフチュウチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('91847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸郡府中町桜ケ丘', '34', '34302', '7350001', '広島県', 'ヒロシマケン', '安芸郡府中町', 'アキグンフチュウチョウ', '桜ケ丘', 'サクラガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸郡府中町清水ケ丘', '34', '34302', '7350002', '広島県', 'ヒロシマケン', '安芸郡府中町', 'アキグンフチュウチョウ', '清水ケ丘', 'シミズガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸郡府中町みくまり', '34', '34302', '7350003', '広島県', 'ヒロシマケン', '安芸郡府中町', 'アキグンフチュウチョウ', 'みくまり', 'ミクマリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸郡府中町山田', '34', '34302', '7350004', '広島県', 'ヒロシマケン', '安芸郡府中町', 'アキグンフチュウチョウ', '山田', 'ヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸郡府中町宮の町', '34', '34302', '7350005', '広島県', 'ヒロシマケン', '安芸郡府中町', 'アキグンフチュウチョウ', '宮の町', 'ミヤノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸郡府中町本町', '34', '34302', '7350006', '広島県', 'ヒロシマケン', '安芸郡府中町', 'アキグンフチュウチョウ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸郡府中町石井城', '34', '34302', '7350007', '広島県', 'ヒロシマケン', '安芸郡府中町', 'アキグンフチュウチョウ', '石井城', 'イシイジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸郡府中町鶴江', '34', '34302', '7350008', '広島県', 'ヒロシマケン', '安芸郡府中町', 'アキグンフチュウチョウ', '鶴江', 'ツルエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸郡府中町城ケ丘', '34', '34302', '7350009', '広島県', 'ヒロシマケン', '安芸郡府中町', 'アキグンフチュウチョウ', '城ケ丘', 'ジョウガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸郡府中町瀬戸ハイム', '34', '34302', '7350011', '広島県', 'ヒロシマケン', '安芸郡府中町', 'アキグンフチュウチョウ', '瀬戸ハイム', 'セトハイム', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸郡府中町八幡', '34', '34302', '7350012', '広島県', 'ヒロシマケン', '安芸郡府中町', 'アキグンフチュウチョウ', '八幡', 'ヤハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸郡府中町浜田', '34', '34302', '7350013', '広島県', 'ヒロシマケン', '安芸郡府中町', 'アキグンフチュウチョウ', '浜田', 'ハマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸郡府中町柳ケ丘', '34', '34302', '7350014', '広島県', 'ヒロシマケン', '安芸郡府中町', 'アキグンフチュウチョウ', '柳ケ丘', 'ヤナギガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸郡府中町青崎東', '34', '34302', '7350015', '広島県', 'ヒロシマケン', '安芸郡府中町', 'アキグンフチュウチョウ', '青崎東', 'アオサキヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸郡府中町青崎中', '34', '34302', '7350016', '広島県', 'ヒロシマケン', '安芸郡府中町', 'アキグンフチュウチョウ', '青崎中', 'アオサキナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸郡府中町青崎南', '34', '34302', '7350017', '広島県', 'ヒロシマケン', '安芸郡府中町', 'アキグンフチュウチョウ', '青崎南', 'アオサキミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸郡府中町大須', '34', '34302', '7350021', '広島県', 'ヒロシマケン', '安芸郡府中町', 'アキグンフチュウチョウ', '大須', 'オオス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸郡府中町大通', '34', '34302', '7350022', '広島県', 'ヒロシマケン', '安芸郡府中町', 'アキグンフチュウチョウ', '大通', 'オオドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸郡府中町浜田本町', '34', '34302', '7350023', '広島県', 'ヒロシマケン', '安芸郡府中町', 'アキグンフチュウチョウ', '浜田本町', 'ハマダホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸郡府中町緑ケ丘', '34', '34302', '7350024', '広島県', 'ヒロシマケン', '安芸郡府中町', 'アキグンフチュウチョウ', '緑ケ丘', 'ミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸郡府中町鹿籠', '34', '34302', '7350025', '広島県', 'ヒロシマケン', '安芸郡府中町', 'アキグンフチュウチョウ', '鹿籠', 'コゴモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸郡府中町桃山', '34', '34302', '7350026', '広島県', 'ヒロシマケン', '安芸郡府中町', 'アキグンフチュウチョウ', '桃山', 'モモヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸郡府中町千代', '34', '34302', '7350027', '広島県', 'ヒロシマケン', '安芸郡府中町', 'アキグンフチュウチョウ', '千代', 'センダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸郡府中町新地', '34', '34302', '7350028', '広島県', 'ヒロシマケン', '安芸郡府中町', 'アキグンフチュウチョウ', '新地', 'シンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸郡府中町茂陰', '34', '34302', '7350029', '広島県', 'ヒロシマケン', '安芸郡府中町', 'アキグンフチュウチョウ', '茂陰', 'モカゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安芸区', '34', '34107', '7360000', '広島県', 'ヒロシマケン', '広島市安芸区', 'ヒロシマシアキク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('91880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸郡海田町', '34', '34304', '7360000', '広島県', 'ヒロシマケン', '安芸郡海田町', 'アキグンカイタチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('91881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸郡海田町砂走', '34', '34304', '7360001', '広島県', 'ヒロシマケン', '安芸郡海田町', 'アキグンカイタチョウ', '砂走', 'スナバシリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸郡海田町国信', '34', '34304', '7360002', '広島県', 'ヒロシマケン', '安芸郡海田町', 'アキグンカイタチョウ', '国信', 'クニノブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸郡海田町曽田', '34', '34304', '7360003', '広島県', 'ヒロシマケン', '安芸郡海田町', 'アキグンカイタチョウ', '曽田', 'ソダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸郡海田町石原', '34', '34304', '7360004', '広島県', 'ヒロシマケン', '安芸郡海田町', 'アキグンカイタチョウ', '石原', 'イシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸郡海田町畝', '34', '34304', '7360005', '広島県', 'ヒロシマケン', '安芸郡海田町', 'アキグンカイタチョウ', '畝', 'ウネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸郡海田町寺迫', '34', '34304', '7360011', '広島県', 'ヒロシマケン', '安芸郡海田町', 'アキグンカイタチョウ', '寺迫', 'テラサコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸郡海田町稲葉', '34', '34304', '7360012', '広島県', 'ヒロシマケン', '安芸郡海田町', 'アキグンカイタチョウ', '稲葉', 'イナバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸郡海田町東', '34', '34304', '7360013', '広島県', 'ヒロシマケン', '安芸郡海田町', 'アキグンカイタチョウ', '東', 'ヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸郡海田町三迫', '34', '34304', '7360014', '広島県', 'ヒロシマケン', '安芸郡海田町', 'アキグンカイタチョウ', '三迫', 'ミサコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸郡海田町成本', '34', '34304', '7360021', '広島県', 'ヒロシマケン', '安芸郡海田町', 'アキグンカイタチョウ', '成本', 'ナリモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸郡海田町蟹原', '34', '34304', '7360022', '広島県', 'ヒロシマケン', '安芸郡海田町', 'アキグンカイタチョウ', '蟹原', 'カニハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸郡海田町浜角', '34', '34304', '7360023', '広島県', 'ヒロシマケン', '安芸郡海田町', 'アキグンカイタチョウ', '浜角', 'ハマカド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸郡海田町西浜', '34', '34304', '7360024', '広島県', 'ヒロシマケン', '安芸郡海田町', 'アキグンカイタチョウ', '西浜', 'ニシハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸郡海田町大立町', '34', '34304', '7360025', '広島県', 'ヒロシマケン', '安芸郡海田町', 'アキグンカイタチョウ', '大立町', 'オオダテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸郡海田町幸町', '34', '34304', '7360026', '広島県', 'ヒロシマケン', '安芸郡海田町', 'アキグンカイタチョウ', '幸町', 'サイワイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸郡海田町曙町', '34', '34304', '7360031', '広島県', 'ヒロシマケン', '安芸郡海田町', 'アキグンカイタチョウ', '曙町', 'アケボノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸郡海田町南幸町', '34', '34304', '7360032', '広島県', 'ヒロシマケン', '安芸郡海田町', 'アキグンカイタチョウ', '南幸町', 'ミナミサイワイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸郡海田町南本町', '34', '34304', '7360033', '広島県', 'ヒロシマケン', '安芸郡海田町', 'アキグンカイタチョウ', '南本町', 'ミナミホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸郡海田町月見町', '34', '34304', '7360034', '広島県', 'ヒロシマケン', '安芸郡海田町', 'アキグンカイタチョウ', '月見町', 'ツキミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸郡海田町日の出町', '34', '34304', '7360035', '広島県', 'ヒロシマケン', '安芸郡海田町', 'アキグンカイタチョウ', '日の出町', 'ヒノデマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸郡海田町大正町', '34', '34304', '7360041', '広島県', 'ヒロシマケン', '安芸郡海田町', 'アキグンカイタチョウ', '大正町', 'タイショウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸郡海田町南大正町', '34', '34304', '7360042', '広島県', 'ヒロシマケン', '安芸郡海田町', 'アキグンカイタチョウ', '南大正町', 'ミナミタイショウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸郡海田町栄町', '34', '34304', '7360043', '広島県', 'ヒロシマケン', '安芸郡海田町', 'アキグンカイタチョウ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸郡海田町南堀川町', '34', '34304', '7360044', '広島県', 'ヒロシマケン', '安芸郡海田町', 'アキグンカイタチョウ', '南堀川町', 'ミナミホリカワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸郡海田町堀川町', '34', '34304', '7360045', '広島県', 'ヒロシマケン', '安芸郡海田町', 'アキグンカイタチョウ', '堀川町', 'ホリカワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸郡海田町窪町', '34', '34304', '7360046', '広島県', 'ヒロシマケン', '安芸郡海田町', 'アキグンカイタチョウ', '窪町', 'クボマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸郡海田町つくも町', '34', '34304', '7360051', '広島県', 'ヒロシマケン', '安芸郡海田町', 'アキグンカイタチョウ', 'つくも町', 'ツクモマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸郡海田町南つくも町', '34', '34304', '7360052', '広島県', 'ヒロシマケン', '安芸郡海田町', 'アキグンカイタチョウ', '南つくも町', 'ミナミツクモマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸郡海田町寿町', '34', '34304', '7360053', '広島県', 'ヒロシマケン', '安芸郡海田町', 'アキグンカイタチョウ', '寿町', 'コトブキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸郡海田町西明神町', '34', '34304', '7360054', '広島県', 'ヒロシマケン', '安芸郡海田町', 'アキグンカイタチョウ', '西明神町', 'ニシミョウジンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸郡海田町南明神町', '34', '34304', '7360055', '広島県', 'ヒロシマケン', '安芸郡海田町', 'アキグンカイタチョウ', '南明神町', 'ミナミミョウジンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸郡海田町明神町', '34', '34304', '7360056', '広島県', 'ヒロシマケン', '安芸郡海田町', 'アキグンカイタチョウ', '明神町', 'ミョウジンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸郡海田町上市', '34', '34304', '7360061', '広島県', 'ヒロシマケン', '安芸郡海田町', 'アキグンカイタチョウ', '上市', 'カミイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸郡海田町昭和町', '34', '34304', '7360062', '広島県', 'ヒロシマケン', '安芸郡海田町', 'アキグンカイタチョウ', '昭和町', 'ショウワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸郡海田町東昭和町', '34', '34304', '7360063', '広島県', 'ヒロシマケン', '安芸郡海田町', 'アキグンカイタチョウ', '東昭和町', 'ヒガシショウワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸郡海田町昭和中町', '34', '34304', '7360064', '広島県', 'ヒロシマケン', '安芸郡海田町', 'アキグンカイタチョウ', '昭和中町', 'ショウワナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸郡海田町南昭和町', '34', '34304', '7360065', '広島県', 'ヒロシマケン', '安芸郡海田町', 'アキグンカイタチョウ', '南昭和町', 'ミナミショウワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸郡海田町中店', '34', '34304', '7360066', '広島県', 'ヒロシマケン', '安芸郡海田町', 'アキグンカイタチョウ', '中店', 'ナカミセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸郡海田町稲荷町', '34', '34304', '7360067', '広島県', 'ヒロシマケン', '安芸郡海田町', 'アキグンカイタチョウ', '稲荷町', 'イナリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸郡海田町新町', '34', '34304', '7360068', '広島県', 'ヒロシマケン', '安芸郡海田町', 'アキグンカイタチョウ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸郡海田町東海田', '34', '34304', '7360071', '広島県', 'ヒロシマケン', '安芸郡海田町', 'アキグンカイタチョウ', '東海田', 'ヒガシカイタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安芸区船越', '34', '34107', '7360081', '広島県', 'ヒロシマケン', '広島市安芸区', 'ヒロシマシアキク', '船越', 'フナコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安芸区船越南', '34', '34107', '7360082', '広島県', 'ヒロシマケン', '広島市安芸区', 'ヒロシマシアキク', '船越南', 'フナコシミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安芸区矢野東', '34', '34107', '7360083', '広島県', 'ヒロシマケン', '広島市安芸区', 'ヒロシマシアキク', '矢野東', 'ヤノヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安芸区矢野新町', '34', '34107', '7360084', '広島県', 'ヒロシマケン', '広島市安芸区', 'ヒロシマシアキク', '矢野新町', 'ヤノシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安芸区矢野西', '34', '34107', '7360085', '広島県', 'ヒロシマケン', '広島市安芸区', 'ヒロシマシアキク', '矢野西', 'ヤノニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安芸区矢野南', '34', '34107', '7360086', '広島県', 'ヒロシマケン', '広島市安芸区', 'ヒロシマシアキク', '矢野南', 'ヤノミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安芸区矢野町', '34', '34107', '7360087', '広島県', 'ヒロシマケン', '広島市安芸区', 'ヒロシマシアキク', '矢野町', 'ヤノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安芸区畑賀', '34', '34107', '7360088', '広島県', 'ヒロシマケン', '広島市安芸区', 'ヒロシマシアキク', '畑賀', 'ハタカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安芸区畑賀町', '34', '34107', '7360089', '広島県', 'ヒロシマケン', '広島市安芸区', 'ヒロシマシアキク', '畑賀町', 'ハタカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市', '34', '34202', '7370000', '広島県', 'ヒロシマケン', '呉市', 'クレシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('91943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市阿賀北', '34', '34202', '7370001', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '阿賀北', 'アガキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市広町大空山', '34', '34202', '7370002', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '広町', 'ヒロマチ', null, null, '大空山', 'オオゾラヤマ');
INSERT INTO `ms_addresses` VALUES ('91945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市阿賀中央', '34', '34202', '7370003', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '阿賀中央', 'アガチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市阿賀南', '34', '34202', '7370004', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '阿賀南', 'アガミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市阿賀町', '34', '34202', '7370005', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '阿賀町', 'アガマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市見晴', '34', '34202', '7370011', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '見晴', 'ミハラシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市警固屋', '34', '34202', '7370012', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '警固屋', 'ケゴヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市的場', '34', '34202', '7370013', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '的場', 'マトバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市坪ノ内町', '34', '34202', '7370014', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '坪ノ内町', 'ツボノウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市船見町', '34', '34202', '7370015', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '船見町', 'フナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市三和町', '34', '34202', '7370021', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '三和町', 'サンワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市清水', '34', '34202', '7370022', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '清水', 'シミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市青山町', '34', '34202', '7370023', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '青山町', 'アオヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市宮原', '34', '34202', '7370024', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '宮原', 'ミヤハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市室瀬町', '34', '34202', '7370025', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '室瀬町', 'ムロセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市神原町', '34', '34202', '7370026', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '神原町', 'カンバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市昭和町', '34', '34202', '7370027', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '昭和町', 'ショウワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市幸町', '34', '34202', '7370028', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市宝町', '34', '34202', '7370029', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '宝町', 'タカラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市上長迫町', '34', '34202', '7370031', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '上長迫町', 'カミナガサコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市本町', '34', '34202', '7370032', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市寺本町', '34', '34202', '7370033', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '寺本町', 'テラモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市溝路町', '34', '34202', '7370034', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '溝路町', 'ミゾロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市長迫町', '34', '34202', '7370035', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '長迫町', 'ナガサコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市和庄', '34', '34202', '7370041', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '和庄', 'ワショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市和庄本町', '34', '34202', '7370042', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '和庄本町', 'ワショウホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市和庄登町', '34', '34202', '7370043', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '和庄登町', 'ワショウノボリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市八幡町', '34', '34202', '7370044', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '八幡町', 'ヤハタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市本通', '34', '34202', '7370045', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '本通', 'ホンドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市中通', '34', '34202', '7370046', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '中通', 'ナカドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市中央', '34', '34202', '7370051', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市東中央', '34', '34202', '7370052', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '東中央', 'ヒガシチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市長ノ木町', '34', '34202', '7370053', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '長ノ木町', 'ナガノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市上山田町', '34', '34202', '7370054', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '上山田町', 'カミヤマダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市下山田町', '34', '34202', '7370055', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '下山田町', 'シモヤマダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市朝日町', '34', '34202', '7370056', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '朝日町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市畝原町', '34', '34202', '7370061', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '畝原町', 'ウネハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市西惣付町', '34', '34202', '7370062', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '西惣付町', 'ニシソウヅケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市東惣付町', '34', '34202', '7370063', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '東惣付町', 'ヒガシソウヅケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市西谷町', '34', '34202', '7370064', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '西谷町', 'ニシタニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市望地町', '34', '34202', '7370065', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '望地町', 'ボウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市上畑町', '34', '34202', '7370071', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '上畑町', 'カミハタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市東畑', '34', '34202', '7370072', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '東畑', 'ヒガシハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市東鹿田町', '34', '34202', '7370073', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '東鹿田町', 'ヒガシシカタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市西鹿田', '34', '34202', '7370074', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '西鹿田', 'ニシシカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市西畑町', '34', '34202', '7370075', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '西畑町', 'ニシハタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市吾妻', '34', '34202', '7370076', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '吾妻', 'アヅマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市伏原', '34', '34202', '7370077', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '伏原', 'フシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市平原町', '34', '34202', '7370078', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '平原町', 'ヒラバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市上平原町', '34', '34202', '7370079', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '上平原町', 'カミヒラバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市広石内', '34', '34202', '7370101', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '広石内', 'ヒロイシウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市広徳丸町', '34', '34202', '7370102', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '広徳丸町', 'ヒロトクマルチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市広塩焼', '34', '34202', '7370103', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '広塩焼', 'ヒロシヤケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市広町田', '34', '34202', '7370104', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '広町田', 'ヒロマチダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市広中迫町', '34', '34202', '7370105', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '広中迫町', 'ヒロナカサコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市広三芦', '34', '34202', '7370106', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '広三芦', 'ヒロミアシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('91999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市広弁天橋町', '34', '34202', '7370107', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '広弁天橋町', 'ヒロベンテンバシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市広大広', '34', '34202', '7370111', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '広大広', 'ヒロオオビロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市広古新開', '34', '34202', '7370112', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '広古新開', 'ヒロコシンガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市広横路', '34', '34202', '7370113', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '広横路', 'ヒロヨコロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市広文化町', '34', '34202', '7370114', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '広文化町', 'ヒロブンカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市広町', '34', '34202', '7370115', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '広町', 'ヒロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市広吉松', '34', '34202', '7370121', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '広吉松', 'ヒロヨシマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市広杭本町', '34', '34202', '7370122', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '広杭本町', 'ヒロクイモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市広両谷', '34', '34202', '7370123', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '広両谷', 'ヒロリョウタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市広中新開', '34', '34202', '7370124', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '広中新開', 'ヒロナカシンガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市広本町', '34', '34202', '7370125', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '広本町', 'ヒロホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市広中町', '34', '34202', '7370131', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '広中町', 'ヒロナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市広名田', '34', '34202', '7370132', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '広名田', 'ヒロナダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市広末広', '34', '34202', '7370133', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '広末広', 'ヒロスエヒロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市広多賀谷', '34', '34202', '7370134', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '広多賀谷', 'ヒロタガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市広津久茂町', '34', '34202', '7370135', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '広津久茂町', 'ヒロツクモチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市広長浜', '34', '34202', '7370136', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '広長浜', 'ヒロナガハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市広小坪', '34', '34202', '7370137', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '広小坪', 'ヒロコツボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市広黄幡町', '34', '34202', '7370138', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '広黄幡町', 'ヒロオウバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市広大新開', '34', '34202', '7370141', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '広大新開', 'ヒロオオシンガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市広駅前', '34', '34202', '7370142', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '広駅前', 'ヒロエキマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市広白石', '34', '34202', '7370143', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '広白石', 'ヒロシライシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市広白岳', '34', '34202', '7370144', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '広白岳', 'ヒロシラタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市仁方西神町', '34', '34202', '7370145', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '仁方西神町', 'ニガタニシガミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市仁方宮上町', '34', '34202', '7370146', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '仁方宮上町', 'ニガタミヤガミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市仁方中筋町', '34', '34202', '7370151', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '仁方中筋町', 'ニガタナカスジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市仁方本町', '34', '34202', '7370152', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '仁方本町', 'ニガタホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市仁方大歳町', '34', '34202', '7370153', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '仁方大歳町', 'ニガタオオトシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市仁方桟橋通', '34', '34202', '7370154', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '仁方桟橋通', 'ニガタサンバシドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市仁方錦町', '34', '34202', '7370155', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '仁方錦町', 'ニガタニシキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市仁方皆実町', '34', '34202', '7370156', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '仁方皆実町', 'ニガタミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市仁方町', '34', '34202', '7370157', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '仁方町', 'ニガタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市郷原町', '34', '34202', '7370161', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '郷原町', 'ゴウハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市郷原学びの丘', '34', '34202', '7370162', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '郷原学びの丘', 'ゴウハラマナビノオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市郷原野路の里', '34', '34202', '7370163', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '郷原野路の里', 'ゴウハラノロノサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市下蒲刈町三之瀬', '34', '34202', '7370301', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '下蒲刈町三之瀬', 'シモカマガリチョウサンノセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市下蒲刈町大地蔵', '34', '34202', '7370302', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '下蒲刈町大地蔵', 'シモカマガリチョウオオジゾウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市下蒲刈町下島', '34', '34202', '7370303', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '下蒲刈町下島', 'シモカマガリチョウシモジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市蒲刈町向', '34', '34202', '7370311', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '蒲刈町向', 'カマガリチョウムカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市蒲刈町宮盛', '34', '34202', '7370401', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '蒲刈町宮盛', 'カマガリチョウミヤザカリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市蒲刈町大浦', '34', '34202', '7370402', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '蒲刈町大浦', 'カマガリチョウオオウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市蒲刈町田戸', '34', '34202', '7370403', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '蒲刈町田戸', 'カマガリチョウタド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市東辰川町', '34', '34202', '7370801', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '東辰川町', 'ヒガシタツカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市南辰川町', '34', '34202', '7370802', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '南辰川町', 'ミナミタツカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市郷町', '34', '34202', '7370803', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '郷町', 'ゴウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市内神町', '34', '34202', '7370804', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '内神町', 'ウチガミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市東片山町', '34', '34202', '7370805', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '東片山町', 'ヒガシカタヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市西片山町', '34', '34202', '7370806', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '西片山町', 'ニシカタヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市江原町', '34', '34202', '7370807', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '江原町', 'エバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市上内神町', '34', '34202', '7370808', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '上内神町', 'カミウチガミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市西辰川', '34', '34202', '7370809', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '西辰川', 'ニシタツカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市西中央', '34', '34202', '7370811', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '西中央', 'ニシチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市西三津田町', '34', '34202', '7370812', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '西三津田町', 'ニシミツタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市東三津田町', '34', '34202', '7370813', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '東三津田町', 'ヒガシミツタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市山手', '34', '34202', '7370814', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '山手', 'ヤマテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市荘山田村二河山', '34', '34202', '7370815', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '荘山田村', 'ソウヤマダムラ', null, null, '二河山', 'フタカワヤマ');
INSERT INTO `ms_addresses` VALUES ('92061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市二河峡町', '34', '34202', '7370816', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '二河峡町', 'ニコウキョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市上二河町', '34', '34202', '7370817', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '上二河町', 'カミニコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市二河町', '34', '34202', '7370818', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '二河町', 'ニコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市三条', '34', '34202', '7370821', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '三条', 'サンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市築地町', '34', '34202', '7370822', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '築地町', 'ツキジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市海岸', '34', '34202', '7370823', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '海岸', 'カイガン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市東川原石町', '34', '34202', '7370824', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '東川原石町', 'ヒガシカワライシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市西川原石町', '34', '34202', '7370825', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '西川原石町', 'ニシカワライシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市両城', '34', '34202', '7370826', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '両城', 'リョウジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市西愛宕町', '34', '34202', '7370827', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '西愛宕町', 'ニシアタゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市東愛宕町', '34', '34202', '7370828', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '東愛宕町', 'ヒガシアタゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市光町', '34', '34202', '7370831', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '光町', 'ヒカリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市若葉町', '34', '34202', '7370832', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '若葉町', 'ワカバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市晴海町', '34', '34202', '7370833', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '晴海町', 'ハルミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市瀬戸見町', '34', '34202', '7370834', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '瀬戸見町', 'セトミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市新宮町', '34', '34202', '7370835', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '新宮町', 'シングウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市北塩屋町', '34', '34202', '7370836', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '北塩屋町', 'キタシオヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市東塩屋町', '34', '34202', '7370837', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '東塩屋町', 'ヒガシシオヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市西塩屋町', '34', '34202', '7370838', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '西塩屋町', 'ニシシオヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市吉浦神賀町', '34', '34202', '7370841', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '吉浦神賀町', 'ヨシウラジンガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市吉浦東町', '34', '34202', '7370842', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '吉浦東町', 'ヨシウラヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市吉浦潭鼓町', '34', '34202', '7370843', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '吉浦潭鼓町', 'ヨシウラタンコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市吉浦池ノ浦町', '34', '34202', '7370844', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '吉浦池ノ浦町', 'ヨシウライケノウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市吉浦新町', '34', '34202', '7370845', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '吉浦新町', 'ヨシウラシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市吉浦町乙廻り', '34', '34202', '7370846', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '吉浦町', 'ヨシウラチョウ', null, null, '乙廻り', 'オトマワリ');
INSERT INTO `ms_addresses` VALUES ('92086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市吉浦新出町', '34', '34202', '7370851', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '吉浦新出町', 'ヨシウラシンデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市吉浦東本町', '34', '34202', '7370852', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '吉浦東本町', 'ヨシウラヒガシホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市吉浦中町', '34', '34202', '7370853', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '吉浦中町', 'ヨシウラナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市吉浦町', '34', '34202', '7370854', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '吉浦町', 'ヨシウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市吉浦本町', '34', '34202', '7370861', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '吉浦本町', 'ヨシウラホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市狩留賀町', '34', '34202', '7370862', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '狩留賀町', 'カルガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市吉浦宮花町', '34', '34202', '7370863', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '吉浦宮花町', 'ヨシウラミヤハナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市吉浦西城町', '34', '34202', '7370864', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '吉浦西城町', 'ヨシウラニシジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市吉浦岩神町', '34', '34202', '7370865', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '吉浦岩神町', 'ヨシウライワガミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市吉浦松葉町', '34', '34202', '7370866', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '吉浦松葉町', 'ヨシウラマツバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市吉浦上城町', '34', '34202', '7370867', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '吉浦上城町', 'ヨシウラカミジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市長谷町', '34', '34202', '7370871', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '長谷町', 'ナガタニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市梅木町', '34', '34202', '7370872', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '梅木町', 'ウメキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市汐見町', '34', '34202', '7370873', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '汐見町', 'シオミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市天応南町', '34', '34202', '7370874', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '天応南町', 'テンノウミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市天応大浜', '34', '34202', '7370875', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '天応大浜', 'テンノウオオハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市天応宮町', '34', '34202', '7370876', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '天応宮町', 'テンノウミヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市弥生町', '34', '34202', '7370877', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '弥生町', 'ヤヨイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市大山町', '34', '34202', '7370878', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '大山町', 'オオヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市天応塩谷町', '34', '34202', '7370881', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '天応塩谷町', 'テンノウシオヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市天応東久保', '34', '34202', '7370882', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '天応東久保', 'テンノウヒガシクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市天応西条', '34', '34202', '7370883', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '天応西条', 'テンノウニシジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市天応伝十原町', '34', '34202', '7370884', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '天応伝十原町', 'テンノウデンジュウバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市天応福浦町', '34', '34202', '7370885', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '天応福浦町', 'テンノウフクウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市焼山ひばりケ丘町', '34', '34202', '7370901', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '焼山ひばりケ丘町', 'ヤケヤマヒバリガオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市焼山此原町', '34', '34202', '7370902', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '焼山此原町', 'ヤケヤマコノハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市焼山西', '34', '34202', '7370903', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '焼山西', 'ヤケヤマニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市焼山打田', '34', '34202', '7370904', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '焼山', 'ヤケヤマ', null, null, '打田', 'ウチダ');
INSERT INTO `ms_addresses` VALUES ('92114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市焼山町山の神', '34', '34202', '7370905', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '焼山町', 'ヤケヤマチョウ', null, null, '山の神', 'ヤマノカミ');
INSERT INTO `ms_addresses` VALUES ('92115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市焼山町野登呂', '34', '34202', '7370906', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '焼山町', 'ヤケヤマチョウ', null, null, '野登呂', 'ノトロ');
INSERT INTO `ms_addresses` VALUES ('92116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市焼山町', '34', '34202', '7370907', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '焼山町', 'ヤケヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市焼山宮ケ迫', '34', '34202', '7370908', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '焼山宮ケ迫', 'ヤケヤマミヤガサコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市焼山北', '34', '34202', '7370911', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '焼山北', 'ヤケヤマキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市焼山本庄', '34', '34202', '7370912', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '焼山本庄', 'ヤケヤマホンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市焼山泉ケ丘', '34', '34202', '7370913', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '焼山泉ケ丘', 'ヤケヤマイズミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市押込西平町', '34', '34202', '7370914', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '押込西平町', 'オシゴメニシヒラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市押込', '34', '34202', '7370915', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '押込', 'オシゴメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市苗代町', '34', '34202', '7370921', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '苗代町', 'ナエシロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市栃原町', '34', '34202', '7370922', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '栃原町', 'トチバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市神山', '34', '34202', '7370923', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '神山', 'ジンヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市焼山南', '34', '34202', '7370924', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '焼山南', 'ヤケヤマミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市焼山三ツ石町', '34', '34202', '7370931', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '焼山三ツ石町', 'ヤケヤマミツイシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市焼山松ケ丘', '34', '34202', '7370932', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '焼山松ケ丘', 'ヤケヤママツガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市焼山桜ケ丘', '34', '34202', '7370933', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '焼山桜ケ丘', 'ヤケヤマサクラガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市焼山政畝', '34', '34202', '7370934', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '焼山政畝', 'ヤケヤママサウネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市焼山中央', '34', '34202', '7370935', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '焼山中央', 'ヤケヤマチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市焼山東', '34', '34202', '7370936', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '焼山東', 'ヤケヤマヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市音戸町坪井', '34', '34202', '7371201', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '音戸町坪井', 'オンドチョウツボイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市音戸町引地', '34', '34202', '7371202', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '音戸町引地', 'オンドチョウヒキジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市音戸町鰯浜', '34', '34202', '7371203', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '音戸町鰯浜', 'オンドチョウイワシハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市音戸町北隠渡', '34', '34202', '7371204', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '音戸町北隠渡', 'オンドチョウキタオンド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市音戸町南隠渡', '34', '34202', '7371205', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '音戸町南隠渡', 'オンドチョウミナミオンド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市音戸町高須', '34', '34202', '7371206', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '音戸町高須', 'オンドチョウタカス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市音戸町波多見', '34', '34202', '7371207', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '音戸町波多見', 'オンドチョウハタミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市音戸町畑', '34', '34202', '7371211', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '音戸町畑', 'オンドチョウハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市音戸町有清', '34', '34202', '7371212', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '音戸町有清', 'オンドチョウアリキヨ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市音戸町先奥', '34', '34202', '7371213', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '音戸町先奥', 'オンドチョウサキオク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市音戸町藤脇', '34', '34202', '7371214', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '音戸町藤脇', 'オンドチョウフジノワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市音戸町早瀬', '34', '34202', '7371215', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '音戸町早瀬', 'オンドチョウハヤセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市音戸町田原', '34', '34202', '7371216', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '音戸町田原', 'オンドチョウタハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市音戸町渡子', '34', '34202', '7371217', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '音戸町渡子', 'オンドチョウトノコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市倉橋町', '34', '34202', '7371377', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '倉橋町', 'クラハシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県江田島市', '34', '34215', '7372100', '広島県', 'ヒロシマケン', '江田島市', 'エタジマシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('92149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県江田島市大柿町飛渡瀬', '34', '34215', '7372101', '広島県', 'ヒロシマケン', '江田島市', 'エタジマシ', '大柿町飛渡瀬', 'オオガキチョウヒトノセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県江田島市江田島町切串', '34', '34215', '7372111', '広島県', 'ヒロシマケン', '江田島市', 'エタジマシ', '江田島町切串', 'エタジマチョウキリクシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県江田島市江田島町幸之浦', '34', '34215', '7372112', '広島県', 'ヒロシマケン', '江田島市', 'エタジマシ', '江田島町幸之浦', 'エタジマチョウコウノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県江田島市江田島町大須', '34', '34215', '7372113', '広島県', 'ヒロシマケン', '江田島市', 'エタジマシ', '江田島町大須', 'エタジマチョウオオズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県江田島市江田島町小用', '34', '34215', '7372121', '広島県', 'ヒロシマケン', '江田島市', 'エタジマシ', '江田島町小用', 'エタジマチョウコヨウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県江田島市江田島町中央', '34', '34215', '7372122', '広島県', 'ヒロシマケン', '江田島市', 'エタジマシ', '江田島町中央', 'エタジマチョウチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県江田島市江田島町国有無番地', '34', '34215', '7372123', '広島県', 'ヒロシマケン', '江田島市', 'エタジマシ', '江田島町国有無番地', 'エタジマチョウコクユウムバンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県江田島市江田島町宮ノ原', '34', '34215', '7372124', '広島県', 'ヒロシマケン', '江田島市', 'エタジマシ', '江田島町宮ノ原', 'エタジマチョウミヤノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県江田島市江田島町大原特借宿舎', '34', '34215', '7372125', '広島県', 'ヒロシマケン', '江田島市', 'エタジマシ', '江田島町大原特借宿舎', 'エタジマチョウオオハラトッカリシュクシャ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県江田島市江田島町津久茂', '34', '34215', '7372126', '広島県', 'ヒロシマケン', '江田島市', 'エタジマシ', '江田島町津久茂', 'エタジマチョウツクモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県江田島市江田島町秋月', '34', '34215', '7372131', '広島県', 'ヒロシマケン', '江田島市', 'エタジマシ', '江田島町秋月', 'エタジマチョウアキヅキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県江田島市江田島町江南', '34', '34215', '7372132', '広島県', 'ヒロシマケン', '江田島市', 'エタジマシ', '江田島町江南', 'エタジマチョウコウナン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県江田島市江田島町鷲部', '34', '34215', '7372133', '広島県', 'ヒロシマケン', '江田島市', 'エタジマシ', '江田島町鷲部', 'エタジマチョウワシベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県江田島市大柿町柿浦', '34', '34215', '7372211', '広島県', 'ヒロシマケン', '江田島市', 'エタジマシ', '大柿町柿浦', 'オオガキチョウカキウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県江田島市大柿町大君', '34', '34215', '7372212', '広島県', 'ヒロシマケン', '江田島市', 'エタジマシ', '大柿町大君', 'オオガキチョウオオキミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県江田島市大柿町大原', '34', '34215', '7372213', '広島県', 'ヒロシマケン', '江田島市', 'エタジマシ', '大柿町大原', 'オオガキチョウオオバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県江田島市大柿町深江', '34', '34215', '7372214', '広島県', 'ヒロシマケン', '江田島市', 'エタジマシ', '大柿町深江', 'オオガキチョウフカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県江田島市大柿町小古江', '34', '34215', '7372215', '広島県', 'ヒロシマケン', '江田島市', 'エタジマシ', '大柿町小古江', 'オオガキチョウオブレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県江田島市能美町中町', '34', '34215', '7372301', '広島県', 'ヒロシマケン', '江田島市', 'エタジマシ', '能美町中町', 'ノウミチョウナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県江田島市能美町鹿川', '34', '34215', '7372302', '広島県', 'ヒロシマケン', '江田島市', 'エタジマシ', '能美町鹿川', 'ノウミチョウカノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県江田島市能美町高田', '34', '34215', '7372303', '広島県', 'ヒロシマケン', '江田島市', 'エタジマシ', '能美町高田', 'ノウミチョウタカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県江田島市沖美町岡大王', '34', '34215', '7372311', '広島県', 'ヒロシマケン', '江田島市', 'エタジマシ', '沖美町岡大王', 'オキミチョウオカダイオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県江田島市沖美町畑', '34', '34215', '7372312', '広島県', 'ヒロシマケン', '江田島市', 'エタジマシ', '沖美町畑', 'オキミチョウハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県江田島市沖美町是長', '34', '34215', '7372313', '広島県', 'ヒロシマケン', '江田島市', 'エタジマシ', '沖美町是長', 'オキミチョウコレナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県江田島市沖美町美能', '34', '34215', '7372314', '広島県', 'ヒロシマケン', '江田島市', 'エタジマシ', '沖美町美能', 'オキミチョウミノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県江田島市沖美町高祖', '34', '34215', '7372315', '広島県', 'ヒロシマケン', '江田島市', 'エタジマシ', '沖美町高祖', 'オキミチョウコウソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県江田島市沖美町三吉', '34', '34215', '7372316', '広島県', 'ヒロシマケン', '江田島市', 'エタジマシ', '沖美町三吉', 'オキミチョウミヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市安浦町女子畑', '34', '34202', '7372501', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '安浦町女子畑', 'ヤスウラチョウオナゴバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市安浦町三津口', '34', '34202', '7372502', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '安浦町三津口', 'ヤスウラチョウミツグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市安浦町安登', '34', '34202', '7372503', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '安浦町安登', 'ヤスウラチョウアト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市安浦町中切', '34', '34202', '7372504', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '安浦町中切', 'ヤスウラチョウナカギリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市安浦町内平', '34', '34202', '7372505', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '安浦町内平', 'ヤスウラチョウウチヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市安浦町原畑', '34', '34202', '7372506', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '安浦町原畑', 'ヤスウラチョウハラハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市安浦町内海', '34', '34202', '7372507', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '安浦町内海', 'ヤスウラチョウウチノウミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市安浦町中畑', '34', '34202', '7372508', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '安浦町中畑', 'ヤスウラチョウナカハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市安浦町下垣内', '34', '34202', '7372509', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '安浦町下垣内', 'ヤスウラチョウシモガウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市安浦町赤向坂', '34', '34202', '7372511', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '安浦町赤向坂', 'ヤスウラチョウアコウザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市安浦町安登西', '34', '34202', '7372512', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '安浦町安登西', 'ヤスウラチョウアトニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市安浦町安登東', '34', '34202', '7372513', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '安浦町安登東', 'ヤスウラチョウアトヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市安浦町中央ハイツ', '34', '34202', '7372514', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '安浦町中央ハイツ', 'ヤスウラチョウチュウオウハイツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市安浦町中央北', '34', '34202', '7372515', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '安浦町中央北', 'ヤスウラチョウチュウオウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市安浦町中央', '34', '34202', '7372516', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '安浦町中央', 'ヤスウラチョウチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市安浦町水尻', '34', '34202', '7372517', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '安浦町水尻', 'ヤスウラチョウミズシリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市安浦町内海北', '34', '34202', '7372518', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '安浦町内海北', 'ヤスウラチョウウチノウミキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市安浦町内海南', '34', '34202', '7372519', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '安浦町内海南', 'ヤスウラチョウウチノウミミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市川尻町原山', '34', '34202', '7372601', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '川尻町原山', 'カワジリチョウハラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市川尻町森', '34', '34202', '7372602', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '川尻町森', 'カワジリチョウモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市川尻町西', '34', '34202', '7372603', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '川尻町西', 'カワジリチョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市川尻町小仁方', '34', '34202', '7372604', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '川尻町小仁方', 'カワジリチョウコニガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市川尻町久俊', '34', '34202', '7372605', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '川尻町久俊', 'カワジリチョウクドシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市川尻町久筋', '34', '34202', '7372606', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '川尻町久筋', 'カワジリチョウクスジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市川尻町東', '34', '34202', '7372607', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '川尻町東', 'カワジリチョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市川尻町小用', '34', '34202', '7372608', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '川尻町小用', 'カワジリチョウコヨウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市川尻町野呂山', '34', '34202', '7372609', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '川尻町野呂山', 'カワジリチョウノロサン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市仁方町蕨谷', '34', '34202', '7372609', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '仁方町', 'ニガタチョウ', null, null, '蕨谷', 'ワラビタニ');
INSERT INTO `ms_addresses` VALUES ('92211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市野呂山', '34', '34202', '7372609', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '野呂山', 'ノロサン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市広町一本杉', '34', '34202', '7372609', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '広町', 'ヒロマチ', null, null, '一本杉', 'イッポンスギ');
INSERT INTO `ms_addresses` VALUES ('92213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市安浦町中切奥野原', '34', '34202', '7372609', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '安浦町中切', 'ヤスウラチョウナカギリ', null, null, '奥野原', 'オクノハラ');
INSERT INTO `ms_addresses` VALUES ('92214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市安浦町中畑鹿条原', '34', '34202', '7372609', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '安浦町中畑', 'ヤスウラチョウナカハタ', null, null, '鹿条原', 'カジョウハラ');
INSERT INTO `ms_addresses` VALUES ('92215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市安浦町中畑侍屋敷', '34', '34202', '7372609', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '安浦町中畑', 'ヤスウラチョウナカハタ', null, null, '侍屋敷', 'サムライヤシキ');
INSERT INTO `ms_addresses` VALUES ('92216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市安浦町中畑膳棚山', '34', '34202', '7372609', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '安浦町中畑', 'ヤスウラチョウナカハタ', null, null, '膳棚山', 'ゼンタナヤマ');
INSERT INTO `ms_addresses` VALUES ('92217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市安浦町中畑立小路', '34', '34202', '7372609', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '安浦町中畑', 'ヤスウラチョウナカハタ', null, null, '立小路', 'タテコウジ');
INSERT INTO `ms_addresses` VALUES ('92218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市安浦町中畑中央', '34', '34202', '7372609', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '安浦町中畑', 'ヤスウラチョウナカハタ', null, null, '中央', 'チュウオウ');
INSERT INTO `ms_addresses` VALUES ('92219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市安浦町中畑東', '34', '34202', '7372609', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '安浦町中畑', 'ヤスウラチョウナカハタ', null, null, '東', 'ヒガシ');
INSERT INTO `ms_addresses` VALUES ('92220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市安浦町野呂山', '34', '34202', '7372609', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '安浦町野呂山', 'ヤスウラチョウノロサン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市川尻町大原', '34', '34202', '7372614', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '川尻町大原', 'カワジリチョウオオバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市川尻町真光地', '34', '34202', '7372615', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '川尻町真光地', 'カワジリチョウシンコウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市川尻町水落', '34', '34202', '7372616', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '川尻町水落', 'カワジリチョウミズオチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市川尻町小畑', '34', '34202', '7372617', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '川尻町小畑', 'カワジリチョウコバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市川尻町板休', '34', '34202', '7372631', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '川尻町板休', 'カワジリチョウイタヤスミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市川尻町上畑', '34', '34202', '7372632', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '川尻町上畑', 'カワジリチョウカンバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市川尻町沖田', '34', '34202', '7372633', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '川尻町沖田', 'カワジリチョウオキダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市川尻町岩戸', '34', '34202', '7372634', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '川尻町岩戸', 'カワジリチョウイワド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市川尻町柳迫', '34', '34202', '7372635', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '川尻町柳迫', 'カワジリチョウヤナギサコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市川尻町才野谷', '34', '34202', '7372636', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '川尻町才野谷', 'カワジリチョウサイノタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県呉市川尻町後懸', '34', '34202', '7372637', '広島県', 'ヒロシマケン', '呉市', 'クレシ', '川尻町後懸', 'カワジリチョウウシロガケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市', '34', '34213', '7380000', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('92259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市佐方', '34', '34213', '7380001', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '佐方', 'サガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市山陽園', '34', '34213', '7380002', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '山陽園', 'サンヨウエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市佐方本町', '34', '34213', '7380003', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '佐方本町', 'サガタホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市桜尾', '34', '34213', '7380004', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '桜尾', 'サクラオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市桜尾本町', '34', '34213', '7380005', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '桜尾本町', 'サクラオホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市大東', '34', '34213', '7380006', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '大東', 'オオヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市城内', '34', '34213', '7380007', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '城内', 'ジョウナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市駅前', '34', '34213', '7380011', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '駅前', 'エキマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市天神', '34', '34213', '7380012', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '天神', 'テンジン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市廿日市', '34', '34213', '7380013', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '廿日市', 'ハツカイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市住吉', '34', '34213', '7380014', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '住吉', 'スミヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市本町', '34', '34213', '7380015', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市可愛', '34', '34213', '7380016', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '可愛', 'カアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市須賀', '34', '34213', '7380017', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '須賀', 'スカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市木材港北', '34', '34213', '7380021', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '木材港北', 'モクザイコウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市木材港南', '34', '34213', '7380022', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '木材港南', 'モクザイコウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市下平良', '34', '34213', '7380023', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '下平良', 'シモヘラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市新宮', '34', '34213', '7380024', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '新宮', 'シングウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市平良', '34', '34213', '7380025', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '平良', 'ヘラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市上平良', '34', '34213', '7380026', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '上平良', 'カミヘラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市平良山手', '34', '34213', '7380027', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '平良山手', 'ヘラヤマテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市原', '34', '34213', '7380031', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '原', 'ハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市峰高', '34', '34213', '7380032', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '峰高', 'ミネタカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市串戸', '34', '34213', '7380033', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '串戸', 'クシド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市宮内', '34', '34213', '7380034', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '宮内', 'ミヤウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市宮園', '34', '34213', '7380035', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '宮園', 'ミヤゾノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市四季が丘', '34', '34213', '7380036', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '四季が丘', 'シキガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市宮園上', '34', '34213', '7380037', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '宮園上', 'ミヤゾノカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市四季が丘上', '34', '34213', '7380038', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '四季が丘上', 'シキガオカカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市宮内工業団地', '34', '34213', '7380039', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '宮内工業団地', 'ミヤウチコウギョウダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市六本松', '34', '34213', '7380041', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '六本松', 'ロッポンマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市地御前', '34', '34213', '7380042', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '地御前', 'ジゴゼン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市地御前北', '34', '34213', '7380043', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '地御前北', 'ジゴゼンキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市阿品台北', '34', '34213', '7380051', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '阿品台北', 'アジナダイキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市阿品台東', '34', '34213', '7380052', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '阿品台東', 'アジナダイヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市阿品台', '34', '34213', '7380053', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '阿品台', 'アジナダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市阿品', '34', '34213', '7380054', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '阿品', 'アジナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市阿品台西', '34', '34213', '7380055', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '阿品台西', 'アジナダイニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市阿品台山の手', '34', '34213', '7380056', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '阿品台山の手', 'アジナダイヤマノテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市陽光台', '34', '34213', '7380060', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '陽光台', 'ヨウコウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市永原', '34', '34213', '7380201', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '永原', 'ナガハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市峠', '34', '34213', '7380202', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '峠', 'トウゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市友田', '34', '34213', '7380203', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '友田', 'トモタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市河津原', '34', '34213', '7380204', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '河津原', 'カワヅハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市玖島', '34', '34213', '7380205', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '玖島', 'クジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市虫所山', '34', '34213', '7380221', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '虫所山', 'ムシトコロヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市津田', '34', '34213', '7380222', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '津田', 'ツタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市浅原', '34', '34213', '7380223', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '浅原', 'アサハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市栗栖', '34', '34213', '7380224', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '栗栖', 'クリス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市中道', '34', '34213', '7380225', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '中道', 'ナカミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市飯山', '34', '34213', '7380226', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '飯山', 'イイノヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市大野鴉ケ岡', '34', '34213', '7380281', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '大野鴉ケ岡', 'オオノカラスガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市大野渡ノ瀬', '34', '34213', '7380282', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '大野渡ノ瀬', 'オオノワタノセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市吉和', '34', '34213', '7380301', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '吉和', 'ヨシワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市佐伯区湯来町葛原', '34', '34108', '7380511', '広島県', 'ヒロシマケン', '広島市佐伯区', 'ヒロシマシサエキク', '湯来町葛原', 'ユキチョウツヅラハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市佐伯区湯来町白砂', '34', '34108', '7380512', '広島県', 'ヒロシマケン', '広島市佐伯区', 'ヒロシマシサエキク', '湯来町白砂', 'ユキチョウシラサゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市佐伯区湯来町菅沢黒谷', '34', '34108', '7380513', '広島県', 'ヒロシマケン', '広島市佐伯区', 'ヒロシマシサエキク', '湯来町菅沢', 'ユキチョウスガサワ', null, null, '黒谷', 'クロダニ');
INSERT INTO `ms_addresses` VALUES ('92317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市佐伯区湯来町伏谷', '34', '34108', '7380513', '広島県', 'ヒロシマケン', '広島市佐伯区', 'ヒロシマシサエキク', '湯来町伏谷', 'ユキチョウフシダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市佐伯区杉並台', '34', '34108', '7380514', '広島県', 'ヒロシマケン', '広島市佐伯区', 'ヒロシマシサエキク', '杉並台', 'スギナミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市佐伯区湯来町和田', '34', '34108', '7380601', '広島県', 'ヒロシマケン', '広島市佐伯区', 'ヒロシマシサエキク', '湯来町和田', 'ユキチョウワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市佐伯区湯来町麦谷', '34', '34108', '7380602', '広島県', 'ヒロシマケン', '広島市佐伯区', 'ヒロシマシサエキク', '湯来町麦谷', 'ユキチョウムギタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市佐伯区湯来町下', '34', '34108', '7380603', '広島県', 'ヒロシマケン', '広島市佐伯区', 'ヒロシマシサエキク', '湯来町下', 'ユキチョウシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市佐伯区湯来町多田', '34', '34108', '7380721', '広島県', 'ヒロシマケン', '広島市佐伯区', 'ヒロシマシサエキク', '湯来町多田', 'ユキチョウタダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市佐伯区湯来町菅沢', '34', '34108', '7380722', '広島県', 'ヒロシマケン', '広島市佐伯区', 'ヒロシマシサエキク', '湯来町菅沢', 'ユキチョウスガサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市', '34', '34212', '7390000', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('92345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市西条町西条', '34', '34212', '7390001', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '西条町西条', 'サイジョウチョウサイジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市西条町吉行', '34', '34212', '7390002', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '西条町吉行', 'サイジョウチョウヨシユキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市西条町土与丸', '34', '34212', '7390003', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '西条町土与丸', 'サイジョウチョウドヨマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市西条末広町', '34', '34212', '7390004', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '西条末広町', 'サイジョウスエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市西条大坪町', '34', '34212', '7390005', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '西条大坪町', 'サイジョウオオツボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市西条上市町', '34', '34212', '7390006', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '西条上市町', 'サイジョウカミイチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市西条土与丸', '34', '34212', '7390007', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '西条土与丸', 'サイジョウドヨマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市西条吉行東', '34', '34212', '7390008', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '西条吉行東', 'サイジョウヨシユキヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市西条本町', '34', '34212', '7390011', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '西条本町', 'サイジョウホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市西条朝日町', '34', '34212', '7390012', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '西条朝日町', 'サイジョウアサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市西条御条町', '34', '34212', '7390013', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '西条御条町', 'サイジョウゴジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市西条昭和町', '34', '34212', '7390014', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '西条昭和町', 'サイジョウショウワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市西条栄町', '34', '34212', '7390015', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '西条栄町', 'サイジョウサカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市西条岡町', '34', '34212', '7390016', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '西条岡町', 'サイジョウオカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市西条町助実', '34', '34212', '7390021', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '西条町助実', 'サイジョウチョウスケザネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市西条町上三永', '34', '34212', '7390022', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '西条町上三永', 'サイジョウチョウカミミナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市西条町下三永', '34', '34212', '7390023', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '西条町下三永', 'サイジョウチョウシモミナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市西条町御薗宇', '34', '34212', '7390024', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '西条町御薗宇', 'サイジョウチョウミソノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市西条中央', '34', '34212', '7390025', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '西条中央', 'サイジョウチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市三永', '34', '34212', '7390026', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '三永', 'ミナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市西条町福本', '34', '34212', '7390031', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '西条町福本', 'サイジョウチョウフクモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市西条町森近', '34', '34212', '7390032', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '西条町森近', 'サイジョウチョウモリチカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市西条町馬木', '34', '34212', '7390033', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '西条町馬木', 'サイジョウチョウウマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市西条町大沢', '34', '34212', '7390034', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '西条町大沢', 'サイジョウチョウオオサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市西条町郷曽', '34', '34212', '7390035', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '西条町郷曽', 'サイジョウチョウゴウソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市西条町田口', '34', '34212', '7390036', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '西条町田口', 'サイジョウチョウタグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市西大沢', '34', '34212', '7390037', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '西大沢', 'ニシオオサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市田口研究団地', '34', '34212', '7390038', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '田口研究団地', 'タグチケンキュウダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市西条町寺家', '34', '34212', '7390041', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '西条町寺家', 'サイジョウチョウジケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市西条町西条東', '34', '34212', '7390042', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '西条町西条東', 'サイジョウチョウサイジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市西条西本町', '34', '34212', '7390043', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '西条西本町', 'サイジョウニシホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市西条町下見', '34', '34212', '7390044', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '西条町下見', 'サイジョウチョウシタミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市鏡山北', '34', '34212', '7390045', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '鏡山北', 'カガミヤマキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市鏡山', '34', '34212', '7390046', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '鏡山', 'カガミヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市西条下見', '34', '34212', '7390047', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '西条下見', 'サイジョウシタミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市西条東北町', '34', '34212', '7390048', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '西条東北町', 'サイジョウヒガシキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市八本松町篠', '34', '34212', '7390131', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '八本松町篠', 'ハチホンマツチョウササ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市八本松町正力', '34', '34212', '7390132', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '八本松町正力', 'ハチホンマツチョウショウリキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市八本松町米満', '34', '34212', '7390133', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '八本松町米満', 'ハチホンマツチョウヨネミツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市八本松町飯田', '34', '34212', '7390141', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '八本松町飯田', 'ハチホンマツチョウイイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市八本松東', '34', '34212', '7390142', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '八本松東', 'ハチホンマツヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市八本松南', '34', '34212', '7390144', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '八本松南', 'ハチホンマツミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市八本松町宗吉', '34', '34212', '7390145', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '八本松町宗吉', 'ハチホンマツチョウムネヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市八本松飯田', '34', '34212', '7390146', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '八本松飯田', 'ハチホンマツイイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市八本松町原', '34', '34212', '7390151', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '八本松町原', 'ハチホンマツチョウハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市八本松町吉川', '34', '34212', '7390152', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '八本松町吉川', 'ハチホンマツチョウヨシカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市吉川工業団地', '34', '34212', '7390153', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '吉川工業団地', 'ヨシカワコウギョウダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市志和町内', '34', '34212', '7390261', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '志和町内', 'シワチョウウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市志和町志和東', '34', '34212', '7390262', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '志和町志和東', 'シワチョウシワヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市志和流通', '34', '34212', '7390263', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '志和流通', 'シワリュウツウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市志和町七条椛坂', '34', '34212', '7390264', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '志和町七条椛坂', 'シワチョウシチジョウカブサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市志和町冠', '34', '34212', '7390265', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '志和町冠', 'シワチョウカンムリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市志和町奥屋', '34', '34212', '7390266', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '志和町奥屋', 'シワチョウオクヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市志和町別府', '34', '34212', '7390267', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '志和町別府', 'シワチョウベフ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市志和町志和西', '34', '34212', '7390268', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '志和町志和西', 'シワチョウシワニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市志和町志和堀', '34', '34212', '7390269', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '志和町志和堀', 'シワチョウシワホリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安芸区上瀬野', '34', '34107', '7390301', '広島県', 'ヒロシマケン', '広島市安芸区', 'ヒロシマシアキク', '上瀬野', 'カミセノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安芸区上瀬野町', '34', '34107', '7390302', '広島県', 'ヒロシマケン', '広島市安芸区', 'ヒロシマシアキク', '上瀬野町', 'カミセノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安芸区上瀬野南', '34', '34107', '7390303', '広島県', 'ヒロシマケン', '広島市安芸区', 'ヒロシマシアキク', '上瀬野南', 'カミセノミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安芸区瀬野', '34', '34107', '7390311', '広島県', 'ヒロシマケン', '広島市安芸区', 'ヒロシマシアキク', '瀬野', 'セノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安芸区瀬野町', '34', '34107', '7390312', '広島県', 'ヒロシマケン', '広島市安芸区', 'ヒロシマシアキク', '瀬野町', 'セノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安芸区瀬野西', '34', '34107', '7390313', '広島県', 'ヒロシマケン', '広島市安芸区', 'ヒロシマシアキク', '瀬野西', 'セノニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安芸区瀬野南', '34', '34107', '7390314', '広島県', 'ヒロシマケン', '広島市安芸区', 'ヒロシマシアキク', '瀬野南', 'セノミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安芸区瀬野南町', '34', '34107', '7390315', '広島県', 'ヒロシマケン', '広島市安芸区', 'ヒロシマシアキク', '瀬野南町', 'セノミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安芸区中野', '34', '34107', '7390321', '広島県', 'ヒロシマケン', '広島市安芸区', 'ヒロシマシアキク', '中野', 'ナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安芸区中野町', '34', '34107', '7390322', '広島県', 'ヒロシマケン', '広島市安芸区', 'ヒロシマシアキク', '中野町', 'ナカノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安芸区中野東', '34', '34107', '7390323', '広島県', 'ヒロシマケン', '広島市安芸区', 'ヒロシマシアキク', '中野東', 'ナカノヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安芸区中野東町', '34', '34107', '7390324', '広島県', 'ヒロシマケン', '広島市安芸区', 'ヒロシマシアキク', '中野東町', 'ナカノヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市福面', '34', '34213', '7390401', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '福面', 'フクメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市対厳山', '34', '34213', '7390402', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '対厳山', 'タイゲンザン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市大野下更地', '34', '34213', '7390403', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '大野下更地', 'オオノシモサラジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市大野十郎原', '34', '34213', '7390404', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '大野十郎原', 'オオノジュウロウバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市大野戸石川', '34', '34213', '7390405', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '大野戸石川', 'オオノトイシガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市大野中山', '34', '34213', '7390406', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '大野中山', 'オオノナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市大野上更地', '34', '34213', '7390407', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '大野上更地', 'オオノカミサラジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市大野鯛ノ原', '34', '34213', '7390408', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '大野鯛ノ原', 'オオノタイノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市宮島口', '34', '34213', '7390411', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '宮島口', 'ミヤジマグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市宮島口西', '34', '34213', '7390412', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '宮島口西', 'ミヤジマグチニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市宮島口上', '34', '34213', '7390413', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '宮島口上', 'ミヤジマグチウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市宮島口東', '34', '34213', '7390414', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '宮島口東', 'ミヤジマグチヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市深江', '34', '34213', '7390421', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '深江', 'フカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市大野早時', '34', '34213', '7390422', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '大野早時', 'オオノソウトキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市大野賀撫津', '34', '34213', '7390423', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '大野賀撫津', 'オオノガブツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市前空', '34', '34213', '7390424', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '前空', 'マエゾラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市物見西', '34', '34213', '7390425', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '物見西', 'モノミニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市物見東', '34', '34213', '7390426', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '物見東', 'モノミヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市上の浜', '34', '34213', '7390432', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '上の浜', 'カミノハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市下の浜', '34', '34213', '7390433', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '下の浜', 'シモノハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市大野1丁目', '34', '34213', '7390434', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '大野', 'オオノ', null, null, '1丁目', '01チョウメ');
INSERT INTO `ms_addresses` VALUES ('92437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市大野2丁目', '34', '34213', '7390434', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '大野', 'オオノ', null, null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('92438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市大野中央', '34', '34213', '7390437', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '大野中央', 'オオノチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市大野原', '34', '34213', '7390441', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '大野原', 'オオノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市梅原', '34', '34213', '7390442', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '梅原', 'ウメハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市沖塩屋', '34', '34213', '7390443', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '沖塩屋', 'オキシオヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市林が原', '34', '34213', '7390444', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '林が原', 'ハヤシガハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市塩屋', '34', '34213', '7390445', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '塩屋', 'シオヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市大野小山', '34', '34213', '7390446', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '大野小山', 'オオノコヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市丸石', '34', '34213', '7390452', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '丸石', 'マルイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市宮浜温泉', '34', '34213', '7390454', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '宮浜温泉', 'ミヤハマオンセン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市八坂', '34', '34213', '7390455', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '八坂', 'ハッサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市大野垣ノ浦', '34', '34213', '7390456', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '大野垣ノ浦', 'オオノカキノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市大野下灘', '34', '34213', '7390457', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '大野下灘', 'オオノシモナダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市大野鳴川', '34', '34213', '7390458', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '大野鳴川', 'オオノナルカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市大野四十八坂', '34', '34213', '7390459', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '大野四十八坂', 'オオノシジュウハッサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市大野郷', '34', '34213', '7390461', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '大野郷', 'オオノゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市大野陣場', '34', '34213', '7390462', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '大野陣場', 'オオノジンバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市大野小田ノ口', '34', '34213', '7390463', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '大野小田ノ口', 'オオノオダノクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市大野水ノ越', '34', '34213', '7390464', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '大野水ノ越', 'オオノミノコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市大野滝ノ下', '34', '34213', '7390466', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '大野滝ノ下', 'オオノタキノシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市大野中津岡', '34', '34213', '7390467', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '大野中津岡', 'オオノナカツオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市大野別府', '34', '34213', '7390471', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '大野別府', 'オオノベフ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市大野棚田', '34', '34213', '7390472', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '大野棚田', 'オオノタナダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市大野田屋', '34', '34213', '7390473', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '大野田屋', 'オオノタヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市大野土井', '34', '34213', '7390474', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '大野土井', 'オオノドイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市大野高畑', '34', '34213', '7390475', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '大野高畑', 'オオノタカバタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市大野高見', '34', '34213', '7390476', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '大野高見', 'オオノタカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市大野水口', '34', '34213', '7390477', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '大野水口', 'オオノミズグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市大野筏津', '34', '34213', '7390478', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '大野筏津', 'オオノイカナヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市大野池田', '34', '34213', '7390479', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '大野池田', 'オオノイケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市大野', '34', '34213', '7390488', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '大野', 'オオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市宮島町杉之浦', '34', '34213', '7390501', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '宮島町', 'ミヤジマチョウ', null, null, '杉之浦', 'スギノウラ');
INSERT INTO `ms_addresses` VALUES ('92474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市宮島町杉之浦住宅', '34', '34213', '7390502', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '宮島町', 'ミヤジマチョウ', null, null, '杉之浦住宅', 'スギノウラジュウタク');
INSERT INTO `ms_addresses` VALUES ('92475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市宮島町ひの木団地', '34', '34213', '7390503', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '宮島町', 'ミヤジマチョウ', null, null, 'ひの木団地', 'ヒノキダンチ');
INSERT INTO `ms_addresses` VALUES ('92476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市宮島町港町', '34', '34213', '7390504', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '宮島町', 'ミヤジマチョウ', null, null, '港町', 'ミナトマチ');
INSERT INTO `ms_addresses` VALUES ('92477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市宮島町胡町', '34', '34213', '7390505', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '宮島町', 'ミヤジマチョウ', null, null, '胡町', 'エビスマチ');
INSERT INTO `ms_addresses` VALUES ('92478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市宮島町緑町', '34', '34213', '7390506', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '宮島町', 'ミヤジマチョウ', null, null, '緑町', 'ミドリマチ');
INSERT INTO `ms_addresses` VALUES ('92479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市宮島町大砂利', '34', '34213', '7390507', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '宮島町', 'ミヤジマチョウ', null, null, '大砂利', 'オオジャリ');
INSERT INTO `ms_addresses` VALUES ('92480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市宮島町伊勢町', '34', '34213', '7390511', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '宮島町', 'ミヤジマチョウ', null, null, '伊勢町', 'イセマチ');
INSERT INTO `ms_addresses` VALUES ('92481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市宮島町新町', '34', '34213', '7390512', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '宮島町', 'ミヤジマチョウ', null, null, '新町', 'シンマチ');
INSERT INTO `ms_addresses` VALUES ('92482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市宮島町上西連町', '34', '34213', '7390513', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '宮島町', 'ミヤジマチョウ', null, null, '上西連町', 'カミサイレンチョウ');
INSERT INTO `ms_addresses` VALUES ('92483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市宮島町東西連町', '34', '34213', '7390514', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '宮島町', 'ミヤジマチョウ', null, null, '東西連町', 'ヒガシサイレンチョウ');
INSERT INTO `ms_addresses` VALUES ('92484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市宮島町魚之棚町', '34', '34213', '7390515', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '宮島町', 'ミヤジマチョウ', null, null, '魚之棚町', 'ウオノタナチョウ');
INSERT INTO `ms_addresses` VALUES ('92485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市宮島町桜町', '34', '34213', '7390516', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '宮島町', 'ミヤジマチョウ', null, null, '桜町', 'サクラマチ');
INSERT INTO `ms_addresses` VALUES ('92486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市宮島町大和町', '34', '34213', '7390517', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '宮島町', 'ミヤジマチョウ', null, null, '大和町', 'ヤマトマチ');
INSERT INTO `ms_addresses` VALUES ('92487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市宮島町下西連町', '34', '34213', '7390518', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '宮島町', 'ミヤジマチョウ', null, null, '下西連町', 'シモサイレンチョウ');
INSERT INTO `ms_addresses` VALUES ('92488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市宮島町大町', '34', '34213', '7390521', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '宮島町', 'ミヤジマチョウ', null, null, '大町', 'オオマチ');
INSERT INTO `ms_addresses` VALUES ('92489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市宮島町南町', '34', '34213', '7390522', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '宮島町', 'ミヤジマチョウ', null, null, '南町', 'ミナミマチ');
INSERT INTO `ms_addresses` VALUES ('92490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市宮島町中江町', '34', '34213', '7390523', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '宮島町', 'ミヤジマチョウ', null, null, '中江町', 'チュウエマチ');
INSERT INTO `ms_addresses` VALUES ('92491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市宮島町滝町', '34', '34213', '7390524', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '宮島町', 'ミヤジマチョウ', null, null, '滝町', 'タキマチ');
INSERT INTO `ms_addresses` VALUES ('92492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市宮島町久保町', '34', '34213', '7390525', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '宮島町', 'ミヤジマチョウ', null, null, '久保町', 'クボマチ');
INSERT INTO `ms_addresses` VALUES ('92493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市宮島町上中西町', '34', '34213', '7390531', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '宮島町', 'ミヤジマチョウ', null, null, '上中西町', 'カミナカニシチョウ');
INSERT INTO `ms_addresses` VALUES ('92494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市宮島町東大西町', '34', '34213', '7390532', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '宮島町', 'ミヤジマチョウ', null, null, '東大西町', 'ヒガシオオニシチョウ');
INSERT INTO `ms_addresses` VALUES ('92495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市宮島町南大西町', '34', '34213', '7390533', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '宮島町', 'ミヤジマチョウ', null, null, '南大西町', 'ミナミオオニシチョウ');
INSERT INTO `ms_addresses` VALUES ('92496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市宮島町西大西町', '34', '34213', '7390534', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '宮島町', 'ミヤジマチョウ', null, null, '西大西町', 'ニシオオニシチョウ');
INSERT INTO `ms_addresses` VALUES ('92497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市宮島町北大西町', '34', '34213', '7390535', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '宮島町', 'ミヤジマチョウ', null, null, '北大西町', 'キタオオニシチョウ');
INSERT INTO `ms_addresses` VALUES ('92498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市宮島町下中西町', '34', '34213', '7390536', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '宮島町', 'ミヤジマチョウ', null, null, '下中西町', 'シモナカニシチョウ');
INSERT INTO `ms_addresses` VALUES ('92499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市宮島町網之浦', '34', '34213', '7390541', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '宮島町', 'ミヤジマチョウ', null, null, '網之浦', 'アミノウラ');
INSERT INTO `ms_addresses` VALUES ('92500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市宮島町多々良潟', '34', '34213', '7390542', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '宮島町', 'ミヤジマチョウ', null, null, '多々良潟', 'タタラガタ');
INSERT INTO `ms_addresses` VALUES ('92501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市宮島町室浜', '34', '34213', '7390543', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '宮島町', 'ミヤジマチョウ', null, null, '室浜', 'ムロハマ');
INSERT INTO `ms_addresses` VALUES ('92502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市宮島町浜之町', '34', '34213', '7390550', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '宮島町', 'ミヤジマチョウ', null, null, '浜之町', 'ハマノチョウ');
INSERT INTO `ms_addresses` VALUES ('92503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市宮島町北之町東表', '34', '34213', '7390551', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '宮島町', 'ミヤジマチョウ', null, null, '北之町東表', 'キタノチョウヒガシオモテ');
INSERT INTO `ms_addresses` VALUES ('92504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市宮島町北之町西表', '34', '34213', '7390552', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '宮島町', 'ミヤジマチョウ', null, null, '北之町西表', 'キタノチョウニシオモテ');
INSERT INTO `ms_addresses` VALUES ('92505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市宮島町中之町表', '34', '34213', '7390553', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '宮島町', 'ミヤジマチョウ', null, null, '中之町表', 'ナカノチョウオモテ');
INSERT INTO `ms_addresses` VALUES ('92506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市宮島町幸町東表', '34', '34213', '7390554', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '宮島町', 'ミヤジマチョウ', null, null, '幸町東表', 'サイワイチョウヒガシオモテ');
INSERT INTO `ms_addresses` VALUES ('92507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市宮島町幸町西表', '34', '34213', '7390555', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '宮島町', 'ミヤジマチョウ', null, null, '幸町西表', 'サイワイチョウニシオモテ');
INSERT INTO `ms_addresses` VALUES ('92508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市宮島町幸町西浜', '34', '34213', '7390556', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '宮島町', 'ミヤジマチョウ', null, null, '幸町西浜', 'サイワイチョウニシハマ');
INSERT INTO `ms_addresses` VALUES ('92509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市宮島町幸町東浜', '34', '34213', '7390557', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '宮島町', 'ミヤジマチョウ', null, null, '幸町東浜', 'サイワイチョウヒガシハマ');
INSERT INTO `ms_addresses` VALUES ('92510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市宮島町中之町浜', '34', '34213', '7390558', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '宮島町', 'ミヤジマチョウ', null, null, '中之町浜', 'ナカノチョウハマ');
INSERT INTO `ms_addresses` VALUES ('92511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市宮島町北之町浜', '34', '34213', '7390559', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '宮島町', 'ミヤジマチョウ', null, null, '北之町浜', 'キタノチョウハマ');
INSERT INTO `ms_addresses` VALUES ('92512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市宮島町', '34', '34213', '7390588', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '宮島町', 'ミヤジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県大竹市', '34', '34211', '7390600', '広島県', 'ヒロシマケン', '大竹市', 'オオタケシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('92516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県大竹市東栄', '34', '34211', '7390601', '広島県', 'ヒロシマケン', '大竹市', 'オオタケシ', '東栄', 'ヒガシサカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県大竹市南栄', '34', '34211', '7390602', '広島県', 'ヒロシマケン', '大竹市', 'オオタケシ', '南栄', 'ミナミサカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県大竹市西栄', '34', '34211', '7390603', '広島県', 'ヒロシマケン', '大竹市', 'オオタケシ', '西栄', 'ニシサカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県大竹市北栄', '34', '34211', '7390604', '広島県', 'ヒロシマケン', '大竹市', 'オオタケシ', '北栄', 'キタサカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県大竹市立戸', '34', '34211', '7390605', '広島県', 'ヒロシマケン', '大竹市', 'オオタケシ', '立戸', 'タチド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県大竹市御幸町', '34', '34211', '7390606', '広島県', 'ヒロシマケン', '大竹市', 'オオタケシ', '御幸町', 'ミユキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県大竹市阿多田', '34', '34211', '7390607', '広島県', 'ヒロシマケン', '大竹市', 'オオタケシ', '阿多田', 'アタタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県大竹市新町', '34', '34211', '7390611', '広島県', 'ヒロシマケン', '大竹市', 'オオタケシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県大竹市油見', '34', '34211', '7390612', '広島県', 'ヒロシマケン', '大竹市', 'オオタケシ', '油見', 'ユウミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県大竹市本町', '34', '34211', '7390613', '広島県', 'ヒロシマケン', '大竹市', 'オオタケシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県大竹市白石', '34', '34211', '7390614', '広島県', 'ヒロシマケン', '大竹市', 'オオタケシ', '白石', 'シライシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県大竹市元町', '34', '34211', '7390615', '広島県', 'ヒロシマケン', '大竹市', 'オオタケシ', '元町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県大竹市木野', '34', '34211', '7390616', '広島県', 'ヒロシマケン', '大竹市', 'オオタケシ', '木野', 'コノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県大竹市港町', '34', '34211', '7390621', '広島県', 'ヒロシマケン', '大竹市', 'オオタケシ', '港町', 'ミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県大竹市晴海', '34', '34211', '7390622', '広島県', 'ヒロシマケン', '大竹市', 'オオタケシ', '晴海', 'ハルミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県大竹市小方', '34', '34211', '7390623', '広島県', 'ヒロシマケン', '大竹市', 'オオタケシ', '小方', 'オガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県大竹市御園', '34', '34211', '7390624', '広島県', 'ヒロシマケン', '大竹市', 'オオタケシ', '御園', 'ミソノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県大竹市御園台', '34', '34211', '7390625', '広島県', 'ヒロシマケン', '大竹市', 'オオタケシ', '御園台', 'ミソノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県大竹市三ツ石町', '34', '34211', '7390626', '広島県', 'ヒロシマケン', '大竹市', 'オオタケシ', '三ツ石町', 'ミツイシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県大竹市小方町小方', '34', '34211', '7390627', '広島県', 'ヒロシマケン', '大竹市', 'オオタケシ', '小方町小方', 'オガタチョウオガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県大竹市防鹿', '34', '34211', '7390631', '広島県', 'ヒロシマケン', '大竹市', 'オオタケシ', '防鹿', 'ボウロク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県大竹市穂仁原', '34', '34211', '7390632', '広島県', 'ヒロシマケン', '大竹市', 'オオタケシ', '穂仁原', 'オニハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県大竹市比作', '34', '34211', '7390633', '広島県', 'ヒロシマケン', '大竹市', 'オオタケシ', '比作', 'ヒッツクリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県大竹市安条', '34', '34211', '7390634', '広島県', 'ヒロシマケン', '大竹市', 'オオタケシ', '安条', 'アンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県大竹市八丁', '34', '34211', '7390635', '広島県', 'ヒロシマケン', '大竹市', 'オオタケシ', '八丁', 'ハッチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県大竹市前飯谷', '34', '34211', '7390636', '広島県', 'ヒロシマケン', '大竹市', 'オオタケシ', '前飯谷', 'マエイイタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県大竹市後飯谷', '34', '34211', '7390637', '広島県', 'ヒロシマケン', '大竹市', 'オオタケシ', '後飯谷', 'ウシロイイタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県大竹市栗谷町広原', '34', '34211', '7390641', '広島県', 'ヒロシマケン', '大竹市', 'オオタケシ', '栗谷町広原', 'クリタニチョウヒロハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県大竹市栗谷町奥谷尻', '34', '34211', '7390642', '広島県', 'ヒロシマケン', '大竹市', 'オオタケシ', '栗谷町奥谷尻', 'クリタニチョウオクタニジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県大竹市栗谷町谷和', '34', '34211', '7390643', '広島県', 'ヒロシマケン', '大竹市', 'オオタケシ', '栗谷町谷和', 'クリタニチョウタニワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県大竹市栗谷町後原', '34', '34211', '7390644', '広島県', 'ヒロシマケン', '大竹市', 'オオタケシ', '栗谷町後原', 'クリタニチョウウシロバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県大竹市栗谷町小栗林', '34', '34211', '7390645', '広島県', 'ヒロシマケン', '大竹市', 'オオタケシ', '栗谷町小栗林', 'クリタニチョウコクリバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県大竹市栗谷町大栗林', '34', '34211', '7390646', '広島県', 'ヒロシマケン', '大竹市', 'オオタケシ', '栗谷町大栗林', 'クリタニチョウオオクリバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県大竹市玖波', '34', '34211', '7390651', '広島県', 'ヒロシマケン', '大竹市', 'オオタケシ', '玖波', 'クバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県大竹市明治新開', '34', '34211', '7390652', '広島県', 'ヒロシマケン', '大竹市', 'オオタケシ', '明治新開', 'メイジシンガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県大竹市黒川', '34', '34211', '7390653', '広島県', 'ヒロシマケン', '大竹市', 'オオタケシ', '黒川', 'クロカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県大竹市小方町黒川', '34', '34211', '7390654', '広島県', 'ヒロシマケン', '大竹市', 'オオタケシ', '小方町黒川', 'オガタチョウクロカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県大竹市湯舟町', '34', '34211', '7390655', '広島県', 'ヒロシマケン', '大竹市', 'オオタケシ', '湯舟町', 'ユブネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県大竹市玖波町', '34', '34211', '7390656', '広島県', 'ヒロシマケン', '大竹市', 'オオタケシ', '玖波町', 'クバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県大竹市松ケ原町', '34', '34211', '7390657', '広島県', 'ヒロシマケン', '大竹市', 'オオタケシ', '松ケ原町', 'マツガハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市大野経小屋', '34', '34213', '7390661', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '大野経小屋', 'オオノキョウゴヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市大野奴メリ谷', '34', '34213', '7390663', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '大野奴メリ谷', 'オオノヌメリダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市大野嵐谷', '34', '34213', '7390664', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '大野嵐谷', 'オオノアラシダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市大野横撫', '34', '34213', '7390665', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '大野横撫', 'オオノヨコナデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県廿日市市大野猪ノウツ', '34', '34213', '7390667', '広島県', 'ヒロシマケン', '廿日市市', 'ハツカイチシ', '大野猪ノウツ', 'オオノイノウツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸高田市甲田町高田原', '34', '34214', '7391101', '広島県', 'ヒロシマケン', '安芸高田市', 'アキタカタシ', '甲田町高田原', 'コウダチョウタカタバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸高田市甲田町上小原', '34', '34214', '7391102', '広島県', 'ヒロシマケン', '安芸高田市', 'アキタカタシ', '甲田町上小原', 'コウダチョウカミオバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸高田市甲田町下小原', '34', '34214', '7391103', '広島県', 'ヒロシマケン', '安芸高田市', 'アキタカタシ', '甲田町下小原', 'コウダチョウシモオバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸高田市甲田町上甲立', '34', '34214', '7391104', '広島県', 'ヒロシマケン', '安芸高田市', 'アキタカタシ', '甲田町上甲立', 'コウダチョウカミコウタチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸高田市甲田町下甲立', '34', '34214', '7391105', '広島県', 'ヒロシマケン', '安芸高田市', 'アキタカタシ', '甲田町下甲立', 'コウダチョウシモコウタチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸高田市甲田町浅塚', '34', '34214', '7391106', '広島県', 'ヒロシマケン', '安芸高田市', 'アキタカタシ', '甲田町浅塚', 'コウダチョウアサツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸高田市甲田町糘地', '34', '34214', '7391107', '広島県', 'ヒロシマケン', '安芸高田市', 'アキタカタシ', '甲田町糘地', 'コウダチョウスクモジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸高田市甲田町深瀬', '34', '34214', '7391108', '広島県', 'ヒロシマケン', '安芸高田市', 'アキタカタシ', '甲田町深瀬', 'コウダチョウフカセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸高田市向原町坂', '34', '34214', '7391201', '広島県', 'ヒロシマケン', '安芸高田市', 'アキタカタシ', '向原町坂', 'ムカイハラチョウサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸高田市向原町戸島', '34', '34214', '7391202', '広島県', 'ヒロシマケン', '安芸高田市', 'アキタカタシ', '向原町戸島', 'ムカイハラチョウトシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸高田市向原町長田', '34', '34214', '7391203', '広島県', 'ヒロシマケン', '安芸高田市', 'アキタカタシ', '向原町長田', 'ムカイハラチョウナガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸高田市向原町有留', '34', '34214', '7391204', '広島県', 'ヒロシマケン', '安芸高田市', 'アキタカタシ', '向原町有留', 'ムカイハラチョウアリドメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸高田市向原町保垣', '34', '34214', '7391205', '広島県', 'ヒロシマケン', '安芸高田市', 'アキタカタシ', '向原町保垣', 'ムカイハラチョウホガキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安佐北区白木町井原', '34', '34106', '7391301', '広島県', 'ヒロシマケン', '広島市安佐北区', 'ヒロシマシアサキタク', '白木町井原', 'シラキチョウイバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安佐北区白木町古屋', '34', '34106', '7391302', '広島県', 'ヒロシマケン', '広島市安佐北区', 'ヒロシマシアサキタク', '白木町古屋', 'シラキチョウコヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安佐北区白木町志路', '34', '34106', '7391303', '広島県', 'ヒロシマケン', '広島市安佐北区', 'ヒロシマシアサキタク', '白木町志路', 'シラキチョウシジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安佐北区白木町市川', '34', '34106', '7391411', '広島県', 'ヒロシマケン', '広島市安佐北区', 'ヒロシマシアサキタク', '白木町市川', 'シラキチョウイチカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安佐北区白木町小越', '34', '34106', '7391412', '広島県', 'ヒロシマケン', '広島市安佐北区', 'ヒロシマシアサキタク', '白木町小越', 'シラキチョウオコエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安佐北区白木町有留', '34', '34106', '7391413', '広島県', 'ヒロシマケン', '広島市安佐北区', 'ヒロシマシアサキタク', '白木町有留', 'シラキチョウアリドメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安佐北区白木町秋山', '34', '34106', '7391414', '広島県', 'ヒロシマケン', '広島市安佐北区', 'ヒロシマシアサキタク', '白木町秋山', 'シラキチョウアキヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安佐北区白木町三田', '34', '34106', '7391521', '広島県', 'ヒロシマケン', '広島市安佐北区', 'ヒロシマシアサキタク', '白木町三田', 'シラキチョウミタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安佐北区', '34', '34106', '7391700', '広島県', 'ヒロシマケン', '広島市安佐北区', 'ヒロシマシアサキタク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('92592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安佐北区落合', '34', '34106', '7391731', '広島県', 'ヒロシマケン', '広島市安佐北区', 'ヒロシマシアサキタク', '落合', 'オチアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安佐北区落合南', '34', '34106', '7391732', '広島県', 'ヒロシマケン', '広島市安佐北区', 'ヒロシマシアサキタク', '落合南', 'オチアイミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安佐北区落合南町', '34', '34106', '7391732', '広島県', 'ヒロシマケン', '広島市安佐北区', 'ヒロシマシアサキタク', '落合南町', 'オチアイミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安佐北区口田南', '34', '34106', '7391733', '広島県', 'ヒロシマケン', '広島市安佐北区', 'ヒロシマシアサキタク', '口田南', 'クチタミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安佐北区口田南町', '34', '34106', '7391733', '広島県', 'ヒロシマケン', '広島市安佐北区', 'ヒロシマシアサキタク', '口田南町', 'クチタミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安佐北区口田', '34', '34106', '7391734', '広島県', 'ヒロシマケン', '広島市安佐北区', 'ヒロシマシアサキタク', '口田', 'クチタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安佐北区口田町', '34', '34106', '7391734', '広島県', 'ヒロシマケン', '広島市安佐北区', 'ヒロシマシアサキタク', '口田町', 'クチタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安佐北区真亀', '34', '34106', '7391741', '広島県', 'ヒロシマケン', '広島市安佐北区', 'ヒロシマシアサキタク', '真亀', 'マガメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安佐北区亀崎', '34', '34106', '7391742', '広島県', 'ヒロシマケン', '広島市安佐北区', 'ヒロシマシアサキタク', '亀崎', 'カメザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安佐北区倉掛', '34', '34106', '7391743', '広島県', 'ヒロシマケン', '広島市安佐北区', 'ヒロシマシアサキタク', '倉掛', 'クラカケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安佐北区深川', '34', '34106', '7391751', '広島県', 'ヒロシマケン', '広島市安佐北区', 'ヒロシマシアサキタク', '深川', 'フカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安佐北区深川町', '34', '34106', '7391751', '広島県', 'ヒロシマケン', '広島市安佐北区', 'ヒロシマシアサキタク', '深川町', 'フカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安佐北区上深川町', '34', '34106', '7391752', '広島県', 'ヒロシマケン', '広島市安佐北区', 'ヒロシマシアサキタク', '上深川町', 'カミフカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安佐北区狩留家町', '34', '34106', '7391753', '広島県', 'ヒロシマケン', '広島市安佐北区', 'ヒロシマシアサキタク', '狩留家町', 'カルガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県広島市安佐北区小河原町', '34', '34106', '7391754', '広島県', 'ヒロシマケン', '広島市安佐北区', 'ヒロシマシアサキタク', '小河原町', 'オガワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸高田市高宮町川根', '34', '34214', '7391801', '広島県', 'ヒロシマケン', '安芸高田市', 'アキタカタシ', '高宮町川根', 'タカミヤチョウカワネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸高田市高宮町佐々部', '34', '34214', '7391802', '広島県', 'ヒロシマケン', '安芸高田市', 'アキタカタシ', '高宮町佐々部', 'タカミヤチョウササベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸高田市高宮町船木', '34', '34214', '7391803', '広島県', 'ヒロシマケン', '安芸高田市', 'アキタカタシ', '高宮町船木', 'タカミヤチョウフナキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸高田市高宮町房後', '34', '34214', '7391804', '広島県', 'ヒロシマケン', '安芸高田市', 'アキタカタシ', '高宮町房後', 'タカミヤチョウボウゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸高田市高宮町原田', '34', '34214', '7391805', '広島県', 'ヒロシマケン', '安芸高田市', 'アキタカタシ', '高宮町原田', 'タカミヤチョウハラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸高田市高宮町来女木', '34', '34214', '7391806', '広島県', 'ヒロシマケン', '安芸高田市', 'アキタカタシ', '高宮町来女木', 'タカミヤチョウクルメギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県安芸高田市高宮町羽佐竹', '34', '34214', '7391807', '広島県', 'ヒロシマケン', '安芸高田市', 'アキタカタシ', '高宮町羽佐竹', 'タカミヤチョウハサダケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市高屋町造賀', '34', '34212', '7392101', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '高屋町造賀', 'タカヤチョウゾウカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市高屋町杵原', '34', '34212', '7392102', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '高屋町杵原', 'タカヤチョウキネハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市高屋町宮領', '34', '34212', '7392103', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '高屋町宮領', 'タカヤチョウミヤリョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市高屋町大畠', '34', '34212', '7392104', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '高屋町大畠', 'タカヤチョウオオバタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市高屋町檜山', '34', '34212', '7392105', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '高屋町檜山', 'タカヤチョウヒヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市高屋町稲木', '34', '34212', '7392106', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '高屋町稲木', 'タカヤチョウイナキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市高屋町高屋堀', '34', '34212', '7392111', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '高屋町高屋堀', 'タカヤチョウタカヤホリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市高屋町貞重', '34', '34212', '7392112', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '高屋町貞重', 'タカヤチョウサダシゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市高屋町高屋東', '34', '34212', '7392113', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '高屋町高屋東', 'タカヤチョウタカヤヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市高屋町白市', '34', '34212', '7392114', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '高屋町白市', 'タカヤチョウシライチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市高屋高美が丘', '34', '34212', '7392115', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '高屋高美が丘', 'タカヤタカミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市高屋うめの辺', '34', '34212', '7392116', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '高屋うめの辺', 'タカヤウメノベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市高屋台', '34', '34212', '7392117', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '高屋台', 'タカヤダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市高屋町小谷', '34', '34212', '7392121', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '高屋町小谷', 'タカヤチョウコダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市高屋町重兼', '34', '34212', '7392122', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '高屋町重兼', 'タカヤチョウシゲカネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市高屋町溝口', '34', '34212', '7392123', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '高屋町溝口', 'タカヤチョウミゾグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市高屋町郷', '34', '34212', '7392124', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '高屋町郷', 'タカヤチョウゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市高屋町中島', '34', '34212', '7392125', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '高屋町中島', 'タカヤチョウナカシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市河内町中河内', '34', '34212', '7392201', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '河内町中河内', 'コウチチョウナカゴウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市河内町下河内', '34', '34212', '7392202', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '河内町下河内', 'コウチチョウシモゴウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市河内町上河内', '34', '34212', '7392203', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '河内町上河内', 'コウチチョウカミゴウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市河内町河戸', '34', '34212', '7392204', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '河内町河戸', 'コウチチョウコウド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市河内町戸野', '34', '34212', '7392205', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '河内町戸野', 'コウチチョウトノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市河内町宇山', '34', '34212', '7392206', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '河内町宇山', 'コウチチョウウヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市河内町小田', '34', '34212', '7392207', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '河内町小田', 'コウチチョウオダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市河内町入野', '34', '34212', '7392208', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '河内町入野', 'コウチチョウニュウノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市福富町上竹仁', '34', '34212', '7392301', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '福富町上竹仁', 'フクトミチョウカミダケニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市福富町下竹仁', '34', '34212', '7392302', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '福富町下竹仁', 'フクトミチョウシモダケニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市福富町久芳', '34', '34212', '7392303', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '福富町久芳', 'フクトミチョウクバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市福富町上戸野', '34', '34212', '7392304', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '福富町上戸野', 'フクトミチョウカミトノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市豊栄町乃美', '34', '34212', '7392311', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '豊栄町乃美', 'トヨサカチョウノミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市豊栄町別府', '34', '34212', '7392312', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '豊栄町別府', 'トヨサカチョウベフ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市豊栄町清武', '34', '34212', '7392313', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '豊栄町清武', 'トヨサカチョウキヨタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市豊栄町飯田', '34', '34212', '7392314', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '豊栄町飯田', 'トヨサカチョウイイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市豊栄町吉原', '34', '34212', '7392315', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '豊栄町吉原', 'トヨサカチョウヨシワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市豊栄町安宿', '34', '34212', '7392316', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '豊栄町安宿', 'トヨサカチョウアスカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市豊栄町鍛冶屋', '34', '34212', '7392317', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '豊栄町鍛冶屋', 'トヨサカチョウカジヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市豊栄町能良', '34', '34212', '7392318', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '豊栄町能良', 'トヨサカチョウノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市安芸津町木谷', '34', '34212', '7392401', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '安芸津町木谷', 'アキツチョウキダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市安芸津町三津', '34', '34212', '7392402', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '安芸津町三津', 'アキツチョウミツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市安芸津町風早', '34', '34212', '7392403', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '安芸津町風早', 'アキツチョウカザハヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市安芸津町大田', '34', '34212', '7392404', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '安芸津町大田', 'アキツチョウオオダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市安芸津町小松原', '34', '34212', '7392405', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '安芸津町小松原', 'アキツチョウコマツバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市黒瀬町小多田', '34', '34212', '7392501', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '黒瀬町小多田', 'クロセチョウオタダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市黒瀬町国近', '34', '34212', '7392502', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '黒瀬町国近', 'クロセチョウクニチカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市黒瀬町南方', '34', '34212', '7392503', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '黒瀬町南方', 'クロセチョウミナミガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市黒瀬町宗近柳国', '34', '34212', '7392504', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '黒瀬町宗近柳国', 'クロセチョウムネチカヤナクニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市黒瀬町大多田', '34', '34212', '7392611', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '黒瀬町大多田', 'クロセチョウオオタダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市黒瀬町丸山', '34', '34212', '7392612', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '黒瀬町丸山', 'クロセチョウマルヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市黒瀬町楢原', '34', '34212', '7392613', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '黒瀬町楢原', 'クロセチョウナラハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市黒瀬松ケ丘', '34', '34212', '7392614', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '黒瀬松ケ丘', 'クロセマツガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市黒瀬春日野', '34', '34212', '7392615', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '黒瀬春日野', 'クロセカスガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市黒瀬町兼広', '34', '34212', '7392616', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '黒瀬町兼広', 'クロセチョウカネヒロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市黒瀬町切田', '34', '34212', '7392617', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '黒瀬町切田', 'クロセチョウキリタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市黒瀬桜が丘', '34', '34212', '7392618', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '黒瀬桜が丘', 'クロセサクラガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市黒瀬切田が丘', '34', '34212', '7392619', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '黒瀬切田が丘', 'クロセキリタガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市黒瀬町南方賀茂精神医療センター', '34', '34212', '7392621', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '黒瀬町南方', 'クロセチョウミナミガタ', null, null, '賀茂精神医療センター', 'カモセイシンイリョウセンター');
INSERT INTO `ms_addresses` VALUES ('92677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市黒瀬町乃美尾', '34', '34212', '7392622', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '黒瀬町乃美尾', 'クロセチョウノミノオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市黒瀬町川角', '34', '34212', '7392623', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '黒瀬町川角', 'クロセチョウカワスミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市黒瀬町菅田', '34', '34212', '7392624', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '黒瀬町菅田', 'クロセチョウスゲタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市黒瀬町上保田', '34', '34212', '7392625', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '黒瀬町上保田', 'クロセチョウカミボウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市黒瀬町市飯田', '34', '34212', '7392626', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '黒瀬町市飯田', 'クロセチョウイチイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市黒瀬学園台', '34', '34212', '7392631', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '黒瀬学園台', 'クロセガクエンダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市黒瀬町兼沢', '34', '34212', '7392731', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '黒瀬町兼沢', 'クロセチョウカネサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '広島県東広島市黒瀬町津江', '34', '34212', '7392732', '広島県', 'ヒロシマケン', '東広島市', 'ヒガシヒロシマシ', '黒瀬町津江', 'クロセチョウツエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道深川市', '01', '01228', '0740000', '北海道', 'ホッカイドウ', '深川市', 'フカガワシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('92713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市', '35', '35208', '7400000', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('92714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県玖珂郡和木町', '35', '35321', '7400000', '山口県', 'ヤマグチケン', '玖珂郡和木町', 'クガグンワキチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('92715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市装束町', '35', '35208', '7400001', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '装束町', 'ショウゾクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市新港町', '35', '35208', '7400002', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '新港町', 'シンミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市飯田町', '35', '35208', '7400003', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '飯田町', 'イイダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市昭和町', '35', '35208', '7400004', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '昭和町', 'ショウワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道深川市1条', '01', '01228', '0740001', '北海道', 'ホッカイドウ', '深川市', 'フカガワシ', '1条', '01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市立石町', '35', '35208', '7400011', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '立石町', 'タテイシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市元町', '35', '35208', '7400012', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '元町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市桂町', '35', '35208', '7400013', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '桂町', 'カツラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市日の出町', '35', '35208', '7400014', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '日の出町', 'ヒノデマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市川口町', '35', '35208', '7400015', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '川口町', 'カワグチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市三笠町', '35', '35208', '7400016', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '三笠町', 'ミカサマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市今津町', '35', '35208', '7400017', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '今津町', 'イマヅマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市麻里布町', '35', '35208', '7400018', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '麻里布町', 'マリフマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市砂山町', '35', '35208', '7400019', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '砂山町', 'スナヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道深川市2条', '01', '01228', '0740002', '北海道', 'ホッカイドウ', '深川市', 'フカガワシ', '2条', '02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市室の木町', '35', '35208', '7400021', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '室の木町', 'ムロノキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市山手町', '35', '35208', '7400022', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '山手町', 'ヤマテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市川下町', '35', '35208', '7400023', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '川下町', 'カワシモマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市旭町', '35', '35208', '7400024', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '旭町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市三角町', '35', '35208', '7400025', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '三角町', 'ミスミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市車町', '35', '35208', '7400026', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '車町', 'クルママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市中津町', '35', '35208', '7400027', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '中津町', 'ナカヅマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市楠町', '35', '35208', '7400028', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '楠町', 'クスノキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道深川市3条', '01', '01228', '0740003', '北海道', 'ホッカイドウ', '深川市', 'フカガワシ', '3条', '03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市門前町', '35', '35208', '7400031', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '門前町', 'モンゼンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市尾津町', '35', '35208', '7400032', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '尾津町', 'オヅマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市灘町', '35', '35208', '7400033', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '灘町', 'ナダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市南岩国町', '35', '35208', '7400034', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '南岩国町', 'ミナミイワクニマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市海土路町', '35', '35208', '7400035', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '海土路町', 'ミドロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市藤生町', '35', '35208', '7400036', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '藤生町', 'フジュウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道深川市4条', '01', '01228', '0740004', '北海道', 'ホッカイドウ', '深川市', 'フカガワシ', '4条', '04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市黒磯町', '35', '35208', '7400041', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '黒磯町', 'クロイソマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市青木町', '35', '35208', '7400042', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '青木町', 'オオギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市保津町', '35', '35208', '7400043', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '保津町', 'ホウヅマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市通津', '35', '35208', '7400044', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '通津', 'ツヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市長野', '35', '35208', '7400045', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '長野', 'ナガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道深川市5条', '01', '01228', '0740005', '北海道', 'ホッカイドウ', '深川市', 'フカガワシ', '5条', '05ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市柱島', '35', '35208', '7400051', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '柱島', 'ハシラジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道深川市6条', '01', '01228', '0740006', '北海道', 'ホッカイドウ', '深川市', 'フカガワシ', '6条', '06ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県玖珂郡和木町和木', '35', '35321', '7400061', '山口県', 'ヤマグチケン', '玖珂郡和木町', 'クガグンワキチョウ', '和木', 'ワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県玖珂郡和木町瀬田', '35', '35321', '7400062', '山口県', 'ヤマグチケン', '玖珂郡和木町', 'クガグンワキチョウ', '瀬田', 'セタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県玖珂郡和木町関ケ浜', '35', '35321', '7400063', '山口県', 'ヤマグチケン', '玖珂郡和木町', 'クガグンワキチョウ', '関ケ浜', 'セキガハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道深川市7条', '01', '01228', '0740007', '北海道', 'ホッカイドウ', '深川市', 'フカガワシ', '7条', '07ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道深川市8条', '01', '01228', '0740008', '北海道', 'ホッカイドウ', '深川市', 'フカガワシ', '8条', '08ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道深川市9条', '01', '01228', '0740009', '北海道', 'ホッカイドウ', '深川市', 'フカガワシ', '9条', '09ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道深川市緑町', '01', '01228', '0740011', '北海道', 'ホッカイドウ', '深川市', 'フカガワシ', '緑町', 'ミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道深川市西町', '01', '01228', '0740012', '北海道', 'ホッカイドウ', '深川市', 'フカガワシ', '西町', 'ニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道深川市文光町', '01', '01228', '0740013', '北海道', 'ホッカイドウ', '深川市', 'フカガワシ', '文光町', 'ブンコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道深川市開西町', '01', '01228', '0740014', '北海道', 'ホッカイドウ', '深川市', 'フカガワシ', '開西町', 'カイセイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道深川市メム芽生', '01', '01228', '0740015', '北海道', 'ホッカイドウ', '深川市', 'フカガワシ', 'メム', 'メム', null, null, '芽生', 'メム');
INSERT INTO `ms_addresses` VALUES ('92765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道深川市稲穂町', '01', '01228', '0740021', '北海道', 'ホッカイドウ', '深川市', 'フカガワシ', '稲穂町', 'イナホチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道深川市北光町', '01', '01228', '0740022', '北海道', 'ホッカイドウ', '深川市', 'フカガワシ', '北光町', 'ホツコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道深川市太子町', '01', '01228', '0740023', '北海道', 'ホッカイドウ', '深川市', 'フカガワシ', '太子町', 'タイシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道深川市新光町', '01', '01228', '0740024', '北海道', 'ホッカイドウ', '深川市', 'フカガワシ', '新光町', 'シンコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道深川市錦町', '01', '01228', '0740025', '北海道', 'ホッカイドウ', '深川市', 'フカガワシ', '錦町', 'ニシキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道深川市錦町西', '01', '01228', '0740026', '北海道', 'ホッカイドウ', '深川市', 'フカガワシ', '錦町西', 'ニシキマチニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道深川市錦町北', '01', '01228', '0740027', '北海道', 'ホッカイドウ', '深川市', 'フカガワシ', '錦町北', 'ニシキマチキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道深川市一已町', '01', '01228', '0740028', '北海道', 'ホッカイドウ', '深川市', 'フカガワシ', '一已町', 'イチヤンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市行波', '35', '35208', '7400301', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '行波', 'ユカバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市下', '35', '35208', '7400302', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '下', 'シモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市杭名', '35', '35208', '7400303', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '杭名', 'クイナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市相ノ谷', '35', '35208', '7400304', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '相ノ谷', 'アイノタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市二鹿', '35', '35208', '7400305', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '二鹿', 'フタシカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市天尾', '35', '35208', '7400306', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '天尾', 'テンノオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道深川市あけぼの町', '01', '01228', '0740031', '北海道', 'ホッカイドウ', '深川市', 'フカガワシ', 'あけぼの町', 'アケボノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市瓦谷', '35', '35208', '7400311', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '瓦谷', 'カワラダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市守内', '35', '35208', '7400312', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '守内', 'シュウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市保木', '35', '35208', '7400313', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '保木', 'ホウキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市寺山', '35', '35208', '7400314', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '寺山', 'テラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市近延', '35', '35208', '7400315', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '近延', 'チカノブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市行正', '35', '35208', '7400316', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '行正', 'ユキマサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市上田', '35', '35208', '7400317', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '上田', 'ウエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市入野', '35', '35208', '7400321', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '入野', 'イリノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市廿木', '35', '35208', '7400322', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '廿木', 'ハタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市大山', '35', '35208', '7400323', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '大山', 'オオヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市伊房', '35', '35208', '7400324', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '伊房', 'イフサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市竹安', '35', '35208', '7400325', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '竹安', 'タケヤス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市土生', '35', '35208', '7400326', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '土生', 'ハブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市角', '35', '35208', '7400327', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '角', 'スミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市美川町小川', '35', '35208', '7400501', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '美川町小川', 'ミカワマチコガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市美川町四馬神', '35', '35208', '7400502', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '美川町四馬神', 'ミカワマチシメガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市美川町添谷', '35', '35208', '7400503', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '美川町添谷', 'ミカワマチソエダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市美川町南桑', '35', '35208', '7400504', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '美川町南桑', 'ミカワマチナグワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市美川町根笠', '35', '35208', '7400505', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '美川町根笠', 'ミカワマチネカサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市本郷町本谷', '35', '35208', '7400601', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '本郷町本谷', 'ホンゴウマチホンダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市本郷町本郷', '35', '35208', '7400602', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '本郷町本郷', 'ホンゴウマチホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市本郷町波野', '35', '35208', '7400603', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '本郷町波野', 'ホンゴウマチハノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市本郷町宇塚', '35', '35208', '7400604', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '本郷町宇塚', 'ホンゴウマチウヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市本郷町西黒沢', '35', '35208', '7400605', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '本郷町西黒沢', 'ホンゴウマチニシクロザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市錦町大野', '35', '35208', '7400721', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '錦町大野', 'ニシキマチオオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市錦町中ノ瀬', '35', '35208', '7400722', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '錦町中ノ瀬', 'ニシキマチナカノセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市錦町府谷', '35', '35208', '7400723', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '錦町府谷', 'ニシキマチフノタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市錦町広瀬', '35', '35208', '7400724', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '錦町広瀬', 'ニシキマチヒロセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市錦町野谷', '35', '35208', '7400725', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '錦町野谷', 'ニシキマチノタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市錦町須川', '35', '35208', '7400811', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '錦町須川', 'ニシキマチスガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市錦町深川', '35', '35208', '7400812', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '錦町深川', 'ニシキマチフカガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市錦町宇佐', '35', '35208', '7400901', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '錦町宇佐', 'ニシキマチウサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市錦町宇佐郷', '35', '35208', '7400902', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '錦町宇佐郷', 'ニシキマチウサゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市錦町大原', '35', '35208', '7400903', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '錦町大原', 'ニシキマチオオハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市錦町宇佐郷向峠', '35', '35208', '7400904', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '錦町宇佐郷', 'ニシキマチウサゴウ', null, null, '向峠', 'ムカタオ');
INSERT INTO `ms_addresses` VALUES ('92815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市美和町秋掛', '35', '35208', '7401201', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '美和町秋掛', 'ミワマチアキガケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市美和町北中山', '35', '35208', '7401202', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '美和町北中山', 'ミワマチキタナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市美和町釜ケ原', '35', '35208', '7401211', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '美和町釜ケ原', 'ミワマチカマガハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市美和町黒沢', '35', '35208', '7401212', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '美和町黒沢', 'ミワマチクロサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市美和町岸根', '35', '35208', '7401213', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '美和町岸根', 'ミワマチガンネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市美和町百合谷', '35', '35208', '7401214', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '美和町百合谷', 'ミワマチユリタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市美和町長谷', '35', '35208', '7401215', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '美和町長谷', 'ミワマチナガタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市美和町日宛', '35', '35208', '7401216', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '美和町日宛', 'ミワマチヒナタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市美和町大根川', '35', '35208', '7401217', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '美和町大根川', 'ミワマチオオネガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市美和町中垣内', '35', '35208', '7401218', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '美和町中垣内', 'ミワマチナカガウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市美和町瀬戸ノ内', '35', '35208', '7401219', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '美和町瀬戸ノ内', 'ミワマチセトノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市美和町上駄床', '35', '35208', '7401221', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '美和町上駄床', 'ミワマチカミダトコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市美和町田ノ口', '35', '35208', '7401222', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '美和町田ノ口', 'ミワマチタノクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市美和町滑', '35', '35208', '7401223', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '美和町滑', 'ミワマチナメラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市美和町佐坂', '35', '35208', '7401224', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '美和町佐坂', 'ミワマチサザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市美和町渋前', '35', '35208', '7401225', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '美和町渋前', 'ミワマチシブクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市美和町生見', '35', '35208', '7401231', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '美和町生見', 'ミワマチイキミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市美和町西畑', '35', '35208', '7401232', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '美和町西畑', 'ミワマチニシバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市美和町阿賀', '35', '35208', '7401241', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '美和町阿賀', 'ミワマチアカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市美和町下畑', '35', '35208', '7401242', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '美和町下畑', 'ミワマチシモバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市由宇町寺迫', '35', '35208', '7401401', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '由宇町', 'ユウマチ', null, null, '寺迫', 'テラザコ');
INSERT INTO `ms_addresses` VALUES ('92836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市由宇町小槇', '35', '35208', '7401402', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '由宇町', 'ユウマチ', null, null, '小槇', 'ショウシン');
INSERT INTO `ms_addresses` VALUES ('92837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市由宇町中倉', '35', '35208', '7401403', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '由宇町', 'ユウマチ', null, null, '中倉', 'ナカクラ');
INSERT INTO `ms_addresses` VALUES ('92838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市由宇町西区', '35', '35208', '7401404', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '由宇町', 'ユウマチ', null, null, '西区', 'ニシク');
INSERT INTO `ms_addresses` VALUES ('92839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市由宇町笠塚', '35', '35208', '7401405', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '由宇町', 'ユウマチ', null, null, '笠塚', 'カサヅカ');
INSERT INTO `ms_addresses` VALUES ('92840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市由宇町峇清', '35', '35208', '7401406', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '由宇町', 'ユウマチ', null, null, '峇清', 'ゴウセイ');
INSERT INTO `ms_addresses` VALUES ('92841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市由宇町横道', '35', '35208', '7401407', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '由宇町', 'ユウマチ', null, null, '横道', 'ヨコミチ');
INSERT INTO `ms_addresses` VALUES ('92842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道深川市多度志', '01', '01228', '0740141', '北海道', 'ホッカイドウ', '深川市', 'フカガワシ', '多度志', 'タドシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市由宇町清水', '35', '35208', '7401411', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '由宇町', 'ユウマチ', null, null, '清水', 'シミズ');
INSERT INTO `ms_addresses` VALUES ('92844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市由宇町中村', '35', '35208', '7401412', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '由宇町', 'ユウマチ', null, null, '中村', 'ナカムラ');
INSERT INTO `ms_addresses` VALUES ('92845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市由宇町上北', '35', '35208', '7401413', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '由宇町', 'ユウマチ', null, null, '上北', 'カミキタ');
INSERT INTO `ms_addresses` VALUES ('92846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市由宇町北区', '35', '35208', '7401414', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '由宇町', 'ユウマチ', null, null, '北区', 'キタク');
INSERT INTO `ms_addresses` VALUES ('92847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市由宇町堀田', '35', '35208', '7401415', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '由宇町', 'ユウマチ', null, null, '堀田', 'ホリタ');
INSERT INTO `ms_addresses` VALUES ('92848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道深川市宇摩', '01', '01228', '0740142', '北海道', 'ホッカイドウ', '深川市', 'フカガワシ', '宇摩', 'ウマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市由宇町港', '35', '35208', '7401424', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '由宇町港', 'ユウマチミナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市由宇町南沖', '35', '35208', '7401425', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '由宇町南沖', 'ユウマチミナミオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市由宇町由宇崎', '35', '35208', '7401426', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '由宇町由宇崎', 'ユウマチユウサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市由宇町中央', '35', '35208', '7401428', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '由宇町中央', 'ユウマチチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道深川市ウッカ', '01', '01228', '0740143', '北海道', 'ホッカイドウ', '深川市', 'フカガワシ', 'ウッカ', 'ウッカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市由宇町有家', '35', '35208', '7401431', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '由宇町', 'ユウマチ', null, null, '有家', 'アラケ');
INSERT INTO `ms_addresses` VALUES ('92855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市由宇町神東', '35', '35208', '7401432', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '由宇町神東', 'ユウマチシントウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道深川市鷹泊', '01', '01228', '0740144', '北海道', 'ホッカイドウ', '深川市', 'フカガワシ', '鷹泊', 'タカドマリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市由宇町千鳥ケ丘', '35', '35208', '7401441', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '由宇町千鳥ケ丘', 'ユウマチチドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道深川市幌内', '01', '01228', '0740145', '北海道', 'ホッカイドウ', '深川市', 'フカガワシ', '幌内', 'ホロナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市由宇町南', '35', '35208', '7401451', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '由宇町南', 'ユウマチミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市由宇町正南', '35', '35208', '7401452', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '由宇町', 'ユウマチ', null, null, '正南', 'セイナン');
INSERT INTO `ms_addresses` VALUES ('92861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市由宇町西', '35', '35208', '7401454', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '由宇町西', 'ユウマチニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道深川市湯内', '01', '01228', '0740146', '北海道', 'ホッカイドウ', '深川市', 'フカガワシ', '湯内', 'ユナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道深川市多度志南', '01', '01228', '0740147', '北海道', 'ホッカイドウ', '深川市', 'フカガワシ', '多度志南', 'タドシミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市由宇町', '35', '35208', '7401488', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '由宇町', 'ユウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道雨竜郡幌加内町', '01', '01439', '0740400', '北海道', 'ホッカイドウ', '雨竜郡幌加内町', 'ウリュウグンホロカナイチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('92866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道雨竜郡幌加内町平和', '01', '01439', '0740401', '北海道', 'ホッカイドウ', '雨竜郡幌加内町', 'ウリュウグンホロカナイチョウ', '平和', 'ヘイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道雨竜郡幌加内町新成生', '01', '01439', '0740402', '北海道', 'ホッカイドウ', '雨竜郡幌加内町', 'ウリュウグンホロカナイチョウ', '新成生', 'シンナリウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道雨竜郡幌加内町下幌加内', '01', '01439', '0740403', '北海道', 'ホッカイドウ', '雨竜郡幌加内町', 'ウリュウグンホロカナイチョウ', '下幌加内', 'シモホロカナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道雨竜郡幌加内町沼牛', '01', '01439', '0740404', '北海道', 'ホッカイドウ', '雨竜郡幌加内町', 'ウリュウグンホロカナイチョウ', '沼牛', 'ヌマウシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道雨竜郡幌加内町弥運内', '01', '01439', '0740405', '北海道', 'ホッカイドウ', '雨竜郡幌加内町', 'ウリュウグンホロカナイチョウ', '弥運内', 'ヤウンナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道雨竜郡幌加内町幌加内', '01', '01439', '0740411', '北海道', 'ホッカイドウ', '雨竜郡幌加内町', 'ウリュウグンホロカナイチョウ', '幌加内', 'ホロカナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道雨竜郡幌加内町親和', '01', '01439', '0740412', '北海道', 'ホッカイドウ', '雨竜郡幌加内町', 'ウリュウグンホロカナイチョウ', '親和', 'シンワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道雨竜郡幌加内町雨煙内', '01', '01439', '0740413', '北海道', 'ホッカイドウ', '雨竜郡幌加内町', 'ウリュウグンホロカナイチョウ', '雨煙内', 'ウエンナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道雨竜郡幌加内町清月', '01', '01439', '0740414', '北海道', 'ホッカイドウ', '雨竜郡幌加内町', 'ウリュウグンホロカナイチョウ', '清月', 'セイゲツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道雨竜郡幌加内町長留内', '01', '01439', '0740415', '北海道', 'ホッカイドウ', '雨竜郡幌加内町', 'ウリュウグンホロカナイチョウ', '長留内', 'オサルナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道雨竜郡幌加内町東栄', '01', '01439', '0740421', '北海道', 'ホッカイドウ', '雨竜郡幌加内町', 'ウリュウグンホロカナイチョウ', '東栄', 'トウエイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道雨竜郡幌加内町振興', '01', '01439', '0740422', '北海道', 'ホッカイドウ', '雨竜郡幌加内町', 'ウリュウグンホロカナイチョウ', '振興', 'シンコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道雨竜郡幌加内町上幌加内', '01', '01439', '0740423', '北海道', 'ホッカイドウ', '雨竜郡幌加内町', 'ウリュウグンホロカナイチョウ', '上幌加内', 'カミホロカナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道雨竜郡幌加内町雨煙別', '01', '01439', '0740424', '北海道', 'ホッカイドウ', '雨竜郡幌加内町', 'ウリュウグンホロカナイチョウ', '雨煙別', 'ウエンベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道雨竜郡幌加内町1', '01', '01439', '0740425', '北海道', 'ホッカイドウ', '雨竜郡幌加内町', 'ウリュウグンホロカナイチョウ', '1', 'セイワダイ01', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道雨竜郡幌加内町2', '01', '01439', '0740426', '北海道', 'ホッカイドウ', '雨竜郡幌加内町', 'ウリュウグンホロカナイチョウ', '2', 'セイワダイ02', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道雨竜郡幌加内町3', '01', '01439', '0740427', '北海道', 'ホッカイドウ', '雨竜郡幌加内町', 'ウリュウグンホロカナイチョウ', '3', 'セイワダイ03', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道雨竜郡幌加内町母子里', '01', '01439', '0740741', '北海道', 'ホッカイドウ', '雨竜郡幌加内町', 'ウリュウグンホロカナイチョウ', '母子里', 'モシリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道雨竜郡幌加内町朱鞠内', '01', '01439', '0740742', '北海道', 'ホッカイドウ', '雨竜郡幌加内町', 'ウリュウグンホロカナイチョウ', '朱鞠内', 'シュマリナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道雨竜郡幌加内町共栄', '01', '01439', '0740743', '北海道', 'ホッカイドウ', '雨竜郡幌加内町', 'ウリュウグンホロカナイチョウ', '共栄', 'キョウエイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道雨竜郡幌加内町大曲', '01', '01439', '0740744', '北海道', 'ホッカイドウ', '雨竜郡幌加内町', 'ウリュウグンホロカナイチョウ', '大曲', 'オオマガリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道雨竜郡幌加内町北星', '01', '01439', '0740745', '北海道', 'ホッカイドウ', '雨竜郡幌加内町', 'ウリュウグンホロカナイチョウ', '北星', 'ホクセイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道雨竜郡幌加内町添牛内', '01', '01439', '0740746', '北海道', 'ホッカイドウ', '雨竜郡幌加内町', 'ウリュウグンホロカナイチョウ', '添牛内', 'ソエウシナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道雨竜郡幌加内町新富', '01', '01439', '0740747', '北海道', 'ホッカイドウ', '雨竜郡幌加内町', 'ウリュウグンホロカナイチョウ', '新富', 'シントミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市錦見', '35', '35208', '7410061', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '錦見', 'ニシミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市岩国', '35', '35208', '7410062', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '岩国', 'イワクニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市関戸', '35', '35208', '7410063', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '関戸', 'セキド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市牛野谷町', '35', '35208', '7410071', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '牛野谷町', 'ウシノヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市平田', '35', '35208', '7410072', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '平田', 'ヒラタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市柱野', '35', '35208', '7410073', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '柱野', 'ハシラノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市六呂師', '35', '35208', '7410074', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '六呂師', 'ロクロシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市叶木', '35', '35208', '7410075', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '叶木', 'カノウギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市横山', '35', '35208', '7410081', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '横山', 'ヨコヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市川西', '35', '35208', '7410082', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '川西', 'カワニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市御庄', '35', '35208', '7410083', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '御庄', 'ミショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市大谷', '35', '35208', '7410084', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '大谷', 'オオタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市持国', '35', '35208', '7410085', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '持国', 'モチクニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市小瀬', '35', '35208', '7410091', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '小瀬', 'オゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市多田', '35', '35208', '7410092', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '多田', 'タダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市田原', '35', '35208', '7410093', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '田原', 'タワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市阿品', '35', '35208', '7410094', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '阿品', 'アジナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道深川市音江町更進', '01', '01228', '0741161', '北海道', 'ホッカイドウ', '深川市', 'フカガワシ', '音江町', 'オトエチョウ', null, null, '更進', 'コウシン');
INSERT INTO `ms_addresses` VALUES ('92926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道深川市音江町菊丘', '01', '01228', '0741162', '北海道', 'ホッカイドウ', '深川市', 'フカガワシ', '音江町', 'オトエチョウ', null, null, '菊丘', 'キクオカ');
INSERT INTO `ms_addresses` VALUES ('92927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道深川市音江町吉住', '01', '01228', '0741163', '北海道', 'ホッカイドウ', '深川市', 'フカガワシ', '音江町', 'オトエチョウ', null, null, '吉住', 'ヨシズミ');
INSERT INTO `ms_addresses` VALUES ('92928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道深川市音江町国見', '01', '01228', '0741164', '北海道', 'ホッカイドウ', '深川市', 'フカガワシ', '音江町', 'オトエチョウ', null, null, '国見', 'クニミ');
INSERT INTO `ms_addresses` VALUES ('92929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市神居町西丘', '01', '01204', '0741181', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '神居町西丘', 'カムイチョウニシオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市神居町豊里', '01', '01204', '0741182', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '神居町豊里', 'カムイチョウトヨサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道深川市音江町広里', '01', '01228', '0741271', '北海道', 'ホッカイドウ', '深川市', 'フカガワシ', '音江町', 'オトエチョウ', null, null, '広里', 'ヒロサト');
INSERT INTO `ms_addresses` VALUES ('92932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道深川市広里町1丁目', '01', '01228', '0741271', '北海道', 'ホッカイドウ', '深川市', 'フカガワシ', '広里町', 'ヒロサトチョウ', null, null, '1丁目', '01チョウメ');
INSERT INTO `ms_addresses` VALUES ('92933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道深川市広里町2丁目', '01', '01228', '0741271', '北海道', 'ホッカイドウ', '深川市', 'フカガワシ', '広里町', 'ヒロサトチョウ', null, null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('92934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道深川市広里町3丁目', '01', '01228', '0741271', '北海道', 'ホッカイドウ', '深川市', 'フカガワシ', '広里町', 'ヒロサトチョウ', null, null, '3丁目', '03チョウメ');
INSERT INTO `ms_addresses` VALUES ('92935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道深川市広里町4丁目', '01', '01228', '0741271', '北海道', 'ホッカイドウ', '深川市', 'フカガワシ', '広里町', 'ヒロサトチョウ', null, null, '4丁目', '04チョウメ');
INSERT INTO `ms_addresses` VALUES ('92936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道深川市広里町5丁目', '01', '01228', '0741271', '北海道', 'ホッカイドウ', '深川市', 'フカガワシ', '広里町', 'ヒロサトチョウ', null, null, '5丁目', '05チョウメ');
INSERT INTO `ms_addresses` VALUES ('92937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道深川市音江町国見', '01', '01228', '0741272', '北海道', 'ホッカイドウ', '深川市', 'フカガワシ', '音江町', 'オトエチョウ', null, null, '国見', 'クニミ');
INSERT INTO `ms_addresses` VALUES ('92938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道深川市音江町1丁目', '01', '01228', '0741273', '北海道', 'ホッカイドウ', '深川市', 'フカガワシ', '音江町', 'オトエチョウ', null, null, '1丁目', '01チョウメ');
INSERT INTO `ms_addresses` VALUES ('92939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道深川市音江町2丁目', '01', '01228', '0741273', '北海道', 'ホッカイドウ', '深川市', 'フカガワシ', '音江町', 'オトエチョウ', null, null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('92940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道深川市音江町音江', '01', '01228', '0741273', '北海道', 'ホッカイドウ', '深川市', 'フカガワシ', '音江町', 'オトエチョウ', null, null, '音江', 'オトエ');
INSERT INTO `ms_addresses` VALUES ('92941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道深川市音江町豊泉', '01', '01228', '0741274', '北海道', 'ホッカイドウ', '深川市', 'フカガワシ', '音江町', 'オトエチョウ', null, null, '豊泉', 'トヨイズミ');
INSERT INTO `ms_addresses` VALUES ('92942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道深川市音江町向陽', '01', '01228', '0741275', '北海道', 'ホッカイドウ', '深川市', 'フカガワシ', '音江町', 'オトエチョウ', null, null, '向陽', 'コウヨウ');
INSERT INTO `ms_addresses` VALUES ('92943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道深川市音江町稲田', '01', '01228', '0741276', '北海道', 'ホッカイドウ', '深川市', 'フカガワシ', '音江町', 'オトエチョウ', null, null, '稲田', 'イナダ');
INSERT INTO `ms_addresses` VALUES ('92945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県柳井市', '35', '35212', '7420000', '山口県', 'ヤマグチケン', '柳井市', 'ヤナイシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('92946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県柳井市姫田', '35', '35212', '7420001', '山口県', 'ヤマグチケン', '柳井市', 'ヤナイシ', '姫田', 'ヒメダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県柳井市山根', '35', '35212', '7420002', '山口県', 'ヤマグチケン', '柳井市', 'ヤナイシ', '山根', 'ヤマネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県柳井市片野西', '35', '35212', '7420003', '山口県', 'ヤマグチケン', '柳井市', 'ヤナイシ', '片野西', 'カタノニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県柳井市土手町', '35', '35212', '7420004', '山口県', 'ヤマグチケン', '柳井市', 'ヤナイシ', '土手町', 'ドテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県柳井市天神', '35', '35212', '7420005', '山口県', 'ヤマグチケン', '柳井市', 'ヤナイシ', '天神', 'テンジン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県柳井市新天地', '35', '35212', '7420006', '山口県', 'ヤマグチケン', '柳井市', 'ヤナイシ', '新天地', 'シンテンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県柳井市東土手', '35', '35212', '7420007', '山口県', 'ヤマグチケン', '柳井市', 'ヤナイシ', '東土手', 'ヒガシドテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県柳井市新市北', '35', '35212', '7420008', '山口県', 'ヤマグチケン', '柳井市', 'ヤナイシ', '新市北', 'シンイチキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県柳井市新市', '35', '35212', '7420009', '山口県', 'ヤマグチケン', '柳井市', 'ヤナイシ', '新市', 'シンイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県柳井市新市南', '35', '35212', '7420010', '山口県', 'ヤマグチケン', '柳井市', 'ヤナイシ', '新市南', 'シンイチミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県柳井市新市沖', '35', '35212', '7420011', '山口県', 'ヤマグチケン', '柳井市', 'ヤナイシ', '新市沖', 'シンイチオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県柳井市北浜', '35', '35212', '7420012', '山口県', 'ヤマグチケン', '柳井市', 'ヤナイシ', '北浜', 'キタハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県柳井市柳井', '35', '35212', '7420021', '山口県', 'ヤマグチケン', '柳井市', 'ヤナイシ', '柳井', 'ヤナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県柳井市柳井津', '35', '35212', '7420022', '山口県', 'ヤマグチケン', '柳井市', 'ヤナイシ', '柳井津', 'ヤナイツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県柳井市南浜', '35', '35212', '7420023', '山口県', 'ヤマグチケン', '柳井市', 'ヤナイシ', '南浜', 'ミナミハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県柳井市ニュータウン南町', '35', '35212', '7420024', '山口県', 'ヤマグチケン', '柳井市', 'ヤナイシ', 'ニュータウン南町', 'ニュータウンミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県柳井市南町', '35', '35212', '7420031', '山口県', 'ヤマグチケン', '柳井市', 'ヤナイシ', '南町', 'ミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県柳井市古開作', '35', '35212', '7420032', '山口県', 'ヤマグチケン', '柳井市', 'ヤナイシ', '古開作', 'コガイサク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県柳井市新庄', '35', '35212', '7420033', '山口県', 'ヤマグチケン', '柳井市', 'ヤナイシ', '新庄', 'シンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県柳井市余田', '35', '35212', '7420034', '山口県', 'ヤマグチケン', '柳井市', 'ヤナイシ', '余田', 'ヨタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県柳井市中央', '35', '35212', '7420035', '山口県', 'ヤマグチケン', '柳井市', 'ヤナイシ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県柳井市駅南', '35', '35212', '7420036', '山口県', 'ヤマグチケン', '柳井市', 'ヤナイシ', '駅南', 'エキナン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県柳井市平郡', '35', '35212', '7420041', '山口県', 'ヤマグチケン', '柳井市', 'ヤナイシ', '平郡', 'ヘイグン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県柳井市日積', '35', '35212', '7420111', '山口県', 'ヤマグチケン', '柳井市', 'ヤナイシ', '日積', 'ヒヅミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県柳井市伊陸', '35', '35212', '7420201', '山口県', 'ヤマグチケン', '柳井市', 'ヤナイシ', '伊陸', 'イカチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市周東町祖生', '35', '35208', '7420301', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '周東町祖生', 'シュウトウマチソオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市玖珂町欽明路', '35', '35208', '7420311', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '玖珂町', 'クガマチ', null, null, '欽明路', 'キンメイジ');
INSERT INTO `ms_addresses` VALUES ('92973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市玖珂町上谷', '35', '35208', '7420312', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '玖珂町', 'クガマチ', null, null, '上谷', 'カミダニ');
INSERT INTO `ms_addresses` VALUES ('92974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市玖珂町下谷', '35', '35208', '7420313', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '玖珂町', 'クガマチ', null, null, '下谷', 'シモダニ');
INSERT INTO `ms_addresses` VALUES ('92975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市玖珂町野口', '35', '35208', '7420314', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '玖珂町', 'クガマチ', null, null, '野口', 'ノグチ');
INSERT INTO `ms_addresses` VALUES ('92976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市玖珂町瀬田', '35', '35208', '7420315', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '玖珂町', 'クガマチ', null, null, '瀬田', 'セダ');
INSERT INTO `ms_addresses` VALUES ('92977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市玖珂町市頭', '35', '35208', '7420321', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '玖珂町', 'クガマチ', null, null, '市頭', 'イチガシラ');
INSERT INTO `ms_addresses` VALUES ('92978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市玖珂町上市', '35', '35208', '7420322', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '玖珂町', 'クガマチ', null, null, '上市', 'ウワイチ');
INSERT INTO `ms_addresses` VALUES ('92979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市玖珂町谷津', '35', '35208', '7420323', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '玖珂町', 'クガマチ', null, null, '谷津', 'ヤツ');
INSERT INTO `ms_addresses` VALUES ('92980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市玖珂町駅通', '35', '35208', '7420324', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '玖珂町', 'クガマチ', null, null, '駅通', 'エキドオリ');
INSERT INTO `ms_addresses` VALUES ('92981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市玖珂町本町', '35', '35208', '7420325', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '玖珂町', 'クガマチ', null, null, '本町', 'ホンマチ');
INSERT INTO `ms_addresses` VALUES ('92982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市玖珂町同道', '35', '35208', '7420326', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '玖珂町', 'クガマチ', null, null, '同道', 'ドウドウ');
INSERT INTO `ms_addresses` VALUES ('92983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市玖珂町鞍掛', '35', '35208', '7420331', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '玖珂町', 'クガマチ', null, null, '鞍掛', 'クラカケ');
INSERT INTO `ms_addresses` VALUES ('92984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市玖珂町阿山', '35', '35208', '7420332', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '玖珂町', 'クガマチ', null, null, '阿山', 'アヤマ');
INSERT INTO `ms_addresses` VALUES ('92985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市玖珂町千束', '35', '35208', '7420333', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '玖珂町', 'クガマチ', null, null, '千束', 'センゾク');
INSERT INTO `ms_addresses` VALUES ('92986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市玖珂町臼田', '35', '35208', '7420334', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '玖珂町', 'クガマチ', null, null, '臼田', 'ウスダ');
INSERT INTO `ms_addresses` VALUES ('92987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市玖珂町新町', '35', '35208', '7420335', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '玖珂町', 'クガマチ', null, null, '新町', 'シンマチ');
INSERT INTO `ms_addresses` VALUES ('92988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市玖珂町新市', '35', '35208', '7420336', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '玖珂町', 'クガマチ', null, null, '新市', 'シンイチ');
INSERT INTO `ms_addresses` VALUES ('92989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市玖珂町久門給', '35', '35208', '7420337', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '玖珂町', 'クガマチ', null, null, '久門給', 'クモンキュウ');
INSERT INTO `ms_addresses` VALUES ('92990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市玖珂町有延', '35', '35208', '7420338', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '玖珂町', 'クガマチ', null, null, '有延', 'アリノブ');
INSERT INTO `ms_addresses` VALUES ('92991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市玖珂町柳井田', '35', '35208', '7420341', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '玖珂町', 'クガマチ', null, null, '柳井田', 'ヤナイダ');
INSERT INTO `ms_addresses` VALUES ('92992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市玖珂町大田', '35', '35208', '7420342', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '玖珂町', 'クガマチ', null, null, '大田', 'オオタ');
INSERT INTO `ms_addresses` VALUES ('92993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市玖珂町野地', '35', '35208', '7420343', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '玖珂町', 'クガマチ', null, null, '野地', 'ノジ');
INSERT INTO `ms_addresses` VALUES ('92994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市玖珂町番地のみ', '35', '35208', '7420344', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '玖珂町', 'クガマチ', null, null, '番地のみ', 'バンチノミ');
INSERT INTO `ms_addresses` VALUES ('92996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市周東町明見谷', '35', '35208', '7420411', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '周東町明見谷', 'シュウトウマチアケミダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市周東町川上', '35', '35208', '7420412', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '周東町川上', 'シュウトウマチカワカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市周東町上久原', '35', '35208', '7420413', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '周東町上久原', 'シュウトウマチカミクバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('92999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市周東町田尻', '35', '35208', '7420414', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '周東町田尻', 'シュウトウマチタジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市周東町中山', '35', '35208', '7420415', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '周東町中山', 'シュウトウマチナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市周東町用田', '35', '35208', '7420416', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '周東町用田', 'シュウトウマチヨウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市周東町下久原', '35', '35208', '7420417', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '周東町下久原', 'シュウトウマチシモクバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市周東町三瀬川', '35', '35208', '7420421', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '周東町三瀬川', 'シュウトウマチサンゼガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市周東町獺越', '35', '35208', '7420422', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '周東町獺越', 'シュウトウマチオソゴエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市周東町下須通', '35', '35208', '7420423', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '周東町下須通', 'シュウトウマチシモスドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市周東町差川', '35', '35208', '7420424', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '周東町差川', 'シュウトウマチサスガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市周東町西長野', '35', '35208', '7420425', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '周東町西長野', 'シュウトウマチニシナガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市周東町上須通', '35', '35208', '7420426', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '周東町上須通', 'シュウトウマチカミスドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県岩国市周東町樋余地', '35', '35208', '7420427', '山口県', 'ヤマグチケン', '岩国市', 'イワクニシ', '周東町樋余地', 'シュウトウマチヒヨジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県熊毛郡平生町', '35', '35344', '7421100', '山口県', 'ヤマグチケン', '熊毛郡平生町', 'クマゲグンヒラオチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('93012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県熊毛郡平生町平生町', '35', '35344', '7421101', '山口県', 'ヤマグチケン', '熊毛郡平生町', 'クマゲグンヒラオチョウ', '平生町', 'ヒラオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県熊毛郡平生町平生村', '35', '35344', '7421102', '山口県', 'ヤマグチケン', '熊毛郡平生町', 'クマゲグンヒラオチョウ', '平生村', 'ヒラオムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県熊毛郡平生町竪ケ浜', '35', '35344', '7421103', '山口県', 'ヤマグチケン', '熊毛郡平生町', 'クマゲグンヒラオチョウ', '竪ケ浜', 'タテガハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県熊毛郡平生町宇佐木', '35', '35344', '7421104', '山口県', 'ヤマグチケン', '熊毛郡平生町', 'クマゲグンヒラオチョウ', '宇佐木', 'ウサナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県熊毛郡平生町大野北', '35', '35344', '7421105', '山口県', 'ヤマグチケン', '熊毛郡平生町', 'クマゲグンヒラオチョウ', '大野北', 'オオノキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県熊毛郡平生町大野南', '35', '35344', '7421106', '山口県', 'ヤマグチケン', '熊毛郡平生町', 'クマゲグンヒラオチョウ', '大野南', 'オオノミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県熊毛郡平生町曽根', '35', '35344', '7421107', '山口県', 'ヤマグチケン', '熊毛郡平生町', 'クマゲグンヒラオチョウ', '曽根', 'ソネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県熊毛郡平生町佐賀', '35', '35344', '7421111', '山口県', 'ヤマグチケン', '熊毛郡平生町', 'クマゲグンヒラオチョウ', '佐賀', 'サガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県熊毛郡平生町小郡', '35', '35344', '7421112', '山口県', 'ヤマグチケン', '熊毛郡平生町', 'クマゲグンヒラオチョウ', '小郡', 'オグニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県熊毛郡平生町尾国', '35', '35344', '7421113', '山口県', 'ヤマグチケン', '熊毛郡平生町', 'クマゲグンヒラオチョウ', '尾国', 'オクニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県熊毛郡平生町佐合島', '35', '35344', '7421114', '山口県', 'ヤマグチケン', '熊毛郡平生町', 'クマゲグンヒラオチョウ', '佐合島', 'サゴウジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県柳井市旭ケ丘', '35', '35212', '7421351', '山口県', 'ヤマグチケン', '柳井市', 'ヤナイシ', '旭ケ丘', 'アサヒガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県柳井市伊保庄', '35', '35212', '7421352', '山口県', 'ヤマグチケン', '柳井市', 'ヤナイシ', '伊保庄', 'イホノショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県柳井市阿月', '35', '35212', '7421353', '山口県', 'ヤマグチケン', '柳井市', 'ヤナイシ', '阿月', 'アツキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県熊毛郡上関町', '35', '35341', '7421400', '山口県', 'ヤマグチケン', '熊毛郡上関町', 'クマゲグンカミノセキチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('93033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県熊毛郡上関町祝島', '35', '35341', '7421401', '山口県', 'ヤマグチケン', '熊毛郡上関町', 'クマゲグンカミノセキチョウ', '祝島', 'イワイシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県熊毛郡上関町長島', '35', '35341', '7421402', '山口県', 'ヤマグチケン', '熊毛郡上関町', 'クマゲグンカミノセキチョウ', '長島', 'ナガシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県熊毛郡上関町室津', '35', '35341', '7421403', '山口県', 'ヤマグチケン', '熊毛郡上関町', 'クマゲグンカミノセキチョウ', '室津', 'ムロツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県熊毛郡上関町八島', '35', '35341', '7421404', '山口県', 'ヤマグチケン', '熊毛郡上関町', 'クマゲグンカミノセキチョウ', '八島', 'ヤシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県熊毛郡田布施町', '35', '35343', '7421500', '山口県', 'ヤマグチケン', '熊毛郡田布施町', 'クマゲグンタブセチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('93038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県熊毛郡田布施町大波野', '35', '35343', '7421501', '山口県', 'ヤマグチケン', '熊毛郡田布施町', 'クマゲグンタブセチョウ', '大波野', 'オオハノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県熊毛郡田布施町波野', '35', '35343', '7421502', '山口県', 'ヤマグチケン', '熊毛郡田布施町', 'クマゲグンタブセチョウ', '波野', 'ハノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県熊毛郡田布施町宿井', '35', '35343', '7421503', '山口県', 'ヤマグチケン', '熊毛郡田布施町', 'クマゲグンタブセチョウ', '宿井', 'シュクイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県熊毛郡田布施町川西', '35', '35343', '7421504', '山口県', 'ヤマグチケン', '熊毛郡田布施町', 'クマゲグンタブセチョウ', '川西', 'カワニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県熊毛郡田布施町下田布施', '35', '35343', '7421511', '山口県', 'ヤマグチケン', '熊毛郡田布施町', 'クマゲグンタブセチョウ', '下田布施', 'シモタブセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県熊毛郡田布施町麻郷奥', '35', '35343', '7421512', '山口県', 'ヤマグチケン', '熊毛郡田布施町', 'クマゲグンタブセチョウ', '麻郷奥', 'オゴウオク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県熊毛郡田布施町麻郷', '35', '35343', '7421513', '山口県', 'ヤマグチケン', '熊毛郡田布施町', 'クマゲグンタブセチョウ', '麻郷', 'オゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県熊毛郡田布施町麻郷団地', '35', '35343', '7421513', '山口県', 'ヤマグチケン', '熊毛郡田布施町', 'クマゲグンタブセチョウ', '麻郷団地', 'オゴウダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県熊毛郡田布施町別府', '35', '35343', '7421514', '山口県', 'ヤマグチケン', '熊毛郡田布施町', 'クマゲグンタブセチョウ', '別府', 'ベフ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県熊毛郡田布施町上田布施', '35', '35343', '7421515', '山口県', 'ヤマグチケン', '熊毛郡田布施町', 'クマゲグンタブセチョウ', '上田布施', 'カミタブセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県熊毛郡田布施町馬島', '35', '35343', '7421516', '山口県', 'ヤマグチケン', '熊毛郡田布施町', 'クマゲグンタブセチョウ', '馬島', 'ウマシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県熊毛郡田布施町中央南', '35', '35343', '7421517', '山口県', 'ヤマグチケン', '熊毛郡田布施町', 'クマゲグンタブセチョウ', '中央南', 'チュウオウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県大島郡周防大島町', '35', '35305', '7422100', '山口県', 'ヤマグチケン', '大島郡周防大島町', 'オオシマグンスオウオオシマチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('93053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県大島郡周防大島町西三蒲', '35', '35305', '7422101', '山口県', 'ヤマグチケン', '大島郡周防大島町', 'オオシマグンスオウオオシマチョウ', '西三蒲', 'ニシミガマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県大島郡周防大島町東三蒲', '35', '35305', '7422102', '山口県', 'ヤマグチケン', '大島郡周防大島町', 'オオシマグンスオウオオシマチョウ', '東三蒲', 'ヒガシミガマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県大島郡周防大島町西屋代', '35', '35305', '7422103', '山口県', 'ヤマグチケン', '大島郡周防大島町', 'オオシマグンスオウオオシマチョウ', '西屋代', 'ニシヤシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県大島郡周防大島町志佐', '35', '35305', '7422104', '山口県', 'ヤマグチケン', '大島郡周防大島町', 'オオシマグンスオウオオシマチョウ', '志佐', 'シサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県大島郡周防大島町小松開作', '35', '35305', '7422105', '山口県', 'ヤマグチケン', '大島郡周防大島町', 'オオシマグンスオウオオシマチョウ', '小松開作', 'コマツカイサク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県大島郡周防大島町小松', '35', '35305', '7422106', '山口県', 'ヤマグチケン', '大島郡周防大島町', 'オオシマグンスオウオオシマチョウ', '小松', 'コマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県大島郡周防大島町東屋代', '35', '35305', '7422107', '山口県', 'ヤマグチケン', '大島郡周防大島町', 'オオシマグンスオウオオシマチョウ', '東屋代', 'ヒガシヤシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県大島郡周防大島町笠佐島', '35', '35305', '7422108', '山口県', 'ヤマグチケン', '大島郡周防大島町', 'オオシマグンスオウオオシマチョウ', '笠佐島', 'カササジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県大島郡周防大島町久賀', '35', '35305', '7422301', '山口県', 'ヤマグチケン', '大島郡周防大島町', 'オオシマグンスオウオオシマチョウ', '久賀', 'クカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県大島郡周防大島町椋野', '35', '35305', '7422302', '山口県', 'ヤマグチケン', '大島郡周防大島町', 'オオシマグンスオウオオシマチョウ', '椋野', 'ムクノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県大島郡周防大島町片添', '35', '35305', '7422511', '山口県', 'ヤマグチケン', '大島郡周防大島町', 'オオシマグンスオウオオシマチョウ', '片添', 'カタゾエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県大島郡周防大島町平野', '35', '35305', '7422512', '山口県', 'ヤマグチケン', '大島郡周防大島町', 'オオシマグンスオウオオシマチョウ', '平野', 'ヒラノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県大島郡周防大島町森', '35', '35305', '7422513', '山口県', 'ヤマグチケン', '大島郡周防大島町', 'オオシマグンスオウオオシマチョウ', '森', 'モリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県大島郡周防大島町神浦', '35', '35305', '7422514', '山口県', 'ヤマグチケン', '大島郡周防大島町', 'オオシマグンスオウオオシマチョウ', '神浦', 'コウノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県大島郡周防大島町内入', '35', '35305', '7422515', '山口県', 'ヤマグチケン', '大島郡周防大島町', 'オオシマグンスオウオオシマチョウ', '内入', 'ウチノニュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県大島郡周防大島町和田', '35', '35305', '7422516', '山口県', 'ヤマグチケン', '大島郡周防大島町', 'オオシマグンスオウオオシマチョウ', '和田', 'ワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県大島郡周防大島町小泊', '35', '35305', '7422517', '山口県', 'ヤマグチケン', '大島郡周防大島町', 'オオシマグンスオウオオシマチョウ', '小泊', 'コドマリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県大島郡周防大島町和佐', '35', '35305', '7422518', '山口県', 'ヤマグチケン', '大島郡周防大島町', 'オオシマグンスオウオオシマチョウ', '和佐', 'ワサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県大島郡周防大島町伊保田', '35', '35305', '7422601', '山口県', 'ヤマグチケン', '大島郡周防大島町', 'オオシマグンスオウオオシマチョウ', '伊保田', 'イホタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県大島郡周防大島町伊保田雨振', '35', '35305', '7422601', '山口県', 'ヤマグチケン', '大島郡周防大島町', 'オオシマグンスオウオオシマチョウ', '伊保田', 'イホタ', null, null, '雨振', 'アマフリ');
INSERT INTO `ms_addresses` VALUES ('93075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県大島郡周防大島町伊保田小伊保田', '35', '35305', '7422601', '山口県', 'ヤマグチケン', '大島郡周防大島町', 'オオシマグンスオウオオシマチョウ', '伊保田', 'イホタ', null, null, '小伊保田', 'コイホタ');
INSERT INTO `ms_addresses` VALUES ('93076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県大島郡周防大島町伊保田情島', '35', '35305', '7422601', '山口県', 'ヤマグチケン', '大島郡周防大島町', 'オオシマグンスオウオオシマチョウ', '伊保田', 'イホタ', null, null, '情島', 'ナサケジマ');
INSERT INTO `ms_addresses` VALUES ('93077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県大島郡周防大島町伊保田両源田', '35', '35305', '7422601', '山口県', 'ヤマグチケン', '大島郡周防大島町', 'オオシマグンスオウオオシマチョウ', '伊保田', 'イホタ', null, null, '両源田', 'リョウゲンダ');
INSERT INTO `ms_addresses` VALUES ('93078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県大島郡周防大島町油宇', '35', '35305', '7422602', '山口県', 'ヤマグチケン', '大島郡周防大島町', 'オオシマグンスオウオオシマチョウ', '油宇', 'ユウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県大島郡周防大島町油宇馬ケ原', '35', '35305', '7422602', '山口県', 'ヤマグチケン', '大島郡周防大島町', 'オオシマグンスオウオオシマチョウ', '油宇', 'ユウ', null, null, '馬ケ原', 'ウマガハラ');
INSERT INTO `ms_addresses` VALUES ('93080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県大島郡周防大島町油宇日向泊', '35', '35305', '7422602', '山口県', 'ヤマグチケン', '大島郡周防大島町', 'オオシマグンスオウオオシマチョウ', '油宇', 'ユウ', null, null, '日向泊', 'ヒュウガドマリ');
INSERT INTO `ms_addresses` VALUES ('93081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県大島郡周防大島町家房', '35', '35305', '7422711', '山口県', 'ヤマグチケン', '大島郡周防大島町', 'オオシマグンスオウオオシマチョウ', '家房', 'カボウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県大島郡周防大島町出井', '35', '35305', '7422712', '山口県', 'ヤマグチケン', '大島郡周防大島町', 'オオシマグンスオウオオシマチョウ', '出井', 'イズイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県大島郡周防大島町津海木', '35', '35305', '7422713', '山口県', 'ヤマグチケン', '大島郡周防大島町', 'オオシマグンスオウオオシマチョウ', '津海木', 'ツノウギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県大島郡周防大島町戸田', '35', '35305', '7422714', '山口県', 'ヤマグチケン', '大島郡周防大島町', 'オオシマグンスオウオオシマチョウ', '戸田', 'ヘタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県大島郡周防大島町横見', '35', '35305', '7422715', '山口県', 'ヤマグチケン', '大島郡周防大島町', 'オオシマグンスオウオオシマチョウ', '横見', 'ヨコミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県大島郡周防大島町日見', '35', '35305', '7422716', '山口県', 'ヤマグチケン', '大島郡周防大島町', 'オオシマグンスオウオオシマチョウ', '日見', 'ヒミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県大島郡周防大島町浮島', '35', '35305', '7422801', '山口県', 'ヤマグチケン', '大島郡周防大島町', 'オオシマグンスオウオオシマチョウ', '浮島', 'ウカシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県大島郡周防大島町油良', '35', '35305', '7422802', '山口県', 'ヤマグチケン', '大島郡周防大島町', 'オオシマグンスオウオオシマチョウ', '油良', 'ユラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県大島郡周防大島町土居', '35', '35305', '7422803', '山口県', 'ヤマグチケン', '大島郡周防大島町', 'オオシマグンスオウオオシマチョウ', '土居', 'ドイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県大島郡周防大島町日前', '35', '35305', '7422804', '山口県', 'ヤマグチケン', '大島郡周防大島町', 'オオシマグンスオウオオシマチョウ', '日前', 'ヒクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県大島郡周防大島町東安下庄', '35', '35305', '7422805', '山口県', 'ヤマグチケン', '大島郡周防大島町', 'オオシマグンスオウオオシマチョウ', '東安下庄', 'ヒガシアゲノショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県大島郡周防大島町西安下庄', '35', '35305', '7422806', '山口県', 'ヤマグチケン', '大島郡周防大島町', 'オオシマグンスオウオオシマチョウ', '西安下庄', 'ニシアゲノショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県大島郡周防大島町秋', '35', '35305', '7422807', '山口県', 'ヤマグチケン', '大島郡周防大島町', 'オオシマグンスオウオオシマチョウ', '秋', 'アキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県大島郡周防大島町西方', '35', '35305', '7422921', '山口県', 'ヤマグチケン', '大島郡周防大島町', 'オオシマグンスオウオオシマチョウ', '西方', 'ニシガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県大島郡周防大島町西方大積', '35', '35305', '7422921', '山口県', 'ヤマグチケン', '大島郡周防大島町', 'オオシマグンスオウオオシマチョウ', '西方', 'ニシガタ', null, null, '大積', 'オオツミ');
INSERT INTO `ms_addresses` VALUES ('93096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県大島郡周防大島町西方小積', '35', '35305', '7422921', '山口県', 'ヤマグチケン', '大島郡周防大島町', 'オオシマグンスオウオオシマチョウ', '西方', 'ニシガタ', null, null, '小積', 'オツミ');
INSERT INTO `ms_addresses` VALUES ('93097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県大島郡周防大島町西方下田', '35', '35305', '7422921', '山口県', 'ヤマグチケン', '大島郡周防大島町', 'オオシマグンスオウオオシマチョウ', '西方', 'ニシガタ', null, null, '下田', 'シタタ');
INSERT INTO `ms_addresses` VALUES ('93098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県大島郡周防大島町西方長崎', '35', '35305', '7422921', '山口県', 'ヤマグチケン', '大島郡周防大島町', 'オオシマグンスオウオオシマチョウ', '西方', 'ニシガタ', null, null, '長崎', 'ナガサキ');
INSERT INTO `ms_addresses` VALUES ('93099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県大島郡周防大島町西方船越', '35', '35305', '7422921', '山口県', 'ヤマグチケン', '大島郡周防大島町', 'オオシマグンスオウオオシマチョウ', '西方', 'ニシガタ', null, null, '船越', 'フナコシ');
INSERT INTO `ms_addresses` VALUES ('93100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県大島郡周防大島町沖家室島', '35', '35305', '7422922', '山口県', 'ヤマグチケン', '大島郡周防大島町', 'オオシマグンスオウオオシマチョウ', '沖家室島', 'オキカムロジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県大島郡周防大島町地家室', '35', '35305', '7422923', '山口県', 'ヤマグチケン', '大島郡周防大島町', 'オオシマグンスオウオオシマチョウ', '地家室', 'ジカムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県大島郡周防大島町地家室佐連', '35', '35305', '7422923', '山口県', 'ヤマグチケン', '大島郡周防大島町', 'オオシマグンスオウオオシマチョウ', '地家室', 'ジカムロ', null, null, '佐連', 'サレ');
INSERT INTO `ms_addresses` VALUES ('93103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県大島郡周防大島町外入', '35', '35305', '7422924', '山口県', 'ヤマグチケン', '大島郡周防大島町', 'オオシマグンスオウオオシマチョウ', '外入', 'トノニュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県大島郡周防大島町外入伊崎', '35', '35305', '7422924', '山口県', 'ヤマグチケン', '大島郡周防大島町', 'オオシマグンスオウオオシマチョウ', '外入', 'トノニュウ', null, null, '伊崎', 'イザキ');
INSERT INTO `ms_addresses` VALUES ('93120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県光市', '35', '35210', '7430000', '山口県', 'ヤマグチケン', '光市', 'ヒカリシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('93121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県光市室積村', '35', '35210', '7430001', '山口県', 'ヤマグチケン', '光市', 'ヒカリシ', '室積村', 'ムロヅミムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県光市室積浦', '35', '35210', '7430002', '山口県', 'ヤマグチケン', '光市', 'ヒカリシ', '室積浦', 'ムロヅミウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県光市牛島', '35', '35210', '7430003', '山口県', 'ヤマグチケン', '光市', 'ヒカリシ', '牛島', 'ウシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県光市室積市延', '35', '35210', '7430004', '山口県', 'ヤマグチケン', '光市', 'ヒカリシ', '室積市延', 'ムロヅミイチノベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県光市室積東ノ庄', '35', '35210', '7430005', '山口県', 'ヤマグチケン', '光市', 'ヒカリシ', '室積東ノ庄', 'ムロヅミヒガシノショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県光市室積神田', '35', '35210', '7430006', '山口県', 'ヤマグチケン', '光市', 'ヒカリシ', '室積神田', 'ムロヅミジンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県光市室積', '35', '35210', '7430007', '山口県', 'ヤマグチケン', '光市', 'ヒカリシ', '室積', 'ムロヅミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県光市室積中央町', '35', '35210', '7430008', '山口県', 'ヤマグチケン', '光市', 'ヒカリシ', '室積中央町', 'ムロヅミチュウオウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県光市室積松原', '35', '35210', '7430009', '山口県', 'ヤマグチケン', '光市', 'ヒカリシ', '室積松原', 'ムロヅミマツバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県光市光井', '35', '35210', '7430011', '山口県', 'ヤマグチケン', '光市', 'ヒカリシ', '光井', 'ミツイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県光市千坊台', '35', '35210', '7430012', '山口県', 'ヤマグチケン', '光市', 'ヒカリシ', '千坊台', 'センボウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県光市中央', '35', '35210', '7430013', '山口県', 'ヤマグチケン', '光市', 'ヒカリシ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県光市浅江', '35', '35210', '7430021', '山口県', 'ヤマグチケン', '光市', 'ヒカリシ', '浅江', 'アサエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県光市虹ケ浜', '35', '35210', '7430022', '山口県', 'ヤマグチケン', '光市', 'ヒカリシ', '虹ケ浜', 'ニジガハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県光市虹ケ丘', '35', '35210', '7430031', '山口県', 'ヤマグチケン', '光市', 'ヒカリシ', '虹ケ丘', 'ニジガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県光市丸山町', '35', '35210', '7430041', '山口県', 'ヤマグチケン', '光市', 'ヒカリシ', '丸山町', 'マルヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県光市宝町', '35', '35210', '7430042', '山口県', 'ヤマグチケン', '光市', 'ヒカリシ', '宝町', 'タカラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県光市協和町', '35', '35210', '7430043', '山口県', 'ヤマグチケン', '光市', 'ヒカリシ', '協和町', 'キョウワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県光市和田町', '35', '35210', '7430044', '山口県', 'ヤマグチケン', '光市', 'ヒカリシ', '和田町', 'ワダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県光市宮ノ下町', '35', '35210', '7430045', '山口県', 'ヤマグチケン', '光市', 'ヒカリシ', '宮ノ下町', 'ミヤノシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県光市木園', '35', '35210', '7430046', '山口県', 'ヤマグチケン', '光市', 'ヒカリシ', '木園', 'キゾノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県光市花園', '35', '35210', '7430047', '山口県', 'ヤマグチケン', '光市', 'ヒカリシ', '花園', 'ハナゾノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県光市中村町', '35', '35210', '7430048', '山口県', 'ヤマグチケン', '光市', 'ヒカリシ', '中村町', 'ナカムラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県光市岩狩', '35', '35210', '7430051', '山口県', 'ヤマグチケン', '光市', 'ヒカリシ', '岩狩', 'イワガリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県光市三井', '35', '35210', '7430052', '山口県', 'ヤマグチケン', '光市', 'ヒカリシ', '三井', 'ミイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県光市小周防', '35', '35210', '7430061', '山口県', 'ヤマグチケン', '光市', 'ヒカリシ', '小周防', 'コズオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県光市立野', '35', '35210', '7430062', '山口県', 'ヤマグチケン', '光市', 'ヒカリシ', '立野', 'タテノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県光市島田', '35', '35210', '7430063', '山口県', 'ヤマグチケン', '光市', 'ヒカリシ', '島田', 'シマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県光市中島田', '35', '35210', '7430064', '山口県', 'ヤマグチケン', '光市', 'ヒカリシ', '中島田', 'ナカシマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県光市上島田', '35', '35210', '7430065', '山口県', 'ヤマグチケン', '光市', 'ヒカリシ', '上島田', 'カミシマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県光市室積新開', '35', '35210', '7430071', '山口県', 'ヤマグチケン', '光市', 'ヒカリシ', '室積新開', 'ムロヅミシンカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県光市室積大町', '35', '35210', '7430072', '山口県', 'ヤマグチケン', '光市', 'ヒカリシ', '室積大町', 'ムロヅミオオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県光市室積正木', '35', '35210', '7430073', '山口県', 'ヤマグチケン', '光市', 'ヒカリシ', '室積正木', 'ムロヅミマサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県光市室積西ノ庄', '35', '35210', '7430074', '山口県', 'ヤマグチケン', '光市', 'ヒカリシ', '室積西ノ庄', 'ムロヅミニシノショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県光市室積沖田', '35', '35210', '7430075', '山口県', 'ヤマグチケン', '光市', 'ヒカリシ', '室積沖田', 'ムロヅミオキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県光市塩田', '35', '35210', '7430101', '山口県', 'ヤマグチケン', '光市', 'ヒカリシ', '塩田', 'シオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県光市三輪', '35', '35210', '7430102', '山口県', 'ヤマグチケン', '光市', 'ヒカリシ', '三輪', 'ミワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県光市岩田', '35', '35210', '7430103', '山口県', 'ヤマグチケン', '光市', 'ヒカリシ', '岩田', 'イワタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県光市岩田立野', '35', '35210', '7430104', '山口県', 'ヤマグチケン', '光市', 'ヒカリシ', '岩田立野', 'イワタタテノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県光市束荷', '35', '35210', '7430105', '山口県', 'ヤマグチケン', '光市', 'ヒカリシ', '束荷', 'ツカリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市', '35', '35207', '7440000', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('93169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市笠戸島', '35', '35207', '7440001', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '笠戸島', 'カサドシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市笠戸島江ノ浦', '35', '35207', '7440001', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '笠戸島', 'カサドシマ', null, null, '江ノ浦', 'エノウラ');
INSERT INTO `ms_addresses` VALUES ('93171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市笠戸島大松ケ浦', '35', '35207', '7440001', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '笠戸島', 'カサドシマ', null, null, '大松ケ浦', 'オオマツガウラ');
INSERT INTO `ms_addresses` VALUES ('93172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市笠戸島尾郷', '35', '35207', '7440001', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '笠戸島', 'カサドシマ', null, null, '尾郷', 'オゴウ');
INSERT INTO `ms_addresses` VALUES ('93173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市笠戸島尾泊', '35', '35207', '7440001', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '笠戸島', 'カサドシマ', null, null, '尾泊', 'オドマリ');
INSERT INTO `ms_addresses` VALUES ('93174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市笠戸島小深浦', '35', '35207', '7440001', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '笠戸島', 'カサドシマ', null, null, '小深浦', 'コブカウラ');
INSERT INTO `ms_addresses` VALUES ('93175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市笠戸島瀬戸', '35', '35207', '7440001', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '笠戸島', 'カサドシマ', null, null, '瀬戸', 'セト');
INSERT INTO `ms_addresses` VALUES ('93176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市笠戸島深浦', '35', '35207', '7440001', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '笠戸島', 'カサドシマ', null, null, '深浦', 'フカウラ');
INSERT INTO `ms_addresses` VALUES ('93177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市笠戸島本浦', '35', '35207', '7440001', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '笠戸島', 'カサドシマ', null, null, '本浦', 'ホンウラ');
INSERT INTO `ms_addresses` VALUES ('93178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市東豊井', '35', '35207', '7440002', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '東豊井', 'ヒガシトヨイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市東豊井江口', '35', '35207', '7440002', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '東豊井', 'ヒガシトヨイ', null, null, '江口', 'エグチ');
INSERT INTO `ms_addresses` VALUES ('93180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市東豊井上豊井', '35', '35207', '7440002', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '東豊井', 'ヒガシトヨイ', null, null, '上豊井', 'カミトヨイ');
INSERT INTO `ms_addresses` VALUES ('93181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市東豊井神田町', '35', '35207', '7440002', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '東豊井', 'ヒガシトヨイ', null, null, '神田町', 'カンダマチ');
INSERT INTO `ms_addresses` VALUES ('93182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市東豊井恋ケ浜', '35', '35207', '7440002', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '東豊井', 'ヒガシトヨイ', null, null, '恋ケ浜', 'コイガハマ');
INSERT INTO `ms_addresses` VALUES ('93183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市東豊井下豊井', '35', '35207', '7440002', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '東豊井', 'ヒガシトヨイ', null, null, '下豊井', 'シモトヨイ');
INSERT INTO `ms_addresses` VALUES ('93184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市東豊井新町', '35', '35207', '7440002', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '東豊井', 'ヒガシトヨイ', null, null, '新町', 'シンマチ');
INSERT INTO `ms_addresses` VALUES ('93185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市東豊井洲鼻', '35', '35207', '7440002', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '東豊井', 'ヒガシトヨイ', null, null, '洲鼻', 'スバナ');
INSERT INTO `ms_addresses` VALUES ('93186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市東豊井住吉町', '35', '35207', '7440002', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '東豊井', 'ヒガシトヨイ', null, null, '住吉町', 'スミヨシチョウ');
INSERT INTO `ms_addresses` VALUES ('93187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市東豊井寺迫', '35', '35207', '7440002', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '東豊井', 'ヒガシトヨイ', null, null, '寺迫', 'テラサコ');
INSERT INTO `ms_addresses` VALUES ('93188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市東豊井寺迫半上', '35', '35207', '7440002', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '東豊井', 'ヒガシトヨイ', null, null, '寺迫半上', 'テラサコハンジョウ');
INSERT INTO `ms_addresses` VALUES ('93189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市東豊井二宮町', '35', '35207', '7440002', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '東豊井', 'ヒガシトヨイ', null, null, '二宮町', 'ニノミヤチョウ');
INSERT INTO `ms_addresses` VALUES ('93190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市東豊井花垣', '35', '35207', '7440002', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '東豊井', 'ヒガシトヨイ', null, null, '花垣', 'ハナガキ');
INSERT INTO `ms_addresses` VALUES ('93191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市東豊井東海岸通り', '35', '35207', '7440002', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '東豊井', 'ヒガシトヨイ', null, null, '東海岸通り', 'ヒガシカイガンドオリ');
INSERT INTO `ms_addresses` VALUES ('93192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市東豊井東豊井開作', '35', '35207', '7440002', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '東豊井', 'ヒガシトヨイ', null, null, '東豊井開作', 'ヒガシトヨイカイサク');
INSERT INTO `ms_addresses` VALUES ('93193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市東豊井松神町', '35', '35207', '7440002', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '東豊井', 'ヒガシトヨイ', null, null, '松神町', 'マツガミチョウ');
INSERT INTO `ms_addresses` VALUES ('93194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市琴平町', '35', '35207', '7440003', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '琴平町', 'コトヒラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市青柳', '35', '35207', '7440004', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '青柳', 'アオヤギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市古川町', '35', '35207', '7440005', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '古川町', 'フルカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市旗岡', '35', '35207', '7440006', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '旗岡', 'ハタオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市西豊井', '35', '35207', '7440011', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '西豊井', 'ニシトヨイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市西豊井相生町', '35', '35207', '7440011', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '西豊井', 'ニシトヨイ', null, null, '相生町', 'アイオイチョウ');
INSERT INTO `ms_addresses` VALUES ('93200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市西豊井旭町', '35', '35207', '7440011', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '西豊井', 'ニシトヨイ', null, null, '旭町', 'アサヒマチ');
INSERT INTO `ms_addresses` VALUES ('93201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市西豊井幸町', '35', '35207', '7440011', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '西豊井', 'ニシトヨイ', null, null, '幸町', 'サイワイチョウ');
INSERT INTO `ms_addresses` VALUES ('93202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市西豊井汐見町', '35', '35207', '7440011', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '西豊井', 'ニシトヨイ', null, null, '汐見町', 'シオミチョウ');
INSERT INTO `ms_addresses` VALUES ('93203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市西豊井高砂町', '35', '35207', '7440011', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '西豊井', 'ニシトヨイ', null, null, '高砂町', 'タカサゴチョウ');
INSERT INTO `ms_addresses` VALUES ('93204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市西豊井所田', '35', '35207', '7440011', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '西豊井', 'ニシトヨイ', null, null, '所田', 'トコロダ');
INSERT INTO `ms_addresses` VALUES ('93205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市西豊井中島町', '35', '35207', '7440011', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '西豊井', 'ニシトヨイ', null, null, '中島町', 'ナカシマチョウ');
INSERT INTO `ms_addresses` VALUES ('93206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市西豊井本町', '35', '35207', '7440011', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '西豊井', 'ニシトヨイ', null, null, '本町', 'ホンマチ');
INSERT INTO `ms_addresses` VALUES ('93207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市西豊井都町', '35', '35207', '7440011', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '西豊井', 'ニシトヨイ', null, null, '都町', 'ミヤコマチ');
INSERT INTO `ms_addresses` VALUES ('93208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市西豊井元町西', '35', '35207', '7440011', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '西豊井', 'ニシトヨイ', null, null, '元町西', 'モトマチニシ');
INSERT INTO `ms_addresses` VALUES ('93209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市西豊井元町東', '35', '35207', '7440011', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '西豊井', 'ニシトヨイ', null, null, '元町東', 'モトマチヒガシ');
INSERT INTO `ms_addresses` VALUES ('93210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市北斗町', '35', '35207', '7440012', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '北斗町', 'ホクトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市栄町', '35', '35207', '7440013', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市中市', '35', '35207', '7440014', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '中市', 'ナカイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市大手町', '35', '35207', '7440015', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '大手町', 'オオテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市樋ノ上', '35', '35207', '7440016', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '樋ノ上', 'ヒノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市東柳', '35', '35207', '7440017', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '東柳', 'ヒガシヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市西柳', '35', '35207', '7440018', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '西柳', 'ニシヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市桜町', '35', '35207', '7440019', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '桜町', 'サクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市平田', '35', '35207', '7440021', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '平田', 'ヒラタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市平田西開作', '35', '35207', '7440021', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '平田', 'ヒラタ', null, null, '西開作', 'ニシガイサク');
INSERT INTO `ms_addresses` VALUES ('93220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市平田東開作', '35', '35207', '7440021', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '平田', 'ヒラタ', null, null, '東開作', 'ヒガシガイサク');
INSERT INTO `ms_addresses` VALUES ('93221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市末武下', '35', '35207', '7440022', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '末武下', 'スエタケシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市末武下あけぼの町', '35', '35207', '7440022', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '末武下', 'スエタケシモ', null, null, 'あけぼの町', 'アケボノチョウ');
INSERT INTO `ms_addresses` VALUES ('93223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市末武下西市沖', '35', '35207', '7440022', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '末武下', 'スエタケシモ', null, null, '西市沖', 'ニシイチオキ');
INSERT INTO `ms_addresses` VALUES ('93224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市末武下西市西', '35', '35207', '7440022', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '末武下', 'スエタケシモ', null, null, '西市西', 'ニシイチニシ');
INSERT INTO `ms_addresses` VALUES ('93225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市末武下西市東', '35', '35207', '7440022', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '末武下', 'スエタケシモ', null, null, '西市東', 'ニシイチヒガシ');
INSERT INTO `ms_addresses` VALUES ('93226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市末武下松中町', '35', '35207', '7440022', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '末武下', 'スエタケシモ', null, null, '松中町', 'マツナカチョウ');
INSERT INTO `ms_addresses` VALUES ('93227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市末武下弥生町', '35', '35207', '7440022', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '末武下', 'スエタケシモ', null, null, '弥生町', 'ヤヨイチョウ');
INSERT INTO `ms_addresses` VALUES ('93228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市末武中', '35', '35207', '7440023', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '末武中', 'スエタケナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市末武中朝日台', '35', '35207', '7440023', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '末武中', 'スエタケナカ', null, null, '朝日台', 'アサヒダイ');
INSERT INTO `ms_addresses` VALUES ('93230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市末武中荒神', '35', '35207', '7440023', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '末武中', 'スエタケナカ', null, null, '荒神', 'コウジン');
INSERT INTO `ms_addresses` VALUES ('93231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市末武中西河原', '35', '35207', '7440023', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '末武中', 'スエタケナカ', null, null, '西河原', 'ニシガハラ');
INSERT INTO `ms_addresses` VALUES ('93232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市末武中東中村', '35', '35207', '7440023', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '末武中', 'スエタケナカ', null, null, '東中村', 'ヒガシナカムラ');
INSERT INTO `ms_addresses` VALUES ('93233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市末武中広石', '35', '35207', '7440023', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '末武中', 'スエタケナカ', null, null, '広石', 'ヒロイシ');
INSERT INTO `ms_addresses` VALUES ('93234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市末武中向香力', '35', '35207', '7440023', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '末武中', 'スエタケナカ', null, null, '向香力', 'ムカイコウリキ');
INSERT INTO `ms_addresses` VALUES ('93235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市末武中山根', '35', '35207', '7440023', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '末武中', 'スエタケナカ', null, null, '山根', 'ヤマネ');
INSERT INTO `ms_addresses` VALUES ('93236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市末武中和田', '35', '35207', '7440023', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '末武中', 'スエタケナカ', null, null, '和田', 'ワダ');
INSERT INTO `ms_addresses` VALUES ('93237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市末武上', '35', '35207', '7440024', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '末武上', 'スエタケカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市末武上上地', '35', '35207', '7440024', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '末武上', 'スエタケカミ', null, null, '上地', 'アゲヂ');
INSERT INTO `ms_addresses` VALUES ('93239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市末武上浴', '35', '35207', '7440024', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '末武上', 'スエタケカミ', null, null, '浴', 'エキ');
INSERT INTO `ms_addresses` VALUES ('93240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市末武上戎町', '35', '35207', '7440024', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '末武上', 'スエタケカミ', null, null, '戎町', 'エビスマチ');
INSERT INTO `ms_addresses` VALUES ('93241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市末武上華陵', '35', '35207', '7440024', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '末武上', 'スエタケカミ', null, null, '華陵', 'カリョウ');
INSERT INTO `ms_addresses` VALUES ('93242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市末武上下高塚', '35', '35207', '7440024', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '末武上', 'スエタケカミ', null, null, '下高塚', 'シモタカツカ');
INSERT INTO `ms_addresses` VALUES ('93243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市末武上昭和', '35', '35207', '7440024', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '末武上', 'スエタケカミ', null, null, '昭和', 'ショウワ');
INSERT INTO `ms_addresses` VALUES ('93244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市末武上大黒町', '35', '35207', '7440024', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '末武上', 'スエタケカミ', null, null, '大黒町', 'ダイコクチョウ');
INSERT INTO `ms_addresses` VALUES ('93245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市末武上高橋', '35', '35207', '7440024', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '末武上', 'スエタケカミ', null, null, '高橋', 'タカハシ');
INSERT INTO `ms_addresses` VALUES ('93246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市末武上常森', '35', '35207', '7440024', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '末武上', 'スエタケカミ', null, null, '常森', 'ツネモリ');
INSERT INTO `ms_addresses` VALUES ('93247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市末武上中市', '35', '35207', '7440024', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '末武上', 'スエタケカミ', null, null, '中市', 'ナカイチ');
INSERT INTO `ms_addresses` VALUES ('93248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市末武上西町', '35', '35207', '7440024', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '末武上', 'スエタケカミ', null, null, '西町', 'ニシマチ');
INSERT INTO `ms_addresses` VALUES ('93249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市末武上東町', '35', '35207', '7440024', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '末武上', 'スエタケカミ', null, null, '東町', 'ヒガシマチ');
INSERT INTO `ms_addresses` VALUES ('93250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市末武上緑ケ丘', '35', '35207', '7440024', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '末武上', 'スエタケカミ', null, null, '緑ケ丘', 'ミドリガオカ');
INSERT INTO `ms_addresses` VALUES ('93251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市末武上南花岡', '35', '35207', '7440024', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '末武上', 'スエタケカミ', null, null, '南花岡', 'ミナミハナオカ');
INSERT INTO `ms_addresses` VALUES ('93252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市中央町', '35', '35207', '7440025', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '中央町', 'チュウオウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市南花岡', '35', '35207', '7440027', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '南花岡', 'ミナミハナオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市藤光町', '35', '35207', '7440028', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '藤光町', 'トウミツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市楠木町', '35', '35207', '7440029', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '楠木町', 'クスノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市生野屋', '35', '35207', '7440031', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '生野屋', 'イクノヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市生野屋猪ノ尻', '35', '35207', '7440031', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '生野屋', 'イクノヤ', null, null, '猪ノ尻', 'イノシリ');
INSERT INTO `ms_addresses` VALUES ('93258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市生野屋上時宗', '35', '35207', '7440031', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '生野屋', 'イクノヤ', null, null, '上時宗', 'カミトキムネ');
INSERT INTO `ms_addresses` VALUES ('93259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市生野屋高垣団地', '35', '35207', '7440031', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '生野屋', 'イクノヤ', null, null, '高垣団地', 'コウガキダンチ');
INSERT INTO `ms_addresses` VALUES ('93260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市生野屋下村', '35', '35207', '7440031', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '生野屋', 'イクノヤ', null, null, '下村', 'シモムラ');
INSERT INTO `ms_addresses` VALUES ('93261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市生野屋大王団地', '35', '35207', '7440031', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '生野屋', 'イクノヤ', null, null, '大王団地', 'ダイオウダンチ');
INSERT INTO `ms_addresses` VALUES ('93262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市生野屋為弘', '35', '35207', '7440031', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '生野屋', 'イクノヤ', null, null, '為弘', 'タメヒロ');
INSERT INTO `ms_addresses` VALUES ('93263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市生野屋田園調布', '35', '35207', '7440031', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '生野屋', 'イクノヤ', null, null, '田園調布', 'デンエンチョウフ');
INSERT INTO `ms_addresses` VALUES ('93264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市生野屋藤立', '35', '35207', '7440031', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '生野屋', 'イクノヤ', null, null, '藤立', 'トウリュウ');
INSERT INTO `ms_addresses` VALUES ('93265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市生野屋時政', '35', '35207', '7440031', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '生野屋', 'イクノヤ', null, null, '時政', 'トキマサ');
INSERT INTO `ms_addresses` VALUES ('93266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市生野屋時宗', '35', '35207', '7440031', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '生野屋', 'イクノヤ', null, null, '時宗', 'トキムネ');
INSERT INTO `ms_addresses` VALUES ('93267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市生野屋中村', '35', '35207', '7440031', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '生野屋', 'イクノヤ', null, null, '中村', 'ナカムラ');
INSERT INTO `ms_addresses` VALUES ('93268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市生野屋西時宗', '35', '35207', '7440031', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '生野屋', 'イクノヤ', null, null, '西時宗', 'ニシトキムネ');
INSERT INTO `ms_addresses` VALUES ('93269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市生野屋西村', '35', '35207', '7440031', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '生野屋', 'イクノヤ', null, null, '西村', 'ニシムラ');
INSERT INTO `ms_addresses` VALUES ('93270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市生野屋西村団地', '35', '35207', '7440031', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '生野屋', 'イクノヤ', null, null, '西村団地', 'ニシムラダンチ');
INSERT INTO `ms_addresses` VALUES ('93271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市生野屋羽根田町', '35', '35207', '7440031', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '生野屋', 'イクノヤ', null, null, '羽根田町', 'ハネダチョウ');
INSERT INTO `ms_addresses` VALUES ('93272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市生野屋東時宗', '35', '35207', '7440031', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '生野屋', 'イクノヤ', null, null, '東時宗', 'ヒガシトキムネ');
INSERT INTO `ms_addresses` VALUES ('93273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市生野屋東万ノ木団地', '35', '35207', '7440031', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '生野屋', 'イクノヤ', null, null, '東万ノ木団地', 'ヒガシマンノキダンチ');
INSERT INTO `ms_addresses` VALUES ('93274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市生野屋万ノ木町', '35', '35207', '7440031', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '生野屋', 'イクノヤ', null, null, '万ノ木町', 'マンノキチョウ');
INSERT INTO `ms_addresses` VALUES ('93275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市生野屋宮本', '35', '35207', '7440031', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '生野屋', 'イクノヤ', null, null, '宮本', 'ミヤモト');
INSERT INTO `ms_addresses` VALUES ('93276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市生野屋西', '35', '35207', '7440032', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '生野屋西', 'イクノヤニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市生野屋南', '35', '35207', '7440033', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '生野屋南', 'イクノヤミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市山田', '35', '35207', '7440041', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '山田', 'ヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市山田梅ノ木原', '35', '35207', '7440041', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '山田', 'ヤマダ', null, null, '梅ノ木原', 'ウメノキハラ');
INSERT INTO `ms_addresses` VALUES ('93280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市山田浴条', '35', '35207', '7440041', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '山田', 'ヤマダ', null, null, '浴条', 'エキジョウ');
INSERT INTO `ms_addresses` VALUES ('93281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市山田山田上', '35', '35207', '7440041', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '山田', 'ヤマダ', null, null, '山田上', 'ヤマダカミ');
INSERT INTO `ms_addresses` VALUES ('93282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市山田山田下', '35', '35207', '7440041', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '山田', 'ヤマダ', null, null, '山田下', 'ヤマダシモ');
INSERT INTO `ms_addresses` VALUES ('93283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市切山', '35', '35207', '7440042', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '切山', 'キリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市切山切山上', '35', '35207', '7440042', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '切山', 'キリヤマ', null, null, '切山上', 'キリヤマカミ');
INSERT INTO `ms_addresses` VALUES ('93285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市切山切山下', '35', '35207', '7440042', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '切山', 'キリヤマ', null, null, '切山下', 'キリヤマシモ');
INSERT INTO `ms_addresses` VALUES ('93286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市切山切山中', '35', '35207', '7440042', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '切山', 'キリヤマ', null, null, '切山中', 'キリヤマナカ');
INSERT INTO `ms_addresses` VALUES ('93287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市切山中', '35', '35207', '7440042', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '切山', 'キリヤマ', null, null, '中', 'ナカ');
INSERT INTO `ms_addresses` VALUES ('93288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市東陽', '35', '35207', '7440043', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '東陽', 'トウヨウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市来巻', '35', '35207', '7440051', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '来巻', 'クルマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市来巻西', '35', '35207', '7440051', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '来巻', 'クルマキ', null, null, '西', 'ニシ');
INSERT INTO `ms_addresses` VALUES ('93291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市来巻東', '35', '35207', '7440051', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '来巻', 'クルマキ', null, null, '東', 'ヒガシ');
INSERT INTO `ms_addresses` VALUES ('93292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市桃山町', '35', '35207', '7440052', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '桃山町', 'モモヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市東和', '35', '35207', '7440053', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '東和', 'トウワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市河内', '35', '35207', '7440061', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '河内', 'コウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市河内青葉台', '35', '35207', '7440061', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '河内', 'コウチ', null, null, '青葉台', 'アオバダイ');
INSERT INTO `ms_addresses` VALUES ('93296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市河内大河内', '35', '35207', '7440061', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '河内', 'コウチ', null, null, '大河内', 'オオコウチ');
INSERT INTO `ms_addresses` VALUES ('93297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市河内岡市', '35', '35207', '7440061', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '河内', 'コウチ', null, null, '岡市', 'オカイチ');
INSERT INTO `ms_addresses` VALUES ('93298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市河内岡ノ原町', '35', '35207', '7440061', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '河内', 'コウチ', null, null, '岡ノ原町', 'オカノハラチョウ');
INSERT INTO `ms_addresses` VALUES ('93299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市河内川瀬', '35', '35207', '7440061', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '河内', 'コウチ', null, null, '川瀬', 'カワセ');
INSERT INTO `ms_addresses` VALUES ('93300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市河内下松セントシティ', '35', '35207', '7440061', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '河内', 'コウチ', null, null, '下松セントシティ', 'クダマツセントシティ');
INSERT INTO `ms_addresses` VALUES ('93301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市河内久保', '35', '35207', '7440061', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '河内', 'コウチ', null, null, '久保', 'クボ');
INSERT INTO `ms_addresses` VALUES ('93302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市河内久保市', '35', '35207', '7440061', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '河内', 'コウチ', null, null, '久保市', 'クボイチ');
INSERT INTO `ms_addresses` VALUES ('93303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市河内黒杭', '35', '35207', '7440061', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '河内', 'コウチ', null, null, '黒杭', 'クロクイ');
INSERT INTO `ms_addresses` VALUES ('93304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市河内小野', '35', '35207', '7440061', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '河内', 'コウチ', null, null, '小野', 'コノ');
INSERT INTO `ms_addresses` VALUES ('93305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市河内幸ケ丘', '35', '35207', '7440061', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '河内', 'コウチ', null, null, '幸ケ丘', 'サチガオカ');
INSERT INTO `ms_addresses` VALUES ('93306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市河内城山台', '35', '35207', '7440061', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '河内', 'コウチ', null, null, '城山台', 'ジョウヤマダイ');
INSERT INTO `ms_addresses` VALUES ('93307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市河内昭和通り', '35', '35207', '7440061', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '河内', 'コウチ', null, null, '昭和通り', 'ショウワドオリ');
INSERT INTO `ms_addresses` VALUES ('93308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市河内素通り', '35', '35207', '7440061', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '河内', 'コウチ', null, null, '素通り', 'スドオリ');
INSERT INTO `ms_addresses` VALUES ('93309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市河内谷', '35', '35207', '7440061', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '河内', 'コウチ', null, null, '谷', 'タニ');
INSERT INTO `ms_addresses` VALUES ('93310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市河内つつじケ丘', '35', '35207', '7440061', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '河内', 'コウチ', null, null, 'つつじケ丘', 'ツツジガオカ');
INSERT INTO `ms_addresses` VALUES ('93311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市河内出合', '35', '35207', '7440061', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '河内', 'コウチ', null, null, '出合', 'デアイ');
INSERT INTO `ms_addresses` VALUES ('93312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市河内殿ケ浴', '35', '35207', '7440061', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '河内', 'コウチ', null, null, '殿ケ浴', 'トノガエキ');
INSERT INTO `ms_addresses` VALUES ('93313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市河内中戸原', '35', '35207', '7440061', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '河内', 'コウチ', null, null, '中戸原', 'ナカトハラ');
INSERT INTO `ms_addresses` VALUES ('93314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市河内成川', '35', '35207', '7440061', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '河内', 'コウチ', null, null, '成川', 'ナルカワ');
INSERT INTO `ms_addresses` VALUES ('93315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市河内二ノ瀬', '35', '35207', '7440061', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '河内', 'コウチ', null, null, '二ノ瀬', 'ニノセ');
INSERT INTO `ms_addresses` VALUES ('93316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市河内葉山', '35', '35207', '7440061', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '河内', 'コウチ', null, null, '葉山', 'ハヤマ');
INSERT INTO `ms_addresses` VALUES ('93317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市河内日ノ出町', '35', '35207', '7440061', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '河内', 'コウチ', null, null, '日ノ出町', 'ヒノデチョウ');
INSERT INTO `ms_addresses` VALUES ('93318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市河内吉原', '35', '35207', '7440061', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '河内', 'コウチ', null, null, '吉原', 'ヨシワラ');
INSERT INTO `ms_addresses` VALUES ('93319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市昭和町', '35', '35207', '7440062', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '昭和町', 'ショウワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市若宮町', '35', '35207', '7440063', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '若宮町', 'ワカミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市星が丘', '35', '35207', '7440065', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '星が丘', 'ホシガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市清瀬町', '35', '35207', '7440071', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '清瀬町', 'キヨセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市望町', '35', '35207', '7440072', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '望町', 'ノゾミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市美里町', '35', '35207', '7440073', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '美里町', 'ミサトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市潮音町', '35', '35207', '7440074', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '潮音町', 'シオネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市瑞穂町', '35', '35207', '7440075', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '瑞穂町', 'ミズホチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市下谷', '35', '35207', '7440271', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '下谷', 'クダタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市下谷赤谷', '35', '35207', '7440271', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '下谷', 'クダタニ', null, null, '赤谷', 'アカダニ');
INSERT INTO `ms_addresses` VALUES ('93329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市下谷清若', '35', '35207', '7440271', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '下谷', 'クダタニ', null, null, '清若', 'キヨワカ');
INSERT INTO `ms_addresses` VALUES ('93330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市下谷下谷一区', '35', '35207', '7440271', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '下谷', 'クダタニ', null, null, '下谷一区', 'クダタニ01ク');
INSERT INTO `ms_addresses` VALUES ('93331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市下谷下谷二区', '35', '35207', '7440271', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '下谷', 'クダタニ', null, null, '下谷二区', 'クダタニ02ク');
INSERT INTO `ms_addresses` VALUES ('93332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市下谷下谷三区', '35', '35207', '7440271', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '下谷', 'クダタニ', null, null, '下谷三区', 'クダタニ03ク');
INSERT INTO `ms_addresses` VALUES ('93333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市下谷中瀬', '35', '35207', '7440271', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '下谷', 'クダタニ', null, null, '中瀬', 'ナカセ');
INSERT INTO `ms_addresses` VALUES ('93334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市下谷中原', '35', '35207', '7440271', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '下谷', 'クダタニ', null, null, '中原', 'ナカバラ');
INSERT INTO `ms_addresses` VALUES ('93335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市下谷西平谷', '35', '35207', '7440271', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '下谷', 'クダタニ', null, null, '西平谷', 'ニシヒラダニ');
INSERT INTO `ms_addresses` VALUES ('93336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市下谷山高', '35', '35207', '7440271', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '下谷', 'クダタニ', null, null, '山高', 'ヤマタカ');
INSERT INTO `ms_addresses` VALUES ('93337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市大藤谷', '35', '35207', '7440272', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '大藤谷', 'オオフジダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市瀬戸', '35', '35207', '7440273', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '瀬戸', 'セト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市瀬戸後山', '35', '35207', '7440273', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '瀬戸', 'セト', null, null, '後山', 'ウシロヤマ');
INSERT INTO `ms_addresses` VALUES ('93340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市瀬戸高橋', '35', '35207', '7440273', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '瀬戸', 'セト', null, null, '高橋', 'タカハシ');
INSERT INTO `ms_addresses` VALUES ('93341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市瀬戸中瀬', '35', '35207', '7440273', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '瀬戸', 'セト', null, null, '中瀬', 'ナカセ');
INSERT INTO `ms_addresses` VALUES ('93342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市瀬戸中原', '35', '35207', '7440273', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '瀬戸', 'セト', null, null, '中原', 'ナカバラ');
INSERT INTO `ms_addresses` VALUES ('93343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市温見', '35', '35207', '7440274', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '温見', 'ヌクミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市温見後山', '35', '35207', '7440274', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '温見', 'ヌクミ', null, null, '後山', 'ウシロヤマ');
INSERT INTO `ms_addresses` VALUES ('93345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市温見道谷', '35', '35207', '7440274', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '温見', 'ヌクミ', null, null, '道谷', 'ミチダニ');
INSERT INTO `ms_addresses` VALUES ('93346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市中須南', '35', '35207', '7440275', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '中須南', 'ナカスミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下松市米川', '35', '35207', '7440276', '山口県', 'ヤマグチケン', '下松市', 'クダマツシ', '米川', 'ヨネガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市', '35', '35215', '7450000', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('93353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市辻町', '35', '35215', '7450001', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '辻町', 'ツジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市二番町', '35', '35215', '7450002', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '二番町', 'ニバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市三番町', '35', '35215', '7450003', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '三番町', 'サンバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市毛利町', '35', '35215', '7450004', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '毛利町', 'モウリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市児玉町', '35', '35215', '7450005', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '児玉町', 'コダマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市花畠町', '35', '35215', '7450006', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '花畠町', 'ハナバタケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市岐南町', '35', '35215', '7450007', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '岐南町', 'キナンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市桜馬場通り', '35', '35215', '7450011', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '桜馬場通り', 'サクラババドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市川端町', '35', '35215', '7450012', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '川端町', 'カワバタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市昭和通り', '35', '35215', '7450013', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '昭和通り', 'ショウワドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市飯島町', '35', '35215', '7450014', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '飯島町', 'イイジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市平和通り', '35', '35215', '7450015', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '平和通り', 'ヘイワドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市若宮町', '35', '35215', '7450016', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '若宮町', 'ワカミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市新町', '35', '35215', '7450017', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市柳町', '35', '35215', '7450021', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '柳町', 'ヤナギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市橋本町', '35', '35215', '7450022', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '橋本町', 'ハシモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市那智町', '35', '35215', '7450023', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '那智町', 'ナチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市晴海町', '35', '35215', '7450024', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '晴海町', 'ハルミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市築港町', '35', '35215', '7450025', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '築港町', 'チッコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市住崎町', '35', '35215', '7450026', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '住崎町', 'スミザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市糀町', '35', '35215', '7450027', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '糀町', 'コウジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市銀南街', '35', '35215', '7450031', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '銀南街', 'ギンナンガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市銀座', '35', '35215', '7450032', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '銀座', 'ギンザ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市みなみ銀座', '35', '35215', '7450033', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', 'みなみ銀座', 'ミナミギンザ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市御幸通り', '35', '35215', '7450034', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '御幸通り', 'ミユキドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市有楽町', '35', '35215', '7450035', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '有楽町', 'ユウラクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市本町', '35', '35215', '7450036', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市栄町', '35', '35215', '7450037', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市戎町', '35', '35215', '7450041', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '戎町', 'エビスマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市野上町', '35', '35215', '7450042', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '野上町', 'ノガミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市都町', '35', '35215', '7450043', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '都町', 'ミヤコマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市千代田町', '35', '35215', '7450044', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '千代田町', 'チヨダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市徳山港町', '35', '35215', '7450045', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '徳山港町', 'トクヤマミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市権現町', '35', '35215', '7450046', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '権現町', 'ゴンゲンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市入船町', '35', '35215', '7450047', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '入船町', 'イリフネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市沖見町', '35', '35215', '7450051', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '沖見町', 'オキミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市初音町', '35', '35215', '7450052', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '初音町', 'ハツネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市御影町', '35', '35215', '7450053', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '御影町', 'ミカゲチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市西松原', '35', '35215', '7450054', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '西松原', 'ニシマツバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市相生町', '35', '35215', '7450055', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '相生町', 'アイオイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市新宿通', '35', '35215', '7450056', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '新宿通', 'シンジュクドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市大津島', '35', '35215', '7450057', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '大津島', 'オオツシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市鐘楼町', '35', '35215', '7450061', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '鐘楼町', 'ショウロウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市月丘町', '35', '35215', '7450062', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '月丘町', 'ツキオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市今住町', '35', '35215', '7450063', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '今住町', 'イマズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市住吉町', '35', '35215', '7450064', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '住吉町', 'スミヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市原宿町', '35', '35215', '7450065', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '原宿町', 'ハラジュクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市岡田町', '35', '35215', '7450066', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '岡田町', 'オカダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市岐山通り', '35', '35215', '7450071', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '岐山通り', 'キサンドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市弥生町', '35', '35215', '7450072', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '弥生町', 'ヤヨイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市代々木通り', '35', '35215', '7450073', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '代々木通り', 'ヨヨギドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市今宿町', '35', '35215', '7450074', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '今宿町', 'イマジュクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市緑町', '35', '35215', '7450075', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '緑町', 'ミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市梅園町', '35', '35215', '7450076', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '梅園町', 'ウメゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市須々万奥', '35', '35215', '7450121', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '須々万奥', 'ススマオク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市須々万本郷', '35', '35215', '7450122', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '須々万本郷', 'ススマホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市徳山杉ケ峠', '35', '35215', '7450123', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '徳山', 'トクヤマ', null, null, '杉ケ峠', 'スギガトウゲ');
INSERT INTO `ms_addresses` VALUES ('93410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市莇地', '35', '35215', '7450124', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '莇地', 'アドウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市長穂', '35', '35215', '7450125', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '長穂', 'ナガホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市大向', '35', '35215', '7450241', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '大向', 'オオムカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市大道理', '35', '35215', '7450242', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '大道理', 'オオドウリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市大潮', '35', '35215', '7450301', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '大潮', 'オオシオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市鹿野上', '35', '35215', '7450302', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '鹿野上', 'カノカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市鹿野中', '35', '35215', '7450303', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '鹿野中', 'カノナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市鹿野下', '35', '35215', '7450304', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '鹿野下', 'カノシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市須万', '35', '35215', '7450401', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '須万', 'スマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市金峰', '35', '35215', '7450402', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '金峰', 'ミタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市八代', '35', '35215', '7450501', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '八代', 'ヤシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市中須北', '35', '35215', '7450511', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '中須北', 'ナカズキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市中須南', '35', '35215', '7450512', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '中須南', 'ナカズミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市奥関屋', '35', '35215', '7450611', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '奥関屋', 'オクセキヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市呼坂', '35', '35215', '7450612', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '呼坂', 'ヨビサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市夢ケ丘', '35', '35215', '7450613', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '夢ケ丘', 'ユメガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市御所尾原', '35', '35215', '7450614', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '御所尾原', 'ゴショオバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市勝間ヶ丘', '35', '35215', '7450615', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '勝間ヶ丘', 'カツマガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市緑ケ丘', '35', '35215', '7450616', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '緑ケ丘', 'ミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市勝間原', '35', '35215', '7450617', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '勝間原', 'カツマバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市藤ヶ台', '35', '35215', '7450618', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '藤ヶ台', 'フジガダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市原', '35', '35215', '7450621', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '原', 'ハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市樋口', '35', '35215', '7450622', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '樋口', 'ヒグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市清尾', '35', '35215', '7450623', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '清尾', 'セイノオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市安田', '35', '35215', '7450631', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '安田', 'ヤスダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市鶴見台', '35', '35215', '7450632', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '鶴見台', 'ツルミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市小松原', '35', '35215', '7450641', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '小松原', 'コマツバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市中村', '35', '35215', '7450642', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '中村', 'ナカムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市新清光台', '35', '35215', '7450643', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '新清光台', 'シンセイコウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市大河内', '35', '35215', '7450651', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '大河内', 'オオカワチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市幸ケ丘', '35', '35215', '7450652', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '幸ケ丘', 'サチガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市清光台町', '35', '35215', '7450653', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '清光台町', 'セイコウダイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市自由ケ丘', '35', '35215', '7450654', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '自由ケ丘', 'ジユウガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市呼坂本町', '35', '35215', '7450661', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '呼坂本町', 'ヨビサカホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市高水原', '35', '35215', '7450662', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '高水原', 'タカミズハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市熊毛中央町', '35', '35215', '7450663', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '熊毛中央町', 'クマゲチュウオウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市久米', '35', '35215', '7450801', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '久米', 'クメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市栗屋', '35', '35215', '7450802', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '栗屋', 'クリヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市大島', '35', '35215', '7450803', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '大島', 'オオシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市粭島', '35', '35215', '7450804', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '粭島', 'スクモジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市櫛ケ浜', '35', '35215', '7450805', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '櫛ケ浜', 'クシガハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市桜木', '35', '35215', '7450806', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '桜木', 'サクラギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市城ケ丘', '35', '35215', '7450807', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '城ケ丘', 'ジョウガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市平原町', '35', '35215', '7450808', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '平原町', 'ヒラバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市五月町', '35', '35215', '7450811', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '五月町', 'サツキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市横浜町', '35', '35215', '7450812', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '横浜町', 'ヨコハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市由加町', '35', '35215', '7450813', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '由加町', 'ユカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市鼓海', '35', '35215', '7450814', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '鼓海', 'コカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市宮前町', '35', '35215', '7450815', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '宮前町', 'ミヤマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市遠石', '35', '35215', '7450816', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '遠石', 'トイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市上遠石町', '35', '35215', '7450817', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '上遠石町', 'カミトイシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市曙町', '35', '35215', '7450821', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '曙町', 'アケボノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市孝田町', '35', '35215', '7450822', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '孝田町', 'コウダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市周陽', '35', '35215', '7450823', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '周陽', 'シュウヨウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市大内町', '35', '35215', '7450824', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '大内町', 'オオウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市秋月', '35', '35215', '7450825', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '秋月', 'アキヅキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市江の宮町', '35', '35215', '7450826', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '江の宮町', 'エノミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市瀬戸見町', '35', '35215', '7450827', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '瀬戸見町', 'セトミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市楠木', '35', '35215', '7450831', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '楠木', 'クスノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市扇町', '35', '35215', '7450832', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '扇町', 'オウギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市泉原町', '35', '35215', '7450833', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '泉原町', 'イズミバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市清水町', '35', '35215', '7450834', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '清水町', 'シミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市舞車町', '35', '35215', '7450835', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '舞車町', 'マイグルマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市慶万町', '35', '35215', '7450836', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '慶万町', 'ケイマンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市譲羽', '35', '35215', '7450837', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '譲羽', 'ユズリハ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市若草町', '35', '35215', '7450841', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '若草町', 'ワカクサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市青山町', '35', '35215', '7450842', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '青山町', 'アオヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市新宮町', '35', '35215', '7450843', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '新宮町', 'シングウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市速玉町', '35', '35215', '7450844', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '速玉町', 'ハヤタマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市河東町', '35', '35215', '7450845', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '河東町', 'カワヒガシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市東山町', '35', '35215', '7450846', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '東山町', 'ヒガシヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市松保町', '35', '35215', '7450847', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '松保町', 'マツホチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市徳山', '35', '35215', '7450851', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '徳山', 'トクヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市川曲', '35', '35215', '7450852', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '川曲', 'カワマガリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市上村', '35', '35215', '7450853', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '上村', 'ジョウソン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市中野', '35', '35215', '7450854', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '中野', 'ナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市川上', '35', '35215', '7450855', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '川上', 'カワカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市浦山', '35', '35215', '7450856', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '浦山', 'ウラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市浦山開作', '35', '35215', '7450857', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '浦山開作', 'ウラヤマカイサク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市花陽', '35', '35215', '7450858', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '花陽', 'カヨウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市新地', '35', '35215', '7450861', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '新地', 'シンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市江口', '35', '35215', '7450862', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '江口', 'エグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市御山町', '35', '35215', '7450863', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '御山町', 'ミヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市北山', '35', '35215', '7450864', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '北山', 'キタヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市蓮ケ浴', '35', '35215', '7450865', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '蓮ケ浴', 'ハスガエキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市土越', '35', '35215', '7450866', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '土越', 'ヒジコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市新堀', '35', '35215', '7450867', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '新堀', 'シンボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市南浦山町', '35', '35215', '7450868', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '南浦山町', 'ミナミウラヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市御弓町', '35', '35215', '7450871', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '御弓町', 'オユミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市一番町', '35', '35215', '7450872', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '一番町', 'イチバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市三田川', '35', '35215', '7450873', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '三田川', 'ミタガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市公園区', '35', '35215', '7450874', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '公園区', 'コウエンク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市西金剛山', '35', '35215', '7450875', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '西金剛山', 'ニシコンゴウザン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市中金剛山', '35', '35215', '7450876', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '中金剛山', 'ナカコンゴウザン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市東金剛山', '35', '35215', '7450877', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '東金剛山', 'ヒガシコンゴウザン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市幸の台', '35', '35215', '7450878', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '幸の台', 'コウノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市東辻', '35', '35215', '7450881', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '東辻', 'ヒガシツジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市一の井手', '35', '35215', '7450882', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '一の井手', 'イチノイデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市栄谷', '35', '35215', '7450883', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '栄谷', 'サカエダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市二の井手', '35', '35215', '7450884', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '二の井手', 'ニノイデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市高尾団地', '35', '35215', '7450885', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '高尾団地', 'タカオダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市黒岩町', '35', '35215', '7450886', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '黒岩町', 'クロイワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市馬屋', '35', '35215', '7450887', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '馬屋', 'ウマヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市戸田', '35', '35215', '7451131', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '戸田', 'ヘタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市湯野', '35', '35215', '7451132', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '湯野', 'ユノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市川崎', '35', '35215', '7460001', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '川崎', 'カワサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市西千代田町', '35', '35215', '7460002', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '西千代田町', 'ニシチヨダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市道源町', '35', '35215', '7460003', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '道源町', 'ドウゲンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市三笹町', '35', '35215', '7460004', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '三笹町', 'ミササチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市渚町', '35', '35215', '7460005', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '渚町', 'ナギサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市開成町', '35', '35215', '7460006', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '開成町', 'カイセイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市竹島町', '35', '35215', '7460007', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '竹島町', 'タケシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市椎木町', '35', '35215', '7460008', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '椎木町', 'シイギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市川手', '35', '35215', '7460009', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '川手', 'カワテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市土井', '35', '35215', '7460011', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '土井', 'ドイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市政所', '35', '35215', '7460012', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '政所', 'マドコロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市桶川町', '35', '35215', '7460013', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '桶川町', 'オケガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市古川町', '35', '35215', '7460014', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '古川町', 'フルカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市清水', '35', '35215', '7460015', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '清水', 'シミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市中央町', '35', '35215', '7460016', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '中央町', 'チュウオウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市宮の前', '35', '35215', '7460017', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '宮の前', 'ミヤノマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市大神', '35', '35215', '7460018', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '大神', 'ダイジン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市臨海町', '35', '35215', '7460019', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '臨海町', 'リンカイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市花園町', '35', '35215', '7460021', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '花園町', 'ハナゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市野村', '35', '35215', '7460022', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '野村', 'ノムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市野村南町', '35', '35215', '7460023', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '野村南町', 'ノムラミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市古泉', '35', '35215', '7460024', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '古泉', 'コイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市古市', '35', '35215', '7460025', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '古市', 'フルイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市浜田', '35', '35215', '7460026', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '浜田', 'ハマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市小川屋町', '35', '35215', '7460027', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '小川屋町', 'オガワヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市港町', '35', '35215', '7460028', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '港町', 'ミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市平野', '35', '35215', '7460029', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '平野', 'ヒラノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市坂根町', '35', '35215', '7460031', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '坂根町', 'サカネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市河内町', '35', '35215', '7460032', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '河内町', 'コウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市新堤町', '35', '35215', '7460033', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '新堤町', 'シンヅツミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市富田', '35', '35215', '7460034', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '富田', 'トンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市日地町', '35', '35215', '7460035', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '日地町', 'ヒジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市温田', '35', '35215', '7460036', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '温田', 'オンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市丸山町', '35', '35215', '7460037', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '丸山町', 'マルヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市福川', '35', '35215', '7460038', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '福川', 'フクガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市社地町', '35', '35215', '7460041', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '社地町', 'シャチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市福川南町', '35', '35215', '7460042', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '福川南町', 'フクガワミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市新田', '35', '35215', '7460043', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '新田', 'シンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市西桝町', '35', '35215', '7460044', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '西桝町', 'ニシマスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市新地町', '35', '35215', '7460045', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '新地町', 'シンチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市御姫町', '35', '35215', '7460051', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '御姫町', 'オヒメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市中畷町', '35', '35215', '7460052', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '中畷町', 'ナカナワテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市室尾', '35', '35215', '7460053', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '室尾', 'ムロオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市長田町', '35', '35215', '7460054', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '長田町', 'ナガタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市かせ河原町', '35', '35215', '7460055', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', 'かせ河原町', 'カセガワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市羽島', '35', '35215', '7460056', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '羽島', 'ハジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市皿山町', '35', '35215', '7460061', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '皿山町', 'サラヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市福川中市町', '35', '35215', '7460062', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '福川中市町', 'フクガワナカイチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市本陣町', '35', '35215', '7460063', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '本陣町', 'ホンジンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市若山', '35', '35215', '7460064', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '若山', 'ワカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市上迫町', '35', '35215', '7460065', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '上迫町', 'カミサコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市四熊', '35', '35215', '7460081', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '四熊', 'シクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市下上', '35', '35215', '7460082', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '下上', 'シモカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市小畑', '35', '35215', '7460083', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '小畑', 'オバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市夜市', '35', '35215', '7460084', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '夜市', 'ヤジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市高瀬', '35', '35215', '7460101', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '高瀬', 'タカセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市夏切', '35', '35215', '7460102', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '夏切', 'ナツキリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市垰', '35', '35215', '7460103', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '垰', 'タオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市米光', '35', '35215', '7460104', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '米光', 'ヨネミツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市馬神', '35', '35215', '7460105', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '馬神', 'ウマガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県防府市', '35', '35206', '7470000', '山口県', 'ヤマグチケン', '防府市', 'ホウフシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('93597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県防府市岩畠', '35', '35206', '7470001', '山口県', 'ヤマグチケン', '防府市', 'ホウフシ', '岩畠', 'イワバタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県防府市酢貝', '35', '35206', '7470002', '山口県', 'ヤマグチケン', '防府市', 'ホウフシ', '酢貝', 'スガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県防府市牟礼柳', '35', '35206', '7470003', '山口県', 'ヤマグチケン', '防府市', 'ホウフシ', '牟礼柳', 'ムレヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県防府市牟礼', '35', '35206', '7470004', '山口県', 'ヤマグチケン', '防府市', 'ホウフシ', '牟礼', 'ムレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県防府市中西', '35', '35206', '7470005', '山口県', 'ヤマグチケン', '防府市', 'ホウフシ', '中西', 'ナカニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県防府市敷山町', '35', '35206', '7470006', '山口県', 'ヤマグチケン', '防府市', 'ホウフシ', '敷山町', 'シキヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県防府市岸津', '35', '35206', '7470011', '山口県', 'ヤマグチケン', '防府市', 'ホウフシ', '岸津', 'キシヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県防府市牟礼今宿', '35', '35206', '7470012', '山口県', 'ヤマグチケン', '防府市', 'ホウフシ', '牟礼今宿', 'ムレイマジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県防府市沖今宿', '35', '35206', '7470013', '山口県', 'ヤマグチケン', '防府市', 'ホウフシ', '沖今宿', 'オキイマジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県防府市江泊', '35', '35206', '7470014', '山口県', 'ヤマグチケン', '防府市', 'ホウフシ', '江泊', 'エドマリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県防府市国分寺町', '35', '35206', '7470021', '山口県', 'ヤマグチケン', '防府市', 'ホウフシ', '国分寺町', 'コクブンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県防府市惣社町', '35', '35206', '7470022', '山口県', 'ヤマグチケン', '防府市', 'ホウフシ', '惣社町', 'ソウシャチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県防府市多々良', '35', '35206', '7470023', '山口県', 'ヤマグチケン', '防府市', 'ホウフシ', '多々良', 'タタラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県防府市国衙', '35', '35206', '7470024', '山口県', 'ヤマグチケン', '防府市', 'ホウフシ', '国衙', 'コクガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県防府市美和町', '35', '35206', '7470025', '山口県', 'ヤマグチケン', '防府市', 'ホウフシ', '美和町', 'ミワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県防府市緑町', '35', '35206', '7470026', '山口県', 'ヤマグチケン', '防府市', 'ホウフシ', '緑町', 'ミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県防府市南松崎町', '35', '35206', '7470027', '山口県', 'ヤマグチケン', '防府市', 'ホウフシ', '南松崎町', 'ミナミマツザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県防府市東松崎町', '35', '35206', '7470028', '山口県', 'ヤマグチケン', '防府市', 'ホウフシ', '東松崎町', 'ヒガシマツザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県防府市松崎町', '35', '35206', '7470029', '山口県', 'ヤマグチケン', '防府市', 'ホウフシ', '松崎町', 'マツザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県防府市迫戸町', '35', '35206', '7470031', '山口県', 'ヤマグチケン', '防府市', 'ホウフシ', '迫戸町', 'セバトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県防府市宮市町', '35', '35206', '7470032', '山口県', 'ヤマグチケン', '防府市', 'ホウフシ', '宮市町', 'ミヤチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県防府市上天神町', '35', '35206', '7470033', '山口県', 'ヤマグチケン', '防府市', 'ホウフシ', '上天神町', 'カミテンジンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県防府市天神', '35', '35206', '7470034', '山口県', 'ヤマグチケン', '防府市', 'ホウフシ', '天神', 'テンジン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県防府市栄町', '35', '35206', '7470035', '山口県', 'ヤマグチケン', '防府市', 'ホウフシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県防府市戎町', '35', '35206', '7470036', '山口県', 'ヤマグチケン', '防府市', 'ホウフシ', '戎町', 'エビスマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県防府市八王子', '35', '35206', '7470037', '山口県', 'ヤマグチケン', '防府市', 'ホウフシ', '八王子', 'ハチオウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県防府市本橋町', '35', '35206', '7470041', '山口県', 'ヤマグチケン', '防府市', 'ホウフシ', '本橋町', 'モトバシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県防府市今市町', '35', '35206', '7470042', '山口県', 'ヤマグチケン', '防府市', 'ホウフシ', '今市町', 'イマイチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県防府市平和町', '35', '35206', '7470043', '山口県', 'ヤマグチケン', '防府市', 'ホウフシ', '平和町', 'ヘイワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県防府市佐波', '35', '35206', '7470044', '山口県', 'ヤマグチケン', '防府市', 'ホウフシ', '佐波', 'サバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県防府市高倉', '35', '35206', '7470045', '山口県', 'ヤマグチケン', '防府市', 'ホウフシ', '高倉', 'タカクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県防府市千日', '35', '35206', '7470046', '山口県', 'ヤマグチケン', '防府市', 'ホウフシ', '千日', 'センニチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県防府市新橋町', '35', '35206', '7470047', '山口県', 'ヤマグチケン', '防府市', 'ホウフシ', '新橋町', 'シンバシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県防府市泉町', '35', '35206', '7470051', '山口県', 'ヤマグチケン', '防府市', 'ホウフシ', '泉町', 'イズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県防府市開出', '35', '35206', '7470052', '山口県', 'ヤマグチケン', '防府市', 'ホウフシ', '開出', 'カイデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県防府市開出本町', '35', '35206', '7470053', '山口県', 'ヤマグチケン', '防府市', 'ホウフシ', '開出本町', 'カイデホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県防府市開出西町', '35', '35206', '7470054', '山口県', 'ヤマグチケン', '防府市', 'ホウフシ', '開出西町', 'カイデニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県防府市中泉町', '35', '35206', '7470055', '山口県', 'ヤマグチケン', '防府市', 'ホウフシ', '中泉町', 'ナカイズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県防府市古祖原', '35', '35206', '7470056', '山口県', 'ヤマグチケン', '防府市', 'ホウフシ', '古祖原', 'コソバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県防府市東佐波令', '35', '35206', '7470061', '山口県', 'ヤマグチケン', '防府市', 'ホウフシ', '東佐波令', 'ヒガシサバリョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県防府市上右田', '35', '35206', '7470062', '山口県', 'ヤマグチケン', '防府市', 'ホウフシ', '上右田', 'カミミギタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県防府市下右田', '35', '35206', '7470063', '山口県', 'ヤマグチケン', '防府市', 'ホウフシ', '下右田', 'シモミギタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県防府市高井', '35', '35206', '7470064', '山口県', 'ヤマグチケン', '防府市', 'ホウフシ', '高井', 'タカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県防府市大崎', '35', '35206', '7470065', '山口県', 'ヤマグチケン', '防府市', 'ホウフシ', '大崎', 'オオサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県防府市自由ケ丘', '35', '35206', '7470066', '山口県', 'ヤマグチケン', '防府市', 'ホウフシ', '自由ケ丘', 'ジユウガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県防府市佐野', '35', '35206', '7470067', '山口県', 'ヤマグチケン', '防府市', 'ホウフシ', '佐野', 'サノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県防府市奥畑', '35', '35206', '7470101', '山口県', 'ヤマグチケン', '防府市', 'ホウフシ', '奥畑', 'オクハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県防府市久兼', '35', '35206', '7470102', '山口県', 'ヤマグチケン', '防府市', 'ホウフシ', '久兼', 'ヒサカネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県防府市和字', '35', '35206', '7470103', '山口県', 'ヤマグチケン', '防府市', 'ホウフシ', '和字', 'ワジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県防府市真尾', '35', '35206', '7470104', '山口県', 'ヤマグチケン', '防府市', 'ホウフシ', '真尾', 'マナオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県防府市鈴屋', '35', '35206', '7470105', '山口県', 'ヤマグチケン', '防府市', 'ホウフシ', '鈴屋', 'スズヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県防府市奈美', '35', '35206', '7470106', '山口県', 'ヤマグチケン', '防府市', 'ホウフシ', '奈美', 'ナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県防府市中山', '35', '35206', '7470107', '山口県', 'ヤマグチケン', '防府市', 'ホウフシ', '中山', 'ナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市徳地堀', '35', '35203', '7470231', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '徳地堀', 'トクヂホリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市徳地伊賀地', '35', '35203', '7470232', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '徳地伊賀地', 'トクヂイカジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市徳地岸見', '35', '35203', '7470233', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '徳地岸見', 'トクヂキシミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市徳地小古祖', '35', '35203', '7470234', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '徳地小古祖', 'トクヂオゴソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市徳地深谷', '35', '35203', '7470235', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '徳地深谷', 'トクヂフカダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市徳地引谷', '35', '35203', '7470341', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '徳地引谷', 'トクヂヒクタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市徳地船路', '35', '35203', '7470342', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '徳地船路', 'トクヂフナジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市徳地三谷', '35', '35203', '7470343', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '徳地三谷', 'トクヂミタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市徳地八坂', '35', '35203', '7470344', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '徳地八坂', 'トクヂヤサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市徳地野谷', '35', '35203', '7470401', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '徳地野谷', 'トクヂノタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市徳地柚木', '35', '35203', '7470402', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '徳地柚木', 'トクヂユノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市徳地山畑', '35', '35203', '7470521', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '徳地山畑', 'トクヂヤマハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市徳地島地', '35', '35203', '7470522', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '徳地島地', 'トクヂシマジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市徳地上村', '35', '35203', '7470523', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '徳地上村', 'トクヂカミムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市徳地藤木', '35', '35203', '7470524', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '徳地藤木', 'トクヂフジキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市徳地鯖河内', '35', '35203', '7470611', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '徳地鯖河内', 'トクヂサバゴウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市徳地串', '35', '35203', '7470612', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '徳地串', 'トクヂクシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県周南市巣山', '35', '35215', '7470621', '山口県', 'ヤマグチケン', '周南市', 'シュウナンシ', '巣山', 'スヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県防府市駅南町', '35', '35206', '7470801', '山口県', 'ヤマグチケン', '防府市', 'ホウフシ', '駅南町', 'エキミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県防府市中央町', '35', '35206', '7470802', '山口県', 'ヤマグチケン', '防府市', 'ホウフシ', '中央町', 'チュウオウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県防府市岡村町', '35', '35206', '7470803', '山口県', 'ヤマグチケン', '防府市', 'ホウフシ', '岡村町', 'オカムラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県防府市松原町', '35', '35206', '7470804', '山口県', 'ヤマグチケン', '防府市', 'ホウフシ', '松原町', 'マツバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県防府市鞠生町', '35', '35206', '7470805', '山口県', 'ヤマグチケン', '防府市', 'ホウフシ', '鞠生町', 'マリフチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県防府市石が口', '35', '35206', '7470806', '山口県', 'ヤマグチケン', '防府市', 'ホウフシ', '石が口', 'イシガグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県防府市桑南', '35', '35206', '7470807', '山口県', 'ヤマグチケン', '防府市', 'ホウフシ', '桑南', 'ソウナン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県防府市桑山', '35', '35206', '7470808', '山口県', 'ヤマグチケン', '防府市', 'ホウフシ', '桑山', 'クワノヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県防府市寿町', '35', '35206', '7470809', '山口県', 'ヤマグチケン', '防府市', 'ホウフシ', '寿町', 'コトブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県防府市車塚町', '35', '35206', '7470811', '山口県', 'ヤマグチケン', '防府市', 'ホウフシ', '車塚町', 'クルマヅカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県防府市鋳物師町', '35', '35206', '7470812', '山口県', 'ヤマグチケン', '防府市', 'ホウフシ', '鋳物師町', 'イモジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県防府市東三田尻', '35', '35206', '7470813', '山口県', 'ヤマグチケン', '防府市', 'ホウフシ', '東三田尻', 'ヒガシミタジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県防府市三田尻', '35', '35206', '7470814', '山口県', 'ヤマグチケン', '防府市', 'ホウフシ', '三田尻', 'ミタジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県防府市協和町', '35', '35206', '7470815', '山口県', 'ヤマグチケン', '防府市', 'ホウフシ', '協和町', 'キョウワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県防府市華浦', '35', '35206', '7470816', '山口県', 'ヤマグチケン', '防府市', 'ホウフシ', '華浦', 'カホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県防府市自力町', '35', '35206', '7470817', '山口県', 'ヤマグチケン', '防府市', 'ホウフシ', '自力町', 'ジリキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県防府市三田尻本町', '35', '35206', '7470818', '山口県', 'ヤマグチケン', '防府市', 'ホウフシ', '三田尻本町', 'ミタジリホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県防府市お茶屋町', '35', '35206', '7470819', '山口県', 'ヤマグチケン', '防府市', 'ホウフシ', 'お茶屋町', 'オチャヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県防府市警固町', '35', '35206', '7470821', '山口県', 'ヤマグチケン', '防府市', 'ホウフシ', '警固町', 'ケイゴマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県防府市勝間', '35', '35206', '7470822', '山口県', 'ヤマグチケン', '防府市', 'ホウフシ', '勝間', 'カツマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県防府市鐘紡町', '35', '35206', '7470823', '山口県', 'ヤマグチケン', '防府市', 'ホウフシ', '鐘紡町', 'カネボウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県防府市新築地町', '35', '35206', '7470824', '山口県', 'ヤマグチケン', '防府市', 'ホウフシ', '新築地町', 'シンツキジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県防府市新田', '35', '35206', '7470825', '山口県', 'ヤマグチケン', '防府市', 'ホウフシ', '新田', 'シンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県防府市向島', '35', '35206', '7470831', '山口県', 'ヤマグチケン', '防府市', 'ホウフシ', '向島', 'ムコウシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県防府市野島', '35', '35206', '7470832', '山口県', 'ヤマグチケン', '防府市', 'ホウフシ', '野島', 'ノシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県防府市浜方', '35', '35206', '7470833', '山口県', 'ヤマグチケン', '防府市', 'ホウフシ', '浜方', 'ハマカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県防府市田島', '35', '35206', '7470834', '山口県', 'ヤマグチケン', '防府市', 'ホウフシ', '田島', 'タジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県防府市西浦', '35', '35206', '7470835', '山口県', 'ヤマグチケン', '防府市', 'ホウフシ', '西浦', 'ニシノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県防府市植松', '35', '35206', '7470836', '山口県', 'ヤマグチケン', '防府市', 'ホウフシ', '植松', 'ウエマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県防府市仁井令町', '35', '35206', '7470841', '山口県', 'ヤマグチケン', '防府市', 'ホウフシ', '仁井令町', 'ニイリョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県防府市清水町', '35', '35206', '7470842', '山口県', 'ヤマグチケン', '防府市', 'ホウフシ', '清水町', 'シミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県防府市東仁井令町', '35', '35206', '7470843', '山口県', 'ヤマグチケン', '防府市', 'ホウフシ', '東仁井令町', 'ヒガシニイリョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県防府市華園町', '35', '35206', '7470844', '山口県', 'ヤマグチケン', '防府市', 'ホウフシ', '華園町', 'ハナゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県防府市仁井令', '35', '35206', '7470845', '山口県', 'ヤマグチケン', '防府市', 'ホウフシ', '仁井令', 'ニイリョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県防府市伊佐江', '35', '35206', '7470846', '山口県', 'ヤマグチケン', '防府市', 'ホウフシ', '伊佐江', 'イサエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県防府市伊佐江町', '35', '35206', '7470847', '山口県', 'ヤマグチケン', '防府市', 'ホウフシ', '伊佐江町', 'イサエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県防府市華城中央', '35', '35206', '7470848', '山口県', 'ヤマグチケン', '防府市', 'ホウフシ', '華城中央', 'ハナギチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県防府市西仁井令', '35', '35206', '7470849', '山口県', 'ヤマグチケン', '防府市', 'ホウフシ', '西仁井令', 'ニシニイリョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県防府市富海', '35', '35206', '7471111', '山口県', 'ヤマグチケン', '防府市', 'ホウフシ', '富海', 'トノミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市鋳銭司', '35', '35203', '7471221', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '鋳銭司', 'スゼンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県防府市切畑', '35', '35206', '7471231', '山口県', 'ヤマグチケン', '防府市', 'ホウフシ', '切畑', 'キリハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県防府市台道', '35', '35206', '7471232', '山口県', 'ヤマグチケン', '防府市', 'ホウフシ', '台道', 'ダイドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県柳井市神代', '35', '35212', '7490101', '山口県', 'ヤマグチケン', '柳井市', 'ヤナイシ', '神代', 'コウジロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県柳井市大畠', '35', '35212', '7490102', '山口県', 'ヤマグチケン', '柳井市', 'ヤナイシ', '大畠', 'オオバタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県柳井市遠崎', '35', '35212', '7490103', '山口県', 'ヤマグチケン', '柳井市', 'ヤナイシ', '遠崎', 'トオザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道芦別市', '01', '01216', '0750000', '北海道', 'ホッカイドウ', '芦別市', 'アシベツシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('93731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市', '35', '35201', '7500000', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('93732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市幸町', '35', '35201', '7500001', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '幸町', 'サイワイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市宮田町', '35', '35201', '7500002', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '宮田町', 'ミヤダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市阿弥陀寺町', '35', '35201', '7500003', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '阿弥陀寺町', 'アミダイジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市中之町', '35', '35201', '7500004', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '中之町', 'ナカノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市唐戸町', '35', '35201', '7500005', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '唐戸町', 'カラトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市南部町', '35', '35201', '7500006', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '南部町', 'ナベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市赤間町', '35', '35201', '7500007', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '赤間町', 'アカマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市田中町', '35', '35201', '7500008', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '田中町', 'タナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市上田中町', '35', '35201', '7500009', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '上田中町', 'カミタナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道芦別市北1条西', '01', '01216', '0750001', '北海道', 'ホッカイドウ', '芦別市', 'アシベツシ', '北1条西', 'キタ01ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市名池町', '35', '35201', '7500011', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '名池町', 'メイチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市観音崎町', '35', '35201', '7500012', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '観音崎町', 'カンノンザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市入江町', '35', '35201', '7500013', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '入江町', 'イリエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市岬之町', '35', '35201', '7500014', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '岬之町', 'ハナノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市西入江町', '35', '35201', '7500015', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '西入江町', 'ニシイリエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市細江町', '35', '35201', '7500016', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '細江町', 'ホソエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市細江新町', '35', '35201', '7500017', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '細江新町', 'ホソエシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市豊前田町', '35', '35201', '7500018', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '豊前田町', 'ブゼンダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市丸山町', '35', '35201', '7500019', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '丸山町', 'マルヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道芦別市北2条西', '01', '01216', '0750002', '北海道', 'ホッカイドウ', '芦別市', 'アシベツシ', '北2条西', 'キタ02ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市長崎中央町', '35', '35201', '7500021', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '長崎中央町', 'ナガサキチュウオウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市関西本町', '35', '35201', '7500022', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '関西本町', 'カンセイホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市長崎新町', '35', '35201', '7500023', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '長崎新町', 'ナガサキシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市笹山町', '35', '35201', '7500024', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '笹山町', 'ササヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市竹崎町', '35', '35201', '7500025', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '竹崎町', 'タケザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市長門町', '35', '35201', '7500026', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '長門町', 'ナガトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市上条町', '35', '35201', '7500027', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '上条町', 'ウエジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市長崎本町', '35', '35201', '7500028', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '長崎本町', 'ナガサキホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市長崎町', '35', '35201', '7500029', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '長崎町', 'ナガサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道芦別市北3条西', '01', '01216', '0750003', '北海道', 'ホッカイドウ', '芦別市', 'アシベツシ', '北3条西', 'キタ03ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市春日町', '35', '35201', '7500031', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '春日町', 'カスガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市関西町', '35', '35201', '7500032', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '関西町', 'カンセイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市山手町', '35', '35201', '7500033', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '山手町', 'ヤマテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市西神田町', '35', '35201', '7500034', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '西神田町', 'ニシカンダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市桜山町', '35', '35201', '7500035', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '桜山町', 'サクラヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市あるかぽーと', '35', '35201', '7500036', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', 'あるかぽーと', 'アルカポート', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道芦別市北4条西', '01', '01216', '0750004', '北海道', 'ホッカイドウ', '芦別市', 'アシベツシ', '北4条西', 'キタ04ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市向洋町', '35', '35201', '7500041', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '向洋町', 'コウヨウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市中央町', '35', '35201', '7500042', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '中央町', 'チュウオウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市東神田町', '35', '35201', '7500043', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '東神田町', 'ヒガシカンダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市神田町', '35', '35201', '7500044', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '神田町', 'カンダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市元町', '35', '35201', '7500045', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '元町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市羽山町', '35', '35201', '7500046', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '羽山町', 'ハヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市向山町', '35', '35201', '7500047', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '向山町', 'ムカイヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市東向山町', '35', '35201', '7500048', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '東向山町', 'ヒガシムカイヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市栄町', '35', '35201', '7500049', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道芦別市北5条西', '01', '01216', '0750005', '北海道', 'ホッカイドウ', '芦別市', 'アシベツシ', '北5条西', 'キタ05ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市大坪本町', '35', '35201', '7500051', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '大坪本町', 'オオツボホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市藤附町', '35', '35201', '7500052', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '藤附町', 'フジツクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市大平町', '35', '35201', '7500053', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '大平町', 'タイヘイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市西大坪町', '35', '35201', '7500054', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '西大坪町', 'ニシオオツボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市南大坪町', '35', '35201', '7500055', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '南大坪町', 'ミナミオオツボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市筋ケ浜町', '35', '35201', '7500056', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '筋ケ浜町', 'スジガハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市筋川町', '35', '35201', '7500057', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '筋川町', 'スジカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市金比羅町', '35', '35201', '7500058', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '金比羅町', 'コンピラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市汐入町', '35', '35201', '7500059', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '汐入町', 'シオイリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道芦別市北6条西', '01', '01216', '0750006', '北海道', 'ホッカイドウ', '芦別市', 'アシベツシ', '北6条西', 'キタ06ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市上新地町', '35', '35201', '7500061', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '上新地町', 'カミシンチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市新地西町', '35', '35201', '7500062', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '新地西町', 'シンチニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市新地町', '35', '35201', '7500063', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '新地町', 'シンチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市今浦町', '35', '35201', '7500064', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '今浦町', 'イマウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市伊崎町', '35', '35201', '7500065', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '伊崎町', 'イザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市東大和町', '35', '35201', '7500066', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '東大和町', 'ヒガシヤマトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市大和町', '35', '35201', '7500067', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '大和町', 'ヤマトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道芦別市北7条西', '01', '01216', '0750007', '北海道', 'ホッカイドウ', '芦別市', 'アシベツシ', '北7条西', 'キタ07ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市彦島海士郷町', '35', '35201', '7500071', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '彦島海士郷町', 'ヒコシマアマノゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市彦島老町', '35', '35201', '7500072', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '彦島老町', 'ヒコシマオイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市彦島老の山公園', '35', '35201', '7500073', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '彦島老の山公園', 'ヒコシマオイノヤマコウエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市彦島本村町', '35', '35201', '7500074', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '彦島本村町', 'ヒコシマホンムラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市彦島江の浦町', '35', '35201', '7500075', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '彦島江の浦町', 'ヒコシマエノウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市彦島弟子待町', '35', '35201', '7500076', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '彦島弟子待町', 'ヒコシマデシマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市彦島弟子待東町', '35', '35201', '7500077', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '彦島弟子待東町', 'ヒコシマデシマツヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市彦島杉田町', '35', '35201', '7500078', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '彦島杉田町', 'ヒコシマスギタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市彦島角倉町', '35', '35201', '7500081', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '彦島角倉町', 'ヒコシマスマクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市彦島山中町', '35', '35201', '7500082', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '彦島山中町', 'ヒコシマヤマナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市彦島桜ケ丘町', '35', '35201', '7500083', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '彦島桜ケ丘町', 'ヒコシマサクラガオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市彦島向井町', '35', '35201', '7500084', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '彦島向井町', 'ヒコシマムカイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市彦島田の首町', '35', '35201', '7500085', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '彦島田の首町', 'ヒコシマタノクビチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市彦島塩浜町', '35', '35201', '7500086', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '彦島塩浜町', 'ヒコシマシオハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市彦島福浦町', '35', '35201', '7500087', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '彦島福浦町', 'ヒコシマフクウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市彦島緑町', '35', '35201', '7500091', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '彦島緑町', 'ヒコシマミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市彦島迫町', '35', '35201', '7500092', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '彦島迫町', 'ヒコシマサコマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市彦島西山町', '35', '35201', '7500093', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '彦島西山町', 'ヒコシマニシヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市彦島竹ノ子島町', '35', '35201', '7500094', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '彦島竹ノ子島町', 'ヒコシマタケノコジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市六連島', '35', '35201', '7500095', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '六連島', 'ムツレジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道芦別市北1条東', '01', '01216', '0750011', '北海道', 'ホッカイドウ', '芦別市', 'アシベツシ', '北1条東', 'キタ01ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道芦別市北2条東', '01', '01216', '0750012', '北海道', 'ホッカイドウ', '芦別市', 'アシベツシ', '北2条東', 'キタ02ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道芦別市北3条東', '01', '01216', '0750013', '北海道', 'ホッカイドウ', '芦別市', 'アシベツシ', '北3条東', 'キタ03ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道芦別市北4条東', '01', '01216', '0750014', '北海道', 'ホッカイドウ', '芦別市', 'アシベツシ', '北4条東', 'キタ04ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道芦別市北5条東', '01', '01216', '0750015', '北海道', 'ホッカイドウ', '芦別市', 'アシベツシ', '北5条東', 'キタ05ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道芦別市北6条東', '01', '01216', '0750016', '北海道', 'ホッカイドウ', '芦別市', 'アシベツシ', '北6条東', 'キタ06ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道芦別市福住町', '01', '01216', '0750017', '北海道', 'ホッカイドウ', '芦別市', 'アシベツシ', '福住町', 'フクズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道芦別市常磐町', '01', '01216', '0750018', '北海道', 'ホッカイドウ', '芦別市', 'アシベツシ', '常磐町', 'トキワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道芦別市高根町', '01', '01216', '0750019', '北海道', 'ホッカイドウ', '芦別市', 'アシベツシ', '高根町', 'タカネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道芦別市南1条西', '01', '01216', '0750021', '北海道', 'ホッカイドウ', '芦別市', 'アシベツシ', '南1条西', 'ミナミ01ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市植田', '35', '35201', '7500251', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '植田', 'ウエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市内日上', '35', '35201', '7500252', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '内日上', 'ウツイカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市内日下', '35', '35201', '7500253', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '内日下', 'ウツイシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市菊川町西中山', '35', '35201', '7500301', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '菊川町西中山', 'キクガワチョウニシナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市菊川町東中山', '35', '35201', '7500302', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '菊川町東中山', 'キクガワチョウヒガシナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市菊川町樅ノ木', '35', '35201', '7500303', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '菊川町樅ノ木', 'キクガワチョウモミノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市菊川町道市', '35', '35201', '7500304', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '菊川町道市', 'キクガワチョウミチイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市菊川町轡井', '35', '35201', '7500305', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '菊川町轡井', 'キクガワチョウクツワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市菊川町下保木', '35', '35201', '7500306', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '菊川町下保木', 'キクガワチョウシモホキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市菊川町上保木', '35', '35201', '7500307', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '菊川町上保木', 'キクガワチョウカミホキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道芦別市南1条東', '01', '01216', '0750031', '北海道', 'ホッカイドウ', '芦別市', 'アシベツシ', '南1条東', 'ミナミ01ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市菊川町上大野', '35', '35201', '7500311', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '菊川町上大野', 'キクガワチョウカミオオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市菊川町下大野', '35', '35201', '7500312', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '菊川町下大野', 'キクガワチョウシモオオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市菊川町田部', '35', '35201', '7500313', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '菊川町田部', 'キクガワチョウタベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市菊川町上田部', '35', '35201', '7500314', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '菊川町上田部', 'キクガワチョウカミタベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市菊川町七見', '35', '35201', '7500315', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '菊川町七見', 'キクガワチョウナナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市菊川町吉賀', '35', '35201', '7500316', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '菊川町吉賀', 'キクガワチョウヨシカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市菊川町下岡枝', '35', '35201', '7500317', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '菊川町下岡枝', 'キクガワチョウシモオカエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道芦別市南2条東', '01', '01216', '0750032', '北海道', 'ホッカイドウ', '芦別市', 'アシベツシ', '南2条東', 'ミナミ02ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市菊川町上岡枝', '35', '35201', '7500321', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '菊川町上岡枝', 'キクガワチョウカミオカエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市菊川町楢崎', '35', '35201', '7500322', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '菊川町楢崎', 'キクガワチョウナラザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市菊川町日新', '35', '35201', '7500323', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '菊川町日新', 'キクガワチョウニッシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市菊川町久野', '35', '35201', '7500324', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '菊川町久野', 'キクガワチョウクノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市菊川町貴飯', '35', '35201', '7500325', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '菊川町貴飯', 'キクガワチョウキバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道芦別市南3条東', '01', '01216', '0750033', '北海道', 'ホッカイドウ', '芦別市', 'アシベツシ', '南3条東', 'ミナミ03ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道芦別市幌内', '01', '01216', '0750034', '北海道', 'ホッカイドウ', '芦別市', 'アシベツシ', '幌内', 'ホロナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道芦別市旭町油谷', '01', '01216', '0750035', '北海道', 'ホッカイドウ', '芦別市', 'アシベツシ', '旭町油谷', 'アサヒマチユヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道芦別市旭町', '01', '01216', '0750036', '北海道', 'ホッカイドウ', '芦別市', 'アシベツシ', '旭町', 'アサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市豊田町殿居', '35', '35201', '7500401', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '豊田町殿居', 'トヨタチョウトノイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市豊田町佐野', '35', '35201', '7500402', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '豊田町佐野', 'トヨタチョウサノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市豊田町一ノ俣', '35', '35201', '7500403', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '豊田町一ノ俣', 'トヨタチョウイチノマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市豊田町荒木', '35', '35201', '7500404', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '豊田町荒木', 'トヨタチョウアラキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市豊田町杢路子', '35', '35201', '7500405', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '豊田町杢路子', 'トヨタチョウムクロウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道芦別市本町', '01', '01216', '0750041', '北海道', 'ホッカイドウ', '芦別市', 'アシベツシ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市豊田町宇内', '35', '35201', '7500411', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '豊田町宇内', 'トヨタチョウウナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市豊田町稲見', '35', '35201', '7500412', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '豊田町稲見', 'トヨタチョウイナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市豊田町金道', '35', '35201', '7500413', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '豊田町金道', 'トヨタチョウキンドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市豊田町八道', '35', '35201', '7500414', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '豊田町八道', 'トヨタチョウヤジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市豊田町浮石', '35', '35201', '7500415', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '豊田町浮石', 'トヨタチョウウキイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市豊田町鷹子', '35', '35201', '7500416', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '豊田町鷹子', 'トヨタチョウタカノコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市豊田町殿敷', '35', '35201', '7500421', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '豊田町殿敷', 'トヨタチョウトノシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市豊田町楢原', '35', '35201', '7500422', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '豊田町楢原', 'トヨタチョウナラワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市豊田町西市', '35', '35201', '7500423', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '豊田町西市', 'トヨタチョウニシイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市豊田町矢田', '35', '35201', '7500424', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '豊田町矢田', 'トヨタチョウヤタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市豊田町庭田', '35', '35201', '7500425', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '豊田町庭田', 'トヨタチョウニワタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市豊田町今出', '35', '35201', '7500431', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '豊田町今出', 'トヨタチョウイマデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市豊田町地吉', '35', '35201', '7500432', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '豊田町地吉', 'トヨタチョウジヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市豊田町大河内', '35', '35201', '7500433', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '豊田町大河内', 'トヨタチョウオオカワチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市豊田町中村', '35', '35201', '7500441', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '豊田町中村', 'トヨタチョウナカムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市豊田町稲光', '35', '35201', '7500442', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '豊田町稲光', 'トヨタチョウイナミツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市豊田町日野', '35', '35201', '7500443', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '豊田町日野', 'トヨタチョウヒノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市豊田町萩原', '35', '35201', '7500444', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '豊田町萩原', 'トヨタチョウハギワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市豊田町東長野', '35', '35201', '7500445', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '豊田町東長野', 'トヨタチョウヒガシナガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市豊田町高山', '35', '35201', '7500446', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '豊田町高山', 'トヨタチョウタカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市豊田町阿座上', '35', '35201', '7500451', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '豊田町阿座上', 'トヨタチョウアザカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市豊田町江良', '35', '35201', '7500452', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '豊田町江良', 'トヨタチョウエラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市豊田町手洗', '35', '35201', '7500453', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '豊田町手洗', 'トヨタチョウタライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市豊田町西長野', '35', '35201', '7500454', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '豊田町西長野', 'トヨタチョウニシナガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市豊田町城戸', '35', '35201', '7500455', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '豊田町城戸', 'トヨタチョウキド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県美祢市豊田前町麻生上', '35', '35213', '7500601', '山口県', 'ヤマグチケン', '美祢市', 'ミネシ', '豊田前町麻生上', 'トヨタマエチョウアソウカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県美祢市豊田前町麻生下', '35', '35213', '7500602', '山口県', 'ヤマグチケン', '美祢市', 'ミネシ', '豊田前町麻生下', 'トヨタマエチョウアソウシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県美祢市豊田前町今山', '35', '35213', '7500603', '山口県', 'ヤマグチケン', '美祢市', 'ミネシ', '豊田前町今山', 'トヨタマエチョウイマヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県美祢市豊田前町保々', '35', '35213', '7500604', '山口県', 'ヤマグチケン', '美祢市', 'ミネシ', '豊田前町保々', 'トヨタマエチョウホウホウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県美祢市豊田前町古烏帽子', '35', '35213', '7500605', '山口県', 'ヤマグチケン', '美祢市', 'ミネシ', '豊田前町古烏帽子', 'トヨタマエチョウフルエボシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県美祢市豊田前町嶽', '35', '35213', '7500606', '山口県', 'ヤマグチケン', '美祢市', 'ミネシ', '豊田前町嶽', 'トヨタマエチョウダケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市吉田', '35', '35201', '7501101', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '吉田', 'ヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市吉田地方', '35', '35201', '7501102', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '吉田地方', 'ヨシダジカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市宇津井', '35', '35201', '7501111', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '宇津井', 'ウヅイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市木屋川本町', '35', '35201', '7501112', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '木屋川本町', 'コヤガワホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市木屋川南町', '35', '35201', '7501113', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '木屋川南町', 'コヤガワミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市王喜本町', '35', '35201', '7501114', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '王喜本町', 'オウキホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市王喜宇津井', '35', '35201', '7501115', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '王喜宇津井', 'オウキウヅイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市白崎', '35', '35201', '7501116', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '白崎', 'シラサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市松屋', '35', '35201', '7501121', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '松屋', 'マツヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市松屋上町', '35', '35201', '7501122', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '松屋上町', 'マツヤカミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市松屋東町', '35', '35201', '7501123', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '松屋東町', 'マツヤヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市松屋本町', '35', '35201', '7501124', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '松屋本町', 'マツヤホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市小月町', '35', '35201', '7501131', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '小月町', 'オヅキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市小月宮の町', '35', '35201', '7501132', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '小月宮の町', 'オヅキミヤノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市小月高雄町', '35', '35201', '7501133', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '小月高雄町', 'オヅキタカオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市小月京泊', '35', '35201', '7501134', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '小月京泊', 'オヅキキョウドマリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市小月西の台', '35', '35201', '7501135', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '小月西の台', 'オヅキニシノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市小月小島', '35', '35201', '7501136', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '小月小島', 'オヅキコジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市小月南町', '35', '35201', '7501137', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '小月南町', 'オヅキミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市小月幸町', '35', '35201', '7501141', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '小月幸町', 'オヅキサイワイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市小月本町', '35', '35201', '7501142', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '小月本町', 'オヅキホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市小月駅前', '35', '35201', '7501143', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '小月駅前', 'オヅキエキマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市小月茶屋', '35', '35201', '7501144', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '小月茶屋', 'オヅキチャヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市小月杉迫', '35', '35201', '7501145', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '小月杉迫', 'オヅキスギサコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市小月公園町', '35', '35201', '7501146', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '小月公園町', 'オヅキコウエンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市小月市原町', '35', '35201', '7501147', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '小月市原町', 'オヅキイチハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市清末', '35', '35201', '7501151', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '清末', 'キヨスエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市清末陣屋', '35', '35201', '7501152', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '清末陣屋', 'キヨスエジンヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市清末鞍馬', '35', '35201', '7501153', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '清末鞍馬', 'キヨスエクラマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市清末本町', '35', '35201', '7501154', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '清末本町', 'キヨスエホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市清末中町', '35', '35201', '7501155', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '清末中町', 'キヨスエナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市清末東町', '35', '35201', '7501156', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '清末東町', 'キヨスエヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市清末西町', '35', '35201', '7501161', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '清末西町', 'キヨスエニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市清末五毛', '35', '35201', '7501162', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '清末五毛', 'キヨスエゴモウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市清末千房', '35', '35201', '7501163', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '清末千房', 'キヨスエセンボウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市清末大門', '35', '35201', '7501164', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '清末大門', 'キヨスエダイモン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市阿内', '35', '35201', '7501171', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '阿内', 'オウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道芦別市西芦別町', '01', '01216', '0750161', '北海道', 'ホッカイドウ', '芦別市', 'アシベツシ', '西芦別町', 'ニシアシベツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道芦別市東頼城町', '01', '01216', '0750162', '北海道', 'ホッカイドウ', '芦別市', 'アシベツシ', '東頼城町', 'ヒガシライジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道芦別市緑泉町', '01', '01216', '0750163', '北海道', 'ホッカイドウ', '芦別市', 'アシベツシ', '緑泉町', 'ロクセンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道芦別市頼城町', '01', '01216', '0750164', '北海道', 'ホッカイドウ', '芦別市', 'アシベツシ', '頼城町', 'ライジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道芦別市青木沢', '01', '01216', '0750165', '北海道', 'ホッカイドウ', '芦別市', 'アシベツシ', '青木沢', 'アオキサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道芦別市川岸', '01', '01216', '0750166', '北海道', 'ホッカイドウ', '芦別市', 'アシベツシ', '川岸', 'カワギシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道芦別市中の丘町', '01', '01216', '0750167', '北海道', 'ホッカイドウ', '芦別市', 'アシベツシ', '中の丘町', 'ナカノオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道芦別市新城町', '01', '01216', '0750251', '北海道', 'ホッカイドウ', '芦別市', 'アシベツシ', '新城町', 'シンジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道芦別市黄金町', '01', '01216', '0750252', '北海道', 'ホッカイドウ', '芦別市', 'アシベツシ', '黄金町', 'コガネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道芦別市豊岡町', '01', '01216', '0750253', '北海道', 'ホッカイドウ', '芦別市', 'アシベツシ', '豊岡町', 'トヨオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道芦別市豊岡', '01', '01216', '0750254', '北海道', 'ホッカイドウ', '芦別市', 'アシベツシ', '豊岡', 'トヨオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市勝谷', '35', '35201', '7510801', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '勝谷', 'ショウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市勝谷新町', '35', '35201', '7510802', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '勝谷新町', 'ショウヤシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市前勝谷町', '35', '35201', '7510803', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '前勝谷町', 'マエショウヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市楠乃', '35', '35201', '7510804', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '楠乃', 'クスノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市一の宮住吉', '35', '35201', '7510805', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '一の宮住吉', 'イチノミヤスミヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市一の宮町', '35', '35201', '7510806', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '一の宮町', 'イチノミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市一の宮学園町', '35', '35201', '7510807', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '一の宮学園町', 'イチノミヤガクエンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市一の宮本町', '35', '35201', '7510808', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '一の宮本町', 'イチノミヤホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市一の宮東町', '35', '35201', '7510809', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '一の宮東町', 'イチノミヤヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市藤ケ谷町', '35', '35201', '7510811', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '藤ケ谷町', 'フジガタニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市椋野上町', '35', '35201', '7510812', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '椋野上町', 'ムクノカミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市みもすそ川町', '35', '35201', '7510813', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', 'みもすそ川町', 'ミモスソガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市壇之浦町', '35', '35201', '7510814', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '壇之浦町', 'ダンノウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市本町', '35', '35201', '7510815', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市椋野町', '35', '35201', '7510816', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '椋野町', 'ムクノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市一の宮卸本町', '35', '35201', '7510817', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '一の宮卸本町', 'イチノミヤオロシホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市卸新町', '35', '35201', '7510818', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '卸新町', 'オロシシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市武久西原台', '35', '35201', '7510819', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '武久西原台', 'タケヒサニシハラダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市新椋野', '35', '35201', '7510820', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '新椋野', 'シンムクノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市三河町', '35', '35201', '7510821', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '三河町', 'ミカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市宝町', '35', '35201', '7510822', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '宝町', 'タカラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市貴船町', '35', '35201', '7510823', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '貴船町', 'キブネマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市山の口町', '35', '35201', '7510824', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '山の口町', 'ヤマノクチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市石神町', '35', '35201', '7510825', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '石神町', 'イシガミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市後田町', '35', '35201', '7510826', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '後田町', 'ウシロダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市幡生本町', '35', '35201', '7510827', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '幡生本町', 'ハタブホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市幡生町', '35', '35201', '7510828', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '幡生町', 'ハタブチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市幡生宮の下町', '35', '35201', '7510829', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '幡生宮の下町', 'ハタブミヤノシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市大学町', '35', '35201', '7510831', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '大学町', 'ダイガクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市生野町', '35', '35201', '7510832', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '生野町', 'イクノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市武久町', '35', '35201', '7510833', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '武久町', 'タケヒサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市山の田東町', '35', '35201', '7510834', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '山の田東町', 'ヤマノタヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市山の田南町', '35', '35201', '7510835', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '山の田南町', 'ヤマノタミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('93999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市山の田西町', '35', '35201', '7510836', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '山の田西町', 'ヤマノタニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市山の田中央町', '35', '35201', '7510837', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '山の田中央町', 'ヤマノタチュウオウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市山の田本町', '35', '35201', '7510838', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '山の田本町', 'ヤマノタホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市山の田北町', '35', '35201', '7510839', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '山の田北町', 'ヤマノタキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市垢田町', '35', '35201', '7510841', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '垢田町', 'アカダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市新垢田南町', '35', '35201', '7510842', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '新垢田南町', 'シンアカダミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市新垢田東町', '35', '35201', '7510843', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '新垢田東町', 'シンアカダヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市新垢田西町', '35', '35201', '7510844', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '新垢田西町', 'シンアカダニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市新垢田北町', '35', '35201', '7510845', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '新垢田北町', 'シンアカダキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市垢田', '35', '35201', '7510846', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '垢田', 'アカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市古屋町', '35', '35201', '7510847', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '古屋町', 'フルヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市綾羅木南町', '35', '35201', '7510848', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '綾羅木南町', 'アヤラギミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市綾羅木本町', '35', '35201', '7510849', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '綾羅木本町', 'アヤラギホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市熊野西町', '35', '35201', '7510851', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '熊野西町', 'クマノニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市熊野町', '35', '35201', '7510852', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '熊野町', 'クマノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市川中豊町', '35', '35201', '7510853', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '川中豊町', 'カワナカユタカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市稗田南町', '35', '35201', '7510854', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '稗田南町', 'ヒエダミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市稗田西町', '35', '35201', '7510855', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '稗田西町', 'ヒエダニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市稗田中町', '35', '35201', '7510856', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '稗田中町', 'ヒエダナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市稗田北町', '35', '35201', '7510857', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '稗田北町', 'ヒエダキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市稗田町', '35', '35201', '7510858', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '稗田町', 'ヒエダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市川中本町', '35', '35201', '7510859', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '川中本町', 'カワナカホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市伊倉東町', '35', '35201', '7510861', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '伊倉東町', 'イクラヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市伊倉', '35', '35201', '7510862', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '伊倉', 'イクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市伊倉本町', '35', '35201', '7510863', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '伊倉本町', 'イクラホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市伊倉町', '35', '35201', '7510864', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '伊倉町', 'イクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市綾羅木新町', '35', '35201', '7510865', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '綾羅木新町', 'アヤラギシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市綾羅木', '35', '35201', '7510866', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '綾羅木', 'アヤラギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市延行', '35', '35201', '7510867', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '延行', 'ノブユキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市有冨', '35', '35201', '7510868', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '有冨', 'アリドミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市伊倉新町', '35', '35201', '7510869', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '伊倉新町', 'イクラシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市秋根', '35', '35201', '7510871', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '秋根', 'アキネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市秋根南町', '35', '35201', '7510872', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '秋根南町', 'アキネミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市秋根西町', '35', '35201', '7510873', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '秋根西町', 'アキネニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市秋根新町', '35', '35201', '7510874', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '秋根新町', 'アキネシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市秋根本町', '35', '35201', '7510875', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '秋根本町', 'アキネホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市秋根北町', '35', '35201', '7510876', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '秋根北町', 'アキネキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市秋根東町', '35', '35201', '7510877', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '秋根東町', 'アキネヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市秋根上町', '35', '35201', '7510878', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '秋根上町', 'アキネカミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市東勝谷', '35', '35201', '7510879', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '東勝谷', 'ヒガシショウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市井田', '35', '35201', '7510881', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '井田', 'イダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市田倉御殿町', '35', '35201', '7510882', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '田倉御殿町', 'タクラゴテンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市田倉', '35', '35201', '7510883', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '田倉', 'タクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市形山', '35', '35201', '7510884', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '形山', 'カタチヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市形山みどり町', '35', '35201', '7510885', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '形山みどり町', 'カタチヤマミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市石原', '35', '35201', '7510886', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '石原', 'イシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市小野', '35', '35201', '7510887', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '小野', 'オノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市形山町', '35', '35201', '7510888', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '形山町', 'カタチヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市山田', '35', '35201', '7520901', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '山田', 'ヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市赤池町', '35', '35201', '7520902', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '赤池町', 'アカイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市員光町', '35', '35201', '7520903', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '員光町', 'カズミツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市員光', '35', '35201', '7520904', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '員光', 'カズミツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市西観音町', '35', '35201', '7520905', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '西観音町', 'ニシカンノンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市東観音町', '35', '35201', '7520906', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '東観音町', 'ヒガシカンノンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市神田', '35', '35201', '7520907', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '神田', 'カンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市王司神田', '35', '35201', '7520911', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '王司神田', 'オウジカンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市王司川端', '35', '35201', '7520912', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '王司川端', 'オウジカワバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市乃木浜', '35', '35201', '7520913', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '乃木浜', 'ノギハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市千鳥浜町', '35', '35201', '7520914', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '千鳥浜町', 'チドリハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市王司本町', '35', '35201', '7520915', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '王司本町', 'オウジホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市王司上町', '35', '35201', '7520916', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '王司上町', 'オウジカミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市才川', '35', '35201', '7520921', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '才川', 'サイガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市千鳥ケ丘町', '35', '35201', '7520922', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '千鳥ケ丘町', 'チドリガオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市宇部', '35', '35201', '7520923', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '宇部', 'ウベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市王司南町', '35', '35201', '7520924', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '王司南町', 'オウジミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市亀浜町', '35', '35201', '7520925', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '亀浜町', 'カメハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市ゆめタウン', '35', '35201', '7520926', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', 'ゆめタウン', 'ユメタウン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市長府扇町', '35', '35201', '7520927', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '長府扇町', 'チョウフオオギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市長府才川', '35', '35201', '7520928', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '長府才川', 'チョウフサイガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市松小田', '35', '35201', '7520931', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '松小田', 'マツオダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市長府松小田北町', '35', '35201', '7520932', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '長府松小田北町', 'チョウフマツオダキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市長府松小田本町', '35', '35201', '7520933', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '長府松小田本町', 'チョウフマツオダホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市長府松小田東町', '35', '35201', '7520934', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '長府松小田東町', 'チョウフマツオダヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市長府松小田中町', '35', '35201', '7520935', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '長府松小田中町', 'チョウフマツオダナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市長府松小田南町', '35', '35201', '7520936', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '長府松小田南町', 'チョウフマツオダミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市長府松小田西町', '35', '35201', '7520937', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '長府松小田西町', 'チョウフマツオダニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市長府新四王司町', '35', '35201', '7520941', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '長府新四王司町', 'チョウフシンシオウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市長府四王司町', '35', '35201', '7520942', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '長府四王司町', 'チョウフシオウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市長府豊城町', '35', '35201', '7520943', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '長府豊城町', 'チョウフホウジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市長府中六波町', '35', '35201', '7520944', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '長府中六波町', 'チョウフナカロッパチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市長府豊浦町', '35', '35201', '7520945', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '長府豊浦町', 'チョウフトヨラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市長府中尾町', '35', '35201', '7520946', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '長府中尾町', 'チョウフナカオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市長府満珠町', '35', '35201', '7520947', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '長府満珠町', 'チョウフマンジュチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市長府満珠新町', '35', '35201', '7520948', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '長府満珠新町', 'チョウフマンジュシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市長府日の出町', '35', '35201', '7520951', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '長府日の出町', 'チョウフヒノデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市長府江下町', '35', '35201', '7520952', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '長府江下町', 'チョウフエゲマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市長府港町', '35', '35201', '7520953', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '長府港町', 'チョウフミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市長府古城町', '35', '35201', '7520954', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '長府古城町', 'チョウフコジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市長府八幡町', '35', '35201', '7520955', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '長府八幡町', 'チョウフヤハタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市長府前八幡町', '35', '35201', '7520956', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '長府前八幡町', 'チョウフマエヤハタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市長府印内町', '35', '35201', '7520957', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '長府印内町', 'チョウフインナイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市長府金屋浜町', '35', '35201', '7520958', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '長府金屋浜町', 'チョウフカナヤハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市長府金屋町', '35', '35201', '7520959', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '長府金屋町', 'チョウフカナヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市長府珠の浦町', '35', '35201', '7520961', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '長府珠の浦町', 'チョウフタマノウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市長府安養寺', '35', '35201', '7520962', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '長府安養寺', 'チョウフアンヨウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市長府中土居北町', '35', '35201', '7520963', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '長府中土居北町', 'チョウフナカドイキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市長府中土居本町', '35', '35201', '7520964', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '長府中土居本町', 'チョウフナカドイホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市長府三島町', '35', '35201', '7520965', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '長府三島町', 'チョウフミシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市長府亀の甲', '35', '35201', '7520966', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '長府亀の甲', 'チョウフカメノコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市長府宮の内町', '35', '35201', '7520967', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '長府宮の内町', 'チョウフミヤノウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市長府紺屋町', '35', '35201', '7520968', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '長府紺屋町', 'チョウフコンヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市長府惣社町', '35', '35201', '7520970', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '長府惣社町', 'チョウフソウシャマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市長府逢坂町', '35', '35201', '7520971', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '長府逢坂町', 'チョウフオウサカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市長府古江小路町', '35', '35201', '7520972', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '長府古江小路町', 'チョウフフルエショウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市長府中之町', '35', '35201', '7520973', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '長府中之町', 'チョウフナカノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市長府土居の内町', '35', '35201', '7520974', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '長府土居の内町', 'チョウフドイノウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市長府中浜町', '35', '35201', '7520975', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '長府中浜町', 'チョウフナカハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市長府南之町', '35', '35201', '7520976', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '長府南之町', 'チョウフミナミノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市長府東侍町', '35', '35201', '7520977', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '長府東侍町', 'チョウフヒガシサムライマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市長府侍町', '35', '35201', '7520978', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '長府侍町', 'チョウフサムライマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市長府川端', '35', '35201', '7520979', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '長府川端', 'チョウフカワバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市長府黒門町', '35', '35201', '7520980', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '長府黒門町', 'チョウフクロモンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市豊浦村', '35', '35201', '7520981', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '豊浦村', 'トヨウラムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市長府新松原町', '35', '35201', '7520982', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '長府新松原町', 'チョウフシンマツバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市長府松原町', '35', '35201', '7520983', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '長府松原町', 'チョウフマツバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市長府宮崎町', '35', '35201', '7520984', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '長府宮崎町', 'チョウフミヤザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市長府外浦町', '35', '35201', '7520985', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '長府外浦町', 'チョウフソトウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市長府黒門東町', '35', '35201', '7520986', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '長府黒門東町', 'チョウフクロモンヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市長府羽衣町', '35', '35201', '7520987', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '長府羽衣町', 'チョウフハゴロモチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市長府羽衣南町', '35', '35201', '7520988', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '長府羽衣南町', 'チョウフハゴロモミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市長府黒門南町', '35', '35201', '7520989', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '長府黒門南町', 'チョウフクロモンミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市高畑', '35', '35201', '7520991', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '高畑', 'タカハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市長府野久留米町', '35', '35201', '7520992', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '長府野久留米町', 'チョウフノグルメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市長府浜浦町', '35', '35201', '7520993', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '長府浜浦町', 'チョウフハマウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市長府高場町', '35', '35201', '7520994', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '長府高場町', 'チョウフタカバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市長府浜浦南町', '35', '35201', '7520995', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '長府浜浦南町', 'チョウフハマウラミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市長府向田町', '35', '35201', '7520996', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '長府向田町', 'チョウフムカイダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市前田', '35', '35201', '7520997', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '前田', 'マエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市長府浜浦西町', '35', '35201', '7520998', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '長府浜浦西町', 'チョウフハマウラニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市', '35', '35203', '7530000', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('94142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市宮野上', '35', '35203', '7530001', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '宮野上', 'ミヤノカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市宮野下', '35', '35203', '7530011', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '宮野下', 'ミヤノシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市桜畠', '35', '35203', '7530021', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '桜畠', 'サクラバタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市折本', '35', '35203', '7530022', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '折本', 'オリモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市三の宮', '35', '35203', '7530023', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '三の宮', 'サンノミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市金古曽町', '35', '35203', '7530024', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '金古曽町', 'カナコソチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市芝崎町', '35', '35203', '7530025', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '芝崎町', 'シバサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市古熊', '35', '35203', '7530031', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '古熊', 'フルクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市堂の前町', '35', '35203', '7530032', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '堂の前町', 'ドウノマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市大市町', '35', '35203', '7530033', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '大市町', 'オオイチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市下竪小路', '35', '35203', '7530034', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '下竪小路', 'シモタテコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市上竪小路', '35', '35203', '7530035', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '上竪小路', 'カミタテコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市円政寺', '35', '35203', '7530036', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '円政寺', 'エンセイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市円政寺町', '35', '35203', '7530036', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '円政寺町', 'エンセイジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市道祖町', '35', '35203', '7530037', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '道祖町', 'ドウソチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市石観音町', '35', '35203', '7530038', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '石観音町', 'イシガンノンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市東山', '35', '35203', '7530041', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '東山', 'ヒガシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市惣太夫町', '35', '35203', '7530042', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '惣太夫町', 'ソウダユウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市宮島町', '35', '35203', '7530043', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '宮島町', 'ミヤジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市鰐石町', '35', '35203', '7530044', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '鰐石町', 'ワニイシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市黄金町', '35', '35203', '7530045', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '黄金町', 'コガネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市本町', '35', '35203', '7530046', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市道場門前', '35', '35203', '7530047', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '道場門前', 'ドウジョウモンゼン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市駅通り', '35', '35203', '7530048', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '駅通り', 'エキドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市旭通り', '35', '35203', '7530051', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '旭通り', 'アサヒドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市三和町', '35', '35203', '7530052', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '三和町', 'サンワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市松美町', '35', '35203', '7530053', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '松美町', 'マツミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市富田原町', '35', '35203', '7530054', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '富田原町', 'トミタバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市今井町', '35', '35203', '7530055', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '今井町', 'イマイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市湯田温泉', '35', '35203', '7530056', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '湯田温泉', 'ユダオンセン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市前町', '35', '35203', '7530057', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '前町', 'マエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市下市町', '35', '35203', '7530058', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '下市町', 'シモイチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市朝倉町', '35', '35203', '7530061', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '朝倉町', 'アサクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市荻町', '35', '35203', '7530062', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '荻町', 'オギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市元町', '35', '35203', '7530063', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '元町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市神田町', '35', '35203', '7530064', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '神田町', 'カンダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市楠木町', '35', '35203', '7530065', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '楠木町', 'クスノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市泉町', '35', '35203', '7530066', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '泉町', 'イズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市赤妻町', '35', '35203', '7530067', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '赤妻町', 'アカヅマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市錦町', '35', '35203', '7530068', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '錦町', 'ニシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市白石', '35', '35203', '7530070', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '白石', 'シライシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市滝町', '35', '35203', '7530071', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '滝町', 'タキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市大手町', '35', '35203', '7530072', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '大手町', 'オオテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市春日町', '35', '35203', '7530073', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '春日町', 'カスガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市中央', '35', '35203', '7530074', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市中園町', '35', '35203', '7530075', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '中園町', 'ナカゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市泉都町', '35', '35203', '7530076', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '泉都町', 'セントチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市熊野町', '35', '35203', '7530077', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '熊野町', 'クマノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市緑町', '35', '35203', '7530078', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '緑町', 'ミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市糸米', '35', '35203', '7530079', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '糸米', 'イトヨネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市香山町', '35', '35203', '7530081', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '香山町', 'コウザンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市水の上町', '35', '35203', '7530082', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '水の上町', 'ミズノウエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市後河原', '35', '35203', '7530083', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '後河原', 'ウシロガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市久保小路', '35', '35203', '7530084', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '久保小路', 'クボショウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市諸願小路', '35', '35203', '7530084', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '諸願小路', 'ショガンショウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市銭湯小路', '35', '35203', '7530084', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '銭湯小路', 'セントウショウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市新馬場', '35', '35203', '7530085', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '新馬場', 'シンババ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市中市町', '35', '35203', '7530086', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '中市町', 'ナカイチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市米屋町', '35', '35203', '7530087', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '米屋町', 'コメヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市中河原', '35', '35203', '7530088', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '中河原', 'ナカガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市中河原町', '35', '35203', '7530088', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '中河原町', 'ナカガワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市亀山町', '35', '35203', '7530089', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '亀山町', 'カメヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市上宇野令', '35', '35203', '7530091', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '上宇野令', 'カミウノレイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市天花', '35', '35203', '7530091', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '天花', 'テンゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市八幡馬場', '35', '35203', '7530092', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '八幡馬場', 'ヤワタノババ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市大殿大路', '35', '35203', '7530093', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '大殿大路', 'オオドノオオジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市野田', '35', '35203', '7530094', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '野田', 'ノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市木町', '35', '35203', '7530095', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '木町', 'キマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県萩市佐々並', '35', '35204', '7530101', '山口県', 'ヤマグチケン', '萩市', 'ハギシ', '佐々並', 'ササナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市大内長野', '35', '35203', '7530211', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '大内長野', 'オオウチナガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市下小鯖', '35', '35203', '7530212', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '下小鯖', 'シモオサバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市上小鯖', '35', '35203', '7530213', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '上小鯖', 'カミオサバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市大内御堀', '35', '35203', '7530214', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '大内御堀', 'オオウチミホリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市大内矢田', '35', '35203', '7530215', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '大内矢田', 'オオウチヤタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市仁保上郷', '35', '35203', '7530301', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '仁保上郷', 'ニホカミゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市仁保中郷', '35', '35203', '7530302', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '仁保中郷', 'ニホナカゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市仁保下郷', '35', '35203', '7530303', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '仁保下郷', 'ニホシモゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市中尾', '35', '35203', '7530801', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '中尾', 'ナカオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市吉敷', '35', '35203', '7530811', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '吉敷', 'ヨシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市宝町', '35', '35203', '7530812', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '宝町', 'タカラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市吉敷中東', '35', '35203', '7530813', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '吉敷中東', 'ヨシキナカヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市吉敷下東', '35', '35203', '7530814', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '吉敷下東', 'ヨシキシモヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市維新公園', '35', '35203', '7530815', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '維新公園', 'イシンコウエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市吉敷佐畑', '35', '35203', '7530816', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '吉敷佐畑', 'ヨシキサバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市吉敷赤田', '35', '35203', '7530817', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '吉敷赤田', 'ヨシキアカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市吉敷上東', '35', '35203', '7530818', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '吉敷上東', 'ヨシキカミヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市葵', '35', '35203', '7530821', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '葵', 'アオイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市周布町', '35', '35203', '7530822', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '周布町', 'スフチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市若宮町', '35', '35203', '7530823', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '若宮町', 'ワカミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市穂積町', '35', '35203', '7530824', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '穂積町', 'ホヅミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市矢原町', '35', '35203', '7530825', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '矢原町', 'ヤバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市幸町', '35', '35203', '7530826', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市平井', '35', '35203', '7530831', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '平井', 'ヒライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市吉田', '35', '35203', '7530841', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '吉田', 'ヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市黒川', '35', '35203', '7530851', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '黒川', 'クロカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市矢原', '35', '35203', '7530861', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '矢原', 'ヤバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市朝田', '35', '35203', '7530871', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '朝田', 'アサダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市朝田流通センター', '35', '35203', '7530872', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '朝田流通センター', 'アサダリュウツウセンター', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市小郡上郷流通センター', '35', '35203', '7530872', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '小郡上郷流通センター', 'オゴオリカミゴウリュウツウセンター', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市山口県流通センター', '35', '35203', '7530872', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '山口県流通センター', 'ヤマグチケンリュウツウセンター', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市上天花町', '35', '35203', '7530891', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '上天花町', 'カミテンゲマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市小郡上郷', '35', '35203', '7540001', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '小郡上郷', 'オゴオリカミゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市小郡下郷', '35', '35203', '7540002', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '小郡下郷', 'オゴオリシモゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市小郡真名', '35', '35203', '7540003', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '小郡真名', 'オゴオリマナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市小郡御幸町', '35', '35203', '7540011', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '小郡御幸町', 'オゴオリミユキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市小郡船倉町', '35', '35203', '7540012', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '小郡船倉町', 'オゴオリフナクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市小郡緑町', '35', '35203', '7540013', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '小郡緑町', 'オゴオリミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市小郡高砂町', '35', '35203', '7540014', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '小郡高砂町', 'オゴオリタカサゴマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市小郡大江町', '35', '35203', '7540015', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '小郡大江町', 'オゴオリオオエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市小郡平成町', '35', '35203', '7540020', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '小郡平成町', 'オゴオリヘイセイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市小郡黄金町', '35', '35203', '7540021', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '小郡黄金町', 'オゴオリコガネマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市小郡花園町', '35', '35203', '7540022', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '小郡花園町', 'オゴオリハナゾノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市小郡前田町', '35', '35203', '7540023', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '小郡前田町', 'オゴオリマエダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市小郡若草町', '35', '35203', '7540024', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '小郡若草町', 'オゴオリワカクサマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市小郡平砂町', '35', '35203', '7540025', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '小郡平砂町', 'オゴオリヒラサマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市小郡栄町', '35', '35203', '7540026', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '小郡栄町', 'オゴオリサカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市小郡三軒屋町', '35', '35203', '7540027', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '小郡三軒屋町', 'オゴオリサンゲンヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市小郡給領町', '35', '35203', '7540028', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '小郡給領町', 'オゴオリキュウリョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市小郡維新町', '35', '35203', '7540029', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '小郡維新町', 'オゴオリイシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県美祢市美東町長田', '35', '35213', '7540121', '山口県', 'ヤマグチケン', '美祢市', 'ミネシ', '美東町長田', 'ミトウチョウナガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県美祢市美東町真名', '35', '35213', '7540122', '山口県', 'ヤマグチケン', '美祢市', 'ミネシ', '美東町真名', 'ミトウチョウマナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県美祢市美東町小野', '35', '35213', '7540123', '山口県', 'ヤマグチケン', '美祢市', 'ミネシ', '美東町小野', 'ミトウチョウオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県美祢市美東町大田', '35', '35213', '7540211', '山口県', 'ヤマグチケン', '美祢市', 'ミネシ', '美東町大田', 'ミトウチョウオオダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県美祢市美東町綾木', '35', '35213', '7540212', '山口県', 'ヤマグチケン', '美祢市', 'ミネシ', '美東町綾木', 'ミトウチョウアヤギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県美祢市美東町長登', '35', '35213', '7540213', '山口県', 'ヤマグチケン', '美祢市', 'ミネシ', '美東町長登', 'ミトウチョウナガノボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県美祢市美東町', '35', '35213', '7540214', '山口県', 'ヤマグチケン', '美祢市', 'ミネシ', '美東町', 'ミトウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県美祢市美東町絵堂', '35', '35213', '7540301', '山口県', 'ヤマグチケン', '美祢市', 'ミネシ', '美東町絵堂', 'ミトウチョウエドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県美祢市美東町赤', '35', '35213', '7540302', '山口県', 'ヤマグチケン', '美祢市', 'ミネシ', '美東町赤', 'ミトウチョウアカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県萩市明木', '35', '35204', '7540411', '山口県', 'ヤマグチケン', '萩市', 'ハギシ', '明木', 'アキラギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県美祢市秋芳町秋吉', '35', '35213', '7540511', '山口県', 'ヤマグチケン', '美祢市', 'ミネシ', '秋芳町秋吉', 'シュウホウチョウアキヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県美祢市秋芳町岩永本郷', '35', '35213', '7540512', '山口県', 'ヤマグチケン', '美祢市', 'ミネシ', '秋芳町岩永本郷', 'シュウホウチョウイワナガホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県美祢市秋芳町岩永下郷', '35', '35213', '7540513', '山口県', 'ヤマグチケン', '美祢市', 'ミネシ', '秋芳町岩永下郷', 'シュウホウチョウイワナガシモゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県美祢市秋芳町', '35', '35213', '7540514', '山口県', 'ヤマグチケン', '美祢市', 'ミネシ', '秋芳町', 'シュウホウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県美祢市秋芳町嘉万', '35', '35213', '7540601', '山口県', 'ヤマグチケン', '美祢市', 'ミネシ', '秋芳町嘉万', 'シュウホウチョウカマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県美祢市秋芳町青景', '35', '35213', '7540602', '山口県', 'ヤマグチケン', '美祢市', 'ミネシ', '秋芳町青景', 'シュウホウチョウアオカゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県美祢市秋芳町別府', '35', '35213', '7540603', '山口県', 'ヤマグチケン', '美祢市', 'ミネシ', '秋芳町別府', 'シュウホウチョウベップ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市陶', '35', '35203', '7540891', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '陶', 'スエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市名田島', '35', '35203', '7540892', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '名田島', 'ナタジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市秋穂二島', '35', '35203', '7540893', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '秋穂二島', 'アイオフタジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市佐山', '35', '35203', '7540894', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '佐山', 'サヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市深溝', '35', '35203', '7540895', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '深溝', 'フカミゾ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市江崎', '35', '35203', '7540896', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '江崎', 'エザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市嘉川', '35', '35203', '7540897', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '嘉川', 'カガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市秋穂東', '35', '35203', '7541101', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '秋穂東', 'アイオヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市秋穂西', '35', '35203', '7541102', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '秋穂西', 'アイオニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山口市阿知須', '35', '35203', '7541277', '山口県', 'ヤマグチケン', '山口市', 'ヤマグチシ', '阿知須', 'アジス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市小野', '35', '35202', '7541311', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '小野', 'オノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市棯小野', '35', '35202', '7541312', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '棯小野', 'ウツギオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市藤河内', '35', '35202', '7541313', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '藤河内', 'フジゴウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市櫟原', '35', '35202', '7541314', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '櫟原', 'イチイバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市如意寺', '35', '35202', '7541315', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '如意寺', 'ニョイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市', '35', '35202', '7550000', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('94350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市沖宇部', '35', '35202', '7550001', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '沖宇部', 'オキウベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市亀浦', '35', '35202', '7550002', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '亀浦', 'カメウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市則貞', '35', '35202', '7550003', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '則貞', 'ノリサダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市草江', '35', '35202', '7550004', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '草江', 'クサエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市五十目山町', '35', '35202', '7550005', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '五十目山町', 'ゴジュウメヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市岬町', '35', '35202', '7550006', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '岬町', 'ミサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市八王子町', '35', '35202', '7550007', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '八王子町', 'ハチオウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市明神町', '35', '35202', '7550008', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '明神町', 'ミョウジンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市東見初町', '35', '35202', '7550009', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '東見初町', 'ヒガシミゾメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市昭和町', '35', '35202', '7550011', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '昭和町', 'ショウワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市幸町', '35', '35202', '7550012', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '幸町', 'サイワイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市明治町', '35', '35202', '7550013', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '明治町', 'メイジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市末広町', '35', '35202', '7550014', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '末広町', 'スエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市笹山町', '35', '35202', '7550015', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '笹山町', 'ササヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市東芝中町', '35', '35202', '7550016', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '東芝中町', 'ヒガシシバナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市芝中町', '35', '35202', '7550017', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '芝中町', 'シバナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市錦町', '35', '35202', '7550018', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '錦町', 'ニシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市東新川町', '35', '35202', '7550019', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '東新川町', 'ヒガシシンカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市常藤町', '35', '35202', '7550021', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '常藤町', 'ツネフジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市神原町', '35', '35202', '7550022', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '神原町', 'カミハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市恩田町', '35', '35202', '7550023', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '恩田町', 'オンダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市野原', '35', '35202', '7550024', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '野原', 'ノバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市野中', '35', '35202', '7550025', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '野中', 'ノナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市松山町', '35', '35202', '7550026', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '松山町', 'マツヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市港町', '35', '35202', '7550027', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '港町', 'ミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市東本町', '35', '35202', '7550028', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '東本町', 'ヒガシホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市新天町', '35', '35202', '7550029', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '新天町', 'シンテンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市常盤町', '35', '35202', '7550031', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '常盤町', 'トキワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市寿町', '35', '35202', '7550032', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '寿町', 'コトブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市琴芝町', '35', '35202', '7550033', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '琴芝町', 'コトシバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市東琴芝', '35', '35202', '7550034', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '東琴芝', 'ヒガシコトシバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市西琴芝', '35', '35202', '7550035', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '西琴芝', 'ニシコトシバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市北琴芝', '35', '35202', '7550036', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '北琴芝', 'キタコトシバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市西梶返', '35', '35202', '7550037', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '西梶返', 'ニシカジガエシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市海南町', '35', '35202', '7550038', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '海南町', 'カイナンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市東梶返', '35', '35202', '7550039', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '東梶返', 'ヒガシカジガエシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市朝日町', '35', '35202', '7550041', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '朝日町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市松島町', '35', '35202', '7550042', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '松島町', 'マツシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市相生町', '35', '35202', '7550043', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '相生町', 'アイオイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市新町', '35', '35202', '7550044', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市中央町', '35', '35202', '7550045', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '中央町', 'チュウオウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市南小串', '35', '35202', '7550046', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '南小串', 'ミナミコグシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市島', '35', '35202', '7550047', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '島', 'シマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市下条', '35', '35202', '7550048', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '下条', 'シモジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市西小串', '35', '35202', '7550049', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '西小串', 'ニシコグシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市上町', '35', '35202', '7550051', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '上町', 'ウエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市西本町', '35', '35202', '7550052', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '西本町', 'ニシホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市西中町', '35', '35202', '7550053', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '西中町', 'ニシナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市助田町', '35', '35202', '7550054', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '助田町', 'スケダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市居能町', '35', '35202', '7550055', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '居能町', 'イノウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市文京町', '35', '35202', '7550056', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '文京町', 'ブンキョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市藤曲', '35', '35202', '7550057', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '藤曲', 'フジマガリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市中山', '35', '35202', '7550058', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '中山', 'ナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市若松町', '35', '35202', '7550061', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '若松町', 'ワカマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市鵜の島町', '35', '35202', '7550062', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '鵜の島町', 'ウノシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市南浜町', '35', '35202', '7550063', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '南浜町', 'ミナミハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市鍋倉町', '35', '35202', '7550064', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '鍋倉町', 'ナベクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市浜町', '35', '35202', '7550065', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '浜町', 'ハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市小松原町', '35', '35202', '7550066', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '小松原町', 'コマツバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市小串', '35', '35202', '7550067', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '小串', 'コグシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市東小串', '35', '35202', '7550068', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '東小串', 'ヒガシコグシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市宮地町', '35', '35202', '7550071', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '宮地町', 'ミヤジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市中村', '35', '35202', '7550072', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '中村', 'ナカムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市中尾', '35', '35202', '7550073', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '中尾', 'ナカオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市川添', '35', '35202', '7550074', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '川添', 'カワゾエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市琴崎町', '35', '35202', '7550075', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '琴崎町', 'コトザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市大小路', '35', '35202', '7550076', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '大小路', 'オオショウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市山門', '35', '35202', '7550077', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '山門', 'ヤマカド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市寺の前町', '35', '35202', '7550078', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '寺の前町', 'テラノマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市北小羽山町', '35', '35202', '7550081', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '北小羽山町', 'キタオバヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市東小羽山町', '35', '35202', '7550082', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '東小羽山町', 'ヒガシオバヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市南小羽山町', '35', '35202', '7550083', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '南小羽山町', 'ミナミオバヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市川上', '35', '35202', '7550084', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '川上', 'カワカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市沼', '35', '35202', '7550085', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '沼', 'ヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市中宇部', '35', '35202', '7550086', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '中宇部', 'ナカウベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市上宇部', '35', '35202', '7550091', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '上宇部', 'カミウベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市上野中町', '35', '35202', '7550092', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '上野中町', 'カミノナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市北迫新町', '35', '35202', '7550093', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '北迫新町', 'キタサコシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市ひらき台', '35', '35202', '7550094', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', 'ひらき台', 'ヒラキダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市風呂ケ迫町', '35', '35202', '7550095', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '風呂ケ迫町', 'フロガサコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市開', '35', '35202', '7550096', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '開', 'ヒラキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市常盤台', '35', '35202', '7550097', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '常盤台', 'トキワダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市西岐波', '35', '35202', '7550151', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '西岐波', 'ニシキワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市あすとぴあ', '35', '35202', '7550152', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', 'あすとぴあ', 'アストピア', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市床波', '35', '35202', '7550153', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '床波', 'トコナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市今村南', '35', '35202', '7550154', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '今村南', 'イマムラミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市今村北', '35', '35202', '7550155', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '今村北', 'イマムラキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市東岐波', '35', '35202', '7550241', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '東岐波', 'ヒガシキワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市上条', '35', '35202', '7550801', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '上条', 'アゲジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市北条', '35', '35202', '7550802', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '北条', 'キタジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市東藤曲', '35', '35202', '7550803', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '東藤曲', 'ヒガシフジマガリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市南中山町', '35', '35202', '7550804', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '南中山町', 'ミナミナカヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市文京台', '35', '35202', '7550805', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '文京台', 'ブンキョウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市浜田', '35', '35202', '7550806', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '浜田', 'ハマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市東平原', '35', '35202', '7550807', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '東平原', 'ヒガシヒラバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市西平原', '35', '35202', '7550808', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '西平原', 'ニシヒラバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市松崎町', '35', '35202', '7550809', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '松崎町', 'マツザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市岩鼻町', '35', '35202', '7550810', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '岩鼻町', 'イワハナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市', '35', '35216', '7560000', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('94477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市大休', '35', '35216', '7560001', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '大休', 'タイキュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市有帆新町', '35', '35216', '7560003', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '有帆新町', 'アリホシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市中里', '35', '35216', '7560004', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '中里', 'ナカザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市中村', '35', '35216', '7560005', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '中村', 'ナカムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市北真土郷', '35', '35216', '7560007', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '北真土郷', 'キタマツチゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市大休団地', '35', '35216', '7560008', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '大休団地', 'タイキュウダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市有帆上町', '35', '35216', '7560009', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '有帆上町', 'アリホウエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市新有帆町', '35', '35216', '7560010', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '新有帆町', 'シンアリホチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市共和台', '35', '35216', '7560011', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '共和台', 'キョウワダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市角石', '35', '35216', '7560012', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '角石', 'カドイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市片山', '35', '35216', '7560013', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '片山', 'カタヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市彼岸田', '35', '35216', '7560014', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '彼岸田', 'ヒガンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市ひがんだ団地', '35', '35216', '7560015', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', 'ひがんだ団地', 'ヒガンダダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市南平台', '35', '35216', '7560016', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '南平台', 'ナンペイダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市仁保の上', '35', '35216', '7560017', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '仁保の上', 'ニホノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市東町', '35', '35216', '7560018', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '東町', 'ヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市南真土郷', '35', '35216', '7560019', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '南真土郷', 'ミナミマツチゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市高畑', '35', '35216', '7560021', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '高畑', 'タカハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市千崎西', '35', '35216', '7560022', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '千崎西', 'チザキニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市千崎東', '35', '35216', '7560023', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '千崎東', 'チザキヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市萩森', '35', '35216', '7560024', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '萩森', 'ハギモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市烏帽子岩', '35', '35216', '7560025', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '烏帽子岩', 'エボシイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市烏帽子岩団地', '35', '35216', '7560026', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '烏帽子岩団地', 'エボシイワダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市烏帽子岩前', '35', '35216', '7560027', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '烏帽子岩前', 'エボシイワマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市共和町', '35', '35216', '7560028', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '共和町', 'キョウワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市船越', '35', '35216', '7560029', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '船越', 'フナコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市青葉台', '35', '35216', '7560030', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '青葉台', 'アオバダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市平和町', '35', '35216', '7560031', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '平和町', 'ヘイワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市平生町', '35', '35216', '7560032', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '平生町', 'ヒラオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市若草町', '35', '35216', '7560033', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '若草町', 'ワカクサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市緑が丘', '35', '35216', '7560034', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '緑が丘', 'ミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市平原', '35', '35216', '7560035', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '平原', 'ヒラバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市大塚団地', '35', '35216', '7560036', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '大塚団地', 'オオツカダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市小松尾', '35', '35216', '7560037', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '小松尾', 'コマツオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市有帆', '35', '35216', '7560038', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '有帆', 'アリホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市千崎', '35', '35216', '7560039', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '千崎', 'チザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市上の郷', '35', '35216', '7560041', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '上の郷', 'カミノゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市大塚', '35', '35216', '7560042', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '大塚', 'オオツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市浜', '35', '35216', '7560043', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '浜', 'ハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市郷', '35', '35216', '7560044', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '郷', 'ゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市南高泊', '35', '35216', '7560045', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '南高泊', 'ミナミタカトマリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市西の郷', '35', '35216', '7560046', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '西の郷', 'ニシノゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市高浜', '35', '35216', '7560047', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '高浜', 'タカハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市後潟下', '35', '35216', '7560048', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '後潟下', 'ウシロガタシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市後潟上', '35', '35216', '7560049', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '後潟上', 'ウシロガタカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市杵築', '35', '35216', '7560051', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '杵築', 'キズキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市浜田町', '35', '35216', '7560052', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '浜田町', 'ハマダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市下木屋', '35', '35216', '7560053', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '下木屋', 'シモゴヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市旦東', '35', '35216', '7560054', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '旦東', 'ダンヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市旦西', '35', '35216', '7560055', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '旦西', 'ダンニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市上木屋', '35', '35216', '7560056', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '上木屋', 'カミゴヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市西高泊', '35', '35216', '7560057', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '西高泊', 'ニシタカドマリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市高千帆', '35', '35216', '7560060', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '高千帆', 'タカチホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市石井手', '35', '35216', '7560063', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '石井手', 'イシイデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市柿の木坂', '35', '35216', '7560067', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '柿の木坂', 'カキノキザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市目出文化町', '35', '35216', '7560071', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '目出文化町', 'メデブンカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市目出緑町', '35', '35216', '7560072', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '目出緑町', 'メデミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市目出幸町', '35', '35216', '7560073', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '目出幸町', 'メデサイワイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市目出湖畔町', '35', '35216', '7560074', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '目出湖畔町', 'メデコハンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市亀の甲', '35', '35216', '7560075', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '亀の甲', 'カメノコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市目出', '35', '35216', '7560076', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '目出', 'メデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市目出新町', '35', '35216', '7560077', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '目出新町', 'メデシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市くし山', '35', '35216', '7560080', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', 'くし山', 'クシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市神帆町', '35', '35216', '7560086', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '神帆町', 'カミホチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市高須', '35', '35216', '7560087', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '高須', 'タカス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市東高泊', '35', '35216', '7560088', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '東高泊', 'ヒガシタカドマリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市日の出', '35', '35216', '7560091', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '日の出', 'ヒノデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市新生', '35', '35216', '7560092', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '新生', 'シンセイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市日産', '35', '35216', '7560093', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '日産', 'ニッサン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市市立病院', '35', '35216', '7560094', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '市立病院', 'シリツビョウイン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市労災病院', '35', '35216', '7560095', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '労災病院', 'ロウサイビョウイン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市北栄町', '35', '35216', '7560801', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '北栄町', 'キタサカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市栄町', '35', '35216', '7560802', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市南中川町', '35', '35216', '7560803', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '南中川町', 'ミナミナカガワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市長寿園', '35', '35216', '7560804', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '長寿園', 'チョウジュエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市自由ケ丘', '35', '35216', '7560805', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '自由ケ丘', 'ジユウガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市中川', '35', '35216', '7560806', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '中川', 'ナカガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市硫酸町', '35', '35216', '7560807', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '硫酸町', 'リュウサンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市旭町', '35', '35216', '7560808', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '旭町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市横土手', '35', '35216', '7560809', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '横土手', 'ヨコドテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市稲荷町', '35', '35216', '7560811', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '稲荷町', 'イナリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市小野山', '35', '35216', '7560812', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '小野山', 'オノヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市住吉本町', '35', '35216', '7560813', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '住吉本町', 'スミヨシホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市千代町', '35', '35216', '7560814', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '千代町', 'チヨマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市高栄', '35', '35216', '7560815', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '高栄', 'コウエイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市西住吉町', '35', '35216', '7560816', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '西住吉町', 'ニシスミヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市小野田', '35', '35216', '7560817', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '小野田', 'オノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市丸河内', '35', '35216', '7560821', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '丸河内', 'マルゴウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市北若山', '35', '35216', '7560822', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '北若山', 'キタワカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市心和園', '35', '35216', '7560823', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '心和園', 'シンワエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市中央', '35', '35216', '7560824', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市東住吉町', '35', '35216', '7560825', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '東住吉町', 'ヒガシスミヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市南若山', '35', '35216', '7560831', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '南若山', 'ミナミワカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市南竜王町', '35', '35216', '7560832', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '南竜王町', 'ミナミリュウオウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市北竜王町', '35', '35216', '7560833', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '北竜王町', 'キタリュウオウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市港町', '35', '35216', '7560834', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '港町', 'ミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市セメント町', '35', '35216', '7560835', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', 'セメント町', 'セメントマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市須恵', '35', '35216', '7560836', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '須恵', 'スエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市平成町', '35', '35216', '7560837', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '平成町', 'ヘイセイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市赤崎', '35', '35216', '7560841', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '赤崎', 'アカサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市刈屋中村', '35', '35216', '7560842', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '刈屋中村', 'カリヤナカムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市刈屋上条', '35', '35216', '7560843', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '刈屋上条', 'カリヤカミジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市木戸大鼻', '35', '35216', '7560844', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '木戸大鼻', 'キドオオバナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市木戸中ノ町', '35', '35216', '7560845', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '木戸中ノ町', 'キドナカノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市木戸新町', '35', '35216', '7560846', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '木戸新町', 'キドシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市新沖', '35', '35216', '7560847', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '新沖', 'シンオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市刈屋西条', '35', '35216', '7560848', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '刈屋西条', 'カリヤニシジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市桜が丘', '35', '35216', '7560851', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '桜が丘', 'サクラガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市奥若山', '35', '35216', '7560852', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '奥若山', 'オクワカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市野来見', '35', '35216', '7560853', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '野来見', 'ノグルミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市叶松', '35', '35216', '7560854', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '叶松', 'カノウマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市えびす町', '35', '35216', '7560855', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', 'えびす町', 'エビスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市古開作', '35', '35216', '7560856', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '古開作', 'フルガイサク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市古開作団地', '35', '35216', '7560857', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '古開作団地', 'フルガイサクダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市波瀬', '35', '35216', '7560861', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '波瀬', 'ハゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市須恵西', '35', '35216', '7560862', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '須恵西', 'スエニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市上の台', '35', '35216', '7560863', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '上の台', 'ウエノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市西が迫', '35', '35216', '7560864', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '西が迫', 'ニシガサコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市田の尻', '35', '35216', '7560865', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '田の尻', 'タノシリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市大浜', '35', '35216', '7560866', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '大浜', 'オオハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市あさひが丘', '35', '35216', '7560871', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', 'あさひが丘', 'アサヒガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市浜河内', '35', '35216', '7560872', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '浜河内', 'ハマゴウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市大須恵', '35', '35216', '7560873', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '大須恵', 'オオズエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市本山町', '35', '35216', '7560874', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '本山町', 'モトヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市南松浜', '35', '35216', '7560875', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '南松浜', 'ミナミマツハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市本山団地', '35', '35216', '7560876', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '本山団地', 'モトヤマダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市松浜', '35', '35216', '7560877', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '松浜', 'マツハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市松浜団地', '35', '35216', '7560878', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '松浜団地', 'マツハマダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市東須恵', '35', '35216', '7560879', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '東須恵', 'ヒガシスエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市笹尾東', '35', '35216', '7560881', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '笹尾東', 'ササオヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市須田ノ木', '35', '35216', '7560882', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '須田ノ木', 'スダノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市東須田の木', '35', '35216', '7560883', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '東須田の木', 'ヒガシスダノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市大学通', '35', '35216', '7560884', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '大学通', 'ダイガクドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市西沖', '35', '35216', '7560885', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '西沖', 'ニシオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市夏目', '35', '35216', '7560886', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '夏目', 'ナツメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市松角', '35', '35216', '7560887', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '松角', 'マツカク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市笹尾西', '35', '35216', '7560888', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '笹尾西', 'ササオニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市須恵東', '35', '35216', '7560889', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '須恵東', 'スエヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市厚狭', '35', '35216', '7570001', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '厚狭', 'アサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市郡', '35', '35216', '7570002', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '郡', 'コオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市山野井', '35', '35216', '7570003', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '山野井', 'ヤマノイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市山川', '35', '35216', '7570004', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '山川', 'ヤマカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市鴨庄', '35', '35216', '7570005', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '鴨庄', 'カモノショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市津布田', '35', '35216', '7570011', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '津布田', 'ツブタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市埴生', '35', '35216', '7570012', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '埴生', 'ハブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県山陽小野田市福田', '35', '35216', '7570013', '山口県', 'ヤマグチケン', '山陽小野田市', 'サンヨウオノダシ', '福田', 'フクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市芦河内', '35', '35202', '7570211', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '芦河内', 'アシガワチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市今富', '35', '35202', '7570212', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '今富', 'イマドミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市奥万倉', '35', '35202', '7570213', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '奥万倉', 'オクマグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市西万倉', '35', '35202', '7570214', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '西万倉', 'ニシマグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市東万倉', '35', '35202', '7570215', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '東万倉', 'ヒガシマグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市船木', '35', '35202', '7570216', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '船木', 'フナキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市矢矯', '35', '35202', '7570217', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '矢矯', 'ヤハギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市東吉部', '35', '35202', '7570401', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '東吉部', 'ヒガシキベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市西吉部', '35', '35202', '7570402', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '西吉部', 'ニシキベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県萩市', '35', '35204', '7580000', '山口県', 'ヤマグチケン', '萩市', 'ハギシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('94644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県萩市相島', '35', '35204', '7580001', '山口県', 'ヤマグチケン', '萩市', 'ハギシ', '相島', 'アイシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県萩市櫃島', '35', '35204', '7580002', '山口県', 'ヤマグチケン', '萩市', 'ハギシ', '櫃島', 'ヒツシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県萩市大島', '35', '35204', '7580003', '山口県', 'ヤマグチケン', '萩市', 'ハギシ', '大島', 'オオシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県萩市肥島', '35', '35204', '7580004', '山口県', 'ヤマグチケン', '萩市', 'ハギシ', '肥島', 'ヒシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県萩市椿東', '35', '35204', '7580011', '山口県', 'ヤマグチケン', '萩市', 'ハギシ', '椿東', 'チントウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県萩市今古萩町', '35', '35204', '7580021', '山口県', 'ヤマグチケン', '萩市', 'ハギシ', '今古萩町', 'イマフルハギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県萩市浜崎町', '35', '35204', '7580022', '山口県', 'ヤマグチケン', '萩市', 'ハギシ', '浜崎町', 'ハマサキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県萩市浜崎新町', '35', '35204', '7580023', '山口県', 'ヤマグチケン', '萩市', 'ハギシ', '浜崎新町', 'ハマサキシンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県萩市東浜崎町', '35', '35204', '7580024', '山口県', 'ヤマグチケン', '萩市', 'ハギシ', '東浜崎町', 'ヒガシハマサキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県萩市土原', '35', '35204', '7580025', '山口県', 'ヤマグチケン', '萩市', 'ハギシ', '土原', 'ヒジワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県萩市古萩町', '35', '35204', '7580026', '山口県', 'ヤマグチケン', '萩市', 'ハギシ', '古萩町', 'フルハギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県萩市吉田町', '35', '35204', '7580027', '山口県', 'ヤマグチケン', '萩市', 'ハギシ', '吉田町', 'ヨシダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県萩市川島', '35', '35204', '7580031', '山口県', 'ヤマグチケン', '萩市', 'ハギシ', '川島', 'カワシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県萩市北古萩町', '35', '35204', '7580032', '山口県', 'ヤマグチケン', '萩市', 'ハギシ', '北古萩町', 'キタフルハギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県萩市恵美須町', '35', '35204', '7580033', '山口県', 'ヤマグチケン', '萩市', 'ハギシ', '恵美須町', 'エビスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県萩市熊谷町', '35', '35204', '7580034', '山口県', 'ヤマグチケン', '萩市', 'ハギシ', '熊谷町', 'クマガヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県萩市細工町', '35', '35204', '7580035', '山口県', 'ヤマグチケン', '萩市', 'ハギシ', '細工町', 'サイクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県萩市塩屋町', '35', '35204', '7580036', '山口県', 'ヤマグチケン', '萩市', 'ハギシ', '塩屋町', 'シオヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県萩市津守町', '35', '35204', '7580037', '山口県', 'ヤマグチケン', '萩市', 'ハギシ', '津守町', 'ツモリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県萩市江向', '35', '35204', '7580041', '山口県', 'ヤマグチケン', '萩市', 'ハギシ', '江向', 'エムカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県萩市御許町', '35', '35204', '7580042', '山口県', 'ヤマグチケン', '萩市', 'ハギシ', '御許町', 'オモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県萩市上五間町', '35', '35204', '7580043', '山口県', 'ヤマグチケン', '萩市', 'ハギシ', '上五間町', 'カミゴケンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県萩市下五間町', '35', '35204', '7580043', '山口県', 'ヤマグチケン', '萩市', 'ハギシ', '下五間町', 'シモゴケンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県萩市唐樋町', '35', '35204', '7580044', '山口県', 'ヤマグチケン', '萩市', 'ハギシ', '唐樋町', 'カラヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県萩市米屋町', '35', '35204', '7580045', '山口県', 'ヤマグチケン', '萩市', 'ハギシ', '米屋町', 'コメヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県萩市西田町', '35', '35204', '7580046', '山口県', 'ヤマグチケン', '萩市', 'ハギシ', '西田町', 'ニシタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県萩市東田町', '35', '35204', '7580047', '山口県', 'ヤマグチケン', '萩市', 'ハギシ', '東田町', 'ヒガシタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県萩市油屋町', '35', '35204', '7580051', '山口県', 'ヤマグチケン', '萩市', 'ハギシ', '油屋町', 'アブラヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県萩市今魚店町', '35', '35204', '7580052', '山口県', 'ヤマグチケン', '萩市', 'ハギシ', '今魚店町', 'イマウオノタナマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県萩市北片河町', '35', '35204', '7580053', '山口県', 'ヤマグチケン', '萩市', 'ハギシ', '北片河町', 'キタカタカワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県萩市樽屋町', '35', '35204', '7580054', '山口県', 'ヤマグチケン', '萩市', 'ハギシ', '樽屋町', 'タルヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県萩市春若町', '35', '35204', '7580055', '山口県', 'ヤマグチケン', '萩市', 'ハギシ', '春若町', 'ハルワカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県萩市古魚店町', '35', '35204', '7580056', '山口県', 'ヤマグチケン', '萩市', 'ハギシ', '古魚店町', 'フルウオノタナマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県萩市堀内', '35', '35204', '7580057', '山口県', 'ヤマグチケン', '萩市', 'ハギシ', '堀内', 'ホリウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県萩市椿', '35', '35204', '7580061', '山口県', 'ヤマグチケン', '萩市', 'ハギシ', '椿', 'ツバキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県萩市橋本町', '35', '35204', '7580062', '山口県', 'ヤマグチケン', '萩市', 'ハギシ', '橋本町', 'ハシモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県萩市山田', '35', '35204', '7580063', '山口県', 'ヤマグチケン', '萩市', 'ハギシ', '山田', 'ヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県萩市瓦町', '35', '35204', '7580071', '山口県', 'ヤマグチケン', '萩市', 'ハギシ', '瓦町', 'カワラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県萩市呉服町', '35', '35204', '7580072', '山口県', 'ヤマグチケン', '萩市', 'ハギシ', '呉服町', 'ゴフクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県萩市河添', '35', '35204', '7580073', '山口県', 'ヤマグチケン', '萩市', 'ハギシ', '河添', 'コウゾエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県萩市平安古町', '35', '35204', '7580074', '山口県', 'ヤマグチケン', '萩市', 'ハギシ', '平安古町', 'ヒヤコマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県萩市南片河', '35', '35204', '7580076', '山口県', 'ヤマグチケン', '萩市', 'ハギシ', '南片河', 'ミナミカタカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県萩市南古萩町', '35', '35204', '7580077', '山口県', 'ヤマグチケン', '萩市', 'ハギシ', '南古萩町', 'ミナミフルハギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県萩市川上', '35', '35204', '7580141', '山口県', 'ヤマグチケン', '萩市', 'ハギシ', '川上', 'カワカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県萩市福井上', '35', '35204', '7580211', '山口県', 'ヤマグチケン', '萩市', 'ハギシ', '福井上', 'フクイカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県萩市福井下', '35', '35204', '7580212', '山口県', 'ヤマグチケン', '萩市', 'ハギシ', '福井下', 'フクイシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県萩市黒川', '35', '35204', '7580213', '山口県', 'ヤマグチケン', '萩市', 'ハギシ', '黒川', 'クロガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県萩市片俣', '35', '35204', '7580301', '山口県', 'ヤマグチケン', '萩市', 'ハギシ', '片俣', 'カタマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県萩市高佐上', '35', '35204', '7580302', '山口県', 'ヤマグチケン', '萩市', 'ハギシ', '高佐上', 'タカサカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県萩市高佐下', '35', '35204', '7580303', '山口県', 'ヤマグチケン', '萩市', 'ハギシ', '高佐下', 'タカサシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県萩市吉部上', '35', '35204', '7580304', '山口県', 'ヤマグチケン', '萩市', 'ハギシ', '吉部上', 'キベカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県萩市吉部下', '35', '35204', '7580305', '山口県', 'ヤマグチケン', '萩市', 'ハギシ', '吉部下', 'キベシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県萩市紫福', '35', '35204', '7580501', '山口県', 'ヤマグチケン', '萩市', 'ハギシ', '紫福', 'シブキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県阿武郡阿武町福田下', '35', '35502', '7580611', '山口県', 'ヤマグチケン', '阿武郡阿武町', 'アブグンアブチョウ', '福田下', 'フクダシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県阿武郡阿武町福田上', '35', '35502', '7580612', '山口県', 'ヤマグチケン', '阿武郡阿武町', 'アブグンアブチョウ', '福田上', 'フクダカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県阿武郡阿武町宇生賀', '35', '35502', '7580613', '山口県', 'ヤマグチケン', '阿武郡阿武町', 'アブグンアブチョウ', '宇生賀', 'ウブカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県萩市見島', '35', '35204', '7580701', '山口県', 'ヤマグチケン', '萩市', 'ハギシ', '見島', 'ミシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市棚井', '35', '35202', '7590121', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '棚井', 'タナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市吉見', '35', '35202', '7590122', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '吉見', 'ヨシミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市末信', '35', '35202', '7590123', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '末信', 'スエノブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市広瀬', '35', '35202', '7590124', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '広瀬', 'ヒロセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市荒瀬', '35', '35202', '7590131', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '荒瀬', 'アラセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市山中', '35', '35202', '7590132', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '山中', 'ヤマナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市車地', '35', '35202', '7590133', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '車地', 'クルマジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市善和', '35', '35202', '7590134', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '善和', 'ヨシワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市瓜生野', '35', '35202', '7590135', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '瓜生野', 'ウリュウノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市木田', '35', '35202', '7590136', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '木田', 'キダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市山の手町', '35', '35202', '7590201', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '山の手町', 'ヤマノテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市沖ノ旦', '35', '35202', '7590202', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '沖ノ旦', 'オキノダン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市中野開作', '35', '35202', '7590203', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '中野開作', 'ナカノガイサク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市妻崎開作', '35', '35202', '7590204', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '妻崎開作', 'ツマザキガイサク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市西沖の山', '35', '35202', '7590205', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '西沖の山', 'ニシオキノヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市東須恵', '35', '35202', '7590206', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '東須恵', 'ヒガシスエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県宇部市際波', '35', '35202', '7590207', '山口県', 'ヤマグチケン', '宇部市', 'ウベシ', '際波', 'キワナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県阿武郡阿東町生雲東分', '35', '35504', '7591231', '山口県', 'ヤマグチケン', '阿武郡阿東町', 'アブグンアトウチョウ', '生雲東分', 'イクモヒガシブン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県阿武郡阿東町篠目', '35', '35504', '7591232', '山口県', 'ヤマグチケン', '阿武郡阿東町', 'アブグンアトウチョウ', '篠目', 'シノメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県阿武郡阿東町生雲西分', '35', '35504', '7591341', '山口県', 'ヤマグチケン', '阿武郡阿東町', 'アブグンアトウチョウ', '生雲西分', 'イクモニシブン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県阿武郡阿東町生雲中', '35', '35504', '7591342', '山口県', 'ヤマグチケン', '阿武郡阿東町', 'アブグンアトウチョウ', '生雲中', 'イクモナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県阿武郡阿東町蔵目喜', '35', '35504', '7591343', '山口県', 'ヤマグチケン', '阿武郡阿東町', 'アブグンアトウチョウ', '蔵目喜', 'ゾウメキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県阿武郡阿東町地福上', '35', '35504', '7591421', '山口県', 'ヤマグチケン', '阿武郡阿東町', 'アブグンアトウチョウ', '地福上', 'ジフクカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県阿武郡阿東町地福下', '35', '35504', '7591422', '山口県', 'ヤマグチケン', '阿武郡阿東町', 'アブグンアトウチョウ', '地福下', 'ジフクシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県阿武郡阿東町', '35', '35504', '7591500', '山口県', 'ヤマグチケン', '阿武郡阿東町', 'アブグンアトウチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('94739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県阿武郡阿東町徳佐上', '35', '35504', '7591511', '山口県', 'ヤマグチケン', '阿武郡阿東町', 'アブグンアトウチョウ', '徳佐上', 'トクサカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県阿武郡阿東町徳佐中', '35', '35504', '7591512', '山口県', 'ヤマグチケン', '阿武郡阿東町', 'アブグンアトウチョウ', '徳佐中', 'トクサナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県阿武郡阿東町徳佐下', '35', '35504', '7591513', '山口県', 'ヤマグチケン', '阿武郡阿東町', 'アブグンアトウチョウ', '徳佐下', 'トクサシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県阿武郡阿東町嘉年上', '35', '35504', '7591601', '山口県', 'ヤマグチケン', '阿武郡阿東町', 'アブグンアトウチョウ', '嘉年上', 'カネカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県阿武郡阿東町嘉年下', '35', '35504', '7591602', '山口県', 'ヤマグチケン', '阿武郡阿東町', 'アブグンアトウチョウ', '嘉年下', 'カネシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県美祢市伊佐町堀越', '35', '35213', '7592131', '山口県', 'ヤマグチケン', '美祢市', 'ミネシ', '伊佐町堀越', 'イサチョウホリコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県美祢市東厚保町山中', '35', '35213', '7592141', '山口県', 'ヤマグチケン', '美祢市', 'ミネシ', '東厚保町山中', 'ヒガシアツチョウヤマナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県美祢市東厚保町川東', '35', '35213', '7592142', '山口県', 'ヤマグチケン', '美祢市', 'ミネシ', '東厚保町川東', 'ヒガシアツチョウカワヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県美祢市西厚保町本郷', '35', '35213', '7592151', '山口県', 'ヤマグチケン', '美祢市', 'ミネシ', '西厚保町本郷', 'ニシアツチョウホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県美祢市西厚保町原', '35', '35213', '7592152', '山口県', 'ヤマグチケン', '美祢市', 'ミネシ', '西厚保町原', 'ニシアツチョウハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県美祢市', '35', '35213', '7592200', '山口県', 'ヤマグチケン', '美祢市', 'ミネシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('94750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県美祢市大嶺町北分', '35', '35213', '7592211', '山口県', 'ヤマグチケン', '美祢市', 'ミネシ', '大嶺町北分', 'オオミネチョウキタブン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県美祢市大嶺町東分', '35', '35213', '7592212', '山口県', 'ヤマグチケン', '美祢市', 'ミネシ', '大嶺町東分', 'オオミネチョウヒガシブン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県美祢市大嶺町西分', '35', '35213', '7592213', '山口県', 'ヤマグチケン', '美祢市', 'ミネシ', '大嶺町西分', 'オオミネチョウニシブン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県美祢市大嶺町奥分', '35', '35213', '7592214', '山口県', 'ヤマグチケン', '美祢市', 'ミネシ', '大嶺町奥分', 'オオミネチョウオクブン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県美祢市伊佐町河原', '35', '35213', '7592221', '山口県', 'ヤマグチケン', '美祢市', 'ミネシ', '伊佐町河原', 'イサチョウカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県美祢市伊佐町伊佐', '35', '35213', '7592222', '山口県', 'ヤマグチケン', '美祢市', 'ミネシ', '伊佐町伊佐', 'イサチョウイサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県美祢市伊佐町奥万倉', '35', '35213', '7592223', '山口県', 'ヤマグチケン', '美祢市', 'ミネシ', '伊佐町奥万倉', 'イサチョウオクマグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県美祢市於福町上駅前', '35', '35213', '7592301', '山口県', 'ヤマグチケン', '美祢市', 'ミネシ', '於福町上', 'オフクチョウカミ', null, null, '駅前', 'エキマエ');
INSERT INTO `ms_addresses` VALUES ('94759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県美祢市於福町上岡田', '35', '35213', '7592301', '山口県', 'ヤマグチケン', '美祢市', 'ミネシ', '於福町上', 'オフクチョウカミ', null, null, '岡田', 'オカダ');
INSERT INTO `ms_addresses` VALUES ('94760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県美祢市於福町上上田代', '35', '35213', '7592301', '山口県', 'ヤマグチケン', '美祢市', 'ミネシ', '於福町上', 'オフクチョウカミ', null, null, '上田代', 'カミタシロ');
INSERT INTO `ms_addresses` VALUES ('94761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県美祢市於福町上栗ケ原', '35', '35213', '7592301', '山口県', 'ヤマグチケン', '美祢市', 'ミネシ', '於福町上', 'オフクチョウカミ', null, null, '栗ケ原', 'クリガハラ');
INSERT INTO `ms_addresses` VALUES ('94762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県美祢市於福町上下田代', '35', '35213', '7592301', '山口県', 'ヤマグチケン', '美祢市', 'ミネシ', '於福町上', 'オフクチョウカミ', null, null, '下田代', 'シモタシロ');
INSERT INTO `ms_addresses` VALUES ('94763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県美祢市於福町上神柳', '35', '35213', '7592301', '山口県', 'ヤマグチケン', '美祢市', 'ミネシ', '於福町上', 'オフクチョウカミ', null, null, '神柳', 'シンリュウ');
INSERT INTO `ms_addresses` VALUES ('94764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県美祢市於福町上大明', '35', '35213', '7592301', '山口県', 'ヤマグチケン', '美祢市', 'ミネシ', '於福町上', 'オフクチョウカミ', null, null, '大明', 'タイメイ');
INSERT INTO `ms_addresses` VALUES ('94765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県美祢市於福町上立石', '35', '35213', '7592301', '山口県', 'ヤマグチケン', '美祢市', 'ミネシ', '於福町上', 'オフクチョウカミ', null, null, '立石', 'タテイシ');
INSERT INTO `ms_addresses` VALUES ('94766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県美祢市於福町上西寺', '35', '35213', '7592301', '山口県', 'ヤマグチケン', '美祢市', 'ミネシ', '於福町上', 'オフクチョウカミ', null, null, '西寺', 'ニシデラ');
INSERT INTO `ms_addresses` VALUES ('94767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県美祢市於福町上平野', '35', '35213', '7592301', '山口県', 'ヤマグチケン', '美祢市', 'ミネシ', '於福町上', 'オフクチョウカミ', null, null, '平野', 'ヒラノ');
INSERT INTO `ms_addresses` VALUES ('94768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県美祢市於福町上古屋', '35', '35213', '7592301', '山口県', 'ヤマグチケン', '美祢市', 'ミネシ', '於福町上', 'オフクチョウカミ', null, null, '古屋', 'フルヤ');
INSERT INTO `ms_addresses` VALUES ('94769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県美祢市於福町上宗済', '35', '35213', '7592301', '山口県', 'ヤマグチケン', '美祢市', 'ミネシ', '於福町上', 'オフクチョウカミ', null, null, '宗済', 'ムネズミ');
INSERT INTO `ms_addresses` VALUES ('94770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県美祢市於福町上横道', '35', '35213', '7592301', '山口県', 'ヤマグチケン', '美祢市', 'ミネシ', '於福町上', 'オフクチョウカミ', null, null, '横道', 'ヨコミチ');
INSERT INTO `ms_addresses` VALUES ('94771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県美祢市於福町上竜現地', '35', '35213', '7592301', '山口県', 'ヤマグチケン', '美祢市', 'ミネシ', '於福町上', 'オフクチョウカミ', null, null, '竜現地', 'リュウゲンジ');
INSERT INTO `ms_addresses` VALUES ('94772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県美祢市於福町下入水', '35', '35213', '7592302', '山口県', 'ヤマグチケン', '美祢市', 'ミネシ', '於福町下', 'オフクチョウシモ', null, null, '入水', 'イリミズ');
INSERT INTO `ms_addresses` VALUES ('94773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県美祢市於福町下榎田', '35', '35213', '7592302', '山口県', 'ヤマグチケン', '美祢市', 'ミネシ', '於福町下', 'オフクチョウシモ', null, null, '榎田', 'エノキダ');
INSERT INTO `ms_addresses` VALUES ('94774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県美祢市於福町下金山', '35', '35213', '7592302', '山口県', 'ヤマグチケン', '美祢市', 'ミネシ', '於福町下', 'オフクチョウシモ', null, null, '金山', 'カネヤマ');
INSERT INTO `ms_addresses` VALUES ('94775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県美祢市於福町下小杉', '35', '35213', '7592302', '山口県', 'ヤマグチケン', '美祢市', 'ミネシ', '於福町下', 'オフクチョウシモ', null, null, '小杉', 'コスギ');
INSERT INTO `ms_addresses` VALUES ('94776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県美祢市於福町下砂地', '35', '35213', '7592302', '山口県', 'ヤマグチケン', '美祢市', 'ミネシ', '於福町下', 'オフクチョウシモ', null, null, '砂地', 'スナジ');
INSERT INTO `ms_addresses` VALUES ('94777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県美祢市於福町下台', '35', '35213', '7592302', '山口県', 'ヤマグチケン', '美祢市', 'ミネシ', '於福町下', 'オフクチョウシモ', null, null, '台', 'ダイ');
INSERT INTO `ms_addresses` VALUES ('94778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県美祢市於福町下西畑', '35', '35213', '7592302', '山口県', 'ヤマグチケン', '美祢市', 'ミネシ', '於福町下', 'オフクチョウシモ', null, null, '西畑', 'ニシバタ');
INSERT INTO `ms_addresses` VALUES ('94779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県美祢市於福町下萩原', '35', '35213', '7592302', '山口県', 'ヤマグチケン', '美祢市', 'ミネシ', '於福町下', 'オフクチョウシモ', null, null, '萩原', 'ハギワラ');
INSERT INTO `ms_addresses` VALUES ('94780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県美祢市於福町下東中村', '35', '35213', '7592302', '山口県', 'ヤマグチケン', '美祢市', 'ミネシ', '於福町下', 'オフクチョウシモ', null, null, '東中村', 'ヒガシナカムラ');
INSERT INTO `ms_addresses` VALUES ('94781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県美祢市於福町下平国木', '35', '35213', '7592302', '山口県', 'ヤマグチケン', '美祢市', 'ミネシ', '於福町下', 'オフクチョウシモ', null, null, '平国木', 'ヒラクニギ');
INSERT INTO `ms_addresses` VALUES ('94782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県美祢市於福町下緑ケ丘', '35', '35213', '7592302', '山口県', 'ヤマグチケン', '美祢市', 'ミネシ', '於福町下', 'オフクチョウシモ', null, null, '緑ケ丘', 'ミドリガオカ');
INSERT INTO `ms_addresses` VALUES ('94783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県美祢市於福町下宮の前', '35', '35213', '7592302', '山口県', 'ヤマグチケン', '美祢市', 'ミネシ', '於福町下', 'オフクチョウシモ', null, null, '宮の前', 'ミヤノマエ');
INSERT INTO `ms_addresses` VALUES ('94784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県萩市上田万', '35', '35204', '7593111', '山口県', 'ヤマグチケン', '萩市', 'ハギシ', '上田万', 'カミタマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県萩市下田万', '35', '35204', '7593112', '山口県', 'ヤマグチケン', '萩市', 'ハギシ', '下田万', 'シモタマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県萩市江崎', '35', '35204', '7593113', '山口県', 'ヤマグチケン', '萩市', 'ハギシ', '江崎', 'エサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県萩市上小川西分', '35', '35204', '7593201', '山口県', 'ヤマグチケン', '萩市', 'ハギシ', '上小川西分', 'カミオガワニシブン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県萩市上小川東分', '35', '35204', '7593202', '山口県', 'ヤマグチケン', '萩市', 'ハギシ', '上小川東分', 'カミオガワヒガシブン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県萩市中小川', '35', '35204', '7593203', '山口県', 'ヤマグチケン', '萩市', 'ハギシ', '中小川', 'ナカオガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県萩市下小川', '35', '35204', '7593204', '山口県', 'ヤマグチケン', '萩市', 'ハギシ', '下小川', 'シモオガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県萩市弥富上', '35', '35204', '7593301', '山口県', 'ヤマグチケン', '萩市', 'ハギシ', '弥富上', 'ヤドミカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県萩市弥富下', '35', '35204', '7593302', '山口県', 'ヤマグチケン', '萩市', 'ハギシ', '弥富下', 'ヤドミシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県萩市鈴野川', '35', '35204', '7593303', '山口県', 'ヤマグチケン', '萩市', 'ハギシ', '鈴野川', 'スズノガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県萩市須佐', '35', '35204', '7593411', '山口県', 'ヤマグチケン', '萩市', 'ハギシ', '須佐', 'スサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県阿武郡阿武町宇田', '35', '35502', '7593501', '山口県', 'ヤマグチケン', '阿武郡阿武町', 'アブグンアブチョウ', '宇田', 'ウタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県阿武郡阿武町惣郷', '35', '35502', '7593502', '山口県', 'ヤマグチケン', '阿武郡阿武町', 'アブグンアブチョウ', '惣郷', 'ソウゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県阿武郡阿武町', '35', '35502', '7593600', '山口県', 'ヤマグチケン', '阿武郡阿武町', 'アブグンアブチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('94798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県萩市大井', '35', '35204', '7593611', '山口県', 'ヤマグチケン', '萩市', 'ハギシ', '大井', 'オオイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県阿武郡阿武町木与', '35', '35502', '7593621', '山口県', 'ヤマグチケン', '阿武郡阿武町', 'アブグンアブチョウ', '木与', 'キヨ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県阿武郡阿武町奈古', '35', '35502', '7593622', '山口県', 'ヤマグチケン', '阿武郡阿武町', 'アブグンアブチョウ', '奈古', 'ナゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県萩市三見', '35', '35204', '7593721', '山口県', 'ヤマグチケン', '萩市', 'ハギシ', '三見', 'サンミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県長門市三隅上', '35', '35211', '7593801', '山口県', 'ヤマグチケン', '長門市', 'ナガトシ', '三隅上', 'ミスミカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県長門市三隅中', '35', '35211', '7593802', '山口県', 'ヤマグチケン', '長門市', 'ナガトシ', '三隅中', 'ミスミナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県長門市三隅下', '35', '35211', '7593803', '山口県', 'ヤマグチケン', '長門市', 'ナガトシ', '三隅下', 'ミスミシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県長門市', '35', '35211', '7594100', '山口県', 'ヤマグチケン', '長門市', 'ナガトシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('94806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県長門市東深川', '35', '35211', '7594101', '山口県', 'ヤマグチケン', '長門市', 'ナガトシ', '東深川', 'ヒガシフカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県長門市西深川', '35', '35211', '7594102', '山口県', 'ヤマグチケン', '長門市', 'ナガトシ', '西深川', 'ニシフカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県長門市深川湯本', '35', '35211', '7594103', '山口県', 'ヤマグチケン', '長門市', 'ナガトシ', '深川湯本', 'フカワユモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県長門市渋木', '35', '35211', '7594104', '山口県', 'ヤマグチケン', '長門市', 'ナガトシ', '渋木', 'シブキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県長門市真木', '35', '35211', '7594105', '山口県', 'ヤマグチケン', '長門市', 'ナガトシ', '真木', 'マキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県長門市仙崎', '35', '35211', '7594106', '山口県', 'ヤマグチケン', '長門市', 'ナガトシ', '仙崎', 'センザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県長門市通', '35', '35211', '7594107', '山口県', 'ヤマグチケン', '長門市', 'ナガトシ', '通', 'カヨイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県長門市俵山', '35', '35211', '7594211', '山口県', 'ヤマグチケン', '長門市', 'ナガトシ', '俵山', 'タワラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県長門市日置上', '35', '35211', '7594401', '山口県', 'ヤマグチケン', '長門市', 'ナガトシ', '日置上', 'ヘキカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県長門市日置中', '35', '35211', '7594402', '山口県', 'ヤマグチケン', '長門市', 'ナガトシ', '日置中', 'ヘキナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県長門市日置下', '35', '35211', '7594403', '山口県', 'ヤマグチケン', '長門市', 'ナガトシ', '日置下', 'ヘキシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県長門市日置野田', '35', '35211', '7594404', '山口県', 'ヤマグチケン', '長門市', 'ナガトシ', '日置野田', 'ヘキノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県長門市日置蔵小田', '35', '35211', '7594405', '山口県', 'ヤマグチケン', '長門市', 'ナガトシ', '日置蔵小田', 'ヘキクラオダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県長門市油谷蔵小田', '35', '35211', '7594501', '山口県', 'ヤマグチケン', '長門市', 'ナガトシ', '油谷蔵小田', 'ユヤクラオダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県長門市油谷久富', '35', '35211', '7594502', '山口県', 'ヤマグチケン', '長門市', 'ナガトシ', '油谷久富', 'ユヤヒサドミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県長門市油谷新別名', '35', '35211', '7594503', '山口県', 'ヤマグチケン', '長門市', 'ナガトシ', '油谷新別名', 'ユヤシンベツミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県長門市油谷河原', '35', '35211', '7594504', '山口県', 'ヤマグチケン', '長門市', 'ナガトシ', '油谷河原', 'ユヤカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県長門市油谷伊上', '35', '35211', '7594505', '山口県', 'ヤマグチケン', '長門市', 'ナガトシ', '油谷伊上', 'ユヤイガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県長門市油谷川尻', '35', '35211', '7594621', '山口県', 'ヤマグチケン', '長門市', 'ナガトシ', '油谷川尻', 'ユヤカワシリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県長門市油谷向津具上', '35', '35211', '7594622', '山口県', 'ヤマグチケン', '長門市', 'ナガトシ', '油谷向津具上', 'ユヤムカツクカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県長門市油谷向津具下', '35', '35211', '7594623', '山口県', 'ヤマグチケン', '長門市', 'ナガトシ', '油谷向津具下', 'ユヤムカツクシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県長門市油谷向津具下大浦', '35', '35211', '7594623', '山口県', 'ヤマグチケン', '長門市', 'ナガトシ', '油谷向津具下', 'ユヤムカツクシモ', null, null, '大浦', 'オオウラ');
INSERT INTO `ms_addresses` VALUES ('94832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県長門市油谷向津具下久津', '35', '35211', '7594623', '山口県', 'ヤマグチケン', '長門市', 'ナガトシ', '油谷向津具下', 'ユヤムカツクシモ', null, null, '久津', 'クヅ');
INSERT INTO `ms_addresses` VALUES ('94833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県長門市油谷後畑', '35', '35211', '7594711', '山口県', 'ヤマグチケン', '長門市', 'ナガトシ', '油谷後畑', 'ユヤウシロバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県長門市油谷津黄', '35', '35211', '7594712', '山口県', 'ヤマグチケン', '長門市', 'ナガトシ', '油谷津黄', 'ユヤツオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県長門市油谷角山', '35', '35211', '7594713', '山口県', 'ヤマグチケン', '長門市', 'ナガトシ', '油谷角山', 'ユヤカドヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市豊北町粟野', '35', '35201', '7595101', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '豊北町粟野', 'ホウホクチョウアワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市豊北町阿川', '35', '35201', '7595241', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '豊北町阿川', 'ホウホクチョウアガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市豊北町神田', '35', '35201', '7595331', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '豊北町神田', 'ホウホクチョウカンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市豊北町角島', '35', '35201', '7595332', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '豊北町角島', 'ホウホクチョウツノシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市豊北町滝部', '35', '35201', '7595511', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '豊北町滝部', 'ホウホクチョウタキベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市豊北町田耕', '35', '35201', '7595512', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '豊北町田耕', 'ホウホクチョウタスキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市豊北町神田上', '35', '35201', '7595513', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '豊北町神田上', 'ホウホクチョウカンダカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市豊北町北宇賀', '35', '35201', '7595513', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '豊北町北宇賀', 'ホウホクチョウキタウカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市豊北町神田上', '35', '35201', '7596121', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '豊北町神田上', 'ホウホクチョウカンダカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市豊北町矢玉', '35', '35201', '7596122', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '豊北町矢玉', 'ホウホクチョウヤタマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市豊浦町川棚', '35', '35201', '7596301', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '豊浦町川棚', 'トヨウラチョウカワタナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市豊浦町小串', '35', '35201', '7596302', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '豊浦町小串', 'トヨウラチョウコグシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市豊浦町宇賀', '35', '35201', '7596303', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '豊浦町宇賀', 'トヨウラチョウウカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市豊浦町吉永', '35', '35201', '7596311', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '豊浦町吉永', 'トヨウラチョウヨシナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市豊浦町黒井', '35', '35201', '7596312', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '豊浦町黒井', 'トヨウラチョウクロイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市豊浦町豊洋台', '35', '35201', '7596313', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '豊浦町豊洋台', 'トヨウラチョウホウヨウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市豊浦町豊洋台新町', '35', '35201', '7596313', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '豊浦町豊洋台新町', 'トヨウラチョウホウヨウダイシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市豊浦町厚母郷', '35', '35201', '7596314', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '豊浦町厚母郷', 'トヨウラチョウアツモゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市豊浦町室津上', '35', '35201', '7596315', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '豊浦町室津上', 'トヨウラチョウムロツカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市豊浦町室津下', '35', '35201', '7596316', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '豊浦町室津下', 'トヨウラチョウムロツシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市豊浦町涌田後地', '35', '35201', '7596317', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '豊浦町涌田後地', 'トヨウラチョウワイタウシロジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市吉見古宿町', '35', '35201', '7596521', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '吉見古宿町', 'ヨシミコジュクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市吉見竜王町', '35', '35201', '7596522', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '吉見竜王町', 'ヨシミリュウオウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市吉見下', '35', '35201', '7596523', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '吉見下', 'ヨシミシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市吉見上', '35', '35201', '7596524', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '吉見上', 'ヨシミカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市吉見里町', '35', '35201', '7596525', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '吉見里町', 'ヨシミサトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市吉見本町', '35', '35201', '7596531', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '吉見本町', 'ヨシミホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市吉見新町', '35', '35201', '7596532', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '吉見新町', 'ヨシミシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市永田本町', '35', '35201', '7596533', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '永田本町', 'ナガタホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市永田郷', '35', '35201', '7596534', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '永田郷', 'ナガタゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市吉母', '35', '35201', '7596541', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '吉母', 'ヨシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市蓋井島', '35', '35201', '7596542', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '蓋井島', 'フタオイジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市福江', '35', '35201', '7596601', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '福江', 'フクエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市蒲生野', '35', '35201', '7596602', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '蒲生野', 'カモウノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市安岡町', '35', '35201', '7596603', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '安岡町', 'ヤスオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市横野町', '35', '35201', '7596604', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '横野町', 'ヨコノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市安岡本町', '35', '35201', '7596611', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '安岡本町', 'ヤスオカホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市安岡駅前', '35', '35201', '7596612', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '安岡駅前', 'ヤスオカエキマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市富任町', '35', '35201', '7596613', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '富任町', 'トミトウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山口県下関市梶栗町', '35', '35201', '7596614', '山口県', 'ヤマグチケン', '下関市', 'シモノセキシ', '梶栗町', 'カジクリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市', '01', '01229', '0760000', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('94880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市', '37', '37201', '7600000', '香川県', 'カガワケン', '高松市', 'タカマツシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('94881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市新北町', '37', '37201', '7600001', '香川県', 'カガワケン', '高松市', 'タカマツシ', '新北町', 'シンキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市茜町', '37', '37201', '7600002', '香川県', 'カガワケン', '高松市', 'タカマツシ', '茜町', 'アカネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市西町', '37', '37201', '7600003', '香川県', 'カガワケン', '高松市', 'タカマツシ', '西町', 'ニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市西宝町', '37', '37201', '7600004', '香川県', 'カガワケン', '高松市', 'タカマツシ', '西宝町', 'サイホウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市宮脇町', '37', '37201', '7600005', '香川県', 'カガワケン', '高松市', 'タカマツシ', '宮脇町', 'ミヤワキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市亀岡町', '37', '37201', '7600006', '香川県', 'カガワケン', '高松市', 'タカマツシ', '亀岡町', 'カメオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市中央町', '37', '37201', '7600007', '香川県', 'カガワケン', '高松市', 'タカマツシ', '中央町', 'チュウオウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市中野町', '37', '37201', '7600008', '香川県', 'カガワケン', '高松市', 'タカマツシ', '中野町', 'ナカノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市峰山町', '37', '37201', '7600009', '香川県', 'カガワケン', '高松市', 'タカマツシ', '峰山町', 'ミネヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市北扇山', '01', '01229', '0760001', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', '北扇山', 'キタオウギヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市浜ノ町', '37', '37201', '7600011', '香川県', 'カガワケン', '高松市', 'タカマツシ', '浜ノ町', 'ハマノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市瀬戸内町', '37', '37201', '7600012', '香川県', 'カガワケン', '高松市', 'タカマツシ', '瀬戸内町', 'セトウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市扇町', '37', '37201', '7600013', '香川県', 'カガワケン', '高松市', 'タカマツシ', '扇町', 'オウギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市昭和町', '37', '37201', '7600014', '香川県', 'カガワケン', '高松市', 'タカマツシ', '昭和町', 'ショウワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市紫雲町', '37', '37201', '7600015', '香川県', 'カガワケン', '高松市', 'タカマツシ', '紫雲町', 'シウンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市幸町', '37', '37201', '7600016', '香川県', 'カガワケン', '高松市', 'タカマツシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市番町', '37', '37201', '7600017', '香川県', 'カガワケン', '高松市', 'タカマツシ', '番町', 'バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市天神前', '37', '37201', '7600018', '香川県', 'カガワケン', '高松市', 'タカマツシ', '天神前', 'テンジンマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市サンポート', '37', '37201', '7600019', '香川県', 'カガワケン', '高松市', 'タカマツシ', 'サンポート', 'サンポート', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市南扇山', '01', '01229', '0760002', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', '南扇山', 'ミナミオウギヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市錦町', '37', '37201', '7600020', '香川県', 'カガワケン', '高松市', 'タカマツシ', '錦町', 'ニシキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市西の丸町', '37', '37201', '7600021', '香川県', 'カガワケン', '高松市', 'タカマツシ', '西の丸町', 'ニシノマルチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市西内町', '37', '37201', '7600022', '香川県', 'カガワケン', '高松市', 'タカマツシ', '西内町', 'ニシウチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市寿町', '37', '37201', '7600023', '香川県', 'カガワケン', '高松市', 'タカマツシ', '寿町', 'コトブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市兵庫町', '37', '37201', '7600024', '香川県', 'カガワケン', '高松市', 'タカマツシ', '兵庫町', 'ヒョウゴマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市古新町', '37', '37201', '7600025', '香川県', 'カガワケン', '高松市', 'タカマツシ', '古新町', 'フルジンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市磨屋町', '37', '37201', '7600026', '香川県', 'カガワケン', '高松市', 'タカマツシ', '磨屋町', 'トギヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市紺屋町', '37', '37201', '7600027', '香川県', 'カガワケン', '高松市', 'タカマツシ', '紺屋町', 'コンヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市鍛冶屋町', '37', '37201', '7600028', '香川県', 'カガワケン', '高松市', 'タカマツシ', '鍛冶屋町', 'カジヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市丸亀町', '37', '37201', '7600029', '香川県', 'カガワケン', '高松市', 'タカマツシ', '丸亀町', 'マルガメマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市布部石綿', '01', '01229', '0760003', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', '布部石綿', 'ヌノベイシワタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市玉藻町', '37', '37201', '7600030', '香川県', 'カガワケン', '高松市', 'タカマツシ', '玉藻町', 'タマモチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市北浜町', '37', '37201', '7600031', '香川県', 'カガワケン', '高松市', 'タカマツシ', '北浜町', 'キタハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市本町', '37', '37201', '7600032', '香川県', 'カガワケン', '高松市', 'タカマツシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市丸の内', '37', '37201', '7600033', '香川県', 'カガワケン', '高松市', 'タカマツシ', '丸の内', 'マルノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市内町', '37', '37201', '7600034', '香川県', 'カガワケン', '高松市', 'タカマツシ', '内町', 'ウチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市鶴屋町', '37', '37201', '7600035', '香川県', 'カガワケン', '高松市', 'タカマツシ', '鶴屋町', 'ツルヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市城東町', '37', '37201', '7600036', '香川県', 'カガワケン', '高松市', 'タカマツシ', '城東町', 'ジョウトウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市東浜町', '37', '37201', '7600037', '香川県', 'カガワケン', '高松市', 'タカマツシ', '東浜町', 'ヒガシハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市井口町', '37', '37201', '7600038', '香川県', 'カガワケン', '高松市', 'タカマツシ', '井口町', 'イグチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市布部市街地', '01', '01229', '0760004', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', '布部市街地', 'ヌノベシガイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市片原町', '37', '37201', '7600040', '香川県', 'カガワケン', '高松市', 'タカマツシ', '片原町', 'カタハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市百間町', '37', '37201', '7600041', '香川県', 'カガワケン', '高松市', 'タカマツシ', '百間町', 'ヒャツケンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市大工町', '37', '37201', '7600042', '香川県', 'カガワケン', '高松市', 'タカマツシ', '大工町', 'ダイクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市今新町', '37', '37201', '7600043', '香川県', 'カガワケン', '高松市', 'タカマツシ', '今新町', 'イマジンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市御坊町', '37', '37201', '7600044', '香川県', 'カガワケン', '高松市', 'タカマツシ', '御坊町', 'ゴボウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市古馬場町', '37', '37201', '7600045', '香川県', 'カガワケン', '高松市', 'タカマツシ', '古馬場町', 'フルババチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市通町', '37', '37201', '7600046', '香川県', 'カガワケン', '高松市', 'タカマツシ', '通町', 'トオリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市塩屋町', '37', '37201', '7600047', '香川県', 'カガワケン', '高松市', 'タカマツシ', '塩屋町', 'シオヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市福田町', '37', '37201', '7600048', '香川県', 'カガワケン', '高松市', 'タカマツシ', '福田町', 'フクダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市八坂町', '37', '37201', '7600049', '香川県', 'カガワケン', '高松市', 'タカマツシ', '八坂町', 'ヤサカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市布部一', '01', '01229', '0760005', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', '布部一', 'ヌノベイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市亀井町', '37', '37201', '7600050', '香川県', 'カガワケン', '高松市', 'タカマツシ', '亀井町', 'カメイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市南新町', '37', '37201', '7600051', '香川県', 'カガワケン', '高松市', 'タカマツシ', '南新町', 'ミナミシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市瓦町', '37', '37201', '7600052', '香川県', 'カガワケン', '高松市', 'タカマツシ', '瓦町', 'カワラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市田町', '37', '37201', '7600053', '香川県', 'カガワケン', '高松市', 'タカマツシ', '田町', 'タマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市常磐町', '37', '37201', '7600054', '香川県', 'カガワケン', '高松市', 'タカマツシ', '常磐町', 'トキワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市観光通', '37', '37201', '7600055', '香川県', 'カガワケン', '高松市', 'タカマツシ', '観光通', 'カンコウドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市中新町', '37', '37201', '7600056', '香川県', 'カガワケン', '高松市', 'タカマツシ', '中新町', 'ナカジンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市旅籠町', '37', '37201', '7600057', '香川県', 'カガワケン', '高松市', 'タカマツシ', '旅籠町', 'ハタゴマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市東田町', '37', '37201', '7600058', '香川県', 'カガワケン', '高松市', 'タカマツシ', '東田町', 'ヒガシタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市西扇山', '01', '01229', '0760006', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', '西扇山', 'ニシオウギヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市末広町', '37', '37201', '7600060', '香川県', 'カガワケン', '高松市', 'タカマツシ', '末広町', 'スエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市築地町', '37', '37201', '7600061', '香川県', 'カガワケン', '高松市', 'タカマツシ', '築地町', 'ツキジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市塩上町', '37', '37201', '7600062', '香川県', 'カガワケン', '高松市', 'タカマツシ', '塩上町', 'シオガミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市多賀町', '37', '37201', '7600063', '香川県', 'カガワケン', '高松市', 'タカマツシ', '多賀町', 'タガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市朝日新町', '37', '37201', '7600064', '香川県', 'カガワケン', '高松市', 'タカマツシ', '朝日新町', 'アサヒシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市朝日町', '37', '37201', '7600065', '香川県', 'カガワケン', '高松市', 'タカマツシ', '朝日町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市福岡町', '37', '37201', '7600066', '香川県', 'カガワケン', '高松市', 'タカマツシ', '福岡町', 'フクオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市松福町', '37', '37201', '7600067', '香川県', 'カガワケン', '高松市', 'タカマツシ', '松福町', 'マツフクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市松島町', '37', '37201', '7600068', '香川県', 'カガワケン', '高松市', 'タカマツシ', '松島町', 'マツシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市南町', '01', '01229', '0760007', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', '南町', 'ミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市藤塚町', '37', '37201', '7600071', '香川県', 'カガワケン', '高松市', 'タカマツシ', '藤塚町', 'フジヅカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市花園町', '37', '37201', '7600072', '香川県', 'カガワケン', '高松市', 'タカマツシ', '花園町', 'ハナゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市栗林町', '37', '37201', '7600073', '香川県', 'カガワケン', '高松市', 'タカマツシ', '栗林町', 'リツリンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市桜町', '37', '37201', '7600074', '香川県', 'カガワケン', '高松市', 'タカマツシ', '桜町', 'サクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市楠上町', '37', '37201', '7600075', '香川県', 'カガワケン', '高松市', 'タカマツシ', '楠上町', 'クスガミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市観光町', '37', '37201', '7600076', '香川県', 'カガワケン', '高松市', 'タカマツシ', '観光町', 'カンコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市上福岡町', '37', '37201', '7600077', '香川県', 'カガワケン', '高松市', 'タカマツシ', '上福岡町', 'カミフクオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市今里町', '37', '37201', '7600078', '香川県', 'カガワケン', '高松市', 'タカマツシ', '今里町', 'イマザトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市松縄町', '37', '37201', '7600079', '香川県', 'カガワケン', '高松市', 'タカマツシ', '松縄町', 'マツナワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市扇町', '01', '01229', '0760008', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', '扇町', 'オウギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市木太町', '37', '37201', '7600080', '香川県', 'カガワケン', '高松市', 'タカマツシ', '木太町', 'キタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市男木町', '37', '37201', '7600091', '香川県', 'カガワケン', '高松市', 'タカマツシ', '男木町', 'オギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市女木町', '37', '37201', '7600092', '香川県', 'カガワケン', '高松市', 'タカマツシ', '女木町', 'メギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市鶴市町台山', '37', '37201', '7600093', '香川県', 'カガワケン', '高松市', 'タカマツシ', '鶴市町', 'ツルイチチョウ', null, null, '台山', 'ダイヤマ');
INSERT INTO `ms_addresses` VALUES ('94967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市末広町', '01', '01229', '0760011', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', '末広町', 'スエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市下五区', '01', '01229', '0760012', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', '下五区', 'シモゴク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市中五区', '01', '01229', '0760013', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', '中五区', 'ナカゴク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市上五区', '01', '01229', '0760014', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', '上五区', 'カミゴク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市上御料', '01', '01229', '0760015', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', '上御料', 'カミゴリョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市中御料', '01', '01229', '0760016', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', '中御料', 'ナカゴリョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市下御料', '01', '01229', '0760017', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', '下御料', 'シモゴリョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市弥生町', '01', '01229', '0760018', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', '弥生町', 'ヤヨイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市緑町', '01', '01229', '0760021', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', '緑町', 'ミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市若葉町', '01', '01229', '0760022', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', '若葉町', 'ワカバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市栄町', '01', '01229', '0760023', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市幸町', '01', '01229', '0760024', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市日の出町', '01', '01229', '0760025', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', '日の出町', 'ヒノデマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市朝日町', '01', '01229', '0760026', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', '朝日町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市花園町', '01', '01229', '0760027', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', '花園町', 'ハナゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市錦町', '01', '01229', '0760028', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', '錦町', 'ニシキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市本町', '01', '01229', '0760031', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', '本町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市若松町', '01', '01229', '0760032', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', '若松町', 'ワカマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市新富町', '01', '01229', '0760033', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', '新富町', 'シントミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市北の峰町', '01', '01229', '0760034', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', '北の峰町', 'キタノミネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市学田三区', '01', '01229', '0760035', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', '学田三区', 'ガクデンサンク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市島ノ下', '01', '01229', '0760036', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', '島ノ下', 'シマノシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市西町', '01', '01229', '0760037', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', '西町', 'ニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市桂木町', '01', '01229', '0760038', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', '桂木町', 'カツラギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市信濃沢', '01', '01229', '0760039', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', '信濃沢', 'シナノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市東鳥沼', '01', '01229', '0760041', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', '東鳥沼', 'ヒガシトリヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市西鳥沼', '01', '01229', '0760042', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', '西鳥沼', 'ニシトリヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市南大沼', '01', '01229', '0760043', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', '南大沼', 'ミナミオオヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市北大沼', '01', '01229', '0760044', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', '北大沼', 'キタオオヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市東学田二区', '01', '01229', '0760045', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', '東学田二区', 'ヒガシガクデンニク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市北斗町', '01', '01229', '0760046', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', '北斗町', 'ホクトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市西学田二区', '01', '01229', '0760047', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', '西学田二区', 'ニシガクデンニク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('94999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市清水山', '01', '01229', '0760048', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', '清水山', 'シミズヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市東麻町', '01', '01229', '0760051', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', '東麻町', 'ヒガシアサマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市南麻町', '01', '01229', '0760052', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', '南麻町', 'ミナミアサマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市東町', '01', '01229', '0760053', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', '東町', 'ヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市春日町', '01', '01229', '0760054', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', '春日町', 'カスガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市西麻町', '01', '01229', '0760055', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', '西麻町', 'ニシアサマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市瑞穂町', '01', '01229', '0760056', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', '瑞穂町', 'ミズホチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市住吉町', '01', '01229', '0760057', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', '住吉町', 'スミヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市新光町', '01', '01229', '0760058', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', '新光町', 'シンコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市北麻町', '01', '01229', '0760059', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', '北麻町', 'キタアサマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道芦別市泉', '01', '01216', '0760081', '北海道', 'ホッカイドウ', '芦別市', 'アシベツシ', '泉', 'イズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市麓郷市街地', '01', '01229', '0760161', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', '麓郷市街地', 'ロクゴウシガイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市東麓郷', '01', '01229', '0760162', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', '東麓郷', 'ヒガシロクゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市西麓郷', '01', '01229', '0760163', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', '西麓郷', 'ニシロクゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市南麓郷', '01', '01229', '0760164', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', '南麓郷', 'ミナミロクゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市北麓郷', '01', '01229', '0760165', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', '北麓郷', 'キタロクゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市布礼別市街地', '01', '01229', '0760171', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', '布礼別市街地', 'フレベツシガイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市東布礼別', '01', '01229', '0760172', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', '東布礼別', 'ヒガシフレベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市西布礼別', '01', '01229', '0760173', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', '西布礼別', 'ニシフレベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市南布礼別', '01', '01229', '0760174', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', '南布礼別', 'ミナミフレベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市北布礼別', '01', '01229', '0760175', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', '北布礼別', 'キタフレベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市中布礼別', '01', '01229', '0760176', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', '中布礼別', 'ナカフレベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市東富丘', '01', '01229', '0760181', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', '東富丘', 'ヒガシトミオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市西富丘', '01', '01229', '0760182', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', '西富丘', 'ニシトミオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市富丘更生', '01', '01229', '0760183', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', '富丘更生', 'トミオカコウセイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市八幡丘', '01', '01229', '0760184', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', '八幡丘', 'ヤハタオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市西達布', '01', '01229', '0760201', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', '西達布', 'ニシタップ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市東山', '01', '01229', '0760202', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', '東山', 'ヒガシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市老節布', '01', '01229', '0760203', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', '老節布', 'ロウセップ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市平沢', '01', '01229', '0760204', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', '平沢', 'タイラザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市春日町', '37', '37201', '7610101', '香川県', 'カガワケン', '高松市', 'タカマツシ', '春日町', 'カスガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市新田町甲', '37', '37201', '7610102', '香川県', 'カガワケン', '高松市', 'タカマツシ', '新田町甲', 'シンデンチョウコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市新田町乙', '37', '37201', '7610103', '香川県', 'カガワケン', '高松市', 'タカマツシ', '新田町乙', 'シンデンチョウオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市高松町', '37', '37201', '7610104', '香川県', 'カガワケン', '高松市', 'タカマツシ', '高松町', 'タカマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市屋島東町', '37', '37201', '7610111', '香川県', 'カガワケン', '高松市', 'タカマツシ', '屋島東町', 'ヤシマヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市屋島中町', '37', '37201', '7610112', '香川県', 'カガワケン', '高松市', 'タカマツシ', '屋島中町', 'ヤシマナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市屋島西町', '37', '37201', '7610113', '香川県', 'カガワケン', '高松市', 'タカマツシ', '屋島西町', 'ヤシマニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市牟礼町牟礼', '37', '37201', '7610121', '香川県', 'カガワケン', '高松市', 'タカマツシ', '牟礼町牟礼', 'ムレチョウムレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市牟礼町大町', '37', '37201', '7610122', '香川県', 'カガワケン', '高松市', 'タカマツシ', '牟礼町大町', 'ムレチョウオオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市牟礼町原', '37', '37201', '7610123', '香川県', 'カガワケン', '高松市', 'タカマツシ', '牟礼町原', 'ムレチョウハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市庵治町', '37', '37201', '7610130', '香川県', 'カガワケン', '高松市', 'タカマツシ', '庵治町', 'アジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市林町', '37', '37201', '7610301', '香川県', 'カガワケン', '高松市', 'タカマツシ', '林町', 'ハヤシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市上林町', '37', '37201', '7610302', '香川県', 'カガワケン', '高松市', 'タカマツシ', '上林町', 'カミハヤシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市六条町', '37', '37201', '7610303', '香川県', 'カガワケン', '高松市', 'タカマツシ', '六条町', 'ロクジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市元山町', '37', '37201', '7610311', '香川県', 'カガワケン', '高松市', 'タカマツシ', '元山町', 'モトヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市東山崎町', '37', '37201', '7610312', '香川県', 'カガワケン', '高松市', 'タカマツシ', '東山崎町', 'ヒガシヤマサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市下田井町', '37', '37201', '7610313', '香川県', 'カガワケン', '高松市', 'タカマツシ', '下田井町', 'シモタイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市前田西町', '37', '37201', '7610321', '香川県', 'カガワケン', '高松市', 'タカマツシ', '前田西町', 'マエダニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市前田東町', '37', '37201', '7610322', '香川県', 'カガワケン', '高松市', 'タカマツシ', '前田東町', 'マエダヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市亀田町', '37', '37201', '7610323', '香川県', 'カガワケン', '高松市', 'タカマツシ', '亀田町', 'カメダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市小村町', '37', '37201', '7610431', '香川県', 'カガワケン', '高松市', 'タカマツシ', '小村町', 'オモレチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市亀田南町', '37', '37201', '7610432', '香川県', 'カガワケン', '高松市', 'タカマツシ', '亀田南町', 'カメダミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市十川西町', '37', '37201', '7610433', '香川県', 'カガワケン', '高松市', 'タカマツシ', '十川西町', 'ソガワニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市十川東町', '37', '37201', '7610434', '香川県', 'カガワケン', '高松市', 'タカマツシ', '十川東町', 'ソガワヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市由良町', '37', '37201', '7610441', '香川県', 'カガワケン', '高松市', 'タカマツシ', '由良町', 'ユラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市川島本町', '37', '37201', '7610442', '香川県', 'カガワケン', '高松市', 'タカマツシ', '川島本町', 'カワシマホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市川島東町', '37', '37201', '7610443', '香川県', 'カガワケン', '高松市', 'タカマツシ', '川島東町', 'カワシマヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市池田町', '37', '37201', '7610444', '香川県', 'カガワケン', '高松市', 'タカマツシ', '池田町', 'イケダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市西植田町', '37', '37201', '7610445', '香川県', 'カガワケン', '高松市', 'タカマツシ', '西植田町', 'ニシウエタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市東植田町', '37', '37201', '7610446', '香川県', 'カガワケン', '高松市', 'タカマツシ', '東植田町', 'ヒガシウエタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市三谷町', '37', '37201', '7610450', '香川県', 'カガワケン', '高松市', 'タカマツシ', '三谷町', 'ミタニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県木田郡三木町田中', '37', '37341', '7610611', '香川県', 'カガワケン', '木田郡三木町', 'キタグンミキチョウ', '田中', 'タナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県木田郡三木町氷上', '37', '37341', '7610612', '香川県', 'カガワケン', '木田郡三木町', 'キタグンミキチョウ', '氷上', 'ヒカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県木田郡三木町上高岡', '37', '37341', '7610613', '香川県', 'カガワケン', '木田郡三木町', 'キタグンミキチョウ', '上高岡', 'カミタカオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県木田郡三木町朝倉', '37', '37341', '7610614', '香川県', 'カガワケン', '木田郡三木町', 'キタグンミキチョウ', '朝倉', 'アサクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県木田郡三木町小蓑', '37', '37341', '7610615', '香川県', 'カガワケン', '木田郡三木町', 'キタグンミキチョウ', '小蓑', 'コミノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県木田郡三木町', '37', '37341', '7610700', '香川県', 'カガワケン', '木田郡三木町', 'キタグンミキチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('95185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県木田郡三木町池戸', '37', '37341', '7610701', '香川県', 'カガワケン', '木田郡三木町', 'キタグンミキチョウ', '池戸', 'イケノベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県木田郡三木町平木', '37', '37341', '7610702', '香川県', 'カガワケン', '木田郡三木町', 'キタグンミキチョウ', '平木', 'ヒラギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県木田郡三木町鹿伏', '37', '37341', '7610703', '香川県', 'カガワケン', '木田郡三木町', 'キタグンミキチョウ', '鹿伏', 'シシブセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県木田郡三木町下高岡', '37', '37341', '7610704', '香川県', 'カガワケン', '木田郡三木町', 'キタグンミキチョウ', '下高岡', 'シモタカオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県木田郡三木町井上', '37', '37341', '7610705', '香川県', 'カガワケン', '木田郡三木町', 'キタグンミキチョウ', '井上', 'イノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県木田郡三木町鹿庭', '37', '37341', '7610821', '香川県', 'カガワケン', '木田郡三木町', 'キタグンミキチョウ', '鹿庭', 'カニワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県木田郡三木町奥山', '37', '37341', '7610822', '香川県', 'カガワケン', '木田郡三木町', 'キタグンミキチョウ', '奥山', 'オクヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県木田郡三木町井戸', '37', '37341', '7610823', '香川県', 'カガワケン', '木田郡三木町', 'キタグンミキチョウ', '井戸', 'イド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県さぬき市大川町富田西', '37', '37206', '7610901', '香川県', 'カガワケン', 'さぬき市', 'サヌキシ', '大川町富田西', 'オオカワマチトミダニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県さぬき市大川町富田中', '37', '37206', '7610902', '香川県', 'カガワケン', 'さぬき市', 'サヌキシ', '大川町富田中', 'オオカワマチトミダナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県さぬき市大川町富田東', '37', '37206', '7610903', '香川県', 'カガワケン', 'さぬき市', 'サヌキシ', '大川町富田東', 'オオカワマチトミダヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県さぬき市大川町田面', '37', '37206', '7610904', '香川県', 'カガワケン', 'さぬき市', 'サヌキシ', '大川町田面', 'オオカワマチタヅラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県さぬき市大川町南川', '37', '37206', '7610905', '香川県', 'カガワケン', 'さぬき市', 'サヌキシ', '大川町南川', 'オオカワマチミナミカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市香南町岡', '37', '37201', '7611401', '香川県', 'カガワケン', '高松市', 'タカマツシ', '香南町岡', 'コウナンチョウオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市香南町由佐', '37', '37201', '7611402', '香川県', 'カガワケン', '高松市', 'タカマツシ', '香南町由佐', 'コウナンチョウユサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市香南町吉光', '37', '37201', '7611403', '香川県', 'カガワケン', '高松市', 'タカマツシ', '香南町吉光', 'コウナンチョウヨシミツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市香南町横井', '37', '37201', '7611404', '香川県', 'カガワケン', '高松市', 'タカマツシ', '香南町横井', 'コウナンチョウヨコイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市香南町池内', '37', '37201', '7611405', '香川県', 'カガワケン', '高松市', 'タカマツシ', '香南町池内', 'コウナンチョウイケノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市香南町西庄', '37', '37201', '7611406', '香川県', 'カガワケン', '高松市', 'タカマツシ', '香南町西庄', 'コウナンチョウニシノショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市塩江町安原下第1号', '37', '37201', '7611501', '香川県', 'カガワケン', '高松市', 'タカマツシ', '塩江町安原下', 'シオノエチョウヤスハラシモ', null, null, '第1号', 'ダイ01ゴウ');
INSERT INTO `ms_addresses` VALUES ('95210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市塩江町安原下第2号', '37', '37201', '7611502', '香川県', 'カガワケン', '高松市', 'タカマツシ', '塩江町安原下', 'シオノエチョウヤスハラシモ', null, null, '第2号', 'ダイ02ゴウ');
INSERT INTO `ms_addresses` VALUES ('95211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市塩江町安原下第3号', '37', '37201', '7611503', '香川県', 'カガワケン', '高松市', 'タカマツシ', '塩江町安原下', 'シオノエチョウヤスハラシモ', null, null, '第3号', 'ダイ03ゴウ');
INSERT INTO `ms_addresses` VALUES ('95212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市塩江町安原下', '37', '37201', '7611504', '香川県', 'カガワケン', '高松市', 'タカマツシ', '塩江町安原下', 'シオノエチョウヤスハラシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市塩江町安原上', '37', '37201', '7611611', '香川県', 'カガワケン', '高松市', 'タカマツシ', '塩江町安原上', 'シオノエチョウヤスハラカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市塩江町安原上東', '37', '37201', '7611612', '香川県', 'カガワケン', '高松市', 'タカマツシ', '塩江町安原上東', 'シオノエチョウヤスハラカミヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市塩江町上西甲', '37', '37201', '7611613', '香川県', 'カガワケン', '高松市', 'タカマツシ', '塩江町上西甲', 'シオノエチョウカミニシコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市塩江町上西乙', '37', '37201', '7611614', '香川県', 'カガワケン', '高松市', 'タカマツシ', '塩江町上西乙', 'シオノエチョウカミニシオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市塩江町安原下上小田', '37', '37201', '7611615', '香川県', 'カガワケン', '高松市', 'タカマツシ', '塩江町安原下', 'シオノエチョウヤスハラシモ', null, null, '上小田', 'カミコタ');
INSERT INTO `ms_addresses` VALUES ('95219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市塩江町安原下炭谷', '37', '37201', '7611615', '香川県', 'カガワケン', '高松市', 'タカマツシ', '塩江町安原下', 'シオノエチョウヤスハラシモ', null, null, '炭谷', 'スミヤ');
INSERT INTO `ms_addresses` VALUES ('95220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市菅沢町', '37', '37201', '7611616', '香川県', 'カガワケン', '高松市', 'タカマツシ', '菅沢町', 'スゲザワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市香川町大野', '37', '37201', '7611701', '香川県', 'カガワケン', '高松市', 'タカマツシ', '香川町大野', 'カガワチョウオオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市香川町寺井', '37', '37201', '7611702', '香川県', 'カガワケン', '高松市', 'タカマツシ', '香川町寺井', 'カガワチョウテライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市香川町浅野', '37', '37201', '7611703', '香川県', 'カガワケン', '高松市', 'タカマツシ', '香川町浅野', 'カガワチョウアサノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市香川町川内原', '37', '37201', '7611704', '香川県', 'カガワケン', '高松市', 'タカマツシ', '香川町川内原', 'カガワチョウカワナイハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市香川町川東下', '37', '37201', '7611705', '香川県', 'カガワケン', '高松市', 'タカマツシ', '香川町川東下', 'カガワチョウカワヒガシシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市香川町川東上', '37', '37201', '7611706', '香川県', 'カガワケン', '高松市', 'タカマツシ', '香川町川東上', 'カガワチョウカワヒガシカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市香川町東谷', '37', '37201', '7611707', '香川県', 'カガワケン', '高松市', 'タカマツシ', '香川町東谷', 'カガワチョウヒガシタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市香川町安原下', '37', '37201', '7611708', '香川県', 'カガワケン', '高松市', 'タカマツシ', '香川町安原下', 'カガワチョウヤスハラシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県綾歌郡綾川町畑田', '37', '37387', '7612101', '香川県', 'カガワケン', '綾歌郡綾川町', 'アヤウタグンアヤガワチョウ', '畑田', 'ハタダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県綾歌郡綾川町千疋', '37', '37387', '7612102', '香川県', 'カガワケン', '綾歌郡綾川町', 'アヤウタグンアヤガワチョウ', '千疋', 'センビキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県綾歌郡綾川町陶', '37', '37387', '7612103', '香川県', 'カガワケン', '綾歌郡綾川町', 'アヤウタグンアヤガワチョウ', '陶', 'スエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県綾歌郡綾川町枌所東', '37', '37387', '7612201', '香川県', 'カガワケン', '綾歌郡綾川町', 'アヤウタグンアヤガワチョウ', '枌所東', 'ソギショヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県綾歌郡綾川町枌所西', '37', '37387', '7612202', '香川県', 'カガワケン', '綾歌郡綾川町', 'アヤウタグンアヤガワチョウ', '枌所西', 'ソギショニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県綾歌郡綾川町山田上', '37', '37387', '7612203', '香川県', 'カガワケン', '綾歌郡綾川町', 'アヤウタグンアヤガワチョウ', '山田上', 'ヤマダカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県綾歌郡綾川町山田下', '37', '37387', '7612204', '香川県', 'カガワケン', '綾歌郡綾川町', 'アヤウタグンアヤガワチョウ', '山田下', 'ヤマダシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県綾歌郡綾川町東分', '37', '37387', '7612205', '香川県', 'カガワケン', '綾歌郡綾川町', 'アヤウタグンアヤガワチョウ', '東分', 'ヒガシブン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県綾歌郡綾川町西分', '37', '37387', '7612206', '香川県', 'カガワケン', '綾歌郡綾川町', 'アヤウタグンアヤガワチョウ', '西分', 'ニシブン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県綾歌郡綾川町羽床上', '37', '37387', '7612207', '香川県', 'カガワケン', '綾歌郡綾川町', 'アヤウタグンアヤガワチョウ', '羽床上', 'ハユカカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県綾歌郡綾川町牛川', '37', '37387', '7612208', '香川県', 'カガワケン', '綾歌郡綾川町', 'アヤウタグンアヤガワチョウ', '牛川', 'ウシカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県綾歌郡綾川町', '37', '37387', '7612300', '香川県', 'カガワケン', '綾歌郡綾川町', 'アヤウタグンアヤガワチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('95245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県綾歌郡綾川町萱原', '37', '37387', '7612304', '香川県', 'カガワケン', '綾歌郡綾川町', 'アヤウタグンアヤガワチョウ', '萱原', 'カヤハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県綾歌郡綾川町滝宮', '37', '37387', '7612305', '香川県', 'カガワケン', '綾歌郡綾川町', 'アヤウタグンアヤガワチョウ', '滝宮', 'タキノミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県綾歌郡綾川町北', '37', '37387', '7612306', '香川県', 'カガワケン', '綾歌郡綾川町', 'アヤウタグンアヤガワチョウ', '北', 'キタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県綾歌郡綾川町小野', '37', '37387', '7612307', '香川県', 'カガワケン', '綾歌郡綾川町', 'アヤウタグンアヤガワチョウ', '小野', 'オノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県綾歌郡綾川町羽床下', '37', '37387', '7612308', '香川県', 'カガワケン', '綾歌郡綾川町', 'アヤウタグンアヤガワチョウ', '羽床下', 'ハユカシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県丸亀市綾歌町岡田上', '37', '37202', '7612401', '香川県', 'カガワケン', '丸亀市', 'マルガメシ', '綾歌町岡田上', 'アヤウタチョウオカダカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県丸亀市綾歌町岡田下', '37', '37202', '7612402', '香川県', 'カガワケン', '丸亀市', 'マルガメシ', '綾歌町岡田下', 'アヤウタチョウオカダシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県丸亀市綾歌町岡田西', '37', '37202', '7612403', '香川県', 'カガワケン', '丸亀市', 'マルガメシ', '綾歌町岡田西', 'アヤウタチョウオカダニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県丸亀市綾歌町岡田東', '37', '37202', '7612404', '香川県', 'カガワケン', '丸亀市', 'マルガメシ', '綾歌町岡田東', 'アヤウタチョウオカダヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県丸亀市綾歌町栗熊西', '37', '37202', '7612405', '香川県', 'カガワケン', '丸亀市', 'マルガメシ', '綾歌町栗熊西', 'アヤウタチョウクリクマニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県丸亀市綾歌町栗熊東', '37', '37202', '7612406', '香川県', 'カガワケン', '丸亀市', 'マルガメシ', '綾歌町栗熊東', 'アヤウタチョウクリクマヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県丸亀市綾歌町富熊', '37', '37202', '7612407', '香川県', 'カガワケン', '丸亀市', 'マルガメシ', '綾歌町富熊', 'アヤウタチョウトミクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県丸亀市綾歌町富熊富士見坂', '37', '37202', '7612408', '香川県', 'カガワケン', '丸亀市', 'マルガメシ', '綾歌町富熊', 'アヤウタチョウトミクマ', null, null, '富士見坂', 'フジミサカ');
INSERT INTO `ms_addresses` VALUES ('95264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県香川郡直島町', '37', '37364', '7613110', '香川県', 'カガワケン', '香川郡直島町', 'カガワグンナオシマチョウ', null, '　', '（全域）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('95265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県小豆郡土庄町', '37', '37322', '7614100', '香川県', 'カガワケン', '小豆郡土庄町', 'ショウズグントノショウチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('95266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県小豆郡土庄町乙', '37', '37322', '7614101', '香川県', 'カガワケン', '小豆郡土庄町', 'ショウズグントノショウチョウ', '乙', 'オツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県小豆郡土庄町甲', '37', '37322', '7614101', '香川県', 'カガワケン', '小豆郡土庄町', 'ショウズグントノショウチョウ', '甲', 'コウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県小豆郡土庄町乙港新町', '37', '37322', '7614102', '香川県', 'カガワケン', '小豆郡土庄町', 'ショウズグントノショウチョウ', '乙', 'オツ', null, null, '港新町', 'ミナトシンマチ');
INSERT INTO `ms_addresses` VALUES ('95269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県小豆郡土庄町甲港新町', '37', '37322', '7614102', '香川県', 'カガワケン', '小豆郡土庄町', 'ショウズグントノショウチョウ', '甲', 'コウ', null, null, '港新町', 'ミナトシンマチ');
INSERT INTO `ms_addresses` VALUES ('95270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県小豆郡土庄町乙大木戸', '37', '37322', '7614103', '香川県', 'カガワケン', '小豆郡土庄町', 'ショウズグントノショウチョウ', '乙', 'オツ', null, null, '大木戸', 'オオキド');
INSERT INTO `ms_addresses` VALUES ('95271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県小豆郡土庄町甲大木戸', '37', '37322', '7614103', '香川県', 'カガワケン', '小豆郡土庄町', 'ショウズグントノショウチョウ', '甲', 'コウ', null, null, '大木戸', 'オオキド');
INSERT INTO `ms_addresses` VALUES ('95272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県小豆郡土庄町乙吉ケ浦', '37', '37322', '7614104', '香川県', 'カガワケン', '小豆郡土庄町', 'ショウズグントノショウチョウ', '乙', 'オツ', null, null, '吉ケ浦', 'ヨシガウラ');
INSERT INTO `ms_addresses` VALUES ('95273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県小豆郡土庄町甲吉ケ浦', '37', '37322', '7614104', '香川県', 'カガワケン', '小豆郡土庄町', 'ショウズグントノショウチョウ', '甲', 'コウ', null, null, '吉ケ浦', 'ヨシガウラ');
INSERT INTO `ms_addresses` VALUES ('95274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県小豆郡土庄町乙西本町', '37', '37322', '7614105', '香川県', 'カガワケン', '小豆郡土庄町', 'ショウズグントノショウチョウ', '乙', 'オツ', null, null, '西本町', 'ニシホンチョウ');
INSERT INTO `ms_addresses` VALUES ('95275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県小豆郡土庄町甲西本町', '37', '37322', '7614105', '香川県', 'カガワケン', '小豆郡土庄町', 'ショウズグントノショウチョウ', '甲', 'コウ', null, null, '西本町', 'ニシホンチョウ');
INSERT INTO `ms_addresses` VALUES ('95276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県小豆郡土庄町乙本町', '37', '37322', '7614106', '香川県', 'カガワケン', '小豆郡土庄町', 'ショウズグントノショウチョウ', '乙', 'オツ', null, null, '本町', 'ホンチョウ');
INSERT INTO `ms_addresses` VALUES ('95277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県小豆郡土庄町甲本町', '37', '37322', '7614106', '香川県', 'カガワケン', '小豆郡土庄町', 'ショウズグントノショウチョウ', '甲', 'コウ', null, null, '本町', 'ホンチョウ');
INSERT INTO `ms_addresses` VALUES ('95278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県小豆郡土庄町乙東港', '37', '37322', '7614111', '香川県', 'カガワケン', '小豆郡土庄町', 'ショウズグントノショウチョウ', '乙', 'オツ', null, null, '東港', 'ヒガシミナト');
INSERT INTO `ms_addresses` VALUES ('95279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県小豆郡土庄町甲東港', '37', '37322', '7614111', '香川県', 'カガワケン', '小豆郡土庄町', 'ショウズグントノショウチョウ', '甲', 'コウ', null, null, '東港', 'ヒガシミナト');
INSERT INTO `ms_addresses` VALUES ('95280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県小豆郡土庄町乙鹿島', '37', '37322', '7614112', '香川県', 'カガワケン', '小豆郡土庄町', 'ショウズグントノショウチョウ', '乙', 'オツ', null, null, '鹿島', 'カシマ');
INSERT INTO `ms_addresses` VALUES ('95281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県小豆郡土庄町甲鹿島', '37', '37322', '7614112', '香川県', 'カガワケン', '小豆郡土庄町', 'ショウズグントノショウチョウ', '甲', 'コウ', null, null, '鹿島', 'カシマ');
INSERT INTO `ms_addresses` VALUES ('95282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県小豆郡土庄町乙柳', '37', '37322', '7614113', '香川県', 'カガワケン', '小豆郡土庄町', 'ショウズグントノショウチョウ', '乙', 'オツ', null, null, '柳', 'ヤナギ');
INSERT INTO `ms_addresses` VALUES ('95283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県小豆郡土庄町甲柳', '37', '37322', '7614113', '香川県', 'カガワケン', '小豆郡土庄町', 'ショウズグントノショウチョウ', '甲', 'コウ', null, null, '柳', 'ヤナギ');
INSERT INTO `ms_addresses` VALUES ('95284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県小豆郡土庄町乙千軒', '37', '37322', '7614114', '香川県', 'カガワケン', '小豆郡土庄町', 'ショウズグントノショウチョウ', '乙', 'オツ', null, null, '千軒', 'センケン');
INSERT INTO `ms_addresses` VALUES ('95285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県小豆郡土庄町甲千軒', '37', '37322', '7614114', '香川県', 'カガワケン', '小豆郡土庄町', 'ショウズグントノショウチョウ', '甲', 'コウ', null, null, '千軒', 'センケン');
INSERT INTO `ms_addresses` VALUES ('95286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県小豆郡土庄町乙小瀬', '37', '37322', '7614115', '香川県', 'カガワケン', '小豆郡土庄町', 'ショウズグントノショウチョウ', '乙', 'オツ', null, null, '小瀬', 'コセ');
INSERT INTO `ms_addresses` VALUES ('95287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県小豆郡土庄町甲小瀬', '37', '37322', '7614115', '香川県', 'カガワケン', '小豆郡土庄町', 'ショウズグントノショウチョウ', '甲', 'コウ', null, null, '小瀬', 'コセ');
INSERT INTO `ms_addresses` VALUES ('95288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県小豆郡土庄町渕崎', '37', '37322', '7614121', '香川県', 'カガワケン', '小豆郡土庄町', 'ショウズグントノショウチョウ', '渕崎', 'フチザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県小豆郡土庄町上庄', '37', '37322', '7614122', '香川県', 'カガワケン', '小豆郡土庄町', 'ショウズグントノショウチョウ', '上庄', 'カミショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県小豆郡土庄町伊喜末', '37', '37322', '7614131', '香川県', 'カガワケン', '小豆郡土庄町', 'ショウズグントノショウチョウ', '伊喜末', 'イギスエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県小豆郡土庄町小江', '37', '37322', '7614132', '香川県', 'カガワケン', '小豆郡土庄町', 'ショウズグントノショウチョウ', '小江', 'オエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県小豆郡土庄町長浜', '37', '37322', '7614133', '香川県', 'カガワケン', '小豆郡土庄町', 'ショウズグントノショウチョウ', '長浜', 'ナガハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県小豆郡土庄町滝宮', '37', '37322', '7614134', '香川県', 'カガワケン', '小豆郡土庄町', 'ショウズグントノショウチョウ', '滝宮', 'タキノミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県小豆郡土庄町馬越', '37', '37322', '7614141', '香川県', 'カガワケン', '小豆郡土庄町', 'ショウズグントノショウチョウ', '馬越', 'ウマゴエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県小豆郡土庄町屋形崎', '37', '37322', '7614142', '香川県', 'カガワケン', '小豆郡土庄町', 'ショウズグントノショウチョウ', '屋形崎', 'ヤカタザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県小豆郡土庄町見目', '37', '37322', '7614143', '香川県', 'カガワケン', '小豆郡土庄町', 'ショウズグントノショウチョウ', '見目', 'ミメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県小豆郡土庄町小海', '37', '37322', '7614144', '香川県', 'カガワケン', '小豆郡土庄町', 'ショウズグントノショウチョウ', '小海', 'オミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県小豆郡土庄町大部', '37', '37322', '7614145', '香川県', 'カガワケン', '小豆郡土庄町', 'ショウズグントノショウチョウ', '大部', 'オオベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県小豆郡土庄町小部', '37', '37322', '7614146', '香川県', 'カガワケン', '小豆郡土庄町', 'ショウズグントノショウチョウ', '小部', 'コベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県小豆郡土庄町肥土山', '37', '37322', '7614151', '香川県', 'カガワケン', '小豆郡土庄町', 'ショウズグントノショウチョウ', '肥土山', 'ヒトヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県小豆郡土庄町黒岩', '37', '37322', '7614152', '香川県', 'カガワケン', '小豆郡土庄町', 'ショウズグントノショウチョウ', '黒岩', 'クロイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県小豆郡土庄町小馬越', '37', '37322', '7614153', '香川県', 'カガワケン', '小豆郡土庄町', 'ショウズグントノショウチョウ', '小馬越', 'コウマゴエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県小豆郡土庄町笠滝', '37', '37322', '7614154', '香川県', 'カガワケン', '小豆郡土庄町', 'ショウズグントノショウチョウ', '笠滝', 'カサガダキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県小豆郡小豆島町中山美しの原高原', '37', '37324', '7614155', '香川県', 'カガワケン', '小豆郡小豆島町', 'ショウズグンショウドシマチョウ', '中山', 'ナカヤマ', null, null, '美しの原高原', 'ウツクシノハラコウゲン');
INSERT INTO `ms_addresses` VALUES ('95305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県小豆郡小豆島町中山蛙子鳴滝', '37', '37324', '7614155', '香川県', 'カガワケン', '小豆郡小豆島町', 'ショウズグンショウドシマチョウ', '中山', 'ナカヤマ', null, null, '蛙子鳴滝', 'カエルゴナルタキ');
INSERT INTO `ms_addresses` VALUES ('95310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県小豆郡小豆島町', '37', '37324', '7614300', '香川県', 'カガワケン', '小豆郡小豆島町', 'ショウズグンショウドシマチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('95311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県小豆郡小豆島町池田', '37', '37324', '7614301', '香川県', 'カガワケン', '小豆郡小豆島町', 'ショウズグンショウドシマチョウ', '池田', 'イケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県小豆郡小豆島町蒲生', '37', '37324', '7614302', '香川県', 'カガワケン', '小豆郡小豆島町', 'ショウズグンショウドシマチョウ', '蒲生', 'カモウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県小豆郡小豆島町中山', '37', '37324', '7614303', '香川県', 'カガワケン', '小豆郡小豆島町', 'ショウズグンショウドシマチョウ', '中山', 'ナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県小豆郡小豆島町室生', '37', '37324', '7614304', '香川県', 'カガワケン', '小豆郡小豆島町', 'ショウズグンショウドシマチョウ', '室生', 'ムロウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県小豆郡小豆島町二面', '37', '37324', '7614305', '香川県', 'カガワケン', '小豆郡小豆島町', 'ショウズグンショウドシマチョウ', '二面', 'フタオモテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県小豆郡小豆島町吉野', '37', '37324', '7614306', '香川県', 'カガワケン', '小豆郡小豆島町', 'ショウズグンショウドシマチョウ', '吉野', 'ヨシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県小豆郡小豆島町蒲野', '37', '37324', '7614307', '香川県', 'カガワケン', '小豆郡小豆島町', 'ショウズグンショウドシマチョウ', '蒲野', 'カマノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県小豆郡小豆島町神浦', '37', '37324', '7614308', '香川県', 'カガワケン', '小豆郡小豆島町', 'ショウズグンショウドシマチョウ', '神浦', 'コウノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県小豆郡小豆島町吉田', '37', '37324', '7614401', '香川県', 'カガワケン', '小豆郡小豆島町', 'ショウズグンショウドシマチョウ', '吉田', 'ヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県小豆郡小豆島町福田', '37', '37324', '7614402', '香川県', 'カガワケン', '小豆郡小豆島町', 'ショウズグンショウドシマチョウ', '福田', 'フクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県小豆郡小豆島町当浜', '37', '37324', '7614403', '香川県', 'カガワケン', '小豆郡小豆島町', 'ショウズグンショウドシマチョウ', '当浜', 'アテハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県小豆郡小豆島町岩谷', '37', '37324', '7614404', '香川県', 'カガワケン', '小豆郡小豆島町', 'ショウズグンショウドシマチョウ', '岩谷', 'イワガタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県小豆郡小豆島町橘', '37', '37324', '7614405', '香川県', 'カガワケン', '小豆郡小豆島町', 'ショウズグンショウドシマチョウ', '橘', 'タチバナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県小豆郡小豆島町安田', '37', '37324', '7614411', '香川県', 'カガワケン', '小豆郡小豆島町', 'ショウズグンショウドシマチョウ', '安田', 'ヤスダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県小豆郡小豆島町木庄', '37', '37324', '7614412', '香川県', 'カガワケン', '小豆郡小豆島町', 'ショウズグンショウドシマチョウ', '木庄', 'キノショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県小豆郡小豆島町苗羽', '37', '37324', '7614421', '香川県', 'カガワケン', '小豆郡小豆島町', 'ショウズグンショウドシマチョウ', '苗羽', 'ノウマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県小豆郡小豆島町古江', '37', '37324', '7614422', '香川県', 'カガワケン', '小豆郡小豆島町', 'ショウズグンショウドシマチョウ', '古江', 'フルエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県小豆郡小豆島町堀越', '37', '37324', '7614423', '香川県', 'カガワケン', '小豆郡小豆島町', 'ショウズグンショウドシマチョウ', '堀越', 'ホリコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県小豆郡小豆島町田浦', '37', '37324', '7614424', '香川県', 'カガワケン', '小豆郡小豆島町', 'ショウズグンショウドシマチョウ', '田浦', 'タノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県小豆郡小豆島町坂手', '37', '37324', '7614425', '香川県', 'カガワケン', '小豆郡小豆島町', 'ショウズグンショウドシマチョウ', '坂手', 'サカテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県小豆郡小豆島町馬木', '37', '37324', '7614426', '香川県', 'カガワケン', '小豆郡小豆島町', 'ショウズグンショウドシマチョウ', '馬木', 'ウマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県小豆郡小豆島町片城', '37', '37324', '7614431', '香川県', 'カガワケン', '小豆郡小豆島町', 'ショウズグンショウドシマチョウ', '片城', 'カタジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県小豆郡小豆島町草壁本町', '37', '37324', '7614432', '香川県', 'カガワケン', '小豆郡小豆島町', 'ショウズグンショウドシマチョウ', '草壁本町', 'クサカベホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県小豆郡小豆島町神懸通', '37', '37324', '7614433', '香川県', 'カガワケン', '小豆郡小豆島町', 'ショウズグンショウドシマチョウ', '神懸通', 'カンカケドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県小豆郡小豆島町西村', '37', '37324', '7614434', '香川県', 'カガワケン', '小豆郡小豆島町', 'ショウズグンショウドシマチョウ', '西村', 'ニシムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県小豆郡土庄町豊島家浦', '37', '37322', '7614661', '香川県', 'カガワケン', '小豆郡土庄町', 'ショウズグントノショウチョウ', '豊島家浦', 'テシマイエウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県小豆郡土庄町豊島唐櫃', '37', '37322', '7614662', '香川県', 'カガワケン', '小豆郡土庄町', 'ショウズグントノショウチョウ', '豊島唐櫃', 'テシマカラト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県小豆郡土庄町豊島甲生', '37', '37322', '7614663', '香川県', 'カガワケン', '小豆郡土庄町', 'ショウズグントノショウチョウ', '豊島甲生', 'テシマコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県小豆郡土庄町伊喜末小豊島', '37', '37322', '7614664', '香川県', 'カガワケン', '小豆郡土庄町', 'ショウズグントノショウチョウ', '伊喜末', 'イギスエ', null, null, '小豊島', 'オデシマ');
INSERT INTO `ms_addresses` VALUES ('95355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市亀水町', '37', '37201', '7618001', '香川県', 'カガワケン', '高松市', 'タカマツシ', '亀水町', 'タルミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市生島町', '37', '37201', '7618002', '香川県', 'カガワケン', '高松市', 'タカマツシ', '生島町', 'イクシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市神在川窪町', '37', '37201', '7618003', '香川県', 'カガワケン', '高松市', 'タカマツシ', '神在川窪町', 'シンザイカワクボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市中山町', '37', '37201', '7618004', '香川県', 'カガワケン', '高松市', 'タカマツシ', '中山町', 'ナカヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市植松町', '37', '37201', '7618005', '香川県', 'カガワケン', '高松市', 'タカマツシ', '植松町', 'ウエマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市香西北町', '37', '37201', '7618011', '香川県', 'カガワケン', '高松市', 'タカマツシ', '香西北町', 'コウザイキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市香西本町', '37', '37201', '7618012', '香川県', 'カガワケン', '高松市', 'タカマツシ', '香西本町', 'コウザイホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市香西東町', '37', '37201', '7618013', '香川県', 'カガワケン', '高松市', 'タカマツシ', '香西東町', 'コウザイヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市香西南町', '37', '37201', '7618014', '香川県', 'カガワケン', '高松市', 'タカマツシ', '香西南町', 'コウザイミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市香西西町', '37', '37201', '7618015', '香川県', 'カガワケン', '高松市', 'タカマツシ', '香西西町', 'コウザイニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市鬼無町是竹', '37', '37201', '7618021', '香川県', 'カガワケン', '高松市', 'タカマツシ', '鬼無町是竹', 'キナシチョウコレタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市鬼無町佐料', '37', '37201', '7618022', '香川県', 'カガワケン', '高松市', 'タカマツシ', '鬼無町佐料', 'キナシチョウサリョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市鬼無町佐藤', '37', '37201', '7618023', '香川県', 'カガワケン', '高松市', 'タカマツシ', '鬼無町佐藤', 'キナシチョウサトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市鬼無町藤井', '37', '37201', '7618024', '香川県', 'カガワケン', '高松市', 'タカマツシ', '鬼無町藤井', 'キナシチョウフジイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市鬼無町山口', '37', '37201', '7618025', '香川県', 'カガワケン', '高松市', 'タカマツシ', '鬼無町山口', 'キナシチョウヤマグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市鬼無町鬼無', '37', '37201', '7618026', '香川県', 'カガワケン', '高松市', 'タカマツシ', '鬼無町鬼無', 'キナシチョウキナシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市郷東町', '37', '37201', '7618031', '香川県', 'カガワケン', '高松市', 'タカマツシ', '郷東町', 'ゴウトウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市鶴市町', '37', '37201', '7618032', '香川県', 'カガワケン', '高松市', 'タカマツシ', '鶴市町', 'ツルイチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市飯田町', '37', '37201', '7618033', '香川県', 'カガワケン', '高松市', 'タカマツシ', '飯田町', 'イイダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市檀紙町', '37', '37201', '7618041', '香川県', 'カガワケン', '高松市', 'タカマツシ', '檀紙町', 'ダンシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市御厩町', '37', '37201', '7618042', '香川県', 'カガワケン', '高松市', 'タカマツシ', '御厩町', 'ミマヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市中間町', '37', '37201', '7618043', '香川県', 'カガワケン', '高松市', 'タカマツシ', '中間町', 'ナカツマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市円座町', '37', '37201', '7618044', '香川県', 'カガワケン', '高松市', 'タカマツシ', '円座町', 'エンザチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市西山崎町', '37', '37201', '7618045', '香川県', 'カガワケン', '高松市', 'タカマツシ', '西山崎町', 'ニシヤマサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市川部町', '37', '37201', '7618046', '香川県', 'カガワケン', '高松市', 'タカマツシ', '川部町', 'カワナベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市岡本町', '37', '37201', '7618047', '香川県', 'カガワケン', '高松市', 'タカマツシ', '岡本町', 'オカモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市西春日町', '37', '37201', '7618051', '香川県', 'カガワケン', '高松市', 'タカマツシ', '西春日町', 'ニシカスガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市松並町', '37', '37201', '7618052', '香川県', 'カガワケン', '高松市', 'タカマツシ', '松並町', 'マツナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市西ハゼ町', '37', '37201', '7618053', '香川県', 'カガワケン', '高松市', 'タカマツシ', '西ハゼ町', 'ニシハゼマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市東ハゼ町', '37', '37201', '7618054', '香川県', 'カガワケン', '高松市', 'タカマツシ', '東ハゼ町', 'ヒガシハゼマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市紙町', '37', '37201', '7618055', '香川県', 'カガワケン', '高松市', 'タカマツシ', '紙町', 'カミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市上天神町', '37', '37201', '7618056', '香川県', 'カガワケン', '高松市', 'タカマツシ', '上天神町', 'カミテンジンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市田村町', '37', '37201', '7618057', '香川県', 'カガワケン', '高松市', 'タカマツシ', '田村町', 'タムラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市勅使町', '37', '37201', '7618058', '香川県', 'カガワケン', '高松市', 'タカマツシ', '勅使町', 'チョクシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市室町', '37', '37201', '7618061', '香川県', 'カガワケン', '高松市', 'タカマツシ', '室町', 'ムロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市室新町', '37', '37201', '7618062', '香川県', 'カガワケン', '高松市', 'タカマツシ', '室新町', 'ムロシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市花ノ宮町', '37', '37201', '7618063', '香川県', 'カガワケン', '高松市', 'タカマツシ', '花ノ宮町', 'ハナノミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市上之町', '37', '37201', '7618064', '香川県', 'カガワケン', '高松市', 'タカマツシ', '上之町', 'カミノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市伏石町', '37', '37201', '7618071', '香川県', 'カガワケン', '高松市', 'タカマツシ', '伏石町', 'フセイシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市三条町', '37', '37201', '7618072', '香川県', 'カガワケン', '高松市', 'タカマツシ', '三条町', 'サンジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市太田下町', '37', '37201', '7618073', '香川県', 'カガワケン', '高松市', 'タカマツシ', '太田下町', 'オオタシモマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市太田上町', '37', '37201', '7618074', '香川県', 'カガワケン', '高松市', 'タカマツシ', '太田上町', 'オオタカミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市多肥下町', '37', '37201', '7618075', '香川県', 'カガワケン', '高松市', 'タカマツシ', '多肥下町', 'タヒシモマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市多肥上町', '37', '37201', '7618076', '香川県', 'カガワケン', '高松市', 'タカマツシ', '多肥上町', 'タヒカミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市出作町', '37', '37201', '7618077', '香川県', 'カガワケン', '高松市', 'タカマツシ', '出作町', 'シュツサクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市仏生山町甲', '37', '37201', '7618078', '香川県', 'カガワケン', '高松市', 'タカマツシ', '仏生山町甲', 'ブッショウザンチョウコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市仏生山町乙', '37', '37201', '7618079', '香川県', 'カガワケン', '高松市', 'タカマツシ', '仏生山町乙', 'ブッショウザンチョウオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市成合町', '37', '37201', '7618081', '香川県', 'カガワケン', '高松市', 'タカマツシ', '成合町', 'ナリアイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市鹿角町', '37', '37201', '7618082', '香川県', 'カガワケン', '高松市', 'タカマツシ', '鹿角町', 'カノツノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市三名町', '37', '37201', '7618083', '香川県', 'カガワケン', '高松市', 'タカマツシ', '三名町', 'サンミョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市一宮町', '37', '37201', '7618084', '香川県', 'カガワケン', '高松市', 'タカマツシ', '一宮町', 'イチノミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市寺井町', '37', '37201', '7618085', '香川県', 'カガワケン', '高松市', 'タカマツシ', '寺井町', 'テライチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県坂出市', '37', '37203', '7620000', '香川県', 'カガワケン', '坂出市', 'サカイデシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('95423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県坂出市京町', '37', '37203', '7620001', '香川県', 'カガワケン', '坂出市', 'サカイデシ', '京町', 'キョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県坂出市入船町', '37', '37203', '7620002', '香川県', 'カガワケン', '坂出市', 'サカイデシ', '入船町', 'イリフネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県坂出市久米町', '37', '37203', '7620003', '香川県', 'カガワケン', '坂出市', 'サカイデシ', '久米町', 'クメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県坂出市昭和町', '37', '37203', '7620004', '香川県', 'カガワケン', '坂出市', 'サカイデシ', '昭和町', 'ショウワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県坂出市横津町', '37', '37203', '7620005', '香川県', 'カガワケン', '坂出市', 'サカイデシ', '横津町', 'ヨコヅチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県坂出市旭町', '37', '37203', '7620006', '香川県', 'カガワケン', '坂出市', 'サカイデシ', '旭町', 'アサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県坂出市室町', '37', '37203', '7620007', '香川県', 'カガワケン', '坂出市', 'サカイデシ', '室町', 'ムロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県坂出市江尻町', '37', '37203', '7620011', '香川県', 'カガワケン', '坂出市', 'サカイデシ', '江尻町', 'エジリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県坂出市林田町', '37', '37203', '7620012', '香川県', 'カガワケン', '坂出市', 'サカイデシ', '林田町', 'ハヤシダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県坂出市王越町乃生', '37', '37203', '7620013', '香川県', 'カガワケン', '坂出市', 'サカイデシ', '王越町乃生', 'オウゴシチョウノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県坂出市王越町木沢', '37', '37203', '7620014', '香川県', 'カガワケン', '坂出市', 'サカイデシ', '王越町木沢', 'オウゴシチョウキサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県坂出市大屋冨町', '37', '37203', '7620015', '香川県', 'カガワケン', '坂出市', 'サカイデシ', '大屋冨町', 'オオヤブチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県坂出市青海町', '37', '37203', '7620016', '香川県', 'カガワケン', '坂出市', 'サカイデシ', '青海町', 'オウミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県坂出市高屋町', '37', '37203', '7620017', '香川県', 'カガワケン', '坂出市', 'サカイデシ', '高屋町', 'タカヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県坂出市神谷町', '37', '37203', '7620018', '香川県', 'カガワケン', '坂出市', 'サカイデシ', '神谷町', 'カンダニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県坂出市西庄町', '37', '37203', '7620021', '香川県', 'カガワケン', '坂出市', 'サカイデシ', '西庄町', 'ニシノショウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県坂出市加茂町甲氏部', '37', '37203', '7620022', '香川県', 'カガワケン', '坂出市', 'サカイデシ', '加茂町甲', 'カモチョウコウ', null, null, '氏部', 'ウジベ');
INSERT INTO `ms_addresses` VALUES ('95440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県坂出市加茂町', '37', '37203', '7620023', '香川県', 'カガワケン', '坂出市', 'サカイデシ', '加茂町', 'カモチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県坂出市府中町', '37', '37203', '7620024', '香川県', 'カガワケン', '坂出市', 'サカイデシ', '府中町', 'フチュウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県坂出市川津町', '37', '37203', '7620025', '香川県', 'カガワケン', '坂出市', 'サカイデシ', '川津町', 'カワツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県坂出市小山町', '37', '37203', '7620026', '香川県', 'カガワケン', '坂出市', 'サカイデシ', '小山町', 'コヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県坂出市大池町', '37', '37203', '7620027', '香川県', 'カガワケン', '坂出市', 'サカイデシ', '大池町', 'オオイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県坂出市文京町', '37', '37203', '7620031', '香川県', 'カガワケン', '坂出市', 'サカイデシ', '文京町', 'ブンキョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県坂出市駒止町', '37', '37203', '7620032', '香川県', 'カガワケン', '坂出市', 'サカイデシ', '駒止町', 'コマドメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県坂出市谷町', '37', '37203', '7620033', '香川県', 'カガワケン', '坂出市', 'サカイデシ', '谷町', 'タニマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県坂出市福江町', '37', '37203', '7620034', '香川県', 'カガワケン', '坂出市', 'サカイデシ', '福江町', 'フクエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県坂出市池園町', '37', '37203', '7620035', '香川県', 'カガワケン', '坂出市', 'サカイデシ', '池園町', 'イケゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県坂出市花町', '37', '37203', '7620036', '香川県', 'カガワケン', '坂出市', 'サカイデシ', '花町', 'ハナマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県坂出市青葉町', '37', '37203', '7620037', '香川県', 'カガワケン', '坂出市', 'サカイデシ', '青葉町', 'アオバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県坂出市笠指町', '37', '37203', '7620038', '香川県', 'カガワケン', '坂出市', 'サカイデシ', '笠指町', 'カザシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県坂出市八幡町', '37', '37203', '7620041', '香川県', 'カガワケン', '坂出市', 'サカイデシ', '八幡町', 'ハチマンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県坂出市白金町', '37', '37203', '7620042', '香川県', 'カガワケン', '坂出市', 'サカイデシ', '白金町', 'シロガネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県坂出市寿町', '37', '37203', '7620043', '香川県', 'カガワケン', '坂出市', 'サカイデシ', '寿町', 'コトブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県坂出市本町', '37', '37203', '7620044', '香川県', 'カガワケン', '坂出市', 'サカイデシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県坂出市元町', '37', '37203', '7620045', '香川県', 'カガワケン', '坂出市', 'サカイデシ', '元町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県坂出市富士見町', '37', '37203', '7620046', '香川県', 'カガワケン', '坂出市', 'サカイデシ', '富士見町', 'フジミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県坂出市新浜町', '37', '37203', '7620047', '香川県', 'カガワケン', '坂出市', 'サカイデシ', '新浜町', 'シンハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県坂出市御供所町', '37', '37203', '7620051', '香川県', 'カガワケン', '坂出市', 'サカイデシ', '御供所町', 'ゴブショチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県坂出市沖の浜', '37', '37203', '7620052', '香川県', 'カガワケン', '坂出市', 'サカイデシ', '沖の浜', 'オキノハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県坂出市西大浜北', '37', '37203', '7620053', '香川県', 'カガワケン', '坂出市', 'サカイデシ', '西大浜北', 'ニシオオハマキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県坂出市西大浜南', '37', '37203', '7620054', '香川県', 'カガワケン', '坂出市', 'サカイデシ', '西大浜南', 'ニシオオハマミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県坂出市築港町', '37', '37203', '7620055', '香川県', 'カガワケン', '坂出市', 'サカイデシ', '築港町', 'チッコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県坂出市中央町', '37', '37203', '7620056', '香川県', 'カガワケン', '坂出市', 'サカイデシ', '中央町', 'チュウオウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県坂出市宮下町', '37', '37203', '7620057', '香川県', 'カガワケン', '坂出市', 'サカイデシ', '宮下町', 'ミヤシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県坂出市常盤町', '37', '37203', '7620058', '香川県', 'カガワケン', '坂出市', 'サカイデシ', '常盤町', 'トキワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県坂出市坂出町', '37', '37203', '7620061', '香川県', 'カガワケン', '坂出市', 'サカイデシ', '坂出町', 'サカイデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県坂出市川崎町', '37', '37203', '7620062', '香川県', 'カガワケン', '坂出市', 'サカイデシ', '川崎町', 'カワサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県坂出市番の州公園', '37', '37203', '7620063', '香川県', 'カガワケン', '坂出市', 'サカイデシ', '番の州公園', 'バンノスコウエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県坂出市番の州町', '37', '37203', '7620064', '香川県', 'カガワケン', '坂出市', 'サカイデシ', '番の州町', 'バンノスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県坂出市番の州緑町', '37', '37203', '7620065', '香川県', 'カガワケン', '坂出市', 'サカイデシ', '番の州緑町', 'バンノスミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県坂出市沙弥島', '37', '37203', '7620066', '香川県', 'カガワケン', '坂出市', 'サカイデシ', '沙弥島', 'シャミジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県坂出市瀬居町', '37', '37203', '7620067', '香川県', 'カガワケン', '坂出市', 'サカイデシ', '瀬居町', 'セイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県坂出市与島町', '37', '37203', '7620071', '香川県', 'カガワケン', '坂出市', 'サカイデシ', '与島町', 'ヨシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県坂出市岩黒', '37', '37203', '7620072', '香川県', 'カガワケン', '坂出市', 'サカイデシ', '岩黒', 'イワクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県坂出市櫃石', '37', '37203', '7620073', '香川県', 'カガワケン', '坂出市', 'サカイデシ', '櫃石', 'ヒツイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県丸亀市飯山町東坂元', '37', '37202', '7620081', '香川県', 'カガワケン', '丸亀市', 'マルガメシ', '飯山町東坂元', 'ハンザンチョウヒガシサカモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県丸亀市飯山町川原', '37', '37202', '7620082', '香川県', 'カガワケン', '丸亀市', 'マルガメシ', '飯山町川原', 'ハンザンチョウカワハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県丸亀市飯山町下法軍寺', '37', '37202', '7620083', '香川県', 'カガワケン', '丸亀市', 'マルガメシ', '飯山町下法軍寺', 'ハンザンチョウシモホウグンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県丸亀市飯山町上法軍寺', '37', '37202', '7620084', '香川県', 'カガワケン', '丸亀市', 'マルガメシ', '飯山町上法軍寺', 'ハンザンチョウカミホウグンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県丸亀市飯山町東小川', '37', '37202', '7620085', '香川県', 'カガワケン', '丸亀市', 'マルガメシ', '飯山町東小川', 'ハンザンチョウヒガシオガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県丸亀市飯山町真時', '37', '37202', '7620086', '香川県', 'カガワケン', '丸亀市', 'マルガメシ', '飯山町真時', 'ハンザンチョウサントキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県丸亀市飯山町西坂元', '37', '37202', '7620087', '香川県', 'カガワケン', '丸亀市', 'マルガメシ', '飯山町西坂元', 'ハンザンチョウニシサカモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県丸亀市', '37', '37202', '7630000', '香川県', 'カガワケン', '丸亀市', 'マルガメシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('95496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県丸亀市風袋町', '37', '37202', '7630001', '香川県', 'カガワケン', '丸亀市', 'マルガメシ', '風袋町', 'フルタイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県丸亀市瓦町', '37', '37202', '7630002', '香川県', 'カガワケン', '丸亀市', 'マルガメシ', '瓦町', 'カワラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県丸亀市葭町', '37', '37202', '7630003', '香川県', 'カガワケン', '丸亀市', 'マルガメシ', '葭町', 'カヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県丸亀市米屋町', '37', '37202', '7630004', '香川県', 'カガワケン', '丸亀市', 'マルガメシ', '米屋町', 'コメヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県丸亀市松屋町', '37', '37202', '7630005', '香川県', 'カガワケン', '丸亀市', 'マルガメシ', '松屋町', 'マツヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県丸亀市魚屋町', '37', '37202', '7630006', '香川県', 'カガワケン', '丸亀市', 'マルガメシ', '魚屋町', 'ウオヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県丸亀市宗古町', '37', '37202', '7630007', '香川県', 'カガワケン', '丸亀市', 'マルガメシ', '宗古町', 'ソウコマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県丸亀市富士見町', '37', '37202', '7630011', '香川県', 'カガワケン', '丸亀市', 'マルガメシ', '富士見町', 'フジミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県丸亀市土居町', '37', '37202', '7630012', '香川県', 'カガワケン', '丸亀市', 'マルガメシ', '土居町', 'ドイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県丸亀市城東町', '37', '37202', '7630013', '香川県', 'カガワケン', '丸亀市', 'マルガメシ', '城東町', 'ジョウトウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県丸亀市御供所町', '37', '37202', '7630014', '香川県', 'カガワケン', '丸亀市', 'マルガメシ', '御供所町', 'ゴブショチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県丸亀市北平山町', '37', '37202', '7630015', '香川県', 'カガワケン', '丸亀市', 'マルガメシ', '北平山町', 'キタヒラヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県丸亀市富屋町', '37', '37202', '7630021', '香川県', 'カガワケン', '丸亀市', 'マルガメシ', '富屋町', 'トミヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県丸亀市浜町', '37', '37202', '7630022', '香川県', 'カガワケン', '丸亀市', 'マルガメシ', '浜町', 'ハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県丸亀市本町', '37', '37202', '7630023', '香川県', 'カガワケン', '丸亀市', 'マルガメシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県丸亀市塩飽町', '37', '37202', '7630024', '香川県', 'カガワケン', '丸亀市', 'マルガメシ', '塩飽町', 'シワクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県丸亀市一番丁', '37', '37202', '7630025', '香川県', 'カガワケン', '丸亀市', 'マルガメシ', '一番丁', 'イチバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県丸亀市六番丁', '37', '37202', '7630026', '香川県', 'カガワケン', '丸亀市', 'マルガメシ', '六番丁', 'ロクバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県丸亀市七番丁', '37', '37202', '7630027', '香川県', 'カガワケン', '丸亀市', 'マルガメシ', '七番丁', 'シチバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県丸亀市八番丁', '37', '37202', '7630028', '香川県', 'カガワケン', '丸亀市', 'マルガメシ', '八番丁', 'ハチバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県丸亀市九番丁', '37', '37202', '7630029', '香川県', 'カガワケン', '丸亀市', 'マルガメシ', '九番丁', 'クバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県丸亀市十番丁', '37', '37202', '7630030', '香川県', 'カガワケン', '丸亀市', 'マルガメシ', '十番丁', 'ジュウバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県丸亀市城南町', '37', '37202', '7630031', '香川県', 'カガワケン', '丸亀市', 'マルガメシ', '城南町', 'ジョウナンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県丸亀市城西町', '37', '37202', '7630032', '香川県', 'カガワケン', '丸亀市', 'マルガメシ', '城西町', 'ジョウセイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県丸亀市中府町', '37', '37202', '7630033', '香川県', 'カガワケン', '丸亀市', 'マルガメシ', '中府町', 'ナカブチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県丸亀市大手町', '37', '37202', '7630034', '香川県', 'カガワケン', '丸亀市', 'マルガメシ', '大手町', 'オオテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県丸亀市西平山町', '37', '37202', '7630041', '香川県', 'カガワケン', '丸亀市', 'マルガメシ', '西平山町', 'ニシヒラヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県丸亀市港町', '37', '37202', '7630042', '香川県', 'カガワケン', '丸亀市', 'マルガメシ', '港町', 'ミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県丸亀市通町', '37', '37202', '7630043', '香川県', 'カガワケン', '丸亀市', 'マルガメシ', '通町', 'トオリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県丸亀市福島町', '37', '37202', '7630044', '香川県', 'カガワケン', '丸亀市', 'マルガメシ', '福島町', 'フクシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県丸亀市新町', '37', '37202', '7630045', '香川県', 'カガワケン', '丸亀市', 'マルガメシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県丸亀市南条町', '37', '37202', '7630046', '香川県', 'カガワケン', '丸亀市', 'マルガメシ', '南条町', 'ナンジョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県丸亀市西本町', '37', '37202', '7630047', '香川県', 'カガワケン', '丸亀市', 'マルガメシ', '西本町', 'ニシホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県丸亀市幸町', '37', '37202', '7630048', '香川県', 'カガワケン', '丸亀市', 'マルガメシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県丸亀市今津町', '37', '37202', '7630051', '香川県', 'カガワケン', '丸亀市', 'マルガメシ', '今津町', 'イマヅチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県丸亀市津森町', '37', '37202', '7630052', '香川県', 'カガワケン', '丸亀市', 'マルガメシ', '津森町', 'ツノモリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県丸亀市金倉町', '37', '37202', '7630053', '香川県', 'カガワケン', '丸亀市', 'マルガメシ', '金倉町', 'カナクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県丸亀市中津町', '37', '37202', '7630054', '香川県', 'カガワケン', '丸亀市', 'マルガメシ', '中津町', 'ナカヅチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県丸亀市新田町', '37', '37202', '7630055', '香川県', 'カガワケン', '丸亀市', 'マルガメシ', '新田町', 'シンデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県丸亀市昭和町', '37', '37202', '7630061', '香川県', 'カガワケン', '丸亀市', 'マルガメシ', '昭和町', 'ショウワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県丸亀市蓬莱町', '37', '37202', '7630062', '香川県', 'カガワケン', '丸亀市', 'マルガメシ', '蓬莱町', 'ホウライチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県丸亀市新浜町', '37', '37202', '7630063', '香川県', 'カガワケン', '丸亀市', 'マルガメシ', '新浜町', 'シンハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県丸亀市前塩屋町', '37', '37202', '7630064', '香川県', 'カガワケン', '丸亀市', 'マルガメシ', '前塩屋町', 'マエジオヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県丸亀市塩屋町', '37', '37202', '7630065', '香川県', 'カガワケン', '丸亀市', 'マルガメシ', '塩屋町', 'シオヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県丸亀市天満町', '37', '37202', '7630066', '香川県', 'カガワケン', '丸亀市', 'マルガメシ', '天満町', 'テンマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県丸亀市田村町', '37', '37202', '7630071', '香川県', 'カガワケン', '丸亀市', 'マルガメシ', '田村町', 'タムラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県丸亀市山北町', '37', '37202', '7630072', '香川県', 'カガワケン', '丸亀市', 'マルガメシ', '山北町', 'ヤマノキタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県丸亀市柞原町', '37', '37202', '7630073', '香川県', 'カガワケン', '丸亀市', 'マルガメシ', '柞原町', 'クバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県丸亀市原田町', '37', '37202', '7630074', '香川県', 'カガワケン', '丸亀市', 'マルガメシ', '原田町', 'ハラダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県丸亀市原田団地', '37', '37202', '7630075', '香川県', 'カガワケン', '丸亀市', 'マルガメシ', '原田団地', 'ハラダダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県丸亀市土器町西', '37', '37202', '7630081', '香川県', 'カガワケン', '丸亀市', 'マルガメシ', '土器町西', 'ドキチョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県丸亀市土器町東', '37', '37202', '7630082', '香川県', 'カガワケン', '丸亀市', 'マルガメシ', '土器町東', 'ドキチョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県丸亀市土器町北', '37', '37202', '7630083', '香川県', 'カガワケン', '丸亀市', 'マルガメシ', '土器町北', 'ドキチョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県丸亀市飯野町東二', '37', '37202', '7630084', '香川県', 'カガワケン', '丸亀市', 'マルガメシ', '飯野町東二', 'イイノチョウヒガシフタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県丸亀市飯野町東分', '37', '37202', '7630085', '香川県', 'カガワケン', '丸亀市', 'マルガメシ', '飯野町東分', 'イイノチョウヒガシブン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県丸亀市飯野町西分', '37', '37202', '7630086', '香川県', 'カガワケン', '丸亀市', 'マルガメシ', '飯野町西分', 'イイノチョウニシブン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県丸亀市川西町北', '37', '37202', '7630091', '香川県', 'カガワケン', '丸亀市', 'マルガメシ', '川西町北', 'カワニシチョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県丸亀市川西町南', '37', '37202', '7630092', '香川県', 'カガワケン', '丸亀市', 'マルガメシ', '川西町南', 'カワニシチョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県丸亀市郡家町', '37', '37202', '7630093', '香川県', 'カガワケン', '丸亀市', 'マルガメシ', '郡家町', 'グンゲチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県丸亀市三条町', '37', '37202', '7630094', '香川県', 'カガワケン', '丸亀市', 'マルガメシ', '三条町', 'サンジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県丸亀市垂水町', '37', '37202', '7630095', '香川県', 'カガワケン', '丸亀市', 'マルガメシ', '垂水町', 'タルミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県丸亀市広島町立石', '37', '37202', '7630101', '香川県', 'カガワケン', '丸亀市', 'マルガメシ', '広島町立石', 'ヒロシマチョウタテイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県丸亀市広島町江の浦', '37', '37202', '7630102', '香川県', 'カガワケン', '丸亀市', 'マルガメシ', '広島町江の浦', 'ヒロシマチョウエノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県丸亀市広島町釜の越', '37', '37202', '7630103', '香川県', 'カガワケン', '丸亀市', 'マルガメシ', '広島町釜の越', 'ヒロシマチョウカマノコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県丸亀市広島町甲路', '37', '37202', '7630104', '香川県', 'カガワケン', '丸亀市', 'マルガメシ', '広島町甲路', 'ヒロシマチョウコウロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県丸亀市広島町青木', '37', '37202', '7630105', '香川県', 'カガワケン', '丸亀市', 'マルガメシ', '広島町青木', 'ヒロシマチョウアオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県丸亀市広島町市井', '37', '37202', '7630106', '香川県', 'カガワケン', '丸亀市', 'マルガメシ', '広島町市井', 'ヒロシマチョウイチイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県丸亀市広島町茂浦', '37', '37202', '7630107', '香川県', 'カガワケン', '丸亀市', 'マルガメシ', '広島町茂浦', 'ヒロシマチョウモウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県丸亀市広島町小手島', '37', '37202', '7630108', '香川県', 'カガワケン', '丸亀市', 'マルガメシ', '広島町小手島', 'ヒロシマチョウオテシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県丸亀市手島町', '37', '37202', '7630111', '香川県', 'カガワケン', '丸亀市', 'マルガメシ', '手島町', 'テシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県丸亀市本島町笠島', '37', '37202', '7630221', '香川県', 'カガワケン', '丸亀市', 'マルガメシ', '本島町笠島', 'ホンジマチョウカサシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県丸亀市本島町甲生', '37', '37202', '7630222', '香川県', 'カガワケン', '丸亀市', 'マルガメシ', '本島町甲生', 'ホンジマチョウコウショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県丸亀市本島町泊', '37', '37202', '7630223', '香川県', 'カガワケン', '丸亀市', 'マルガメシ', '本島町泊', 'ホンジマチョウトマリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県丸亀市本島町小阪', '37', '37202', '7630224', '香川県', 'カガワケン', '丸亀市', 'マルガメシ', '本島町小阪', 'ホンジマチョウコサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県丸亀市本島町生の浜', '37', '37202', '7630225', '香川県', 'カガワケン', '丸亀市', 'マルガメシ', '本島町生の浜', 'ホンジマチョウイケノハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県丸亀市本島町尻浜', '37', '37202', '7630226', '香川県', 'カガワケン', '丸亀市', 'マルガメシ', '本島町尻浜', 'ホンジマチョウシリハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県丸亀市本島町福田', '37', '37202', '7630227', '香川県', 'カガワケン', '丸亀市', 'マルガメシ', '本島町福田', 'ホンジマチョウフクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県丸亀市本島町大浦', '37', '37202', '7630228', '香川県', 'カガワケン', '丸亀市', 'マルガメシ', '本島町大浦', 'ホンジマチョウオオウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県丸亀市牛島', '37', '37202', '7630231', '香川県', 'カガワケン', '丸亀市', 'マルガメシ', '牛島', 'ウシジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県仲多度郡多度津町', '37', '37404', '7640000', '香川県', 'カガワケン', '仲多度郡多度津町', 'ナカタドグンタドツチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('95590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県仲多度郡多度津町東新町', '37', '37404', '7640001', '香川県', 'カガワケン', '仲多度郡多度津町', 'ナカタドグンタドツチョウ', '東新町', 'ヒガシシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県仲多度郡多度津町家中', '37', '37404', '7640002', '香川県', 'カガワケン', '仲多度郡多度津町', 'ナカタドグンタドツチョウ', '家中', 'カチュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県仲多度郡多度津町元町', '37', '37404', '7640003', '香川県', 'カガワケン', '仲多度郡多度津町', 'ナカタドグンタドツチョウ', '元町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県仲多度郡多度津町仲ノ町', '37', '37404', '7640004', '香川県', 'カガワケン', '仲多度郡多度津町', 'ナカタドグンタドツチョウ', '仲ノ町', 'ナカノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県仲多度郡多度津町大通り', '37', '37404', '7640005', '香川県', 'カガワケン', '仲多度郡多度津町', 'ナカタドグンタドツチョウ', '大通り', 'オオドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県仲多度郡多度津町日の出町', '37', '37404', '7640006', '香川県', 'カガワケン', '仲多度郡多度津町', 'ナカタドグンタドツチョウ', '日の出町', 'ヒノデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県仲多度郡多度津町栄町', '37', '37404', '7640011', '香川県', 'カガワケン', '仲多度郡多度津町', 'ナカタドグンタドツチョウ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県仲多度郡多度津町桜川', '37', '37404', '7640012', '香川県', 'カガワケン', '仲多度郡多度津町', 'ナカタドグンタドツチョウ', '桜川', 'サクラガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県仲多度郡多度津町京町', '37', '37404', '7640013', '香川県', 'カガワケン', '仲多度郡多度津町', 'ナカタドグンタドツチョウ', '京町', 'キョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県仲多度郡多度津町本通', '37', '37404', '7640014', '香川県', 'カガワケン', '仲多度郡多度津町', 'ナカタドグンタドツチョウ', '本通', 'ホンドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県仲多度郡多度津町西浜', '37', '37404', '7640015', '香川県', 'カガワケン', '仲多度郡多度津町', 'ナカタドグンタドツチョウ', '西浜', 'ニシハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県仲多度郡多度津町東浜', '37', '37404', '7640016', '香川県', 'カガワケン', '仲多度郡多度津町', 'ナカタドグンタドツチョウ', '東浜', 'ヒガシハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県仲多度郡多度津町西港町', '37', '37404', '7640017', '香川県', 'カガワケン', '仲多度郡多度津町', 'ナカタドグンタドツチョウ', '西港町', 'ニシミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県仲多度郡多度津町東港町', '37', '37404', '7640018', '香川県', 'カガワケン', '仲多度郡多度津町', 'ナカタドグンタドツチョウ', '東港町', 'ヒガシミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県仲多度郡多度津町堀江', '37', '37404', '7640021', '香川県', 'カガワケン', '仲多度郡多度津町', 'ナカタドグンタドツチョウ', '堀江', 'ホリエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県仲多度郡多度津町北鴨', '37', '37404', '7640022', '香川県', 'カガワケン', '仲多度郡多度津町', 'ナカタドグンタドツチョウ', '北鴨', 'キタガモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県仲多度郡多度津町若葉町', '37', '37404', '7640023', '香川県', 'カガワケン', '仲多度郡多度津町', 'ナカタドグンタドツチョウ', '若葉町', 'ワカバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県仲多度郡多度津町幸町', '37', '37404', '7640024', '香川県', 'カガワケン', '仲多度郡多度津町', 'ナカタドグンタドツチョウ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県仲多度郡多度津町寿町', '37', '37404', '7640025', '香川県', 'カガワケン', '仲多度郡多度津町', 'ナカタドグンタドツチョウ', '寿町', 'コトブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県仲多度郡多度津町南鴨', '37', '37404', '7640026', '香川県', 'カガワケン', '仲多度郡多度津町', 'ナカタドグンタドツチョウ', '南鴨', 'ミナミガモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県仲多度郡多度津町道福寺', '37', '37404', '7640027', '香川県', 'カガワケン', '仲多度郡多度津町', 'ナカタドグンタドツチョウ', '道福寺', 'ドウフクジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県仲多度郡多度津町葛原', '37', '37404', '7640028', '香川県', 'カガワケン', '仲多度郡多度津町', 'ナカタドグンタドツチョウ', '葛原', 'カズハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県仲多度郡多度津町庄', '37', '37404', '7640031', '香川県', 'カガワケン', '仲多度郡多度津町', 'ナカタドグンタドツチョウ', '庄', 'ショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県仲多度郡多度津町三井', '37', '37404', '7640032', '香川県', 'カガワケン', '仲多度郡多度津町', 'ナカタドグンタドツチョウ', '三井', 'ミイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県仲多度郡多度津町青木', '37', '37404', '7640033', '香川県', 'カガワケン', '仲多度郡多度津町', 'ナカタドグンタドツチョウ', '青木', 'オオギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県仲多度郡多度津町山階', '37', '37404', '7640034', '香川県', 'カガワケン', '仲多度郡多度津町', 'ナカタドグンタドツチョウ', '山階', 'ヤマシナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県仲多度郡多度津町奥白方', '37', '37404', '7640035', '香川県', 'カガワケン', '仲多度郡多度津町', 'ナカタドグンタドツチョウ', '奥白方', 'オクシラカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県仲多度郡多度津町見立', '37', '37404', '7640036', '香川県', 'カガワケン', '仲多度郡多度津町', 'ナカタドグンタドツチョウ', '見立', 'ミタチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県仲多度郡多度津町西白方', '37', '37404', '7640037', '香川県', 'カガワケン', '仲多度郡多度津町', 'ナカタドグンタドツチョウ', '西白方', 'ニシシラカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県仲多度郡多度津町東白方', '37', '37404', '7640038', '香川県', 'カガワケン', '仲多度郡多度津町', 'ナカタドグンタドツチョウ', '東白方', 'ヒガシシラカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県仲多度郡多度津町佐柳', '37', '37404', '7640040', '香川県', 'カガワケン', '仲多度郡多度津町', 'ナカタドグンタドツチョウ', '佐柳', 'サナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県仲多度郡多度津町高見', '37', '37404', '7640050', '香川県', 'カガワケン', '仲多度郡多度津町', 'ナカタドグンタドツチョウ', '高見', 'タカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県善通寺市', '37', '37204', '7650000', '香川県', 'カガワケン', '善通寺市', 'ゼンツウジシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('95632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県善通寺市仙遊町', '37', '37204', '7650001', '香川県', 'カガワケン', '善通寺市', 'ゼンツウジシ', '仙遊町', 'センユウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県善通寺市南町', '37', '37204', '7650002', '香川県', 'カガワケン', '善通寺市', 'ゼンツウジシ', '南町', 'ミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県善通寺市善通寺町', '37', '37204', '7650003', '香川県', 'カガワケン', '善通寺市', 'ゼンツウジシ', '善通寺町', 'ゼンツウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県善通寺市善通寺町', '37', '37204', '7650004', '香川県', 'カガワケン', '善通寺市', 'ゼンツウジシ', '善通寺町', 'ゼンツウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県善通寺市上吉田町', '37', '37204', '7650011', '香川県', 'カガワケン', '善通寺市', 'ゼンツウジシ', '上吉田町', 'カミヨシダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県善通寺市上吉田町', '37', '37204', '7650012', '香川県', 'カガワケン', '善通寺市', 'ゼンツウジシ', '上吉田町', 'カミヨシダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県善通寺市文京町', '37', '37204', '7650013', '香川県', 'カガワケン', '善通寺市', 'ゼンツウジシ', '文京町', 'ブンキョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県善通寺市生野本町', '37', '37204', '7650014', '香川県', 'カガワケン', '善通寺市', 'ゼンツウジシ', '生野本町', 'イカノホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県善通寺市下吉田町', '37', '37204', '7650021', '香川県', 'カガワケン', '善通寺市', 'ゼンツウジシ', '下吉田町', 'シモヨシダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県善通寺市稲木町', '37', '37204', '7650022', '香川県', 'カガワケン', '善通寺市', 'ゼンツウジシ', '稲木町', 'イナギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県善通寺市金蔵寺町', '37', '37204', '7650031', '香川県', 'カガワケン', '善通寺市', 'ゼンツウジシ', '金蔵寺町', 'コンゾウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県善通寺市原田町', '37', '37204', '7650032', '香川県', 'カガワケン', '善通寺市', 'ゼンツウジシ', '原田町', 'ハラダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県善通寺市木徳町', '37', '37204', '7650033', '香川県', 'カガワケン', '善通寺市', 'ゼンツウジシ', '木徳町', 'キトクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県善通寺市与北町', '37', '37204', '7650040', '香川県', 'カガワケン', '善通寺市', 'ゼンツウジシ', '与北町', 'ヨギタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県善通寺市櫛梨町', '37', '37204', '7650051', '香川県', 'カガワケン', '善通寺市', 'ゼンツウジシ', '櫛梨町', 'クシナシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県善通寺市大麻町', '37', '37204', '7650052', '香川県', 'カガワケン', '善通寺市', 'ゼンツウジシ', '大麻町', 'オオサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県善通寺市生野町', '37', '37204', '7650053', '香川県', 'カガワケン', '善通寺市', 'ゼンツウジシ', '生野町', 'イカノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県善通寺市吉原町', '37', '37204', '7650061', '香川県', 'カガワケン', '善通寺市', 'ゼンツウジシ', '吉原町', 'ヨシワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県善通寺市碑殿町', '37', '37204', '7650062', '香川県', 'カガワケン', '善通寺市', 'ゼンツウジシ', '碑殿町', 'ヒドノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県善通寺市弘田町', '37', '37204', '7650071', '香川県', 'カガワケン', '善通寺市', 'ゼンツウジシ', '弘田町', 'ヒロタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県善通寺市中村町', '37', '37204', '7650072', '香川県', 'カガワケン', '善通寺市', 'ゼンツウジシ', '中村町', 'ナカムラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県善通寺市中村町', '37', '37204', '7650073', '香川県', 'カガワケン', '善通寺市', 'ゼンツウジシ', '中村町', 'ナカムラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県仲多度郡琴平町', '37', '37403', '7660000', '香川県', 'カガワケン', '仲多度郡琴平町', 'ナカタドグンコトヒラチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('95663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県仲多度郡まんのう町', '37', '37406', '7660000', '香川県', 'カガワケン', '仲多度郡まんのう町', 'ナカタドグンマンノウチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('95664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県仲多度郡琴平町琴平町', '37', '37403', '7660001', '香川県', 'カガワケン', '仲多度郡琴平町', 'ナカタドグンコトヒラチョウ', '琴平町', 'コトヒラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県仲多度郡琴平町琴平町川西', '37', '37403', '7660001', '香川県', 'カガワケン', '仲多度郡琴平町', 'ナカタドグンコトヒラチョウ', '琴平町', 'コトヒラチョウ', null, null, '川西', 'カワニシ');
INSERT INTO `ms_addresses` VALUES ('95666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県仲多度郡琴平町琴平町', '37', '37403', '7660002', '香川県', 'カガワケン', '仲多度郡琴平町', 'ナカタドグンコトヒラチョウ', '琴平町', 'コトヒラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県仲多度郡琴平町琴平町川東', '37', '37403', '7660002', '香川県', 'カガワケン', '仲多度郡琴平町', 'ナカタドグンコトヒラチョウ', '琴平町', 'コトヒラチョウ', null, null, '川東', 'カワヒガシ');
INSERT INTO `ms_addresses` VALUES ('95668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県仲多度郡琴平町五條', '37', '37403', '7660003', '香川県', 'カガワケン', '仲多度郡琴平町', 'ナカタドグンコトヒラチョウ', '五條', 'ゴジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県仲多度郡琴平町榎井', '37', '37403', '7660004', '香川県', 'カガワケン', '仲多度郡琴平町', 'ナカタドグンコトヒラチョウ', '榎井', 'エナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県仲多度郡琴平町苗田', '37', '37403', '7660005', '香川県', 'カガワケン', '仲多度郡琴平町', 'ナカタドグンコトヒラチョウ', '苗田', 'ノウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県仲多度郡琴平町上櫛梨', '37', '37403', '7660006', '香川県', 'カガワケン', '仲多度郡琴平町', 'ナカタドグンコトヒラチョウ', '上櫛梨', 'カミクシナシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県仲多度郡琴平町下櫛梨', '37', '37403', '7660007', '香川県', 'カガワケン', '仲多度郡琴平町', 'ナカタドグンコトヒラチョウ', '下櫛梨', 'シモクシナシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県仲多度郡まんのう町公文', '37', '37406', '7660011', '香川県', 'カガワケン', '仲多度郡まんのう町', 'ナカタドグンマンノウチョウ', '公文', 'クモン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県仲多度郡まんのう町西高篠', '37', '37406', '7660012', '香川県', 'カガワケン', '仲多度郡まんのう町', 'ナカタドグンマンノウチョウ', '西高篠', 'ニシタカシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県仲多度郡まんのう町東高篠', '37', '37406', '7660013', '香川県', 'カガワケン', '仲多度郡まんのう町', 'ナカタドグンマンノウチョウ', '東高篠', 'ヒガシタカシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県仲多度郡まんのう町羽間', '37', '37406', '7660014', '香川県', 'カガワケン', '仲多度郡まんのう町', 'ナカタドグンマンノウチョウ', '羽間', 'ハザマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県仲多度郡まんのう町長尾', '37', '37406', '7660015', '香川県', 'カガワケン', '仲多度郡まんのう町', 'ナカタドグンマンノウチョウ', '長尾', 'ナガオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県仲多度郡まんのう町炭所東', '37', '37406', '7660016', '香川県', 'カガワケン', '仲多度郡まんのう町', 'ナカタドグンマンノウチョウ', '炭所東', 'スミショヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県仲多度郡まんのう町炭所西', '37', '37406', '7660017', '香川県', 'カガワケン', '仲多度郡まんのう町', 'ナカタドグンマンノウチョウ', '炭所西', 'スミショニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県仲多度郡まんのう町四条', '37', '37406', '7660021', '香川県', 'カガワケン', '仲多度郡まんのう町', 'ナカタドグンマンノウチョウ', '四条', 'シジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県仲多度郡まんのう町吉野下', '37', '37406', '7660022', '香川県', 'カガワケン', '仲多度郡まんのう町', 'ナカタドグンマンノウチョウ', '吉野下', 'ヨシノシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県仲多度郡まんのう町吉野', '37', '37406', '7660023', '香川県', 'カガワケン', '仲多度郡まんのう町', 'ナカタドグンマンノウチョウ', '吉野', 'ヨシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県仲多度郡まんのう町神野', '37', '37406', '7660024', '香川県', 'カガワケン', '仲多度郡まんのう町', 'ナカタドグンマンノウチョウ', '神野', 'カンノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県仲多度郡まんのう町真野', '37', '37406', '7660025', '香川県', 'カガワケン', '仲多度郡まんのう町', 'ナカタドグンマンノウチョウ', '真野', 'マノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県仲多度郡まんのう町岸上', '37', '37406', '7660026', '香川県', 'カガワケン', '仲多度郡まんのう町', 'ナカタドグンマンノウチョウ', '岸上', 'キシノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県仲多度郡まんのう町五条', '37', '37406', '7660027', '香川県', 'カガワケン', '仲多度郡まんのう町', 'ナカタドグンマンノウチョウ', '五条', 'ゴジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県仲多度郡まんのう町造田', '37', '37406', '7660201', '香川県', 'カガワケン', '仲多度郡まんのう町', 'ナカタドグンマンノウチョウ', '造田', 'ソウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県仲多度郡まんのう町中通', '37', '37406', '7660202', '香川県', 'カガワケン', '仲多度郡まんのう町', 'ナカタドグンマンノウチョウ', '中通', 'ナカト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県仲多度郡まんのう町川東', '37', '37406', '7660203', '香川県', 'カガワケン', '仲多度郡まんのう町', 'ナカタドグンマンノウチョウ', '川東', 'カワヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県仲多度郡まんのう町勝浦', '37', '37406', '7660204', '香川県', 'カガワケン', '仲多度郡まんのう町', 'ナカタドグンマンノウチョウ', '勝浦', 'カツウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県三豊市', '37', '37208', '7670000', '香川県', 'カガワケン', '三豊市', 'ミトヨシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('95694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県三豊市高瀬町上高瀬', '37', '37208', '7670001', '香川県', 'カガワケン', '三豊市', 'ミトヨシ', '高瀬町上高瀬', 'タカセチョウカミタカセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県三豊市高瀬町新名', '37', '37208', '7670002', '香川県', 'カガワケン', '三豊市', 'ミトヨシ', '高瀬町新名', 'タカセチョウシンミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県三豊市高瀬町比地中', '37', '37208', '7670003', '香川県', 'カガワケン', '三豊市', 'ミトヨシ', '高瀬町比地中', 'タカセチョウヒジナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県三豊市高瀬町比地', '37', '37208', '7670004', '香川県', 'カガワケン', '三豊市', 'ミトヨシ', '高瀬町比地', 'タカセチョウヒジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県三豊市高瀬町下勝間', '37', '37208', '7670011', '香川県', 'カガワケン', '三豊市', 'ミトヨシ', '高瀬町下勝間', 'タカセチョウシモカツマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県三豊市高瀬町上勝間', '37', '37208', '7670012', '香川県', 'カガワケン', '三豊市', 'ミトヨシ', '高瀬町上勝間', 'タカセチョウカミカツマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県三豊市高瀬町下麻', '37', '37208', '7670013', '香川県', 'カガワケン', '三豊市', 'ミトヨシ', '高瀬町下麻', 'タカセチョウシモアサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県三豊市高瀬町上麻', '37', '37208', '7670014', '香川県', 'カガワケン', '三豊市', 'ミトヨシ', '高瀬町上麻', 'タカセチョウカミアサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県三豊市高瀬町佐股', '37', '37208', '7670021', '香川県', 'カガワケン', '三豊市', 'ミトヨシ', '高瀬町佐股', 'タカセチョウサマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県三豊市高瀬町羽方', '37', '37208', '7670022', '香川県', 'カガワケン', '三豊市', 'ミトヨシ', '高瀬町羽方', 'タカセチョウハガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県三豊市三野町大見', '37', '37208', '7670031', '香川県', 'カガワケン', '三豊市', 'ミトヨシ', '三野町大見', 'ミノチョウオオミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県三豊市三野町下高瀬', '37', '37208', '7670032', '香川県', 'カガワケン', '三豊市', 'ミトヨシ', '三野町下高瀬', 'ミノチョウシモタカセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県三豊市三野町吉津', '37', '37208', '7670033', '香川県', 'カガワケン', '三豊市', 'ミトヨシ', '三野町吉津', 'ミノチョウヨシヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県観音寺市', '37', '37205', '7680000', '香川県', 'カガワケン', '観音寺市', 'カンオンジシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('95714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県観音寺市室本町', '37', '37205', '7680001', '香川県', 'カガワケン', '観音寺市', 'カンオンジシ', '室本町', 'ムロモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県観音寺市高屋町', '37', '37205', '7680002', '香川県', 'カガワケン', '観音寺市', 'カンオンジシ', '高屋町', 'タカヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県観音寺市出作町', '37', '37205', '7680011', '香川県', 'カガワケン', '観音寺市', 'カンオンジシ', '出作町', 'シュツサクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県観音寺市植田町', '37', '37205', '7680012', '香川県', 'カガワケン', '観音寺市', 'カンオンジシ', '植田町', 'ウエダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県観音寺市村黒町', '37', '37205', '7680013', '香川県', 'カガワケン', '観音寺市', 'カンオンジシ', '村黒町', 'ムラグロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県観音寺市流岡町', '37', '37205', '7680014', '香川県', 'カガワケン', '観音寺市', 'カンオンジシ', '流岡町', 'ナガレオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県観音寺市吉岡町', '37', '37205', '7680021', '香川県', 'カガワケン', '観音寺市', 'カンオンジシ', '吉岡町', 'ヨシオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県観音寺市本大町', '37', '37205', '7680022', '香川県', 'カガワケン', '観音寺市', 'カンオンジシ', '本大町', 'モトダイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県観音寺市古川町', '37', '37205', '7680023', '香川県', 'カガワケン', '観音寺市', 'カンオンジシ', '古川町', 'フルカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県観音寺市中田井町', '37', '37205', '7680024', '香川県', 'カガワケン', '観音寺市', 'カンオンジシ', '中田井町', 'ナカダイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県観音寺市池之尻町', '37', '37205', '7680031', '香川県', 'カガワケン', '観音寺市', 'カンオンジシ', '池之尻町', 'イケノシリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県観音寺市原町', '37', '37205', '7680032', '香川県', 'カガワケン', '観音寺市', 'カンオンジシ', '原町', 'ハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県観音寺市新田町', '37', '37205', '7680033', '香川県', 'カガワケン', '観音寺市', 'カンオンジシ', '新田町', 'シンデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県観音寺市柞田町', '37', '37205', '7680040', '香川県', 'カガワケン', '観音寺市', 'カンオンジシ', '柞田町', 'クニタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県観音寺市木之郷町', '37', '37205', '7680051', '香川県', 'カガワケン', '観音寺市', 'カンオンジシ', '木之郷町', 'キノゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県観音寺市粟井町', '37', '37205', '7680052', '香川県', 'カガワケン', '観音寺市', 'カンオンジシ', '粟井町', 'アワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県観音寺市観音寺町', '37', '37205', '7680060', '香川県', 'カガワケン', '観音寺市', 'カンオンジシ', '観音寺町', 'カンオンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県観音寺市八幡町', '37', '37205', '7680061', '香川県', 'カガワケン', '観音寺市', 'カンオンジシ', '八幡町', 'ヤハタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県観音寺市有明町', '37', '37205', '7680062', '香川県', 'カガワケン', '観音寺市', 'カンオンジシ', '有明町', 'アリアケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県観音寺市三本松町', '37', '37205', '7680063', '香川県', 'カガワケン', '観音寺市', 'カンオンジシ', '三本松町', 'サンボンマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県観音寺市琴浪町', '37', '37205', '7680064', '香川県', 'カガワケン', '観音寺市', 'カンオンジシ', '琴浪町', 'コトナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県観音寺市瀬戸町', '37', '37205', '7680065', '香川県', 'カガワケン', '観音寺市', 'カンオンジシ', '瀬戸町', 'セトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県観音寺市昭和町', '37', '37205', '7680066', '香川県', 'カガワケン', '観音寺市', 'カンオンジシ', '昭和町', 'ショウワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県観音寺市坂本町', '37', '37205', '7680067', '香川県', 'カガワケン', '観音寺市', 'カンオンジシ', '坂本町', 'サカモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県観音寺市天神町', '37', '37205', '7680068', '香川県', 'カガワケン', '観音寺市', 'カンオンジシ', '天神町', 'テンジンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県観音寺市茂木町', '37', '37205', '7680069', '香川県', 'カガワケン', '観音寺市', 'カンオンジシ', '茂木町', 'シゲキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県観音寺市南町', '37', '37205', '7680070', '香川県', 'カガワケン', '観音寺市', 'カンオンジシ', '南町', 'ミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県観音寺市伊吹町', '37', '37205', '7680071', '香川県', 'カガワケン', '観音寺市', 'カンオンジシ', '伊吹町', 'イブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県観音寺市栄町', '37', '37205', '7680072', '香川県', 'カガワケン', '観音寺市', 'カンオンジシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県三豊市山本町辻', '37', '37208', '7680101', '香川県', 'カガワケン', '三豊市', 'ミトヨシ', '山本町辻', 'ヤマモトチョウツジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県三豊市山本町大野', '37', '37208', '7680102', '香川県', 'カガワケン', '三豊市', 'ミトヨシ', '山本町大野', 'ヤマモトチョウオオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県三豊市山本町財田西', '37', '37208', '7680103', '香川県', 'カガワケン', '三豊市', 'ミトヨシ', '山本町財田西', 'ヤマモトチョウサイタニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県三豊市山本町神田', '37', '37208', '7680104', '香川県', 'カガワケン', '三豊市', 'ミトヨシ', '山本町神田', 'ヤマモトチョウコウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県三豊市山本町河内', '37', '37208', '7680105', '香川県', 'カガワケン', '三豊市', 'ミトヨシ', '山本町河内', 'ヤマモトチョウコウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市国分寺町新居', '37', '37201', '7690101', '香川県', 'カガワケン', '高松市', 'タカマツシ', '国分寺町新居', 'コクブンジチョウニイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市国分寺町国分', '37', '37201', '7690102', '香川県', 'カガワケン', '高松市', 'タカマツシ', '国分寺町国分', 'コクブンジチョウコクブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市国分寺町福家', '37', '37201', '7690103', '香川県', 'カガワケン', '高松市', 'タカマツシ', '国分寺町福家', 'コクブンジチョウフケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市国分寺町新名', '37', '37201', '7690104', '香川県', 'カガワケン', '高松市', 'タカマツシ', '国分寺町新名', 'コクブンジチョウシンミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県高松市国分寺町柏原', '37', '37201', '7690105', '香川県', 'カガワケン', '高松市', 'タカマツシ', '国分寺町柏原', 'コクブンジチョウカシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県綾歌郡宇多津町', '37', '37386', '7690200', '香川県', 'カガワケン', '綾歌郡宇多津町', 'アヤウタグンウタヅチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('95770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県綾歌郡宇多津町浜一番丁', '37', '37386', '7690201', '香川県', 'カガワケン', '綾歌郡宇多津町', 'アヤウタグンウタヅチョウ', '浜一番丁', 'ハマ01バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県綾歌郡宇多津町浜二番丁', '37', '37386', '7690202', '香川県', 'カガワケン', '綾歌郡宇多津町', 'アヤウタグンウタヅチョウ', '浜二番丁', 'ハマ02バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県綾歌郡宇多津町浜三番丁', '37', '37386', '7690203', '香川県', 'カガワケン', '綾歌郡宇多津町', 'アヤウタグンウタヅチョウ', '浜三番丁', 'ハマ03バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県綾歌郡宇多津町浜四番丁', '37', '37386', '7690204', '香川県', 'カガワケン', '綾歌郡宇多津町', 'アヤウタグンウタヅチョウ', '浜四番丁', 'ハマ04バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県綾歌郡宇多津町浜五番丁', '37', '37386', '7690205', '香川県', 'カガワケン', '綾歌郡宇多津町', 'アヤウタグンウタヅチョウ', '浜五番丁', 'ハマ05バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県綾歌郡宇多津町浜六番丁', '37', '37386', '7690206', '香川県', 'カガワケン', '綾歌郡宇多津町', 'アヤウタグンウタヅチョウ', '浜六番丁', 'ハマ06バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県綾歌郡宇多津町浜七番丁', '37', '37386', '7690207', '香川県', 'カガワケン', '綾歌郡宇多津町', 'アヤウタグンウタヅチョウ', '浜七番丁', 'ハマ07バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県綾歌郡宇多津町浜八番丁', '37', '37386', '7690208', '香川県', 'カガワケン', '綾歌郡宇多津町', 'アヤウタグンウタヅチョウ', '浜八番丁', 'ハマ08バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県綾歌郡宇多津町浜九番丁', '37', '37386', '7690209', '香川県', 'カガワケン', '綾歌郡宇多津町', 'アヤウタグンウタヅチョウ', '浜九番丁', 'ハマ09バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県綾歌郡宇多津町', '37', '37386', '7690210', '香川県', 'カガワケン', '綾歌郡宇多津町', 'アヤウタグンウタヅチョウ', null, '　', '（直番地）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('95780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県綾歌郡宇多津町十楽寺', '37', '37386', '7690211', '香川県', 'カガワケン', '綾歌郡宇多津町', 'アヤウタグンウタヅチョウ', '十楽寺', 'ジュウラクジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県綾歌郡宇多津町沼ノ池', '37', '37386', '7690212', '香川県', 'カガワケン', '綾歌郡宇多津町', 'アヤウタグンウタヅチョウ', '沼ノ池', 'ヌマノイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県綾歌郡宇多津町東分', '37', '37386', '7690213', '香川県', 'カガワケン', '綾歌郡宇多津町', 'アヤウタグンウタヅチョウ', '東分', 'ヒガシブン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県綾歌郡宇多津町吉田', '37', '37386', '7690221', '香川県', 'カガワケン', '綾歌郡宇多津町', 'アヤウタグンウタヅチョウ', '吉田', 'ヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県綾歌郡宇多津町大橋', '37', '37386', '7690222', '香川県', 'カガワケン', '綾歌郡宇多津町', 'アヤウタグンウタヅチョウ', '大橋', 'オオハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県綾歌郡宇多津町新開', '37', '37386', '7690223', '香川県', 'カガワケン', '綾歌郡宇多津町', 'アヤウタグンウタヅチョウ', '新開', 'シンガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県綾歌郡宇多津町平山', '37', '37386', '7690224', '香川県', 'カガワケン', '綾歌郡宇多津町', 'アヤウタグンウタヅチョウ', '平山', 'ヒラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県綾歌郡宇多津町新町', '37', '37386', '7690225', '香川県', 'カガワケン', '綾歌郡宇多津町', 'アヤウタグンウタヅチョウ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県綾歌郡宇多津町坂下', '37', '37386', '7690226', '香川県', 'カガワケン', '綾歌郡宇多津町', 'アヤウタグンウタヅチョウ', '坂下', 'サカシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県綾歌郡宇多津町岩屋', '37', '37386', '7690227', '香川県', 'カガワケン', '綾歌郡宇多津町', 'アヤウタグンウタヅチョウ', '岩屋', 'イワヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県綾歌郡宇多津町向山', '37', '37386', '7690228', '香川県', 'カガワケン', '綾歌郡宇多津町', 'アヤウタグンウタヅチョウ', '向山', 'ムカウヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県仲多度郡まんのう町佐文', '37', '37406', '7690301', '香川県', 'カガワケン', '仲多度郡まんのう町', 'ナカタドグンマンノウチョウ', '佐文', 'サブミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県仲多度郡まんのう町塩入', '37', '37406', '7690302', '香川県', 'カガワケン', '仲多度郡まんのう町', 'ナカタドグンマンノウチョウ', '塩入', 'シオイリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県仲多度郡まんのう町七箇', '37', '37406', '7690303', '香川県', 'カガワケン', '仲多度郡まんのう町', 'ナカタドグンマンノウチョウ', '七箇', 'シチカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県仲多度郡まんのう町十郷', '37', '37406', '7690310', '香川県', 'カガワケン', '仲多度郡まんのう町', 'ナカタドグンマンノウチョウ', '十郷', 'ソゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県仲多度郡まんのう町買田', '37', '37406', '7690311', '香川県', 'カガワケン', '仲多度郡まんのう町', 'ナカタドグンマンノウチョウ', '買田', 'カイタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県仲多度郡まんのう町宮田', '37', '37406', '7690312', '香川県', 'カガワケン', '仲多度郡まんのう町', 'ナカタドグンマンノウチョウ', '宮田', 'ミヤダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県仲多度郡まんのう町生間', '37', '37406', '7690313', '香川県', 'カガワケン', '仲多度郡まんのう町', 'ナカタドグンマンノウチョウ', '生間', 'イカマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県仲多度郡まんのう町帆山', '37', '37406', '7690314', '香川県', 'カガワケン', '仲多度郡まんのう町', 'ナカタドグンマンノウチョウ', '帆山', 'ホノヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県仲多度郡まんのう町後山', '37', '37406', '7690315', '香川県', 'カガワケン', '仲多度郡まんのう町', 'ナカタドグンマンノウチョウ', '後山', 'ウシロヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県仲多度郡まんのう町大口', '37', '37406', '7690316', '香川県', 'カガワケン', '仲多度郡まんのう町', 'ナカタドグンマンノウチョウ', '大口', 'オオクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県仲多度郡まんのう町新目', '37', '37406', '7690317', '香川県', 'カガワケン', '仲多度郡まんのう町', 'ナカタドグンマンノウチョウ', '新目', 'シンメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県仲多度郡まんのう町山脇', '37', '37406', '7690318', '香川県', 'カガワケン', '仲多度郡まんのう町', 'ナカタドグンマンノウチョウ', '山脇', 'ヤマワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県仲多度郡まんのう町追上', '37', '37406', '7690319', '香川県', 'カガワケン', '仲多度郡まんのう町', 'ナカタドグンマンノウチョウ', '追上', 'オイアゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県三豊市財田町財田上', '37', '37208', '7690401', '香川県', 'カガワケン', '三豊市', 'ミトヨシ', '財田町財田上', 'サイタチョウサイタカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県三豊市財田町財田中', '37', '37208', '7690402', '香川県', 'カガワケン', '三豊市', 'ミトヨシ', '財田町財田中', 'サイタチョウサイタナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県三豊市詫間町詫間', '37', '37208', '7691101', '香川県', 'カガワケン', '三豊市', 'ミトヨシ', '詫間町詫間', 'タクマチョウタクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県三豊市詫間町松崎', '37', '37208', '7691102', '香川県', 'カガワケン', '三豊市', 'ミトヨシ', '詫間町松崎', 'タクマチョウマツサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県三豊市詫間町香田', '37', '37208', '7691103', '香川県', 'カガワケン', '三豊市', 'ミトヨシ', '詫間町香田', 'タクマチョウコウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県三豊市詫間町大浜', '37', '37208', '7691104', '香川県', 'カガワケン', '三豊市', 'ミトヨシ', '詫間町大浜', 'タクマチョウオオハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県三豊市詫間町積', '37', '37208', '7691105', '香川県', 'カガワケン', '三豊市', 'ミトヨシ', '詫間町積', 'タクマチョウツム', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県三豊市詫間町箱', '37', '37208', '7691106', '香川県', 'カガワケン', '三豊市', 'ミトヨシ', '詫間町箱', 'タクマチョウハコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県三豊市詫間町生里', '37', '37208', '7691107', '香川県', 'カガワケン', '三豊市', 'ミトヨシ', '詫間町生里', 'タクマチョウナマリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県三豊市詫間町粟島', '37', '37208', '7691108', '香川県', 'カガワケン', '三豊市', 'ミトヨシ', '詫間町粟島', 'タクマチョウアワシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県三豊市詫間町志々島', '37', '37208', '7691109', '香川県', 'カガワケン', '三豊市', 'ミトヨシ', '詫間町志々島', 'タクマチョウシシジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県三豊市仁尾町仁尾己', '37', '37208', '7691401', '香川県', 'カガワケン', '三豊市', 'ミトヨシ', '仁尾町仁尾己', 'ニオチョウニオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県三豊市仁尾町仁尾戊', '37', '37208', '7691402', '香川県', 'カガワケン', '三豊市', 'ミトヨシ', '仁尾町仁尾戊', 'ニオチョウニオボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県三豊市仁尾町仁尾丙', '37', '37208', '7691403', '香川県', 'カガワケン', '三豊市', 'ミトヨシ', '仁尾町仁尾丙', 'ニオチョウニオヘイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県三豊市仁尾町仁尾乙', '37', '37208', '7691404', '香川県', 'カガワケン', '三豊市', 'ミトヨシ', '仁尾町仁尾乙', 'ニオチョウニオオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県三豊市仁尾町仁尾庚', '37', '37208', '7691405', '香川県', 'カガワケン', '三豊市', 'ミトヨシ', '仁尾町仁尾庚', 'ニオチョウニオコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県三豊市仁尾町仁尾辛', '37', '37208', '7691406', '香川県', 'カガワケン', '三豊市', 'ミトヨシ', '仁尾町仁尾辛', 'ニオチョウニオシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県三豊市仁尾町仁尾丁', '37', '37208', '7691407', '香川県', 'カガワケン', '三豊市', 'ミトヨシ', '仁尾町仁尾丁', 'ニオチョウニオテイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県三豊市仁尾町仁尾甲', '37', '37208', '7691408', '香川県', 'カガワケン', '三豊市', 'ミトヨシ', '仁尾町仁尾甲', 'ニオチョウニオコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県三豊市仁尾町家の浦', '37', '37208', '7691410', '香川県', 'カガワケン', '三豊市', 'ミトヨシ', '仁尾町家の浦', 'ニオチョウイエノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県三豊市豊中町比地大', '37', '37208', '7691501', '香川県', 'カガワケン', '三豊市', 'ミトヨシ', '豊中町比地大', 'トヨナカチョウヒジダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県三豊市豊中町笠田笠岡', '37', '37208', '7691502', '香川県', 'カガワケン', '三豊市', 'ミトヨシ', '豊中町笠田笠岡', 'トヨナカチョウカサダカサオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県三豊市豊中町笠田竹田', '37', '37208', '7691503', '香川県', 'カガワケン', '三豊市', 'ミトヨシ', '豊中町笠田竹田', 'トヨナカチョウカサダタケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県三豊市豊中町上高野', '37', '37208', '7691504', '香川県', 'カガワケン', '三豊市', 'ミトヨシ', '豊中町上高野', 'トヨナカチョウカミダカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県三豊市豊中町本山乙', '37', '37208', '7691505', '香川県', 'カガワケン', '三豊市', 'ミトヨシ', '豊中町本山乙', 'トヨナカチョウモトヤマオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県三豊市豊中町本山甲', '37', '37208', '7691506', '香川県', 'カガワケン', '三豊市', 'ミトヨシ', '豊中町本山甲', 'トヨナカチョウモトヤマコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県三豊市豊中町岡本', '37', '37208', '7691507', '香川県', 'カガワケン', '三豊市', 'ミトヨシ', '豊中町岡本', 'トヨナカチョウオカモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県三豊市豊中町下高野', '37', '37208', '7691508', '香川県', 'カガワケン', '三豊市', 'ミトヨシ', '豊中町下高野', 'トヨナカチョウシモダカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県観音寺市豊浜町姫浜', '37', '37205', '7691601', '香川県', 'カガワケン', '観音寺市', 'カンオンジシ', '豊浜町姫浜', 'トヨハマチョウヒメハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県観音寺市豊浜町和田浜', '37', '37205', '7691602', '香川県', 'カガワケン', '観音寺市', 'カンオンジシ', '豊浜町和田浜', 'トヨハマチョウワダハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県観音寺市豊浜町和田', '37', '37205', '7691603', '香川県', 'カガワケン', '観音寺市', 'カンオンジシ', '豊浜町和田', 'トヨハマチョウワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県観音寺市豊浜町箕浦', '37', '37205', '7691604', '香川県', 'カガワケン', '観音寺市', 'カンオンジシ', '豊浜町箕浦', 'トヨハマチョウミノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県観音寺市大野原町大野原', '37', '37205', '7691611', '香川県', 'カガワケン', '観音寺市', 'カンオンジシ', '大野原町大野原', 'オオノハラチョウオオノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県観音寺市大野原町中姫', '37', '37205', '7691612', '香川県', 'カガワケン', '観音寺市', 'カンオンジシ', '大野原町中姫', 'オオノハラチョウナカヒメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県観音寺市大野原町花稲', '37', '37205', '7691613', '香川県', 'カガワケン', '観音寺市', 'カンオンジシ', '大野原町花稲', 'オオノハラチョウハナイナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県観音寺市大野原町萩原', '37', '37205', '7691614', '香川県', 'カガワケン', '観音寺市', 'カンオンジシ', '大野原町萩原', 'オオノハラチョウハギワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県観音寺市大野原町丸井', '37', '37205', '7691615', '香川県', 'カガワケン', '観音寺市', 'カンオンジシ', '大野原町丸井', 'オオノハラチョウマルイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県観音寺市大野原町福田原', '37', '37205', '7691616', '香川県', 'カガワケン', '観音寺市', 'カンオンジシ', '大野原町福田原', 'オオノハラチョウフクダハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県観音寺市大野原町青岡', '37', '37205', '7691617', '香川県', 'カガワケン', '観音寺市', 'カンオンジシ', '大野原町青岡', 'オオノハラチョウアオオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県観音寺市大野原町井関', '37', '37205', '7691621', '香川県', 'カガワケン', '観音寺市', 'カンオンジシ', '大野原町井関', 'オオノハラチョウイセキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県観音寺市大野原町内野々', '37', '37205', '7691622', '香川県', 'カガワケン', '観音寺市', 'カンオンジシ', '大野原町内野々', 'オオノハラチョウウチノノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県観音寺市大野原町田野々', '37', '37205', '7691623', '香川県', 'カガワケン', '観音寺市', 'カンオンジシ', '大野原町田野々', 'オオノハラチョウタノノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県観音寺市大野原町有木', '37', '37205', '7691624', '香川県', 'カガワケン', '観音寺市', 'カンオンジシ', '大野原町有木', 'オオノハラチョウアリキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県観音寺市大野原町海老済', '37', '37205', '7691625', '香川県', 'カガワケン', '観音寺市', 'カンオンジシ', '大野原町海老済', 'オオノハラチョウエビスクイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県さぬき市志度', '37', '37206', '7692101', '香川県', 'カガワケン', 'さぬき市', 'サヌキシ', '志度', 'シド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県さぬき市鴨庄', '37', '37206', '7692102', '香川県', 'カガワケン', 'さぬき市', 'サヌキシ', '鴨庄', 'カモショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県さぬき市小田', '37', '37206', '7692103', '香川県', 'カガワケン', 'さぬき市', 'サヌキシ', '小田', 'オダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県さぬき市鴨部', '37', '37206', '7692104', '香川県', 'カガワケン', 'さぬき市', 'サヌキシ', '鴨部', 'カベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県さぬき市末', '37', '37206', '7692105', '香川県', 'カガワケン', 'さぬき市', 'サヌキシ', '末', 'スエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県さぬき市', '37', '37206', '7692300', '香川県', 'カガワケン', 'さぬき市', 'サヌキシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('95868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県さぬき市長尾東', '37', '37206', '7692301', '香川県', 'カガワケン', 'さぬき市', 'サヌキシ', '長尾東', 'ナガオヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県さぬき市長尾西', '37', '37206', '7692302', '香川県', 'カガワケン', 'さぬき市', 'サヌキシ', '長尾西', 'ナガオニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県さぬき市長尾名', '37', '37206', '7692303', '香川県', 'カガワケン', 'さぬき市', 'サヌキシ', '長尾名', 'ナガオミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県さぬき市昭和', '37', '37206', '7692304', '香川県', 'カガワケン', 'さぬき市', 'サヌキシ', '昭和', 'ショウワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県さぬき市前山', '37', '37206', '7692305', '香川県', 'カガワケン', 'さぬき市', 'サヌキシ', '前山', 'マエヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県さぬき市多和', '37', '37206', '7692306', '香川県', 'カガワケン', 'さぬき市', 'サヌキシ', '多和', 'タワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県さぬき市造田宮西', '37', '37206', '7692311', '香川県', 'カガワケン', 'さぬき市', 'サヌキシ', '造田宮西', 'ゾウタミヤニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県さぬき市造田是弘', '37', '37206', '7692312', '香川県', 'カガワケン', 'さぬき市', 'サヌキシ', '造田是弘', 'ゾウタコレヒロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県さぬき市造田野間田', '37', '37206', '7692313', '香川県', 'カガワケン', 'さぬき市', 'サヌキシ', '造田野間田', 'ゾウタノマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県さぬき市造田乙井', '37', '37206', '7692314', '香川県', 'カガワケン', 'さぬき市', 'サヌキシ', '造田乙井', 'ゾウタオトイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県さぬき市造田オレンジタウン', '37', '37206', '7692315', '香川県', 'カガワケン', 'さぬき市', 'サヌキシ', '造田', 'ゾウタ', null, null, 'オレンジタウン', 'オレンジタウン');
INSERT INTO `ms_addresses` VALUES ('95879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県さぬき市寒川町石田東', '37', '37206', '7692321', '香川県', 'カガワケン', 'さぬき市', 'サヌキシ', '寒川町石田東', 'サンガワマチイシダヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県さぬき市寒川町石田西', '37', '37206', '7692322', '香川県', 'カガワケン', 'さぬき市', 'サヌキシ', '寒川町石田西', 'サンガワマチイシダニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県さぬき市寒川町神前', '37', '37206', '7692323', '香川県', 'カガワケン', 'さぬき市', 'サヌキシ', '寒川町神前', 'サンガワマチカンザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県さぬき市津田町津田', '37', '37206', '7692401', '香川県', 'カガワケン', 'さぬき市', 'サヌキシ', '津田町津田', 'ツダマチツダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県さぬき市津田町鶴羽', '37', '37206', '7692402', '香川県', 'カガワケン', 'さぬき市', 'サヌキシ', '津田町鶴羽', 'ツダマチツルワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県東かがわ市小磯', '37', '37207', '7692511', '香川県', 'カガワケン', '東かがわ市', 'ヒガシカガワシ', '小磯', 'コイソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県東かがわ市落合', '37', '37207', '7692512', '香川県', 'カガワケン', '東かがわ市', 'ヒガシカガワシ', '落合', 'オチアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県東かがわ市大谷', '37', '37207', '7692513', '香川県', 'カガワケン', '東かがわ市', 'ヒガシカガワシ', '大谷', 'オオタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県東かがわ市松崎', '37', '37207', '7692514', '香川県', 'カガワケン', '東かがわ市', 'ヒガシカガワシ', '松崎', 'マツサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県東かがわ市町田', '37', '37207', '7692515', '香川県', 'カガワケン', '東かがわ市', 'ヒガシカガワシ', '町田', 'マチダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県東かがわ市土居', '37', '37207', '7692516', '香川県', 'カガワケン', '東かがわ市', 'ヒガシカガワシ', '土居', 'ドイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県東かがわ市三殿', '37', '37207', '7692517', '香川県', 'カガワケン', '東かがわ市', 'ヒガシカガワシ', '三殿', 'ミドノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県東かがわ市中山', '37', '37207', '7692518', '香川県', 'カガワケン', '東かがわ市', 'ヒガシカガワシ', '中山', 'ナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県東かがわ市小砂', '37', '37207', '7692519', '香川県', 'カガワケン', '東かがわ市', 'ヒガシカガワシ', '小砂', 'コザレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県東かがわ市馬篠', '37', '37207', '7692520', '香川県', 'カガワケン', '東かがわ市', 'ヒガシカガワシ', '馬篠', 'ウマシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県東かがわ市大内', '37', '37207', '7692521', '香川県', 'カガワケン', '東かがわ市', 'ヒガシカガワシ', '大内', 'オオチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県東かがわ市三本松', '37', '37207', '7692601', '香川県', 'カガワケン', '東かがわ市', 'ヒガシカガワシ', '三本松', 'サンボンマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県東かがわ市川東', '37', '37207', '7692602', '香川県', 'カガワケン', '東かがわ市', 'ヒガシカガワシ', '川東', 'カワヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県東かがわ市横内', '37', '37207', '7692603', '香川県', 'カガワケン', '東かがわ市', 'ヒガシカガワシ', '横内', 'ヨコウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県東かがわ市西村', '37', '37207', '7692604', '香川県', 'カガワケン', '東かがわ市', 'ヒガシカガワシ', '西村', 'ニシムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県東かがわ市中筋', '37', '37207', '7692605', '香川県', 'カガワケン', '東かがわ市', 'ヒガシカガワシ', '中筋', 'ナカスジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県東かがわ市水主', '37', '37207', '7692606', '香川県', 'カガワケン', '東かがわ市', 'ヒガシカガワシ', '水主', 'ミズシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県東かがわ市', '37', '37207', '7692700', '香川県', 'カガワケン', '東かがわ市', 'ヒガシカガワシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('95908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県東かがわ市湊', '37', '37207', '7692701', '香川県', 'カガワケン', '東かがわ市', 'ヒガシカガワシ', '湊', 'ミナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県東かがわ市松原', '37', '37207', '7692702', '香川県', 'カガワケン', '東かがわ市', 'ヒガシカガワシ', '松原', 'マツバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県東かがわ市伊座', '37', '37207', '7692703', '香川県', 'カガワケン', '東かがわ市', 'ヒガシカガワシ', '伊座', 'イザ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県東かがわ市帰来', '37', '37207', '7692704', '香川県', 'カガワケン', '東かがわ市', 'ヒガシカガワシ', '帰来', 'キライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県東かがわ市白鳥', '37', '37207', '7692705', '香川県', 'カガワケン', '東かがわ市', 'ヒガシカガワシ', '白鳥', 'シロトリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県東かがわ市東山', '37', '37207', '7692711', '香川県', 'カガワケン', '東かがわ市', 'ヒガシカガワシ', '東山', 'ヒガシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県東かがわ市西山', '37', '37207', '7692712', '香川県', 'カガワケン', '東かがわ市', 'ヒガシカガワシ', '西山', 'ニシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県東かがわ市与田山', '37', '37207', '7692713', '香川県', 'カガワケン', '東かがわ市', 'ヒガシカガワシ', '与田山', 'ヨダヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県東かがわ市入野山', '37', '37207', '7692714', '香川県', 'カガワケン', '東かがわ市', 'ヒガシカガワシ', '入野山', 'ニュウノヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県東かがわ市五名', '37', '37207', '7692715', '香川県', 'カガワケン', '東かがわ市', 'ヒガシカガワシ', '五名', 'ゴミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県東かがわ市引田', '37', '37207', '7692901', '香川県', 'カガワケン', '東かがわ市', 'ヒガシカガワシ', '引田', 'ヒケタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県東かがわ市馬宿', '37', '37207', '7692902', '香川県', 'カガワケン', '東かがわ市', 'ヒガシカガワシ', '馬宿', 'ウマヤド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県東かがわ市南野', '37', '37207', '7692903', '香川県', 'カガワケン', '東かがわ市', 'ヒガシカガワシ', '南野', 'ミナミノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県東かがわ市坂元', '37', '37207', '7692904', '香川県', 'カガワケン', '東かがわ市', 'ヒガシカガワシ', '坂元', 'サカモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県東かがわ市黒羽', '37', '37207', '7692905', '香川県', 'カガワケン', '東かがわ市', 'ヒガシカガワシ', '黒羽', 'クレハ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県東かがわ市川股', '37', '37207', '7692906', '香川県', 'カガワケン', '東かがわ市', 'ヒガシカガワシ', '川股', 'カワマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県東かがわ市吉田', '37', '37207', '7692907', '香川県', 'カガワケン', '東かがわ市', 'ヒガシカガワシ', '吉田', 'ヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '香川県東かがわ市小海', '37', '37207', '7692908', '香川県', 'カガワケン', '東かがわ市', 'ヒガシカガワシ', '小海', 'オウミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道留萌市', '01', '01212', '0770000', '北海道', 'ホッカイドウ', '留萌市', 'ルモイシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('95933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市', '36', '36201', '7700000', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('95934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市春日町', '36', '36201', '7700001', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '春日町', 'カスガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市春日', '36', '36201', '7700002', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '春日', 'カスガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市北田宮', '36', '36201', '7700003', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '北田宮', 'キタタミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市南田宮', '36', '36201', '7700004', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '南田宮', 'ミナミタミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市南矢三町', '36', '36201', '7700005', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '南矢三町', 'ミナミヤソチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市北矢三町', '36', '36201', '7700006', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '北矢三町', 'キタヤソチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道留萌市三泊町', '01', '01212', '0770001', '北海道', 'ホッカイドウ', '留萌市', 'ルモイシ', '三泊町', 'サンドマリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市北佐古一番町', '36', '36201', '7700011', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '北佐古一番町', 'キタサコイチバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市北佐古二番町', '36', '36201', '7700012', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '北佐古二番町', 'キタサコニバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道留萌市塩見町', '01', '01212', '0770002', '北海道', 'ホッカイドウ', '留萌市', 'ルモイシ', '塩見町', 'シオミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市佐古一番町', '36', '36201', '7700021', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '佐古一番町', 'サコ01バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市佐古二番町', '36', '36201', '7700022', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '佐古二番町', 'サコ02バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市佐古三番町', '36', '36201', '7700023', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '佐古三番町', 'サコ03バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市佐古四番町', '36', '36201', '7700024', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '佐古四番町', 'サコ04バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市佐古五番町', '36', '36201', '7700025', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '佐古五番町', 'サコ05バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市佐古六番町', '36', '36201', '7700026', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '佐古六番町', 'サコ06バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市佐古七番町', '36', '36201', '7700027', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '佐古七番町', 'サコ07バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市佐古八番町', '36', '36201', '7700028', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '佐古八番町', 'サコ08バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道留萌市春日町', '01', '01212', '0770003', '北海道', 'ホッカイドウ', '留萌市', 'ルモイシ', '春日町', 'カスガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市南佐古一番町', '36', '36201', '7700031', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '南佐古一番町', 'ミナミサコ01バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市南佐古二番町', '36', '36201', '7700032', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '南佐古二番町', 'ミナミサコ02バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市南佐古三番町', '36', '36201', '7700033', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '南佐古三番町', 'ミナミサコ03バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市南佐古四番町', '36', '36201', '7700034', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '南佐古四番町', 'ミナミサコ04バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市南佐古五番町', '36', '36201', '7700035', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '南佐古五番町', 'ミナミサコ05バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市南佐古六番町', '36', '36201', '7700036', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '南佐古六番町', 'ミナミサコ06バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市南佐古七番町', '36', '36201', '7700037', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '南佐古七番町', 'ミナミサコ07バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市南佐古八番町', '36', '36201', '7700038', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '南佐古八番町', 'ミナミサコ08バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市佐古山町', '36', '36201', '7700039', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '佐古山町', 'サコヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道留萌市元町', '01', '01212', '0770004', '北海道', 'ホッカイドウ', '留萌市', 'ルモイシ', '元町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市蔵本元町', '36', '36201', '7700041', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '蔵本元町', 'クラモトモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市蔵本町', '36', '36201', '7700042', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '蔵本町', 'クラモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市南蔵本町', '36', '36201', '7700043', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '南蔵本町', 'ミナミクラモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市庄町', '36', '36201', '7700044', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '庄町', 'ショウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市南庄町', '36', '36201', '7700045', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '南庄町', 'ミナミショウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市鮎喰町', '36', '36201', '7700046', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '鮎喰町', 'アクイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市名東町', '36', '36201', '7700047', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '名東町', 'ミョウドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市加茂名町', '36', '36201', '7700048', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '加茂名町', 'カモナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道留萌市船場町', '01', '01212', '0770005', '北海道', 'ホッカイドウ', '留萌市', 'ルモイシ', '船場町', 'フナバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市北島田町', '36', '36201', '7700051', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '北島田町', 'キタシマダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市中島田町', '36', '36201', '7700052', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '中島田町', 'ナカシマダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市南島田町', '36', '36201', '7700053', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '南島田町', 'ミナミシマダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道留萌市末広町', '01', '01212', '0770006', '北海道', 'ホッカイドウ', '留萌市', 'ルモイシ', '末広町', 'スエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市不動北町', '36', '36201', '7700061', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '不動北町', 'フドウキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市不動東町', '36', '36201', '7700062', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '不動東町', 'フドウヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市不動本町', '36', '36201', '7700063', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '不動本町', 'フドウホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市不動西町', '36', '36201', '7700064', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '不動西町', 'フドウニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道留萌市栄町', '01', '01212', '0770007', '北海道', 'ホッカイドウ', '留萌市', 'ルモイシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道留萌市東雲町', '01', '01212', '0770011', '北海道', 'ホッカイドウ', '留萌市', 'ルモイシ', '東雲町', 'シノノメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道留萌市大和田', '01', '01212', '0770012', '北海道', 'ホッカイドウ', '留萌市', 'ルモイシ', '大和田', 'オオワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道留萌市潮静', '01', '01212', '0770013', '北海道', 'ホッカイドウ', '留萌市', 'ルモイシ', '潮静', 'チョウセイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道留萌市留萌原野', '01', '01212', '0770013', '北海道', 'ホッカイドウ', '留萌市', 'ルモイシ', '留萌原野', 'ルモイゲンヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道留萌市南町', '01', '01212', '0770014', '北海道', 'ホッカイドウ', '留萌市', 'ルモイシ', '南町', 'ミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道留萌市緑ケ丘町', '01', '01212', '0770015', '北海道', 'ホッカイドウ', '留萌市', 'ルモイシ', '緑ケ丘町', 'ミドリガオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道留萌市元川町', '01', '01212', '0770016', '北海道', 'ホッカイドウ', '留萌市', 'ルモイシ', '元川町', 'モトカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道留萌市高砂町', '01', '01212', '0770021', '北海道', 'ホッカイドウ', '留萌市', 'ルモイシ', '高砂町', 'タカサゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道留萌市堀川町', '01', '01212', '0770022', '北海道', 'ホッカイドウ', '留萌市', 'ルモイシ', '堀川町', 'ホリカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道留萌市五十嵐町', '01', '01212', '0770023', '北海道', 'ホッカイドウ', '留萌市', 'ルモイシ', '五十嵐町', 'イガラシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道留萌市千鳥町', '01', '01212', '0770024', '北海道', 'ホッカイドウ', '留萌市', 'ルモイシ', '千鳥町', 'チドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道留萌市野本町', '01', '01212', '0770025', '北海道', 'ホッカイドウ', '留萌市', 'ルモイシ', '野本町', 'ノモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道留萌市泉町', '01', '01212', '0770026', '北海道', 'ホッカイドウ', '留萌市', 'ルモイシ', '泉町', 'イズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道留萌市住之江町', '01', '01212', '0770027', '北海道', 'ホッカイドウ', '留萌市', 'ルモイシ', '住之江町', 'スミノエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道留萌市花園町', '01', '01212', '0770028', '北海道', 'ホッカイドウ', '留萌市', 'ルモイシ', '花園町', 'ハナゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道留萌市幸町', '01', '01212', '0770031', '北海道', 'ホッカイドウ', '留萌市', 'ルモイシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道留萌市宮園町', '01', '01212', '0770032', '北海道', 'ホッカイドウ', '留萌市', 'ルモイシ', '宮園町', 'ミヤゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道留萌市見晴町', '01', '01212', '0770033', '北海道', 'ホッカイドウ', '留萌市', 'ルモイシ', '見晴町', 'ミハラシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('95999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道留萌市平和台', '01', '01212', '0770034', '北海道', 'ホッカイドウ', '留萌市', 'ルモイシ', '平和台', 'ヘイワダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道留萌市礼受町', '01', '01212', '0770035', '北海道', 'ホッカイドウ', '留萌市', 'ルモイシ', '礼受町', 'レウケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道留萌市浜中町', '01', '01212', '0770036', '北海道', 'ホッカイドウ', '留萌市', 'ルモイシ', '浜中町', 'ハマナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道留萌市沖見町', '01', '01212', '0770037', '北海道', 'ホッカイドウ', '留萌市', 'ルモイシ', '沖見町', 'オキミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道留萌市寿町', '01', '01212', '0770038', '北海道', 'ホッカイドウ', '留萌市', 'ルモイシ', '寿町', 'コトブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道留萌市明元町', '01', '01212', '0770041', '北海道', 'ホッカイドウ', '留萌市', 'ルモイシ', '明元町', 'アケモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道留萌市開運町', '01', '01212', '0770042', '北海道', 'ホッカイドウ', '留萌市', 'ルモイシ', '開運町', 'カイウンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道留萌市旭町', '01', '01212', '0770043', '北海道', 'ホッカイドウ', '留萌市', 'ルモイシ', '旭町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道留萌市錦町', '01', '01212', '0770044', '北海道', 'ホッカイドウ', '留萌市', 'ルモイシ', '錦町', 'ニシキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道留萌市本町', '01', '01212', '0770045', '北海道', 'ホッカイドウ', '留萌市', 'ルモイシ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道留萌市港町', '01', '01212', '0770046', '北海道', 'ホッカイドウ', '留萌市', 'ルモイシ', '港町', 'ミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道留萌市瀬越町', '01', '01212', '0770047', '北海道', 'ホッカイドウ', '留萌市', 'ルモイシ', '瀬越町', 'セゴシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道留萌市大町', '01', '01212', '0770048', '北海道', 'ホッカイドウ', '留萌市', 'ルモイシ', '大町', 'オオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市上助任町', '36', '36201', '7700801', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '上助任町', 'カミスケトウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市吉野本町', '36', '36201', '7700802', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '吉野本町', 'ヨシノホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市上吉野町', '36', '36201', '7700803', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '上吉野町', 'カミヨシノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市中吉野町', '36', '36201', '7700804', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '中吉野町', 'ナカヨシノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市下助任町', '36', '36201', '7700805', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '下助任町', 'シモスケトウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市北前川町', '36', '36201', '7700806', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '北前川町', 'キタマエガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市中前川町', '36', '36201', '7700807', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '中前川町', 'ナカマエガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市南前川町', '36', '36201', '7700808', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '南前川町', 'ミナミマエガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市東吉野町', '36', '36201', '7700811', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '東吉野町', 'ヒガシヨシノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市北常三島町', '36', '36201', '7700812', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '北常三島町', 'キタジョウサンジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市中常三島町', '36', '36201', '7700813', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '中常三島町', 'ナカジョウサンジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市南常三島町', '36', '36201', '7700814', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '南常三島町', 'ミナミジョウサンジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市助任橋', '36', '36201', '7700815', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '助任橋', 'スケトウバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市助任本町', '36', '36201', '7700816', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '助任本町', 'スケトウホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市北出来島町', '36', '36201', '7700821', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '北出来島町', 'キタデキジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市東出来島町', '36', '36201', '7700822', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '東出来島町', 'ヒガシデキジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市出来島本町', '36', '36201', '7700823', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '出来島本町', 'デキジマホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市南出来島町', '36', '36201', '7700824', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '南出来島町', 'ミナミデキジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市寺島本町西', '36', '36201', '7700831', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '寺島本町西', 'テラシマホンチョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市寺島本町東', '36', '36201', '7700832', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '寺島本町東', 'テラシマホンチョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市一番町', '36', '36201', '7700833', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '一番町', 'イチバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市元町', '36', '36201', '7700834', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '元町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市藍場町', '36', '36201', '7700835', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '藍場町', 'アイバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市八百屋町', '36', '36201', '7700841', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '八百屋町', 'ヤオヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市通町', '36', '36201', '7700842', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '通町', 'トオリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市両国本町', '36', '36201', '7700843', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '両国本町', 'リョウゴクホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市中通町', '36', '36201', '7700844', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '中通町', 'ナカトオリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市新内町', '36', '36201', '7700845', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '新内町', 'シンウチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市南内町', '36', '36201', '7700846', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '南内町', 'ミナミウチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市幸町', '36', '36201', '7700847', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市徳島町城内', '36', '36201', '7700851', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '徳島町城内', 'トクシマチョウジョウナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市徳島町', '36', '36201', '7700852', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '徳島町', 'トクシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市中徳島町', '36', '36201', '7700853', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '中徳島町', 'ナカトクシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市徳島本町', '36', '36201', '7700854', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '徳島本町', 'トクシマホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市新蔵町', '36', '36201', '7700855', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '新蔵町', 'シンクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市中洲町', '36', '36201', '7700856', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '中洲町', 'ナカズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市住吉', '36', '36201', '7700861', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '住吉', 'スミヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市城東町', '36', '36201', '7700862', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '城東町', 'ジョウトウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市安宅', '36', '36201', '7700863', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '安宅', 'アタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市大和町', '36', '36201', '7700864', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '大和町', 'ヤマトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市南末広町', '36', '36201', '7700865', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '南末広町', 'ミナミスエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市末広', '36', '36201', '7700866', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '末広', 'スエヒロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市新南福島', '36', '36201', '7700867', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '新南福島', 'シンミナミフクシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市福島', '36', '36201', '7700868', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '福島', 'フクシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市金沢', '36', '36201', '7700871', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '金沢', 'カナザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市北沖洲', '36', '36201', '7700872', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '北沖洲', 'キタオキノス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市東沖洲', '36', '36201', '7700873', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '東沖洲', 'ヒガシオキノス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市南沖洲', '36', '36201', '7700874', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '南沖洲', 'ミナミオキノス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市西船場町', '36', '36201', '7700901', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '西船場町', 'ニシセンバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市西新町', '36', '36201', '7700902', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '西新町', 'ニシシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市西大工町', '36', '36201', '7700903', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '西大工町', 'ニシダイクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市新町橋', '36', '36201', '7700904', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '新町橋', 'シンマチバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市東大工町', '36', '36201', '7700905', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '東大工町', 'ヒガシダイクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市東山手町', '36', '36201', '7700906', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '東山手町', 'ヒガシヤマテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市西山手町', '36', '36201', '7700907', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '西山手町', 'ニシヤマテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市眉山町', '36', '36201', '7700908', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '眉山町', 'ビザンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市寺町', '36', '36201', '7700909', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '寺町', 'テラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市東船場町', '36', '36201', '7700911', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '東船場町', 'ヒガシセンバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市東新町', '36', '36201', '7700912', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '東新町', 'ヒガシシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市南新町', '36', '36201', '7700913', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '南新町', 'ミナミシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市籠屋町', '36', '36201', '7700914', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '籠屋町', 'カゴヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市富田町', '36', '36201', '7700915', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '富田町', 'トミダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市銀座', '36', '36201', '7700916', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '銀座', 'ギンザ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市両国橋', '36', '36201', '7700917', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '両国橋', 'リョウゴクバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市紺屋町', '36', '36201', '7700918', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '紺屋町', 'コンヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市栄町', '36', '36201', '7700921', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市鷹匠町', '36', '36201', '7700922', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '鷹匠町', 'タカジョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市大道', '36', '36201', '7700923', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '大道', 'オオミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市幟町', '36', '36201', '7700924', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '幟町', 'ノボリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市弓町', '36', '36201', '7700925', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '弓町', 'ユミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市伊賀町', '36', '36201', '7700926', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '伊賀町', 'イガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市勢見町', '36', '36201', '7700927', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '勢見町', 'セイミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市二軒屋町', '36', '36201', '7700928', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '二軒屋町', 'ニケンヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市西富田町', '36', '36201', '7700929', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '西富田町', 'ニシトミダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市富田浜', '36', '36201', '7700931', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '富田浜', 'トミダハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市仲之町', '36', '36201', '7700932', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '仲之町', 'ナカノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市南仲之町', '36', '36201', '7700933', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '南仲之町', 'ミナミナカノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市秋田町', '36', '36201', '7700934', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '秋田町', 'アキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市伊月町', '36', '36201', '7700935', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '伊月町', 'イツキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市中央通', '36', '36201', '7700936', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '中央通', 'チュウオウドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市富田橋', '36', '36201', '7700937', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '富田橋', 'トミダバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市明神町', '36', '36201', '7700938', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '明神町', 'ミョウジンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市かちどき橋', '36', '36201', '7700939', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', 'かちどき橋', 'カチドキバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市万代町', '36', '36201', '7700941', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '万代町', 'バンダイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市昭和町', '36', '36201', '7700942', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '昭和町', 'ショウワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市中昭和町', '36', '36201', '7700943', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '中昭和町', 'ナカショウワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市南昭和町', '36', '36201', '7700944', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '南昭和町', 'ミナミショウワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道増毛郡増毛町阿分', '01', '01481', '0770131', '北海道', 'ホッカイドウ', '増毛郡増毛町', 'マシケグンマシケチョウ', '阿分', 'アフン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道増毛郡増毛町舎熊', '01', '01481', '0770132', '北海道', 'ホッカイドウ', '増毛郡増毛町', 'マシケグンマシケチョウ', '舎熊', 'シャクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道増毛郡増毛町信砂', '01', '01481', '0770133', '北海道', 'ホッカイドウ', '増毛郡増毛町', 'マシケグンマシケチョウ', '信砂', 'ノブシャ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道増毛郡増毛町御料', '01', '01481', '0770134', '北海道', 'ホッカイドウ', '増毛郡増毛町', 'マシケグンマシケチョウ', '御料', 'ゴリョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道増毛郡増毛町', '01', '01481', '0770200', '北海道', 'ホッカイドウ', '増毛郡増毛町', 'マシケグンマシケチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('96104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道増毛郡増毛町永寿町', '01', '01481', '0770201', '北海道', 'ホッカイドウ', '増毛郡増毛町', 'マシケグンマシケチョウ', '永寿町', 'エイジュチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道増毛郡増毛町野塚町', '01', '01481', '0770202', '北海道', 'ホッカイドウ', '増毛郡増毛町', 'マシケグンマシケチョウ', '野塚町', 'ノヅカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道増毛郡増毛町稲葉海岸町', '01', '01481', '0770203', '北海道', 'ホッカイドウ', '増毛郡増毛町', 'マシケグンマシケチョウ', '稲葉海岸町', 'イナバカイガンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道増毛郡増毛町稲葉町', '01', '01481', '0770204', '北海道', 'ホッカイドウ', '増毛郡増毛町', 'マシケグンマシケチョウ', '稲葉町', 'イナバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道増毛郡増毛町弁天町', '01', '01481', '0770205', '北海道', 'ホッカイドウ', '増毛郡増毛町', 'マシケグンマシケチョウ', '弁天町', 'ベンテンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道増毛郡増毛町中歌', '01', '01481', '0770206', '北海道', 'ホッカイドウ', '増毛郡増毛町', 'マシケグンマシケチョウ', '中歌', 'ナカウタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道増毛郡増毛町箸別', '01', '01481', '0770207', '北海道', 'ホッカイドウ', '増毛郡増毛町', 'マシケグンマシケチョウ', '箸別', 'ハシベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道増毛郡増毛町湯の沢', '01', '01481', '0770208', '北海道', 'ホッカイドウ', '増毛郡増毛町', 'マシケグンマシケチョウ', '湯の沢', 'ユノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道増毛郡増毛町舎熊', '01', '01481', '0770209', '北海道', 'ホッカイドウ', '増毛郡増毛町', 'マシケグンマシケチョウ', '舎熊', 'シャクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道増毛郡増毛町暑寒海岸町', '01', '01481', '0770211', '北海道', 'ホッカイドウ', '増毛郡増毛町', 'マシケグンマシケチョウ', '暑寒海岸町', 'ショカンカイガンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道増毛郡増毛町七源町', '01', '01481', '0770212', '北海道', 'ホッカイドウ', '増毛郡増毛町', 'マシケグンマシケチョウ', '七源町', 'シチゲンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道増毛郡増毛町畠中北町', '01', '01481', '0770213', '北海道', 'ホッカイドウ', '増毛郡増毛町', 'マシケグンマシケチョウ', '畠中北町', 'ハタナカキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道増毛郡増毛町畠中町', '01', '01481', '0770214', '北海道', 'ホッカイドウ', '増毛郡増毛町', 'マシケグンマシケチョウ', '畠中町', 'ハタナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道増毛郡増毛町暑寒町', '01', '01481', '0770215', '北海道', 'ホッカイドウ', '増毛郡増毛町', 'マシケグンマシケチョウ', '暑寒町', 'ショカンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道増毛郡増毛町暑寒沢', '01', '01481', '0770216', '北海道', 'ホッカイドウ', '増毛郡増毛町', 'マシケグンマシケチョウ', '暑寒沢', 'ショカンザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道増毛郡増毛町別苅', '01', '01481', '0770217', '北海道', 'ホッカイドウ', '増毛郡増毛町', 'マシケグンマシケチョウ', '別苅', 'ベツカリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道増毛郡増毛町栄町', '01', '01481', '0770218', '北海道', 'ホッカイドウ', '増毛郡増毛町', 'マシケグンマシケチョウ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道増毛郡増毛町港町', '01', '01481', '0770221', '北海道', 'ホッカイドウ', '増毛郡増毛町', 'マシケグンマシケチョウ', '港町', 'ミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道増毛郡増毛町見晴町', '01', '01481', '0770222', '北海道', 'ホッカイドウ', '増毛郡増毛町', 'マシケグンマシケチョウ', '見晴町', 'ミハラシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道増毛郡増毛町南永寿町', '01', '01481', '0770223', '北海道', 'ホッカイドウ', '増毛郡増毛町', 'マシケグンマシケチョウ', '南永寿町', 'ミナミエイジュチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道増毛郡増毛町南畠中町', '01', '01481', '0770224', '北海道', 'ホッカイドウ', '増毛郡増毛町', 'マシケグンマシケチョウ', '南畠中町', 'ミナミハタナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道増毛郡増毛町南暑寒町', '01', '01481', '0770225', '北海道', 'ホッカイドウ', '増毛郡増毛町', 'マシケグンマシケチョウ', '南暑寒町', 'ミナミショカンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道増毛郡増毛町雄冬', '01', '01481', '0770341', '北海道', 'ホッカイドウ', '増毛郡増毛町', 'マシケグンマシケチョウ', '雄冬', 'オフユ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道増毛郡増毛町岩老', '01', '01481', '0770344', '北海道', 'ホッカイドウ', '増毛郡増毛町', 'マシケグンマシケチョウ', '岩老', 'イワオイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道増毛郡増毛町岩尾', '01', '01481', '0770345', '北海道', 'ホッカイドウ', '増毛郡増毛町', 'マシケグンマシケチョウ', '岩尾', 'イワオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道石狩市浜益区雄冬', '01', '01235', '0770351', '北海道', 'ホッカイドウ', '石狩市', 'イシカリシ', '浜益区雄冬', 'ハママスクオフユ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道留萌郡小平町川上', '01', '01482', '0770461', '北海道', 'ホッカイドウ', '留萌郡小平町', 'ルモイグンオビラチョウ', '川上', 'カワカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道留萌郡小平町滝下', '01', '01482', '0770462', '北海道', 'ホッカイドウ', '留萌郡小平町', 'ルモイグンオビラチョウ', '滝下', 'タキシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道留萌郡小平町達布', '01', '01482', '0770463', '北海道', 'ホッカイドウ', '留萌郡小平町', 'ルモイグンオビラチョウ', '達布', 'タップ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道留萌郡小平町住吉', '01', '01482', '0770464', '北海道', 'ホッカイドウ', '留萌郡小平町', 'ルモイグンオビラチョウ', '住吉', 'スミヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道留萌郡小平町寧楽', '01', '01482', '0770465', '北海道', 'ホッカイドウ', '留萌郡小平町', 'ルモイグンオビラチョウ', '寧楽', 'ネイラク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道留萌郡小平町平和2区', '01', '01482', '0770466', '北海道', 'ホッカイドウ', '留萌郡小平町', 'ルモイグンオビラチョウ', '平和', 'ヘイワ', null, null, '2区', '02ク');
INSERT INTO `ms_addresses` VALUES ('96141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市津田海岸町', '36', '36201', '7708001', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '津田海岸町', 'ツダカイガンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市津田町', '36', '36201', '7708002', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '津田町', 'ツダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市津田本町', '36', '36201', '7708003', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '津田本町', 'ツダホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市津田西町', '36', '36201', '7708004', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '津田西町', 'ツダニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市津田浜之町', '36', '36201', '7708005', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '津田浜之町', 'ツダハマノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市新浜町', '36', '36201', '7708006', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '新浜町', 'シンハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市新浜本町', '36', '36201', '7708007', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '新浜本町', 'シンハマホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市西新浜町', '36', '36201', '7708008', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '西新浜町', 'ニシシンハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市論田町', '36', '36201', '7708011', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '論田町', 'ロンデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市大原町', '36', '36201', '7708012', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '大原町', 'オオバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市雑賀町', '36', '36201', '7708021', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '雑賀町', 'サイカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市大松町', '36', '36201', '7708022', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '大松町', 'オオマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市勝占町', '36', '36201', '7708023', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '勝占町', 'カツラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市西須賀町', '36', '36201', '7708024', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '西須賀町', 'ニシズカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市三軒屋町', '36', '36201', '7708025', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '三軒屋町', 'サンゲンヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市大谷町', '36', '36201', '7708031', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '大谷町', 'オオタニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市北山町', '36', '36201', '7708032', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '北山町', 'キタヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市方上町', '36', '36201', '7708033', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '方上町', 'カタノカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市上八万町', '36', '36201', '7708040', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '上八万町', 'カミハチマンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市上八万町西山しらさぎ台', '36', '36201', '7708041', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '上八万町西山', 'カミハチマンチョウニシヤマ', null, null, 'しらさぎ台', 'シラサギダイ');
INSERT INTO `ms_addresses` VALUES ('96161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市沖浜町', '36', '36201', '7708051', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '沖浜町', 'オキノハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市沖浜', '36', '36201', '7708052', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '沖浜', 'オキノハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市沖浜東', '36', '36201', '7708053', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '沖浜東', 'オキノハマヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市山城西', '36', '36201', '7708054', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '山城西', 'ヤマシロニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市山城町', '36', '36201', '7708055', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '山城町', 'ヤマシロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市問屋町', '36', '36201', '7708056', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '問屋町', 'トイヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市西二軒屋町', '36', '36201', '7708061', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '西二軒屋町', 'ニシニケンヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市南二軒屋町', '36', '36201', '7708063', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '南二軒屋町', 'ミナミニケンヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市城南町', '36', '36201', '7708064', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '城南町', 'ジョウナンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市八万町', '36', '36201', '7708070', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '八万町', 'ハチマンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市八万町中津山', '36', '36201', '7708071', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '八万町', 'ハチマンチョウ', null, null, '中津山', 'ナカツヤマ');
INSERT INTO `ms_addresses` VALUES ('96172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市八万町中津浦', '36', '36201', '7708072', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '八万町', 'ハチマンチョウ', null, null, '中津浦', 'ナカツウラ');
INSERT INTO `ms_addresses` VALUES ('96173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市八万町上福万', '36', '36201', '7708073', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '八万町', 'ハチマンチョウ', null, null, '上福万', 'カミフクマン');
INSERT INTO `ms_addresses` VALUES ('96174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市八万町下福万', '36', '36201', '7708074', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '八万町', 'ハチマンチョウ', null, null, '下福万', 'シモフクマン');
INSERT INTO `ms_addresses` VALUES ('96175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市八万町千鳥', '36', '36201', '7708075', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '八万町', 'ハチマンチョウ', null, null, '千鳥', 'チドリ');
INSERT INTO `ms_addresses` VALUES ('96176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市八万町内浜', '36', '36201', '7708076', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '八万町', 'ハチマンチョウ', null, null, '内浜', 'ウチハマ');
INSERT INTO `ms_addresses` VALUES ('96177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市八万町夷山', '36', '36201', '7708077', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '八万町', 'ハチマンチョウ', null, null, '夷山', 'エビスヤマ');
INSERT INTO `ms_addresses` VALUES ('96178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市八万町橋本', '36', '36201', '7708078', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '八万町', 'ハチマンチョウ', null, null, '橋本', 'ハシモト');
INSERT INTO `ms_addresses` VALUES ('96179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市八万町大坪', '36', '36201', '7708079', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '八万町', 'ハチマンチョウ', null, null, '大坪', 'オオツボ');
INSERT INTO `ms_addresses` VALUES ('96180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市八万町弐丈', '36', '36201', '7708081', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '八万町', 'ハチマンチョウ', null, null, '弐丈', 'ニジョウ');
INSERT INTO `ms_addresses` VALUES ('96181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市八万町川南', '36', '36201', '7708082', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '八万町', 'ハチマンチョウ', null, null, '川南', 'カワミナミ');
INSERT INTO `ms_addresses` VALUES ('96182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市八万町法花', '36', '36201', '7708083', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '八万町', 'ハチマンチョウ', null, null, '法花', 'ホッケ');
INSERT INTO `ms_addresses` VALUES ('96183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市八万町法花谷', '36', '36201', '7708084', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '八万町', 'ハチマンチョウ', null, null, '法花谷', 'ホッケダニ');
INSERT INTO `ms_addresses` VALUES ('96246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市川内町旭野', '36', '36201', '7710101', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '川内町', 'カワウチチョウ', null, null, '旭野', 'アサヒノ');
INSERT INTO `ms_addresses` VALUES ('96247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市川内町小松北', '36', '36201', '7710102', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '川内町', 'カワウチチョウ', null, null, '小松北', 'コマツキタ');
INSERT INTO `ms_addresses` VALUES ('96248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市川内町小松東', '36', '36201', '7710103', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '川内町', 'カワウチチョウ', null, null, '小松東', 'コマツヒガシ');
INSERT INTO `ms_addresses` VALUES ('96249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市川内町小松西', '36', '36201', '7710104', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '川内町', 'カワウチチョウ', null, null, '小松西', 'コマツニシ');
INSERT INTO `ms_addresses` VALUES ('96250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市川内町下別宮西', '36', '36201', '7710105', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '川内町', 'カワウチチョウ', null, null, '下別宮西', 'シモベツクニシ');
INSERT INTO `ms_addresses` VALUES ('96251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市川内町下別宮東', '36', '36201', '7710106', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '川内町', 'カワウチチョウ', null, null, '下別宮東', 'シモベツクヒガシ');
INSERT INTO `ms_addresses` VALUES ('96252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市川内町富久', '36', '36201', '7710111', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '川内町', 'カワウチチョウ', null, null, '富久', 'トミヒサ');
INSERT INTO `ms_addresses` VALUES ('96253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市川内町富吉', '36', '36201', '7710112', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '川内町', 'カワウチチョウ', null, null, '富吉', 'トミヨシ');
INSERT INTO `ms_addresses` VALUES ('96254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市川内町松岡', '36', '36201', '7710113', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '川内町', 'カワウチチョウ', null, null, '松岡', 'マツオカ');
INSERT INTO `ms_addresses` VALUES ('96255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市川内町宮島本浦', '36', '36201', '7710114', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '川内町', 'カワウチチョウ', null, null, '宮島本浦', 'ミヤジマホンウラ');
INSERT INTO `ms_addresses` VALUES ('96256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市川内町宮島浜', '36', '36201', '7710115', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '川内町', 'カワウチチョウ', null, null, '宮島浜', 'ミヤジマハマ');
INSERT INTO `ms_addresses` VALUES ('96257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市川内町宮島錦野', '36', '36201', '7710116', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '川内町', 'カワウチチョウ', null, null, '宮島錦野', 'ミヤジマニシキノ');
INSERT INTO `ms_addresses` VALUES ('96258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市川内町鶴島', '36', '36201', '7710117', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '川内町', 'カワウチチョウ', null, null, '鶴島', 'ツルシマ');
INSERT INTO `ms_addresses` VALUES ('96259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市川内町鈴江東', '36', '36201', '7710121', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '川内町', 'カワウチチョウ', null, null, '鈴江東', 'スズエヒガシ');
INSERT INTO `ms_addresses` VALUES ('96260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市川内町鈴江西', '36', '36201', '7710122', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '川内町', 'カワウチチョウ', null, null, '鈴江西', 'スズエニシ');
INSERT INTO `ms_addresses` VALUES ('96261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市川内町鈴江北', '36', '36201', '7710123', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '川内町', 'カワウチチョウ', null, null, '鈴江北', 'スズエキタ');
INSERT INTO `ms_addresses` VALUES ('96262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市川内町鈴江南', '36', '36201', '7710124', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '川内町', 'カワウチチョウ', null, null, '鈴江南', 'スズエミナミ');
INSERT INTO `ms_addresses` VALUES ('96263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市川内町金岡', '36', '36201', '7710125', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '川内町', 'カワウチチョウ', null, null, '金岡', 'カナオカ');
INSERT INTO `ms_addresses` VALUES ('96264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市川内町上別宮東', '36', '36201', '7710126', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '川内町', 'カワウチチョウ', null, null, '上別宮東', 'カミベツクヒガシ');
INSERT INTO `ms_addresses` VALUES ('96265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市川内町上別宮南', '36', '36201', '7710127', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '川内町', 'カワウチチョウ', null, null, '上別宮南', 'カミベツクミナミ');
INSERT INTO `ms_addresses` VALUES ('96266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市川内町上別宮北', '36', '36201', '7710128', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '川内町', 'カワウチチョウ', null, null, '上別宮北', 'カミベツクキタ');
INSERT INTO `ms_addresses` VALUES ('96267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市川内町北原', '36', '36201', '7710129', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '川内町', 'カワウチチョウ', null, null, '北原', 'キタハラ');
INSERT INTO `ms_addresses` VALUES ('96268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市川内町加賀須野', '36', '36201', '7710130', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '川内町', 'カワウチチョウ', null, null, '加賀須野', 'カガスノ');
INSERT INTO `ms_addresses` VALUES ('96269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市川内町大松', '36', '36201', '7710131', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '川内町', 'カワウチチョウ', null, null, '大松', 'オオマツ');
INSERT INTO `ms_addresses` VALUES ('96270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市川内町平石夷野', '36', '36201', '7710132', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '川内町', 'カワウチチョウ', null, null, '平石夷野', 'ヒライシエビスノ');
INSERT INTO `ms_addresses` VALUES ('96271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市川内町平石夷野番外', '36', '36201', '7710133', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '川内町', 'カワウチチョウ', null, null, '平石夷野番外', 'ヒライシエビスノバンガイ');
INSERT INTO `ms_addresses` VALUES ('96272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市川内町平石住吉', '36', '36201', '7710134', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '川内町', 'カワウチチョウ', null, null, '平石住吉', 'ヒライシスミヨシ');
INSERT INTO `ms_addresses` VALUES ('96273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市川内町平石若松', '36', '36201', '7710135', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '川内町', 'カワウチチョウ', null, null, '平石若松', 'ヒライシワカマツ');
INSERT INTO `ms_addresses` VALUES ('96274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市川内町平石古田', '36', '36201', '7710136', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '川内町', 'カワウチチョウ', null, null, '平石古田', 'ヒライシコデン');
INSERT INTO `ms_addresses` VALUES ('96275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市川内町平石若宮', '36', '36201', '7710137', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '川内町', 'カワウチチョウ', null, null, '平石若宮', 'ヒライシワカミヤ');
INSERT INTO `ms_addresses` VALUES ('96276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市川内町平石流通団地', '36', '36201', '7710138', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '川内町', 'カワウチチョウ', null, null, '平石流通団地', 'ヒライシリュウツウダンチ');
INSERT INTO `ms_addresses` VALUES ('96277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市川内町米津', '36', '36201', '7710139', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '川内町', 'カワウチチョウ', null, null, '米津', 'ヨネヅ');
INSERT INTO `ms_addresses` VALUES ('96278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市川内町竹須賀', '36', '36201', '7710141', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '川内町', 'カワウチチョウ', null, null, '竹須賀', 'タケズカ');
INSERT INTO `ms_addresses` VALUES ('96279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市川内町沖島', '36', '36201', '7710142', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '川内町', 'カワウチチョウ', null, null, '沖島', 'オキノシマ');
INSERT INTO `ms_addresses` VALUES ('96280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市川内町中島', '36', '36201', '7710143', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '川内町', 'カワウチチョウ', null, null, '中島', 'ナカシマ');
INSERT INTO `ms_addresses` VALUES ('96281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市川内町榎瀬', '36', '36201', '7710144', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '川内町', 'カワウチチョウ', null, null, '榎瀬', 'エノキセ');
INSERT INTO `ms_addresses` VALUES ('96294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡松茂町', '36', '36401', '7710200', '徳島県', 'トクシマケン', '板野郡松茂町', 'イタノグンマツシゲチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('96295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡北島町', '36', '36402', '7710200', '徳島県', 'トクシマケン', '板野郡北島町', 'イタノグンキタジマチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('96296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡北島町北村', '36', '36402', '7710201', '徳島県', 'トクシマケン', '板野郡北島町', 'イタノグンキタジマチョウ', '北村', 'キタムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡北島町太郎八須', '36', '36402', '7710202', '徳島県', 'トクシマケン', '板野郡北島町', 'イタノグンキタジマチョウ', '太郎八須', 'タロウハチズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡北島町中村', '36', '36402', '7710203', '徳島県', 'トクシマケン', '板野郡北島町', 'イタノグンキタジマチョウ', '中村', 'ナカムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡北島町鯛浜', '36', '36402', '7710204', '徳島県', 'トクシマケン', '板野郡北島町', 'イタノグンキタジマチョウ', '鯛浜', 'タイノハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡北島町江尻', '36', '36402', '7710205', '徳島県', 'トクシマケン', '板野郡北島町', 'イタノグンキタジマチョウ', '江尻', 'エジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡北島町高房', '36', '36402', '7710206', '徳島県', 'トクシマケン', '板野郡北島町', 'イタノグンキタジマチョウ', '高房', 'タカボウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡北島町新喜来', '36', '36402', '7710207', '徳島県', 'トクシマケン', '板野郡北島町', 'イタノグンキタジマチョウ', '新喜来', 'シンキライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡松茂町長岸', '36', '36401', '7710211', '徳島県', 'トクシマケン', '板野郡松茂町', 'イタノグンマツシゲチョウ', '長岸', 'ナガギシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡松茂町中喜来', '36', '36401', '7710212', '徳島県', 'トクシマケン', '板野郡松茂町', 'イタノグンマツシゲチョウ', '中喜来', 'ナカギライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡松茂町豊久', '36', '36401', '7710213', '徳島県', 'トクシマケン', '板野郡松茂町', 'イタノグンマツシゲチョウ', '豊久', 'トヨヒサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡松茂町満穂', '36', '36401', '7710214', '徳島県', 'トクシマケン', '板野郡松茂町', 'イタノグンマツシゲチョウ', '満穂', 'ミツホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡松茂町豊岡', '36', '36401', '7710215', '徳島県', 'トクシマケン', '板野郡松茂町', 'イタノグンマツシゲチョウ', '豊岡', 'トヨオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡松茂町長原', '36', '36401', '7710216', '徳島県', 'トクシマケン', '板野郡松茂町', 'イタノグンマツシゲチョウ', '長原', 'ナガハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡松茂町豊中', '36', '36401', '7710217', '徳島県', 'トクシマケン', '板野郡松茂町', 'イタノグンマツシゲチョウ', '豊中', 'トヨナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡松茂町住吉', '36', '36401', '7710218', '徳島県', 'トクシマケン', '板野郡松茂町', 'イタノグンマツシゲチョウ', '住吉', 'スミヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡松茂町笹木野', '36', '36401', '7710219', '徳島県', 'トクシマケン', '板野郡松茂町', 'イタノグンマツシゲチョウ', '笹木野', 'ササギノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡松茂町広島', '36', '36401', '7710220', '徳島県', 'トクシマケン', '板野郡松茂町', 'イタノグンマツシゲチョウ', '広島', 'ヒロシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県鳴門市瀬戸町明神', '36', '36202', '7710360', '徳島県', 'トクシマケン', '鳴門市', 'ナルトシ', '瀬戸町明神', 'セトチョウアキノカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県鳴門市瀬戸町堂浦', '36', '36202', '7710361', '徳島県', 'トクシマケン', '鳴門市', 'ナルトシ', '瀬戸町堂浦', 'セトチョウドウノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県鳴門市瀬戸町北泊小海', '36', '36202', '7710362', '徳島県', 'トクシマケン', '鳴門市', 'ナルトシ', '瀬戸町北泊', 'セトチョウキタドマリ', null, null, '小海', 'オオミ');
INSERT INTO `ms_addresses` VALUES ('96326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県鳴門市瀬戸町湊谷', '36', '36202', '7710363', '徳島県', 'トクシマケン', '鳴門市', 'ナルトシ', '瀬戸町湊谷', 'セトチョウミナトダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県鳴門市瀬戸町北泊', '36', '36202', '7710364', '徳島県', 'トクシマケン', '鳴門市', 'ナルトシ', '瀬戸町北泊', 'セトチョウキタドマリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県鳴門市瀬戸町小島田', '36', '36202', '7710365', '徳島県', 'トクシマケン', '鳴門市', 'ナルトシ', '瀬戸町小島田', 'セトチョウコシマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県鳴門市瀬戸町中島田', '36', '36202', '7710366', '徳島県', 'トクシマケン', '鳴門市', 'ナルトシ', '瀬戸町中島田', 'セトチョウナカシマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県鳴門市瀬戸町大島田', '36', '36202', '7710367', '徳島県', 'トクシマケン', '鳴門市', 'ナルトシ', '瀬戸町大島田', 'セトチョウオオシマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県鳴門市瀬戸町室', '36', '36202', '7710368', '徳島県', 'トクシマケン', '鳴門市', 'ナルトシ', '瀬戸町室', 'セトチョウムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県鳴門市瀬戸町撫佐', '36', '36202', '7710369', '徳島県', 'トクシマケン', '鳴門市', 'ナルトシ', '瀬戸町撫佐', 'セトチョウムサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県鳴門市北灘町櫛木', '36', '36202', '7710371', '徳島県', 'トクシマケン', '鳴門市', 'ナルトシ', '北灘町櫛木', 'キタナダチョウクシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県鳴門市北灘町粟田', '36', '36202', '7710372', '徳島県', 'トクシマケン', '鳴門市', 'ナルトシ', '北灘町粟田', 'キタナダチョウアワタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県鳴門市北灘町大浦', '36', '36202', '7710373', '徳島県', 'トクシマケン', '鳴門市', 'ナルトシ', '北灘町大浦', 'キタナダチョウオオウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県鳴門市北灘町宿毛谷', '36', '36202', '7710374', '徳島県', 'トクシマケン', '鳴門市', 'ナルトシ', '北灘町宿毛谷', 'キタナダチョウシュクモダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県鳴門市北灘町鳥ケ丸', '36', '36202', '7710375', '徳島県', 'トクシマケン', '鳴門市', 'ナルトシ', '北灘町鳥ケ丸', 'キタナダチョウトリガマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県鳴門市北灘町折野', '36', '36202', '7710376', '徳島県', 'トクシマケン', '鳴門市', 'ナルトシ', '北灘町折野', 'キタナダチョウオリノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県鳴門市北灘町大須', '36', '36202', '7710377', '徳島県', 'トクシマケン', '鳴門市', 'ナルトシ', '北灘町大須', 'キタナダチョウオオズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県鳴門市北灘町碁浦', '36', '36202', '7710378', '徳島県', 'トクシマケン', '鳴門市', 'ナルトシ', '北灘町碁浦', 'キタナダチョウゴノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市応神町古川', '36', '36201', '7711151', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '応神町古川', 'オウジンチョウフルカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市応神町中原', '36', '36201', '7711152', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '応神町中原', 'オウジンチョウナカハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市応神町吉成', '36', '36201', '7711153', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '応神町吉成', 'オウジンチョウヨシナリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市応神町東貞方', '36', '36201', '7711154', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '応神町東貞方', 'オウジンチョウヒガシサダカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市応神町西貞方', '36', '36201', '7711155', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '応神町西貞方', 'オウジンチョウニシサダカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市応神町応神産業団地', '36', '36201', '7711156', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '応神町応神産業団地', 'オウジンチョウオウジンサンギョウダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡藍住町', '36', '36403', '7711200', '徳島県', 'トクシマケン', '板野郡藍住町', 'イタノグンアイズミチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('96350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡藍住町奥野', '36', '36403', '7711201', '徳島県', 'トクシマケン', '板野郡藍住町', 'イタノグンアイズミチョウ', '奥野', 'オクノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡藍住町奥野猪熊', '36', '36403', '7711202', '徳島県', 'トクシマケン', '板野郡藍住町', 'イタノグンアイズミチョウ', '奥野', 'オクノ', null, null, '猪熊', 'イノクマ');
INSERT INTO `ms_addresses` VALUES ('96352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡藍住町奥野東中須', '36', '36403', '7711202', '徳島県', 'トクシマケン', '板野郡藍住町', 'イタノグンアイズミチョウ', '奥野', 'オクノ', null, null, '東中須', 'ヒガシナカズ');
INSERT INTO `ms_addresses` VALUES ('96353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡藍住町奥野前川', '36', '36403', '7711202', '徳島県', 'トクシマケン', '板野郡藍住町', 'イタノグンアイズミチョウ', '奥野', 'オクノ', null, null, '前川', 'マエガワ');
INSERT INTO `ms_addresses` VALUES ('96354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡藍住町奥野和田', '36', '36403', '7711202', '徳島県', 'トクシマケン', '板野郡藍住町', 'イタノグンアイズミチョウ', '奥野', 'オクノ', null, null, '和田', 'ワダ');
INSERT INTO `ms_addresses` VALUES ('96355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡藍住町奥野矢上前', '36', '36403', '7711203', '徳島県', 'トクシマケン', '板野郡藍住町', 'イタノグンアイズミチョウ', '奥野', 'オクノ', null, null, '矢上前', 'ヤカミマエ');
INSERT INTO `ms_addresses` VALUES ('96356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡藍住町徳命', '36', '36403', '7711210', '徳島県', 'トクシマケン', '板野郡藍住町', 'イタノグンアイズミチョウ', '徳命', 'トクメイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡藍住町徳命元村', '36', '36403', '7711211', '徳島県', 'トクシマケン', '板野郡藍住町', 'イタノグンアイズミチョウ', '徳命', 'トクメイ', null, null, '元村', 'モトムラ');
INSERT INTO `ms_addresses` VALUES ('96358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡藍住町徳命元村東', '36', '36403', '7711211', '徳島県', 'トクシマケン', '板野郡藍住町', 'イタノグンアイズミチョウ', '徳命', 'トクメイ', null, null, '元村東', 'モトムラヒガシ');
INSERT INTO `ms_addresses` VALUES ('96359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡藍住町徳命前須西', '36', '36403', '7711212', '徳島県', 'トクシマケン', '板野郡藍住町', 'イタノグンアイズミチョウ', '徳命', 'トクメイ', null, null, '前須西', 'マエズニシ');
INSERT INTO `ms_addresses` VALUES ('96360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡藍住町徳命前須東', '36', '36403', '7711212', '徳島県', 'トクシマケン', '板野郡藍住町', 'イタノグンアイズミチョウ', '徳命', 'トクメイ', null, null, '前須東', 'マエズヒガシ');
INSERT INTO `ms_addresses` VALUES ('96361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡藍住町東中富', '36', '36403', '7711220', '徳島県', 'トクシマケン', '板野郡藍住町', 'イタノグンアイズミチョウ', '東中富', 'ヒガシナカトミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡藍住町東中富長江傍示', '36', '36403', '7711221', '徳島県', 'トクシマケン', '板野郡藍住町', 'イタノグンアイズミチョウ', '東中富', 'ヒガシナカトミ', null, null, '長江傍示', 'ナガエホウジ');
INSERT INTO `ms_addresses` VALUES ('96363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡藍住町東中富北傍示', '36', '36403', '7711222', '徳島県', 'トクシマケン', '板野郡藍住町', 'イタノグンアイズミチョウ', '東中富', 'ヒガシナカトミ', null, null, '北傍示', 'キタホウジ');
INSERT INTO `ms_addresses` VALUES ('96364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡藍住町東中富敷地傍示', '36', '36403', '7711223', '徳島県', 'トクシマケン', '板野郡藍住町', 'イタノグンアイズミチョウ', '東中富', 'ヒガシナカトミ', null, null, '敷地傍示', 'シキジホウジ');
INSERT INTO `ms_addresses` VALUES ('96365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡藍住町東中富天王傍示', '36', '36403', '7711223', '徳島県', 'トクシマケン', '板野郡藍住町', 'イタノグンアイズミチョウ', '東中富', 'ヒガシナカトミ', null, null, '天王傍示', 'テンノウホウジ');
INSERT INTO `ms_addresses` VALUES ('96366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡藍住町東中富大塚傍示', '36', '36403', '7711224', '徳島県', 'トクシマケン', '板野郡藍住町', 'イタノグンアイズミチョウ', '東中富', 'ヒガシナカトミ', null, null, '大塚傍示', 'オオツカホウジ');
INSERT INTO `ms_addresses` VALUES ('96367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡藍住町東中富慶長', '36', '36403', '7711224', '徳島県', 'トクシマケン', '板野郡藍住町', 'イタノグンアイズミチョウ', '東中富', 'ヒガシナカトミ', null, null, '慶長', 'ケイチョウ');
INSERT INTO `ms_addresses` VALUES ('96368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡藍住町東中富貞享', '36', '36403', '7711224', '徳島県', 'トクシマケン', '板野郡藍住町', 'イタノグンアイズミチョウ', '東中富', 'ヒガシナカトミ', null, null, '貞享', 'テイキョウ');
INSERT INTO `ms_addresses` VALUES ('96369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡藍住町東中富西安永', '36', '36403', '7711224', '徳島県', 'トクシマケン', '板野郡藍住町', 'イタノグンアイズミチョウ', '東中富', 'ヒガシナカトミ', null, null, '西安永', 'ニシアンエイ');
INSERT INTO `ms_addresses` VALUES ('96370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡藍住町東中富東安永', '36', '36403', '7711224', '徳島県', 'トクシマケン', '板野郡藍住町', 'イタノグンアイズミチョウ', '東中富', 'ヒガシナカトミ', null, null, '東安永', 'ヒガシアンエイ');
INSERT INTO `ms_addresses` VALUES ('96371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡藍住町東中富鑓場傍示', '36', '36403', '7711224', '徳島県', 'トクシマケン', '板野郡藍住町', 'イタノグンアイズミチョウ', '東中富', 'ヒガシナカトミ', null, null, '鑓場傍示', 'ヤリバホウジ');
INSERT INTO `ms_addresses` VALUES ('96372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡藍住町富吉', '36', '36403', '7711230', '徳島県', 'トクシマケン', '板野郡藍住町', 'イタノグンアイズミチョウ', '富吉', 'トミヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡藍住町富吉須崎', '36', '36403', '7711231', '徳島県', 'トクシマケン', '板野郡藍住町', 'イタノグンアイズミチョウ', '富吉', 'トミヨシ', null, null, '須崎', 'スザキ');
INSERT INTO `ms_addresses` VALUES ('96374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡藍住町富吉富吉', '36', '36403', '7711231', '徳島県', 'トクシマケン', '板野郡藍住町', 'イタノグンアイズミチョウ', '富吉', 'トミヨシ', null, null, '富吉', 'トミヨシ');
INSERT INTO `ms_addresses` VALUES ('96375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡藍住町富吉豊吉', '36', '36403', '7711231', '徳島県', 'トクシマケン', '板野郡藍住町', 'イタノグンアイズミチョウ', '富吉', 'トミヨシ', null, null, '豊吉', 'トヨヨシ');
INSERT INTO `ms_addresses` VALUES ('96376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡藍住町富吉地神', '36', '36403', '7711232', '徳島県', 'トクシマケン', '板野郡藍住町', 'イタノグンアイズミチョウ', '富吉', 'トミヨシ', null, null, '地神', 'ジガミ');
INSERT INTO `ms_addresses` VALUES ('96377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡藍住町富吉穂実', '36', '36403', '7711232', '徳島県', 'トクシマケン', '板野郡藍住町', 'イタノグンアイズミチョウ', '富吉', 'トミヨシ', null, null, '穂実', 'ホウミ');
INSERT INTO `ms_addresses` VALUES ('96378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡藍住町乙瀬', '36', '36403', '7711240', '徳島県', 'トクシマケン', '板野郡藍住町', 'イタノグンアイズミチョウ', '乙瀬', 'オトゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡藍住町矢上', '36', '36403', '7711250', '徳島県', 'トクシマケン', '板野郡藍住町', 'イタノグンアイズミチョウ', '矢上', 'ヤカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡藍住町矢上西', '36', '36403', '7711251', '徳島県', 'トクシマケン', '板野郡藍住町', 'イタノグンアイズミチョウ', '矢上', 'ヤカミ', null, null, '西', 'ニシ');
INSERT INTO `ms_addresses` VALUES ('96381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡藍住町矢上原', '36', '36403', '7711251', '徳島県', 'トクシマケン', '板野郡藍住町', 'イタノグンアイズミチョウ', '矢上', 'ヤカミ', null, null, '原', 'ハラ');
INSERT INTO `ms_addresses` VALUES ('96382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡藍住町矢上春日', '36', '36403', '7711252', '徳島県', 'トクシマケン', '板野郡藍住町', 'イタノグンアイズミチョウ', '矢上', 'ヤカミ', null, null, '春日', 'カスガ');
INSERT INTO `ms_addresses` VALUES ('96383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡藍住町矢上北分', '36', '36403', '7711252', '徳島県', 'トクシマケン', '板野郡藍住町', 'イタノグンアイズミチョウ', '矢上', 'ヤカミ', null, null, '北分', 'キタブン');
INSERT INTO `ms_addresses` VALUES ('96384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡藍住町矢上江ノ口', '36', '36403', '7711253', '徳島県', 'トクシマケン', '板野郡藍住町', 'イタノグンアイズミチョウ', '矢上', 'ヤカミ', null, null, '江ノ口', 'エノクチ');
INSERT INTO `ms_addresses` VALUES ('96385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡藍住町矢上安任', '36', '36403', '7711253', '徳島県', 'トクシマケン', '板野郡藍住町', 'イタノグンアイズミチョウ', '矢上', 'ヤカミ', null, null, '安任', 'ヤストウ');
INSERT INTO `ms_addresses` VALUES ('96386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡藍住町笠木', '36', '36403', '7711260', '徳島県', 'トクシマケン', '板野郡藍住町', 'イタノグンアイズミチョウ', '笠木', 'カサギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡藍住町笠木東野', '36', '36403', '7711261', '徳島県', 'トクシマケン', '板野郡藍住町', 'イタノグンアイズミチョウ', '笠木', 'カサギ', null, null, '東野', 'ヒガシノ');
INSERT INTO `ms_addresses` VALUES ('96388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡藍住町笠木中野', '36', '36403', '7711262', '徳島県', 'トクシマケン', '板野郡藍住町', 'イタノグンアイズミチョウ', '笠木', 'カサギ', null, null, '中野', 'ナカノ');
INSERT INTO `ms_addresses` VALUES ('96389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡藍住町笠木西野', '36', '36403', '7711262', '徳島県', 'トクシマケン', '板野郡藍住町', 'イタノグンアイズミチョウ', '笠木', 'カサギ', null, null, '西野', 'ニシノ');
INSERT INTO `ms_addresses` VALUES ('96390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡藍住町住吉', '36', '36403', '7711264', '徳島県', 'トクシマケン', '板野郡藍住町', 'イタノグンアイズミチョウ', '住吉', 'スミヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡藍住町住吉逆藤', '36', '36403', '7711265', '徳島県', 'トクシマケン', '板野郡藍住町', 'イタノグンアイズミチョウ', '住吉', 'スミヨシ', null, null, '逆藤', 'サカフジ');
INSERT INTO `ms_addresses` VALUES ('96392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡藍住町住吉神蔵', '36', '36403', '7711265', '徳島県', 'トクシマケン', '板野郡藍住町', 'イタノグンアイズミチョウ', '住吉', 'スミヨシ', null, null, '神蔵', 'ジンゾウ');
INSERT INTO `ms_addresses` VALUES ('96393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡藍住町住吉千鳥ケ浜', '36', '36403', '7711265', '徳島県', 'トクシマケン', '板野郡藍住町', 'イタノグンアイズミチョウ', '住吉', 'スミヨシ', null, null, '千鳥ケ浜', 'チドリガハマ');
INSERT INTO `ms_addresses` VALUES ('96394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡藍住町住吉藤ノ木', '36', '36403', '7711266', '徳島県', 'トクシマケン', '板野郡藍住町', 'イタノグンアイズミチョウ', '住吉', 'スミヨシ', null, null, '藤ノ木', 'フジノキ');
INSERT INTO `ms_addresses` VALUES ('96395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡藍住町住吉若宮', '36', '36403', '7711266', '徳島県', 'トクシマケン', '板野郡藍住町', 'イタノグンアイズミチョウ', '住吉', 'スミヨシ', null, null, '若宮', 'ワカミヤ');
INSERT INTO `ms_addresses` VALUES ('96396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡藍住町住吉乾', '36', '36403', '7711267', '徳島県', 'トクシマケン', '板野郡藍住町', 'イタノグンアイズミチョウ', '住吉', 'スミヨシ', null, null, '乾', 'イヌイ');
INSERT INTO `ms_addresses` VALUES ('96397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡藍住町住吉江端', '36', '36403', '7711267', '徳島県', 'トクシマケン', '板野郡藍住町', 'イタノグンアイズミチョウ', '住吉', 'スミヨシ', null, null, '江端', 'エバタ');
INSERT INTO `ms_addresses` VALUES ('96398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡藍住町勝瑞', '36', '36403', '7711270', '徳島県', 'トクシマケン', '板野郡藍住町', 'イタノグンアイズミチョウ', '勝瑞', 'ショウズイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡藍住町勝瑞幸島', '36', '36403', '7711271', '徳島県', 'トクシマケン', '板野郡藍住町', 'イタノグンアイズミチョウ', '勝瑞', 'ショウズイ', null, null, '幸島', 'コウジマ');
INSERT INTO `ms_addresses` VALUES ('96400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡藍住町勝瑞成長', '36', '36403', '7711272', '徳島県', 'トクシマケン', '板野郡藍住町', 'イタノグンアイズミチョウ', '勝瑞', 'ショウズイ', null, null, '成長', 'セイチョウ');
INSERT INTO `ms_addresses` VALUES ('96401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡藍住町勝瑞正喜地', '36', '36403', '7711273', '徳島県', 'トクシマケン', '板野郡藍住町', 'イタノグンアイズミチョウ', '勝瑞', 'ショウズイ', null, null, '正喜地', 'ショウキチ');
INSERT INTO `ms_addresses` VALUES ('96402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡藍住町勝瑞東勝地', '36', '36403', '7711273', '徳島県', 'トクシマケン', '板野郡藍住町', 'イタノグンアイズミチョウ', '勝瑞', 'ショウズイ', null, null, '東勝地', 'ヒガシカツチ');
INSERT INTO `ms_addresses` VALUES ('96409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡上板町', '36', '36405', '7711300', '徳島県', 'トクシマケン', '板野郡上板町', 'イタノグンカミイタチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('96410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡上板町鍛冶屋原', '36', '36405', '7711301', '徳島県', 'トクシマケン', '板野郡上板町', 'イタノグンカミイタチョウ', '鍛冶屋原', 'カジヤバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡上板町七條', '36', '36405', '7711302', '徳島県', 'トクシマケン', '板野郡上板町', 'イタノグンカミイタチョウ', '七條', 'シチジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡上板町泉谷', '36', '36405', '7711310', '徳島県', 'トクシマケン', '板野郡上板町', 'イタノグンカミイタチョウ', '泉谷', 'イズミダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡上板町引野', '36', '36405', '7711311', '徳島県', 'トクシマケン', '板野郡上板町', 'イタノグンカミイタチョウ', '引野', 'ヒキノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡上板町神宅', '36', '36405', '7711320', '徳島県', 'トクシマケン', '板野郡上板町', 'イタノグンカミイタチョウ', '神宅', 'カンヤケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡上板町西分', '36', '36405', '7711330', '徳島県', 'トクシマケン', '板野郡上板町', 'イタノグンカミイタチョウ', '西分', 'ニシブン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡上板町第十新田', '36', '36405', '7711341', '徳島県', 'トクシマケン', '板野郡上板町', 'イタノグンカミイタチョウ', '第十新田', 'ダイジュウシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡上板町佐藤塚', '36', '36405', '7711342', '徳島県', 'トクシマケン', '板野郡上板町', 'イタノグンカミイタチョウ', '佐藤塚', 'サトウヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡上板町椎本', '36', '36405', '7711343', '徳島県', 'トクシマケン', '板野郡上板町', 'イタノグンカミイタチョウ', '椎本', 'シイノモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡上板町下六條', '36', '36405', '7711344', '徳島県', 'トクシマケン', '板野郡上板町', 'イタノグンカミイタチョウ', '下六條', 'シモロクジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡上板町上六條', '36', '36405', '7711345', '徳島県', 'トクシマケン', '板野郡上板町', 'イタノグンカミイタチョウ', '上六條', 'カミロクジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡上板町高磯', '36', '36405', '7711346', '徳島県', 'トクシマケン', '板野郡上板町', 'イタノグンカミイタチョウ', '高磯', 'タカイソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡上板町高瀬', '36', '36405', '7711347', '徳島県', 'トクシマケン', '板野郡上板町', 'イタノグンカミイタチョウ', '高瀬', 'タカセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡上板町瀬部', '36', '36405', '7711350', '徳島県', 'トクシマケン', '板野郡上板町', 'イタノグンカミイタチョウ', '瀬部', 'セベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市吉野町柿原', '36', '36206', '7711401', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '吉野町柿原', 'ヨシノチョウカキハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市吉野町西条', '36', '36206', '7711402', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '吉野町西条', 'ヨシノチョウサイジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市吉野町五条', '36', '36206', '7711403', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '吉野町五条', 'ヨシノチョウゴジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市土成町秋月', '36', '36206', '7711501', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '土成町秋月', 'ドナリチョウアキヅキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市土成町水田', '36', '36206', '7711502', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '土成町水田', 'ドナリチョウミズタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市土成町浦池', '36', '36206', '7711503', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '土成町浦池', 'ドナリチョウウラノイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市土成町成当', '36', '36206', '7711504', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '土成町成当', 'ドナリチョウナリトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市土成町郡', '36', '36206', '7711505', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '土成町郡', 'ドナリチョウコオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市土成町土成', '36', '36206', '7711506', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '土成町土成', 'ドナリチョウドナリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市土成町吉田', '36', '36206', '7711507', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '土成町吉田', 'ドナリチョウヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市土成町宮川内', '36', '36206', '7711508', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '土成町宮川内', 'ドナリチョウミヤガワウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市土成町高尾', '36', '36206', '7711509', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '土成町高尾', 'ドナリチョウタカオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市市場町市場興崎', '36', '36206', '7711601', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '市場町市場', 'イチバチョウイチバ', null, null, '興崎', 'コウザキ');
INSERT INTO `ms_addresses` VALUES ('96443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市市場町市場上野段', '36', '36206', '7711602', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '市場町市場', 'イチバチョウイチバ', null, null, '上野段', 'ウエノダン');
INSERT INTO `ms_addresses` VALUES ('96444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市市場町市場岸ノ下', '36', '36206', '7711603', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '市場町市場', 'イチバチョウイチバ', null, null, '岸ノ下', 'キシノシタ');
INSERT INTO `ms_addresses` VALUES ('96445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市市場町市場町筋', '36', '36206', '7711604', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '市場町市場', 'イチバチョウイチバ', null, null, '町筋', 'マチスジ');
INSERT INTO `ms_addresses` VALUES ('96446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市市場町香美', '36', '36206', '7711610', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '市場町香美', 'イチバチョウカガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市市場町香美北香美', '36', '36206', '7711611', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '市場町香美', 'イチバチョウカガミ', null, null, '北香美', 'キタカガミ');
INSERT INTO `ms_addresses` VALUES ('96448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市市場町上喜来', '36', '36206', '7711612', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '市場町上喜来', 'イチバチョウカミギライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市市場町大俣', '36', '36206', '7711613', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '市場町大俣', 'イチバチョウオオマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市市場町犬墓', '36', '36206', '7711614', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '市場町犬墓', 'イチバチョウイヌノハカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市市場町大影', '36', '36206', '7711615', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '市場町大影', 'イチバチョウオオカゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市市場町日開谷', '36', '36206', '7711616', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '市場町日開谷', 'イチバチョウヒガイダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市市場町尾開', '36', '36206', '7711621', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '市場町尾開', 'イチバチョウオバリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市市場町興崎', '36', '36206', '7711622', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '市場町興崎', 'イチバチョウコウザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市市場町切幡', '36', '36206', '7711623', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '市場町切幡', 'イチバチョウキリハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市市場町山野上', '36', '36206', '7711624', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '市場町山野上', 'イチバチョウヤマノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市市場町八幡', '36', '36206', '7711625', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '市場町八幡', 'イチバチョウヤワタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市市場町伊月', '36', '36206', '7711626', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '市場町伊月', 'イチバチョウイツキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市市場町大野島', '36', '36206', '7711627', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '市場町大野島', 'イチバチョウオオノジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市', '36', '36206', '7711700', '徳島県', 'トクシマケン', '阿波市', 'アワシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('96462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町伊沢市', '36', '36206', '7711701', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町伊沢市', 'アワチョウイサワイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町王地', '36', '36206', '7711701', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町王地', 'アワチョウオウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町王地南', '36', '36206', '7711701', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町王地南', 'アワチョウオウジミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町大坪', '36', '36206', '7711701', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町大坪', 'アワチョウオオツボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町大原', '36', '36206', '7711701', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町大原', 'アワチョウオオハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町大道南', '36', '36206', '7711701', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町大道南', 'アワチョウオオミチミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町勝命', '36', '36206', '7711701', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町勝命', 'アワチョウカツミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町勝命北', '36', '36206', '7711701', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町勝命北', 'アワチョウカツミョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町庚申原', '36', '36206', '7711701', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町庚申原', 'アワチョウコウシンバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町下喜来', '36', '36206', '7711701', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町下喜来', 'アワチョウシモギライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町下喜来南', '36', '36206', '7711701', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町下喜来南', 'アワチョウシモギライミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町新開', '36', '36206', '7711701', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町新開', 'アワチョウシンバリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町清原', '36', '36206', '7711701', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町清原', 'アワチョウセイバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町谷島', '36', '36206', '7711701', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町谷島', 'アワチョウタニジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町谷島北', '36', '36206', '7711701', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町谷島北', 'アワチョウタニジマキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町西清原', '36', '36206', '7711701', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町西清原', 'アワチョウニシセイバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町平川原北', '36', '36206', '7711701', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町平川原北', 'アワチョウヘイガワラキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町平川原南', '36', '36206', '7711701', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町平川原南', 'アワチョウヘイガワラミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町南谷島', '36', '36206', '7711701', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町南谷島', 'アワチョウミナミタニジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町伊勢', '36', '36206', '7711702', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町伊勢', 'アワチョウイセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町井出口', '36', '36206', '7711702', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町井出口', 'アワチョウイデグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町稲荷', '36', '36206', '7711702', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町稲荷', 'アワチョウイナリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町大久保', '36', '36206', '7711702', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町大久保', 'アワチョウオオクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町柏谷左右', '36', '36206', '7711702', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町柏谷左右', 'アワチョウカシワダニサユウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町川添', '36', '36206', '7711702', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町川添', 'アワチョウカワゾエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町北ノ名', '36', '36206', '7711702', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町北ノ名', 'アワチョウキタノミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町山王', '36', '36206', '7711702', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町山王', 'アワチョウサンノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町四歩一', '36', '36206', '7711702', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町四歩一', 'アワチョウシブイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町下原', '36', '36206', '7711702', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町下原', 'アワチョウシモバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町大次郎', '36', '36206', '7711702', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町大次郎', 'アワチョウダイジロウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町谷口', '36', '36206', '7711702', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町谷口', 'アワチョウタニグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町寺サコ', '36', '36206', '7711702', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町寺サコ', 'アワチョウテラサコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町天西山', '36', '36206', '7711702', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町天西山', 'アワチョウテンサイザン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町西ノ岡', '36', '36206', '7711702', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町西ノ岡', 'アワチョウニシノオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町野神', '36', '36206', '7711702', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町野神', 'アワチョウノガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町久原', '36', '36206', '7711702', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町久原', 'アワチョウヒサハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町本町', '36', '36206', '7711702', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町本町', 'アワチョウホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町本安', '36', '36206', '7711702', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町本安', 'アワチョウホンヤス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町森沢', '36', '36206', '7711702', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町森沢', 'アワチョウモリサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町安政', '36', '36206', '7711702', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町安政', 'アワチョウヤスマサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町山尻', '36', '36206', '7711702', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町山尻', 'アワチョウヤマジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町早田', '36', '36206', '7711702', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町早田', 'アワチョウワサダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町伊沢田', '36', '36206', '7711703', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町伊沢田', 'アワチョウイサワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町大道北', '36', '36206', '7711703', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町大道北', 'アワチョウオオミチキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町岡地', '36', '36206', '7711703', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町岡地', 'アワチョウオカジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町北柴生', '36', '36206', '7711703', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町北柴生', 'アワチョウキタシボウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町北原', '36', '36206', '7711703', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町北原', 'アワチョウキタバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町真福寺', '36', '36206', '7711703', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町真福寺', 'アワチョウシンプクジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町綱懸', '36', '36206', '7711703', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町綱懸', 'アワチョウツナカケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町東条', '36', '36206', '7711703', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町東条', 'アワチョウトウジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町中原', '36', '36206', '7711703', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町中原', 'アワチョウナカハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町西柴生', '36', '36206', '7711703', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町西柴生', 'アワチョウニシシボウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町西原', '36', '36206', '7711703', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町西原', 'アワチョウニシバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町東柴生', '36', '36206', '7711703', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町東柴生', 'アワチョウヒガシシボウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町東原', '36', '36206', '7711703', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町東原', 'アワチョウヒガシバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町前島', '36', '36206', '7711703', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町前島', 'アワチョウマエジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町丸山', '36', '36206', '7711703', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町丸山', 'アワチョウマルヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町南柴生', '36', '36206', '7711703', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町南柴生', 'アワチョウミナミシボウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町伊沢谷東縁', '36', '36206', '7711704', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町伊沢谷東縁', 'アワチョウイサワダニヒガシベリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町糸下', '36', '36206', '7711704', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町糸下', 'アワチョウイトガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町芋場', '36', '36206', '7711704', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町芋場', 'アワチョウイモバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町梅ノ木原', '36', '36206', '7711704', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町梅ノ木原', 'アワチョウウメノキバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町梅ノ東', '36', '36206', '7711704', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町梅ノ東', 'アワチョウウメノヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町小倉', '36', '36206', '7711704', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町小倉', 'アワチョウオグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町亀底', '36', '36206', '7711704', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町亀底', 'アワチョウカメゾコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町北久保', '36', '36206', '7711704', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町北久保', 'アワチョウキタクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町北五味知', '36', '36206', '7711704', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町北五味知', 'アワチョウキタゴミジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町北正広', '36', '36206', '7711704', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町北正広', 'アワチョウキタマサヒロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町立割', '36', '36206', '7711704', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町立割', 'アワチョウタテワリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町西正広', '36', '36206', '7711704', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町西正広', 'アワチョウニシマサヒロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町八丁原', '36', '36206', '7711704', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町八丁原', 'アワチョウハッチョウバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町東正広', '36', '36206', '7711704', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町東正広', 'アワチョウヒガシマサヒロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町引地', '36', '36206', '7711704', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町引地', 'アワチョウヒキチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町広野', '36', '36206', '7711704', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町広野', 'アワチョウヒロノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町真重', '36', '36206', '7711704', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町真重', 'アワチョウマシゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町南五味知', '36', '36206', '7711704', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町南五味知', 'アワチョウミナミゴミジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町元町', '36', '36206', '7711704', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町元町', 'アワチョウモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町山ノ神', '36', '36206', '7711704', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町山ノ神', 'アワチョウヤマノカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町赤坂', '36', '36206', '7711705', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町赤坂', 'アワチョウアカサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町医王寺', '36', '36206', '7711705', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町医王寺', 'アワチョウイオウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町居屋敷', '36', '36206', '7711705', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町居屋敷', 'アワチョウイヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町梅川内', '36', '36206', '7711705', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町梅川内', 'アワチョウウメカワウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町王子川', '36', '36206', '7711705', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町王子川', 'アワチョウオウジガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町川久保', '36', '36206', '7711705', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町川久保', 'アワチョウカワクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町北整理', '36', '36206', '7711705', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町北整理', 'アワチョウキタセイリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町北山', '36', '36206', '7711705', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町北山', 'アワチョウキタヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町五明', '36', '36206', '7711705', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町五明', 'アワチョウゴミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町桜ノ岡', '36', '36206', '7711705', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町桜ノ岡', 'アワチョウサクラノオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町寒風', '36', '36206', '7711705', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町寒風', 'アワチョウサムカゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町十善地', '36', '36206', '7711705', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町十善地', 'アワチョウジュウゼンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町善地', '36', '36206', '7711705', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町善地', 'アワチョウゼンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町高垣', '36', '36206', '7711705', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町高垣', 'アワチョウタカガキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町栩ケ窪', '36', '36206', '7711705', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町栩ケ窪', 'アワチョウトチガクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町馬場', '36', '36206', '7711705', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町馬場', 'アワチョウババ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町日吉谷', '36', '36206', '7711705', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町日吉谷', 'アワチョウヒヨシダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町松川内', '36', '36206', '7711705', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町松川内', 'アワチョウマツカワウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町岩津', '36', '36206', '7711706', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町岩津', 'アワチョウイワヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町植桜', '36', '36206', '7711706', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町植桜', 'アワチョウウエザクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町乙岩津', '36', '36206', '7711706', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町乙岩津', 'アワチョウオツイワヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町北岡', '36', '36206', '7711706', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町北岡', 'アワチョウキタオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町北西谷', '36', '36206', '7711706', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町北西谷', 'アワチョウキタニシダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町三本柳', '36', '36206', '7711706', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町三本柳', 'アワチョウサンボンヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町中川原', '36', '36206', '7711706', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町中川原', 'アワチョウナカガワハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町中坪', '36', '36206', '7711706', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町中坪', 'アワチョウナカツボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町中長峰', '36', '36206', '7711706', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町中長峰', 'アワチョウナカナガミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町西島', '36', '36206', '7711706', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町西島', 'アワチョウニシジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町西整理', '36', '36206', '7711706', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町西整理', 'アワチョウニシセイリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町西長峰', '36', '36206', '7711706', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町西長峰', 'アワチョウニシナガミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町西林', '36', '36206', '7711706', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町西林', 'アワチョウニシバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町東川原', '36', '36206', '7711706', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町東川原', 'アワチョウヒガシカワハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町東島', '36', '36206', '7711706', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町東島', 'アワチョウヒガシジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町東整理', '36', '36206', '7711706', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町東整理', 'アワチョウヒガシセイリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町東長峰', '36', '36206', '7711706', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町東長峰', 'アワチョウヒガシナガミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町東村', '36', '36206', '7711706', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町東村', 'アワチョウヒガシムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町南川原', '36', '36206', '7711706', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町南川原', 'アワチョウミナミカワハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町南整理', '36', '36206', '7711706', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町南整理', 'アワチョウミナミセイリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市阿波町南西谷', '36', '36206', '7711706', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '阿波町南西谷', 'アワチョウミナミニシダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿波市市場町犬墓小竹', '36', '36206', '7711714', '徳島県', 'トクシマケン', '阿波市', 'アワシ', '市場町犬墓', 'イチバチョウイヌノハカ', null, null, '小竹', 'コタケ');
INSERT INTO `ms_addresses` VALUES ('96581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町入倉', '36', '36207', '7712101', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '入倉', 'イリクラ');
INSERT INTO `ms_addresses` VALUES ('96582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町大久保', '36', '36207', '7712101', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '大久保', 'オオクボ');
INSERT INTO `ms_addresses` VALUES ('96583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町切久保', '36', '36207', '7712101', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '切久保', 'キリクボ');
INSERT INTO `ms_addresses` VALUES ('96584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町正部', '36', '36207', '7712101', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '正部', 'ショウブ');
INSERT INTO `ms_addresses` VALUES ('96585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町丈寄', '36', '36207', '7712101', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '丈寄', 'ジョウヨリ');
INSERT INTO `ms_addresses` VALUES ('96586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町清田', '36', '36207', '7712101', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '清田', 'セイダ');
INSERT INTO `ms_addresses` VALUES ('96587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町家ノ前', '36', '36207', '7712102', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '家ノ前', 'イエノマエ');
INSERT INTO `ms_addresses` VALUES ('96588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町大池', '36', '36207', '7712102', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '大池', 'オオイケ');
INSERT INTO `ms_addresses` VALUES ('96589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町大上', '36', '36207', '7712102', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '大上', 'オオウエ');
INSERT INTO `ms_addresses` VALUES ('96590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町大北', '36', '36207', '7712102', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '大北', 'オオキタ');
INSERT INTO `ms_addresses` VALUES ('96591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町大佐古', '36', '36207', '7712102', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '大佐古', 'オオサコ');
INSERT INTO `ms_addresses` VALUES ('96592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町大前', '36', '36207', '7712102', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '大前', 'オオマエ');
INSERT INTO `ms_addresses` VALUES ('96593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町岡ノ内', '36', '36207', '7712102', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '岡ノ内', 'オカノウチ');
INSERT INTO `ms_addresses` VALUES ('96594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町押上', '36', '36207', '7712102', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '押上', 'オシアゲ');
INSERT INTO `ms_addresses` VALUES ('96595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町茅原', '36', '36207', '7712102', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '茅原', 'カヤバラ');
INSERT INTO `ms_addresses` VALUES ('96596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町川ノ上', '36', '36207', '7712102', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '川ノ上', 'カワノウエ');
INSERT INTO `ms_addresses` VALUES ('96597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町観音', '36', '36207', '7712102', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '観音', 'カンノン');
INSERT INTO `ms_addresses` VALUES ('96598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町栗林', '36', '36207', '7712102', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '栗林', 'クリバヤシ');
INSERT INTO `ms_addresses` VALUES ('96599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町黒砂', '36', '36207', '7712102', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '黒砂', 'クロスナ');
INSERT INTO `ms_addresses` VALUES ('96600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町狙ケ内', '36', '36207', '7712102', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '狙ケ内', 'サルガウチ');
INSERT INTO `ms_addresses` VALUES ('96601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町猿坂', '36', '36207', '7712102', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '猿坂', 'サルサカ');
INSERT INTO `ms_addresses` VALUES ('96602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町下白地', '36', '36207', '7712102', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '下白地', 'シモシロジ');
INSERT INTO `ms_addresses` VALUES ('96603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町白地', '36', '36207', '7712102', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '白地', 'シロジ');
INSERT INTO `ms_addresses` VALUES ('96604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町炭釜', '36', '36207', '7712102', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '炭釜', 'スミガマ');
INSERT INTO `ms_addresses` VALUES ('96605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町芹佐古', '36', '36207', '7712102', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '芹佐古', 'セリザコ');
INSERT INTO `ms_addresses` VALUES ('96606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町惣後', '36', '36207', '7712102', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '惣後', 'ソウゴ');
INSERT INTO `ms_addresses` VALUES ('96607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町惣田', '36', '36207', '7712102', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '惣田', 'ソウダ');
INSERT INTO `ms_addresses` VALUES ('96608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町外墓', '36', '36207', '7712102', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '外墓', 'ソトバカ');
INSERT INTO `ms_addresses` VALUES ('96609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町滝ノ上', '36', '36207', '7712102', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '滝ノ上', 'タキノウエ');
INSERT INTO `ms_addresses` VALUES ('96610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町立見山', '36', '36207', '7712102', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '立見山', 'タツミヤマ');
INSERT INTO `ms_addresses` VALUES ('96611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町田ノ岡', '36', '36207', '7712102', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '田ノ岡', 'タノオカ');
INSERT INTO `ms_addresses` VALUES ('96612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町狙坂', '36', '36207', '7712102', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '狙坂', 'タンザカ');
INSERT INTO `ms_addresses` VALUES ('96613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町中岡', '36', '36207', '7712102', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '中岡', 'ナカオカ');
INSERT INTO `ms_addresses` VALUES ('96614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町長地', '36', '36207', '7712102', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '長地', 'ナガジ');
INSERT INTO `ms_addresses` VALUES ('96615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町中野田ノ井', '36', '36207', '7712102', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '中野田ノ井', 'ナカノタノイ');
INSERT INTO `ms_addresses` VALUES ('96616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町中横尾', '36', '36207', '7712102', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '中横尾', 'ナカヨコオ');
INSERT INTO `ms_addresses` VALUES ('96617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町西浦', '36', '36207', '7712102', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '西浦', 'ニシウラ');
INSERT INTO `ms_addresses` VALUES ('96618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町西ノ谷', '36', '36207', '7712102', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '西ノ谷', 'ニシノタニ');
INSERT INTO `ms_addresses` VALUES ('96619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町野田ノ井', '36', '36207', '7712102', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '野田ノ井', 'ノタノイ');
INSERT INTO `ms_addresses` VALUES ('96620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町橋谷', '36', '36207', '7712102', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '橋谷', 'ハシダニ');
INSERT INTO `ms_addresses` VALUES ('96621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町場シ所', '36', '36207', '7712102', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '場シ所', 'バシトコ');
INSERT INTO `ms_addresses` VALUES ('96622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町東筋', '36', '36207', '7712102', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '東筋', 'ヒガシスジ');
INSERT INTO `ms_addresses` VALUES ('96623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町平尾', '36', '36207', '7712102', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '平尾', 'ヒラオ');
INSERT INTO `ms_addresses` VALUES ('96624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町平野', '36', '36207', '7712102', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '平野', 'ヒラノ');
INSERT INTO `ms_addresses` VALUES ('96625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町藤宇', '36', '36207', '7712102', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '藤宇', 'フジユウ');
INSERT INTO `ms_addresses` VALUES ('96626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町前坂', '36', '36207', '7712102', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '前坂', 'マエザカ');
INSERT INTO `ms_addresses` VALUES ('96627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町水ノ岡', '36', '36207', '7712102', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '水ノ岡', 'ミズノオカ');
INSERT INTO `ms_addresses` VALUES ('96628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町味噌ケ久保', '36', '36207', '7712102', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '味噌ケ久保', 'ミソガクボ');
INSERT INTO `ms_addresses` VALUES ('96629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町道ノ上', '36', '36207', '7712102', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '道ノ上', 'ミチノウエ');
INSERT INTO `ms_addresses` VALUES ('96630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町宮ノ岡', '36', '36207', '7712102', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '宮ノ岡', 'ミヤノオカ');
INSERT INTO `ms_addresses` VALUES ('96631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町南畠', '36', '36207', '7712102', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '南畠', 'ムナバタ');
INSERT INTO `ms_addresses` VALUES ('96632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町薬師ケ久保', '36', '36207', '7712102', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '薬師ケ久保', 'ヤクシガクボ');
INSERT INTO `ms_addresses` VALUES ('96633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町山西屋敷', '36', '36207', '7712102', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '山西屋敷', 'ヤマニシヤシキ');
INSERT INTO `ms_addresses` VALUES ('96634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町山橋谷', '36', '36207', '7712102', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '山橋谷', 'ヤマハシダニ');
INSERT INTO `ms_addresses` VALUES ('96635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町横尾', '36', '36207', '7712102', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '横尾', 'ヨコオ');
INSERT INTO `ms_addresses` VALUES ('96636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町一ノ宮', '36', '36207', '7712103', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '一ノ宮', 'イチノミヤ');
INSERT INTO `ms_addresses` VALUES ('96637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町後谷', '36', '36207', '7712103', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '後谷', 'ウシロダニ');
INSERT INTO `ms_addresses` VALUES ('96638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町倉尾', '36', '36207', '7712103', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '倉尾', 'クラオ');
INSERT INTO `ms_addresses` VALUES ('96639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町三頭山', '36', '36207', '7712103', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '三頭山', 'サントウザン');
INSERT INTO `ms_addresses` VALUES ('96640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町下後谷', '36', '36207', '7712103', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '下後谷', 'シモウシロダニ');
INSERT INTO `ms_addresses` VALUES ('96641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町高惣', '36', '36207', '7712103', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '高惣', 'タカソウ');
INSERT INTO `ms_addresses` VALUES ('96642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町谷尻', '36', '36207', '7712103', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '谷尻', 'タニジリ');
INSERT INTO `ms_addresses` VALUES ('96643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町露口', '36', '36207', '7712103', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '露口', 'ツユグチ');
INSERT INTO `ms_addresses` VALUES ('96644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町中沼田', '36', '36207', '7712103', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '中沼田', 'ナカヌマダ');
INSERT INTO `ms_addresses` VALUES ('96645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町中野', '36', '36207', '7712103', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '中野', 'ナカノ');
INSERT INTO `ms_addresses` VALUES ('96646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町夏弥喜', '36', '36207', '7712103', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '夏弥喜', 'ナツヤキ');
INSERT INTO `ms_addresses` VALUES ('96647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町ナロヲ', '36', '36207', '7712103', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, 'ナロヲ', 'ナロオ');
INSERT INTO `ms_addresses` VALUES ('96648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町西大久保', '36', '36207', '7712103', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '西大久保', 'ニシオオクボ');
INSERT INTO `ms_addresses` VALUES ('96649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町西沼田', '36', '36207', '7712103', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '西沼田', 'ニシヌマダ');
INSERT INTO `ms_addresses` VALUES ('96650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町沼田', '36', '36207', '7712103', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '沼田', 'ヌマダ');
INSERT INTO `ms_addresses` VALUES ('96651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町八ノ坪', '36', '36207', '7712103', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '八ノ坪', 'ハチノツボ');
INSERT INTO `ms_addresses` VALUES ('96652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町坊ケ谷', '36', '36207', '7712103', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '坊ケ谷', 'ボウガタニ');
INSERT INTO `ms_addresses` VALUES ('96653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町水久保', '36', '36207', '7712103', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '水久保', 'ミズクボ');
INSERT INTO `ms_addresses` VALUES ('96654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町宗ノ分', '36', '36207', '7712103', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '宗ノ分', 'ムネノブン');
INSERT INTO `ms_addresses` VALUES ('96655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町屋内', '36', '36207', '7712103', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '屋内', 'ヤナイ');
INSERT INTO `ms_addresses` VALUES ('96656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町鵜飼口', '36', '36207', '7712104', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '鵜飼口', 'ウガイグチ');
INSERT INTO `ms_addresses` VALUES ('96657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町岡', '36', '36207', '7712104', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '岡', 'オカ');
INSERT INTO `ms_addresses` VALUES ('96658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町小長谷', '36', '36207', '7712104', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '小長谷', 'オバセ');
INSERT INTO `ms_addresses` VALUES ('96659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町小長谷端', '36', '36207', '7712104', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '小長谷端', 'オバセバタ');
INSERT INTO `ms_addresses` VALUES ('96660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町笠仏', '36', '36207', '7712104', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '笠仏', 'カサボトケ');
INSERT INTO `ms_addresses` VALUES ('96661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町川縁', '36', '36207', '7712104', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '川縁', 'カワベリ');
INSERT INTO `ms_addresses` VALUES ('96662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町荒神', '36', '36207', '7712104', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '荒神', 'コウジン');
INSERT INTO `ms_addresses` VALUES ('96663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町助松', '36', '36207', '7712104', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '助松', 'スケマツ');
INSERT INTO `ms_addresses` VALUES ('96664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町高畑', '36', '36207', '7712104', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '高畑', 'タカバタケ');
INSERT INTO `ms_addresses` VALUES ('96665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町辰角', '36', '36207', '7712104', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '辰角', 'タツカク');
INSERT INTO `ms_addresses` VALUES ('96666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町谷頭', '36', '36207', '7712104', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '谷頭', 'タニガシラ');
INSERT INTO `ms_addresses` VALUES ('96667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町玉振前', '36', '36207', '7712104', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '玉振前', 'タマフリマエ');
INSERT INTO `ms_addresses` VALUES ('96668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町チゲジ', '36', '36207', '7712104', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, 'チゲジ', 'チゲジ');
INSERT INTO `ms_addresses` VALUES ('96669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町天神東', '36', '36207', '7712104', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '天神東', 'テンジンヒガシ');
INSERT INTO `ms_addresses` VALUES ('96670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町轟', '36', '36207', '7712104', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '轟', 'トドロキ');
INSERT INTO `ms_addresses` VALUES ('96671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町中黒', '36', '36207', '7712104', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '中黒', 'ナカグロ');
INSERT INTO `ms_addresses` VALUES ('96672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町中須', '36', '36207', '7712104', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '中須', 'ナカス');
INSERT INTO `ms_addresses` VALUES ('96673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町中道北', '36', '36207', '7712104', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '中道北', 'ナカミチキタ');
INSERT INTO `ms_addresses` VALUES ('96674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町中道南', '36', '36207', '7712104', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '中道南', 'ナカミチミナミ');
INSERT INTO `ms_addresses` VALUES ('96675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町ノツゴ', '36', '36207', '7712104', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, 'ノツゴ', 'ノツゴ');
INSERT INTO `ms_addresses` VALUES ('96676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町ノリコヘ', '36', '36207', '7712104', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, 'ノリコヘ', 'ノリコヘ');
INSERT INTO `ms_addresses` VALUES ('96677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町橋本', '36', '36207', '7712104', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '橋本', 'ハシノモト');
INSERT INTO `ms_addresses` VALUES ('96678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町東岸ノ下', '36', '36207', '7712104', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '東岸ノ下', 'ヒガシキシノシタ');
INSERT INTO `ms_addresses` VALUES ('96679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町東段', '36', '36207', '7712104', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '東段', 'ヒガシダン');
INSERT INTO `ms_addresses` VALUES ('96680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町東宗重', '36', '36207', '7712104', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '東宗重', 'ヒガシムネシゲ');
INSERT INTO `ms_addresses` VALUES ('96681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町坊僧', '36', '36207', '7712104', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '坊僧', 'ボウソウ');
INSERT INTO `ms_addresses` VALUES ('96682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町丸山', '36', '36207', '7712104', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '丸山', 'マルヤマ');
INSERT INTO `ms_addresses` VALUES ('96683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町南原', '36', '36207', '7712104', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '南原', 'ミナミハラ');
INSERT INTO `ms_addresses` VALUES ('96684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町明神原', '36', '36207', '7712104', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '明神原', 'ミョウジンバラ');
INSERT INTO `ms_addresses` VALUES ('96685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町宗重', '36', '36207', '7712104', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '宗重', 'ムネシゲ');
INSERT INTO `ms_addresses` VALUES ('96686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町薬師', '36', '36207', '7712104', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '薬師', 'ヤクシ');
INSERT INTO `ms_addresses` VALUES ('96687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町池ノ浦', '36', '36207', '7712105', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '池ノ浦', 'イケノウラ');
INSERT INTO `ms_addresses` VALUES ('96688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町銀杏木', '36', '36207', '7712105', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '銀杏木', 'イチョウギ');
INSERT INTO `ms_addresses` VALUES ('96689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町梅ケ久保', '36', '36207', '7712105', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '梅ケ久保', 'ウメガクボ');
INSERT INTO `ms_addresses` VALUES ('96690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町駅', '36', '36207', '7712105', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '駅', 'エキ');
INSERT INTO `ms_addresses` VALUES ('96691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町蛭子', '36', '36207', '7712105', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '蛭子', 'エビス');
INSERT INTO `ms_addresses` VALUES ('96692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町柿木', '36', '36207', '7712105', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '柿木', 'カキノキ');
INSERT INTO `ms_addresses` VALUES ('96693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町鍵掛', '36', '36207', '7712105', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '鍵掛', 'カンカケ');
INSERT INTO `ms_addresses` VALUES ('96694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町願勝寺', '36', '36207', '7712105', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '願勝寺', 'ガンショウジ');
INSERT INTO `ms_addresses` VALUES ('96695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町北土ケ久保', '36', '36207', '7712105', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '北土ケ久保', 'キタツチガクボ');
INSERT INTO `ms_addresses` VALUES ('96696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町喜入道', '36', '36207', '7712105', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '喜入道', 'キニュウドウ');
INSERT INTO `ms_addresses` VALUES ('96697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町滝宮', '36', '36207', '7712105', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '滝宮', 'タキノミヤ');
INSERT INTO `ms_addresses` VALUES ('96698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町土ケ久保', '36', '36207', '7712105', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '土ケ久保', 'ツチガクボ');
INSERT INTO `ms_addresses` VALUES ('96699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町西段', '36', '36207', '7712105', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '西段', 'ニシダン');
INSERT INTO `ms_addresses` VALUES ('96700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町宮西', '36', '36207', '7712105', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '宮西', 'ミヤニシ');
INSERT INTO `ms_addresses` VALUES ('96701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町宮東', '36', '36207', '7712105', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '宮東', 'ミヤヒガシ');
INSERT INTO `ms_addresses` VALUES ('96702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町宮南', '36', '36207', '7712105', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '宮南', 'ミヤミナミ');
INSERT INTO `ms_addresses` VALUES ('96703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町養泉', '36', '36207', '7712105', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '養泉', 'ヨウセン');
INSERT INTO `ms_addresses` VALUES ('96704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町荒川', '36', '36207', '7712106', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '荒川', 'アラカワ');
INSERT INTO `ms_addresses` VALUES ('96705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町井出縁', '36', '36207', '7712106', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '井出縁', 'イデベリ');
INSERT INTO `ms_addresses` VALUES ('96706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町井ノ神', '36', '36207', '7712106', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '井ノ神', 'イノカミ');
INSERT INTO `ms_addresses` VALUES ('96707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町大泉', '36', '36207', '7712106', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '大泉', 'オオイズミ');
INSERT INTO `ms_addresses` VALUES ('96708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町大宮西', '36', '36207', '7712106', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '大宮西', 'オオミヤニシ');
INSERT INTO `ms_addresses` VALUES ('96709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町上突出', '36', '36207', '7712106', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '上突出', 'カミツキダシ');
INSERT INTO `ms_addresses` VALUES ('96710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町岸ノ下', '36', '36207', '7712106', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '岸ノ下', 'キシノシタ');
INSERT INTO `ms_addresses` VALUES ('96711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町北東原', '36', '36207', '7712106', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '北東原', 'キタヒガシバラ');
INSERT INTO `ms_addresses` VALUES ('96712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町喜来市', '36', '36207', '7712106', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '喜来市', 'キライイチ');
INSERT INTO `ms_addresses` VALUES ('96713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町里平野', '36', '36207', '7712106', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '里平野', 'サトヒラノ');
INSERT INTO `ms_addresses` VALUES ('96714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町下突出', '36', '36207', '7712106', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '下突出', 'シモツキダシ');
INSERT INTO `ms_addresses` VALUES ('96715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町谷ヨリ西', '36', '36207', '7712106', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '谷ヨリ西', 'タニヨリニシ');
INSERT INTO `ms_addresses` VALUES ('96716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町乳ノ木', '36', '36207', '7712106', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '乳ノ木', 'チチノキ');
INSERT INTO `ms_addresses` VALUES ('96717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町寺ノ下', '36', '36207', '7712106', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '寺ノ下', 'テラノシタ');
INSERT INTO `ms_addresses` VALUES ('96718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町天神', '36', '36207', '7712106', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '天神', 'テンジン');
INSERT INTO `ms_addresses` VALUES ('96719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町天神北', '36', '36207', '7712106', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '天神北', 'テンジンキタ');
INSERT INTO `ms_addresses` VALUES ('96720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町中東原', '36', '36207', '7712106', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '中東原', 'ナカヒガシバラ');
INSERT INTO `ms_addresses` VALUES ('96721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町西荒川', '36', '36207', '7712106', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '西荒川', 'ニシアラカワ');
INSERT INTO `ms_addresses` VALUES ('96722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町沼田島', '36', '36207', '7712106', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '沼田島', 'ヌマダジマ');
INSERT INTO `ms_addresses` VALUES ('96723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町東荒川', '36', '36207', '7712106', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '東荒川', 'ヒガシアラカワ');
INSERT INTO `ms_addresses` VALUES ('96724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町南荒川', '36', '36207', '7712106', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '南荒川', 'ミナミアラカワ');
INSERT INTO `ms_addresses` VALUES ('96725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町南東原', '36', '36207', '7712106', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '南東原', 'ミナミヒガシバラ');
INSERT INTO `ms_addresses` VALUES ('96726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町妙見', '36', '36207', '7712106', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '妙見', 'ミョウケン');
INSERT INTO `ms_addresses` VALUES ('96727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町山嫁坂', '36', '36207', '7712106', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '山嫁坂', 'ヤマヨメザカ');
INSERT INTO `ms_addresses` VALUES ('96728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町雨下', '36', '36207', '7712107', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '雨下', 'アマゲ');
INSERT INTO `ms_addresses` VALUES ('96729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町上野', '36', '36207', '7712107', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '上野', 'ウエノ');
INSERT INTO `ms_addresses` VALUES ('96730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町小原', '36', '36207', '7712107', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '小原', 'コバラ');
INSERT INTO `ms_addresses` VALUES ('96731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町境目', '36', '36207', '7712107', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '境目', 'サカイメ');
INSERT INTO `ms_addresses` VALUES ('96732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町里西屋敷', '36', '36207', '7712107', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '里西屋敷', 'サトニシヤシキ');
INSERT INTO `ms_addresses` VALUES ('96733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町下ノ段', '36', '36207', '7712107', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '下ノ段', 'シモノダン');
INSERT INTO `ms_addresses` VALUES ('96734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町城', '36', '36207', '7712107', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '城', 'シロ');
INSERT INTO `ms_addresses` VALUES ('96735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町滝下', '36', '36207', '7712107', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '滝下', 'タキシタ');
INSERT INTO `ms_addresses` VALUES ('96736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町竹ノ内', '36', '36207', '7712107', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '竹ノ内', 'タケノウチ');
INSERT INTO `ms_addresses` VALUES ('96737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町田辺', '36', '36207', '7712107', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '田辺', 'タナベ');
INSERT INTO `ms_addresses` VALUES ('96738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町谷口', '36', '36207', '7712107', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '谷口', 'タニグチ');
INSERT INTO `ms_addresses` VALUES ('96739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町栂尾', '36', '36207', '7712107', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '栂尾', 'ツガオ');
INSERT INTO `ms_addresses` VALUES ('96740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町突落', '36', '36207', '7712107', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '突落', 'ツキオトシ');
INSERT INTO `ms_addresses` VALUES ('96741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町中尾', '36', '36207', '7712107', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '中尾', 'ナカオ');
INSERT INTO `ms_addresses` VALUES ('96742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町中耕地', '36', '36207', '7712107', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '中耕地', 'ナカゴウチ');
INSERT INTO `ms_addresses` VALUES ('96743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町中筋', '36', '36207', '7712107', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '中筋', 'ナカスジ');
INSERT INTO `ms_addresses` VALUES ('96744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町中通', '36', '36207', '7712107', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '中通', 'ナカドオリ');
INSERT INTO `ms_addresses` VALUES ('96745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町中西', '36', '36207', '7712107', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '中西', 'ナカニシ');
INSERT INTO `ms_addresses` VALUES ('96746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町長畑', '36', '36207', '7712107', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '長畑', 'ナガハタ');
INSERT INTO `ms_addresses` VALUES ('96747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町中山', '36', '36207', '7712107', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '中山', 'ナカヤマ');
INSERT INTO `ms_addresses` VALUES ('96748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町夏蕨', '36', '36207', '7712107', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '夏蕨', 'ナツワラビ');
INSERT INTO `ms_addresses` VALUES ('96749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町西宮ノ上', '36', '36207', '7712107', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '西宮ノ上', 'ニシミヤノウエ');
INSERT INTO `ms_addresses` VALUES ('96750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町東宮ノ上', '36', '36207', '7712107', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '東宮ノ上', 'ヒガシミヤノウエ');
INSERT INTO `ms_addresses` VALUES ('96751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町細野', '36', '36207', '7712107', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '細野', 'ホソノ');
INSERT INTO `ms_addresses` VALUES ('96752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町前田', '36', '36207', '7712107', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '前田', 'マエダ');
INSERT INTO `ms_addresses` VALUES ('96753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町松ノ花', '36', '36207', '7712107', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '松ノ花', 'マツノハナ');
INSERT INTO `ms_addresses` VALUES ('96754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町松ノ本', '36', '36207', '7712107', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '松ノ本', 'マツノモト');
INSERT INTO `ms_addresses` VALUES ('96755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町宮北', '36', '36207', '7712107', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '宮北', 'ミヤキタ');
INSERT INTO `ms_addresses` VALUES ('96756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町宮前', '36', '36207', '7712107', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '宮前', 'ミヤマエ');
INSERT INTO `ms_addresses` VALUES ('96757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町八幡', '36', '36207', '7712107', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '八幡', 'ヤハタ');
INSERT INTO `ms_addresses` VALUES ('96758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町山夏蕨', '36', '36207', '7712107', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '山夏蕨', 'ヤマナツワラビ');
INSERT INTO `ms_addresses` VALUES ('96759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市美馬町吉水', '36', '36207', '7712107', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '美馬町', 'ミマチョウ', null, null, '吉水', 'ヨシミズ');
INSERT INTO `ms_addresses` VALUES ('96761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市三野町清水', '36', '36208', '7712301', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '三野町清水', 'ミノチョウシミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市三野町加茂野宮', '36', '36208', '7712302', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '三野町加茂野宮', 'ミノチョウカモノミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市三野町勢力', '36', '36208', '7712303', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '三野町勢力', 'ミノチョウセイリキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市三野町芝生', '36', '36208', '7712304', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '三野町芝生', 'ミノチョウシボウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市三野町太刀野', '36', '36208', '7712305', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '三野町太刀野', 'ミノチョウタチノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市三野町太刀野山', '36', '36208', '7712306', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '三野町太刀野山', 'ミノチョウタチノヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好郡東みよし町昼間', '36', '36489', '7712501', '徳島県', 'トクシマケン', '三好郡東みよし町', 'ミヨシグンヒガシミヨシチョウ', '昼間', 'ヒルマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好郡東みよし町足代', '36', '36489', '7712502', '徳島県', 'トクシマケン', '三好郡東みよし町', 'ミヨシグンヒガシミヨシチョウ', '足代', 'アシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好郡東みよし町東山', '36', '36489', '7712503', '徳島県', 'トクシマケン', '三好郡東みよし町', 'ミヨシグンヒガシミヨシチョウ', '東山', 'ヒガシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県名西郡神山町', '36', '36342', '7713200', '徳島県', 'トクシマケン', '名西郡神山町', 'ミョウザイグンカミヤマチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('96773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県名西郡神山町阿野', '36', '36342', '7713201', '徳島県', 'トクシマケン', '名西郡神山町', 'ミョウザイグンカミヤマチョウ', '阿野', 'アノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県名西郡神山町阿野石堂', '36', '36342', '7713202', '徳島県', 'トクシマケン', '名西郡神山町', 'ミョウザイグンカミヤマチョウ', '阿野', 'アノ', null, null, '石堂', 'イシドウ');
INSERT INTO `ms_addresses` VALUES ('96775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県名西郡神山町阿野井ノ谷', '36', '36342', '7713202', '徳島県', 'トクシマケン', '名西郡神山町', 'ミョウザイグンカミヤマチョウ', '阿野', 'アノ', null, null, '井ノ谷', 'イノタニ');
INSERT INTO `ms_addresses` VALUES ('96776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県名西郡神山町阿野宇度木', '36', '36342', '7713202', '徳島県', 'トクシマケン', '名西郡神山町', 'ミョウザイグンカミヤマチョウ', '阿野', 'アノ', null, null, '宇度木', 'ウトギ');
INSERT INTO `ms_addresses` VALUES ('96777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県名西郡神山町阿野上河内', '36', '36342', '7713202', '徳島県', 'トクシマケン', '名西郡神山町', 'ミョウザイグンカミヤマチョウ', '阿野', 'アノ', null, null, '上河内', 'カミゴウチ');
INSERT INTO `ms_addresses` VALUES ('96778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県名西郡神山町阿野川平', '36', '36342', '7713202', '徳島県', 'トクシマケン', '名西郡神山町', 'ミョウザイグンカミヤマチョウ', '阿野', 'アノ', null, null, '川平', 'カワヒラ');
INSERT INTO `ms_addresses` VALUES ('96779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県名西郡神山町阿野黒木', '36', '36342', '7713202', '徳島県', 'トクシマケン', '名西郡神山町', 'ミョウザイグンカミヤマチョウ', '阿野', 'アノ', null, null, '黒木', 'クロギ');
INSERT INTO `ms_addresses` VALUES ('96780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県名西郡神山町阿野駒坂', '36', '36342', '7713202', '徳島県', 'トクシマケン', '名西郡神山町', 'ミョウザイグンカミヤマチョウ', '阿野', 'アノ', null, null, '駒坂', 'コマサカ');
INSERT INTO `ms_addresses` VALUES ('96781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県名西郡神山町阿野地ノ平', '36', '36342', '7713202', '徳島県', 'トクシマケン', '名西郡神山町', 'ミョウザイグンカミヤマチョウ', '阿野', 'アノ', null, null, '地ノ平', 'ジノタイラ');
INSERT INTO `ms_addresses` VALUES ('96782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県名西郡神山町阿野神木', '36', '36342', '7713202', '徳島県', 'トクシマケン', '名西郡神山町', 'ミョウザイグンカミヤマチョウ', '阿野', 'アノ', null, null, '神木', 'ジンギ');
INSERT INTO `ms_addresses` VALUES ('96783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県名西郡神山町阿野須賀', '36', '36342', '7713202', '徳島県', 'トクシマケン', '名西郡神山町', 'ミョウザイグンカミヤマチョウ', '阿野', 'アノ', null, null, '須賀', 'スガ');
INSERT INTO `ms_addresses` VALUES ('96784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県名西郡神山町阿野長瀬', '36', '36342', '7713202', '徳島県', 'トクシマケン', '名西郡神山町', 'ミョウザイグンカミヤマチョウ', '阿野', 'アノ', null, null, '長瀬', 'ナガセ');
INSERT INTO `ms_addresses` VALUES ('96785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県名西郡神山町阿野長代', '36', '36342', '7713202', '徳島県', 'トクシマケン', '名西郡神山町', 'ミョウザイグンカミヤマチョウ', '阿野', 'アノ', null, null, '長代', 'ナガタイ');
INSERT INTO `ms_addresses` VALUES ('96786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県名西郡神山町阿野二ノ宮', '36', '36342', '7713202', '徳島県', 'トクシマケン', '名西郡神山町', 'ミョウザイグンカミヤマチョウ', '阿野', 'アノ', null, null, '二ノ宮', 'ニノミヤ');
INSERT INTO `ms_addresses` VALUES ('96787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県名西郡神山町阿野日浦', '36', '36342', '7713202', '徳島県', 'トクシマケン', '名西郡神山町', 'ミョウザイグンカミヤマチョウ', '阿野', 'アノ', null, null, '日浦', 'ヒウラ');
INSERT INTO `ms_addresses` VALUES ('96788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県名西郡神山町阿野東代次', '36', '36342', '7713202', '徳島県', 'トクシマケン', '名西郡神山町', 'ミョウザイグンカミヤマチョウ', '阿野', 'アノ', null, null, '東代次', 'ヒガシヨツギ');
INSERT INTO `ms_addresses` VALUES ('96789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県名西郡神山町阿野広石', '36', '36342', '7713202', '徳島県', 'トクシマケン', '名西郡神山町', 'ミョウザイグンカミヤマチョウ', '阿野', 'アノ', null, null, '広石', 'ヒロイシ');
INSERT INTO `ms_addresses` VALUES ('96790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県名西郡神山町阿野福原', '36', '36342', '7713202', '徳島県', 'トクシマケン', '名西郡神山町', 'ミョウザイグンカミヤマチョウ', '阿野', 'アノ', null, null, '福原', 'フクハラ');
INSERT INTO `ms_addresses` VALUES ('96791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県名西郡神山町阿野府中', '36', '36342', '7713202', '徳島県', 'トクシマケン', '名西郡神山町', 'ミョウザイグンカミヤマチョウ', '阿野', 'アノ', null, null, '府中', 'フチュウ');
INSERT INTO `ms_addresses` VALUES ('96792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県名西郡神山町阿野船底', '36', '36342', '7713202', '徳島県', 'トクシマケン', '名西郡神山町', 'ミョウザイグンカミヤマチョウ', '阿野', 'アノ', null, null, '船底', 'フナゾコ');
INSERT INTO `ms_addresses` VALUES ('96793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県名西郡神山町阿野本名', '36', '36342', '7713202', '徳島県', 'トクシマケン', '名西郡神山町', 'ミョウザイグンカミヤマチョウ', '阿野', 'アノ', null, null, '本名', 'ホンミョウ');
INSERT INTO `ms_addresses` VALUES ('96794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県名西郡神山町阿野松尾', '36', '36342', '7713202', '徳島県', 'トクシマケン', '名西郡神山町', 'ミョウザイグンカミヤマチョウ', '阿野', 'アノ', null, null, '松尾', 'マツオ');
INSERT INTO `ms_addresses` VALUES ('96795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県名西郡神山町阿野宮分', '36', '36342', '7713202', '徳島県', 'トクシマケン', '名西郡神山町', 'ミョウザイグンカミヤマチョウ', '阿野', 'アノ', null, null, '宮分', 'ミヤブン');
INSERT INTO `ms_addresses` VALUES ('96796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県名西郡神山町阿野屋那瀬', '36', '36342', '7713202', '徳島県', 'トクシマケン', '名西郡神山町', 'ミョウザイグンカミヤマチョウ', '阿野', 'アノ', null, null, '屋那瀬', 'ヤナゼ');
INSERT INTO `ms_addresses` VALUES ('96797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県名西郡神山町阿野代次', '36', '36342', '7713202', '徳島県', 'トクシマケン', '名西郡神山町', 'ミョウザイグンカミヤマチョウ', '阿野', 'アノ', null, null, '代次', 'ヨツギ');
INSERT INTO `ms_addresses` VALUES ('96798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県名西郡神山町鬼籠野', '36', '36342', '7713203', '徳島県', 'トクシマケン', '名西郡神山町', 'ミョウザイグンカミヤマチョウ', '鬼籠野', 'オロノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県名西郡神山町神領', '36', '36342', '7713310', '徳島県', 'トクシマケン', '名西郡神山町', 'ミョウザイグンカミヤマチョウ', '神領', 'ジンリョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県名西郡神山町神領石堂', '36', '36342', '7713311', '徳島県', 'トクシマケン', '名西郡神山町', 'ミョウザイグンカミヤマチョウ', '神領', 'ジンリョウ', null, null, '石堂', 'イシドウ');
INSERT INTO `ms_addresses` VALUES ('96801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県名西郡神山町神領川北', '36', '36342', '7713311', '徳島県', 'トクシマケン', '名西郡神山町', 'ミョウザイグンカミヤマチョウ', '神領', 'ジンリョウ', null, null, '川北', 'カワキタ');
INSERT INTO `ms_addresses` VALUES ('96802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県名西郡神山町神領北', '36', '36342', '7713311', '徳島県', 'トクシマケン', '名西郡神山町', 'ミョウザイグンカミヤマチョウ', '神領', 'ジンリョウ', null, null, '北', 'キタ');
INSERT INTO `ms_addresses` VALUES ('96803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県名西郡神山町神領谷', '36', '36342', '7713311', '徳島県', 'トクシマケン', '名西郡神山町', 'ミョウザイグンカミヤマチョウ', '神領', 'ジンリョウ', null, null, '谷', 'タニ');
INSERT INTO `ms_addresses` VALUES ('96804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県名西郡神山町神領西野間', '36', '36342', '7713311', '徳島県', 'トクシマケン', '名西郡神山町', 'ミョウザイグンカミヤマチョウ', '神領', 'ジンリョウ', null, null, '西野間', 'ニシノマ');
INSERT INTO `ms_addresses` VALUES ('96805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県名西郡神山町神領東野間', '36', '36342', '7713311', '徳島県', 'トクシマケン', '名西郡神山町', 'ミョウザイグンカミヤマチョウ', '神領', 'ジンリョウ', null, null, '東野間', 'ヒガシノマ');
INSERT INTO `ms_addresses` VALUES ('96806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県名西郡神山町神領本野間', '36', '36342', '7713311', '徳島県', 'トクシマケン', '名西郡神山町', 'ミョウザイグンカミヤマチョウ', '神領', 'ジンリョウ', null, null, '本野間', 'ホンノマ');
INSERT INTO `ms_addresses` VALUES ('96808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県名西郡神山町下分', '36', '36342', '7713421', '徳島県', 'トクシマケン', '名西郡神山町', 'ミョウザイグンカミヤマチョウ', '下分', 'シモブン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県名西郡神山町上分', '36', '36342', '7713422', '徳島県', 'トクシマケン', '名西郡神山町', 'ミョウザイグンカミヤマチョウ', '上分', 'カミブン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県名東郡佐那河内村', '36', '36321', '7714100', '徳島県', 'トクシマケン', '名東郡佐那河内村', 'ミョウドウグンサナゴウチソン', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('96811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県名東郡佐那河内村下', '36', '36321', '7714101', '徳島県', 'トクシマケン', '名東郡佐那河内村', 'ミョウドウグンサナゴウチソン', '下', 'シモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県名東郡佐那河内村上', '36', '36321', '7714102', '徳島県', 'トクシマケン', '名東郡佐那河内村', 'ミョウドウグンサナゴウチソン', '上', 'カミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市丈六町', '36', '36201', '7714261', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '丈六町', 'ジョウロクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市丈六町長尾', '36', '36201', '7714262', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '丈六町', 'ジョウロクチョウ', null, null, '長尾', 'ナガオ');
INSERT INTO `ms_addresses` VALUES ('96816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市丈六町丈領', '36', '36201', '7714263', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '丈六町', 'ジョウロクチョウ', null, null, '丈領', 'ジョウリョウ');
INSERT INTO `ms_addresses` VALUES ('96817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市多家良町', '36', '36201', '7714264', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '多家良町', 'タカラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市飯谷町', '36', '36201', '7714265', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '飯谷町', 'イイタニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市八多町', '36', '36201', '7714266', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '八多町', 'ハタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市渋野町', '36', '36201', '7714267', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '渋野町', 'シブノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県勝浦郡勝浦町', '36', '36301', '7714300', '徳島県', 'トクシマケン', '勝浦郡勝浦町', 'カツウラグンカツウラチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('96822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県勝浦郡勝浦町沼江', '36', '36301', '7714301', '徳島県', 'トクシマケン', '勝浦郡勝浦町', 'カツウラグンカツウラチョウ', '沼江', 'ヌエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県勝浦郡勝浦町中角', '36', '36301', '7714302', '徳島県', 'トクシマケン', '勝浦郡勝浦町', 'カツウラグンカツウラチョウ', '中角', 'ナカツノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県勝浦郡勝浦町生名', '36', '36301', '7714303', '徳島県', 'トクシマケン', '勝浦郡勝浦町', 'カツウラグンカツウラチョウ', '生名', 'イクナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県勝浦郡勝浦町星谷', '36', '36301', '7714304', '徳島県', 'トクシマケン', '勝浦郡勝浦町', 'カツウラグンカツウラチョウ', '星谷', 'ホシタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県勝浦郡勝浦町久国', '36', '36301', '7714305', '徳島県', 'トクシマケン', '勝浦郡勝浦町', 'カツウラグンカツウラチョウ', '久国', 'ヒサクニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県勝浦郡勝浦町棚野', '36', '36301', '7714306', '徳島県', 'トクシマケン', '勝浦郡勝浦町', 'カツウラグンカツウラチョウ', '棚野', 'タナノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県勝浦郡勝浦町三渓', '36', '36301', '7714307', '徳島県', 'トクシマケン', '勝浦郡勝浦町', 'カツウラグンカツウラチョウ', '三渓', 'ミタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県勝浦郡勝浦町坂本', '36', '36301', '7714308', '徳島県', 'トクシマケン', '勝浦郡勝浦町', 'カツウラグンカツウラチョウ', '坂本', 'サカモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県勝浦郡上勝町', '36', '36302', '7714500', '徳島県', 'トクシマケン', '勝浦郡上勝町', 'カツウラグンカミカツチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('96832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県勝浦郡上勝町福原', '36', '36302', '7714501', '徳島県', 'トクシマケン', '勝浦郡上勝町', 'カツウラグンカミカツチョウ', '福原', 'フクハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県勝浦郡上勝町旭', '36', '36302', '7714502', '徳島県', 'トクシマケン', '勝浦郡上勝町', 'カツウラグンカミカツチョウ', '旭', 'アサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県勝浦郡上勝町生実', '36', '36302', '7714503', '徳島県', 'トクシマケン', '勝浦郡上勝町', 'カツウラグンカミカツチョウ', '生実', 'イクミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県勝浦郡上勝町傍示', '36', '36302', '7714504', '徳島県', 'トクシマケン', '勝浦郡上勝町', 'カツウラグンカミカツチョウ', '傍示', 'ホウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県勝浦郡上勝町正木', '36', '36302', '7714505', '徳島県', 'トクシマケン', '勝浦郡上勝町', 'カツウラグンカミカツチョウ', '正木', 'マサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿南市楠根町', '36', '36204', '7715170', '徳島県', 'トクシマケン', '阿南市', 'アナンシ', '楠根町', 'クスネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿南市熊谷町', '36', '36204', '7715171', '徳島県', 'トクシマケン', '阿南市', 'アナンシ', '熊谷町', 'クマダニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿南市吉井町', '36', '36204', '7715172', '徳島県', 'トクシマケン', '阿南市', 'アナンシ', '吉井町', 'ヨシイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿南市加茂町', '36', '36204', '7715173', '徳島県', 'トクシマケン', '阿南市', 'アナンシ', '加茂町', 'カモチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿南市水井町', '36', '36204', '7715174', '徳島県', 'トクシマケン', '阿南市', 'アナンシ', '水井町', 'スイイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿南市細野町', '36', '36204', '7715175', '徳島県', 'トクシマケン', '阿南市', 'アナンシ', '細野町', 'ホソノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿南市大田井町', '36', '36204', '7715176', '徳島県', 'トクシマケン', '阿南市', 'アナンシ', '大田井町', 'オオタイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿南市大井町', '36', '36204', '7715177', '徳島県', 'トクシマケン', '阿南市', 'アナンシ', '大井町', 'オオイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿南市十八女町', '36', '36204', '7715178', '徳島県', 'トクシマケン', '阿南市', 'アナンシ', '十八女町', 'サカリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿南市深瀬町', '36', '36204', '7715179', '徳島県', 'トクシマケン', '阿南市', 'アナンシ', '深瀬町', 'フカセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県那賀郡那賀町', '36', '36368', '7715200', '徳島県', 'トクシマケン', '那賀郡那賀町', 'ナカグンナカチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('96848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県那賀郡那賀町和食', '36', '36368', '7715201', '徳島県', 'トクシマケン', '那賀郡那賀町', 'ナカグンナカチョウ', '和食', 'ワジキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県那賀郡那賀町土佐', '36', '36368', '7715202', '徳島県', 'トクシマケン', '那賀郡那賀町', 'ナカグンナカチョウ', '土佐', 'トサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県那賀郡那賀町和食郷', '36', '36368', '7715203', '徳島県', 'トクシマケン', '那賀郡那賀町', 'ナカグンナカチョウ', '和食郷', 'ワジキゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県那賀郡那賀町中山', '36', '36368', '7715204', '徳島県', 'トクシマケン', '那賀郡那賀町', 'ナカグンナカチョウ', '中山', 'ナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県那賀郡那賀町百合谷', '36', '36368', '7715205', '徳島県', 'トクシマケン', '那賀郡那賀町', 'ナカグンナカチョウ', '百合谷', 'モマエダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県那賀郡那賀町百合', '36', '36368', '7715206', '徳島県', 'トクシマケン', '那賀郡那賀町', 'ナカグンナカチョウ', '百合', 'モマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県那賀郡那賀町阿井', '36', '36368', '7715207', '徳島県', 'トクシマケン', '那賀郡那賀町', 'ナカグンナカチョウ', '阿井', 'アイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県那賀郡那賀町仁宇', '36', '36368', '7715208', '徳島県', 'トクシマケン', '那賀郡那賀町', 'ナカグンナカチョウ', '仁宇', 'ニウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県那賀郡那賀町小仁宇', '36', '36368', '7715209', '徳島県', 'トクシマケン', '那賀郡那賀町', 'ナカグンナカチョウ', '小仁宇', 'コニウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県那賀郡那賀町榎谷', '36', '36368', '7715320', '徳島県', 'トクシマケン', '那賀郡那賀町', 'ナカグンナカチョウ', '榎谷', 'エノキダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県那賀郡那賀町馬路', '36', '36368', '7715321', '徳島県', 'トクシマケン', '那賀郡那賀町', 'ナカグンナカチョウ', '馬路', 'ウマジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県那賀郡那賀町谷内', '36', '36368', '7715322', '徳島県', 'トクシマケン', '那賀郡那賀町', 'ナカグンナカチョウ', '谷内', 'タニウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県那賀郡那賀町相名', '36', '36368', '7715323', '徳島県', 'トクシマケン', '那賀郡那賀町', 'ナカグンナカチョウ', '相名', 'アイナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県那賀郡那賀町井ノ谷', '36', '36368', '7715324', '徳島県', 'トクシマケン', '那賀郡那賀町', 'ナカグンナカチョウ', '井ノ谷', 'イノタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県那賀郡那賀町平野', '36', '36368', '7715325', '徳島県', 'トクシマケン', '那賀郡那賀町', 'ナカグンナカチョウ', '平野', 'ヒラノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県那賀郡那賀町内山', '36', '36368', '7715326', '徳島県', 'トクシマケン', '那賀郡那賀町', 'ナカグンナカチョウ', '内山', 'ウチヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県那賀郡那賀町西納', '36', '36368', '7715327', '徳島県', 'トクシマケン', '那賀郡那賀町', 'ナカグンナカチョウ', '西納', 'ニシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県那賀郡那賀町請ノ谷', '36', '36368', '7715328', '徳島県', 'トクシマケン', '那賀郡那賀町', 'ナカグンナカチョウ', '請ノ谷', 'ウケノタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県那賀郡那賀町竹ケ谷', '36', '36368', '7715329', '徳島県', 'トクシマケン', '那賀郡那賀町', 'ナカグンナカチョウ', '竹ケ谷', 'タケガタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県那賀郡那賀町朝生', '36', '36368', '7715401', '徳島県', 'トクシマケン', '那賀郡那賀町', 'ナカグンナカチョウ', '朝生', 'アソウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県那賀郡那賀町簗ノ上', '36', '36368', '7715402', '徳島県', 'トクシマケン', '那賀郡那賀町', 'ナカグンナカチョウ', '簗ノ上', 'ヤナノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県那賀郡那賀町鮎川', '36', '36368', '7715403', '徳島県', 'トクシマケン', '那賀郡那賀町', 'ナカグンナカチョウ', '鮎川', 'アイカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県那賀郡那賀町牛輪', '36', '36368', '7715404', '徳島県', 'トクシマケン', '那賀郡那賀町', 'ナカグンナカチョウ', '牛輪', 'ウシワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県那賀郡那賀町入野', '36', '36368', '7715405', '徳島県', 'トクシマケン', '那賀郡那賀町', 'ナカグンナカチョウ', '入野', 'イリノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県那賀郡那賀町延野', '36', '36368', '7715406', '徳島県', 'トクシマケン', '那賀郡那賀町', 'ナカグンナカチョウ', '延野', 'ノブノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県那賀郡那賀町雄', '36', '36368', '7715407', '徳島県', 'トクシマケン', '那賀郡那賀町', 'ナカグンナカチョウ', '雄', 'オンドリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県那賀郡那賀町吉野', '36', '36368', '7715408', '徳島県', 'トクシマケン', '那賀郡那賀町', 'ナカグンナカチョウ', '吉野', 'ヨシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県那賀郡那賀町鉢', '36', '36368', '7715409', '徳島県', 'トクシマケン', '那賀郡那賀町', 'ナカグンナカチョウ', '鉢', 'ハチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県那賀郡那賀町大久保', '36', '36368', '7715410', '徳島県', 'トクシマケン', '那賀郡那賀町', 'ナカグンナカチョウ', '大久保', 'オオクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県那賀郡那賀町横石', '36', '36368', '7715411', '徳島県', 'トクシマケン', '那賀郡那賀町', 'ナカグンナカチョウ', '横石', 'ヨコイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県那賀郡那賀町朴野', '36', '36368', '7715412', '徳島県', 'トクシマケン', '那賀郡那賀町', 'ナカグンナカチョウ', '朴野', 'ホオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県那賀郡那賀町蔭谷', '36', '36368', '7715413', '徳島県', 'トクシマケン', '那賀郡那賀町', 'ナカグンナカチョウ', '蔭谷', 'カゲダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県那賀郡那賀町音谷', '36', '36368', '7715501', '徳島県', 'トクシマケン', '那賀郡那賀町', 'ナカグンナカチョウ', '音谷', 'オンダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県那賀郡那賀町桜谷', '36', '36368', '7715502', '徳島県', 'トクシマケン', '那賀郡那賀町', 'ナカグンナカチョウ', '桜谷', 'サクラダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県那賀郡那賀町小浜', '36', '36368', '7715503', '徳島県', 'トクシマケン', '那賀郡那賀町', 'ナカグンナカチョウ', '小浜', 'コハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県那賀郡那賀町臼ケ谷', '36', '36368', '7715504', '徳島県', 'トクシマケン', '那賀郡那賀町', 'ナカグンナカチョウ', '臼ケ谷', 'ウスガタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県那賀郡那賀町長安', '36', '36368', '7715505', '徳島県', 'トクシマケン', '那賀郡那賀町', 'ナカグンナカチョウ', '長安', 'ナガヤス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県那賀郡那賀町桧曽根', '36', '36368', '7715506', '徳島県', 'トクシマケン', '那賀郡那賀町', 'ナカグンナカチョウ', '桧曽根', 'ヒソネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県那賀郡那賀町菖蒲', '36', '36368', '7715507', '徳島県', 'トクシマケン', '那賀郡那賀町', 'ナカグンナカチョウ', '菖蒲', 'ショウブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県那賀郡那賀町東尾', '36', '36368', '7715508', '徳島県', 'トクシマケン', '那賀郡那賀町', 'ナカグンナカチョウ', '東尾', 'ヒガシオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県那賀郡那賀町水崎', '36', '36368', '7715511', '徳島県', 'トクシマケン', '那賀郡那賀町', 'ナカグンナカチョウ', '水崎', 'ミサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県那賀郡那賀町小計', '36', '36368', '7715512', '徳島県', 'トクシマケン', '那賀郡那賀町', 'ナカグンナカチョウ', '小計', 'コバカリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県那賀郡那賀町古屋', '36', '36368', '7715513', '徳島県', 'トクシマケン', '那賀郡那賀町', 'ナカグンナカチョウ', '古屋', 'フルヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県那賀郡那賀町深森', '36', '36368', '7715514', '徳島県', 'トクシマケン', '那賀郡那賀町', 'ナカグンナカチョウ', '深森', 'フカモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県那賀郡那賀町川俣', '36', '36368', '7715515', '徳島県', 'トクシマケン', '那賀郡那賀町', 'ナカグンナカチョウ', '川俣', 'カワマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県那賀郡那賀町大戸', '36', '36368', '7715516', '徳島県', 'トクシマケン', '那賀郡那賀町', 'ナカグンナカチョウ', '大戸', 'オオト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県那賀郡那賀町日真', '36', '36368', '7715517', '徳島県', 'トクシマケン', '那賀郡那賀町', 'ナカグンナカチョウ', '日真', 'ヒマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県那賀郡那賀町拝宮', '36', '36368', '7715518', '徳島県', 'トクシマケン', '那賀郡那賀町', 'ナカグンナカチョウ', '拝宮', 'ハイギュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県那賀郡那賀町日浦', '36', '36368', '7715531', '徳島県', 'トクシマケン', '那賀郡那賀町', 'ナカグンナカチョウ', '日浦', 'ヒウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県那賀郡那賀町花瀬', '36', '36368', '7715532', '徳島県', 'トクシマケン', '那賀郡那賀町', 'ナカグンナカチョウ', '花瀬', 'ハナゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県那賀郡那賀町阿津江', '36', '36368', '7716101', '徳島県', 'トクシマケン', '那賀郡那賀町', 'ナカグンナカチョウ', '阿津江', 'アヅエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県那賀郡那賀町木頭名', '36', '36368', '7716102', '徳島県', 'トクシマケン', '那賀郡那賀町', 'ナカグンナカチョウ', '木頭名', 'キトウミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県那賀郡那賀町出羽', '36', '36368', '7716103', '徳島県', 'トクシマケン', '那賀郡那賀町', 'ナカグンナカチョウ', '出羽', 'イズリハ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県那賀郡那賀町当山', '36', '36368', '7716104', '徳島県', 'トクシマケン', '那賀郡那賀町', 'ナカグンナカチョウ', '当山', 'トウヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県那賀郡那賀町木頭', '36', '36368', '7716105', '徳島県', 'トクシマケン', '那賀郡那賀町', 'ナカグンナカチョウ', '木頭', 'キトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県那賀郡那賀町坂州', '36', '36368', '7716106', '徳島県', 'トクシマケン', '那賀郡那賀町', 'ナカグンナカチョウ', '坂州', 'サカシュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県那賀郡那賀町掛盤', '36', '36368', '7716107', '徳島県', 'トクシマケン', '那賀郡那賀町', 'ナカグンナカチョウ', '掛盤', 'カケバン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県那賀郡那賀町小泉', '36', '36368', '7716111', '徳島県', 'トクシマケン', '那賀郡那賀町', 'ナカグンナカチョウ', '小泉', 'コイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県那賀郡那賀町高野', '36', '36368', '7716112', '徳島県', 'トクシマケン', '那賀郡那賀町', 'ナカグンナカチョウ', '高野', 'タカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県那賀郡那賀町寺内', '36', '36368', '7716113', '徳島県', 'トクシマケン', '那賀郡那賀町', 'ナカグンナカチョウ', '寺内', 'テラウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県那賀郡那賀町沢谷', '36', '36368', '7716114', '徳島県', 'トクシマケン', '那賀郡那賀町', 'ナカグンナカチョウ', '沢谷', 'サワダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県那賀郡那賀町小畠', '36', '36368', '7716115', '徳島県', 'トクシマケン', '那賀郡那賀町', 'ナカグンナカチョウ', '小畠', 'オバタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県那賀郡那賀町横谷', '36', '36368', '7716116', '徳島県', 'トクシマケン', '那賀郡那賀町', 'ナカグンナカチョウ', '横谷', 'ヨコダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県那賀郡那賀町川成', '36', '36368', '7716117', '徳島県', 'トクシマケン', '那賀郡那賀町', 'ナカグンナカチョウ', '川成', 'カワナリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県那賀郡那賀町岩倉', '36', '36368', '7716118', '徳島県', 'トクシマケン', '那賀郡那賀町', 'ナカグンナカチョウ', '岩倉', 'イワクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県那賀郡那賀町平谷', '36', '36368', '7716321', '徳島県', 'トクシマケン', '那賀郡那賀町', 'ナカグンナカチョウ', '平谷', 'ヒラダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県那賀郡那賀町大殿', '36', '36368', '7716322', '徳島県', 'トクシマケン', '那賀郡那賀町', 'ナカグンナカチョウ', '大殿', 'オオトノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県那賀郡那賀町白石', '36', '36368', '7716323', '徳島県', 'トクシマケン', '那賀郡那賀町', 'ナカグンナカチョウ', '白石', 'シライシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県那賀郡那賀町御所谷', '36', '36368', '7716324', '徳島県', 'トクシマケン', '那賀郡那賀町', 'ナカグンナカチョウ', '御所谷', 'ゴショダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県那賀郡那賀町丈ケ谷', '36', '36368', '7716325', '徳島県', 'トクシマケン', '那賀郡那賀町', 'ナカグンナカチョウ', '丈ケ谷', 'ジョウガタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県那賀郡那賀町府殿', '36', '36368', '7716326', '徳島県', 'トクシマケン', '那賀郡那賀町', 'ナカグンナカチョウ', '府殿', 'フドノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県那賀郡那賀町成瀬', '36', '36368', '7716327', '徳島県', 'トクシマケン', '那賀郡那賀町', 'ナカグンナカチョウ', '成瀬', 'ナルセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県那賀郡那賀町海川', '36', '36368', '7716328', '徳島県', 'トクシマケン', '那賀郡那賀町', 'ナカグンナカチョウ', '海川', 'カイカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県那賀郡那賀町木頭助', '36', '36368', '7716401', '徳島県', 'トクシマケン', '那賀郡那賀町', 'ナカグンナカチョウ', '木頭助', 'キトウスケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県那賀郡那賀町木頭出原', '36', '36368', '7716402', '徳島県', 'トクシマケン', '那賀郡那賀町', 'ナカグンナカチョウ', '木頭出原', 'キトウイズハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県那賀郡那賀町木頭和無田', '36', '36368', '7716403', '徳島県', 'トクシマケン', '那賀郡那賀町', 'ナカグンナカチョウ', '木頭和無田', 'キトウワムダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県那賀郡那賀町木頭南宇', '36', '36368', '7716404', '徳島県', 'トクシマケン', '那賀郡那賀町', 'ナカグンナカチョウ', '木頭南宇', 'キトウミナミウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県那賀郡那賀町木頭西宇', '36', '36368', '7716405', '徳島県', 'トクシマケン', '那賀郡那賀町', 'ナカグンナカチョウ', '木頭西宇', 'キトウニシウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県那賀郡那賀町木頭折宇', '36', '36368', '7716511', '徳島県', 'トクシマケン', '那賀郡那賀町', 'ナカグンナカチョウ', '木頭折宇', 'キトウオリウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県那賀郡那賀町木頭北川', '36', '36368', '7716512', '徳島県', 'トクシマケン', '那賀郡那賀町', 'ナカグンナカチョウ', '木頭北川', 'キトウキタガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県鳴門市', '36', '36202', '7720000', '徳島県', 'トクシマケン', '鳴門市', 'ナルトシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('96933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県鳴門市撫養町黒崎', '36', '36202', '7720001', '徳島県', 'トクシマケン', '鳴門市', 'ナルトシ', '撫養町黒崎', 'ムヤチョウクロサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県鳴門市撫養町斎田', '36', '36202', '7720002', '徳島県', 'トクシマケン', '鳴門市', 'ナルトシ', '撫養町斎田', 'ムヤチョウサイタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県鳴門市撫養町南浜', '36', '36202', '7720003', '徳島県', 'トクシマケン', '鳴門市', 'ナルトシ', '撫養町南浜', 'ムヤチョウミナミハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県鳴門市撫養町木津', '36', '36202', '7720004', '徳島県', 'トクシマケン', '鳴門市', 'ナルトシ', '撫養町木津', 'ムヤチョウキヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県鳴門市撫養町大桑島', '36', '36202', '7720011', '徳島県', 'トクシマケン', '鳴門市', 'ナルトシ', '撫養町大桑島', 'ムヤチョウオオクワジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県鳴門市撫養町小桑島', '36', '36202', '7720012', '徳島県', 'トクシマケン', '鳴門市', 'ナルトシ', '撫養町小桑島', 'ムヤチョウコクワジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県鳴門市撫養町岡崎', '36', '36202', '7720013', '徳島県', 'トクシマケン', '鳴門市', 'ナルトシ', '撫養町岡崎', 'ムヤチョウオカザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県鳴門市撫養町弁財天', '36', '36202', '7720014', '徳島県', 'トクシマケン', '鳴門市', 'ナルトシ', '撫養町弁財天', 'ムヤチョウベザイテン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県鳴門市撫養町北浜', '36', '36202', '7720015', '徳島県', 'トクシマケン', '鳴門市', 'ナルトシ', '撫養町北浜', 'ムヤチョウキタハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県鳴門市撫養町林崎', '36', '36202', '7720016', '徳島県', 'トクシマケン', '鳴門市', 'ナルトシ', '撫養町林崎', 'ムヤチョウハヤサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県鳴門市撫養町立岩', '36', '36202', '7720017', '徳島県', 'トクシマケン', '鳴門市', 'ナルトシ', '撫養町立岩', 'ムヤチョウタテイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県鳴門市里浦町里浦', '36', '36202', '7720021', '徳島県', 'トクシマケン', '鳴門市', 'ナルトシ', '里浦町里浦', 'サトウラチョウサトウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県鳴門市里浦町粟津', '36', '36202', '7720022', '徳島県', 'トクシマケン', '鳴門市', 'ナルトシ', '里浦町粟津', 'サトウラチョウアワヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県鳴門市大津町木津野', '36', '36202', '7720031', '徳島県', 'トクシマケン', '鳴門市', 'ナルトシ', '大津町木津野', 'オオツチョウキヅノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県鳴門市大津町吉永', '36', '36202', '7720032', '徳島県', 'トクシマケン', '鳴門市', 'ナルトシ', '大津町吉永', 'オオツチョウヨシナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県鳴門市大津町長江', '36', '36202', '7720033', '徳島県', 'トクシマケン', '鳴門市', 'ナルトシ', '大津町長江', 'オオツチョウナガエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県鳴門市大津町徳長', '36', '36202', '7720034', '徳島県', 'トクシマケン', '鳴門市', 'ナルトシ', '大津町徳長', 'オオツチョウトクナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県鳴門市大津町矢倉', '36', '36202', '7720035', '徳島県', 'トクシマケン', '鳴門市', 'ナルトシ', '大津町矢倉', 'オオツチョウヤグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県鳴門市大津町大代', '36', '36202', '7720041', '徳島県', 'トクシマケン', '鳴門市', 'ナルトシ', '大津町大代', 'オオツチョウオオシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県鳴門市大津町備前島', '36', '36202', '7720042', '徳島県', 'トクシマケン', '鳴門市', 'ナルトシ', '大津町備前島', 'オオツチョウビゼンジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県鳴門市大津町段関', '36', '36202', '7720043', '徳島県', 'トクシマケン', '鳴門市', 'ナルトシ', '大津町段関', 'オオツチョウダンゼキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県鳴門市大津町大幸', '36', '36202', '7720044', '徳島県', 'トクシマケン', '鳴門市', 'ナルトシ', '大津町大幸', 'オオツチョウダイコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県鳴門市鳴門町高島', '36', '36202', '7720051', '徳島県', 'トクシマケン', '鳴門市', 'ナルトシ', '鳴門町高島', 'ナルトチョウタカシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県鳴門市鳴門町三ツ石', '36', '36202', '7720052', '徳島県', 'トクシマケン', '鳴門市', 'ナルトシ', '鳴門町三ツ石', 'ナルトチョウミツイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県鳴門市鳴門町土佐泊浦', '36', '36202', '7720053', '徳島県', 'トクシマケン', '鳴門市', 'ナルトシ', '鳴門町土佐泊浦', 'ナルトチョウトサドマリウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県鳴門市瀬戸町明神楠谷', '36', '36202', '7720060', '徳島県', 'トクシマケン', '鳴門市', 'ナルトシ', '瀬戸町明神', 'セトチョウアキノカミ', null, null, '楠谷', 'クスノキダニ');
INSERT INTO `ms_addresses` VALUES ('96959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県鳴門市瀬戸町明神弐軒家', '36', '36202', '7720060', '徳島県', 'トクシマケン', '鳴門市', 'ナルトシ', '瀬戸町明神', 'セトチョウアキノカミ', null, null, '弐軒家', 'ニケンヤ');
INSERT INTO `ms_addresses` VALUES ('96960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県鳴門市瀬戸町明神水汲谷', '36', '36202', '7720060', '徳島県', 'トクシマケン', '鳴門市', 'ナルトシ', '瀬戸町明神', 'セトチョウアキノカミ', null, null, '水汲谷', 'ミズクミダニ');
INSERT INTO `ms_addresses` VALUES ('96970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県小松島市', '36', '36203', '7730000', '徳島県', 'トクシマケン', '小松島市', 'コマツシマシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('96971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県小松島市小松島町', '36', '36203', '7730001', '徳島県', 'トクシマケン', '小松島市', 'コマツシマシ', '小松島町', 'コマツシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県小松島市神田瀬町', '36', '36203', '7730002', '徳島県', 'トクシマケン', '小松島市', 'コマツシマシ', '神田瀬町', 'カンダセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県小松島市松島町', '36', '36203', '7730003', '徳島県', 'トクシマケン', '小松島市', 'コマツシマシ', '松島町', 'マツシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県小松島市堀川町', '36', '36203', '7730004', '徳島県', 'トクシマケン', '小松島市', 'コマツシマシ', '堀川町', 'ホリカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県小松島市南小松島町', '36', '36203', '7730005', '徳島県', 'トクシマケン', '小松島市', 'コマツシマシ', '南小松島町', 'ミナミコマツシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県小松島市横須町', '36', '36203', '7730006', '徳島県', 'トクシマケン', '小松島市', 'コマツシマシ', '横須町', 'ヨコスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県小松島市金磯町', '36', '36203', '7730007', '徳島県', 'トクシマケン', '小松島市', 'コマツシマシ', '金磯町', 'カナイソチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県小松島市田野町', '36', '36203', '7730008', '徳島県', 'トクシマケン', '小松島市', 'コマツシマシ', '田野町', 'タノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県小松島市芝生町', '36', '36203', '7730009', '徳島県', 'トクシマケン', '小松島市', 'コマツシマシ', '芝生町', 'シボウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県小松島市日開野町', '36', '36203', '7730010', '徳島県', 'トクシマケン', '小松島市', 'コマツシマシ', '日開野町', 'ヒガイノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県小松島市新居見町', '36', '36203', '7730011', '徳島県', 'トクシマケン', '小松島市', 'コマツシマシ', '新居見町', 'ニイミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県小松島市田浦町', '36', '36203', '7730012', '徳島県', 'トクシマケン', '小松島市', 'コマツシマシ', '田浦町', 'タウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県小松島市前原町', '36', '36203', '7730013', '徳島県', 'トクシマケン', '小松島市', 'コマツシマシ', '前原町', 'マエバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県小松島市江田町', '36', '36203', '7730014', '徳島県', 'トクシマケン', '小松島市', 'コマツシマシ', '江田町', 'エダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県小松島市中田町', '36', '36203', '7730015', '徳島県', 'トクシマケン', '小松島市', 'コマツシマシ', '中田町', 'チュウデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県小松島市中郷町', '36', '36203', '7730016', '徳島県', 'トクシマケン', '小松島市', 'コマツシマシ', '中郷町', 'ナカノゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県小松島市立江町', '36', '36203', '7730017', '徳島県', 'トクシマケン', '小松島市', 'コマツシマシ', '立江町', 'タツエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県小松島市櫛淵町', '36', '36203', '7730018', '徳島県', 'トクシマケン', '小松島市', 'コマツシマシ', '櫛淵町', 'クシブチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県小松島市豊浦町', '36', '36203', '7730019', '徳島県', 'トクシマケン', '小松島市', 'コマツシマシ', '豊浦町', 'トヨウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県小松島市和田津開町', '36', '36203', '7730020', '徳島県', 'トクシマケン', '小松島市', 'コマツシマシ', '和田津開町', 'ワダツビラキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県小松島市赤石町', '36', '36203', '7730021', '徳島県', 'トクシマケン', '小松島市', 'コマツシマシ', '赤石町', 'アカイシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県小松島市大林町', '36', '36203', '7730022', '徳島県', 'トクシマケン', '小松島市', 'コマツシマシ', '大林町', 'オオハヤシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県小松島市坂野町', '36', '36203', '7730023', '徳島県', 'トクシマケン', '小松島市', 'コマツシマシ', '坂野町', 'サカノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県小松島市間新田町', '36', '36203', '7730024', '徳島県', 'トクシマケン', '小松島市', 'コマツシマシ', '間新田町', 'アイシンデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県小松島市和田島町', '36', '36203', '7730025', '徳島県', 'トクシマケン', '小松島市', 'コマツシマシ', '和田島町', 'ワダジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('96996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県小松島市和田島町松田新田', '36', '36203', '7730031', '徳島県', 'トクシマケン', '小松島市', 'コマツシマシ', '和田島町', 'ワダジマチョウ', null, null, '松田新田', 'マツダシンデン');
INSERT INTO `ms_addresses` VALUES ('96997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市大原町小神子', '36', '36201', '7730070', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '大原町', 'オオバラチョウ', null, null, '小神子', 'コミコ');
INSERT INTO `ms_addresses` VALUES ('96998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市大原町小神子山', '36', '36201', '7730070', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '大原町', 'オオバラチョウ', null, null, '小神子山', 'コミコヤマ');
INSERT INTO `ms_addresses` VALUES ('97004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿南市', '36', '36204', '7740000', '徳島県', 'トクシマケン', '阿南市', 'アナンシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('97005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿南市辰巳町', '36', '36204', '7740001', '徳島県', 'トクシマケン', '阿南市', 'アナンシ', '辰巳町', 'タツミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿南市豊益町', '36', '36204', '7740002', '徳島県', 'トクシマケン', '阿南市', 'アナンシ', '豊益町', 'トヨマスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿南市畭町', '36', '36204', '7740003', '徳島県', 'トクシマケン', '阿南市', 'アナンシ', '畭町', 'ハリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿南市福村町', '36', '36204', '7740004', '徳島県', 'トクシマケン', '阿南市', 'アナンシ', '福村町', 'フクムラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿南市向原町', '36', '36204', '7740005', '徳島県', 'トクシマケン', '阿南市', 'アナンシ', '向原町', 'ムカイバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿南市黒津地町', '36', '36204', '7740006', '徳島県', 'トクシマケン', '阿南市', 'アナンシ', '黒津地町', 'クロツチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿南市出来町', '36', '36204', '7740007', '徳島県', 'トクシマケン', '阿南市', 'アナンシ', '出来町', 'デキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿南市原ケ崎町', '36', '36204', '7740008', '徳島県', 'トクシマケン', '阿南市', 'アナンシ', '原ケ崎町', 'ハラガサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿南市西路見町', '36', '36204', '7740009', '徳島県', 'トクシマケン', '阿南市', 'アナンシ', '西路見町', 'サイロミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿南市領家町', '36', '36204', '7740011', '徳島県', 'トクシマケン', '阿南市', 'アナンシ', '領家町', 'リョウケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿南市七見町', '36', '36204', '7740012', '徳島県', 'トクシマケン', '阿南市', 'アナンシ', '七見町', 'ナナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿南市日開野町', '36', '36204', '7740013', '徳島県', 'トクシマケン', '阿南市', 'アナンシ', '日開野町', 'ヒガイノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿南市学原町', '36', '36204', '7740014', '徳島県', 'トクシマケン', '阿南市', 'アナンシ', '学原町', 'ガクバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿南市才見町', '36', '36204', '7740015', '徳島県', 'トクシマケン', '阿南市', 'アナンシ', '才見町', 'サイミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿南市中林町', '36', '36204', '7740016', '徳島県', 'トクシマケン', '阿南市', 'アナンシ', '中林町', 'ナカバヤシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿南市見能林町', '36', '36204', '7740017', '徳島県', 'トクシマケン', '阿南市', 'アナンシ', '見能林町', 'ミノバヤシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿南市津乃峰町', '36', '36204', '7740021', '徳島県', 'トクシマケン', '阿南市', 'アナンシ', '津乃峰町', 'ツノミネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿南市大潟町', '36', '36204', '7740022', '徳島県', 'トクシマケン', '阿南市', 'アナンシ', '大潟町', 'オオガタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿南市橘町', '36', '36204', '7740023', '徳島県', 'トクシマケン', '阿南市', 'アナンシ', '橘町', 'タチバナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿南市富岡町', '36', '36204', '7740030', '徳島県', 'トクシマケン', '阿南市', 'アナンシ', '富岡町', 'トミオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿南市住吉町', '36', '36204', '7740041', '徳島県', 'トクシマケン', '阿南市', 'アナンシ', '住吉町', 'スミヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿南市横見町', '36', '36204', '7740042', '徳島県', 'トクシマケン', '阿南市', 'アナンシ', '横見町', 'ヨコミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿南市柳島町', '36', '36204', '7740043', '徳島県', 'トクシマケン', '阿南市', 'アナンシ', '柳島町', 'ヤナギジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿南市上中町', '36', '36204', '7740044', '徳島県', 'トクシマケン', '阿南市', 'アナンシ', '上中町', 'カミナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿南市宝田町', '36', '36204', '7740045', '徳島県', 'トクシマケン', '阿南市', 'アナンシ', '宝田町', 'タカラダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿南市長生町', '36', '36204', '7740046', '徳島県', 'トクシマケン', '阿南市', 'アナンシ', '長生町', 'ナガイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿南市下大野町', '36', '36204', '7740047', '徳島県', 'トクシマケン', '阿南市', 'アナンシ', '下大野町', 'シモオオノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿南市中大野町', '36', '36204', '7740048', '徳島県', 'トクシマケン', '阿南市', 'アナンシ', '中大野町', 'ナカオオノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿南市上大野町', '36', '36204', '7740049', '徳島県', 'トクシマケン', '阿南市', 'アナンシ', '上大野町', 'カミオオノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿南市伊島町', '36', '36204', '7741760', '徳島県', 'トクシマケン', '阿南市', 'アナンシ', '伊島町', 'イシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県海部郡牟岐町', '36', '36383', '7750000', '徳島県', 'トクシマケン', '海部郡牟岐町', 'カイフグンムギチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('97038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県海部郡牟岐町河内', '36', '36383', '7750001', '徳島県', 'トクシマケン', '海部郡牟岐町', 'カイフグンムギチョウ', '河内', 'コウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県海部郡牟岐町橘', '36', '36383', '7750002', '徳島県', 'トクシマケン', '海部郡牟岐町', 'カイフグンムギチョウ', '橘', 'タチバナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県海部郡牟岐町辺川', '36', '36383', '7750003', '徳島県', 'トクシマケン', '海部郡牟岐町', 'カイフグンムギチョウ', '辺川', 'ヘガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県海部郡牟岐町川長', '36', '36383', '7750004', '徳島県', 'トクシマケン', '海部郡牟岐町', 'カイフグンムギチョウ', '川長', 'カワタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県海部郡牟岐町灘', '36', '36383', '7750005', '徳島県', 'トクシマケン', '海部郡牟岐町', 'カイフグンムギチョウ', '灘', 'ナダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県海部郡牟岐町中村', '36', '36383', '7750006', '徳島県', 'トクシマケン', '海部郡牟岐町', 'カイフグンムギチョウ', '中村', 'ナカムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県海部郡牟岐町内妻', '36', '36383', '7750007', '徳島県', 'トクシマケン', '海部郡牟岐町', 'カイフグンムギチョウ', '内妻', 'ウチヅマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県海部郡牟岐町牟岐浦', '36', '36383', '7750010', '徳島県', 'トクシマケン', '海部郡牟岐町', 'カイフグンムギチョウ', '牟岐浦', 'ムギウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県海部郡牟岐町牟岐浦浜崎', '36', '36383', '7750011', '徳島県', 'トクシマケン', '海部郡牟岐町', 'カイフグンムギチョウ', '牟岐浦', 'ムギウラ', null, null, '浜崎', 'ハマサキ');
INSERT INTO `ms_addresses` VALUES ('97047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県海部郡牟岐町牟岐浦宮ノ本', '36', '36383', '7750012', '徳島県', 'トクシマケン', '海部郡牟岐町', 'カイフグンムギチョウ', '牟岐浦', 'ムギウラ', null, null, '宮ノ本', 'ミヤノモト');
INSERT INTO `ms_addresses` VALUES ('97048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県海部郡牟岐町牟岐浦出羽島', '36', '36383', '7750013', '徳島県', 'トクシマケン', '海部郡牟岐町', 'カイフグンムギチョウ', '牟岐浦', 'ムギウラ', null, null, '出羽島', 'テバジマ');
INSERT INTO `ms_addresses` VALUES ('97049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県海部郡海陽町浅川', '36', '36388', '7750101', '徳島県', 'トクシマケン', '海部郡海陽町', 'カイフグンカイヨウチョウ', '浅川', 'アサカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県海部郡海陽町', '36', '36388', '7750200', '徳島県', 'トクシマケン', '海部郡海陽町', 'カイフグンカイヨウチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('97051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県海部郡海陽町四方原', '36', '36388', '7750202', '徳島県', 'トクシマケン', '海部郡海陽町', 'カイフグンカイヨウチョウ', '四方原', 'シホウハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県海部郡海陽町大里', '36', '36388', '7750203', '徳島県', 'トクシマケン', '海部郡海陽町', 'カイフグンカイヨウチョウ', '大里', 'オオザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県海部郡海陽町多良', '36', '36388', '7750204', '徳島県', 'トクシマケン', '海部郡海陽町', 'カイフグンカイヨウチョウ', '多良', 'タラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県海部郡海陽町吉野', '36', '36388', '7750205', '徳島県', 'トクシマケン', '海部郡海陽町', 'カイフグンカイヨウチョウ', '吉野', 'ヨシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県海部郡海陽町熟田', '36', '36388', '7750206', '徳島県', 'トクシマケン', '海部郡海陽町', 'カイフグンカイヨウチョウ', '熟田', 'ズクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県海部郡海陽町鞆浦', '36', '36388', '7750301', '徳島県', 'トクシマケン', '海部郡海陽町', 'カイフグンカイヨウチョウ', '鞆浦', 'トモウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県海部郡海陽町奥浦', '36', '36388', '7750302', '徳島県', 'トクシマケン', '海部郡海陽町', 'カイフグンカイヨウチョウ', '奥浦', 'オクウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県海部郡海陽町高園', '36', '36388', '7750303', '徳島県', 'トクシマケン', '海部郡海陽町', 'カイフグンカイヨウチョウ', '高園', 'タカゾノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県海部郡海陽町野江', '36', '36388', '7750304', '徳島県', 'トクシマケン', '海部郡海陽町', 'カイフグンカイヨウチョウ', '野江', 'ノエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県海部郡海陽町中山', '36', '36388', '7750305', '徳島県', 'トクシマケン', '海部郡海陽町', 'カイフグンカイヨウチョウ', '中山', 'ナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県海部郡海陽町櫛川', '36', '36388', '7750306', '徳島県', 'トクシマケン', '海部郡海陽町', 'カイフグンカイヨウチョウ', '櫛川', 'クシカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県海部郡海陽町芝', '36', '36388', '7750307', '徳島県', 'トクシマケン', '海部郡海陽町', 'カイフグンカイヨウチョウ', '芝', 'シバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県海部郡海陽町吉田', '36', '36388', '7750308', '徳島県', 'トクシマケン', '海部郡海陽町', 'カイフグンカイヨウチョウ', '吉田', 'ヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県海部郡海陽町富田', '36', '36388', '7750309', '徳島県', 'トクシマケン', '海部郡海陽町', 'カイフグンカイヨウチョウ', '富田', 'トミダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県海部郡海陽町大井', '36', '36388', '7750310', '徳島県', 'トクシマケン', '海部郡海陽町', 'カイフグンカイヨウチョウ', '大井', 'オオイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県海部郡海陽町平井', '36', '36388', '7750411', '徳島県', 'トクシマケン', '海部郡海陽町', 'カイフグンカイヨウチョウ', '平井', 'ヒライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県海部郡海陽町小川', '36', '36388', '7750412', '徳島県', 'トクシマケン', '海部郡海陽町', 'カイフグンカイヨウチョウ', '小川', 'オガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県海部郡海陽町神野', '36', '36388', '7750413', '徳島県', 'トクシマケン', '海部郡海陽町', 'カイフグンカイヨウチョウ', '神野', 'コウノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県海部郡海陽町若松', '36', '36388', '7750414', '徳島県', 'トクシマケン', '海部郡海陽町', 'カイフグンカイヨウチョウ', '若松', 'ワカマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県海部郡海陽町相川', '36', '36388', '7750415', '徳島県', 'トクシマケン', '海部郡海陽町', 'カイフグンカイヨウチョウ', '相川', 'アイカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県海部郡海陽町宍喰浦', '36', '36388', '7750501', '徳島県', 'トクシマケン', '海部郡海陽町', 'カイフグンカイヨウチョウ', '宍喰浦', 'シシクイウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県海部郡海陽町久保', '36', '36388', '7750502', '徳島県', 'トクシマケン', '海部郡海陽町', 'カイフグンカイヨウチョウ', '久保', 'クボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県海部郡海陽町日比原', '36', '36388', '7750503', '徳島県', 'トクシマケン', '海部郡海陽町', 'カイフグンカイヨウチョウ', '日比原', 'ヒビハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県海部郡海陽町尾崎', '36', '36388', '7750504', '徳島県', 'トクシマケン', '海部郡海陽町', 'カイフグンカイヨウチョウ', '尾崎', 'オサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県海部郡海陽町芥附', '36', '36388', '7750505', '徳島県', 'トクシマケン', '海部郡海陽町', 'カイフグンカイヨウチョウ', '芥附', 'クグツケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県海部郡海陽町角坂', '36', '36388', '7750506', '徳島県', 'トクシマケン', '海部郡海陽町', 'カイフグンカイヨウチョウ', '角坂', 'カクサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県海部郡海陽町広岡', '36', '36388', '7750507', '徳島県', 'トクシマケン', '海部郡海陽町', 'カイフグンカイヨウチョウ', '広岡', 'ヒロオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県海部郡海陽町小谷', '36', '36388', '7750508', '徳島県', 'トクシマケン', '海部郡海陽町', 'カイフグンカイヨウチョウ', '小谷', 'コダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県海部郡海陽町塩深', '36', '36388', '7750509', '徳島県', 'トクシマケン', '海部郡海陽町', 'カイフグンカイヨウチョウ', '塩深', 'シオフカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県海部郡海陽町船津', '36', '36388', '7750510', '徳島県', 'トクシマケン', '海部郡海陽町', 'カイフグンカイヨウチョウ', '船津', 'フナツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県海部郡海陽町久尾', '36', '36388', '7750511', '徳島県', 'トクシマケン', '海部郡海陽町', 'カイフグンカイヨウチョウ', '久尾', 'クオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県海部郡海陽町宍喰浦那佐', '36', '36388', '7750512', '徳島県', 'トクシマケン', '海部郡海陽町', 'カイフグンカイヨウチョウ', '宍喰浦', 'シシクイウラ', null, null, '那佐', 'ナサ');
INSERT INTO `ms_addresses` VALUES ('97085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県海部郡海陽町宍喰浦竹ケ島', '36', '36388', '7750513', '徳島県', 'トクシマケン', '海部郡海陽町', 'カイフグンカイヨウチョウ', '宍喰浦', 'シシクイウラ', null, null, '竹ケ島', 'タケガシマ');
INSERT INTO `ms_addresses` VALUES ('97088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市', '36', '36205', '7760000', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('97089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市鴨島町牛島', '36', '36205', '7760001', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '鴨島町牛島', 'カモジマチョウウシシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市鴨島町麻植塚', '36', '36205', '7760002', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '鴨島町麻植塚', 'カモジマチョウオエヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市鴨島町内原', '36', '36205', '7760003', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '鴨島町内原', 'カモジマチョウウチバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市鴨島町中島', '36', '36205', '7760004', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '鴨島町中島', 'カモジマチョウナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市鴨島町喜来', '36', '36205', '7760005', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '鴨島町喜来', 'カモジマチョウキライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市鴨島町喜来甲', '36', '36205', '7760006', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '鴨島町喜来甲', 'カモジマチョウキライコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市鴨島町喜来乙', '36', '36205', '7760007', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '鴨島町喜来乙', 'カモジマチョウキライオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市鴨島町鴨島', '36', '36205', '7760010', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '鴨島町鴨島', 'カモジマチョウカモジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市鴨島町鴨島甲', '36', '36205', '7760011', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '鴨島町鴨島甲', 'カモジマチョウカモジマコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市鴨島町鴨島乙', '36', '36205', '7760012', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '鴨島町鴨島乙', 'カモジマチョウカモジマオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市鴨島町上下島', '36', '36205', '7760013', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '鴨島町上下島', 'カモジマチョウジョウゲジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市鴨島町知恵島', '36', '36205', '7760014', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '鴨島町知恵島', 'カモジマチョウチエジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市鴨島町粟島', '36', '36205', '7760015', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '鴨島町粟島', 'カモジマチョウアワジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市鴨島町西麻植', '36', '36205', '7760020', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '鴨島町西麻植', 'カモジマチョウニシオエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市鴨島町敷地', '36', '36205', '7760031', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '鴨島町敷地', 'カモジマチョウシキジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市鴨島町樋山地', '36', '36205', '7760032', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '鴨島町樋山地', 'カモジマチョウヒヤマジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市鴨島町飯尾', '36', '36205', '7760033', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '鴨島町飯尾', 'カモジマチョウイノオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市鴨島町呉郷団地', '36', '36205', '7760034', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '鴨島町呉郷団地', 'カモジマチョウゴキョウダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市鴨島町森藤', '36', '36205', '7760035', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '鴨島町森藤', 'カモジマチョウモリトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市鴨島町山路', '36', '36205', '7760036', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '鴨島町山路', 'カモジマチョウサンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市鴨島町上浦', '36', '36205', '7760037', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '鴨島町上浦', 'カモジマチョウカミウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市穴吹町三島小島', '36', '36207', '7770001', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '穴吹町三島', 'アナブキチョウミシマ', null, null, '小島', 'オシマ');
INSERT INTO `ms_addresses` VALUES ('97119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市穴吹町三島舞中島', '36', '36207', '7770002', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '穴吹町三島', 'アナブキチョウミシマ', null, null, '舞中島', 'マイナカシマ');
INSERT INTO `ms_addresses` VALUES ('97120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市穴吹町三島三谷', '36', '36207', '7770003', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '穴吹町三島', 'アナブキチョウミシマ', null, null, '三谷', 'ミタニ');
INSERT INTO `ms_addresses` VALUES ('97121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市穴吹町三島大重', '36', '36207', '7770004', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '穴吹町三島', 'アナブキチョウミシマ', null, null, '大重', 'オオシゲ');
INSERT INTO `ms_addresses` VALUES ('97122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市穴吹町穴吹', '36', '36207', '7770005', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '穴吹町穴吹', 'アナブキチョウアナブキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市穴吹町口山', '36', '36207', '7770006', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '穴吹町口山', 'アナブキチョウクチヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市穴吹町古宮', '36', '36207', '7770007', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '穴吹町古宮', 'アナブキチョウフルミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市木屋平市初', '36', '36207', '7770301', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '木屋平', 'コヤダイラ', null, null, '市初', 'イチハナ');
INSERT INTO `ms_addresses` VALUES ('97126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市木屋平今丸', '36', '36207', '7770301', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '木屋平', 'コヤダイラ', null, null, '今丸', 'イママル');
INSERT INTO `ms_addresses` VALUES ('97127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市木屋平尾山', '36', '36207', '7770301', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '木屋平', 'コヤダイラ', null, null, '尾山', 'オヤマ');
INSERT INTO `ms_addresses` VALUES ('97128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市木屋平カゴミ', '36', '36207', '7770301', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '木屋平', 'コヤダイラ', null, null, 'カゴミ', 'カゴミ');
INSERT INTO `ms_addresses` VALUES ('97129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市木屋平樫原', '36', '36207', '7770301', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '木屋平', 'コヤダイラ', null, null, '樫原', 'カシワラ');
INSERT INTO `ms_addresses` VALUES ('97130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市木屋平木中', '36', '36207', '7770301', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '木屋平', 'コヤダイラ', null, null, '木中', 'キナカ');
INSERT INTO `ms_addresses` VALUES ('97131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市木屋平桑柄', '36', '36207', '7770301', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '木屋平', 'コヤダイラ', null, null, '桑柄', 'クワガラ');
INSERT INTO `ms_addresses` VALUES ('97132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市木屋平ケヤキヒラ', '36', '36207', '7770301', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '木屋平', 'コヤダイラ', null, null, 'ケヤキヒラ', 'ケヤキヒラ');
INSERT INTO `ms_addresses` VALUES ('97133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市木屋平小日浦', '36', '36207', '7770301', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '木屋平', 'コヤダイラ', null, null, '小日浦', 'コビウラ');
INSERT INTO `ms_addresses` VALUES ('97134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市木屋平地神滝', '36', '36207', '7770301', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '木屋平', 'コヤダイラ', null, null, '地神滝', 'ジジンダキ');
INSERT INTO `ms_addresses` VALUES ('97135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市木屋平菅蔵', '36', '36207', '7770301', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '木屋平', 'コヤダイラ', null, null, '菅蔵', 'スゲゾウ');
INSERT INTO `ms_addresses` VALUES ('97136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市木屋平杖谷', '36', '36207', '7770301', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '木屋平', 'コヤダイラ', null, null, '杖谷', 'ツエダニ');
INSERT INTO `ms_addresses` VALUES ('97137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市木屋平葛尾', '36', '36207', '7770301', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '木屋平', 'コヤダイラ', null, null, '葛尾', 'ツヅロウ');
INSERT INTO `ms_addresses` VALUES ('97138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市木屋平ハジコノ', '36', '36207', '7770301', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '木屋平', 'コヤダイラ', null, null, 'ハジコノ', 'ハジコノ');
INSERT INTO `ms_addresses` VALUES ('97139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市木屋平ビヤガイチ', '36', '36207', '7770301', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '木屋平', 'コヤダイラ', null, null, 'ビヤガイチ', 'ビヤガイチ');
INSERT INTO `ms_addresses` VALUES ('97140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市木屋平二戸', '36', '36207', '7770301', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '木屋平', 'コヤダイラ', null, null, '二戸', 'フタド');
INSERT INTO `ms_addresses` VALUES ('97141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市木屋平三ツ木', '36', '36207', '7770301', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '木屋平', 'コヤダイラ', null, null, '三ツ木', 'ミツギ');
INSERT INTO `ms_addresses` VALUES ('97142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市木屋平貢', '36', '36207', '7770301', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '木屋平', 'コヤダイラ', null, null, '貢', 'ミツグ');
INSERT INTO `ms_addresses` VALUES ('97143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市木屋平南張', '36', '36207', '7770301', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '木屋平', 'コヤダイラ', null, null, '南張', 'ミナミバリ');
INSERT INTO `ms_addresses` VALUES ('97144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市木屋平向樫原', '36', '36207', '7770301', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '木屋平', 'コヤダイラ', null, null, '向樫原', 'ムコウカシワラ');
INSERT INTO `ms_addresses` VALUES ('97145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市木屋平麻衣', '36', '36207', '7770302', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '木屋平', 'コヤダイラ', null, null, '麻衣', 'アサギヌ');
INSERT INTO `ms_addresses` VALUES ('97146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市木屋平大北', '36', '36207', '7770302', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '木屋平', 'コヤダイラ', null, null, '大北', 'オオキタ');
INSERT INTO `ms_addresses` VALUES ('97147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市木屋平川井', '36', '36207', '7770302', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '木屋平', 'コヤダイラ', null, null, '川井', 'カワイ');
INSERT INTO `ms_addresses` VALUES ('97148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市木屋平下名', '36', '36207', '7770302', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '木屋平', 'コヤダイラ', null, null, '下名', 'シモミョウ');
INSERT INTO `ms_addresses` VALUES ('97149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市木屋平竹尾', '36', '36207', '7770302', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '木屋平', 'コヤダイラ', null, null, '竹尾', 'タケオ');
INSERT INTO `ms_addresses` VALUES ('97150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市木屋平櫟木', '36', '36207', '7770302', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '木屋平', 'コヤダイラ', null, null, '櫟木', 'チチノギ');
INSERT INTO `ms_addresses` VALUES ('97151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市木屋平川上', '36', '36207', '7770303', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '木屋平', 'コヤダイラ', null, null, '川上', 'カワカミ');
INSERT INTO `ms_addresses` VALUES ('97152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市木屋平川上カケ', '36', '36207', '7770303', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '木屋平', 'コヤダイラ', null, null, '川上カケ', 'カワカミカケ');
INSERT INTO `ms_addresses` VALUES ('97153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市木屋平太合', '36', '36207', '7770303', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '木屋平', 'コヤダイラ', null, null, '太合', 'タイゴウ');
INSERT INTO `ms_addresses` VALUES ('97154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市木屋平太合カケ', '36', '36207', '7770303', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '木屋平', 'コヤダイラ', null, null, '太合カケ', 'タイゴウカケ');
INSERT INTO `ms_addresses` VALUES ('97155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市木屋平谷口', '36', '36207', '7770303', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '木屋平', 'コヤダイラ', null, null, '谷口', 'タニグチ');
INSERT INTO `ms_addresses` VALUES ('97156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市木屋平谷口カケ', '36', '36207', '7770303', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '木屋平', 'コヤダイラ', null, null, '谷口カケ', 'タニグチカケ');
INSERT INTO `ms_addresses` VALUES ('97157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市木屋平森遠', '36', '36207', '7770303', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '木屋平', 'コヤダイラ', null, null, '森遠', 'モリトオ');
INSERT INTO `ms_addresses` VALUES ('97158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市木屋平八幡', '36', '36207', '7770303', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '木屋平', 'コヤダイラ', null, null, '八幡', 'ヤワタ');
INSERT INTO `ms_addresses` VALUES ('97159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市木屋平弓道', '36', '36207', '7770303', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '木屋平', 'コヤダイラ', null, null, '弓道', 'ユドウ');
INSERT INTO `ms_addresses` VALUES ('97161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市', '36', '36208', '7780000', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('97162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市池田町ウエノ', '36', '36208', '7780001', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '池田町ウエノ', 'イケダチョウウエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市池田町マチ', '36', '36208', '7780002', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '池田町マチ', 'イケダチョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市池田町サラダ', '36', '36208', '7780003', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '池田町サラダ', 'イケダチョウサラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市池田町シンマチ', '36', '36208', '7780004', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '池田町シンマチ', 'イケダチョウシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市池田町シマ', '36', '36208', '7780005', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '池田町シマ', 'イケダチョウシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市池田町トウゲ', '36', '36208', '7780006', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '池田町トウゲ', 'イケダチョウトウゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市池田町ヤマダ', '36', '36208', '7780007', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '池田町ヤマダ', 'イケダチョウヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市池田町クヤウジ', '36', '36208', '7780008', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '池田町クヤウジ', 'イケダチョウクヤウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市池田町ヤサン', '36', '36208', '7780009', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '池田町ヤサン', 'イケダチョウヤサン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市池田町ウエマツ', '36', '36208', '7780010', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '池田町ウエマツ', 'イケダチョウウエマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市池田町ハヤシ', '36', '36208', '7780011', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '池田町ハヤシ', 'イケダチョウハヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市池田町イケミナミ', '36', '36208', '7780012', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '池田町イケミナミ', 'イケダチョウイケミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市池田町シンヤマ', '36', '36208', '7780013', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '池田町シンヤマ', 'イケダチョウシンヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市池田町イタノ', '36', '36208', '7780014', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '池田町イタノ', 'イケダチョウイタノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市池田町州津', '36', '36208', '7780020', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '池田町州津', 'イケダチョウシュウヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市池田町西山上久保', '36', '36208', '7780031', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '池田町西山', 'イケダチョウニシヤマ', null, null, '上久保', 'ウワクボ');
INSERT INTO `ms_addresses` VALUES ('97178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市池田町西山落', '36', '36208', '7780031', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '池田町西山', 'イケダチョウニシヤマ', null, null, '落', 'オチ');
INSERT INTO `ms_addresses` VALUES ('97179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市池田町西山上中尾', '36', '36208', '7780031', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '池田町西山', 'イケダチョウニシヤマ', null, null, '上中尾', 'カミナカオ');
INSERT INTO `ms_addresses` VALUES ('97180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市池田町西山谷浦', '36', '36208', '7780031', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '池田町西山', 'イケダチョウニシヤマ', null, null, '谷浦', 'タニウラ');
INSERT INTO `ms_addresses` VALUES ('97181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市池田町西山津寺', '36', '36208', '7780031', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '池田町西山', 'イケダチョウニシヤマ', null, null, '津寺', 'ツデラ');
INSERT INTO `ms_addresses` VALUES ('97182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市池田町西山坪尻', '36', '36208', '7780031', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '池田町西山', 'イケダチョウニシヤマ', null, null, '坪尻', 'ツボジリ');
INSERT INTO `ms_addresses` VALUES ('97183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市池田町西山中尾', '36', '36208', '7780031', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '池田町西山', 'イケダチョウニシヤマ', null, null, '中尾', 'ナカオ');
INSERT INTO `ms_addresses` VALUES ('97184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市池田町西山西ノ岡', '36', '36208', '7780031', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '池田町西山', 'イケダチョウニシヤマ', null, null, '西ノ岡', 'ニシノオカ');
INSERT INTO `ms_addresses` VALUES ('97185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市池田町西山船原', '36', '36208', '7780031', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '池田町西山', 'イケダチョウニシヤマ', null, null, '船原', 'フナバラ');
INSERT INTO `ms_addresses` VALUES ('97186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市池田町西山横佐古', '36', '36208', '7780031', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '池田町西山', 'イケダチョウニシヤマ', null, null, '横佐古', 'ヨコサコ');
INSERT INTO `ms_addresses` VALUES ('97187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市池田町西山蔭', '36', '36208', '7780032', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '池田町西山', 'イケダチョウニシヤマ', null, null, '蔭', 'カゲ');
INSERT INTO `ms_addresses` VALUES ('97188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市池田町西山樫ノ下', '36', '36208', '7780032', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '池田町西山', 'イケダチョウニシヤマ', null, null, '樫ノ下', 'カシノシタ');
INSERT INTO `ms_addresses` VALUES ('97189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市池田町西山岸ノ上', '36', '36208', '7780032', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '池田町西山', 'イケダチョウニシヤマ', null, null, '岸ノ上', 'キシノウエ');
INSERT INTO `ms_addresses` VALUES ('97190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市池田町西山込野', '36', '36208', '7780032', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '池田町西山', 'イケダチョウニシヤマ', null, null, '込野', 'コミノ');
INSERT INTO `ms_addresses` VALUES ('97191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市池田町西山下ノ浦', '36', '36208', '7780032', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '池田町西山', 'イケダチョウニシヤマ', null, null, '下ノ浦', 'シモノウラ');
INSERT INTO `ms_addresses` VALUES ('97192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市池田町西山乳ノ木', '36', '36208', '7780032', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '池田町西山', 'イケダチョウニシヤマ', null, null, '乳ノ木', 'チチノキ');
INSERT INTO `ms_addresses` VALUES ('97193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市池田町西山乳ノ木道北', '36', '36208', '7780032', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '池田町西山', 'イケダチョウニシヤマ', null, null, '乳ノ木道北', 'チチノキミチキタ');
INSERT INTO `ms_addresses` VALUES ('97194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市池田町西山中塚', '36', '36208', '7780032', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '池田町西山', 'イケダチョウニシヤマ', null, null, '中塚', 'ナカツカ');
INSERT INTO `ms_addresses` VALUES ('97195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市池田町西山西谷', '36', '36208', '7780032', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '池田町西山', 'イケダチョウニシヤマ', null, null, '西谷', 'ニシタニ');
INSERT INTO `ms_addresses` VALUES ('97196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市池田町西山登リ尾', '36', '36208', '7780032', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '池田町西山', 'イケダチョウニシヤマ', null, null, '登リ尾', 'ノボリオ');
INSERT INTO `ms_addresses` VALUES ('97197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市池田町西山宮ノ西', '36', '36208', '7780032', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '池田町西山', 'イケダチョウニシヤマ', null, null, '宮ノ西', 'ミヤノニシ');
INSERT INTO `ms_addresses` VALUES ('97198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市池田町西山宮ノ東', '36', '36208', '7780032', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '池田町西山', 'イケダチョウニシヤマ', null, null, '宮ノ東', 'ミヤノヒガシ');
INSERT INTO `ms_addresses` VALUES ('97199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市池田町西山', '36', '36208', '7780040', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '池田町西山', 'イケダチョウニシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市西祖谷山村一宇', '36', '36208', '7780101', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '西祖谷山村一宇', 'ニシイヤヤマムライチウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市西祖谷山村尾井ノ内', '36', '36208', '7780101', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '西祖谷山村尾井ノ内', 'ニシイヤヤマムラオイノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市西祖谷山村重末', '36', '36208', '7780101', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '西祖谷山村重末', 'ニシイヤヤマムラシゲスエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市西祖谷山村田ノ内', '36', '36208', '7780101', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '西祖谷山村田ノ内', 'ニシイヤヤマムラタノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市西祖谷山村戸ノ谷', '36', '36208', '7780101', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '西祖谷山村戸ノ谷', 'ニシイヤヤマムラトノタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市西祖谷山村眠谷', '36', '36208', '7780101', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '西祖谷山村眠谷', 'ニシイヤヤマムラネムリダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市西祖谷山村冥地', '36', '36208', '7780101', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '西祖谷山村冥地', 'ニシイヤヤマムラミョウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市西祖谷山村今久保', '36', '36208', '7780102', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '西祖谷山村今久保', 'ニシイヤヤマムライマクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市西祖谷山村閑定', '36', '36208', '7780102', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '西祖谷山村閑定', 'ニシイヤヤマムラカンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市西祖谷山村善徳', '36', '36208', '7780102', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '西祖谷山村善徳', 'ニシイヤヤマムラゼントク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市西祖谷山村中尾', '36', '36208', '7780102', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '西祖谷山村中尾', 'ニシイヤヤマムラナカオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市西祖谷山村有瀬', '36', '36208', '7780103', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '西祖谷山村有瀬', 'ニシイヤヤマムラアルセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市西祖谷山村吾橋', '36', '36208', '7780104', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '西祖谷山村吾橋', 'ニシイヤヤマムラアハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市西祖谷山村榎', '36', '36208', '7780104', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '西祖谷山村榎', 'ニシイヤヤマムラエノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市西祖谷山村上吾橋', '36', '36208', '7780104', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '西祖谷山村上吾橋', 'ニシイヤヤマムラカミアハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市西祖谷山村下吾橋', '36', '36208', '7780104', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '西祖谷山村下吾橋', 'ニシイヤヤマムラシモアハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市西祖谷山村土日浦', '36', '36208', '7780104', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '西祖谷山村土日浦', 'ニシイヤヤマムラツチヒウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市西祖谷山村東山', '36', '36208', '7780104', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '西祖谷山村東山', 'ニシイヤヤマムラヒガシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市西祖谷山村南山', '36', '36208', '7780104', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '西祖谷山村南山', 'ニシイヤヤマムラミナミヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市西祖谷山村後山', '36', '36208', '7780105', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '西祖谷山村後山', 'ニシイヤヤマムラウシロヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市西祖谷山村後山西', '36', '36208', '7780105', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '西祖谷山村後山西', 'ニシイヤヤマムラウシロヤマニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市西祖谷山村後山向', '36', '36208', '7780105', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '西祖谷山村後山向', 'ニシイヤヤマムラウシロヤマムカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市西祖谷山村徳善', '36', '36208', '7780105', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '西祖谷山村徳善', 'ニシイヤヤマムラトクゼン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市西祖谷山村徳善北', '36', '36208', '7780105', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '西祖谷山村徳善北', 'ニシイヤヤマムラトクゼンキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市西祖谷山村徳善西', '36', '36208', '7780105', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '西祖谷山村徳善西', 'ニシイヤヤマムラトクゼンニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市西祖谷山村西岡', '36', '36208', '7780105', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '西祖谷山村西岡', 'ニシイヤヤマムラニシオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市西祖谷山村東西岡', '36', '36208', '7780105', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '西祖谷山村東西岡', 'ニシイヤヤマムラヒガシニシオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市池田町松尾', '36', '36208', '7780165', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '池田町松尾', 'イケダチョウマツオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市池田町松尾祖谷温泉', '36', '36208', '7780165', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '池田町松尾', 'イケダチョウマツオ', null, null, '祖谷温泉', 'イヤオンセン');
INSERT INTO `ms_addresses` VALUES ('97230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市東祖谷菅生', '36', '36208', '7780201', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '東祖谷菅生', 'ヒガシイヤスゲオイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市東祖谷見ノ越', '36', '36208', '7780201', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '東祖谷見ノ越', 'ヒガシイヤミノコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市東祖谷落合', '36', '36208', '7780202', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '東祖谷落合', 'ヒガシイヤオチアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市東祖谷久保', '36', '36208', '7780202', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '東祖谷久保', 'ヒガシイヤクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市東祖谷奥の井', '36', '36208', '7780203', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '東祖谷奥の井', 'ヒガシイヤオクノイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市東祖谷釜ケ谷', '36', '36208', '7780203', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '東祖谷釜ケ谷', 'ヒガシイヤカマガタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市東祖谷九鬼', '36', '36208', '7780203', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '東祖谷九鬼', 'ヒガシイヤクキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市東祖谷栗枝渡', '36', '36208', '7780203', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '東祖谷栗枝渡', 'ヒガシイヤクリスド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市東祖谷下瀬', '36', '36208', '7780203', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '東祖谷下瀬', 'ヒガシイヤシモセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市東祖谷中上', '36', '36208', '7780203', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '東祖谷中上', 'ヒガシイヤナカウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市東祖谷西山', '36', '36208', '7780203', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '東祖谷西山', 'ヒガシイヤニシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市東祖谷林', '36', '36208', '7780203', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '東祖谷林', 'ヒガシイヤハヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市東祖谷大枝', '36', '36208', '7780204', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '東祖谷大枝', 'ヒガシイヤオオエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市東祖谷大西', '36', '36208', '7780204', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '東祖谷大西', 'ヒガシイヤオオニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市東祖谷京上', '36', '36208', '7780204', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '東祖谷京上', 'ヒガシイヤキョウジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市東祖谷若林', '36', '36208', '7780204', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '東祖谷若林', 'ヒガシイヤワカバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市東祖谷阿佐', '36', '36208', '7780205', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '東祖谷阿佐', 'ヒガシイヤアサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市東祖谷小川', '36', '36208', '7780205', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '東祖谷小川', 'ヒガシイヤオガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市東祖谷樫尾', '36', '36208', '7780205', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '東祖谷樫尾', 'ヒガシイヤカシオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市東祖谷古味', '36', '36208', '7780205', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '東祖谷古味', 'ヒガシイヤコミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市東祖谷新居屋', '36', '36208', '7780205', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '東祖谷新居屋', 'ヒガシイヤニイヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市東祖谷麦生土', '36', '36208', '7780205', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '東祖谷麦生土', 'ヒガシイヤムジュウト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市東祖谷元井', '36', '36208', '7780205', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '東祖谷元井', 'ヒガシイヤモットイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市東祖谷今井', '36', '36208', '7780206', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '東祖谷今井', 'ヒガシイヤイマイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市東祖谷小島', '36', '36208', '7780206', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '東祖谷小島', 'ヒガシイヤオシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市東祖谷佐野', '36', '36208', '7780206', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '東祖谷佐野', 'ヒガシイヤサノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市東祖谷高野', '36', '36208', '7780206', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '東祖谷高野', 'ヒガシイヤタカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市東祖谷釣井', '36', '36208', '7780206', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '東祖谷釣井', 'ヒガシイヤツルイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市東祖谷和田', '36', '36208', '7780206', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '東祖谷和田', 'ヒガシイヤワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市池田町白地', '36', '36208', '7785251', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '池田町白地', 'イケダチョウハクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市池田町馬路', '36', '36208', '7785252', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '池田町馬路', 'イケダチョウウマジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市池田町佐野', '36', '36208', '7785253', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '池田町佐野', 'イケダチョウサノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市山城町佐連ミネ畑', '36', '36208', '7785254', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '山城町佐連', 'ヤマシロチョウサレ', null, null, 'ミネ畑', 'ミネバタ');
INSERT INTO `ms_addresses` VALUES ('97277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡板野町', '36', '36404', '7790100', '徳島県', 'トクシマケン', '板野郡板野町', 'イタノグンイタノチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('97278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡板野町大坂', '36', '36404', '7790101', '徳島県', 'トクシマケン', '板野郡板野町', 'イタノグンイタノチョウ', '大坂', 'オオサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡板野町川端', '36', '36404', '7790102', '徳島県', 'トクシマケン', '板野郡板野町', 'イタノグンイタノチョウ', '川端', 'カワバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡板野町川端新田', '36', '36404', '7790103', '徳島県', 'トクシマケン', '板野郡板野町', 'イタノグンイタノチョウ', '川端', 'カワバタ', null, null, '新田', 'シンデン');
INSERT INTO `ms_addresses` VALUES ('97281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡板野町吹田', '36', '36404', '7790104', '徳島県', 'トクシマケン', '板野郡板野町', 'イタノグンイタノチョウ', '吹田', 'フキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡板野町大寺', '36', '36404', '7790105', '徳島県', 'トクシマケン', '板野郡板野町', 'イタノグンイタノチョウ', '大寺', 'オオテラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡板野町大寺岡ノ宮', '36', '36404', '7790106', '徳島県', 'トクシマケン', '板野郡板野町', 'イタノグンイタノチョウ', '大寺', 'オオテラ', null, null, '岡ノ宮', 'オカノミヤ');
INSERT INTO `ms_addresses` VALUES ('97284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡板野町古城', '36', '36404', '7790107', '徳島県', 'トクシマケン', '板野郡板野町', 'イタノグンイタノチョウ', '古城', 'フルシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡板野町犬伏', '36', '36404', '7790108', '徳島県', 'トクシマケン', '板野郡板野町', 'イタノグンイタノチョウ', '犬伏', 'イヌブシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡板野町那東', '36', '36404', '7790111', '徳島県', 'トクシマケン', '板野郡板野町', 'イタノグンイタノチョウ', '那東', 'ナトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡板野町松谷', '36', '36404', '7790112', '徳島県', 'トクシマケン', '板野郡板野町', 'イタノグンイタノチョウ', '松谷', 'マツダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡板野町黒谷', '36', '36404', '7790113', '徳島県', 'トクシマケン', '板野郡板野町', 'イタノグンイタノチョウ', '黒谷', 'クロダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡板野町羅漢', '36', '36404', '7790114', '徳島県', 'トクシマケン', '板野郡板野町', 'イタノグンイタノチョウ', '羅漢', 'ラカン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡板野町矢武', '36', '36404', '7790115', '徳島県', 'トクシマケン', '板野郡板野町', 'イタノグンイタノチョウ', '矢武', 'ヤタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡板野町唐園', '36', '36404', '7790116', '徳島県', 'トクシマケン', '板野郡板野町', 'イタノグンイタノチョウ', '唐園', 'トウノソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡板野町中久保', '36', '36404', '7790117', '徳島県', 'トクシマケン', '板野郡板野町', 'イタノグンイタノチョウ', '中久保', 'ナカクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡板野町下庄', '36', '36404', '7790118', '徳島県', 'トクシマケン', '板野郡板野町', 'イタノグンイタノチョウ', '下庄', 'シモノショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県板野郡板野町西中富', '36', '36404', '7790119', '徳島県', 'トクシマケン', '板野郡板野町', 'イタノグンイタノチョウ', '西中富', 'ニシナカトミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県鳴門市大麻町萩原', '36', '36202', '7790221', '徳島県', 'トクシマケン', '鳴門市', 'ナルトシ', '大麻町萩原', 'オオアサチョウハギワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県鳴門市大麻町三俣', '36', '36202', '7790222', '徳島県', 'トクシマケン', '鳴門市', 'ナルトシ', '大麻町三俣', 'オオアサチョウミツマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県鳴門市大麻町川崎', '36', '36202', '7790223', '徳島県', 'トクシマケン', '鳴門市', 'ナルトシ', '大麻町川崎', 'オオアサチョウカワサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県鳴門市大麻町津慈', '36', '36202', '7790224', '徳島県', 'トクシマケン', '鳴門市', 'ナルトシ', '大麻町津慈', 'オオアサチョウツジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県鳴門市大麻町檜', '36', '36202', '7790225', '徳島県', 'トクシマケン', '鳴門市', 'ナルトシ', '大麻町檜', 'オオアサチョウヒノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県鳴門市大麻町板東', '36', '36202', '7790230', '徳島県', 'トクシマケン', '鳴門市', 'ナルトシ', '大麻町板東', 'オオアサチョウバンドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県鳴門市大麻町板東大林', '36', '36202', '7790231', '徳島県', 'トクシマケン', '鳴門市', 'ナルトシ', '大麻町板東', 'オオアサチョウバンドウ', null, null, '大林', 'オオバヤシ');
INSERT INTO `ms_addresses` VALUES ('97306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県鳴門市大麻町板東辻見堂', '36', '36202', '7790232', '徳島県', 'トクシマケン', '鳴門市', 'ナルトシ', '大麻町板東', 'オオアサチョウバンドウ', null, null, '辻見堂', 'ツジミドウ');
INSERT INTO `ms_addresses` VALUES ('97307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県鳴門市大麻町板東宝蔵', '36', '36202', '7790233', '徳島県', 'トクシマケン', '鳴門市', 'ナルトシ', '大麻町板東', 'オオアサチョウバンドウ', null, null, '宝蔵', 'ホウゾウ');
INSERT INTO `ms_addresses` VALUES ('97308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県鳴門市大麻町板東采女', '36', '36202', '7790234', '徳島県', 'トクシマケン', '鳴門市', 'ナルトシ', '大麻町板東', 'オオアサチョウバンドウ', null, null, '采女', 'ウネメ');
INSERT INTO `ms_addresses` VALUES ('97309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県鳴門市大麻町板東永井', '36', '36202', '7790235', '徳島県', 'トクシマケン', '鳴門市', 'ナルトシ', '大麻町板東', 'オオアサチョウバンドウ', null, null, '永井', 'ナガイ');
INSERT INTO `ms_addresses` VALUES ('97310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県鳴門市大麻町板東西山田', '36', '36202', '7790236', '徳島県', 'トクシマケン', '鳴門市', 'ナルトシ', '大麻町板東', 'オオアサチョウバンドウ', null, null, '西山田', 'ニシヤマダ');
INSERT INTO `ms_addresses` VALUES ('97311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県鳴門市大麻町板東北条', '36', '36202', '7790237', '徳島県', 'トクシマケン', '鳴門市', 'ナルトシ', '大麻町板東', 'オオアサチョウバンドウ', null, null, '北条', 'ホウジョウ');
INSERT INTO `ms_addresses` VALUES ('97312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県鳴門市大麻町板東東山田', '36', '36202', '7790238', '徳島県', 'トクシマケン', '鳴門市', 'ナルトシ', '大麻町板東', 'オオアサチョウバンドウ', null, null, '東山田', 'ヒガシヤマダ');
INSERT INTO `ms_addresses` VALUES ('97313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県鳴門市大麻町姫田', '36', '36202', '7790301', '徳島県', 'トクシマケン', '鳴門市', 'ナルトシ', '大麻町姫田', 'オオアサチョウヒメダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県鳴門市大麻町大谷', '36', '36202', '7790302', '徳島県', 'トクシマケン', '鳴門市', 'ナルトシ', '大麻町大谷', 'オオアサチョウオオタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県鳴門市大麻町池谷', '36', '36202', '7790303', '徳島県', 'トクシマケン', '鳴門市', 'ナルトシ', '大麻町池谷', 'オオアサチョウイケノタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県鳴門市大麻町松村', '36', '36202', '7790304', '徳島県', 'トクシマケン', '鳴門市', 'ナルトシ', '大麻町松村', 'オオアサチョウマツムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県鳴門市大麻町高畑', '36', '36202', '7790305', '徳島県', 'トクシマケン', '鳴門市', 'ナルトシ', '大麻町高畑', 'オオアサチョウタカバタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県鳴門市大麻町牛屋島', '36', '36202', '7790311', '徳島県', 'トクシマケン', '鳴門市', 'ナルトシ', '大麻町牛屋島', 'オオアサチョウウシヤジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県鳴門市大麻町東馬詰', '36', '36202', '7790312', '徳島県', 'トクシマケン', '鳴門市', 'ナルトシ', '大麻町東馬詰', 'オオアサチョウヒガシウマヅメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県鳴門市大麻町中馬詰', '36', '36202', '7790313', '徳島県', 'トクシマケン', '鳴門市', 'ナルトシ', '大麻町中馬詰', 'オオアサチョウナカウマヅメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県鳴門市大麻町西馬詰', '36', '36202', '7790314', '徳島県', 'トクシマケン', '鳴門市', 'ナルトシ', '大麻町西馬詰', 'オオアサチョウニシウマヅメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県鳴門市大麻町市場', '36', '36202', '7790315', '徳島県', 'トクシマケン', '鳴門市', 'ナルトシ', '大麻町市場', 'オオアサチョウイチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿南市羽ノ浦町中庄', '36', '36204', '7791101', '徳島県', 'トクシマケン', '阿南市', 'アナンシ', '羽ノ浦町中庄', 'ハノウラチョウナカノショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿南市羽ノ浦町宮倉', '36', '36204', '7791102', '徳島県', 'トクシマケン', '阿南市', 'アナンシ', '羽ノ浦町宮倉', 'ハノウラチョウミヤグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿南市羽ノ浦町春日野', '36', '36204', '7791103', '徳島県', 'トクシマケン', '阿南市', 'アナンシ', '羽ノ浦町春日野', 'ハノウラチョウカスガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿南市羽ノ浦町西春日野', '36', '36204', '7791104', '徳島県', 'トクシマケン', '阿南市', 'アナンシ', '羽ノ浦町西春日野', 'ハノウラチョウニシカスガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿南市羽ノ浦町古庄', '36', '36204', '7791105', '徳島県', 'トクシマケン', '阿南市', 'アナンシ', '羽ノ浦町古庄', 'ハノウラチョウフルショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿南市羽ノ浦町岩脇', '36', '36204', '7791106', '徳島県', 'トクシマケン', '阿南市', 'アナンシ', '羽ノ浦町岩脇', 'ハノウラチョウイワワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿南市羽ノ浦町岩脇奥ノ谷', '36', '36204', '7791107', '徳島県', 'トクシマケン', '阿南市', 'アナンシ', '羽ノ浦町岩脇', 'ハノウラチョウイワワキ', null, null, '奥ノ谷', 'オクノタニ');
INSERT INTO `ms_addresses` VALUES ('97330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿南市羽ノ浦町明見', '36', '36204', '7791108', '徳島県', 'トクシマケン', '阿南市', 'アナンシ', '羽ノ浦町明見', 'ハノウラチョウミョウケン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿南市羽ノ浦町古毛', '36', '36204', '7791109', '徳島県', 'トクシマケン', '阿南市', 'アナンシ', '羽ノ浦町古毛', 'ハノウラチョウコモウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿南市那賀川町江野島', '36', '36204', '7791111', '徳島県', 'トクシマケン', '阿南市', 'アナンシ', '那賀川町江野島', 'ナカガワチョウエノシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿南市那賀川町色ケ島', '36', '36204', '7791112', '徳島県', 'トクシマケン', '阿南市', 'アナンシ', '那賀川町色ケ島', 'ナカガワチョウイロガシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿南市那賀川町芳崎', '36', '36204', '7791113', '徳島県', 'トクシマケン', '阿南市', 'アナンシ', '那賀川町芳崎', 'ナカガワチョウホウザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿南市那賀川町今津浦', '36', '36204', '7791114', '徳島県', 'トクシマケン', '阿南市', 'アナンシ', '那賀川町今津浦', 'ナカガワチョウイマヅウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿南市那賀川町敷地', '36', '36204', '7791115', '徳島県', 'トクシマケン', '阿南市', 'アナンシ', '那賀川町敷地', 'ナカガワチョウシキジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿南市那賀川町小延', '36', '36204', '7791116', '徳島県', 'トクシマケン', '阿南市', 'アナンシ', '那賀川町小延', 'ナカガワチョウコノブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿南市那賀川町島尻', '36', '36204', '7791117', '徳島県', 'トクシマケン', '阿南市', 'アナンシ', '那賀川町島尻', 'ナカガワチョウシマジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿南市那賀川町豊香野', '36', '36204', '7791118', '徳島県', 'トクシマケン', '阿南市', 'アナンシ', '那賀川町豊香野', 'ナカガワチョウユタカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿南市那賀川町日向', '36', '36204', '7791119', '徳島県', 'トクシマケン', '阿南市', 'アナンシ', '那賀川町日向', 'ナカガワチョウヒナタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿南市那賀川町黒地', '36', '36204', '7791121', '徳島県', 'トクシマケン', '阿南市', 'アナンシ', '那賀川町黒地', 'ナカガワチョウクロジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿南市那賀川町八幡', '36', '36204', '7791122', '徳島県', 'トクシマケン', '阿南市', 'アナンシ', '那賀川町八幡', 'ナカガワチョウヤワタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿南市那賀川町手島', '36', '36204', '7791123', '徳島県', 'トクシマケン', '阿南市', 'アナンシ', '那賀川町手島', 'ナカガワチョウテシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿南市那賀川町原', '36', '36204', '7791231', '徳島県', 'トクシマケン', '阿南市', 'アナンシ', '那賀川町原', 'ナカガワチョウハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿南市那賀川町西原', '36', '36204', '7791232', '徳島県', 'トクシマケン', '阿南市', 'アナンシ', '那賀川町西原', 'ナカガワチョウニシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿南市那賀川町大京原', '36', '36204', '7791233', '徳島県', 'トクシマケン', '阿南市', 'アナンシ', '那賀川町大京原', 'ナカガワチョウダイキョウバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿南市那賀川町古津', '36', '36204', '7791234', '徳島県', 'トクシマケン', '阿南市', 'アナンシ', '那賀川町古津', 'ナカガワチョウフルツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿南市那賀川町苅屋', '36', '36204', '7791235', '徳島県', 'トクシマケン', '阿南市', 'アナンシ', '那賀川町苅屋', 'ナカガワチョウカリヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿南市那賀川町工地', '36', '36204', '7791236', '徳島県', 'トクシマケン', '阿南市', 'アナンシ', '那賀川町工地', 'ナカガワチョウタクムジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿南市那賀川町三栗', '36', '36204', '7791241', '徳島県', 'トクシマケン', '阿南市', 'アナンシ', '那賀川町三栗', 'ナカガワチョウミグリュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿南市那賀川町赤池', '36', '36204', '7791242', '徳島県', 'トクシマケン', '阿南市', 'アナンシ', '那賀川町赤池', 'ナカガワチョウアカイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿南市那賀川町上福井', '36', '36204', '7791243', '徳島県', 'トクシマケン', '阿南市', 'アナンシ', '那賀川町上福井', 'ナカガワチョウカミフクイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿南市那賀川町みどり台', '36', '36204', '7791244', '徳島県', 'トクシマケン', '阿南市', 'アナンシ', '那賀川町みどり台', 'ナカガワチョウミドリダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿南市那賀川町中島', '36', '36204', '7791245', '徳島県', 'トクシマケン', '阿南市', 'アナンシ', '那賀川町中島', 'ナカガワチョウナカシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿南市那賀川町北中島', '36', '36204', '7791246', '徳島県', 'トクシマケン', '阿南市', 'アナンシ', '那賀川町北中島', 'ナカガワチョウキタナカシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿南市内原町', '36', '36204', '7791401', '徳島県', 'トクシマケン', '阿南市', 'アナンシ', '内原町', 'ウチワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿南市桑野町', '36', '36204', '7791402', '徳島県', 'トクシマケン', '阿南市', 'アナンシ', '桑野町', 'クワノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿南市山口町', '36', '36204', '7791403', '徳島県', 'トクシマケン', '阿南市', 'アナンシ', '山口町', 'ヤマグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿南市阿瀬比町', '36', '36204', '7791404', '徳島県', 'トクシマケン', '阿南市', 'アナンシ', '阿瀬比町', 'アセビチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿南市新野町', '36', '36204', '7791510', '徳島県', 'トクシマケン', '阿南市', 'アナンシ', '新野町', 'アラタノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿南市福井町', '36', '36204', '7791620', '徳島県', 'トクシマケン', '阿南市', 'アナンシ', '福井町', 'フクイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿南市橘町タテアジロ', '36', '36204', '7791630', '徳島県', 'トクシマケン', '阿南市', 'アナンシ', '橘町', 'タチバナチョウ', null, null, 'タテアジロ', 'タテアジロ');
INSERT INTO `ms_addresses` VALUES ('97368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿南市橘町袴', '36', '36204', '7791630', '徳島県', 'トクシマケン', '阿南市', 'アナンシ', '橘町', 'タチバナチョウ', null, null, '袴', 'ハカマ');
INSERT INTO `ms_addresses` VALUES ('97369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿南市橘町袴傍示', '36', '36204', '7791630', '徳島県', 'トクシマケン', '阿南市', 'アナンシ', '橘町', 'タチバナチョウ', null, null, '袴傍示', 'ハカマホウジ');
INSERT INTO `ms_addresses` VALUES ('97370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿南市橘町棒面', '36', '36204', '7791630', '徳島県', 'トクシマケン', '阿南市', 'アナンシ', '橘町', 'タチバナチョウ', null, null, '棒面', 'ボウメン');
INSERT INTO `ms_addresses` VALUES ('97371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿南市橘町小勝', '36', '36204', '7791631', '徳島県', 'トクシマケン', '阿南市', 'アナンシ', '橘町', 'タチバナチョウ', null, null, '小勝', 'コカツ');
INSERT INTO `ms_addresses` VALUES ('97372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿南市椿泊町', '36', '36204', '7791740', '徳島県', 'トクシマケン', '阿南市', 'アナンシ', '椿泊町', 'ツバキドマリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県阿南市椿町', '36', '36204', '7791750', '徳島県', 'トクシマケン', '阿南市', 'アナンシ', '椿町', 'ツバキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県海部郡美波町西由岐', '36', '36387', '7792101', '徳島県', 'トクシマケン', '海部郡美波町', 'カイフグンミナミチョウ', '西由岐', 'ニシユキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県海部郡美波町港町', '36', '36387', '7792102', '徳島県', 'トクシマケン', '海部郡美波町', 'カイフグンミナミチョウ', '港町', 'ミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県海部郡美波町西の地', '36', '36387', '7792103', '徳島県', 'トクシマケン', '海部郡美波町', 'カイフグンミナミチョウ', '西の地', 'ニシノジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県海部郡美波町東由岐', '36', '36387', '7792104', '徳島県', 'トクシマケン', '海部郡美波町', 'カイフグンミナミチョウ', '東由岐', 'ヒガシユキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県海部郡美波町志和岐', '36', '36387', '7792105', '徳島県', 'トクシマケン', '海部郡美波町', 'カイフグンミナミチョウ', '志和岐', 'シワギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県海部郡美波町阿部', '36', '36387', '7792106', '徳島県', 'トクシマケン', '海部郡美波町', 'カイフグンミナミチョウ', '阿部', 'アブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県海部郡美波町伊座利', '36', '36387', '7792107', '徳島県', 'トクシマケン', '海部郡美波町', 'カイフグンミナミチョウ', '伊座利', 'イザリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県海部郡美波町木岐', '36', '36387', '7792108', '徳島県', 'トクシマケン', '海部郡美波町', 'カイフグンミナミチョウ', '木岐', 'キキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県海部郡美波町田井', '36', '36387', '7792109', '徳島県', 'トクシマケン', '海部郡美波町', 'カイフグンミナミチョウ', '田井', 'タイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県海部郡美波町', '36', '36387', '7792300', '徳島県', 'トクシマケン', '海部郡美波町', 'カイフグンミナミチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('97385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県海部郡美波町赤松', '36', '36387', '7792301', '徳島県', 'トクシマケン', '海部郡美波町', 'カイフグンミナミチョウ', '赤松', 'アカマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県海部郡美波町北河内', '36', '36387', '7792302', '徳島県', 'トクシマケン', '海部郡美波町', 'カイフグンミナミチョウ', '北河内', 'キタガワウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県海部郡美波町恵比須浜', '36', '36387', '7792303', '徳島県', 'トクシマケン', '海部郡美波町', 'カイフグンミナミチョウ', '恵比須浜', 'エビスハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県海部郡美波町日和佐浦', '36', '36387', '7792304', '徳島県', 'トクシマケン', '海部郡美波町', 'カイフグンミナミチョウ', '日和佐浦', 'ヒワサウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県海部郡美波町奥河内', '36', '36387', '7792305', '徳島県', 'トクシマケン', '海部郡美波町', 'カイフグンミナミチョウ', '奥河内', 'オクガワウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県海部郡美波町西河内', '36', '36387', '7792306', '徳島県', 'トクシマケン', '海部郡美波町', 'カイフグンミナミチョウ', '西河内', 'ニシガワウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県海部郡美波町山河内', '36', '36387', '7792307', '徳島県', 'トクシマケン', '海部郡美波町', 'カイフグンミナミチョウ', '山河内', 'ヤマガワウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市国府町佐野塚', '36', '36201', '7793101', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '国府町佐野塚', 'コクフチョウサノヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市国府町西黒田', '36', '36201', '7793102', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '国府町西黒田', 'コクフチョウニシクロダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市国府町東黒田', '36', '36201', '7793103', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '国府町東黒田', 'コクフチョウヒガシクロダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市国府町西高輪', '36', '36201', '7793104', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '国府町西高輪', 'コクフチョウニシタカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市国府町東高輪', '36', '36201', '7793105', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '国府町東高輪', 'コクフチョウヒガシタカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市国府町花園', '36', '36201', '7793106', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '国府町花園', 'コクフチョウハナゾノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市国府町竜王', '36', '36201', '7793111', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '国府町竜王', 'コクフチョウリュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市国府町芝原', '36', '36201', '7793112', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '国府町芝原', 'コクフチョウシバハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市国府町川原田', '36', '36201', '7793113', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '国府町川原田', 'コクフチョウカワラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市国府町桜間', '36', '36201', '7793114', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '国府町桜間', 'コクフチョウサクラマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市国府町敷地', '36', '36201', '7793115', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '国府町敷地', 'コクフチョウシキジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市国府町池尻', '36', '36201', '7793116', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '国府町池尻', 'コクフチョウイケジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市国府町日開', '36', '36201', '7793117', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '国府町日開', 'コクフチョウヒガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市国府町井戸', '36', '36201', '7793118', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '国府町井戸', 'コクフチョウイド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市国府町北岩延', '36', '36201', '7793119', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '国府町北岩延', 'コクフチョウキタイワノブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市国府町南岩延', '36', '36201', '7793120', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '国府町南岩延', 'コクフチョウミナミイワノブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市国府町和田', '36', '36201', '7793121', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '国府町和田', 'コクフチョウワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市国府町府中', '36', '36201', '7793122', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '国府町府中', 'コクフチョウコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市国府町観音寺', '36', '36201', '7793123', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '国府町観音寺', 'コクフチョウカンノンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市国府町中', '36', '36201', '7793124', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '国府町中', 'コクフチョウナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市国府町早淵', '36', '36201', '7793125', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '国府町早淵', 'コクフチョウハヤブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市国府町矢野', '36', '36201', '7793126', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '国府町矢野', 'コクフチョウヤノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市国府町西矢野', '36', '36201', '7793127', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '国府町西矢野', 'コクフチョウニシヤノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市国府町延命', '36', '36201', '7793128', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '国府町延命', 'コクフチョウエンメイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市下町', '36', '36201', '7793131', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '下町', 'シモマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市一宮町', '36', '36201', '7793132', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '一宮町', 'イチノミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県徳島市入田町', '36', '36201', '7793133', '徳島県', 'トクシマケン', '徳島市', 'トクシマシ', '入田町', 'ニュウタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県名西郡石井町', '36', '36341', '7793200', '徳島県', 'トクシマケン', '名西郡石井町', 'ミョウザイグンイシイチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('97421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県名西郡石井町高原中須', '36', '36341', '7793201', '徳島県', 'トクシマケン', '名西郡石井町', 'ミョウザイグンイシイチョウ', '高原', 'タカハラ', null, null, '中須', 'ナカス');
INSERT INTO `ms_addresses` VALUES ('97422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県名西郡石井町高原関', '36', '36341', '7793202', '徳島県', 'トクシマケン', '名西郡石井町', 'ミョウザイグンイシイチョウ', '高原', 'タカハラ', null, null, '関', 'セキ');
INSERT INTO `ms_addresses` VALUES ('97423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県名西郡石井町高原平島', '36', '36341', '7793203', '徳島県', 'トクシマケン', '名西郡石井町', 'ミョウザイグンイシイチョウ', '高原', 'タカハラ', null, null, '平島', 'ヘイシマ');
INSERT INTO `ms_addresses` VALUES ('97424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県名西郡石井町高原西高原', '36', '36341', '7793204', '徳島県', 'トクシマケン', '名西郡石井町', 'ミョウザイグンイシイチョウ', '高原', 'タカハラ', null, null, '西高原', 'ニシタカハラ');
INSERT INTO `ms_addresses` VALUES ('97425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県名西郡石井町高原東高原', '36', '36341', '7793205', '徳島県', 'トクシマケン', '名西郡石井町', 'ミョウザイグンイシイチョウ', '高原', 'タカハラ', null, null, '東高原', 'ヒガシタカハラ');
INSERT INTO `ms_addresses` VALUES ('97426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県名西郡石井町高原池北', '36', '36341', '7793206', '徳島県', 'トクシマケン', '名西郡石井町', 'ミョウザイグンイシイチョウ', '高原', 'タカハラ', null, null, '池北', 'イケキタ');
INSERT INTO `ms_addresses` VALUES ('97427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県名西郡石井町高原桑島', '36', '36341', '7793207', '徳島県', 'トクシマケン', '名西郡石井町', 'ミョウザイグンイシイチョウ', '高原', 'タカハラ', null, null, '桑島', 'クワジマ');
INSERT INTO `ms_addresses` VALUES ('97428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県名西郡石井町高原中島', '36', '36341', '7793208', '徳島県', 'トクシマケン', '名西郡石井町', 'ミョウザイグンイシイチョウ', '高原', 'タカハラ', null, null, '中島', 'ナカシマ');
INSERT INTO `ms_addresses` VALUES ('97429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県名西郡石井町藍畑西覚円', '36', '36341', '7793211', '徳島県', 'トクシマケン', '名西郡石井町', 'ミョウザイグンイシイチョウ', '藍畑', 'アイハタ', null, null, '西覚円', 'ニシカクエン');
INSERT INTO `ms_addresses` VALUES ('97430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県名西郡石井町藍畑東覚円', '36', '36341', '7793212', '徳島県', 'トクシマケン', '名西郡石井町', 'ミョウザイグンイシイチョウ', '藍畑', 'アイハタ', null, null, '東覚円', 'ヒガシカクエン');
INSERT INTO `ms_addresses` VALUES ('97431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県名西郡石井町藍畑高畑', '36', '36341', '7793213', '徳島県', 'トクシマケン', '名西郡石井町', 'ミョウザイグンイシイチョウ', '藍畑', 'アイハタ', null, null, '高畑', 'タカバタケ');
INSERT INTO `ms_addresses` VALUES ('97432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県名西郡石井町藍畑第十', '36', '36341', '7793214', '徳島県', 'トクシマケン', '名西郡石井町', 'ミョウザイグンイシイチョウ', '藍畑', 'アイハタ', null, null, '第十', 'ダイジュウ');
INSERT INTO `ms_addresses` VALUES ('97433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県名西郡石井町藍畑竜王', '36', '36341', '7793215', '徳島県', 'トクシマケン', '名西郡石井町', 'ミョウザイグンイシイチョウ', '藍畑', 'アイハタ', null, null, '竜王', 'リュウオウ');
INSERT INTO `ms_addresses` VALUES ('97434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県名西郡石井町高川原南島', '36', '36341', '7793221', '徳島県', 'トクシマケン', '名西郡石井町', 'ミョウザイグンイシイチョウ', '高川原', 'タカガワラ', null, null, '南島', 'ミナミジマ');
INSERT INTO `ms_addresses` VALUES ('97435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県名西郡石井町高川原天神', '36', '36341', '7793222', '徳島県', 'トクシマケン', '名西郡石井町', 'ミョウザイグンイシイチョウ', '高川原', 'タカガワラ', null, null, '天神', 'テンジン');
INSERT INTO `ms_addresses` VALUES ('97436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県名西郡石井町高川原高川原', '36', '36341', '7793223', '徳島県', 'トクシマケン', '名西郡石井町', 'ミョウザイグンイシイチョウ', '高川原', 'タカガワラ', null, null, '高川原', 'タカガワラ');
INSERT INTO `ms_addresses` VALUES ('97437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県名西郡石井町高川原加茂野', '36', '36341', '7793224', '徳島県', 'トクシマケン', '名西郡石井町', 'ミョウザイグンイシイチョウ', '高川原', 'タカガワラ', null, null, '加茂野', 'カモノ');
INSERT INTO `ms_addresses` VALUES ('97438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県名西郡石井町高川原桜間', '36', '36341', '7793225', '徳島県', 'トクシマケン', '名西郡石井町', 'ミョウザイグンイシイチョウ', '高川原', 'タカガワラ', null, null, '桜間', 'サクラマ');
INSERT INTO `ms_addresses` VALUES ('97439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県名西郡石井町高川原市楽', '36', '36341', '7793226', '徳島県', 'トクシマケン', '名西郡石井町', 'ミョウザイグンイシイチョウ', '高川原', 'タカガワラ', null, null, '市楽', 'イチラク');
INSERT INTO `ms_addresses` VALUES ('97440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県名西郡石井町石井重松', '36', '36341', '7793231', '徳島県', 'トクシマケン', '名西郡石井町', 'ミョウザイグンイシイチョウ', '石井', 'イシイ', null, null, '重松', 'シゲマツ');
INSERT INTO `ms_addresses` VALUES ('97441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県名西郡石井町石井城の内', '36', '36341', '7793232', '徳島県', 'トクシマケン', '名西郡石井町', 'ミョウザイグンイシイチョウ', '石井', 'イシイ', null, null, '城の内', 'ジョウノウチ');
INSERT INTO `ms_addresses` VALUES ('97442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県名西郡石井町石井石井', '36', '36341', '7793233', '徳島県', 'トクシマケン', '名西郡石井町', 'ミョウザイグンイシイチョウ', '石井', 'イシイ', null, null, '石井', 'イシイ');
INSERT INTO `ms_addresses` VALUES ('97443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県名西郡石井町石井白鳥', '36', '36341', '7793234', '徳島県', 'トクシマケン', '名西郡石井町', 'ミョウザイグンイシイチョウ', '石井', 'イシイ', null, null, '白鳥', 'シロトリ');
INSERT INTO `ms_addresses` VALUES ('97444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県名西郡石井町石井尼寺', '36', '36341', '7793235', '徳島県', 'トクシマケン', '名西郡石井町', 'ミョウザイグンイシイチョウ', '石井', 'イシイ', null, null, '尼寺', 'ニジ');
INSERT INTO `ms_addresses` VALUES ('97445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県名西郡石井町石井内谷', '36', '36341', '7793236', '徳島県', 'トクシマケン', '名西郡石井町', 'ミョウザイグンイシイチョウ', '石井', 'イシイ', null, null, '内谷', 'ウチダニ');
INSERT INTO `ms_addresses` VALUES ('97446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県名西郡石井町浦庄諏訪', '36', '36341', '7793241', '徳島県', 'トクシマケン', '名西郡石井町', 'ミョウザイグンイシイチョウ', '浦庄', 'ウラショウ', null, null, '諏訪', 'スワ');
INSERT INTO `ms_addresses` VALUES ('97447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県名西郡石井町浦庄国実', '36', '36341', '7793242', '徳島県', 'トクシマケン', '名西郡石井町', 'ミョウザイグンイシイチョウ', '浦庄', 'ウラショウ', null, null, '国実', 'クニザネ');
INSERT INTO `ms_addresses` VALUES ('97448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県名西郡石井町浦庄大万', '36', '36341', '7793243', '徳島県', 'トクシマケン', '名西郡石井町', 'ミョウザイグンイシイチョウ', '浦庄', 'ウラショウ', null, null, '大万', 'ダイマン');
INSERT INTO `ms_addresses` VALUES ('97449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県名西郡石井町浦庄下浦', '36', '36341', '7793244', '徳島県', 'トクシマケン', '名西郡石井町', 'ミョウザイグンイシイチョウ', '浦庄', 'ウラショウ', null, null, '下浦', 'シモウラ');
INSERT INTO `ms_addresses` VALUES ('97450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県名西郡石井町浦庄上浦', '36', '36341', '7793245', '徳島県', 'トクシマケン', '名西郡石井町', 'ミョウザイグンイシイチョウ', '浦庄', 'ウラショウ', null, null, '上浦', 'カミウラ');
INSERT INTO `ms_addresses` VALUES ('97453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市川島町川島', '36', '36205', '7793301', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '川島町川島', 'カワシマチョウカワシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市川島町山田', '36', '36205', '7793302', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '川島町山田', 'カワシマチョウヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市川島町桑村', '36', '36205', '7793303', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '川島町桑村', 'カワシマチョウクワムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市川島町宮島', '36', '36205', '7793304', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '川島町宮島', 'カワシマチョウミヤノシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市川島町児島', '36', '36205', '7793305', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '川島町児島', 'カワシマチョウコジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市川島町学', '36', '36205', '7793306', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '川島町学', 'カワシマチョウガク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市川島町三ツ島', '36', '36205', '7793307', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '川島町三ツ島', 'カワシマチョウミツジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町石堂', '36', '36205', '7793401', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町石堂', 'ヤマカワチョウイシドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町恵下', '36', '36205', '7793401', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町恵下', 'ヤマカワチョウエゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町翁喜台', '36', '36205', '7793401', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町翁喜台', 'ヤマカワチョウオキダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町川東', '36', '36205', '7793401', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町川東', 'ヤマカワチョウカワヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町住吉', '36', '36205', '7793401', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町住吉', 'ヤマカワチョウスミヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町建石', '36', '36205', '7793401', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町建石', 'ヤマカワチョウタテイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町町', '36', '36205', '7793401', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町町', 'ヤマカワチョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町忌部', '36', '36205', '7793402', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町忌部', 'ヤマカワチョウイムベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町忌部山', '36', '36205', '7793402', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町忌部山', 'ヤマカワチョウイムベヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町岩戸', '36', '36205', '7793402', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町岩戸', 'ヤマカワチョウイワト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町雲宮', '36', '36205', '7793402', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町雲宮', 'ヤマカワチョウクモミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町堤内', '36', '36205', '7793402', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町堤内', 'ヤマカワチョウテイナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町天神', '36', '36205', '7793402', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町天神', 'ヤマカワチョウテンジン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町中須賀', '36', '36205', '7793402', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町中須賀', 'ヤマカワチョウナカスカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町流', '36', '36205', '7793402', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町流', 'ヤマカワチョウナガレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町西久保', '36', '36205', '7793402', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町西久保', 'ヤマカワチョウニシクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町西麓', '36', '36205', '7793402', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町西麓', 'ヤマカワチョウニシフモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町東麓', '36', '36205', '7793402', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町東麓', 'ヤマカワチョウヒガシフモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町宮北', '36', '36205', '7793402', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町宮北', 'ヤマカワチョウミヤキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町宮島', '36', '36205', '7793402', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町宮島', 'ヤマカワチョウミヤジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町山路', '36', '36205', '7793402', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町山路', 'ヤマカワチョウヤマジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町春日', '36', '36205', '7793403', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町春日', 'ヤマカワチョウカスガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町北須賀', '36', '36205', '7793403', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町北須賀', 'ヤマカワチョウキタスガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町諏訪', '36', '36205', '7793403', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町諏訪', 'ヤマカワチョウスワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町堤外', '36', '36205', '7793403', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町堤外', 'ヤマカワチョウテイガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町八幡', '36', '36205', '7793403', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町八幡', 'ヤマカワチョウハチマン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町前川', '36', '36205', '7793403', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町前川', 'ヤマカワチョウマエガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町三島', '36', '36205', '7793403', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町三島', 'ヤマカワチョウミシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町若宮', '36', '36205', '7793403', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町若宮', 'ヤマカワチョウワカミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町市久保', '36', '36205', '7793404', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町市久保', 'ヤマカワチョウイチクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町一里塚', '36', '36205', '7793404', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町一里塚', 'ヤマカワチョウイチリヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町大須賀', '36', '36205', '7793404', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町大須賀', 'ヤマカワチョウオオスカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町大塚', '36', '36205', '7793404', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町大塚', 'ヤマカワチョウオオツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町麻掛', '36', '36205', '7793404', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町麻掛', 'ヤマカワチョウオカケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町槻原', '36', '36205', '7793404', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町槻原', 'ヤマカワチョウカエキバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町川田', '36', '36205', '7793404', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町川田', 'ヤマカワチョウカワタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町川田市', '36', '36205', '7793404', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町川田市', 'ヤマカワチョウカワタイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町川田天神', '36', '36205', '7793404', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町川田天神', 'ヤマカワチョウカワタテンジン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町北島', '36', '36205', '7793404', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町北島', 'ヤマカワチョウキタジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町鼓山', '36', '36205', '7793404', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町鼓山', 'ヤマカワチョウツツミヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町引地', '36', '36205', '7793404', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町引地', 'ヤマカワチョウヒキチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町日知利子', '36', '36205', '7793404', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町日知利子', 'ヤマカワチョウヒヂリコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町藤生', '36', '36205', '7793404', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町藤生', 'ヤマカワチョウフジショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町舟戸', '36', '36205', '7793404', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町舟戸', 'ヤマカワチョウフナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町湯立', '36', '36205', '7793404', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町湯立', 'ヤマカワチョウユダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町赤刎', '36', '36205', '7793405', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町赤刎', 'ヤマカワチョウアカハネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町伊端穂', '36', '36205', '7793405', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町伊端穂', 'ヤマカワチョウイズホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町井上', '36', '36205', '7793405', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町井上', 'ヤマカワチョウイノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町井傍', '36', '36205', '7793405', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町井傍', 'ヤマカワチョウイノソバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町牛ノ子尾', '36', '36205', '7793405', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町牛ノ子尾', 'ヤマカワチョウウシノコオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町大藤谷', '36', '36205', '7793405', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町大藤谷', 'ヤマカワチョウオオトダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町大峰', '36', '36205', '7793405', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町大峰', 'ヤマカワチョウオオミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町大室', '36', '36205', '7793405', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町大室', 'ヤマカワチョウオオムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町奥原', '36', '36205', '7793405', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町奥原', 'ヤマカワチョウオクバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町柿木谷', '36', '36205', '7793405', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町柿木谷', 'ヤマカワチョウカキノキダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町楮本', '36', '36205', '7793405', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町楮本', 'ヤマカワチョウカジノモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町片岸', '36', '36205', '7793405', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町片岸', 'ヤマカワチョウカタギシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町川田八幡', '36', '36205', '7793405', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町川田八幡', 'ヤマカワチョウカワタハチマン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町木戸口', '36', '36205', '7793405', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町木戸口', 'ヤマカワチョウキドグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町黒岩', '36', '36205', '7793405', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町黒岩', 'ヤマカワチョウクロイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町桑ノ峰', '36', '36205', '7793405', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町桑ノ峰', 'ヤマカワチョウクワノミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町高頭', '36', '36205', '7793405', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町高頭', 'ヤマカワチョウコウズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町御饌免', '36', '36205', '7793405', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町御饌免', 'ヤマカワチョウゴセンメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町御旅館', '36', '36205', '7793405', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町御旅館', 'ヤマカワチョウゴリョカン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町権現谷', '36', '36205', '7793405', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町権現谷', 'ヤマカワチョウゴンゲンダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町坂口', '36', '36205', '7793405', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町坂口', 'ヤマカワチョウサカグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町貞田', '36', '36205', '7793405', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町貞田', 'ヤマカワチョウサダタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町小路', '36', '36205', '7793405', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町小路', 'ヤマカワチョウショウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町瀬津', '36', '36205', '7793405', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町瀬津', 'ヤマカワチョウセヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町田ノ浦', '36', '36205', '7793405', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町田ノ浦', 'ヤマカワチョウタノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町塚穴', '36', '36205', '7793405', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町塚穴', 'ヤマカワチョウツカアナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町土仏西向', '36', '36205', '7793405', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町土仏西向', 'ヤマカワチョウツチボトケニシムカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町天神佐古', '36', '36205', '7793405', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町天神佐古', 'ヤマカワチョウテンジンサコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町天王原', '36', '36205', '7793405', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町天王原', 'ヤマカワチョウテンノウバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町土橋', '36', '36205', '7793405', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町土橋', 'ヤマカワチョウドバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町土橋ノ上', '36', '36205', '7793405', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町土橋ノ上', 'ヤマカワチョウドバシノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町中ノ郷', '36', '36205', '7793405', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町中ノ郷', 'ヤマカワチョウナカノゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町鍋倉', '36', '36205', '7793405', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町鍋倉', 'ヤマカワチョウナベクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町野宮谷', '36', '36205', '7793405', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町野宮谷', 'ヤマカワチョウノミヤダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町八ケ久保', '36', '36205', '7793405', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町八ケ久保', 'ヤマカワチョウハチガクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町榛木原', '36', '36205', '7793405', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町榛木原', 'ヤマカワチョウハリノキバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町一ツ石', '36', '36205', '7793405', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町一ツ石', 'ヤマカワチョウヒトツイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町平山', '36', '36205', '7793405', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町平山', 'ヤマカワチョウヒラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町日鷲谷', '36', '36205', '7793405', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町日鷲谷', 'ヤマカワチョウヒワシダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町宮谷', '36', '36205', '7793405', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町宮谷', 'ヤマカワチョウミヤダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町村雲', '36', '36205', '7793405', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町村雲', 'ヤマカワチョウムラクモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町茂草', '36', '36205', '7793405', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町茂草', 'ヤマカワチョウモソウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町矢落', '36', '36205', '7793405', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町矢落', 'ヤマカワチョウヤオチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町木綿麻山', '36', '36205', '7793405', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町木綿麻山', 'ヤマカワチョウユウマヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町榎谷', '36', '36205', '7793406', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町榎谷', 'ヤマカワチョウエノキダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町大内', '36', '36205', '7793406', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町大内', 'ヤマカワチョウオオウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町奥川田', '36', '36205', '7793406', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町奥川田', 'ヤマカワチョウオクカワタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町奥野井', '36', '36205', '7793406', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町奥野井', 'ヤマカワチョウオクノイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町皆瀬', '36', '36205', '7793406', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町皆瀬', 'ヤマカワチョウカイゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町楠根地', '36', '36205', '7793406', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町楠根地', 'ヤマカワチョウクスネジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町桑内', '36', '36205', '7793406', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町桑内', 'ヤマカワチョウクワウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町西野峰', '36', '36205', '7793406', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町西野峰', 'ヤマカワチョウニシノミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町久宗', '36', '36205', '7793406', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町久宗', 'ヤマカワチョウヒサムネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町馬見尾', '36', '36205', '7793406', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町馬見尾', 'ヤマカワチョウマミオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町青木', '36', '36205', '7793407', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町青木', 'ヤマカワチョウアオギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町赤岩', '36', '36205', '7793407', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町赤岩', 'ヤマカワチョウアカイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町朝日', '36', '36205', '7793407', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町朝日', 'ヤマカワチョウアサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町安楽寺', '36', '36205', '7793407', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町安楽寺', 'ヤマカワチョウアンラクジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町浦山', '36', '36205', '7793407', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町浦山', 'ヤマカワチョウウラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町祗園', '36', '36205', '7793407', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町祗園', 'ヤマカワチョウギオン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町境谷', '36', '36205', '7793407', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町境谷', 'ヤマカワチョウサカイダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町坂田', '36', '36205', '7793407', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町坂田', 'ヤマカワチョウサカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町新田谷', '36', '36205', '7793407', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町新田谷', 'ヤマカワチョウシンタダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町季邦', '36', '36205', '7793407', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町季邦', 'ヤマカワチョウスエクニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町津由谷', '36', '36205', '7793407', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町津由谷', 'ヤマカワチョウツユダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町西ノ原', '36', '36205', '7793407', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町西ノ原', 'ヤマカワチョウニシノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町旗見', '36', '36205', '7793407', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町旗見', 'ヤマカワチョウハタミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町東麦原', '36', '36205', '7793407', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町東麦原', 'ヤマカワチョウヒガシムギハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町古城', '36', '36205', '7793407', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町古城', 'ヤマカワチョウフルシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町丸山', '36', '36205', '7793407', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町丸山', 'ヤマカワチョウマルヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町宮地', '36', '36205', '7793407', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町宮地', 'ヤマカワチョウミヤジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町迎坂', '36', '36205', '7793407', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町迎坂', 'ヤマカワチョウムカエザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町麦原', '36', '36205', '7793407', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町麦原', 'ヤマカワチョウムギハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町向坂', '36', '36205', '7793407', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町向坂', 'ヤマカワチョウムコウザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町山ノ神', '36', '36205', '7793407', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町山ノ神', 'ヤマカワチョウヤマノカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市山川町横走', '36', '36205', '7793407', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '山川町横走', 'ヤマカワチョウヨコハシリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市美郷愛後', '36', '36205', '7793501', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '美郷愛後', 'ミサトアイゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市美郷穴地', '36', '36205', '7793501', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '美郷穴地', 'ミサトアナジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市美郷一野山', '36', '36205', '7793501', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '美郷一野山', 'ミサトイチノヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市美郷大神', '36', '36205', '7793501', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '美郷大神', 'ミサトオオガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市美郷大平', '36', '36205', '7793501', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '美郷大平', 'ミサトオオヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市美郷柿谷', '36', '36205', '7793501', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '美郷柿谷', 'ミサトカキダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市美郷倉羅', '36', '36205', '7793501', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '美郷倉羅', 'ミサトクララ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市美郷古井', '36', '36205', '7793501', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '美郷古井', 'ミサトコイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市美郷重野尾', '36', '36205', '7793501', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '美郷重野尾', 'ミサトシゲノオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市美郷下浦', '36', '36205', '7793501', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '美郷下浦', 'ミサトシモウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市美郷下城戸', '36', '36205', '7793501', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '美郷下城戸', 'ミサトシモジョウド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市美郷上戸峯', '36', '36205', '7793501', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '美郷上戸峯', 'ミサトジョウドミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市美郷平', '36', '36205', '7793501', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '美郷平', 'ミサトタイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市美郷滝ケ山', '36', '36205', '7793501', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '美郷滝ケ山', 'ミサトタキガヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市美郷田平', '36', '36205', '7793501', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '美郷田平', 'ミサトタダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市美郷照尾', '36', '36205', '7793501', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '美郷照尾', 'ミサトテラオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市美郷張', '36', '36205', '7793501', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '美郷張', 'ミサトハリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市美郷張峯', '36', '36205', '7793501', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '美郷張峯', 'ミサトハリミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市美郷宮倉', '36', '36205', '7793501', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '美郷宮倉', 'ミサトミヤグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市美郷宗田', '36', '36205', '7793501', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '美郷宗田', 'ミサトムネダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市美郷大岸', '36', '36205', '7793502', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '美郷大岸', 'ミサトオオギシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市美郷大佐古', '36', '36205', '7793502', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '美郷大佐古', 'ミサトオオザコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市美郷奥分', '36', '36205', '7793502', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '美郷奥分', 'ミサトオクブン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市美郷樫平', '36', '36205', '7793502', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '美郷樫平', 'ミサトカシダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市美郷川向', '36', '36205', '7793502', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '美郷川向', 'ミサトカワムカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市美郷岸宗', '36', '36205', '7793502', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '美郷岸宗', 'ミサトキシノムネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市美郷小竹', '36', '36205', '7793502', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '美郷小竹', 'ミサトコダケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市美郷下畠', '36', '36205', '7793502', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '美郷下畠', 'ミサトシモハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市美郷下林', '36', '36205', '7793502', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '美郷下林', 'ミサトシモバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市美郷竹屋敷', '36', '36205', '7793502', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '美郷竹屋敷', 'ミサトタケヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市美郷立石', '36', '36205', '7793502', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '美郷立石', 'ミサトタテイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市美郷谷向', '36', '36205', '7793502', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '美郷谷向', 'ミサトタニムカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市美郷中畠', '36', '36205', '7793502', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '美郷中畠', 'ミサトナカハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市美郷中分', '36', '36205', '7793502', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '美郷中分', 'ミサトナカブン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市美郷中村中筋', '36', '36205', '7793502', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '美郷中村中筋', 'ミサトナカムラナカスジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市美郷西條', '36', '36205', '7793502', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '美郷西條', 'ミサトニシジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市美郷西谷', '36', '36205', '7793502', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '美郷西谷', 'ミサトニシタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市美郷西畠', '36', '36205', '7793502', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '美郷西畠', 'ミサトニシハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市美郷西槇山', '36', '36205', '7793502', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '美郷西槇山', 'ミサトニシマキヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市美郷日浦', '36', '36205', '7793502', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '美郷日浦', 'ミサトヒウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市美郷東', '36', '36205', '7793502', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '美郷東', 'ミサトヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市美郷東條', '36', '36205', '7793502', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '美郷東條', 'ミサトヒガシジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市美郷東槇山', '36', '36205', '7793502', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '美郷東槇山', 'ミサトヒガシマキヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市美郷槇山', '36', '36205', '7793502', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '美郷槇山', 'ミサトマキヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市美郷松尾', '36', '36205', '7793502', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '美郷松尾', 'ミサトマツオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市美郷矢ノ丸', '36', '36205', '7793502', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '美郷矢ノ丸', 'ミサトヤノマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市美郷川俣', '36', '36205', '7793503', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '美郷川俣', 'ミサトカワマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市美郷品野', '36', '36205', '7793503', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '美郷品野', 'ミサトシナノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市美郷高野尾', '36', '36205', '7793503', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '美郷高野尾', 'ミサトタカノオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市美郷中筋', '36', '36205', '7793503', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '美郷中筋', 'ミサトナカスジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市美郷湯殿', '36', '36205', '7793503', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '美郷湯殿', 'ミサトユドノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市美郷毛無', '36', '36205', '7793504', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '美郷毛無', 'ミサトケナシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市美郷土井ノ奥', '36', '36205', '7793504', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '美郷土井ノ奥', 'ミサトドイノオク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市美郷峠', '36', '36205', '7793504', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '美郷峠', 'ミサトトウゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市美郷刷石', '36', '36205', '7793504', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '美郷刷石', 'ミサトハケイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市美郷恵美子', '36', '36205', '7793505', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '美郷恵美子', 'ミサトエビス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市美郷大鹿', '36', '36205', '7793505', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '美郷大鹿', 'ミサトオオジカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市美郷大野', '36', '36205', '7793505', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '美郷大野', 'ミサトオオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市美郷奥丸', '36', '36205', '7793505', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '美郷奥丸', 'ミサトオクマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市美郷上谷', '36', '36205', '7793505', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '美郷上谷', 'ミサトカミダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市美郷栗木', '36', '36205', '7793505', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '美郷栗木', 'ミサトクリノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市美郷来見坂', '36', '36205', '7793505', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '美郷来見坂', 'ミサトクルミザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市美郷暮石', '36', '36205', '7793505', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '美郷暮石', 'ミサトクレイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市美郷古土地', '36', '36205', '7793505', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '美郷古土地', 'ミサトコドチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市美郷木屋浦', '36', '36205', '7793505', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '美郷木屋浦', 'ミサトコヤノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市美郷山王', '36', '36205', '7793505', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '美郷山王', 'ミサトサンノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市美郷菅草', '36', '36205', '7793505', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '美郷菅草', 'ミサトスゲソウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市美郷月野', '36', '36205', '7793505', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '美郷月野', 'ミサトツキノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市美郷栩谷', '36', '36205', '7793505', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '美郷栩谷', 'ミサトトチダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市美郷殿河', '36', '36205', '7793505', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '美郷殿河', 'ミサトトノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市美郷土用地', '36', '36205', '7793505', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '美郷土用地', 'ミサトドヨウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市美郷中谷', '36', '36205', '7793505', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '美郷中谷', 'ミサトナカノタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市美郷花地', '36', '36205', '7793505', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '美郷花地', 'ミサトハナジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市美郷東山峠', '36', '36205', '7793505', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '美郷東山峠', 'ミサトヒガシヤマトウゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市美郷丸山', '36', '36205', '7793505', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '美郷丸山', 'ミサトマルヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県吉野川市美郷湯下', '36', '36205', '7793505', '徳島県', 'トクシマケン', '吉野川市', 'ヨシノガワシ', '美郷湯下', 'ミサトユゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市', '36', '36207', '7793600', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('97663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市脇町拝原', '36', '36207', '7793601', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '脇町', 'ワキマチ', null, null, '拝原', 'ハイバラ');
INSERT INTO `ms_addresses` VALUES ('97664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市脇町猪尻', '36', '36207', '7793602', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '脇町猪尻', 'ワキマチイノシリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市脇町猪尻庄', '36', '36207', '7793603', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '脇町猪尻', 'ワキマチイノシリ', null, null, '庄', 'ショウ');
INSERT INTO `ms_addresses` VALUES ('97666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市脇町猪尻土井', '36', '36207', '7793603', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '脇町猪尻', 'ワキマチイノシリ', null, null, '土井', 'ドイ');
INSERT INTO `ms_addresses` VALUES ('97667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市脇町猪尻西上野', '36', '36207', '7793603', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '脇町猪尻', 'ワキマチイノシリ', null, null, '西上野', 'ニシウエノ');
INSERT INTO `ms_addresses` VALUES ('97668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市脇町北庄', '36', '36207', '7793604', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '脇町', 'ワキマチ', null, null, '北庄', 'キタショウ');
INSERT INTO `ms_addresses` VALUES ('97669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市脇町猪尻古作', '36', '36207', '7793604', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '脇町猪尻', 'ワキマチイノシリ', null, null, '古作', 'コサク');
INSERT INTO `ms_addresses` VALUES ('97670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市脇町脇町', '36', '36207', '7793610', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '脇町脇町', 'ワキマチワキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市脇町岩倉', '36', '36207', '7793620', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '脇町岩倉', 'ワキマチイワクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市脇町上ノ原', '36', '36207', '7793620', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '脇町上ノ原', 'ワキマチウエノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市脇町馬木', '36', '36207', '7793620', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '脇町馬木', 'ワキマチウマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市脇町川原町', '36', '36207', '7793620', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '脇町川原町', 'ワキマチカワラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市脇町木ノ内', '36', '36207', '7793620', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '脇町木ノ内', 'ワキマチキノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市脇町新町', '36', '36207', '7793620', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '脇町新町', 'ワキマチシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市脇町助松', '36', '36207', '7793620', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '脇町助松', 'ワキマチスケマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市脇町田上', '36', '36207', '7793620', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '脇町田上', 'ワキマチタネエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市脇町野村', '36', '36207', '7793620', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '脇町野村', 'ワキマチノムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市脇町別所', '36', '36207', '7793620', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '脇町別所', 'ワキマチベッショ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市脇町北星', '36', '36207', '7793625', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '脇町', 'ワキマチ', null, null, '北星', 'キタボシ');
INSERT INTO `ms_addresses` VALUES ('97682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市脇町新山', '36', '36207', '7793631', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '脇町', 'ワキマチ', null, null, '新山', 'シンヤマ');
INSERT INTO `ms_addresses` VALUES ('97683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市脇町井口東', '36', '36207', '7793632', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '脇町', 'ワキマチ', null, null, '井口東', 'イグチヒガシ');
INSERT INTO `ms_addresses` VALUES ('97684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市脇町上ノ原', '36', '36207', '7793632', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '脇町', 'ワキマチ', null, null, '上ノ原', 'ウエノハラ');
INSERT INTO `ms_addresses` VALUES ('97685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市脇町井口', '36', '36207', '7793633', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '脇町', 'ワキマチ', null, null, '井口', 'イグチ');
INSERT INTO `ms_addresses` VALUES ('97686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市脇町小星', '36', '36207', '7793634', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '脇町', 'ワキマチ', null, null, '小星', 'コボシ');
INSERT INTO `ms_addresses` VALUES ('97687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市脇町川原柴', '36', '36207', '7793635', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '脇町', 'ワキマチ', null, null, '川原柴', 'カワラシバ');
INSERT INTO `ms_addresses` VALUES ('97688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市脇町暮畑', '36', '36207', '7793635', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '脇町', 'ワキマチ', null, null, '暮畑', 'クレバタケ');
INSERT INTO `ms_addresses` VALUES ('97689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市脇町梨子木', '36', '36207', '7793635', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '脇町', 'ワキマチ', null, null, '梨子木', 'ナシノキ');
INSERT INTO `ms_addresses` VALUES ('97690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市脇町横倉', '36', '36207', '7793635', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '脇町', 'ワキマチ', null, null, '横倉', 'ヨコグラ');
INSERT INTO `ms_addresses` VALUES ('97691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市脇町芋穴', '36', '36207', '7793636', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '脇町', 'ワキマチ', null, null, '芋穴', 'イモアナ');
INSERT INTO `ms_addresses` VALUES ('97692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市脇町中八', '36', '36207', '7793636', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '脇町', 'ワキマチ', null, null, '中八', 'ナカバチ');
INSERT INTO `ms_addresses` VALUES ('97693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市脇町上中野', '36', '36207', '7793637', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '脇町', 'ワキマチ', null, null, '上中野', 'カミナカノ');
INSERT INTO `ms_addresses` VALUES ('97694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市脇町下中野', '36', '36207', '7793637', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '脇町', 'ワキマチ', null, null, '下中野', 'シモナカノ');
INSERT INTO `ms_addresses` VALUES ('97695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市脇町平帽子', '36', '36207', '7793637', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '脇町', 'ワキマチ', null, null, '平帽子', 'ヒラボウシ');
INSERT INTO `ms_addresses` VALUES ('97696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市脇町舟木', '36', '36207', '7793637', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '脇町', 'ワキマチ', null, null, '舟木', 'フナキ');
INSERT INTO `ms_addresses` VALUES ('97697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市脇町神楽田', '36', '36207', '7793638', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '脇町', 'ワキマチ', null, null, '神楽田', 'カグラデン');
INSERT INTO `ms_addresses` VALUES ('97698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市脇町西大谷', '36', '36207', '7793638', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '脇町', 'ワキマチ', null, null, '西大谷', 'ニシオオタニ');
INSERT INTO `ms_addresses` VALUES ('97699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市脇町東大谷', '36', '36207', '7793638', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '脇町', 'ワキマチ', null, null, '東大谷', 'ヒガシオオタニ');
INSERT INTO `ms_addresses` VALUES ('97700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市脇町芋尻', '36', '36207', '7793639', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '脇町', 'ワキマチ', null, null, '芋尻', 'イモジリ');
INSERT INTO `ms_addresses` VALUES ('97701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市脇町小丸', '36', '36207', '7793639', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '脇町', 'ワキマチ', null, null, '小丸', 'コマル');
INSERT INTO `ms_addresses` VALUES ('97702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市脇町白木', '36', '36207', '7793639', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '脇町', 'ワキマチ', null, null, '白木', 'シラキ');
INSERT INTO `ms_addresses` VALUES ('97703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市脇町段', '36', '36207', '7793639', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '脇町', 'ワキマチ', null, null, '段', 'ダン');
INSERT INTO `ms_addresses` VALUES ('97704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市脇町段名', '36', '36207', '7793639', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '脇町', 'ワキマチ', null, null, '段名', 'ダンミョウ');
INSERT INTO `ms_addresses` VALUES ('97705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市脇町中段', '36', '36207', '7793639', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '脇町', 'ワキマチ', null, null, '中段', 'ナカダン');
INSERT INTO `ms_addresses` VALUES ('97706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市脇町羽出床', '36', '36207', '7793639', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '脇町', 'ワキマチ', null, null, '羽出床', 'ハデトコ');
INSERT INTO `ms_addresses` VALUES ('97708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市脇町曽江名', '36', '36207', '7793741', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '脇町', 'ワキマチ', null, null, '曽江名', 'ソエミョウ');
INSERT INTO `ms_addresses` VALUES ('97709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市脇町西赤谷', '36', '36207', '7793742', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '脇町', 'ワキマチ', null, null, '西赤谷', 'ニシアカタニ');
INSERT INTO `ms_addresses` VALUES ('97710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市脇町東赤谷名', '36', '36207', '7793743', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '脇町', 'ワキマチ', null, null, '東赤谷名', 'ヒガシアカタニミョウ');
INSERT INTO `ms_addresses` VALUES ('97711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市脇町西俣名', '36', '36207', '7793744', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '脇町', 'ワキマチ', null, null, '西俣名', 'ニシマタミョウ');
INSERT INTO `ms_addresses` VALUES ('97712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬市脇町東俣名', '36', '36207', '7793745', '徳島県', 'トクシマケン', '美馬市', 'ミマシ', '脇町', 'ワキマチ', null, null, '東俣名', 'ヒガシマタミョウ');
INSERT INTO `ms_addresses` VALUES ('97713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町', '36', '36468', '7794100', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('97714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町貞光馬出', '36', '36468', '7794101', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '貞光', 'サダミツ', null, null, '馬出', 'ウマダシ');
INSERT INTO `ms_addresses` VALUES ('97715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町貞光大須賀', '36', '36468', '7794101', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '貞光', 'サダミツ', null, null, '大須賀', 'オオスカ');
INSERT INTO `ms_addresses` VALUES ('97716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町貞光中須賀', '36', '36468', '7794101', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '貞光', 'サダミツ', null, null, '中須賀', 'ナカスカ');
INSERT INTO `ms_addresses` VALUES ('97717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町貞光西浦', '36', '36468', '7794101', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '貞光', 'サダミツ', null, null, '西浦', 'ニシウラ');
INSERT INTO `ms_addresses` VALUES ('97718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町貞光東浦', '36', '36468', '7794101', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '貞光', 'サダミツ', null, null, '東浦', 'ヒガシウラ');
INSERT INTO `ms_addresses` VALUES ('97719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町貞光町', '36', '36468', '7794101', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '貞光', 'サダミツ', null, null, '町', 'マチ');
INSERT INTO `ms_addresses` VALUES ('97720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町貞光宮下', '36', '36468', '7794101', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '貞光', 'サダミツ', null, null, '宮下', 'ミヤシタ');
INSERT INTO `ms_addresses` VALUES ('97721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町貞光大坊', '36', '36468', '7794102', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '貞光', 'サダミツ', null, null, '大坊', 'ダイボウ');
INSERT INTO `ms_addresses` VALUES ('97722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町貞光辻', '36', '36468', '7794102', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '貞光', 'サダミツ', null, null, '辻', 'ツジ');
INSERT INTO `ms_addresses` VALUES ('97723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町貞光西山', '36', '36468', '7794102', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '貞光', 'サダミツ', null, null, '西山', 'ニシヤマ');
INSERT INTO `ms_addresses` VALUES ('97724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町貞光野口', '36', '36468', '7794102', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '貞光', 'サダミツ', null, null, '野口', 'ノグチ');
INSERT INTO `ms_addresses` VALUES ('97725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町貞光平石', '36', '36468', '7794102', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '貞光', 'サダミツ', null, null, '平石', 'ヒライシ');
INSERT INTO `ms_addresses` VALUES ('97726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町貞光別所', '36', '36468', '7794102', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '貞光', 'サダミツ', null, null, '別所', 'ベッショ');
INSERT INTO `ms_addresses` VALUES ('97727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町貞光前田', '36', '36468', '7794102', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '貞光', 'サダミツ', null, null, '前田', 'マエダ');
INSERT INTO `ms_addresses` VALUES ('97728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町貞光江ノ脇', '36', '36468', '7794103', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '貞光', 'サダミツ', null, null, '江ノ脇', 'エノワキ');
INSERT INTO `ms_addresses` VALUES ('97729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町貞光岡', '36', '36468', '7794103', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '貞光', 'サダミツ', null, null, '岡', 'オカ');
INSERT INTO `ms_addresses` VALUES ('97730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町貞光宮内', '36', '36468', '7794103', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '貞光', 'サダミツ', null, null, '宮内', 'ミヤウチ');
INSERT INTO `ms_addresses` VALUES ('97731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町貞光太田西', '36', '36468', '7794104', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '貞光', 'サダミツ', null, null, '太田西', 'オオタニシ');
INSERT INTO `ms_addresses` VALUES ('97732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町貞光太田東', '36', '36468', '7794104', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '貞光', 'サダミツ', null, null, '太田東', 'オオタヒガシ');
INSERT INTO `ms_addresses` VALUES ('97733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町貞光太田東山', '36', '36468', '7794104', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '貞光', 'サダミツ', null, null, '太田東山', 'オオタヒガシヤマ');
INSERT INTO `ms_addresses` VALUES ('97734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町貞光小長谷', '36', '36468', '7794104', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '貞光', 'サダミツ', null, null, '小長谷', 'コバセ');
INSERT INTO `ms_addresses` VALUES ('97735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町貞光小山北', '36', '36468', '7794104', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '貞光', 'サダミツ', null, null, '小山北', 'コヤマキタ');
INSERT INTO `ms_addresses` VALUES ('97736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町貞光柴内', '36', '36468', '7794104', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '貞光', 'サダミツ', null, null, '柴内', 'シバウチ');
INSERT INTO `ms_addresses` VALUES ('97737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町貞光柴山', '36', '36468', '7794104', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '貞光', 'サダミツ', null, null, '柴山', 'シバヤマ');
INSERT INTO `ms_addresses` VALUES ('97738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町貞光僧地', '36', '36468', '7794104', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '貞光', 'サダミツ', null, null, '僧地', 'ソウチ');
INSERT INTO `ms_addresses` VALUES ('97739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町貞光僧山', '36', '36468', '7794104', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '貞光', 'サダミツ', null, null, '僧山', 'ソウヤマ');
INSERT INTO `ms_addresses` VALUES ('97740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町貞光浦山', '36', '36468', '7794105', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '貞光', 'サダミツ', null, null, '浦山', 'ウラヤマ');
INSERT INTO `ms_addresses` VALUES ('97741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町貞光乙部', '36', '36468', '7794105', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '貞光', 'サダミツ', null, null, '乙部', 'オトベ');
INSERT INTO `ms_addresses` VALUES ('97742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町貞光皆瀬', '36', '36468', '7794105', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '貞光', 'サダミツ', null, null, '皆瀬', 'カイゼ');
INSERT INTO `ms_addresses` VALUES ('97743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町貞光竹屋敷', '36', '36468', '7794105', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '貞光', 'サダミツ', null, null, '竹屋敷', 'タケヤシキ');
INSERT INTO `ms_addresses` VALUES ('97744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町貞光長谷', '36', '36468', '7794105', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '貞光', 'サダミツ', null, null, '長谷', 'ナガタニ');
INSERT INTO `ms_addresses` VALUES ('97745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町貞光西丸井', '36', '36468', '7794105', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '貞光', 'サダミツ', null, null, '西丸井', 'ニシマルイ');
INSERT INTO `ms_addresses` VALUES ('97746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町貞光引地', '36', '36468', '7794105', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '貞光', 'サダミツ', null, null, '引地', 'ヒキチ');
INSERT INTO `ms_addresses` VALUES ('97747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町貞光宅熊', '36', '36468', '7794105', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '貞光', 'サダミツ', null, null, '宅熊', 'ヤケグマ');
INSERT INTO `ms_addresses` VALUES ('97748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町貞光大久保', '36', '36468', '7794106', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '貞光', 'サダミツ', null, null, '大久保', 'オオクボ');
INSERT INTO `ms_addresses` VALUES ('97749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町貞光皆瀬川向', '36', '36468', '7794106', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '貞光', 'サダミツ', null, null, '皆瀬川向', 'カイゼカワムカイ');
INSERT INTO `ms_addresses` VALUES ('97750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町貞光白村', '36', '36468', '7794106', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '貞光', 'サダミツ', null, null, '白村', 'シラムラ');
INSERT INTO `ms_addresses` VALUES ('97751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町貞光捨子谷北', '36', '36468', '7794106', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '貞光', 'サダミツ', null, null, '捨子谷北', 'スツコタニキタ');
INSERT INTO `ms_addresses` VALUES ('97752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町貞光捨子谷南', '36', '36468', '7794106', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '貞光', 'サダミツ', null, null, '捨子谷南', 'スツコタニミナミ');
INSERT INTO `ms_addresses` VALUES ('97753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町貞光谷向', '36', '36468', '7794106', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '貞光', 'サダミツ', null, null, '谷向', 'タニムカイ');
INSERT INTO `ms_addresses` VALUES ('97754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町貞光中山', '36', '36468', '7794106', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '貞光', 'サダミツ', null, null, '中山', 'ナカヤマ');
INSERT INTO `ms_addresses` VALUES ('97755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町貞光西谷', '36', '36468', '7794106', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '貞光', 'サダミツ', null, null, '西谷', 'ニシタニ');
INSERT INTO `ms_addresses` VALUES ('97756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町貞光家賀道上', '36', '36468', '7794107', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '貞光', 'サダミツ', null, null, '家賀道上', 'ケカミチウエ');
INSERT INTO `ms_addresses` VALUES ('97757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町貞光家賀道下', '36', '36468', '7794107', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '貞光', 'サダミツ', null, null, '家賀道下', 'ケカミチシタ');
INSERT INTO `ms_addresses` VALUES ('97758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町貞光平野', '36', '36468', '7794107', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '貞光', 'サダミツ', null, null, '平野', 'タイラノ');
INSERT INTO `ms_addresses` VALUES ('97759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町貞光長木', '36', '36468', '7794107', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '貞光', 'サダミツ', null, null, '長木', 'ナガキ');
INSERT INTO `ms_addresses` VALUES ('97760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町貞光長木影', '36', '36468', '7794107', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '貞光', 'サダミツ', null, null, '長木影', 'ナガキカゲ');
INSERT INTO `ms_addresses` VALUES ('97761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町貞光広谷', '36', '36468', '7794107', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '貞光', 'サダミツ', null, null, '広谷', 'ヒロタニ');
INSERT INTO `ms_addresses` VALUES ('97762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町貞光広谷影', '36', '36468', '7794107', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '貞光', 'サダミツ', null, null, '広谷影', 'ヒロタニカゲ');
INSERT INTO `ms_addresses` VALUES ('97763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町貞光広谷東', '36', '36468', '7794107', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '貞光', 'サダミツ', null, null, '広谷東', 'ヒロタニヒガシ');
INSERT INTO `ms_addresses` VALUES ('97764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町貞光川見', '36', '36468', '7794108', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '貞光', 'サダミツ', null, null, '川見', 'カワミ');
INSERT INTO `ms_addresses` VALUES ('97765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町貞光川見津', '36', '36468', '7794108', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '貞光', 'サダミツ', null, null, '川見津', 'カワミツ');
INSERT INTO `ms_addresses` VALUES ('97766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町貞光川見西', '36', '36468', '7794108', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '貞光', 'サダミツ', null, null, '川見西', 'カワミニシ');
INSERT INTO `ms_addresses` VALUES ('97767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町貞光長瀬', '36', '36468', '7794108', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '貞光', 'サダミツ', null, null, '長瀬', 'ナガセ');
INSERT INTO `ms_addresses` VALUES ('97768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町貞光日浦川向', '36', '36468', '7794108', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '貞光', 'サダミツ', null, null, '日浦川向', 'ヒウラカワムカイ');
INSERT INTO `ms_addresses` VALUES ('97769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町貞光東丸井', '36', '36468', '7794108', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '貞光', 'サダミツ', null, null, '東丸井', 'ヒガシマルイ');
INSERT INTO `ms_addresses` VALUES ('97770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町貞光三木枋', '36', '36468', '7794108', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '貞光', 'サダミツ', null, null, '三木枋', 'ミキドチ');
INSERT INTO `ms_addresses` VALUES ('97771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町貞光森ノ本', '36', '36468', '7794108', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '貞光', 'サダミツ', null, null, '森ノ本', 'モリノモト');
INSERT INTO `ms_addresses` VALUES ('97772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町貞光吉良', '36', '36468', '7794109', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '貞光', 'サダミツ', null, null, '吉良', 'キラ');
INSERT INTO `ms_addresses` VALUES ('97773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町貞光木屋', '36', '36468', '7794109', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '貞光', 'サダミツ', null, null, '木屋', 'コヤ');
INSERT INTO `ms_addresses` VALUES ('97774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町貞光猿飼', '36', '36468', '7794109', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '貞光', 'サダミツ', null, null, '猿飼', 'サルカイ');
INSERT INTO `ms_addresses` VALUES ('97775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町貞光成谷', '36', '36468', '7794109', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '貞光', 'サダミツ', null, null, '成谷', 'ナルタニ');
INSERT INTO `ms_addresses` VALUES ('97776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町貞光日浦', '36', '36468', '7794109', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '貞光', 'サダミツ', null, null, '日浦', 'ヒウラ');
INSERT INTO `ms_addresses` VALUES ('97777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町貞光宮平', '36', '36468', '7794109', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '貞光', 'サダミツ', null, null, '宮平', 'ミヤダイラ');
INSERT INTO `ms_addresses` VALUES ('97778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町貞光横野', '36', '36468', '7794109', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '貞光', 'サダミツ', null, null, '横野', 'ヨコノ');
INSERT INTO `ms_addresses` VALUES ('97780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町一宇一宇', '36', '36468', '7794301', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '一宇', 'イチウ', null, null, '一宇', 'イチウ');
INSERT INTO `ms_addresses` VALUES ('97781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町一宇蔭', '36', '36468', '7794301', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '一宇', 'イチウ', null, null, '蔭', 'カゲ');
INSERT INTO `ms_addresses` VALUES ('97782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町一宇樫地', '36', '36468', '7794301', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '一宇', 'イチウ', null, null, '樫地', 'カシジ');
INSERT INTO `ms_addresses` VALUES ('97783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町一宇剪宇', '36', '36468', '7794301', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '一宇', 'イチウ', null, null, '剪宇', 'キリウ');
INSERT INTO `ms_addresses` VALUES ('97784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町一宇太刀之本', '36', '36468', '7794301', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '一宇', 'イチウ', null, null, '太刀之本', 'タチノモト');
INSERT INTO `ms_addresses` VALUES ('97785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町一宇赤松', '36', '36468', '7794302', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '一宇', 'イチウ', null, null, '赤松', 'アカマツ');
INSERT INTO `ms_addresses` VALUES ('97786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町一宇寺地', '36', '36468', '7794302', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '一宇', 'イチウ', null, null, '寺地', 'テラジ');
INSERT INTO `ms_addresses` VALUES ('97787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町一宇大横', '36', '36468', '7794303', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '一宇', 'イチウ', null, null, '大横', 'オオヨコ');
INSERT INTO `ms_addresses` VALUES ('97788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町一宇木地屋', '36', '36468', '7794303', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '一宇', 'イチウ', null, null, '木地屋', 'キジヤ');
INSERT INTO `ms_addresses` VALUES ('97789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町一宇切越', '36', '36468', '7794303', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '一宇', 'イチウ', null, null, '切越', 'キリコシ');
INSERT INTO `ms_addresses` VALUES ('97790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町一宇十家', '36', '36468', '7794303', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '一宇', 'イチウ', null, null, '十家', 'トイエ');
INSERT INTO `ms_addresses` VALUES ('97791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町一宇中横', '36', '36468', '7794303', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '一宇', 'イチウ', null, null, '中横', 'ナカヨコ');
INSERT INTO `ms_addresses` VALUES ('97792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町一宇伊良原', '36', '36468', '7794304', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '一宇', 'イチウ', null, null, '伊良原', 'イラハラ');
INSERT INTO `ms_addresses` VALUES ('97793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町一宇大野', '36', '36468', '7794304', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '一宇', 'イチウ', null, null, '大野', 'オオノ');
INSERT INTO `ms_addresses` VALUES ('97794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町一宇九藤中', '36', '36468', '7794304', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '一宇', 'イチウ', null, null, '九藤中', 'クドウジュウ');
INSERT INTO `ms_addresses` VALUES ('97795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町一宇子安', '36', '36468', '7794304', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '一宇', 'イチウ', null, null, '子安', 'コヤス');
INSERT INTO `ms_addresses` VALUES ('97796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町一宇久藪', '36', '36468', '7794304', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '一宇', 'イチウ', null, null, '久藪', 'ヒサヤブ');
INSERT INTO `ms_addresses` VALUES ('97797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町一宇出羽', '36', '36468', '7794305', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '一宇', 'イチウ', null, null, '出羽', 'イズリハ');
INSERT INTO `ms_addresses` VALUES ('97798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町一宇臼木', '36', '36468', '7794305', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '一宇', 'イチウ', null, null, '臼木', 'ウスキ');
INSERT INTO `ms_addresses` VALUES ('97799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町一宇漆日浦', '36', '36468', '7794305', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '一宇', 'イチウ', null, null, '漆日浦', 'ウルシビウラ');
INSERT INTO `ms_addresses` VALUES ('97800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町一宇大屋内', '36', '36468', '7794305', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '一宇', 'イチウ', null, null, '大屋内', 'オオヤウチ');
INSERT INTO `ms_addresses` VALUES ('97801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町一宇白井', '36', '36468', '7794305', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '一宇', 'イチウ', null, null, '白井', 'シロイ');
INSERT INTO `ms_addresses` VALUES ('97802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町一宇平', '36', '36468', '7794305', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '一宇', 'イチウ', null, null, '平', 'タイラ');
INSERT INTO `ms_addresses` VALUES ('97803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町一宇明谷', '36', '36468', '7794305', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '一宇', 'イチウ', null, null, '明谷', 'ミョウダニ');
INSERT INTO `ms_addresses` VALUES ('97804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町一宇漆野瀬', '36', '36468', '7794306', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '一宇', 'イチウ', null, null, '漆野瀬', 'ウルシノセ');
INSERT INTO `ms_addresses` VALUES ('97805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町一宇河内', '36', '36468', '7794306', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '一宇', 'イチウ', null, null, '河内', 'カワチ');
INSERT INTO `ms_addresses` VALUES ('97806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町一宇桑平', '36', '36468', '7794306', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '一宇', 'イチウ', null, null, '桑平', 'クワダイラ');
INSERT INTO `ms_addresses` VALUES ('97807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町一宇葛籠', '36', '36468', '7794306', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '一宇', 'イチウ', null, null, '葛籠', 'ツヅロ');
INSERT INTO `ms_addresses` VALUES ('97808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町一宇平井', '36', '36468', '7794306', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '一宇', 'イチウ', null, null, '平井', 'ヒライ');
INSERT INTO `ms_addresses` VALUES ('97809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町一宇廣澤', '36', '36468', '7794306', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '一宇', 'イチウ', null, null, '廣澤', 'ヒロサワ');
INSERT INTO `ms_addresses` VALUES ('97810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町一宇法正', '36', '36468', '7794306', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '一宇', 'イチウ', null, null, '法正', 'ホウショウ');
INSERT INTO `ms_addresses` VALUES ('97811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町一宇大佐古', '36', '36468', '7794307', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '一宇', 'イチウ', null, null, '大佐古', 'オオザコ');
INSERT INTO `ms_addresses` VALUES ('97812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町一宇奥大野', '36', '36468', '7794307', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '一宇', 'イチウ', null, null, '奥大野', 'オクオオノ');
INSERT INTO `ms_addresses` VALUES ('97813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町一宇川又', '36', '36468', '7794307', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '一宇', 'イチウ', null, null, '川又', 'カワマタ');
INSERT INTO `ms_addresses` VALUES ('97814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町一宇實平', '36', '36468', '7794307', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '一宇', 'イチウ', null, null, '實平', 'サネヒラ');
INSERT INTO `ms_addresses` VALUES ('97815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町一宇中野', '36', '36468', '7794307', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '一宇', 'イチウ', null, null, '中野', 'ナカノ');
INSERT INTO `ms_addresses` VALUES ('97816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町半田逢坂', '36', '36468', '7794401', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '半田', 'ハンダ', null, null, '逢坂', 'オウサカ');
INSERT INTO `ms_addresses` VALUES ('97817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町半田小野', '36', '36468', '7794401', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '半田', 'ハンダ', null, null, '小野', 'オノ');
INSERT INTO `ms_addresses` VALUES ('97818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町半田天皇', '36', '36468', '7794401', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '半田', 'ハンダ', null, null, '天皇', 'テンノウ');
INSERT INTO `ms_addresses` VALUES ('97819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町半田中藪', '36', '36468', '7794401', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '半田', 'ハンダ', null, null, '中藪', 'ナカヤブ');
INSERT INTO `ms_addresses` VALUES ('97820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町半田松生', '36', '36468', '7794401', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '半田', 'ハンダ', null, null, '松生', 'マツバエ');
INSERT INTO `ms_addresses` VALUES ('97821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町半田上蔭', '36', '36468', '7794402', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '半田', 'ハンダ', null, null, '上蔭', 'ウワカゲ');
INSERT INTO `ms_addresses` VALUES ('97822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町半田蔭名', '36', '36468', '7794402', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '半田', 'ハンダ', null, null, '蔭名', 'カゲミョウ');
INSERT INTO `ms_addresses` VALUES ('97823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町半田田井', '36', '36468', '7794402', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '半田', 'ハンダ', null, null, '田井', 'タイ');
INSERT INTO `ms_addresses` VALUES ('97824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町半田日浦', '36', '36468', '7794402', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '半田', 'ハンダ', null, null, '日浦', 'ヒウラ');
INSERT INTO `ms_addresses` VALUES ('97825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町半田木ノ内', '36', '36468', '7794403', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '半田', 'ハンダ', null, null, '木ノ内', 'キノウチ');
INSERT INTO `ms_addresses` VALUES ('97826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町半田京都', '36', '36468', '7794403', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '半田', 'ハンダ', null, null, '京都', 'キョウト');
INSERT INTO `ms_addresses` VALUES ('97827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町半田猿飼', '36', '36468', '7794403', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '半田', 'ハンダ', null, null, '猿飼', 'サルカイ');
INSERT INTO `ms_addresses` VALUES ('97828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町半田白石', '36', '36468', '7794403', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '半田', 'ハンダ', null, null, '白石', 'シロイシ');
INSERT INTO `ms_addresses` VALUES ('97829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町半田西久保', '36', '36468', '7794403', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '半田', 'ハンダ', null, null, '西久保', 'ニシクボ');
INSERT INTO `ms_addresses` VALUES ('97830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町半田東久保', '36', '36468', '7794403', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '半田', 'ハンダ', null, null, '東久保', 'ヒガシクボ');
INSERT INTO `ms_addresses` VALUES ('97831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町半田平良石', '36', '36468', '7794403', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '半田', 'ハンダ', null, null, '平良石', 'ヒラライシ');
INSERT INTO `ms_addresses` VALUES ('97832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町半田青野', '36', '36468', '7794404', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '半田', 'ハンダ', null, null, '青野', 'アオノ');
INSERT INTO `ms_addresses` VALUES ('97833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町半田折坂', '36', '36468', '7794404', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '半田', 'ハンダ', null, null, '折坂', 'オリサカ');
INSERT INTO `ms_addresses` VALUES ('97834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町半田小井野', '36', '36468', '7794404', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '半田', 'ハンダ', null, null, '小井野', 'コイノ');
INSERT INTO `ms_addresses` VALUES ('97835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町半田高清', '36', '36468', '7794404', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '半田', 'ハンダ', null, null, '高清', 'コウセ');
INSERT INTO `ms_addresses` VALUES ('97836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町半田坂根', '36', '36468', '7794404', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '半田', 'ハンダ', null, null, '坂根', 'サカネ');
INSERT INTO `ms_addresses` VALUES ('97837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町半田下尾尻', '36', '36468', '7794404', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '半田', 'ハンダ', null, null, '下尾尻', 'シモウジリ');
INSERT INTO `ms_addresses` VALUES ('97838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町半田下竹', '36', '36468', '7794404', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '半田', 'ハンダ', null, null, '下竹', 'シモタケ');
INSERT INTO `ms_addresses` VALUES ('97839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町半田上蓮', '36', '36468', '7794404', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '半田', 'ハンダ', null, null, '上蓮', 'ジョウレン');
INSERT INTO `ms_addresses` VALUES ('97840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町半田日谷尾', '36', '36468', '7794404', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '半田', 'ハンダ', null, null, '日谷尾', 'ヒガオ');
INSERT INTO `ms_addresses` VALUES ('97841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町半田葛城', '36', '36468', '7794405', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '半田', 'ハンダ', null, null, '葛城', 'カツラギ');
INSERT INTO `ms_addresses` VALUES ('97842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町半田上喜来', '36', '36468', '7794405', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '半田', 'ハンダ', null, null, '上喜来', 'カミギライ');
INSERT INTO `ms_addresses` VALUES ('97843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町半田中熊', '36', '36468', '7794405', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '半田', 'ハンダ', null, null, '中熊', 'ナカグマ');
INSERT INTO `ms_addresses` VALUES ('97844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町半田長野', '36', '36468', '7794405', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '半田', 'ハンダ', null, null, '長野', 'ナガノ');
INSERT INTO `ms_addresses` VALUES ('97845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町半田日開野', '36', '36468', '7794405', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '半田', 'ハンダ', null, null, '日開野', 'ヒガイノ');
INSERT INTO `ms_addresses` VALUES ('97846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町半田樫尾', '36', '36468', '7794406', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '半田', 'ハンダ', null, null, '樫尾', 'カシオ');
INSERT INTO `ms_addresses` VALUES ('97847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町半田紙屋', '36', '36468', '7794406', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '半田', 'ハンダ', null, null, '紙屋', 'カミヤ');
INSERT INTO `ms_addresses` VALUES ('97848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町半田小谷', '36', '36468', '7794406', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '半田', 'ハンダ', null, null, '小谷', 'コダニ');
INSERT INTO `ms_addresses` VALUES ('97849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町半田佐古戸', '36', '36468', '7794406', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '半田', 'ハンダ', null, null, '佐古戸', 'サコオド');
INSERT INTO `ms_addresses` VALUES ('97850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町半田下喜来', '36', '36468', '7794406', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '半田', 'ハンダ', null, null, '下喜来', 'シモギライ');
INSERT INTO `ms_addresses` VALUES ('97851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県美馬郡つるぎ町半田東毛田', '36', '36468', '7794407', '徳島県', 'トクシマケン', '美馬郡つるぎ町', 'ミマグンツルギチョウ', '半田', 'ハンダ', null, null, '東毛田', 'ヒガシケタ');
INSERT INTO `ms_addresses` VALUES ('97854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好郡東みよし町', '36', '36489', '7794700', '徳島県', 'トクシマケン', '三好郡東みよし町', 'ミヨシグンヒガシミヨシチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('97855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好郡東みよし町加茂', '36', '36489', '7794701', '徳島県', 'トクシマケン', '三好郡東みよし町', 'ミヨシグンヒガシミヨシチョウ', '加茂', 'カモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好郡東みよし町西庄', '36', '36489', '7794702', '徳島県', 'トクシマケン', '三好郡東みよし町', 'ミヨシグンヒガシミヨシチョウ', '西庄', 'ニシショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好郡東みよし町中庄', '36', '36489', '7794703', '徳島県', 'トクシマケン', '三好郡東みよし町', 'ミヨシグンヒガシミヨシチョウ', '中庄', 'ナカショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好郡東みよし町中庄奥村', '36', '36489', '7794704', '徳島県', 'トクシマケン', '三好郡東みよし町', 'ミヨシグンヒガシミヨシチョウ', '中庄', 'ナカショウ', null, null, '奥村', 'オクムラ');
INSERT INTO `ms_addresses` VALUES ('97859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好郡東みよし町毛田', '36', '36489', '7794705', '徳島県', 'トクシマケン', '三好郡東みよし町', 'ミヨシグンヒガシミヨシチョウ', '毛田', 'ケタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好郡東みよし町毛田黒長谷', '36', '36489', '7794706', '徳島県', 'トクシマケン', '三好郡東みよし町', 'ミヨシグンヒガシミヨシチョウ', '毛田', 'ケタ', null, null, '黒長谷', 'クロハゼ');
INSERT INTO `ms_addresses` VALUES ('97861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好郡東みよし町毛田大藤', '36', '36489', '7794707', '徳島県', 'トクシマケン', '三好郡東みよし町', 'ミヨシグンヒガシミヨシチョウ', '毛田', 'ケタ', null, null, '大藤', 'オオト');
INSERT INTO `ms_addresses` VALUES ('97863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市井川町旭町', '36', '36208', '7794801', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '井川町旭町', 'イカワチョウアサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市井川町大佐古', '36', '36208', '7794801', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '井川町大佐古', 'イカワチョウオオサコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市井川町片山', '36', '36208', '7794801', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '井川町片山', 'イカワチョウカタヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市井川町才長谷', '36', '36208', '7794801', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '井川町才長谷', 'イカワチョウサイハゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市井川町新町', '36', '36208', '7794801', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '井川町新町', 'イカワチョウシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市井川町辻', '36', '36208', '7794801', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '井川町辻', 'イカワチョウツジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市井川町仲ノ町', '36', '36208', '7794801', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '井川町仲ノ町', 'イカワチョウナカノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市井川町浜西', '36', '36208', '7794801', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '井川町浜西', 'イカワチョウハマニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市井川町浜東', '36', '36208', '7794801', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '井川町浜東', 'イカワチョウハマヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市井川町本町', '36', '36208', '7794801', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '井川町本町', 'イカワチョウホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市井川町井関', '36', '36208', '7794802', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '井川町井関', 'イカワチョウイゼキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市井川町岡野前', '36', '36208', '7794802', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '井川町岡野前', 'イカワチョウオカノマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市井川町御領田', '36', '36208', '7794802', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '井川町御領田', 'イカワチョウゴリョウデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市井川町流堂', '36', '36208', '7794802', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '井川町流堂', 'イカワチョウナガレドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市井川町野津後', '36', '36208', '7794802', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '井川町野津後', 'イカワチョウノツゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市井川町向坂', '36', '36208', '7794802', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '井川町向坂', 'イカワチョウムコウザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市井川町島', '36', '36208', '7794803', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '井川町島', 'イカワチョウシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市井川町タクミ田', '36', '36208', '7794803', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '井川町タクミ田', 'イカワチョウタクミダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市井川町田中', '36', '36208', '7794803', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '井川町田中', 'イカワチョウタナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市井川町中岡', '36', '36208', '7794803', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '井川町中岡', 'イカワチョウナカオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市井川町中村西', '36', '36208', '7794803', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '井川町中村西', 'イカワチョウナカムラニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市井川町中村東', '36', '36208', '7794803', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '井川町中村東', 'イカワチョウナカムラヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市井川町中村南', '36', '36208', '7794803', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '井川町中村南', 'イカワチョウナカムラミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市井川町野津後流', '36', '36208', '7794803', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '井川町野津後流', 'イカワチョウノツゴナガレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市井川町八幡', '36', '36208', '7794803', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '井川町八幡', 'イカワチョウハチマン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市井川町吉岡', '36', '36208', '7794803', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '井川町吉岡', 'イカワチョウヨシオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市井川町井内東', '36', '36208', '7794804', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '井川町井内東', 'イカワチョウイウチヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市井川町井内西', '36', '36208', '7794805', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '井川町井内西', 'イカワチョウイウチニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市井川町西井川', '36', '36208', '7794806', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '井川町西井川', 'イカワチョウニシイカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市井川町里川', '36', '36208', '7794807', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '井川町里川', 'イカワチョウサトガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市池田町中西', '36', '36208', '7795161', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '池田町中西', 'イケダチョウナカニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市池田町漆川', '36', '36208', '7795162', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '池田町漆川', 'イケダチョウシツカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市池田町中津川', '36', '36208', '7795163', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '池田町中津川', 'イケダチョウナカツガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市池田町大利', '36', '36208', '7795164', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '池田町大利', 'イケダチョウオオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市池田町松尾', '36', '36208', '7795165', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '池田町松尾', 'イケダチョウマツオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市池田町川崎', '36', '36208', '7795166', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '池田町川崎', 'イケダチョウカワサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市西祖谷山村下名', '36', '36208', '7795171', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '西祖谷山村下名', 'ニシイヤヤマムラシモミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市西祖谷山村小祖谷', '36', '36208', '7795172', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '西祖谷山村小祖谷', 'ニシイヤヤマムラオイヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市西祖谷山村坂瀬', '36', '36208', '7795173', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '西祖谷山村坂瀬', 'ニシイヤヤマムラサカセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市山城町大和川', '36', '36208', '7795301', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '山城町大和川', 'ヤマシロチョウヤマトガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市山城町若山', '36', '36208', '7795302', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '山城町若山', 'ヤマシロチョウワカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市山城町下川', '36', '36208', '7795303', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '山城町下川', 'ヤマシロチョウシモカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市山城町大川持', '36', '36208', '7795304', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '山城町大川持', 'ヤマシロチョウオオカワモチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市山城町川口', '36', '36208', '7795305', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '山城町川口', 'ヤマシロチョウカワグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市山城町寺野', '36', '36208', '7795306', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '山城町寺野', 'ヤマシロチョウテラノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市山城町相川', '36', '36208', '7795307', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '山城町相川', 'ヤマシロチョウアイカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市山城町中ノ瀬', '36', '36208', '7795311', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '山城町中ノ瀬', 'ヤマシロチョウナカノセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市山城町八千坊', '36', '36208', '7795312', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '山城町八千坊', 'ヤマシロチョウハッセンボウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市山城町黒川', '36', '36208', '7795313', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '山城町黒川', 'ヤマシロチョウクロカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市山城町岩戸', '36', '36208', '7795314', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '山城町岩戸', 'ヤマシロチョウイワド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市山城町引地', '36', '36208', '7795315', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '山城町引地', 'ヤマシロチョウヒキチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市山城町末貞', '36', '36208', '7795316', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '山城町末貞', 'ヤマシロチョウスエサダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市山城町国政', '36', '36208', '7795321', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '山城町国政', 'ヤマシロチョウクニマサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市山城町重実', '36', '36208', '7795322', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '山城町重実', 'ヤマシロチョウシゲザネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市山城町中野', '36', '36208', '7795323', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '山城町中野', 'ヤマシロチョウナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市山城町白川', '36', '36208', '7795324', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '山城町白川', 'ヤマシロチョウシロカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市山城町光兼', '36', '36208', '7795325', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '山城町光兼', 'ヤマシロチョウミツカネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市山城町仏子', '36', '36208', '7795326', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '山城町仏子', 'ヤマシロチョウブッシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市山城町尾又', '36', '36208', '7795327', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '山城町尾又', 'ヤマシロチョウオマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市山城町粟山', '36', '36208', '7795328', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '山城町粟山', 'ヤマシロチョウアワヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市山城町茂地', '36', '36208', '7795331', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '山城町茂地', 'ヤマシロチョウモジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市山城町小川谷', '36', '36208', '7795332', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '山城町小川谷', 'ヤマシロチョウオガワダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市山城町大野', '36', '36208', '7795333', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '山城町大野', 'ヤマシロチョウオオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市山城町信正', '36', '36208', '7795334', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '山城町信正', 'ヤマシロチョウノブマサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市山城町頼広', '36', '36208', '7795335', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '山城町頼広', 'ヤマシロチョウヨリヒロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市山城町赤谷', '36', '36208', '7795336', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '山城町赤谷', 'ヤマシロチョウアカダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市山城町平野', '36', '36208', '7795337', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '山城町平野', 'ヤマシロチョウタイラノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市山城町佐連', '36', '36208', '7795341', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '山城町佐連', 'ヤマシロチョウサレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市山城町大谷', '36', '36208', '7795342', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '山城町大谷', 'ヤマシロチョウオオタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市山城町柴川', '36', '36208', '7795343', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '山城町柴川', 'ヤマシロチョウシバカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市山城町政友', '36', '36208', '7795344', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '山城町政友', 'ヤマシロチョウマサトモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市山城町瀬貝', '36', '36208', '7795345', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '山城町瀬貝', 'ヤマシロチョウセガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市山城町脇', '36', '36208', '7795346', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '山城町脇', 'ヤマシロチョウワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市山城町大月', '36', '36208', '7795347', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '山城町大月', 'ヤマシロチョウオオツキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市山城町重実殿野', '36', '36208', '7795422', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '山城町重実', 'ヤマシロチョウシゲザネ', null, null, '殿野', 'トノノ');
INSERT INTO `ms_addresses` VALUES ('97940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市山城町西宇', '36', '36208', '7795451', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '山城町西宇', 'ヤマシロチョウニシウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市山城町上名', '36', '36208', '7795452', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '山城町上名', 'ヤマシロチョウカミミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '徳島県三好市山城町下名', '36', '36208', '7795453', '徳島県', 'トクシマケン', '三好市', 'ミヨシシ', '山城町下名', 'ヤマシロチョウシモミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市', '39', '39201', '7800000', '高知県', 'コウチケン', '高知市', 'コウチシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('97944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市久礼野', '39', '39201', '7800001', '高知県', 'コウチケン', '高知市', 'コウチシ', '久礼野', 'クレノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市重倉', '39', '39201', '7800002', '高知県', 'コウチケン', '高知市', 'コウチシ', '重倉', 'シゲクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市七ツ淵', '39', '39201', '7800003', '高知県', 'コウチケン', '高知市', 'コウチシ', '七ツ淵', 'ナナツブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市三谷', '39', '39201', '7800004', '高知県', 'コウチケン', '高知市', 'コウチシ', '三谷', 'ミタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市中秦泉寺', '39', '39201', '7800021', '高知県', 'コウチケン', '高知市', 'コウチシ', '中秦泉寺', 'ナカジンゼンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市北秦泉寺', '39', '39201', '7800022', '高知県', 'コウチケン', '高知市', 'コウチシ', '北秦泉寺', 'キタジンゼンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市東秦泉寺', '39', '39201', '7800023', '高知県', 'コウチケン', '高知市', 'コウチシ', '東秦泉寺', 'ヒガシジンゼンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市前里', '39', '39201', '7800024', '高知県', 'コウチケン', '高知市', 'コウチシ', '前里', 'マエザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市愛宕山', '39', '39201', '7800025', '高知県', 'コウチケン', '高知市', 'コウチシ', '愛宕山', 'アタゴヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市秦南町', '39', '39201', '7800026', '高知県', 'コウチケン', '高知市', 'コウチシ', '秦南町', 'ハダミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市愛宕山南町', '39', '39201', '7800027', '高知県', 'コウチケン', '高知市', 'コウチシ', '愛宕山南町', 'アタゴヤマミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市宇津野', '39', '39201', '7800031', '高知県', 'コウチケン', '高知市', 'コウチシ', '宇津野', 'ウツノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市加賀野井', '39', '39201', '7800032', '高知県', 'コウチケン', '高知市', 'コウチシ', '加賀野井', 'カガノイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市西秦泉寺', '39', '39201', '7800033', '高知県', 'コウチケン', '高知市', 'コウチシ', '西秦泉寺', 'ニシジンゼンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市三園町', '39', '39201', '7800034', '高知県', 'コウチケン', '高知市', 'コウチシ', '三園町', 'ミソノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市入明町', '39', '39201', '7800041', '高知県', 'コウチケン', '高知市', 'コウチシ', '入明町', 'イリアケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市洞ケ島町', '39', '39201', '7800042', '高知県', 'コウチケン', '高知市', 'コウチシ', '洞ケ島町', 'ホラガジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市寿町', '39', '39201', '7800043', '高知県', 'コウチケン', '高知市', 'コウチシ', '寿町', 'コトブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市中水道', '39', '39201', '7800044', '高知県', 'コウチケン', '高知市', 'コウチシ', '中水道', 'ナカスイドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市幸町', '39', '39201', '7800045', '高知県', 'コウチケン', '高知市', 'コウチシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市伊勢崎町', '39', '39201', '7800046', '高知県', 'コウチケン', '高知市', 'コウチシ', '伊勢崎町', 'イセザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市相模町', '39', '39201', '7800047', '高知県', 'コウチケン', '高知市', 'コウチシ', '相模町', 'サガミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市吉田町', '39', '39201', '7800048', '高知県', 'コウチケン', '高知市', 'コウチシ', '吉田町', 'ヨシダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市愛宕町', '39', '39201', '7800051', '高知県', 'コウチケン', '高知市', 'コウチシ', '愛宕町', 'アタゴマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市大川筋', '39', '39201', '7800052', '高知県', 'コウチケン', '高知市', 'コウチシ', '大川筋', 'オオカワスジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市駅前町', '39', '39201', '7800053', '高知県', 'コウチケン', '高知市', 'コウチシ', '駅前町', 'エキマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市相生町', '39', '39201', '7800054', '高知県', 'コウチケン', '高知市', 'コウチシ', '相生町', 'アイオイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市江陽町', '39', '39201', '7800055', '高知県', 'コウチケン', '高知市', 'コウチシ', '江陽町', 'コウヨウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市北本町', '39', '39201', '7800056', '高知県', 'コウチケン', '高知市', 'コウチシ', '北本町', 'キタホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市栄田町', '39', '39201', '7800061', '高知県', 'コウチケン', '高知市', 'コウチシ', '栄田町', 'サカエダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市新本町', '39', '39201', '7800062', '高知県', 'コウチケン', '高知市', 'コウチシ', '新本町', 'シンホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市昭和町', '39', '39201', '7800063', '高知県', 'コウチケン', '高知市', 'コウチシ', '昭和町', 'ショウワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市和泉町', '39', '39201', '7800064', '高知県', 'コウチケン', '高知市', 'コウチシ', '和泉町', 'イズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市塩田町', '39', '39201', '7800065', '高知県', 'コウチケン', '高知市', 'コウチシ', '塩田町', 'シオタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市比島町', '39', '39201', '7800066', '高知県', 'コウチケン', '高知市', 'コウチシ', '比島町', 'ヒジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市高そね', '39', '39201', '7800071', '高知県', 'コウチケン', '高知市', 'コウチシ', '高そね', 'タカソネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市杉井流', '39', '39201', '7800072', '高知県', 'コウチケン', '高知市', 'コウチシ', '杉井流', 'スギイル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市北金田', '39', '39201', '7800073', '高知県', 'コウチケン', '高知市', 'コウチシ', '北金田', 'キタカナダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市南金田', '39', '39201', '7800074', '高知県', 'コウチケン', '高知市', 'コウチシ', '南金田', 'ミナミカナダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市北川添', '39', '39201', '7800081', '高知県', 'コウチケン', '高知市', 'コウチシ', '北川添', 'キタカワゾエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市南川添', '39', '39201', '7800082', '高知県', 'コウチケン', '高知市', 'コウチシ', '南川添', 'ミナミカワゾエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市北御座', '39', '39201', '7800083', '高知県', 'コウチケン', '高知市', 'コウチシ', '北御座', 'キタゴザ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市南御座', '39', '39201', '7800084', '高知県', 'コウチケン', '高知市', 'コウチシ', '南御座', 'ミナミゴザ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市札場', '39', '39201', '7800085', '高知県', 'コウチケン', '高知市', 'コウチシ', '札場', 'フダバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市海老ノ丸', '39', '39201', '7800086', '高知県', 'コウチケン', '高知市', 'コウチシ', '海老ノ丸', 'エビノマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市南久保', '39', '39201', '7800087', '高知県', 'コウチケン', '高知市', 'コウチシ', '南久保', 'ミナミクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市北久保', '39', '39201', '7800088', '高知県', 'コウチケン', '高知市', 'コウチシ', '北久保', 'キタクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市小倉町', '39', '39201', '7800801', '高知県', 'コウチケン', '高知市', 'コウチシ', '小倉町', 'オクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市丸池町', '39', '39201', '7800802', '高知県', 'コウチケン', '高知市', 'コウチシ', '丸池町', 'マルイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市弥生町', '39', '39201', '7800803', '高知県', 'コウチケン', '高知市', 'コウチシ', '弥生町', 'ヤヨイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市日の出町', '39', '39201', '7800804', '高知県', 'コウチケン', '高知市', 'コウチシ', '日の出町', 'ヒノデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市東雲町', '39', '39201', '7800805', '高知県', 'コウチケン', '高知市', 'コウチシ', '東雲町', 'シノノメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市知寄町', '39', '39201', '7800806', '高知県', 'コウチケン', '高知市', 'コウチシ', '知寄町', 'チヨリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市弘化台', '39', '39201', '7800811', '高知県', 'コウチケン', '高知市', 'コウチシ', '弘化台', 'コウカダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市若松町', '39', '39201', '7800812', '高知県', 'コウチケン', '高知市', 'コウチシ', '若松町', 'ワカマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('97999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市青柳町', '39', '39201', '7800813', '高知県', 'コウチケン', '高知市', 'コウチシ', '青柳町', 'アオヤギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市稲荷町', '39', '39201', '7800814', '高知県', 'コウチケン', '高知市', 'コウチシ', '稲荷町', 'イナリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市二葉町', '39', '39201', '7800815', '高知県', 'コウチケン', '高知市', 'コウチシ', '二葉町', 'フタバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市南宝永町', '39', '39201', '7800816', '高知県', 'コウチケン', '高知市', 'コウチシ', '南宝永町', 'ミナミホウエイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市中宝永町', '39', '39201', '7800817', '高知県', 'コウチケン', '高知市', 'コウチシ', '中宝永町', 'ナカホウエイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市宝永町', '39', '39201', '7800818', '高知県', 'コウチケン', '高知市', 'コウチシ', '宝永町', 'ホウエイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市桜井町', '39', '39201', '7800821', '高知県', 'コウチケン', '高知市', 'コウチシ', '桜井町', 'サクライチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市はりまや町', '39', '39201', '7800822', '高知県', 'コウチケン', '高知市', 'コウチシ', 'はりまや町', 'ハリマヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市菜園場町', '39', '39201', '7800823', '高知県', 'コウチケン', '高知市', 'コウチシ', '菜園場町', 'サエンバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市城見町', '39', '39201', '7800824', '高知県', 'コウチケン', '高知市', 'コウチシ', '城見町', 'シロミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市農人町', '39', '39201', '7800825', '高知県', 'コウチケン', '高知市', 'コウチシ', '農人町', 'ノウニンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市中の島', '39', '39201', '7800831', '高知県', 'コウチケン', '高知市', 'コウチシ', '中の島', 'ナカノシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市九反田', '39', '39201', '7800832', '高知県', 'コウチケン', '高知市', 'コウチシ', '九反田', 'クタンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市南はりまや町', '39', '39201', '7800833', '高知県', 'コウチケン', '高知市', 'コウチシ', '南はりまや町', 'ミナミハリマヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市堺町', '39', '39201', '7800834', '高知県', 'コウチケン', '高知市', 'コウチシ', '堺町', 'サカイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市帯屋町', '39', '39201', '7800841', '高知県', 'コウチケン', '高知市', 'コウチシ', '帯屋町', 'オビヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市追手筋', '39', '39201', '7800842', '高知県', 'コウチケン', '高知市', 'コウチシ', '追手筋', 'オウテスジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市廿代町', '39', '39201', '7800843', '高知県', 'コウチケン', '高知市', 'コウチシ', '廿代町', 'ニジュウダイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市永国寺町', '39', '39201', '7800844', '高知県', 'コウチケン', '高知市', 'コウチシ', '永国寺町', 'エイコクジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市丸ノ内', '39', '39201', '7800850', '高知県', 'コウチケン', '高知市', 'コウチシ', '丸ノ内', 'マルノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市升形', '39', '39201', '7800861', '高知県', 'コウチケン', '高知市', 'コウチシ', '升形', 'マスガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市鷹匠町', '39', '39201', '7800862', '高知県', 'コウチケン', '高知市', 'コウチシ', '鷹匠町', 'タカジョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市与力町', '39', '39201', '7800863', '高知県', 'コウチケン', '高知市', 'コウチシ', '与力町', 'ヨリキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市唐人町', '39', '39201', '7800864', '高知県', 'コウチケン', '高知市', 'コウチシ', '唐人町', 'トウジンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市本町', '39', '39201', '7800870', '高知県', 'コウチケン', '高知市', 'コウチシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市上町', '39', '39201', '7800901', '高知県', 'コウチケン', '高知市', 'コウチシ', '上町', 'カミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市本丁筋', '39', '39201', '7800902', '高知県', 'コウチケン', '高知市', 'コウチシ', '本丁筋', 'ホンチョウスジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市水通町', '39', '39201', '7800903', '高知県', 'コウチケン', '高知市', 'コウチシ', '水通町', 'スイドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市通町', '39', '39201', '7800904', '高知県', 'コウチケン', '高知市', 'コウチシ', '通町', 'トオリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市新屋敷', '39', '39201', '7800911', '高知県', 'コウチケン', '高知市', 'コウチシ', '新屋敷', 'シンヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市八反町', '39', '39201', '7800912', '高知県', 'コウチケン', '高知市', 'コウチシ', '八反町', 'ハッタンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市北八反町', '39', '39201', '7800913', '高知県', 'コウチケン', '高知市', 'コウチシ', '北八反町', 'キタハッタンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市宝町', '39', '39201', '7800914', '高知県', 'コウチケン', '高知市', 'コウチシ', '宝町', 'タカラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市小津町', '39', '39201', '7800915', '高知県', 'コウチケン', '高知市', 'コウチシ', '小津町', 'オヅチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市城北町', '39', '39201', '7800916', '高知県', 'コウチケン', '高知市', 'コウチシ', '城北町', 'ジョウホクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市井口町', '39', '39201', '7800921', '高知県', 'コウチケン', '高知市', 'コウチシ', '井口町', 'イグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市平和町', '39', '39201', '7800922', '高知県', 'コウチケン', '高知市', 'コウチシ', '平和町', 'ヘイワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市三ノ丸', '39', '39201', '7800923', '高知県', 'コウチケン', '高知市', 'コウチシ', '三ノ丸', 'サンノマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市宮前町', '39', '39201', '7800924', '高知県', 'コウチケン', '高知市', 'コウチシ', '宮前町', 'ミヤマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市西町', '39', '39201', '7800925', '高知県', 'コウチケン', '高知市', 'コウチシ', '西町', 'ニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市大膳町', '39', '39201', '7800926', '高知県', 'コウチケン', '高知市', 'コウチシ', '大膳町', 'ダイゼンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市山ノ端町', '39', '39201', '7800927', '高知県', 'コウチケン', '高知市', 'コウチシ', '山ノ端町', 'ヤマノハナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市越前町', '39', '39201', '7800928', '高知県', 'コウチケン', '高知市', 'コウチシ', '越前町', 'エチゼンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市桜馬場', '39', '39201', '7800929', '高知県', 'コウチケン', '高知市', 'コウチシ', '桜馬場', 'サクラババ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市玉水町', '39', '39201', '7800931', '高知県', 'コウチケン', '高知市', 'コウチシ', '玉水町', 'タマミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市縄手町', '39', '39201', '7800932', '高知県', 'コウチケン', '高知市', 'コウチシ', '縄手町', 'ナワテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市鏡川町', '39', '39201', '7800933', '高知県', 'コウチケン', '高知市', 'コウチシ', '鏡川町', 'カガミガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市下島町', '39', '39201', '7800934', '高知県', 'コウチケン', '高知市', 'コウチシ', '下島町', 'シモジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市旭町', '39', '39201', '7800935', '高知県', 'コウチケン', '高知市', 'コウチシ', '旭町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市赤石町', '39', '39201', '7800936', '高知県', 'コウチケン', '高知市', 'コウチシ', '赤石町', 'アカイシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市中須賀町', '39', '39201', '7800937', '高知県', 'コウチケン', '高知市', 'コウチシ', '中須賀町', 'ナカスカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市旭駅前町', '39', '39201', '7800938', '高知県', 'コウチケン', '高知市', 'コウチシ', '旭駅前町', 'アサヒエキマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市元町', '39', '39201', '7800941', '高知県', 'コウチケン', '高知市', 'コウチシ', '元町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市南元町', '39', '39201', '7800942', '高知県', 'コウチケン', '高知市', 'コウチシ', '南元町', 'ミナミモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市旭上町', '39', '39201', '7800943', '高知県', 'コウチケン', '高知市', 'コウチシ', '旭上町', 'アサヒカミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市水源町', '39', '39201', '7800944', '高知県', 'コウチケン', '高知市', 'コウチシ', '水源町', 'スイゲンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市本宮町', '39', '39201', '7800945', '高知県', 'コウチケン', '高知市', 'コウチシ', '本宮町', 'ホングウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市上本宮町', '39', '39201', '7800946', '高知県', 'コウチケン', '高知市', 'コウチシ', '上本宮町', 'カミホングウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市大谷', '39', '39201', '7800947', '高知県', 'コウチケン', '高知市', 'コウチシ', '大谷', 'オオタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市岩ケ淵', '39', '39201', '7800948', '高知県', 'コウチケン', '高知市', 'コウチシ', '岩ケ淵', 'イワガブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市鳥越', '39', '39201', '7800949', '高知県', 'コウチケン', '高知市', 'コウチシ', '鳥越', 'トリゴエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市西塚ノ原', '39', '39201', '7800951', '高知県', 'コウチケン', '高知市', 'コウチシ', '西塚ノ原', 'ニシツカノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市塚ノ原', '39', '39201', '7800952', '高知県', 'コウチケン', '高知市', 'コウチシ', '塚ノ原', 'ツカノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市長尾山町', '39', '39201', '7800953', '高知県', 'コウチケン', '高知市', 'コウチシ', '長尾山町', 'ナガオヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市佐々木町', '39', '39201', '7800954', '高知県', 'コウチケン', '高知市', 'コウチシ', '佐々木町', 'ササキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市旭天神町', '39', '39201', '7800955', '高知県', 'コウチケン', '高知市', 'コウチシ', '旭天神町', 'アサヒテンジンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市北端町', '39', '39201', '7800956', '高知県', 'コウチケン', '高知市', 'コウチシ', '北端町', 'キタバタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市山手町', '39', '39201', '7800957', '高知県', 'コウチケン', '高知市', 'コウチシ', '山手町', 'ヤマテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市蓮台', '39', '39201', '7800961', '高知県', 'コウチケン', '高知市', 'コウチシ', '蓮台', 'レンダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市尾立', '39', '39201', '7800962', '高知県', 'コウチケン', '高知市', 'コウチシ', '尾立', 'ヒジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市口細山', '39', '39201', '7800963', '高知県', 'コウチケン', '高知市', 'コウチシ', '口細山', 'クチホソヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市横内', '39', '39201', '7800964', '高知県', 'コウチケン', '高知市', 'コウチシ', '横内', 'ヨコウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市福井町', '39', '39201', '7800965', '高知県', 'コウチケン', '高知市', 'コウチシ', '福井町', 'フクイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市福井扇町', '39', '39201', '7800966', '高知県', 'コウチケン', '高知市', 'コウチシ', '福井扇町', 'フクイオウギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市福井東町', '39', '39201', '7800967', '高知県', 'コウチケン', '高知市', 'コウチシ', '福井東町', 'フクイヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市南万々', '39', '39201', '7800971', '高知県', 'コウチケン', '高知市', 'コウチシ', '南万々', 'ミナミママ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市中万々', '39', '39201', '7800972', '高知県', 'コウチケン', '高知市', 'コウチシ', '中万々', 'ナカママ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市万々', '39', '39201', '7800973', '高知県', 'コウチケン', '高知市', 'コウチシ', '万々', 'ママ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市円行寺', '39', '39201', '7800974', '高知県', 'コウチケン', '高知市', 'コウチシ', '円行寺', 'エンギョウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市柴巻', '39', '39201', '7800975', '高知県', 'コウチケン', '高知市', 'コウチシ', '柴巻', 'シバマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市みづき', '39', '39201', '7800976', '高知県', 'コウチケン', '高知市', 'コウチシ', 'みづき', 'ミヅキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市みづき山', '39', '39201', '7800977', '高知県', 'コウチケン', '高知市', 'コウチシ', 'みづき山', 'ミヅキヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市一ツ橋町', '39', '39201', '7800981', '高知県', 'コウチケン', '高知市', 'コウチシ', '一ツ橋町', 'ヒトツバシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市東久万', '39', '39201', '7800982', '高知県', 'コウチケン', '高知市', 'コウチシ', '東久万', 'ヒガシクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市中久万', '39', '39201', '7800983', '高知県', 'コウチケン', '高知市', 'コウチシ', '中久万', 'ナカクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市西久万', '39', '39201', '7800984', '高知県', 'コウチケン', '高知市', 'コウチシ', '西久万', 'ニシクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市南久万', '39', '39201', '7800985', '高知県', 'コウチケン', '高知市', 'コウチシ', '南久万', 'ミナミクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市宗安寺', '39', '39201', '7800991', '高知県', 'コウチケン', '高知市', 'コウチシ', '宗安寺', 'ソウアンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市行川', '39', '39201', '7800992', '高知県', 'コウチケン', '高知市', 'コウチシ', '行川', 'ナメガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市針原', '39', '39201', '7800993', '高知県', 'コウチケン', '高知市', 'コウチシ', '針原', 'ハリハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市唐岩', '39', '39201', '7800994', '高知県', 'コウチケン', '高知市', 'コウチシ', '唐岩', 'カライワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市領家', '39', '39201', '7800995', '高知県', 'コウチケン', '高知市', 'コウチシ', '領家', 'リョウケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市上里', '39', '39201', '7800996', '高知県', 'コウチケン', '高知市', 'コウチシ', '上里', 'ジョウリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道深川市納内町', '01', '01228', '0780151', '北海道', 'ホッカイドウ', '深川市', 'フカガワシ', '納内町', 'オサムナイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道深川市音江町内園', '01', '01228', '0780152', '北海道', 'ホッカイドウ', '深川市', 'フカガワシ', '音江町', 'オトエチョウ', null, null, '内園', 'ウチゾノ');
INSERT INTO `ms_addresses` VALUES ('98094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道深川市納内町北', '01', '01228', '0780153', '北海道', 'ホッカイドウ', '深川市', 'フカガワシ', '納内町北', 'オサムナイチョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道深川市納内町グリーンタウン', '01', '01228', '0780154', '北海道', 'ホッカイドウ', '深川市', 'フカガワシ', '納内町グリーンタウン', 'オサムナイチョウグリーンタウン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市神居町神居古潭', '01', '01204', '0780185', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '神居町神居古潭', 'カムイチョウカムイコタン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市神居町西丘', '01', '01204', '0780186', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '神居町西丘', 'カムイチョウニシオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡比布町', '01', '01455', '0780300', '北海道', 'ホッカイドウ', '上川郡比布町', 'カミカワグンピップチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('98099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡比布町基線', '01', '01455', '0780310', '北海道', 'ホッカイドウ', '上川郡比布町', 'カミカワグンピップチョウ', '基線', 'キセン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡比布町南1線', '01', '01455', '0780311', '北海道', 'ホッカイドウ', '上川郡比布町', 'カミカワグンピップチョウ', '南1線', 'ミナミ01セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡比布町北1線', '01', '01455', '0780321', '北海道', 'ホッカイドウ', '上川郡比布町', 'カミカワグンピップチョウ', '北1線', 'キタ01セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡比布町北2線', '01', '01455', '0780322', '北海道', 'ホッカイドウ', '上川郡比布町', 'カミカワグンピップチョウ', '北2線', 'キタ02セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡比布町北3線', '01', '01455', '0780323', '北海道', 'ホッカイドウ', '上川郡比布町', 'カミカワグンピップチョウ', '北3線', 'キタ03セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡比布町北4線', '01', '01455', '0780324', '北海道', 'ホッカイドウ', '上川郡比布町', 'カミカワグンピップチョウ', '北4線', 'キタ04セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡比布町北5線', '01', '01455', '0780325', '北海道', 'ホッカイドウ', '上川郡比布町', 'カミカワグンピップチョウ', '北5線', 'キタ05セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡比布町北6線', '01', '01455', '0780326', '北海道', 'ホッカイドウ', '上川郡比布町', 'カミカワグンピップチョウ', '北6線', 'キタ06セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡比布町北7線', '01', '01455', '0780327', '北海道', 'ホッカイドウ', '上川郡比布町', 'カミカワグンピップチョウ', '北7線', 'キタ07セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡比布町北8線', '01', '01455', '0780328', '北海道', 'ホッカイドウ', '上川郡比布町', 'カミカワグンピップチョウ', '北8線', 'キタ08セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡比布町北9線', '01', '01455', '0780329', '北海道', 'ホッカイドウ', '上川郡比布町', 'カミカワグンピップチョウ', '北9線', 'キタ09セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡比布町北10線', '01', '01455', '0780330', '北海道', 'ホッカイドウ', '上川郡比布町', 'カミカワグンピップチョウ', '北10線', 'キタ10セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡比布町北11線', '01', '01455', '0780331', '北海道', 'ホッカイドウ', '上川郡比布町', 'カミカワグンピップチョウ', '北11線', 'キタ11セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡比布町北12線', '01', '01455', '0780332', '北海道', 'ホッカイドウ', '上川郡比布町', 'カミカワグンピップチョウ', '北12線', 'キタ12セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡比布町北13線', '01', '01455', '0780333', '北海道', 'ホッカイドウ', '上川郡比布町', 'カミカワグンピップチョウ', '北13線', 'キタ13セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡比布町北14線', '01', '01455', '0780334', '北海道', 'ホッカイドウ', '上川郡比布町', 'カミカワグンピップチョウ', '北14線', 'キタ14セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡比布町北15線', '01', '01455', '0780335', '北海道', 'ホッカイドウ', '上川郡比布町', 'カミカワグンピップチョウ', '北15線', 'キタ15セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡比布町市街地', '01', '01455', '0780341', '北海道', 'ホッカイドウ', '上川郡比布町', 'カミカワグンピップチョウ', '市街地', 'シガイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡比布町西町', '01', '01455', '0780342', '北海道', 'ホッカイドウ', '上川郡比布町', 'カミカワグンピップチョウ', '西町', 'ニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡比布町中町', '01', '01455', '0780343', '北海道', 'ホッカイドウ', '上川郡比布町', 'カミカワグンピップチョウ', '中町', 'ナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡比布町緑町', '01', '01455', '0780344', '北海道', 'ホッカイドウ', '上川郡比布町', 'カミカワグンピップチョウ', '緑町', 'ミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡比布町南町', '01', '01455', '0780345', '北海道', 'ホッカイドウ', '上川郡比布町', 'カミカワグンピップチョウ', '南町', 'ミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡比布町新町', '01', '01455', '0780346', '北海道', 'ホッカイドウ', '上川郡比布町', 'カミカワグンピップチョウ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡比布町東町', '01', '01455', '0780347', '北海道', 'ホッカイドウ', '上川郡比布町', 'カミカワグンピップチョウ', '東町', 'ヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡比布町北町', '01', '01455', '0780348', '北海道', 'ホッカイドウ', '上川郡比布町', 'カミカワグンピップチョウ', '北町', 'キタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡比布町寿町', '01', '01455', '0780349', '北海道', 'ホッカイドウ', '上川郡比布町', 'カミカワグンピップチョウ', '寿町', 'コトブキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市土居町', '39', '39201', '7808001', '高知県', 'コウチケン', '高知市', 'コウチシ', '土居町', 'ドイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市役知町', '39', '39201', '7808002', '高知県', 'コウチケン', '高知市', 'コウチシ', '役知町', 'ヤクチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市北新田町', '39', '39201', '7808003', '高知県', 'コウチケン', '高知市', 'コウチシ', '北新田町', 'キタシンタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市新田町', '39', '39201', '7808004', '高知県', 'コウチケン', '高知市', 'コウチシ', '新田町', 'シンタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市南新田町', '39', '39201', '7808005', '高知県', 'コウチケン', '高知市', 'コウチシ', '南新田町', 'ミナミシンタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市萩町', '39', '39201', '7808006', '高知県', 'コウチケン', '高知市', 'コウチシ', '萩町', 'ハギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市仲田町', '39', '39201', '7808007', '高知県', 'コウチケン', '高知市', 'コウチシ', '仲田町', 'ナカタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市潮新町', '39', '39201', '7808008', '高知県', 'コウチケン', '高知市', 'コウチシ', '潮新町', 'ウシオシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市桟橋通', '39', '39201', '7808010', '高知県', 'コウチケン', '高知市', 'コウチシ', '桟橋通', 'サンバシドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市梅ノ辻', '39', '39201', '7808011', '高知県', 'コウチケン', '高知市', 'コウチシ', '梅ノ辻', 'ウメノツジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市天神町', '39', '39201', '7808012', '高知県', 'コウチケン', '高知市', 'コウチシ', '天神町', 'テンジンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市筆山町', '39', '39201', '7808013', '高知県', 'コウチケン', '高知市', 'コウチシ', '筆山町', 'ヒツザンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市塩屋崎町', '39', '39201', '7808014', '高知県', 'コウチケン', '高知市', 'コウチシ', '塩屋崎町', 'シオヤザキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市百石町', '39', '39201', '7808015', '高知県', 'コウチケン', '高知市', 'コウチシ', '百石町', 'ヒャッコクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市南ノ丸町', '39', '39201', '7808016', '高知県', 'コウチケン', '高知市', 'コウチシ', '南ノ丸町', 'ミナミノマルチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市南竹島町', '39', '39201', '7808017', '高知県', 'コウチケン', '高知市', 'コウチシ', '南竹島町', 'ミナミタケシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市竹島町', '39', '39201', '7808018', '高知県', 'コウチケン', '高知市', 'コウチシ', '竹島町', 'タケシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市北竹島町', '39', '39201', '7808019', '高知県', 'コウチケン', '高知市', 'コウチシ', '北竹島町', 'キタタケシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市孕東町', '39', '39201', '7808021', '高知県', 'コウチケン', '高知市', 'コウチシ', '孕東町', 'ハラミヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市孕西町', '39', '39201', '7808022', '高知県', 'コウチケン', '高知市', 'コウチシ', '孕西町', 'ハラミニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市六泉寺町', '39', '39201', '7808023', '高知県', 'コウチケン', '高知市', 'コウチシ', '六泉寺町', 'ロクセンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市深谷町', '39', '39201', '7808024', '高知県', 'コウチケン', '高知市', 'コウチシ', '深谷町', 'フカダニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市南中山', '39', '39201', '7808025', '高知県', 'コウチケン', '高知市', 'コウチシ', '南中山', 'ミナミナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市北中山', '39', '39201', '7808026', '高知県', 'コウチケン', '高知市', 'コウチシ', '北中山', 'キタナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市高見町', '39', '39201', '7808027', '高知県', 'コウチケン', '高知市', 'コウチシ', '高見町', 'タカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市北高見町', '39', '39201', '7808028', '高知県', 'コウチケン', '高知市', 'コウチシ', '北高見町', 'キタタカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市大原町', '39', '39201', '7808031', '高知県', 'コウチケン', '高知市', 'コウチシ', '大原町', 'オオハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市小石木町', '39', '39201', '7808032', '高知県', 'コウチケン', '高知市', 'コウチシ', '小石木町', 'コイシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市幸崎', '39', '39201', '7808033', '高知県', 'コウチケン', '高知市', 'コウチシ', '幸崎', 'コウザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市南河ノ瀬町', '39', '39201', '7808034', '高知県', 'コウチケン', '高知市', 'コウチシ', '南河ノ瀬町', 'ミナミゴウノセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市河ノ瀬町', '39', '39201', '7808035', '高知県', 'コウチケン', '高知市', 'コウチシ', '河ノ瀬町', 'ゴウノセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市東城山町', '39', '39201', '7808036', '高知県', 'コウチケン', '高知市', 'コウチシ', '東城山町', 'ヒガシジョウヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市城山町', '39', '39201', '7808037', '高知県', 'コウチケン', '高知市', 'コウチシ', '城山町', 'ジョウヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市石立町', '39', '39201', '7808038', '高知県', 'コウチケン', '高知市', 'コウチシ', '石立町', 'イシタテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市東石立町', '39', '39201', '7808039', '高知県', 'コウチケン', '高知市', 'コウチシ', '東石立町', 'ヒガシイシタテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市神田', '39', '39201', '7808040', '高知県', 'コウチケン', '高知市', 'コウチシ', '神田', 'コウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市鴨部', '39', '39201', '7808050', '高知県', 'コウチケン', '高知市', 'コウチシ', '鴨部', 'カモベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市鴨部上町', '39', '39201', '7808051', '高知県', 'コウチケン', '高知市', 'コウチシ', '鴨部上町', 'カモベカミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市鴨部', '39', '39201', '7808052', '高知県', 'コウチケン', '高知市', 'コウチシ', '鴨部', 'カモベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市朝倉甲', '39', '39201', '7808061', '高知県', 'コウチケン', '高知市', 'コウチシ', '朝倉甲', 'アサクラコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市朝倉乙', '39', '39201', '7808062', '高知県', 'コウチケン', '高知市', 'コウチシ', '朝倉乙', 'アサクラオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市朝倉丙', '39', '39201', '7808063', '高知県', 'コウチケン', '高知市', 'コウチシ', '朝倉丙', 'アサクラヘイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市朝倉丁', '39', '39201', '7808064', '高知県', 'コウチケン', '高知市', 'コウチシ', '朝倉丁', 'アサクラテイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市朝倉戊', '39', '39201', '7808065', '高知県', 'コウチケン', '高知市', 'コウチシ', '朝倉戊', 'アサクラボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市朝倉己', '39', '39201', '7808066', '高知県', 'コウチケン', '高知市', 'コウチシ', '朝倉己', 'アサクラキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市鴨部高町', '39', '39201', '7808071', '高知県', 'コウチケン', '高知市', 'コウチシ', '鴨部高町', 'カモベタカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市曙町', '39', '39201', '7808072', '高知県', 'コウチケン', '高知市', 'コウチシ', '曙町', 'アケボノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市朝倉本町', '39', '39201', '7808073', '高知県', 'コウチケン', '高知市', 'コウチシ', '朝倉本町', 'アサクラホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市朝倉横町', '39', '39201', '7808074', '高知県', 'コウチケン', '高知市', 'コウチシ', '朝倉横町', 'アサクラヨコマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市朝倉南町', '39', '39201', '7808075', '高知県', 'コウチケン', '高知市', 'コウチシ', '朝倉南町', 'アサクラミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市朝倉東町', '39', '39201', '7808076', '高知県', 'コウチケン', '高知市', 'コウチシ', '朝倉東町', 'アサクラヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市朝倉西町', '39', '39201', '7808077', '高知県', 'コウチケン', '高知市', 'コウチシ', '朝倉西町', 'アサクラニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市若草町', '39', '39201', '7808081', '高知県', 'コウチケン', '高知市', 'コウチシ', '若草町', 'ワカクサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市若草南町', '39', '39201', '7808082', '高知県', 'コウチケン', '高知市', 'コウチシ', '若草南町', 'ワカクサミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市鵜来巣', '39', '39201', '7808083', '高知県', 'コウチケン', '高知市', 'コウチシ', '鵜来巣', 'ウグルス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市槇山町', '39', '39201', '7808084', '高知県', 'コウチケン', '高知市', 'コウチシ', '槇山町', 'マキヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市大谷公園町', '39', '39201', '7808085', '高知県', 'コウチケン', '高知市', 'コウチシ', '大谷公園町', 'オオタニコウエンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市針木東町', '39', '39201', '7808086', '高知県', 'コウチケン', '高知市', 'コウチシ', '針木東町', 'ハリギヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市針木北', '39', '39201', '7808087', '高知県', 'コウチケン', '高知市', 'コウチシ', '針木北', 'ハリギキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市針木本町', '39', '39201', '7808088', '高知県', 'コウチケン', '高知市', 'コウチシ', '針木本町', 'ハリギホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市針木南', '39', '39201', '7808089', '高知県', 'コウチケン', '高知市', 'コウチシ', '針木南', 'ハリギミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市針木西', '39', '39201', '7808090', '高知県', 'コウチケン', '高知市', 'コウチシ', '針木西', 'ハリギニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市薊野', '39', '39201', '7810010', '高知県', 'コウチケン', '高知市', 'コウチシ', '薊野', 'アゾウノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市薊野北町', '39', '39201', '7810011', '高知県', 'コウチケン', '高知市', 'コウチシ', '薊野北町', 'アゾウノキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市薊野東町', '39', '39201', '7810012', '高知県', 'コウチケン', '高知市', 'コウチシ', '薊野東町', 'アゾウノヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市薊野中町', '39', '39201', '7810013', '高知県', 'コウチケン', '高知市', 'コウチシ', '薊野中町', 'アゾウノナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市薊野南町', '39', '39201', '7810014', '高知県', 'コウチケン', '高知市', 'コウチシ', '薊野南町', 'アゾウノミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市薊野西町', '39', '39201', '7810015', '高知県', 'コウチケン', '高知市', 'コウチシ', '薊野西町', 'アゾウノニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市池', '39', '39201', '7810111', '高知県', 'コウチケン', '高知市', 'コウチシ', '池', 'イケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市仁井田', '39', '39201', '7810112', '高知県', 'コウチケン', '高知市', 'コウチシ', '仁井田', 'ニイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市種崎', '39', '39201', '7810113', '高知県', 'コウチケン', '高知市', 'コウチシ', '種崎', 'タネザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市十津', '39', '39201', '7810114', '高知県', 'コウチケン', '高知市', 'コウチシ', '十津', 'トオズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市横浜', '39', '39201', '7810240', '高知県', 'コウチケン', '高知市', 'コウチシ', '横浜', 'ヨコハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市横浜新町', '39', '39201', '7810241', '高知県', 'コウチケン', '高知市', 'コウチシ', '横浜新町', 'ヨコハマシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市横浜西町', '39', '39201', '7810242', '高知県', 'コウチケン', '高知市', 'コウチシ', '横浜西町', 'ヨコハマニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市横浜東町', '39', '39201', '7810243', '高知県', 'コウチケン', '高知市', 'コウチシ', '横浜東町', 'ヨコハマヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市横浜南町', '39', '39201', '7810244', '高知県', 'コウチケン', '高知市', 'コウチシ', '横浜南町', 'ヨコハマミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市長浜蒔絵台', '39', '39201', '7810245', '高知県', 'コウチケン', '高知市', 'コウチシ', '長浜蒔絵台', 'ナガハママキエダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市瀬戸', '39', '39201', '7810250', '高知県', 'コウチケン', '高知市', 'コウチシ', '瀬戸', 'セト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市瀬戸西町', '39', '39201', '7810251', '高知県', 'コウチケン', '高知市', 'コウチシ', '瀬戸西町', 'セトニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市瀬戸東町', '39', '39201', '7810252', '高知県', 'コウチケン', '高知市', 'コウチシ', '瀬戸東町', 'セトヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市瀬戸南町', '39', '39201', '7810253', '高知県', 'コウチケン', '高知市', 'コウチシ', '瀬戸南町', 'セトミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市御畳瀬', '39', '39201', '7810261', '高知県', 'コウチケン', '高知市', 'コウチシ', '御畳瀬', 'ミマセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市浦戸', '39', '39201', '7810262', '高知県', 'コウチケン', '高知市', 'コウチシ', '浦戸', 'ウラド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市長浜', '39', '39201', '7810270', '高知県', 'コウチケン', '高知市', 'コウチシ', '長浜', 'ナガハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市長浜宮田', '39', '39201', '7810271', '高知県', 'コウチケン', '高知市', 'コウチシ', '長浜宮田', 'ナガハマミヤタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市春野町弘岡上', '39', '39201', '7810301', '高知県', 'コウチケン', '高知市', 'コウチシ', '春野町弘岡上', 'ハルノチョウヒロオカカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市春野町弘岡中', '39', '39201', '7810302', '高知県', 'コウチケン', '高知市', 'コウチシ', '春野町弘岡中', 'ハルノチョウヒロオカナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市春野町弘岡下', '39', '39201', '7810303', '高知県', 'コウチケン', '高知市', 'コウチシ', '春野町弘岡下', 'ハルノチョウヒロオカシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市春野町西分', '39', '39201', '7810304', '高知県', 'コウチケン', '高知市', 'コウチシ', '春野町西分', 'ハルノチョウニシブン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市春野町芳原', '39', '39201', '7810311', '高知県', 'コウチケン', '高知市', 'コウチシ', '春野町芳原', 'ハルノチョウヨシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市春野町平和', '39', '39201', '7810312', '高知県', 'コウチケン', '高知市', 'コウチシ', '春野町平和', 'ハルノチョウヘイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市春野町内ノ谷', '39', '39201', '7810313', '高知県', 'コウチケン', '高知市', 'コウチシ', '春野町内ノ谷', 'ハルノチョウウチノタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市春野町南ケ丘', '39', '39201', '7810314', '高知県', 'コウチケン', '高知市', 'コウチシ', '春野町南ケ丘', 'ハルノチョウミナミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市春野町東諸木', '39', '39201', '7810315', '高知県', 'コウチケン', '高知市', 'コウチシ', '春野町東諸木', 'ハルノチョウヒガシモロギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市春野町西諸木', '39', '39201', '7810316', '高知県', 'コウチケン', '高知市', 'コウチシ', '春野町西諸木', 'ハルノチョウニシモロギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市春野町秋山', '39', '39201', '7810321', '高知県', 'コウチケン', '高知市', 'コウチシ', '春野町秋山', 'ハルノチョウアキヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市春野町甲殿', '39', '39201', '7810322', '高知県', 'コウチケン', '高知市', 'コウチシ', '春野町甲殿', 'ハルノチョウコウドノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市春野町仁ノ', '39', '39201', '7810323', '高知県', 'コウチケン', '高知市', 'コウチシ', '春野町仁ノ', 'ハルノチョウニノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市春野町西畑', '39', '39201', '7810324', '高知県', 'コウチケン', '高知市', 'コウチシ', '春野町西畑', 'ハルノチョウサイバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市春野町森山', '39', '39201', '7810325', '高知県', 'コウチケン', '高知市', 'コウチシ', '春野町森山', 'ハルノチョウモリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐市', '39', '39205', '7811100', '高知県', 'コウチケン', '土佐市', 'トサシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('98294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐市高岡町甲', '39', '39205', '7811101', '高知県', 'コウチケン', '土佐市', 'トサシ', '高岡町甲', 'タカオカチョウコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐市高岡町乙', '39', '39205', '7811102', '高知県', 'コウチケン', '土佐市', 'トサシ', '高岡町乙', 'タカオカチョウオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐市高岡町丙', '39', '39205', '7811103', '高知県', 'コウチケン', '土佐市', 'トサシ', '高岡町丙', 'タカオカチョウヘイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐市高岡町丁', '39', '39205', '7811104', '高知県', 'コウチケン', '土佐市', 'トサシ', '高岡町丁', 'タカオカチョウテイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐市蓮池', '39', '39205', '7811105', '高知県', 'コウチケン', '土佐市', 'トサシ', '蓮池', 'ハスイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐市北地', '39', '39205', '7811111', '高知県', 'コウチケン', '土佐市', 'トサシ', '北地', 'キタジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐市福田', '39', '39205', '7811112', '高知県', 'コウチケン', '土佐市', 'トサシ', '福田', 'フクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐市甲原', '39', '39205', '7811113', '高知県', 'コウチケン', '土佐市', 'トサシ', '甲原', 'カンバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐市谷地', '39', '39205', '7811114', '高知県', 'コウチケン', '土佐市', 'トサシ', '谷地', 'ヤツジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐市東鴨地', '39', '39205', '7811121', '高知県', 'コウチケン', '土佐市', 'トサシ', '東鴨地', 'ヒガシカモジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐市本村', '39', '39205', '7811122', '高知県', 'コウチケン', '土佐市', 'トサシ', '本村', 'ホンムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐市西鴨地', '39', '39205', '7811123', '高知県', 'コウチケン', '土佐市', 'トサシ', '西鴨地', 'ニシカモジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐市宮ノ内', '39', '39205', '7811124', '高知県', 'コウチケン', '土佐市', 'トサシ', '宮ノ内', 'ミヤノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐市積善寺', '39', '39205', '7811125', '高知県', 'コウチケン', '土佐市', 'トサシ', '積善寺', 'シャクゼンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐市永野', '39', '39205', '7811131', '高知県', 'コウチケン', '土佐市', 'トサシ', '永野', 'ナガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐市市野々', '39', '39205', '7811132', '高知県', 'コウチケン', '土佐市', 'トサシ', '市野々', 'イチノノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐市鷹ノ巣', '39', '39205', '7811133', '高知県', 'コウチケン', '土佐市', 'トサシ', '鷹ノ巣', 'タカノス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐市家俊', '39', '39205', '7811134', '高知県', 'コウチケン', '土佐市', 'トサシ', '家俊', 'イエトシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐市太郎丸', '39', '39205', '7811135', '高知県', 'コウチケン', '土佐市', 'トサシ', '太郎丸', 'タロウマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐市浅井', '39', '39205', '7811136', '高知県', 'コウチケン', '土佐市', 'トサシ', '浅井', 'アザイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐市岩戸', '39', '39205', '7811141', '高知県', 'コウチケン', '土佐市', 'トサシ', '岩戸', 'イワト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐市出間', '39', '39205', '7811142', '高知県', 'コウチケン', '土佐市', 'トサシ', '出間', 'イズマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐市波介', '39', '39205', '7811143', '高知県', 'コウチケン', '土佐市', 'トサシ', '波介', 'ハゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐市中島', '39', '39205', '7811151', '高知県', 'コウチケン', '土佐市', 'トサシ', '中島', 'ナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐市用石', '39', '39205', '7811152', '高知県', 'コウチケン', '土佐市', 'トサシ', '用石', 'モチイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐市塚地', '39', '39205', '7811153', '高知県', 'コウチケン', '土佐市', 'トサシ', '塚地', 'ツカジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐市新居', '39', '39205', '7811154', '高知県', 'コウチケン', '土佐市', 'トサシ', '新居', 'ニイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐市宇佐町宇佐', '39', '39205', '7811161', '高知県', 'コウチケン', '土佐市', 'トサシ', '宇佐町宇佐', 'ウサチョウウサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐市宇佐町渭浜', '39', '39205', '7811162', '高知県', 'コウチケン', '土佐市', 'トサシ', '宇佐町渭浜', 'ウサチョウイハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐市宇佐町福島', '39', '39205', '7811163', '高知県', 'コウチケン', '土佐市', 'トサシ', '宇佐町福島', 'ウサチョウフクシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐市宇佐町井尻', '39', '39205', '7811164', '高知県', 'コウチケン', '土佐市', 'トサシ', '宇佐町井尻', 'ウサチョウイジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐市宇佐町竜', '39', '39205', '7811165', '高知県', 'コウチケン', '土佐市', 'トサシ', '宇佐町竜', 'ウサチョウリュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡越知町', '39', '39403', '7811300', '高知県', 'コウチケン', '高岡郡越知町', 'タカオカグンオチチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('98328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡越知町越知甲', '39', '39403', '7811301', '高知県', 'コウチケン', '高岡郡越知町', 'タカオカグンオチチョウ', '越知甲', 'オチコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡越知町越知乙', '39', '39403', '7811302', '高知県', 'コウチケン', '高岡郡越知町', 'タカオカグンオチチョウ', '越知乙', 'オチオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡越知町越知丙', '39', '39403', '7811303', '高知県', 'コウチケン', '高岡郡越知町', 'タカオカグンオチチョウ', '越知丙', 'オチヘイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡越知町越知丁', '39', '39403', '7811304', '高知県', 'コウチケン', '高岡郡越知町', 'タカオカグンオチチョウ', '越知丁', 'オチテイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡越知町野老山', '39', '39403', '7811305', '高知県', 'コウチケン', '高岡郡越知町', 'タカオカグンオチチョウ', '野老山', 'トコロヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡越知町山室', '39', '39403', '7811306', '高知県', 'コウチケン', '高岡郡越知町', 'タカオカグンオチチョウ', '山室', 'ヤマムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡越知町柴尾', '39', '39403', '7811307', '高知県', 'コウチケン', '高岡郡越知町', 'タカオカグンオチチョウ', '柴尾', 'シボオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡越知町宮地', '39', '39403', '7811308', '高知県', 'コウチケン', '高岡郡越知町', 'タカオカグンオチチョウ', '宮地', 'ミヤジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡越知町今成', '39', '39403', '7811311', '高知県', 'コウチケン', '高岡郡越知町', 'タカオカグンオチチョウ', '今成', 'イマナリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡越知町横畠南', '39', '39403', '7811312', '高知県', 'コウチケン', '高岡郡越知町', 'タカオカグンオチチョウ', '横畠南', 'ヨコバタケミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡越知町横畠東', '39', '39403', '7811313', '高知県', 'コウチケン', '高岡郡越知町', 'タカオカグンオチチョウ', '横畠東', 'ヨコバタケヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡越知町横畠中', '39', '39403', '7811314', '高知県', 'コウチケン', '高岡郡越知町', 'タカオカグンオチチョウ', '横畠中', 'ヨコバタケナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡越知町横畠北', '39', '39403', '7811315', '高知県', 'コウチケン', '高岡郡越知町', 'タカオカグンオチチョウ', '横畠北', 'ヨコバタケキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡越知町鎌井田本村', '39', '39403', '7811321', '高知県', 'コウチケン', '高岡郡越知町', 'タカオカグンオチチョウ', '鎌井田本村', 'カマイダホンソン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡越知町鎌井田桑薮', '39', '39403', '7811322', '高知県', 'コウチケン', '高岡郡越知町', 'タカオカグンオチチョウ', '鎌井田桑薮', 'カマイダクヤブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡越知町鎌井田日ノ浦', '39', '39403', '7811323', '高知県', 'コウチケン', '高岡郡越知町', 'タカオカグンオチチョウ', '鎌井田日ノ浦', 'カマイダヒノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡越知町鎌井田清助', '39', '39403', '7811324', '高知県', 'コウチケン', '高岡郡越知町', 'タカオカグンオチチョウ', '鎌井田清助', 'カマイダセイスケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡越知町浅尾', '39', '39403', '7811325', '高知県', 'コウチケン', '高岡郡越知町', 'タカオカグンオチチョウ', '浅尾', 'アソオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡越知町片岡', '39', '39403', '7811326', '高知県', 'コウチケン', '高岡郡越知町', 'タカオカグンオチチョウ', '片岡', 'カタオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡越知町黒瀬', '39', '39403', '7811327', '高知県', 'コウチケン', '高岡郡越知町', 'タカオカグンオチチョウ', '黒瀬', 'クロセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡越知町南片岡', '39', '39403', '7811328', '高知県', 'コウチケン', '高岡郡越知町', 'タカオカグンオチチョウ', '南片岡', 'ミナミカタオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡越知町五味', '39', '39403', '7811331', '高知県', 'コウチケン', '高岡郡越知町', 'タカオカグンオチチョウ', '五味', 'ゴミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡越知町中大平', '39', '39403', '7811332', '高知県', 'コウチケン', '高岡郡越知町', 'タカオカグンオチチョウ', '中大平', 'ナカオオヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡越知町大平', '39', '39403', '7811333', '高知県', 'コウチケン', '高岡郡越知町', 'タカオカグンオチチョウ', '大平', 'オオヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡越知町桐見川', '39', '39403', '7811334', '高知県', 'コウチケン', '高岡郡越知町', 'タカオカグンオチチョウ', '桐見川', 'キリミガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡越知町長者', '39', '39403', '7811335', '高知県', 'コウチケン', '高岡郡越知町', 'タカオカグンオチチョウ', '長者', 'チョウジャ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡越知町南ノ川', '39', '39403', '7811336', '高知県', 'コウチケン', '高岡郡越知町', 'タカオカグンオチチョウ', '南ノ川', 'ミナミノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡越知町佐之国', '39', '39403', '7811337', '高知県', 'コウチケン', '高岡郡越知町', 'タカオカグンオチチョウ', '佐之国', 'サノクニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡越知町峰', '39', '39403', '7811338', '高知県', 'コウチケン', '高岡郡越知町', 'タカオカグンオチチョウ', '峰', 'ミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡仁淀川町', '39', '39387', '7811500', '高知県', 'コウチケン', '吾川郡仁淀川町', 'アガワグンニヨドガワチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('98358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡仁淀川町大崎', '39', '39387', '7811501', '高知県', 'コウチケン', '吾川郡仁淀川町', 'アガワグンニヨドガワチョウ', '大崎', 'オオサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡仁淀川町川口', '39', '39387', '7811502', '高知県', 'コウチケン', '吾川郡仁淀川町', 'アガワグンニヨドガワチョウ', '川口', 'カワグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡仁淀川町橘谷', '39', '39387', '7811503', '高知県', 'コウチケン', '吾川郡仁淀川町', 'アガワグンニヨドガワチョウ', '橘谷', 'タチバナダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡仁淀川町藤ノ野', '39', '39387', '7811504', '高知県', 'コウチケン', '吾川郡仁淀川町', 'アガワグンニヨドガワチョウ', '藤ノ野', 'フジノノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡仁淀川町桜', '39', '39387', '7811505', '高知県', 'コウチケン', '吾川郡仁淀川町', 'アガワグンニヨドガワチョウ', '桜', 'サクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡仁淀川町鹿森', '39', '39387', '7811506', '高知県', 'コウチケン', '吾川郡仁淀川町', 'アガワグンニヨドガワチョウ', '鹿森', 'シシモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡仁淀川町寺村', '39', '39387', '7811511', '高知県', 'コウチケン', '吾川郡仁淀川町', 'アガワグンニヨドガワチョウ', '寺村', 'テラムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡仁淀川町岩戸', '39', '39387', '7811512', '高知県', 'コウチケン', '吾川郡仁淀川町', 'アガワグンニヨドガワチョウ', '岩戸', 'イワド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡仁淀川町峯岩戸', '39', '39387', '7811513', '高知県', 'コウチケン', '吾川郡仁淀川町', 'アガワグンニヨドガワチョウ', '峯岩戸', 'ミネイワド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡仁淀川町大板', '39', '39387', '7811514', '高知県', 'コウチケン', '吾川郡仁淀川町', 'アガワグンニヨドガワチョウ', '大板', 'オオイタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡仁淀川町蕨谷', '39', '39387', '7811515', '高知県', 'コウチケン', '吾川郡仁淀川町', 'アガワグンニヨドガワチョウ', '蕨谷', 'ワラビダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡仁淀川町中村', '39', '39387', '7811516', '高知県', 'コウチケン', '吾川郡仁淀川町', 'アガワグンニヨドガワチョウ', '中村', 'ナカムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡仁淀川町葛原', '39', '39387', '7811517', '高知県', 'コウチケン', '吾川郡仁淀川町', 'アガワグンニヨドガワチョウ', '葛原', 'クズワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡仁淀川町加枝', '39', '39387', '7811518', '高知県', 'コウチケン', '吾川郡仁淀川町', 'アガワグンニヨドガワチョウ', '加枝', 'カエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡仁淀川町大蕨', '39', '39387', '7811520', '高知県', 'コウチケン', '吾川郡仁淀川町', 'アガワグンニヨドガワチョウ', '大蕨', 'オオワラビ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡仁淀川町本村', '39', '39387', '7811521', '高知県', 'コウチケン', '吾川郡仁淀川町', 'アガワグンニヨドガワチョウ', '本村', 'ホンムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡仁淀川町田村', '39', '39387', '7811522', '高知県', 'コウチケン', '吾川郡仁淀川町', 'アガワグンニヨドガワチョウ', '田村', 'タムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡仁淀川町宗津', '39', '39387', '7811523', '高知県', 'コウチケン', '吾川郡仁淀川町', 'アガワグンニヨドガワチョウ', '宗津', 'ソウヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡仁淀川町長屋', '39', '39387', '7811524', '高知県', 'コウチケン', '吾川郡仁淀川町', 'アガワグンニヨドガワチョウ', '長屋', 'ナガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡仁淀川町久喜', '39', '39387', '7811531', '高知県', 'コウチケン', '吾川郡仁淀川町', 'アガワグンニヨドガワチョウ', '久喜', 'クキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡仁淀川町相能', '39', '39387', '7811532', '高知県', 'コウチケン', '吾川郡仁淀川町', 'アガワグンニヨドガワチョウ', '相能', 'アイノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡仁淀川町引地', '39', '39387', '7811533', '高知県', 'コウチケン', '吾川郡仁淀川町', 'アガワグンニヨドガワチョウ', '引地', 'ヒキチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡仁淀川町遅越', '39', '39387', '7811534', '高知県', 'コウチケン', '吾川郡仁淀川町', 'アガワグンニヨドガワチョウ', '遅越', 'オソゴエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡仁淀川町二子野', '39', '39387', '7811535', '高知県', 'コウチケン', '吾川郡仁淀川町', 'アガワグンニヨドガワチョウ', '二子野', 'フタゴノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡仁淀川町大平', '39', '39387', '7811601', '高知県', 'コウチケン', '吾川郡仁淀川町', 'アガワグンニヨドガワチョウ', '大平', 'オオヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡仁淀川町楮原', '39', '39387', '7811602', '高知県', 'コウチケン', '吾川郡仁淀川町', 'アガワグンニヨドガワチョウ', '楮原', 'カジハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡仁淀川町日浦', '39', '39387', '7811603', '高知県', 'コウチケン', '吾川郡仁淀川町', 'アガワグンニヨドガワチョウ', '日浦', 'ヒウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡仁淀川町見ノ越', '39', '39387', '7811604', '高知県', 'コウチケン', '吾川郡仁淀川町', 'アガワグンニヨドガワチョウ', '見ノ越', 'ミノコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡仁淀川町川内谷', '39', '39387', '7811605', '高知県', 'コウチケン', '吾川郡仁淀川町', 'アガワグンニヨドガワチョウ', '川内谷', 'カワウチダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡仁淀川町土居', '39', '39387', '7811606', '高知県', 'コウチケン', '吾川郡仁淀川町', 'アガワグンニヨドガワチョウ', '土居', 'ドイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡仁淀川町北浦', '39', '39387', '7811607', '高知県', 'コウチケン', '吾川郡仁淀川町', 'アガワグンニヨドガワチョウ', '北浦', 'キタウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡仁淀川町坂本', '39', '39387', '7811608', '高知県', 'コウチケン', '吾川郡仁淀川町', 'アガワグンニヨドガワチョウ', '坂本', 'サカモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡仁淀川町寄合', '39', '39387', '7811609', '高知県', 'コウチケン', '吾川郡仁淀川町', 'アガワグンニヨドガワチョウ', '寄合', 'ヨリアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡仁淀川町竹ノ谷', '39', '39387', '7811610', '高知県', 'コウチケン', '吾川郡仁淀川町', 'アガワグンニヨドガワチョウ', '竹ノ谷', 'タケノタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡仁淀川町岩丸', '39', '39387', '7811611', '高知県', 'コウチケン', '吾川郡仁淀川町', 'アガワグンニヨドガワチョウ', '岩丸', 'イワマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡仁淀川町池川大渡', '39', '39387', '7811612', '高知県', 'コウチケン', '吾川郡仁淀川町', 'アガワグンニヨドガワチョウ', '池川大渡', 'イケガワオオド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡仁淀川町明戸岩', '39', '39387', '7811613', '高知県', 'コウチケン', '吾川郡仁淀川町', 'アガワグンニヨドガワチョウ', '明戸岩', 'ミョウトイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡仁淀川町大西', '39', '39387', '7811614', '高知県', 'コウチケン', '吾川郡仁淀川町', 'アガワグンニヨドガワチョウ', '大西', 'オオニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡仁淀川町岩柄', '39', '39387', '7811615', '高知県', 'コウチケン', '吾川郡仁淀川町', 'アガワグンニヨドガワチョウ', '岩柄', 'イワガラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡仁淀川町百川内', '39', '39387', '7811616', '高知県', 'コウチケン', '吾川郡仁淀川町', 'アガワグンニヨドガワチョウ', '百川内', 'モモガワウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡仁淀川町大野', '39', '39387', '7811617', '高知県', 'コウチケン', '吾川郡仁淀川町', 'アガワグンニヨドガワチョウ', '大野', 'オオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡仁淀川町椿山', '39', '39387', '7811618', '高知県', 'コウチケン', '吾川郡仁淀川町', 'アガワグンニヨドガワチョウ', '椿山', 'ツバヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡仁淀川町用居甲出丸', '39', '39387', '7811619', '高知県', 'コウチケン', '吾川郡仁淀川町', 'アガワグンニヨドガワチョウ', '用居甲', 'モチイコウ', null, null, '出丸', 'イズマル');
INSERT INTO `ms_addresses` VALUES ('98402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡仁淀川町用居甲舟形', '39', '39387', '7811619', '高知県', 'コウチケン', '吾川郡仁淀川町', 'アガワグンニヨドガワチョウ', '用居甲', 'モチイコウ', null, null, '舟形', 'フナガタ');
INSERT INTO `ms_addresses` VALUES ('98403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡仁淀川町用居甲用居', '39', '39387', '7811619', '高知県', 'コウチケン', '吾川郡仁淀川町', 'アガワグンニヨドガワチョウ', '用居甲', 'モチイコウ', null, null, '用居', 'モチイ');
INSERT INTO `ms_addresses` VALUES ('98404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡仁淀川町用居乙瓜生野', '39', '39387', '7811620', '高知県', 'コウチケン', '吾川郡仁淀川町', 'アガワグンニヨドガワチョウ', '用居乙', 'モチイオツ', null, null, '瓜生野', 'ウリウノ');
INSERT INTO `ms_addresses` VALUES ('98405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡仁淀川町用居乙折尾', '39', '39387', '7811620', '高知県', 'コウチケン', '吾川郡仁淀川町', 'アガワグンニヨドガワチョウ', '用居乙', 'モチイオツ', null, null, '折尾', 'オリオ');
INSERT INTO `ms_addresses` VALUES ('98406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡仁淀川町用居乙桧谷', '39', '39387', '7811620', '高知県', 'コウチケン', '吾川郡仁淀川町', 'アガワグンニヨドガワチョウ', '用居乙', 'モチイオツ', null, null, '桧谷', 'ヒノキダニ');
INSERT INTO `ms_addresses` VALUES ('98407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡仁淀川町入江谷', '39', '39387', '7811621', '高知県', 'コウチケン', '吾川郡仁淀川町', 'アガワグンニヨドガワチョウ', '入江谷', 'イリエダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡仁淀川町成川', '39', '39387', '7811622', '高知県', 'コウチケン', '吾川郡仁淀川町', 'アガワグンニヨドガワチョウ', '成川', 'ナルガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡仁淀川町余能', '39', '39387', '7811623', '高知県', 'コウチケン', '吾川郡仁淀川町', 'アガワグンニヨドガワチョウ', '余能', 'ヨノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡仁淀川町土居安居土居', '39', '39387', '7811624', '高知県', 'コウチケン', '吾川郡仁淀川町', 'アガワグンニヨドガワチョウ', '土居', 'ドイ', null, null, '安居土居', 'ヤスイドイ');
INSERT INTO `ms_addresses` VALUES ('98411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡仁淀川町吉ケ成', '39', '39387', '7811625', '高知県', 'コウチケン', '吾川郡仁淀川町', 'アガワグンニヨドガワチョウ', '吉ケ成', 'ヨシガナル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡仁淀川町坪井川', '39', '39387', '7811626', '高知県', 'コウチケン', '吾川郡仁淀川町', 'アガワグンニヨドガワチョウ', '坪井川', 'ツボイガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡仁淀川町宮ケ平', '39', '39387', '7811627', '高知県', 'コウチケン', '吾川郡仁淀川町', 'アガワグンニヨドガワチョウ', '宮ケ平', 'ミヤガヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡仁淀川町大屋', '39', '39387', '7811628', '高知県', 'コウチケン', '吾川郡仁淀川町', 'アガワグンニヨドガワチョウ', '大屋', 'オオヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡仁淀川町名野川', '39', '39387', '7811741', '高知県', 'コウチケン', '吾川郡仁淀川町', 'アガワグンニヨドガワチョウ', '名野川', 'ナノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡仁淀川町竹屋敷', '39', '39387', '7811742', '高知県', 'コウチケン', '吾川郡仁淀川町', 'アガワグンニヨドガワチョウ', '竹屋敷', 'タケヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡仁淀川町崎ノ山', '39', '39387', '7811743', '高知県', 'コウチケン', '吾川郡仁淀川町', 'アガワグンニヨドガワチョウ', '崎ノ山', 'サキノヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡仁淀川町名野川大平', '39', '39387', '7811744', '高知県', 'コウチケン', '吾川郡仁淀川町', 'アガワグンニヨドガワチョウ', '名野川大平', 'ナノカワオオヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡仁淀川町下北川', '39', '39387', '7811745', '高知県', 'コウチケン', '吾川郡仁淀川町', 'アガワグンニヨドガワチョウ', '下北川', 'シモキタガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡仁淀川町北川', '39', '39387', '7811746', '高知県', 'コウチケン', '吾川郡仁淀川町', 'アガワグンニヨドガワチョウ', '北川', 'キタガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡仁淀川町大渡', '39', '39387', '7811751', '高知県', 'コウチケン', '吾川郡仁淀川町', 'アガワグンニヨドガワチョウ', '大渡', 'オオド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡仁淀川町峠ノ越', '39', '39387', '7811752', '高知県', 'コウチケン', '吾川郡仁淀川町', 'アガワグンニヨドガワチョウ', '峠ノ越', 'トウノコエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡仁淀川町潰溜', '39', '39387', '7811753', '高知県', 'コウチケン', '吾川郡仁淀川町', 'アガワグンニヨドガワチョウ', '潰溜', 'ツエダマリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡仁淀川町北', '39', '39387', '7811754', '高知県', 'コウチケン', '吾川郡仁淀川町', 'アガワグンニヨドガワチョウ', '北', 'キタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡仁淀川町森山', '39', '39387', '7811755', '高知県', 'コウチケン', '吾川郡仁淀川町', 'アガワグンニヨドガワチョウ', '森山', 'モリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡仁淀川町大尾', '39', '39387', '7811756', '高知県', 'コウチケン', '吾川郡仁淀川町', 'アガワグンニヨドガワチョウ', '大尾', 'オオオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡仁淀川町鷲ノ巣', '39', '39387', '7811757', '高知県', 'コウチケン', '吾川郡仁淀川町', 'アガワグンニヨドガワチョウ', '鷲ノ巣', 'ワシノス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡仁淀川町橘', '39', '39387', '7811758', '高知県', 'コウチケン', '吾川郡仁淀川町', 'アガワグンニヨドガワチョウ', '橘', 'タチバナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡仁淀川町二ノ滝', '39', '39387', '7811761', '高知県', 'コウチケン', '吾川郡仁淀川町', 'アガワグンニヨドガワチョウ', '二ノ滝', 'ニノタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡仁淀川町下名野川', '39', '39387', '7811762', '高知県', 'コウチケン', '吾川郡仁淀川町', 'アガワグンニヨドガワチョウ', '下名野川', 'シモナノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡仁淀川町中', '39', '39387', '7811763', '高知県', 'コウチケン', '吾川郡仁淀川町', 'アガワグンニヨドガワチョウ', '中', 'ナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡仁淀川町長坂', '39', '39387', '7811764', '高知県', 'コウチケン', '吾川郡仁淀川町', 'アガワグンニヨドガワチョウ', '長坂', 'ナガサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡仁淀川町津江', '39', '39387', '7811765', '高知県', 'コウチケン', '吾川郡仁淀川町', 'アガワグンニヨドガワチョウ', '津江', 'ツエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡仁淀川町上名野川', '39', '39387', '7811766', '高知県', 'コウチケン', '吾川郡仁淀川町', 'アガワグンニヨドガワチョウ', '上名野川', 'カミナノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡仁淀川町森', '39', '39387', '7811801', '高知県', 'コウチケン', '吾川郡仁淀川町', 'アガワグンニヨドガワチョウ', '森', 'モリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡仁淀川町高瀬', '39', '39387', '7811802', '高知県', 'コウチケン', '吾川郡仁淀川町', 'アガワグンニヨドガワチョウ', '高瀬', 'タカセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡仁淀川町別枝', '39', '39387', '7811803', '高知県', 'コウチケン', '吾川郡仁淀川町', 'アガワグンニヨドガワチョウ', '別枝', 'ベッシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡仁淀川町川渡', '39', '39387', '7811804', '高知県', 'コウチケン', '吾川郡仁淀川町', 'アガワグンニヨドガワチョウ', '川渡', 'カワド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡仁淀川町長者乙', '39', '39387', '7811911', '高知県', 'コウチケン', '吾川郡仁淀川町', 'アガワグンニヨドガワチョウ', '長者乙', 'チョウジャオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡仁淀川町長者丁', '39', '39387', '7811912', '高知県', 'コウチケン', '吾川郡仁淀川町', 'アガワグンニヨドガワチョウ', '長者丁', 'チョウジャテイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡仁淀川町長者丙', '39', '39387', '7811913', '高知県', 'コウチケン', '吾川郡仁淀川町', 'アガワグンニヨドガワチョウ', '長者丙', 'チョウジャヘイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡仁淀川町泉', '39', '39387', '7811914', '高知県', 'コウチケン', '吾川郡仁淀川町', 'アガワグンニヨドガワチョウ', '泉', 'イズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡仁淀川町大植', '39', '39387', '7811915', '高知県', 'コウチケン', '吾川郡仁淀川町', 'アガワグンニヨドガワチョウ', '大植', 'オオウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡いの町', '39', '39386', '7812100', '高知県', 'コウチケン', '吾川郡いの町', 'アガワグンイノチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('98446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡日高村', '39', '39410', '7812100', '高知県', 'コウチケン', '高岡郡日高村', 'タカオカグンヒダカムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('98447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡いの町大国町', '39', '39386', '7812101', '高知県', 'コウチケン', '吾川郡いの町', 'アガワグンイノチョウ', '大国町', 'ダイコクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡いの町公園町', '39', '39386', '7812102', '高知県', 'コウチケン', '吾川郡いの町', 'アガワグンイノチョウ', '公園町', 'コウエンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡いの町幸町', '39', '39386', '7812103', '高知県', 'コウチケン', '吾川郡いの町', 'アガワグンイノチョウ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡いの町藤町', '39', '39386', '7812104', '高知県', 'コウチケン', '吾川郡いの町', 'アガワグンイノチョウ', '藤町', 'フジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡いの町新町', '39', '39386', '7812105', '高知県', 'コウチケン', '吾川郡いの町', 'アガワグンイノチョウ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡いの町駅南町', '39', '39386', '7812106', '高知県', 'コウチケン', '吾川郡いの町', 'アガワグンイノチョウ', '駅南町', 'エキミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡いの町駅前町', '39', '39386', '7812107', '高知県', 'コウチケン', '吾川郡いの町', 'アガワグンイノチョウ', '駅前町', 'エキマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡いの町駅東町', '39', '39386', '7812108', '高知県', 'コウチケン', '吾川郡いの町', 'アガワグンイノチョウ', '駅東町', 'エキヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡いの町', '39', '39386', '7812110', '高知県', 'コウチケン', '吾川郡いの町', 'アガワグンイノチョウ', null, '　', '（直番地）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('98456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡いの町枝川', '39', '39386', '7812120', '高知県', 'コウチケン', '吾川郡いの町', 'アガワグンイノチョウ', '枝川', 'エダガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡いの町池の内', '39', '39386', '7812121', '高知県', 'コウチケン', '吾川郡いの町', 'アガワグンイノチョウ', '池の内', 'イケノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡いの町天王北', '39', '39386', '7812122', '高知県', 'コウチケン', '吾川郡いの町', 'アガワグンイノチョウ', '天王北', 'テンノウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡いの町天王南', '39', '39386', '7812123', '高知県', 'コウチケン', '吾川郡いの町', 'アガワグンイノチョウ', '天王南', 'テンノウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡いの町八田', '39', '39386', '7812124', '高知県', 'コウチケン', '吾川郡いの町', 'アガワグンイノチョウ', '八田', 'ハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡いの町大内', '39', '39386', '7812126', '高知県', 'コウチケン', '吾川郡いの町', 'アガワグンイノチョウ', '大内', 'オオチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡いの町鎌田', '39', '39386', '7812127', '高知県', 'コウチケン', '吾川郡いの町', 'アガワグンイノチョウ', '鎌田', 'カマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡いの町波川', '39', '39386', '7812128', '高知県', 'コウチケン', '吾川郡いの町', 'アガワグンイノチョウ', '波川', 'ハカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡いの町槇', '39', '39386', '7812131', '高知県', 'コウチケン', '吾川郡いの町', 'アガワグンイノチョウ', '槇', 'マキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡いの町成山', '39', '39386', '7812132', '高知県', 'コウチケン', '吾川郡いの町', 'アガワグンイノチョウ', '成山', 'ナルヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡いの町加田', '39', '39386', '7812133', '高知県', 'コウチケン', '吾川郡いの町', 'アガワグンイノチョウ', '加田', 'カダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡いの町神谷', '39', '39386', '7812134', '高知県', 'コウチケン', '吾川郡いの町', 'アガワグンイノチョウ', '神谷', 'コウノタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡いの町小野', '39', '39386', '7812135', '高知県', 'コウチケン', '吾川郡いの町', 'アガワグンイノチョウ', '小野', 'コノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡いの町鹿敷', '39', '39386', '7812136', '高知県', 'コウチケン', '吾川郡いの町', 'アガワグンイノチョウ', '鹿敷', 'カシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡いの町勝賀瀬', '39', '39386', '7812141', '高知県', 'コウチケン', '吾川郡いの町', 'アガワグンイノチョウ', '勝賀瀬', 'ショウガセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡いの町中追', '39', '39386', '7812142', '高知県', 'コウチケン', '吾川郡いの町', 'アガワグンイノチョウ', '中追', 'ナカオイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡いの町楠瀬', '39', '39386', '7812143', '高知県', 'コウチケン', '吾川郡いの町', 'アガワグンイノチョウ', '楠瀬', 'クスノセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡いの町柳瀬本村', '39', '39386', '7812144', '高知県', 'コウチケン', '吾川郡いの町', 'アガワグンイノチョウ', '柳瀬本村', 'ヤナノセホンムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡いの町柳瀬石見', '39', '39386', '7812145', '高知県', 'コウチケン', '吾川郡いの町', 'アガワグンイノチョウ', '柳瀬石見', 'ヤナノセイシミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡いの町柳瀬上分', '39', '39386', '7812146', '高知県', 'コウチケン', '吾川郡いの町', 'アガワグンイノチョウ', '柳瀬上分', 'ヤナノセカミブン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡日高村下分', '39', '39410', '7812151', '高知県', 'コウチケン', '高岡郡日高村', 'タカオカグンヒダカムラ', '下分', 'シモブン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡日高村沖名', '39', '39410', '7812152', '高知県', 'コウチケン', '高岡郡日高村', 'タカオカグンヒダカムラ', '沖名', 'オキナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡日高村本郷', '39', '39410', '7812153', '高知県', 'コウチケン', '高岡郡日高村', 'タカオカグンヒダカムラ', '本郷', 'ホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡日高村岩目地', '39', '39410', '7812154', '高知県', 'コウチケン', '高岡郡日高村', 'タカオカグンヒダカムラ', '岩目地', 'イワメジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡日高村九頭', '39', '39410', '7812155', '高知県', 'コウチケン', '高岡郡日高村', 'タカオカグンヒダカムラ', '九頭', 'クズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡日高村柱谷', '39', '39410', '7812161', '高知県', 'コウチケン', '高岡郡日高村', 'タカオカグンヒダカムラ', '柱谷', 'ハシラタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡日高村名越屋', '39', '39410', '7812162', '高知県', 'コウチケン', '高岡郡日高村', 'タカオカグンヒダカムラ', '名越屋', 'ナゴヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡日高村大花', '39', '39410', '7812163', '高知県', 'コウチケン', '高岡郡日高村', 'タカオカグンヒダカムラ', '大花', 'オオハナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡日高村本村', '39', '39410', '7812164', '高知県', 'コウチケン', '高岡郡日高村', 'タカオカグンヒダカムラ', '本村', 'ホンムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡日高村宮ノ谷', '39', '39410', '7812165', '高知県', 'コウチケン', '高岡郡日高村', 'タカオカグンヒダカムラ', '宮ノ谷', 'ミヤノタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡日高村長畑', '39', '39410', '7812166', '高知県', 'コウチケン', '高岡郡日高村', 'タカオカグンヒダカムラ', '長畑', 'ナガバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡日高村鴨地', '39', '39410', '7812167', '高知県', 'コウチケン', '高岡郡日高村', 'タカオカグンヒダカムラ', '鴨地', 'カモジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡いの町小川東津賀才', '39', '39386', '7812321', '高知県', 'コウチケン', '吾川郡いの町', 'アガワグンイノチョウ', '小川東津賀才', 'コガワヒガシツガサイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡いの町小川西津賀才', '39', '39386', '7812322', '高知県', 'コウチケン', '吾川郡いの町', 'アガワグンイノチョウ', '小川西津賀才', 'コガワニシツガサイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡いの町小川樅ノ木山', '39', '39386', '7812323', '高知県', 'コウチケン', '吾川郡いの町', 'アガワグンイノチョウ', '小川樅ノ木山', 'コガワモミノキヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡いの町小川新別', '39', '39386', '7812324', '高知県', 'コウチケン', '吾川郡いの町', 'アガワグンイノチョウ', '小川新別', 'コガワシンベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡いの町小川柳野', '39', '39386', '7812325', '高知県', 'コウチケン', '吾川郡いの町', 'アガワグンイノチョウ', '小川柳野', 'コガワヤナギノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡いの町下八川甲', '39', '39386', '7812331', '高知県', 'コウチケン', '吾川郡いの町', 'アガワグンイノチョウ', '下八川甲', 'シモヤカワコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡いの町下八川乙', '39', '39386', '7812332', '高知県', 'コウチケン', '吾川郡いの町', 'アガワグンイノチョウ', '下八川乙', 'シモヤカワオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡いの町下八川丙', '39', '39386', '7812333', '高知県', 'コウチケン', '吾川郡いの町', 'アガワグンイノチョウ', '下八川丙', 'シモヤカワヘイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡いの町下八川丁', '39', '39386', '7812334', '高知県', 'コウチケン', '吾川郡いの町', 'アガワグンイノチョウ', '下八川丁', 'シモヤカワテイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡いの町下八川十田', '39', '39386', '7812335', '高知県', 'コウチケン', '吾川郡いの町', 'アガワグンイノチョウ', '下八川十田', 'シモヤカワトオダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡いの町上八川甲枝川', '39', '39386', '7812401', '高知県', 'コウチケン', '吾川郡いの町', 'アガワグンイノチョウ', '上八川甲', 'カミヤカワコウ', null, null, '枝川', 'エダガワ');
INSERT INTO `ms_addresses` VALUES ('98502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡いの町上八川甲大久保', '39', '39386', '7812401', '高知県', 'コウチケン', '吾川郡いの町', 'アガワグンイノチョウ', '上八川甲', 'カミヤカワコウ', null, null, '大久保', 'オオクボ');
INSERT INTO `ms_addresses` VALUES ('98503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡いの町上八川甲木ノ瀬', '39', '39386', '7812401', '高知県', 'コウチケン', '吾川郡いの町', 'アガワグンイノチョウ', '上八川甲', 'カミヤカワコウ', null, null, '木ノ瀬', 'キノセ');
INSERT INTO `ms_addresses` VALUES ('98504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡いの町上八川甲土居', '39', '39386', '7812401', '高知県', 'コウチケン', '吾川郡いの町', 'アガワグンイノチョウ', '上八川甲', 'カミヤカワコウ', null, null, '土居', 'ドイ');
INSERT INTO `ms_addresses` VALUES ('98505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡いの町上八川甲西川', '39', '39386', '7812401', '高知県', 'コウチケン', '吾川郡いの町', 'アガワグンイノチョウ', '上八川甲', 'カミヤカワコウ', null, null, '西川', 'ニシカワ');
INSERT INTO `ms_addresses` VALUES ('98506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡いの町上八川甲本郷', '39', '39386', '7812401', '高知県', 'コウチケン', '吾川郡いの町', 'アガワグンイノチョウ', '上八川甲', 'カミヤカワコウ', null, null, '本郷', 'ホンゴウ');
INSERT INTO `ms_addresses` VALUES ('98507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡いの町上八川甲柚ノ木野', '39', '39386', '7812401', '高知県', 'コウチケン', '吾川郡いの町', 'アガワグンイノチョウ', '上八川甲', 'カミヤカワコウ', null, null, '柚ノ木野', 'ユノキノ');
INSERT INTO `ms_addresses` VALUES ('98508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡いの町上八川丙柿薮', '39', '39386', '7812402', '高知県', 'コウチケン', '吾川郡いの町', 'アガワグンイノチョウ', '上八川丙', 'カミヤカワヘイ', null, null, '柿薮', 'カキヤブ');
INSERT INTO `ms_addresses` VALUES ('98509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡いの町上八川丙小申田', '39', '39386', '7812402', '高知県', 'コウチケン', '吾川郡いの町', 'アガワグンイノチョウ', '上八川丙', 'カミヤカワヘイ', null, null, '小申田', 'コサルダ');
INSERT INTO `ms_addresses` VALUES ('98510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡いの町上八川丙津賀谷', '39', '39386', '7812402', '高知県', 'コウチケン', '吾川郡いの町', 'アガワグンイノチョウ', '上八川丙', 'カミヤカワヘイ', null, null, '津賀谷', 'ツガノタニ');
INSERT INTO `ms_addresses` VALUES ('98511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡いの町上八川丙寺野', '39', '39386', '7812402', '高知県', 'コウチケン', '吾川郡いの町', 'アガワグンイノチョウ', '上八川丙', 'カミヤカワヘイ', null, null, '寺野', 'テラノ');
INSERT INTO `ms_addresses` VALUES ('98512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡いの町上八川丙古江', '39', '39386', '7812402', '高知県', 'コウチケン', '吾川郡いの町', 'アガワグンイノチョウ', '上八川丙', 'カミヤカワヘイ', null, null, '古江', 'フルエ');
INSERT INTO `ms_addresses` VALUES ('98513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡いの町上八川丙連行', '39', '39386', '7812402', '高知県', 'コウチケン', '吾川郡いの町', 'アガワグンイノチョウ', '上八川丙', 'カミヤカワヘイ', null, null, '連行', 'レンギョウ');
INSERT INTO `ms_addresses` VALUES ('98515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡いの町清水上分伊守川', '39', '39386', '7812511', '高知県', 'コウチケン', '吾川郡いの町', 'アガワグンイノチョウ', '清水上分', 'キヨミズカミブン', null, null, '伊守川', 'イモリカワ');
INSERT INTO `ms_addresses` VALUES ('98516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡いの町清水上分川窪', '39', '39386', '7812511', '高知県', 'コウチケン', '吾川郡いの町', 'アガワグンイノチョウ', '清水上分', 'キヨミズカミブン', null, null, '川窪', 'カワクボ');
INSERT INTO `ms_addresses` VALUES ('98517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡いの町清水上分敷槇', '39', '39386', '7812511', '高知県', 'コウチケン', '吾川郡いの町', 'アガワグンイノチョウ', '清水上分', 'キヨミズカミブン', null, null, '敷槇', 'シキマキ');
INSERT INTO `ms_addresses` VALUES ('98518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡いの町清水上分土居', '39', '39386', '7812511', '高知県', 'コウチケン', '吾川郡いの町', 'アガワグンイノチョウ', '清水上分', 'キヨミズカミブン', null, null, '土居', 'ドイ');
INSERT INTO `ms_addresses` VALUES ('98519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡いの町清水上分程野', '39', '39386', '7812511', '高知県', 'コウチケン', '吾川郡いの町', 'アガワグンイノチョウ', '清水上分', 'キヨミズカミブン', null, null, '程野', 'ホドノ');
INSERT INTO `ms_addresses` VALUES ('98520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡いの町清水下分大野', '39', '39386', '7812512', '高知県', 'コウチケン', '吾川郡いの町', 'アガワグンイノチョウ', '清水下分', 'キヨミズシモブン', null, null, '大野', 'オオノ');
INSERT INTO `ms_addresses` VALUES ('98521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡いの町清水下分川口', '39', '39386', '7812512', '高知県', 'コウチケン', '吾川郡いの町', 'アガワグンイノチョウ', '清水下分', 'キヨミズシモブン', null, null, '川口', 'カワグチ');
INSERT INTO `ms_addresses` VALUES ('98522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡いの町清水下分馬路', '39', '39386', '7812512', '高知県', 'コウチケン', '吾川郡いの町', 'アガワグンイノチョウ', '清水下分', 'キヨミズシモブン', null, null, '馬路', 'バロウ');
INSERT INTO `ms_addresses` VALUES ('98523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡いの町清水下分日比原', '39', '39386', '7812512', '高知県', 'コウチケン', '吾川郡いの町', 'アガワグンイノチョウ', '清水下分', 'キヨミズシモブン', null, null, '日比原', 'ヒビハラ');
INSERT INTO `ms_addresses` VALUES ('98524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡いの町清水下分槇川', '39', '39386', '7812512', '高知県', 'コウチケン', '吾川郡いの町', 'アガワグンイノチョウ', '清水下分', 'キヨミズシモブン', null, null, '槇川', 'マキガワ');
INSERT INTO `ms_addresses` VALUES ('98525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡いの町清水下分松ノ木', '39', '39386', '7812512', '高知県', 'コウチケン', '吾川郡いの町', 'アガワグンイノチョウ', '清水下分', 'キヨミズシモブン', null, null, '松ノ木', 'マツノキ');
INSERT INTO `ms_addresses` VALUES ('98526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡いの町長沢', '39', '39386', '7812601', '高知県', 'コウチケン', '吾川郡いの町', 'アガワグンイノチョウ', '長沢', 'ナガサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡いの町戸中', '39', '39386', '7812602', '高知県', 'コウチケン', '吾川郡いの町', 'アガワグンイノチョウ', '戸中', 'トチュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡いの町大森', '39', '39386', '7812603', '高知県', 'コウチケン', '吾川郡いの町', 'アガワグンイノチョウ', '大森', 'オオモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡いの町越裏門', '39', '39386', '7812604', '高知県', 'コウチケン', '吾川郡いの町', 'アガワグンイノチョウ', '越裏門', 'エリモン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡いの町寺川', '39', '39386', '7812605', '高知県', 'コウチケン', '吾川郡いの町', 'アガワグンイノチョウ', '寺川', 'テラガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡いの町脇ノ山', '39', '39386', '7812611', '高知県', 'コウチケン', '吾川郡いの町', 'アガワグンイノチョウ', '脇ノ山', 'ワキノヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡いの町高薮', '39', '39386', '7812612', '高知県', 'コウチケン', '吾川郡いの町', 'アガワグンイノチョウ', '高薮', 'タカヤブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡いの町足谷', '39', '39386', '7812613', '高知県', 'コウチケン', '吾川郡いの町', 'アガワグンイノチョウ', '足谷', 'アシダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡いの町葛原', '39', '39386', '7812614', '高知県', 'コウチケン', '吾川郡いの町', 'アガワグンイノチョウ', '葛原', 'カズラハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡いの町桑瀬', '39', '39386', '7812615', '高知県', 'コウチケン', '吾川郡いの町', 'アガワグンイノチョウ', '桑瀬', 'クワゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県吾川郡いの町中ノ川', '39', '39386', '7812616', '高知県', 'コウチケン', '吾川郡いの町', 'アガワグンイノチョウ', '中ノ川', 'ナカノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市東旭川町東桜岡', '01', '01204', '0781271', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '東旭川町東桜岡', 'ヒガシアサヒカワチョウヒガシサクラオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市東旭川町豊田', '01', '01204', '0781272', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '東旭川町豊田', 'ヒガシアサヒカワチョウトヨタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市東旭川町米原', '01', '01204', '0781273', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '東旭川町米原', 'ヒガシアサヒカワチョウヨネハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市東旭川町瑞穂', '01', '01204', '0781274', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '東旭川町瑞穂', 'ヒガシアサヒカワチョウミズホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡当麻町', '01', '01454', '0781300', '北海道', 'ホッカイドウ', '上川郡当麻町', 'カミカワグントウマチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('98542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡当麻町3条西', '01', '01454', '0781303', '北海道', 'ホッカイドウ', '上川郡当麻町', 'カミカワグントウマチョウ', '3条西', '03ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡当麻町4条西', '01', '01454', '0781304', '北海道', 'ホッカイドウ', '上川郡当麻町', 'カミカワグントウマチョウ', '4条西', '04ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡当麻町5条西', '01', '01454', '0781305', '北海道', 'ホッカイドウ', '上川郡当麻町', 'カミカワグントウマチョウ', '5条西', '05ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡当麻町6条西', '01', '01454', '0781306', '北海道', 'ホッカイドウ', '上川郡当麻町', 'カミカワグントウマチョウ', '6条西', '06ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市鏡大河内', '39', '39201', '7813101', '高知県', 'コウチケン', '高知市', 'コウチシ', '鏡大河内', 'カガミオオガチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市鏡小浜', '39', '39201', '7813102', '高知県', 'コウチケン', '高知市', 'コウチシ', '鏡小浜', 'カガミコハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市鏡大利', '39', '39201', '7813103', '高知県', 'コウチケン', '高知市', 'コウチシ', '鏡大利', 'カガミオオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市鏡今井', '39', '39201', '7813104', '高知県', 'コウチケン', '高知市', 'コウチシ', '鏡今井', 'カガミイマイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市鏡草峰', '39', '39201', '7813105', '高知県', 'コウチケン', '高知市', 'コウチシ', '鏡草峰', 'カガミクサミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市鏡白岩', '39', '39201', '7813106', '高知県', 'コウチケン', '高知市', 'コウチシ', '鏡白岩', 'カガミシロイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市鏡狩山', '39', '39201', '7813107', '高知県', 'コウチケン', '高知市', 'コウチシ', '鏡狩山', 'カガミカリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市鏡吉原', '39', '39201', '7813108', '高知県', 'コウチケン', '高知市', 'コウチシ', '鏡吉原', 'カガミヨシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市鏡的渕', '39', '39201', '7813111', '高知県', 'コウチケン', '高知市', 'コウチシ', '鏡的渕', 'カガミマトブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市鏡去坂', '39', '39201', '7813112', '高知県', 'コウチケン', '高知市', 'コウチシ', '鏡去坂', 'カガミサルサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市鏡竹奈路', '39', '39201', '7813113', '高知県', 'コウチケン', '高知市', 'コウチシ', '鏡竹奈路', 'カガミタケナロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市鏡敷ノ山', '39', '39201', '7813114', '高知県', 'コウチケン', '高知市', 'コウチシ', '鏡敷ノ山', 'カガミシキノヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市鏡柿ノ又', '39', '39201', '7813115', '高知県', 'コウチケン', '高知市', 'コウチシ', '鏡柿ノ又', 'カガミカキノマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市鏡横矢', '39', '39201', '7813121', '高知県', 'コウチケン', '高知市', 'コウチシ', '鏡横矢', 'カガミヨコヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市鏡増原', '39', '39201', '7813122', '高知県', 'コウチケン', '高知市', 'コウチシ', '鏡増原', 'カガミマスハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市鏡葛山', '39', '39201', '7813123', '高知県', 'コウチケン', '高知市', 'コウチシ', '鏡葛山', 'カガミカズラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市鏡梅ノ木', '39', '39201', '7813124', '高知県', 'コウチケン', '高知市', 'コウチシ', '鏡梅ノ木', 'カガミウメノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市鏡小山', '39', '39201', '7813125', '高知県', 'コウチケン', '高知市', 'コウチシ', '鏡小山', 'カガミコヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡当麻町3条東', '01', '01454', '0781313', '北海道', 'ホッカイドウ', '上川郡当麻町', 'カミカワグントウマチョウ', '3条東', '03ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡当麻町4条東', '01', '01454', '0781314', '北海道', 'ホッカイドウ', '上川郡当麻町', 'カミカワグントウマチョウ', '4条東', '04ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡当麻町5条東', '01', '01454', '0781315', '北海道', 'ホッカイドウ', '上川郡当麻町', 'カミカワグントウマチョウ', '5条東', '05ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡当麻町6条東', '01', '01454', '0781316', '北海道', 'ホッカイドウ', '上川郡当麻町', 'カミカワグントウマチョウ', '6条東', '06ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市土佐山', '39', '39201', '7813201', '高知県', 'コウチケン', '高知市', 'コウチシ', '土佐山', 'トサヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市土佐山都網', '39', '39201', '7813202', '高知県', 'コウチケン', '高知市', 'コウチシ', '土佐山都網', 'トサヤマツアミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市土佐山弘瀬', '39', '39201', '7813203', '高知県', 'コウチケン', '高知市', 'コウチシ', '土佐山弘瀬', 'トサヤマヒロセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市土佐山高川', '39', '39201', '7813211', '高知県', 'コウチケン', '高知市', 'コウチシ', '土佐山高川', 'トサヤマタカカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市土佐山梶谷', '39', '39201', '7813212', '高知県', 'コウチケン', '高知市', 'コウチシ', '土佐山梶谷', 'トサヤマカジタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市土佐山西川', '39', '39201', '7813213', '高知県', 'コウチケン', '高知市', 'コウチシ', '土佐山西川', 'トサヤマニシガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市土佐山菖蒲', '39', '39201', '7813214', '高知県', 'コウチケン', '高知市', 'コウチシ', '土佐山菖蒲', 'トサヤマショウブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市土佐山桑尾', '39', '39201', '7813221', '高知県', 'コウチケン', '高知市', 'コウチシ', '土佐山桑尾', 'トサヤマクワオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市土佐山東川', '39', '39201', '7813222', '高知県', 'コウチケン', '高知市', 'コウチシ', '土佐山東川', 'トサヤマヒガシカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市土佐山中切', '39', '39201', '7813223', '高知県', 'コウチケン', '高知市', 'コウチシ', '土佐山中切', 'トサヤマナカギリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡当麻町4条南', '01', '01454', '0781324', '北海道', 'ホッカイドウ', '上川郡当麻町', 'カミカワグントウマチョウ', '4条南', '04ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡当麻町中央', '01', '01454', '0781331', '北海道', 'ホッカイドウ', '上川郡当麻町', 'カミカワグントウマチョウ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡当麻町宇園別', '01', '01454', '0781332', '北海道', 'ホッカイドウ', '上川郡当麻町', 'カミカワグントウマチョウ', '宇園別', 'ウエンベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡当麻町伊香牛', '01', '01454', '0781333', '北海道', 'ホッカイドウ', '上川郡当麻町', 'カミカワグントウマチョウ', '伊香牛', 'イカウシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐郡土佐町地蔵寺', '39', '39363', '7813331', '高知県', 'コウチケン', '土佐郡土佐町', 'トサグントサチョウ', '地蔵寺', 'ジゾウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐郡土佐町栗木', '39', '39363', '7813332', '高知県', 'コウチケン', '土佐郡土佐町', 'トサグントサチョウ', '栗木', 'クリキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐郡土佐町東石原', '39', '39363', '7813333', '高知県', 'コウチケン', '土佐郡土佐町', 'トサグントサチョウ', '東石原', 'ヒガシイシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐郡土佐町西石原', '39', '39363', '7813334', '高知県', 'コウチケン', '土佐郡土佐町', 'トサグントサチョウ', '西石原', 'ニシイシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐郡土佐町有間', '39', '39363', '7813335', '高知県', 'コウチケン', '土佐郡土佐町', 'トサグントサチョウ', '有間', 'アリマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐郡土佐町芥川', '39', '39363', '7813336', '高知県', 'コウチケン', '土佐郡土佐町', 'トサグントサチョウ', '芥川', 'アクタガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐郡土佐町瀬戸', '39', '39363', '7813337', '高知県', 'コウチケン', '土佐郡土佐町', 'トサグントサチョウ', '瀬戸', 'セド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡当麻町北星', '01', '01454', '0781334', '北海道', 'ホッカイドウ', '上川郡当麻町', 'カミカワグントウマチョウ', '北星', 'ホクセイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡当麻町緑郷', '01', '01454', '0781335', '北海道', 'ホッカイドウ', '上川郡当麻町', 'カミカワグントウマチョウ', '緑郷', 'ロクゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡当麻町東', '01', '01454', '0781337', '北海道', 'ホッカイドウ', '上川郡当麻町', 'カミカワグントウマチョウ', '東', 'ヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐郡土佐町', '39', '39363', '7813400', '高知県', 'コウチケン', '土佐郡土佐町', 'トサグントサチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('98593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐郡土佐町土居', '39', '39363', '7813401', '高知県', 'コウチケン', '土佐郡土佐町', 'トサグントサチョウ', '土居', 'ドイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐郡土佐町境', '39', '39363', '7813402', '高知県', 'コウチケン', '土佐郡土佐町', 'トサグントサチョウ', '境', 'サカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐郡土佐町宮古野', '39', '39363', '7813403', '高知県', 'コウチケン', '土佐郡土佐町', 'トサグントサチョウ', '宮古野', 'ミヤコノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐郡土佐町溜井', '39', '39363', '7813404', '高知県', 'コウチケン', '土佐郡土佐町', 'トサグントサチョウ', '溜井', 'ヌルイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐郡土佐町南泉', '39', '39363', '7813405', '高知県', 'コウチケン', '土佐郡土佐町', 'トサグントサチョウ', '南泉', 'ミナイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐郡土佐町高須', '39', '39363', '7813406', '高知県', 'コウチケン', '土佐郡土佐町', 'トサグントサチョウ', '高須', 'タカス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐郡土佐町樫山', '39', '39363', '7813407', '高知県', 'コウチケン', '土佐郡土佐町', 'トサグントサチョウ', '樫山', 'カシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐郡土佐町相川', '39', '39363', '7813408', '高知県', 'コウチケン', '土佐郡土佐町', 'トサグントサチョウ', '相川', 'アイカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐郡土佐町和田', '39', '39363', '7813409', '高知県', 'コウチケン', '土佐郡土佐町', 'トサグントサチョウ', '和田', 'ワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡当麻町開明', '01', '01454', '0781341', '北海道', 'ホッカイドウ', '上川郡当麻町', 'カミカワグントウマチョウ', '開明', 'カイメイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐郡土佐町田井', '39', '39363', '7813521', '高知県', 'コウチケン', '土佐郡土佐町', 'トサグントサチョウ', '田井', 'タイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐郡土佐町大渕', '39', '39363', '7813522', '高知県', 'コウチケン', '土佐郡土佐町', 'トサグントサチョウ', '大渕', 'オオブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐郡土佐町古味', '39', '39363', '7813523', '高知県', 'コウチケン', '土佐郡土佐町', 'トサグントサチョウ', '古味', 'コミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐郡土佐町井尻', '39', '39363', '7813524', '高知県', 'コウチケン', '土佐郡土佐町', 'トサグントサチョウ', '井尻', 'イジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐郡土佐町下川', '39', '39363', '7813525', '高知県', 'コウチケン', '土佐郡土佐町', 'トサグントサチョウ', '下川', 'シモカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐郡土佐町上津川', '39', '39363', '7813526', '高知県', 'コウチケン', '土佐郡土佐町', 'トサグントサチョウ', '上津川', 'コウヅカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県長岡郡本山町', '39', '39341', '7813600', '高知県', 'コウチケン', '長岡郡本山町', 'ナガオカグンモトヤマチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('98612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県長岡郡本山町本山', '39', '39341', '7813601', '高知県', 'コウチケン', '長岡郡本山町', 'ナガオカグンモトヤマチョウ', '本山', 'モトヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県長岡郡本山町大石', '39', '39341', '7813602', '高知県', 'コウチケン', '長岡郡本山町', 'ナガオカグンモトヤマチョウ', '大石', 'オオイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県長岡郡本山町吉延', '39', '39341', '7813603', '高知県', 'コウチケン', '長岡郡本山町', 'ナガオカグンモトヤマチョウ', '吉延', 'ヨシノブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県長岡郡本山町井窪', '39', '39341', '7813604', '高知県', 'コウチケン', '長岡郡本山町', 'ナガオカグンモトヤマチョウ', '井窪', 'イノクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県長岡郡本山町下津野', '39', '39341', '7813605', '高知県', 'コウチケン', '長岡郡本山町', 'ナガオカグンモトヤマチョウ', '下津野', 'シモツノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県長岡郡本山町高角', '39', '39341', '7813606', '高知県', 'コウチケン', '長岡郡本山町', 'ナガオカグンモトヤマチョウ', '高角', 'タカツノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県長岡郡本山町古田', '39', '39341', '7813607', '高知県', 'コウチケン', '長岡郡本山町', 'ナガオカグンモトヤマチョウ', '古田', 'フルタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県長岡郡本山町木能津', '39', '39341', '7813608', '高知県', 'コウチケン', '長岡郡本山町', 'ナガオカグンモトヤマチョウ', '木能津', 'キノウヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県長岡郡本山町助藤', '39', '39341', '7813609', '高知県', 'コウチケン', '長岡郡本山町', 'ナガオカグンモトヤマチョウ', '助藤', 'スケトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県長岡郡本山町下関', '39', '39341', '7813610', '高知県', 'コウチケン', '長岡郡本山町', 'ナガオカグンモトヤマチョウ', '下関', 'シモゼキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県長岡郡本山町上関甲', '39', '39341', '7813611', '高知県', 'コウチケン', '長岡郡本山町', 'ナガオカグンモトヤマチョウ', '上関甲', 'カミゼキコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県長岡郡本山町上関乙', '39', '39341', '7813612', '高知県', 'コウチケン', '長岡郡本山町', 'ナガオカグンモトヤマチョウ', '上関乙', 'カミゼキオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県長岡郡本山町北山甲', '39', '39341', '7813613', '高知県', 'コウチケン', '長岡郡本山町', 'ナガオカグンモトヤマチョウ', '北山甲', 'キタヤマコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県長岡郡本山町北山乙', '39', '39341', '7813614', '高知県', 'コウチケン', '長岡郡本山町', 'ナガオカグンモトヤマチョウ', '北山乙', 'キタヤマオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県長岡郡本山町北山丙', '39', '39341', '7813615', '高知県', 'コウチケン', '長岡郡本山町', 'ナガオカグンモトヤマチョウ', '北山丙', 'キタヤマヘイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県長岡郡本山町寺家', '39', '39341', '7813617', '高知県', 'コウチケン', '長岡郡本山町', 'ナガオカグンモトヤマチョウ', '寺家', 'ジケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県長岡郡本山町吉野', '39', '39341', '7813618', '高知県', 'コウチケン', '長岡郡本山町', 'ナガオカグンモトヤマチョウ', '吉野', 'ヨシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県長岡郡本山町立野', '39', '39341', '7813619', '高知県', 'コウチケン', '長岡郡本山町', 'ナガオカグンモトヤマチョウ', '立野', 'タチノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県長岡郡本山町坂本', '39', '39341', '7813620', '高知県', 'コウチケン', '長岡郡本山町', 'ナガオカグンモトヤマチョウ', '坂本', 'サカモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県長岡郡本山町屋所', '39', '39341', '7813621', '高知県', 'コウチケン', '長岡郡本山町', 'ナガオカグンモトヤマチョウ', '屋所', 'ヤトコロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県長岡郡本山町沢ケ内', '39', '39341', '7813622', '高知県', 'コウチケン', '長岡郡本山町', 'ナガオカグンモトヤマチョウ', '沢ケ内', 'ソウガウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県長岡郡本山町瓜生野', '39', '39341', '7813623', '高知県', 'コウチケン', '長岡郡本山町', 'ナガオカグンモトヤマチョウ', '瓜生野', 'ウリウノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県長岡郡本山町七戸', '39', '39341', '7813624', '高知県', 'コウチケン', '長岡郡本山町', 'ナガオカグンモトヤマチョウ', '七戸', 'ナナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐郡大川村', '39', '39364', '7813700', '高知県', 'コウチケン', '土佐郡大川村', 'トサグンオオカワムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('98637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐郡大川村船戸', '39', '39364', '7813701', '高知県', 'コウチケン', '土佐郡大川村', 'トサグンオオカワムラ', '船戸', 'フナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐郡大川村船戸桃ケ谷', '39', '39364', '7813702', '高知県', 'コウチケン', '土佐郡大川村', 'トサグンオオカワムラ', '船戸', 'フナト', null, null, '桃ケ谷', 'モモガヤ');
INSERT INTO `ms_addresses` VALUES ('98639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐郡大川村小松', '39', '39364', '7813703', '高知県', 'コウチケン', '土佐郡大川村', 'トサグンオオカワムラ', '小松', 'コマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐郡大川村朝谷', '39', '39364', '7813704', '高知県', 'コウチケン', '土佐郡大川村', 'トサグンオオカワムラ', '朝谷', 'アサタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐郡大川村大北川', '39', '39364', '7813705', '高知県', 'コウチケン', '土佐郡大川村', 'トサグンオオカワムラ', '大北川', 'オオキタガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐郡大川村高野', '39', '39364', '7813711', '高知県', 'コウチケン', '土佐郡大川村', 'トサグンオオカワムラ', '高野', 'タカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐郡大川村川崎', '39', '39364', '7813712', '高知県', 'コウチケン', '土佐郡大川村', 'トサグンオオカワムラ', '川崎', 'カワサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐郡大川村井野川', '39', '39364', '7813713', '高知県', 'コウチケン', '土佐郡大川村', 'トサグンオオカワムラ', '井野川', 'イノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐郡大川村大平', '39', '39364', '7813714', '高知県', 'コウチケン', '土佐郡大川村', 'トサグンオオカワムラ', '大平', 'オオヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐郡大川村小麦畝', '39', '39364', '7813715', '高知県', 'コウチケン', '土佐郡大川村', 'トサグンオオカワムラ', '小麦畝', 'コムギウネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐郡大川村小北川', '39', '39364', '7813716', '高知県', 'コウチケン', '土佐郡大川村', 'トサグンオオカワムラ', '小北川', 'コキタガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐郡大川村大薮', '39', '39364', '7813717', '高知県', 'コウチケン', '土佐郡大川村', 'トサグンオオカワムラ', '大薮', 'オオヤブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐郡大川村中切', '39', '39364', '7813721', '高知県', 'コウチケン', '土佐郡大川村', 'トサグンオオカワムラ', '中切', 'ナカギリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐郡大川村下小南川', '39', '39364', '7813722', '高知県', 'コウチケン', '土佐郡大川村', 'トサグンオオカワムラ', '下小南川', 'シモオミナガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐郡大川村上小南川', '39', '39364', '7813723', '高知県', 'コウチケン', '土佐郡大川村', 'トサグンオオカワムラ', '上小南川', 'カミオミナガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐郡大川村南野山', '39', '39364', '7813724', '高知県', 'コウチケン', '土佐郡大川村', 'トサグンオオカワムラ', '南野山', 'ミナミノヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐郡大川村下切', '39', '39364', '7813725', '高知県', 'コウチケン', '土佐郡大川村', 'トサグンオオカワムラ', '下切', 'シタギリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐郡土佐町柚ノ木', '39', '39363', '7813741', '高知県', 'コウチケン', '土佐郡土佐町', 'トサグントサチョウ', '柚ノ木', 'ユノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐郡土佐町南川', '39', '39363', '7813742', '高知県', 'コウチケン', '土佐郡土佐町', 'トサグントサチョウ', '南川', 'ミナガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡愛別町', '01', '01456', '0781400', '北海道', 'ホッカイドウ', '上川郡愛別町', 'カミカワグンアイベツチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('98659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡愛別町愛別', '01', '01456', '0781401', '北海道', 'ホッカイドウ', '上川郡愛別町', 'カミカワグンアイベツチョウ', '愛別', 'アイベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡愛別町東町', '01', '01456', '0781402', '北海道', 'ホッカイドウ', '上川郡愛別町', 'カミカワグンアイベツチョウ', '東町', 'ヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡愛別町南町', '01', '01456', '0781403', '北海道', 'ホッカイドウ', '上川郡愛別町', 'カミカワグンアイベツチョウ', '南町', 'ミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡愛別町北町', '01', '01456', '0781404', '北海道', 'ホッカイドウ', '上川郡愛別町', 'カミカワグンアイベツチョウ', '北町', 'キタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡愛別町本町', '01', '01456', '0781405', '北海道', 'ホッカイドウ', '上川郡愛別町', 'カミカワグンアイベツチョウ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡愛別町金富', '01', '01456', '0781411', '北海道', 'ホッカイドウ', '上川郡愛別町', 'カミカワグンアイベツチョウ', '金富', 'カナトミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡愛別町厚生', '01', '01456', '0781412', '北海道', 'ホッカイドウ', '上川郡愛別町', 'カミカワグンアイベツチョウ', '厚生', 'コウセイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡愛別町伏古', '01', '01456', '0781413', '北海道', 'ホッカイドウ', '上川郡愛別町', 'カミカワグンアイベツチョウ', '伏古', 'フシコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡愛別町協和', '01', '01456', '0781414', '北海道', 'ホッカイドウ', '上川郡愛別町', 'カミカワグンアイベツチョウ', '協和', 'キョウワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡愛別町徳星', '01', '01456', '0781415', '北海道', 'ホッカイドウ', '上川郡愛別町', 'カミカワグンアイベツチョウ', '徳星', 'トクセイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市香北町永瀬', '39', '39212', '7814201', '高知県', 'コウチケン', '香美市', 'カミシ', '香北町永瀬', 'カホクチョウナガセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市香北町蕨野', '39', '39212', '7814202', '高知県', 'コウチケン', '香美市', 'カミシ', '香北町蕨野', 'カホクチョウワラビノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市香北町白石', '39', '39212', '7814203', '高知県', 'コウチケン', '香美市', 'カミシ', '香北町白石', 'カホクチョウシライシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市香北町根須', '39', '39212', '7814204', '高知県', 'コウチケン', '香美市', 'カミシ', '香北町根須', 'カホクチョウネズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市香北町吉野', '39', '39212', '7814205', '高知県', 'コウチケン', '香美市', 'カミシ', '香北町吉野', 'カホクチョウヨシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市香北町小川', '39', '39212', '7814206', '高知県', 'コウチケン', '香美市', 'カミシ', '香北町小川', 'カホクチョウオガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市香北町西川乙', '39', '39212', '7814207', '高知県', 'コウチケン', '香美市', 'カミシ', '香北町西川乙', 'カホクチョウニシカワオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市香北町西川甲', '39', '39212', '7814208', '高知県', 'コウチケン', '香美市', 'カミシ', '香北町西川甲', 'カホクチョウニシカワコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市香北町韮生野', '39', '39212', '7814211', '高知県', 'コウチケン', '香美市', 'カミシ', '香北町韮生野', 'カホクチョウニロウノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市香北町美良布', '39', '39212', '7814212', '高知県', 'コウチケン', '香美市', 'カミシ', '香北町美良布', 'カホクチョウビラフ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市香北町下野尻', '39', '39212', '7814213', '高知県', 'コウチケン', '香美市', 'カミシ', '香北町下野尻', 'カホクチョウシモノジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市香北町太郎丸', '39', '39212', '7814214', '高知県', 'コウチケン', '香美市', 'カミシ', '香北町太郎丸', 'カホクチョウタロマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市香北町岩改', '39', '39212', '7814215', '高知県', 'コウチケン', '香美市', 'カミシ', '香北町岩改', 'カホクチョウイワカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市香北町萩野', '39', '39212', '7814216', '高知県', 'コウチケン', '香美市', 'カミシ', '香北町萩野', 'カホクチョウハギノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市香北町橋川野', '39', '39212', '7814217', '高知県', 'コウチケン', '香美市', 'カミシ', '香北町橋川野', 'カホクチョウハシカワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市香北町白川', '39', '39212', '7814221', '高知県', 'コウチケン', '香美市', 'カミシ', '香北町白川', 'カホクチョウシラカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市香北町五百蔵', '39', '39212', '7814222', '高知県', 'コウチケン', '香美市', 'カミシ', '香北町五百蔵', 'カホクチョウイオロイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市香北町有川', '39', '39212', '7814223', '高知県', 'コウチケン', '香美市', 'カミシ', '香北町有川', 'カホクチョウアラカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市香北町有瀬', '39', '39212', '7814224', '高知県', 'コウチケン', '香美市', 'カミシ', '香北町有瀬', 'カホクチョウアラセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市香北町西峯', '39', '39212', '7814225', '高知県', 'コウチケン', '香美市', 'カミシ', '香北町西峯', 'カホクチョウニシノミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市香北町河野', '39', '39212', '7814226', '高知県', 'コウチケン', '香美市', 'カミシ', '香北町河野', 'カホクチョウコウノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市香北町川ノ内', '39', '39212', '7814227', '高知県', 'コウチケン', '香美市', 'カミシ', '香北町川ノ内', 'カホクチョウカワノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市香北町日ノ御子', '39', '39212', '7814231', '高知県', 'コウチケン', '香美市', 'カミシ', '香北町日ノ御子', 'カホクチョウヒノミコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市香北町谷相', '39', '39212', '7814232', '高知県', 'コウチケン', '香美市', 'カミシ', '香北町谷相', 'カホクチョウタニアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市香北町中谷', '39', '39212', '7814233', '高知県', 'コウチケン', '香美市', 'カミシ', '香北町中谷', 'カホクチョウナカタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市香北町横谷', '39', '39212', '7814234', '高知県', 'コウチケン', '香美市', 'カミシ', '香北町横谷', 'カホクチョウヨコタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市香北町朴ノ木', '39', '39212', '7814235', '高知県', 'コウチケン', '香美市', 'カミシ', '香北町朴ノ木', 'カホクチョウホウノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市香北町永野', '39', '39212', '7814236', '高知県', 'コウチケン', '香美市', 'カミシ', '香北町永野', 'カホクチョウナガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市香北町大井平', '39', '39212', '7814241', '高知県', 'コウチケン', '香美市', 'カミシ', '香北町大井平', 'カホクチョウオオイダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市香北町大束', '39', '39212', '7814242', '高知県', 'コウチケン', '香美市', 'カミシ', '香北町大束', 'カホクチョウオオツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市香北町梅久保', '39', '39212', '7814243', '高知県', 'コウチケン', '香美市', 'カミシ', '香北町梅久保', 'カホクチョウウメノクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市香北町日浦込', '39', '39212', '7814244', '高知県', 'コウチケン', '香美市', 'カミシ', '香北町日浦込', 'カホクチョウヒウラゴミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市香北町清爪', '39', '39212', '7814245', '高知県', 'コウチケン', '香美市', 'カミシ', '香北町清爪', 'カホクチョウセイヅメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市香北町日比原', '39', '39212', '7814246', '高知県', 'コウチケン', '香美市', 'カミシ', '香北町日比原', 'カホクチョウヒビハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市香北町猪野々', '39', '39212', '7814247', '高知県', 'コウチケン', '香美市', 'カミシ', '香北町猪野々', 'カホクチョウイノノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市物部町大栃', '39', '39212', '7814401', '高知県', 'コウチケン', '香美市', 'カミシ', '物部町大栃', 'モノベチョウオオドチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市物部町山崎', '39', '39212', '7814402', '高知県', 'コウチケン', '香美市', 'カミシ', '物部町山崎', 'モノベチョウヤマサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市物部町押谷', '39', '39212', '7814403', '高知県', 'コウチケン', '香美市', 'カミシ', '物部町押谷', 'モノベチョウオスダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市物部町小浜', '39', '39212', '7814404', '高知県', 'コウチケン', '香美市', 'カミシ', '物部町小浜', 'モノベチョウコハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市物部町根木屋', '39', '39212', '7814405', '高知県', 'コウチケン', '香美市', 'カミシ', '物部町根木屋', 'モノベチョウネキヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市物部町仙頭', '39', '39212', '7814406', '高知県', 'コウチケン', '香美市', 'カミシ', '物部町仙頭', 'モノベチョウセンドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市物部町中谷川', '39', '39212', '7814411', '高知県', 'コウチケン', '香美市', 'カミシ', '物部町中谷川', 'モノベチョウナカタニガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市物部町拓', '39', '39212', '7814412', '高知県', 'コウチケン', '香美市', 'カミシ', '物部町拓', 'モノベチョウツブセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市物部町庄谷相', '39', '39212', '7814413', '高知県', 'コウチケン', '香美市', 'カミシ', '物部町庄谷相', 'モノベチョウショウダニアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市物部町頓定', '39', '39212', '7814414', '高知県', 'コウチケン', '香美市', 'カミシ', '物部町頓定', 'モノベチョウトンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市物部町舞川', '39', '39212', '7814415', '高知県', 'コウチケン', '香美市', 'カミシ', '物部町舞川', 'モノベチョウマイカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市物部町安丸', '39', '39212', '7814521', '高知県', 'コウチケン', '香美市', 'カミシ', '物部町安丸', 'モノベチョウヤスマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市物部町黒代', '39', '39212', '7814522', '高知県', 'コウチケン', '香美市', 'カミシ', '物部町黒代', 'モノベチョウクロダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市物部町神池', '39', '39212', '7814523', '高知県', 'コウチケン', '香美市', 'カミシ', '物部町神池', 'モノベチョウカミイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市物部町楮佐古', '39', '39212', '7814524', '高知県', 'コウチケン', '香美市', 'カミシ', '物部町楮佐古', 'モノベチョウカジサコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市物部町柳瀬', '39', '39212', '7814525', '高知県', 'コウチケン', '香美市', 'カミシ', '物部町柳瀬', 'モノベチョウヤナイセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市物部町五王堂', '39', '39212', '7814526', '高知県', 'コウチケン', '香美市', 'カミシ', '物部町五王堂', 'モノベチョウゴオウドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市物部町南池', '39', '39212', '7814527', '高知県', 'コウチケン', '香美市', 'カミシ', '物部町南池', 'モノベチョウミナミイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市物部町大西', '39', '39212', '7814528', '高知県', 'コウチケン', '香美市', 'カミシ', '物部町大西', 'モノベチョウオオニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市物部町中上', '39', '39212', '7814529', '高知県', 'コウチケン', '香美市', 'カミシ', '物部町中上', 'モノベチョウナカウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市物部町笹', '39', '39212', '7814530', '高知県', 'コウチケン', '香美市', 'カミシ', '物部町笹', 'モノベチョウササ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市物部町久保', '39', '39212', '7814531', '高知県', 'コウチケン', '香美市', 'カミシ', '物部町久保', 'モノベチョウクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市物部町岡ノ内', '39', '39212', '7814641', '高知県', 'コウチケン', '香美市', 'カミシ', '物部町岡ノ内', 'モノベチョウオカノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市物部町別役', '39', '39212', '7814642', '高知県', 'コウチケン', '香美市', 'カミシ', '物部町別役', 'モノベチョウベッチャク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市物部町市宇', '39', '39212', '7814643', '高知県', 'コウチケン', '香美市', 'カミシ', '物部町市宇', 'モノベチョウイチウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市物部町別府', '39', '39212', '7814644', '高知県', 'コウチケン', '香美市', 'カミシ', '物部町別府', 'モノベチョウベフ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市物部町山崎桑ノ川', '39', '39212', '7814645', '高知県', 'コウチケン', '香美市', 'カミシ', '物部町山崎', 'モノベチョウヤマサキ', null, null, '桑ノ川', 'クワノカワ');
INSERT INTO `ms_addresses` VALUES ('98735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市布師田', '39', '39201', '7815101', '高知県', 'コウチケン', '高知市', 'コウチシ', '布師田', 'ヌノシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市大津甲', '39', '39201', '7815102', '高知県', 'コウチケン', '高知市', 'コウチシ', '大津甲', 'オオツコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市大津乙', '39', '39201', '7815103', '高知県', 'コウチケン', '高知市', 'コウチシ', '大津乙', 'オオツオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市介良', '39', '39201', '7815104', '高知県', 'コウチケン', '高知市', 'コウチシ', '介良', 'ケラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市介良甲', '39', '39201', '7815105', '高知県', 'コウチケン', '高知市', 'コウチシ', '介良甲', 'ケラコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市介良乙', '39', '39201', '7815106', '高知県', 'コウチケン', '高知市', 'コウチシ', '介良乙', 'ケラオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市介良丙', '39', '39201', '7815107', '高知県', 'コウチケン', '高知市', 'コウチシ', '介良丙', 'ケラヘイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市潮見台', '39', '39201', '7815108', '高知県', 'コウチケン', '高知市', 'コウチシ', '潮見台', 'シオミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香南市', '39', '39211', '7815200', '高知県', 'コウチケン', '香南市', 'コウナンシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('98746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香南市野市町本村', '39', '39211', '7815201', '高知県', 'コウチケン', '香南市', 'コウナンシ', '野市町本村', 'ノイチチョウホンムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香南市野市町兎田', '39', '39211', '7815202', '高知県', 'コウチケン', '香南市', 'コウナンシ', '野市町兎田', 'ノイチチョウウサイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香南市野市町中山田', '39', '39211', '7815203', '高知県', 'コウチケン', '香南市', 'コウナンシ', '野市町中山田', 'ノイチチョウナカヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香南市野市町新宮', '39', '39211', '7815204', '高知県', 'コウチケン', '香南市', 'コウナンシ', '野市町新宮', 'ノイチチョウシングウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香南市野市町みどり野東', '39', '39211', '7815205', '高知県', 'コウチケン', '香南市', 'コウナンシ', '野市町みどり野東', 'ノイチチョウミドリノヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香南市野市町みどり野', '39', '39211', '7815206', '高知県', 'コウチケン', '香南市', 'コウナンシ', '野市町みどり野', 'ノイチチョウミドリノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香南市野市町中ノ村', '39', '39211', '7815211', '高知県', 'コウチケン', '香南市', 'コウナンシ', '野市町中ノ村', 'ノイチチョウナカノムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香南市野市町土居', '39', '39211', '7815212', '高知県', 'コウチケン', '香南市', 'コウナンシ', '野市町土居', 'ノイチチョウドイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香南市野市町東野', '39', '39211', '7815213', '高知県', 'コウチケン', '香南市', 'コウナンシ', '野市町東野', 'ノイチチョウヒガシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香南市野市町父養寺', '39', '39211', '7815221', '高知県', 'コウチケン', '香南市', 'コウナンシ', '野市町父養寺', 'ノイチチョウブヨウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香南市野市町母代寺', '39', '39211', '7815222', '高知県', 'コウチケン', '香南市', 'コウナンシ', '野市町母代寺', 'ノイチチョウボダイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香南市野市町西佐古', '39', '39211', '7815223', '高知県', 'コウチケン', '香南市', 'コウナンシ', '野市町西佐古', 'ノイチチョウニシサコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香南市野市町東佐古', '39', '39211', '7815224', '高知県', 'コウチケン', '香南市', 'コウナンシ', '野市町東佐古', 'ノイチチョウヒガシサコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香南市野市町深渕', '39', '39211', '7815231', '高知県', 'コウチケン', '香南市', 'コウナンシ', '野市町深渕', 'ノイチチョウフカブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香南市野市町西野', '39', '39211', '7815232', '高知県', 'コウチケン', '香南市', 'コウナンシ', '野市町西野', 'ノイチチョウニシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香南市野市町大谷', '39', '39211', '7815233', '高知県', 'コウチケン', '香南市', 'コウナンシ', '野市町大谷', 'ノイチチョウオオタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香南市野市町上岡', '39', '39211', '7815234', '高知県', 'コウチケン', '香南市', 'コウナンシ', '野市町上岡', 'ノイチチョウカミオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香南市野市町下井', '39', '39211', '7815235', '高知県', 'コウチケン', '香南市', 'コウナンシ', '野市町下井', 'ノイチチョウシモイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香南市吉川町吉原', '39', '39211', '7815241', '高知県', 'コウチケン', '香南市', 'コウナンシ', '吉川町吉原', 'ヨシカワチョウヨシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香南市吉川町古川', '39', '39211', '7815242', '高知県', 'コウチケン', '香南市', 'コウナンシ', '吉川町古川', 'ヨシカワチョウフルカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香南市赤岡町', '39', '39211', '7815310', '高知県', 'コウチケン', '香南市', 'コウナンシ', '赤岡町', 'アカオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香南市香我美町岸本', '39', '39211', '7815331', '高知県', 'コウチケン', '香南市', 'コウナンシ', '香我美町岸本', 'カガミチョウキシモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香南市香我美町徳王子', '39', '39211', '7815332', '高知県', 'コウチケン', '香南市', 'コウナンシ', '香我美町徳王子', 'カガミチョウトクオウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香南市香我美町上分', '39', '39211', '7815451', '高知県', 'コウチケン', '香南市', 'コウナンシ', '香我美町上分', 'カガミチョウカミブン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香南市香我美町下分', '39', '39211', '7815452', '高知県', 'コウチケン', '香南市', 'コウナンシ', '香我美町下分', 'カガミチョウシモブン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香南市香我美町山北', '39', '39211', '7815453', '高知県', 'コウチケン', '香南市', 'コウナンシ', '香我美町山北', 'カガミチョウヤマキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香南市香我美町口西川', '39', '39211', '7815454', '高知県', 'コウチケン', '香南市', 'コウナンシ', '香我美町口西川', 'カガミチョウクチニシガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香南市香我美町中西川', '39', '39211', '7815455', '高知県', 'コウチケン', '香南市', 'コウナンシ', '香我美町中西川', 'カガミチョウナカニシガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香南市香我美町福万', '39', '39211', '7815461', '高知県', 'コウチケン', '香南市', 'コウナンシ', '香我美町福万', 'カガミチョウフクマン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香南市香我美町山川', '39', '39211', '7815462', '高知県', 'コウチケン', '香南市', 'コウナンシ', '香我美町山川', 'カガミチョウヤマガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香南市香我美町末延', '39', '39211', '7815463', '高知県', 'コウチケン', '香南市', 'コウナンシ', '香我美町末延', 'カガミチョウスエノブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香南市香我美町末清', '39', '39211', '7815464', '高知県', 'コウチケン', '香南市', 'コウナンシ', '香我美町末清', 'カガミチョウスエキヨ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香南市香我美町正延', '39', '39211', '7815465', '高知県', 'コウチケン', '香南市', 'コウナンシ', '香我美町正延', 'カガミチョウマサノブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香南市香我美町別役', '39', '39211', '7815466', '高知県', 'コウチケン', '香南市', 'コウナンシ', '香我美町別役', 'カガミチョウベッチャク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香南市香我美町奥西川', '39', '39211', '7815467', '高知県', 'コウチケン', '香南市', 'コウナンシ', '香我美町奥西川', 'カガミチョウオクニシガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香南市香我美町撫川', '39', '39211', '7815468', '高知県', 'コウチケン', '香南市', 'コウナンシ', '香我美町撫川', 'カガミチョウムガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香南市香我美町舞川', '39', '39211', '7815469', '高知県', 'コウチケン', '香南市', 'コウナンシ', '香我美町舞川', 'カガミチョウマイカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香南市夜須町坪井', '39', '39211', '7815601', '高知県', 'コウチケン', '香南市', 'コウナンシ', '夜須町坪井', 'ヤスチョウツボイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香南市夜須町千切', '39', '39211', '7815602', '高知県', 'コウチケン', '香南市', 'コウナンシ', '夜須町千切', 'ヤスチョウチギレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香南市夜須町西山', '39', '39211', '7815603', '高知県', 'コウチケン', '香南市', 'コウナンシ', '夜須町西山', 'ヤスチョウニシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香南市夜須町出口', '39', '39211', '7815604', '高知県', 'コウチケン', '香南市', 'コウナンシ', '夜須町出口', 'ヤスチョウイデグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香南市夜須町十ノ木', '39', '39211', '7815605', '高知県', 'コウチケン', '香南市', 'コウナンシ', '夜須町十ノ木', 'ヤスチョウトオノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香南市夜須町上夜須', '39', '39211', '7815606', '高知県', 'コウチケン', '香南市', 'コウナンシ', '夜須町上夜須', 'ヤスチョウカミヤス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香南市夜須町夜須川', '39', '39211', '7815611', '高知県', 'コウチケン', '香南市', 'コウナンシ', '夜須町夜須川', 'ヤスチョウヤスガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香南市夜須町細川', '39', '39211', '7815612', '高知県', 'コウチケン', '香南市', 'コウナンシ', '夜須町細川', 'ヤスチョウホソカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香南市夜須町国光', '39', '39211', '7815613', '高知県', 'コウチケン', '香南市', 'コウナンシ', '夜須町国光', 'ヤスチョウクニミツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香南市夜須町羽尾', '39', '39211', '7815614', '高知県', 'コウチケン', '香南市', 'コウナンシ', '夜須町羽尾', 'ヤスチョウハオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香南市夜須町沢谷', '39', '39211', '7815615', '高知県', 'コウチケン', '香南市', 'コウナンシ', '夜須町沢谷', 'ヤスチョウサワタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香南市夜須町仲木屋', '39', '39211', '7815616', '高知県', 'コウチケン', '香南市', 'コウナンシ', '夜須町仲木屋', 'ヤスチョウナカギヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香南市夜須町手結', '39', '39211', '7815621', '高知県', 'コウチケン', '香南市', 'コウナンシ', '夜須町手結', 'ヤスチョウテイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香南市夜須町手結山', '39', '39211', '7815622', '高知県', 'コウチケン', '香南市', 'コウナンシ', '夜須町手結山', 'ヤスチョウテイヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸郡芸西村', '39', '39307', '7815700', '高知県', 'コウチケン', '安芸郡芸西村', 'アキグンゲイセイムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('98800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸郡芸西村和食甲', '39', '39307', '7815701', '高知県', 'コウチケン', '安芸郡芸西村', 'アキグンゲイセイムラ', '和食甲', 'ワジキコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸郡芸西村和食乙', '39', '39307', '7815702', '高知県', 'コウチケン', '安芸郡芸西村', 'アキグンゲイセイムラ', '和食乙', 'ワジキオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸郡芸西村西分甲', '39', '39307', '7815703', '高知県', 'コウチケン', '安芸郡芸西村', 'アキグンゲイセイムラ', '西分甲', 'ニシブンコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸郡芸西村西分乙', '39', '39307', '7815704', '高知県', 'コウチケン', '安芸郡芸西村', 'アキグンゲイセイムラ', '西分乙', 'ニシブンオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸郡芸西村馬ノ上', '39', '39307', '7815705', '高知県', 'コウチケン', '安芸郡芸西村', 'アキグンゲイセイムラ', '馬ノ上', 'ウマノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸郡芸西村道家', '39', '39307', '7815706', '高知県', 'コウチケン', '安芸郡芸西村', 'アキグンゲイセイムラ', '道家', 'ドウケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸郡芸西村国光', '39', '39307', '7815707', '高知県', 'コウチケン', '安芸郡芸西村', 'アキグンゲイセイムラ', '国光', 'クニミツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸郡芸西村久重', '39', '39307', '7815708', '高知県', 'コウチケン', '安芸郡芸西村', 'アキグンゲイセイムラ', '久重', 'クエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸郡馬路村', '39', '39306', '7816200', '高知県', 'コウチケン', '安芸郡馬路村', 'アキグンウマジムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('98811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸郡馬路村馬路', '39', '39306', '7816201', '高知県', 'コウチケン', '安芸郡馬路村', 'アキグンウマジムラ', '馬路', 'ウマジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸郡馬路村魚梁瀬', '39', '39306', '7816202', '高知県', 'コウチケン', '安芸郡馬路村', 'アキグンウマジムラ', '魚梁瀬', 'ヤナセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸郡奈半利町', '39', '39302', '7816400', '高知県', 'コウチケン', '安芸郡奈半利町', 'アキグンナハリチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('98814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸郡安田町', '39', '39304', '7816400', '高知県', 'コウチケン', '安芸郡安田町', 'アキグンヤスダチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('98815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸郡北川村', '39', '39305', '7816400', '高知県', 'コウチケン', '安芸郡北川村', 'アキグンキタガワムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('98816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸郡奈半利町甲', '39', '39302', '7816401', '高知県', 'コウチケン', '安芸郡奈半利町', 'アキグンナハリチョウ', '甲', 'コウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸郡奈半利町乙', '39', '39302', '7816402', '高知県', 'コウチケン', '安芸郡奈半利町', 'アキグンナハリチョウ', '乙', 'オツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸郡奈半利町丙', '39', '39302', '7816403', '高知県', 'コウチケン', '安芸郡奈半利町', 'アキグンナハリチョウ', '丙', 'ヘイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸郡田野町', '39', '39303', '7816410', '高知県', 'コウチケン', '安芸郡田野町', 'アキグンタノチョウ', null, '　', '（全域）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('98820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸郡安田町安田', '39', '39304', '7816421', '高知県', 'コウチケン', '安芸郡安田町', 'アキグンヤスダチョウ', '安田', 'ヤスダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸郡安田町唐浜', '39', '39304', '7816422', '高知県', 'コウチケン', '安芸郡安田町', 'アキグンヤスダチョウ', '唐浜', 'トウノハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸郡安田町西島', '39', '39304', '7816423', '高知県', 'コウチケン', '安芸郡安田町', 'アキグンヤスダチョウ', '西島', 'ニシジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸郡安田町隆見', '39', '39304', '7816424', '高知県', 'コウチケン', '安芸郡安田町', 'アキグンヤスダチョウ', '隆見', 'タカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸郡安田町東島', '39', '39304', '7816425', '高知県', 'コウチケン', '安芸郡安田町', 'アキグンヤスダチョウ', '東島', 'ヒガシジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸郡安田町間下', '39', '39304', '7816426', '高知県', 'コウチケン', '安芸郡安田町', 'アキグンヤスダチョウ', '間下', 'マゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸郡安田町内京坊', '39', '39304', '7816427', '高知県', 'コウチケン', '安芸郡安田町', 'アキグンヤスダチョウ', '内京坊', 'ナイキョウボウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸郡安田町正弘', '39', '39304', '7816430', '高知県', 'コウチケン', '安芸郡安田町', 'アキグンヤスダチョウ', '正弘', 'マサヒロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸郡安田町別所', '39', '39304', '7816431', '高知県', 'コウチケン', '安芸郡安田町', 'アキグンヤスダチョウ', '別所', 'ベッシヨ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸郡安田町西ノ川', '39', '39304', '7816432', '高知県', 'コウチケン', '安芸郡安田町', 'アキグンヤスダチョウ', '西ノ川', 'ニシノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸郡安田町中ノ川', '39', '39304', '7816433', '高知県', 'コウチケン', '安芸郡安田町', 'アキグンヤスダチョウ', '中ノ川', 'ナカノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸郡安田町与床', '39', '39304', '7816434', '高知県', 'コウチケン', '安芸郡安田町', 'アキグンヤスダチョウ', '与床', 'ヨドコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸郡安田町船倉', '39', '39304', '7816435', '高知県', 'コウチケン', '安芸郡安田町', 'アキグンヤスダチョウ', '船倉', 'フナクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸郡安田町瀬切', '39', '39304', '7816436', '高知県', 'コウチケン', '安芸郡安田町', 'アキグンヤスダチョウ', '瀬切', 'セギリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸郡安田町中里', '39', '39304', '7816437', '高知県', 'コウチケン', '安芸郡安田町', 'アキグンヤスダチョウ', '中里', 'ナカザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸郡安田町小川', '39', '39304', '7816438', '高知県', 'コウチケン', '安芸郡安田町', 'アキグンヤスダチョウ', '小川', 'オガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸郡安田町日々入', '39', '39304', '7816439', '高知県', 'コウチケン', '安芸郡安田町', 'アキグンヤスダチョウ', '日々入', 'ヒビイリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸郡北川村野友甲', '39', '39305', '7816441', '高知県', 'コウチケン', '安芸郡北川村', 'アキグンキタガワムラ', '野友甲', 'ノトモコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸郡北川村野友乙', '39', '39305', '7816442', '高知県', 'コウチケン', '安芸郡北川村', 'アキグンキタガワムラ', '野友乙', 'ノトモオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸郡北川村加茂', '39', '39305', '7816443', '高知県', 'コウチケン', '安芸郡北川村', 'アキグンキタガワムラ', '加茂', 'カモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸郡北川村野川', '39', '39305', '7816444', '高知県', 'コウチケン', '安芸郡北川村', 'アキグンキタガワムラ', '野川', 'ノガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸郡北川村長山', '39', '39305', '7816445', '高知県', 'コウチケン', '安芸郡北川村', 'アキグンキタガワムラ', '長山', 'ナガヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸郡北川村西谷', '39', '39305', '7816446', '高知県', 'コウチケン', '安芸郡北川村', 'アキグンキタガワムラ', '西谷', 'ニシダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸郡北川村木積', '39', '39305', '7816447', '高知県', 'コウチケン', '安芸郡北川村', 'アキグンキタガワムラ', '木積', 'コツモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸郡北川村宗ノ上', '39', '39305', '7816448', '高知県', 'コウチケン', '安芸郡北川村', 'アキグンキタガワムラ', '宗ノ上', 'ソウノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸郡北川村柏木', '39', '39305', '7816449', '高知県', 'コウチケン', '安芸郡北川村', 'アキグンキタガワムラ', '柏木', 'カシワギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸郡北川村和田', '39', '39305', '7816450', '高知県', 'コウチケン', '安芸郡北川村', 'アキグンキタガワムラ', '和田', 'ワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸郡北川村小島', '39', '39305', '7816451', '高知県', 'コウチケン', '安芸郡北川村', 'アキグンキタガワムラ', '小島', 'コシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸郡北川村平鍋', '39', '39305', '7816452', '高知県', 'コウチケン', '安芸郡北川村', 'アキグンキタガワムラ', '平鍋', 'ヒラナベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸郡北川村二タ又', '39', '39305', '7816453', '高知県', 'コウチケン', '安芸郡北川村', 'アキグンキタガワムラ', '二タ又', 'フタマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸郡北川村島', '39', '39305', '7816454', '高知県', 'コウチケン', '安芸郡北川村', 'アキグンキタガワムラ', '島', 'シマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸郡北川村久江ノ上', '39', '39305', '7816455', '高知県', 'コウチケン', '安芸郡北川村', 'アキグンキタガワムラ', '久江ノ上', 'クエノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸郡北川村久木', '39', '39305', '7816456', '高知県', 'コウチケン', '安芸郡北川村', 'アキグンキタガワムラ', '久木', 'クキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸郡北川村弘瀬', '39', '39305', '7816457', '高知県', 'コウチケン', '安芸郡北川村', 'アキグンキタガワムラ', '弘瀬', 'ヒロセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸郡北川村安倉', '39', '39305', '7816458', '高知県', 'コウチケン', '安芸郡北川村', 'アキグンキタガワムラ', '安倉', 'アグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸郡北川村菅ノ上', '39', '39305', '7816459', '高知県', 'コウチケン', '安芸郡北川村', 'アキグンキタガワムラ', '菅ノ上', 'スゲノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸郡北川村竹屋敷', '39', '39305', '7816460', '高知県', 'コウチケン', '安芸郡北川村', 'アキグンキタガワムラ', '竹屋敷', 'タケヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡愛別町豊里', '01', '01456', '0781651', '北海道', 'ホッカイドウ', '上川郡愛別町', 'カミカワグンアイベツチョウ', '豊里', 'トヨサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡愛別町中央', '01', '01456', '0781652', '北海道', 'ホッカイドウ', '上川郡愛別町', 'カミカワグンアイベツチョウ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡愛別町愛山', '01', '01456', '0781653', '北海道', 'ホッカイドウ', '上川郡愛別町', 'カミカワグンアイベツチョウ', '愛山', 'アイザン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡愛別町愛山町', '01', '01456', '0781654', '北海道', 'ホッカイドウ', '上川郡愛別町', 'カミカワグンアイベツチョウ', '愛山町', 'アイザンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県室戸市羽根町甲', '39', '39202', '7816741', '高知県', 'コウチケン', '室戸市', 'ムロトシ', '羽根町甲', 'ハネチョウコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県室戸市羽根町乙', '39', '39202', '7816742', '高知県', 'コウチケン', '室戸市', 'ムロトシ', '羽根町乙', 'ハネチョウオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県室戸市吉良川町乙', '39', '39202', '7816831', '高知県', 'コウチケン', '室戸市', 'ムロトシ', '吉良川町乙', 'キラガワチョウオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県室戸市吉良川町甲', '39', '39202', '7816832', '高知県', 'コウチケン', '室戸市', 'ムロトシ', '吉良川町甲', 'キラガワチョウコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県室戸市吉良川町丙', '39', '39202', '7816833', '高知県', 'コウチケン', '室戸市', 'ムロトシ', '吉良川町丙', 'キラガワチョウヘイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡上川町', '01', '01457', '0781700', '北海道', 'ホッカイドウ', '上川郡上川町', 'カミカワグンカミカワチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('98867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡上川町層雲峡', '01', '01457', '0781701', '北海道', 'ホッカイドウ', '上川郡上川町', 'カミカワグンカミカワチョウ', '層雲峡', 'ソウウンキョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県室戸市', '39', '39202', '7817100', '高知県', 'コウチケン', '室戸市', 'ムロトシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('98869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県室戸市室戸岬町', '39', '39202', '7817101', '高知県', 'コウチケン', '室戸市', 'ムロトシ', '室戸岬町', 'ムロトミサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県室戸市室津', '39', '39202', '7817102', '高知県', 'コウチケン', '室戸市', 'ムロトシ', '室津', 'ムロツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県室戸市浮津', '39', '39202', '7817103', '高知県', 'コウチケン', '室戸市', 'ムロトシ', '浮津', 'ウキツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県室戸市浮津一番町', '39', '39202', '7817104', '高知県', 'コウチケン', '室戸市', 'ムロトシ', '浮津一番町', 'ウキツ01バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県室戸市浮津二番町', '39', '39202', '7817105', '高知県', 'コウチケン', '室戸市', 'ムロトシ', '浮津二番町', 'ウキツ02バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県室戸市浮津三番町', '39', '39202', '7817106', '高知県', 'コウチケン', '室戸市', 'ムロトシ', '浮津三番町', 'ウキツ03バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県室戸市元甲', '39', '39202', '7817107', '高知県', 'コウチケン', '室戸市', 'ムロトシ', '元甲', 'モトコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県室戸市元乙', '39', '39202', '7817108', '高知県', 'コウチケン', '室戸市', 'ムロトシ', '元乙', 'モトオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県室戸市領家', '39', '39202', '7817109', '高知県', 'コウチケン', '室戸市', 'ムロトシ', '領家', 'リョウケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡上川町清川', '01', '01457', '0781711', '北海道', 'ホッカイドウ', '上川郡上川町', 'カミカワグンカミカワチョウ', '清川', 'キヨカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡上川町白川', '01', '01457', '0781712', '北海道', 'ホッカイドウ', '上川郡上川町', 'カミカワグンカミカワチョウ', '白川', 'シラカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡上川町菊水', '01', '01457', '0781721', '北海道', 'ホッカイドウ', '上川郡上川町', 'カミカワグンカミカワチョウ', '菊水', 'キクスイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡上川町新光町', '01', '01457', '0781722', '北海道', 'ホッカイドウ', '上川郡上川町', 'カミカワグンカミカワチョウ', '新光町', 'シンコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県室戸市佐喜浜町', '39', '39202', '7817220', '高知県', 'コウチケン', '室戸市', 'ムロトシ', '佐喜浜町', 'サキハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸郡東洋町', '39', '39301', '7817300', '高知県', 'コウチケン', '安芸郡東洋町', 'アキグントウヨウチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('98885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸郡東洋町野根丙', '39', '39301', '7817301', '高知県', 'コウチケン', '安芸郡東洋町', 'アキグントウヨウチョウ', '野根丙', 'ノネヘイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸郡東洋町野根甲', '39', '39301', '7817302', '高知県', 'コウチケン', '安芸郡東洋町', 'アキグントウヨウチョウ', '野根甲', 'ノネコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸郡東洋町野根丁', '39', '39301', '7817303', '高知県', 'コウチケン', '安芸郡東洋町', 'アキグントウヨウチョウ', '野根丁', 'ノネテイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸郡東洋町野根乙', '39', '39301', '7817304', '高知県', 'コウチケン', '安芸郡東洋町', 'アキグントウヨウチョウ', '野根乙', 'ノネオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡上川町東雲', '01', '01457', '0781731', '北海道', 'ホッカイドウ', '上川郡上川町', 'カミカワグンカミカワチョウ', '東雲', 'トウウン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡上川町共進', '01', '01457', '0781732', '北海道', 'ホッカイドウ', '上川郡上川町', 'カミカワグンカミカワチョウ', '共進', 'キョウシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡上川町栄町', '01', '01457', '0781733', '北海道', 'ホッカイドウ', '上川郡上川町', 'カミカワグンカミカワチョウ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡上川町中央町', '01', '01457', '0781741', '北海道', 'ホッカイドウ', '上川郡上川町', 'カミカワグンカミカワチョウ', '中央町', 'チュウオウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸郡東洋町甲浦', '39', '39301', '7817411', '高知県', 'コウチケン', '安芸郡東洋町', 'アキグントウヨウチョウ', '甲浦', 'カンノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸郡東洋町河内', '39', '39301', '7817412', '高知県', 'コウチケン', '安芸郡東洋町', 'アキグントウヨウチョウ', '河内', 'カワウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸郡東洋町白浜', '39', '39301', '7817413', '高知県', 'コウチケン', '安芸郡東洋町', 'アキグントウヨウチョウ', '白浜', 'シラハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸郡東洋町生見', '39', '39301', '7817414', '高知県', 'コウチケン', '安芸郡東洋町', 'アキグントウヨウチョウ', '生見', 'イクミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡上川町西町', '01', '01457', '0781742', '北海道', 'ホッカイドウ', '上川郡上川町', 'カミカワグンカミカワチョウ', '西町', 'ニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡上川町花園町', '01', '01457', '0781743', '北海道', 'ホッカイドウ', '上川郡上川町', 'カミカワグンカミカワチョウ', '花園町', 'ハナゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡上川町北町', '01', '01457', '0781744', '北海道', 'ホッカイドウ', '上川郡上川町', 'カミカワグンカミカワチョウ', '北町', 'キタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡上川町本町', '01', '01457', '0781751', '北海道', 'ホッカイドウ', '上川郡上川町', 'カミカワグンカミカワチョウ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡上川町川端町', '01', '01457', '0781752', '北海道', 'ホッカイドウ', '上川郡上川町', 'カミカワグンカミカワチョウ', '川端町', 'カワバタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡上川町南町', '01', '01457', '0781753', '北海道', 'ホッカイドウ', '上川郡上川町', 'カミカワグンカミカワチョウ', '南町', 'ミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡上川町旭町', '01', '01457', '0781761', '北海道', 'ホッカイドウ', '上川郡上川町', 'カミカワグンカミカワチョウ', '旭町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡上川町新町', '01', '01457', '0781762', '北海道', 'ホッカイドウ', '上川郡上川町', 'カミカワグンカミカワチョウ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡上川町東町', '01', '01457', '0781763', '北海道', 'ホッカイドウ', '上川郡上川町', 'カミカワグンカミカワチョウ', '東町', 'ヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡上川町中越', '01', '01457', '0781771', '北海道', 'ホッカイドウ', '上川郡上川町', 'カミカワグンカミカワチョウ', '中越', 'ナカコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡上川町天幕', '01', '01457', '0781772', '北海道', 'ホッカイドウ', '上川郡上川町', 'カミカワグンカミカワチョウ', '天幕', 'テンマク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡上川町日東', '01', '01457', '0781773', '北海道', 'ホッカイドウ', '上川郡上川町', 'カミカワグンカミカワチョウ', '日東', 'ニットウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡上川町豊原', '01', '01457', '0781774', '北海道', 'ホッカイドウ', '上川郡上川町', 'カミカワグンカミカワチョウ', '豊原', 'トヨハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡上川町越路', '01', '01457', '0781775', '北海道', 'ホッカイドウ', '上川郡上川町', 'カミカワグンカミカワチョウ', '越路', 'コシジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市高須砂地', '39', '39201', '7818101', '高知県', 'コウチケン', '高知市', 'コウチシ', '高須砂地', 'タカススナヂ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市高須本町', '39', '39201', '7818102', '高知県', 'コウチケン', '高知市', 'コウチシ', '高須本町', 'タカスホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市高須新木', '39', '39201', '7818103', '高知県', 'コウチケン', '高知市', 'コウチシ', '高須新木', 'タカスシンギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市高須', '39', '39201', '7818104', '高知県', 'コウチケン', '高知市', 'コウチシ', '高須', 'タカス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市高須東町', '39', '39201', '7818105', '高知県', 'コウチケン', '高知市', 'コウチシ', '高須東町', 'タカスヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市高須大島', '39', '39201', '7818111', '高知県', 'コウチケン', '高知市', 'コウチシ', '高須大島', 'タカスオオシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市高須大谷', '39', '39201', '7818112', '高知県', 'コウチケン', '高知市', 'コウチシ', '高須大谷', 'タカスオオタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市高須絶海', '39', '39201', '7818113', '高知県', 'コウチケン', '高知市', 'コウチシ', '高須絶海', 'タカスタルミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市高須西町', '39', '39201', '7818114', '高知県', 'コウチケン', '高知市', 'コウチシ', '高須西町', 'タカスニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市葛島', '39', '39201', '7818121', '高知県', 'コウチケン', '高知市', 'コウチシ', '葛島', 'カヅラシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市高須新町', '39', '39201', '7818122', '高知県', 'コウチケン', '高知市', 'コウチシ', '高須新町', 'タカスシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市高須', '39', '39201', '7818123', '高知県', 'コウチケン', '高知市', 'コウチシ', '高須', 'タカス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市屋頭', '39', '39201', '7818124', '高知県', 'コウチケン', '高知市', 'コウチシ', '屋頭', 'ヤガシラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市五台山', '39', '39201', '7818125', '高知県', 'コウチケン', '高知市', 'コウチシ', '五台山', 'ゴダイサン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市吸江', '39', '39201', '7818126', '高知県', 'コウチケン', '高知市', 'コウチシ', '吸江', 'ギュウコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市一宮', '39', '39201', '7818130', '高知県', 'コウチケン', '高知市', 'コウチシ', '一宮', 'イック', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市一宮しなね', '39', '39201', '7818131', '高知県', 'コウチケン', '高知市', 'コウチシ', '一宮しなね', 'イックシナネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市一宮東町', '39', '39201', '7818132', '高知県', 'コウチケン', '高知市', 'コウチシ', '一宮東町', 'イックヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市一宮徳谷', '39', '39201', '7818133', '高知県', 'コウチケン', '高知市', 'コウチシ', '一宮徳谷', 'イックトクダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市一宮中町', '39', '39201', '7818134', '高知県', 'コウチケン', '高知市', 'コウチシ', '一宮中町', 'イックナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市一宮南町', '39', '39201', '7818135', '高知県', 'コウチケン', '高知市', 'コウチシ', '一宮南町', 'イックミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高知市一宮西町', '39', '39201', '7818136', '高知県', 'コウチケン', '高知市', 'コウチシ', '一宮西町', 'イックニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市', '39', '39212', '7820000', '高知県', 'コウチケン', '香美市', 'カミシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('98947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市土佐山田町杉田', '39', '39212', '7820001', '高知県', 'コウチケン', '香美市', 'カミシ', '土佐山田町杉田', 'トサヤマダチョウスイタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市土佐山田町船谷', '39', '39212', '7820002', '高知県', 'コウチケン', '香美市', 'カミシ', '土佐山田町船谷', 'トサヤマダチョウフナダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市土佐山田町宮ノ口', '39', '39212', '7820003', '高知県', 'コウチケン', '香美市', 'カミシ', '土佐山田町宮ノ口', 'トサヤマダチョウミヤノクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市土佐山田町間', '39', '39212', '7820004', '高知県', 'コウチケン', '香美市', 'カミシ', '土佐山田町間', 'トサヤマダチョウハザマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市土佐山田町逆川', '39', '39212', '7820005', '高知県', 'コウチケン', '香美市', 'カミシ', '土佐山田町逆川', 'トサヤマダチョウサカカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市土佐山田町影山', '39', '39212', '7820006', '高知県', 'コウチケン', '香美市', 'カミシ', '土佐山田町影山', 'トサヤマダチョウカゲヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市土佐山田町林田', '39', '39212', '7820007', '高知県', 'コウチケン', '香美市', 'カミシ', '土佐山田町林田', 'トサヤマダチョウハヤシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市土佐山田町佐古薮', '39', '39212', '7820008', '高知県', 'コウチケン', '香美市', 'カミシ', '土佐山田町佐古薮', 'トサヤマダチョウサコヤブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市土佐山田町神母ノ木', '39', '39212', '7820009', '高知県', 'コウチケン', '香美市', 'カミシ', '土佐山田町神母ノ木', 'トサヤマダチョウイゲノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市土佐山田町テクノパーク', '39', '39212', '7820010', '高知県', 'コウチケン', '香美市', 'カミシ', '土佐山田町テクノパーク', 'トサヤマダチョウテクノパーク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市土佐山田町山田島', '39', '39212', '7820011', '高知県', 'コウチケン', '香美市', 'カミシ', '土佐山田町山田島', 'トサヤマダチョウヤマダジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市土佐山田町加茂', '39', '39212', '7820012', '高知県', 'コウチケン', '香美市', 'カミシ', '土佐山田町加茂', 'トサヤマダチョウカモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市土佐山田町町田', '39', '39212', '7820013', '高知県', 'コウチケン', '香美市', 'カミシ', '土佐山田町町田', 'トサヤマダチョウマチダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市土佐山田町小田島', '39', '39212', '7820014', '高知県', 'コウチケン', '香美市', 'カミシ', '土佐山田町小田島', 'トサヤマダチョウオダジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市土佐山田町下ノ村', '39', '39212', '7820015', '高知県', 'コウチケン', '香美市', 'カミシ', '土佐山田町下ノ村', 'トサヤマダチョウシモノムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市土佐山田町山田小島', '39', '39212', '7820016', '高知県', 'コウチケン', '香美市', 'カミシ', '土佐山田町山田', 'トサヤマダチョウヤマダ', null, null, '小島', 'コジマ');
INSERT INTO `ms_addresses` VALUES ('98963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市土佐山田町山田八王子', '39', '39212', '7820016', '高知県', 'コウチケン', '香美市', 'カミシ', '土佐山田町山田', 'トサヤマダチョウヤマダ', null, null, '八王子', 'ハチオウジ');
INSERT INTO `ms_addresses` VALUES ('98964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市土佐山田町山田原', '39', '39212', '7820016', '高知県', 'コウチケン', '香美市', 'カミシ', '土佐山田町山田', 'トサヤマダチョウヤマダ', null, null, '原', 'ハラ');
INSERT INTO `ms_addresses` VALUES ('98965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市土佐山田町岩積', '39', '39212', '7820017', '高知県', 'コウチケン', '香美市', 'カミシ', '土佐山田町岩積', 'トサヤマダチョウイワズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市土佐山田町戸板島', '39', '39212', '7820018', '高知県', 'コウチケン', '香美市', 'カミシ', '土佐山田町戸板島', 'トサヤマダチョウトイタジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市土佐山田町中野', '39', '39212', '7820019', '高知県', 'コウチケン', '香美市', 'カミシ', '土佐山田町中野', 'トサヤマダチョウナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市土佐山田町岩次', '39', '39212', '7820021', '高知県', 'コウチケン', '香美市', 'カミシ', '土佐山田町岩次', 'トサヤマダチョウイワツギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市土佐山田町京田立石', '39', '39212', '7820022', '高知県', 'コウチケン', '香美市', 'カミシ', '土佐山田町京田', 'トサヤマダチョウキョウデン', null, null, '立石', 'タテイシ');
INSERT INTO `ms_addresses` VALUES ('98970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市土佐山田町京田', '39', '39212', '7820023', '高知県', 'コウチケン', '香美市', 'カミシ', '土佐山田町京田', 'トサヤマダチョウキョウデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市土佐山田町神通寺', '39', '39212', '7820024', '高知県', 'コウチケン', '香美市', 'カミシ', '土佐山田町神通寺', 'トサヤマダチョウジンツウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市土佐山田町松本', '39', '39212', '7820025', '高知県', 'コウチケン', '香美市', 'カミシ', '土佐山田町松本', 'トサヤマダチョウマツモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市土佐山田町東本町', '39', '39212', '7820031', '高知県', 'コウチケン', '香美市', 'カミシ', '土佐山田町東本町', 'トサヤマダチョウヒガシホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市土佐山田町西本町', '39', '39212', '7820032', '高知県', 'コウチケン', '香美市', 'カミシ', '土佐山田町西本町', 'トサヤマダチョウニシホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市土佐山田町旭町', '39', '39212', '7820033', '高知県', 'コウチケン', '香美市', 'カミシ', '土佐山田町旭町', 'トサヤマダチョウアサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市土佐山田町宝町', '39', '39212', '7820034', '高知県', 'コウチケン', '香美市', 'カミシ', '土佐山田町宝町', 'トサヤマダチョウタカラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市土佐山田町百石町', '39', '39212', '7820035', '高知県', 'コウチケン', '香美市', 'カミシ', '土佐山田町百石町', 'トサヤマダチョウヒャッコクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市土佐山田町古町', '39', '39212', '7820036', '高知県', 'コウチケン', '香美市', 'カミシ', '土佐山田町', 'トサヤマダチョウ', null, null, '古町', 'フルマチ');
INSERT INTO `ms_addresses` VALUES ('98979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市土佐山田町宮前町', '39', '39212', '7820037', '高知県', 'コウチケン', '香美市', 'カミシ', '土佐山田町宮前町', 'トサヤマダチョウミヤマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市土佐山田町秦山町', '39', '39212', '7820038', '高知県', 'コウチケン', '香美市', 'カミシ', '土佐山田町秦山町', 'トサヤマダチョウジンザンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市土佐山田町栄町', '39', '39212', '7820039', '高知県', 'コウチケン', '香美市', 'カミシ', '土佐山田町栄町', 'トサヤマダチョウサカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市土佐山田町北本町', '39', '39212', '7820041', '高知県', 'コウチケン', '香美市', 'カミシ', '土佐山田町', 'トサヤマダチョウ', null, null, '北本町', 'キタホンマチ');
INSERT INTO `ms_addresses` VALUES ('98983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市土佐山田町前山', '39', '39212', '7820042', '高知県', 'コウチケン', '香美市', 'カミシ', '土佐山田町', 'トサヤマダチョウ', null, null, '前山', 'マエヤマ');
INSERT INTO `ms_addresses` VALUES ('98984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市土佐山田町北組西', '39', '39212', '7820043', '高知県', 'コウチケン', '香美市', 'カミシ', '土佐山田町', 'トサヤマダチョウ', null, null, '北組西', 'キタグミニシ');
INSERT INTO `ms_addresses` VALUES ('98985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市土佐山田町中組', '39', '39212', '7820044', '高知県', 'コウチケン', '香美市', 'カミシ', '土佐山田町', 'トサヤマダチョウ', null, null, '中組', 'ナカグミ');
INSERT INTO `ms_addresses` VALUES ('98986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市土佐山田町黒土', '39', '39212', '7820045', '高知県', 'コウチケン', '香美市', 'カミシ', '土佐山田町', 'トサヤマダチョウ', null, null, '黒土', 'クロツチ');
INSERT INTO `ms_addresses` VALUES ('98987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市土佐山田町南組', '39', '39212', '7820046', '高知県', 'コウチケン', '香美市', 'カミシ', '土佐山田町', 'トサヤマダチョウ', null, null, '南組', 'ミナミグミ');
INSERT INTO `ms_addresses` VALUES ('98988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市土佐山田町', '39', '39212', '7820047', '高知県', 'コウチケン', '香美市', 'カミシ', '土佐山田町', 'トサヤマダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市土佐山田町楠目油石', '39', '39212', '7820051', '高知県', 'コウチケン', '香美市', 'カミシ', '土佐山田町楠目', 'トサヤマダチョウクズメ', null, null, '油石', 'アブライシ');
INSERT INTO `ms_addresses` VALUES ('98990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市土佐山田町楠目前行', '39', '39212', '7820051', '高知県', 'コウチケン', '香美市', 'カミシ', '土佐山田町楠目', 'トサヤマダチョウクズメ', null, null, '前行', 'ゼンギョウ');
INSERT INTO `ms_addresses` VALUES ('98991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市土佐山田町楠目談議所', '39', '39212', '7820051', '高知県', 'コウチケン', '香美市', 'カミシ', '土佐山田町楠目', 'トサヤマダチョウクズメ', null, null, '談議所', 'ダンギショ');
INSERT INTO `ms_addresses` VALUES ('98992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市土佐山田町楠目中村', '39', '39212', '7820051', '高知県', 'コウチケン', '香美市', 'カミシ', '土佐山田町楠目', 'トサヤマダチョウクズメ', null, null, '中村', 'ナカムラ');
INSERT INTO `ms_addresses` VALUES ('98993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市土佐山田町楠目平田', '39', '39212', '7820051', '高知県', 'コウチケン', '香美市', 'カミシ', '土佐山田町楠目', 'トサヤマダチョウクズメ', null, null, '平田', 'ヒラタ');
INSERT INTO `ms_addresses` VALUES ('98994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市土佐山田町楠目伏原', '39', '39212', '7820051', '高知県', 'コウチケン', '香美市', 'カミシ', '土佐山田町楠目', 'トサヤマダチョウクズメ', null, null, '伏原', 'フシハラ');
INSERT INTO `ms_addresses` VALUES ('98995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市土佐山田町楠目予岳', '39', '39212', '7820051', '高知県', 'コウチケン', '香美市', 'カミシ', '土佐山田町楠目', 'トサヤマダチョウクズメ', null, null, '予岳', 'ヨガク');
INSERT INTO `ms_addresses` VALUES ('98996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市土佐山田町植', '39', '39212', '7820054', '高知県', 'コウチケン', '香美市', 'カミシ', '土佐山田町植', 'トサヤマダチョウウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市土佐山田町須江', '39', '39212', '7820055', '高知県', 'コウチケン', '香美市', 'カミシ', '土佐山田町須江', 'トサヤマダチョウスエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市土佐山田町上改田', '39', '39212', '7820056', '高知県', 'コウチケン', '香美市', 'カミシ', '土佐山田町上改田', 'トサヤマダチョウカミカイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('98999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市土佐山田町久次', '39', '39212', '7820057', '高知県', 'コウチケン', '香美市', 'カミシ', '土佐山田町久次', 'トサヤマダチョウヒサツギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市土佐山田町新改', '39', '39212', '7820058', '高知県', 'コウチケン', '香美市', 'カミシ', '土佐山田町新改', 'トサヤマダチョウシンガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市土佐山田町入野', '39', '39212', '7820059', '高知県', 'コウチケン', '香美市', 'カミシ', '土佐山田町入野', 'トサヤマダチョウイリノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市土佐山田町曽我部川', '39', '39212', '7820061', '高知県', 'コウチケン', '香美市', 'カミシ', '土佐山田町曽我部川', 'トサヤマダチョウソガベガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市土佐山田町平山', '39', '39212', '7820062', '高知県', 'コウチケン', '香美市', 'カミシ', '土佐山田町平山', 'トサヤマダチョウヒラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市土佐山田町東川', '39', '39212', '7820063', '高知県', 'コウチケン', '香美市', 'カミシ', '土佐山田町東川', 'トサヤマダチョウヒガシガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市土佐山田町大法寺', '39', '39212', '7820064', '高知県', 'コウチケン', '香美市', 'カミシ', '土佐山田町大法寺', 'トサヤマダチョウダイホウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市土佐山田町佐竹', '39', '39212', '7820071', '高知県', 'コウチケン', '香美市', 'カミシ', '土佐山田町佐竹', 'トサヤマダチョウサタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市土佐山田町有谷', '39', '39212', '7820072', '高知県', 'コウチケン', '香美市', 'カミシ', '土佐山田町有谷', 'トサヤマダチョウアラタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市土佐山田町中後入', '39', '39212', '7820073', '高知県', 'コウチケン', '香美市', 'カミシ', '土佐山田町中後入', 'トサヤマダチョウナカゴウニュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市土佐山田町大後入', '39', '39212', '7820074', '高知県', 'コウチケン', '香美市', 'カミシ', '土佐山田町大後入', 'トサヤマダチョウオオゴウニュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市土佐山田町西後入', '39', '39212', '7820075', '高知県', 'コウチケン', '香美市', 'カミシ', '土佐山田町西後入', 'トサヤマダチョウニシゴニュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市土佐山田町本村', '39', '39212', '7820076', '高知県', 'コウチケン', '香美市', 'カミシ', '土佐山田町本村', 'トサヤマダチョウホンムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市土佐山田町佐野仁井田', '39', '39212', '7820077', '高知県', 'コウチケン', '香美市', 'カミシ', '土佐山田町佐野', 'トサヤマダチョウサノ', null, null, '仁井田', 'ニイダ');
INSERT INTO `ms_addresses` VALUES ('99013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市土佐山田町大平', '39', '39212', '7820078', '高知県', 'コウチケン', '香美市', 'カミシ', '土佐山田町大平', 'トサヤマダチョウオオヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市土佐山田町佐野', '39', '39212', '7820079', '高知県', 'コウチケン', '香美市', 'カミシ', '土佐山田町佐野', 'トサヤマダチョウサノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道雨竜郡秩父別町', '01', '01434', '0782100', '北海道', 'ホッカイドウ', '雨竜郡秩父別町', 'ウリュウグンチップベツチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('99016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道雨竜郡秩父別町1条', '01', '01434', '0782101', '北海道', 'ホッカイドウ', '雨竜郡秩父別町', 'ウリュウグンチップベツチョウ', '1条', '01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道雨竜郡秩父別町2条', '01', '01434', '0782102', '北海道', 'ホッカイドウ', '雨竜郡秩父別町', 'ウリュウグンチップベツチョウ', '2条', '02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道雨竜郡秩父別町3条', '01', '01434', '0782103', '北海道', 'ホッカイドウ', '雨竜郡秩父別町', 'ウリュウグンチップベツチョウ', '3条', '03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道雨竜郡秩父別町4条', '01', '01434', '0782104', '北海道', 'ホッカイドウ', '雨竜郡秩父別町', 'ウリュウグンチップベツチョウ', '4条', '04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道雨竜郡秩父別町5条', '01', '01434', '0782105', '北海道', 'ホッカイドウ', '雨竜郡秩父別町', 'ウリュウグンチップベツチョウ', '5条', '05ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道雨竜郡秩父別町6条', '01', '01434', '0782106', '北海道', 'ホッカイドウ', '雨竜郡秩父別町', 'ウリュウグンチップベツチョウ', '6条', '06ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道雨竜郡秩父別町7条', '01', '01434', '0782107', '北海道', 'ホッカイドウ', '雨竜郡秩父別町', 'ウリュウグンチップベツチョウ', '7条', '07ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道雨竜郡秩父別町8条', '01', '01434', '0782108', '北海道', 'ホッカイドウ', '雨竜郡秩父別町', 'ウリュウグンチップベツチョウ', '8条', '08ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道雨竜郡秩父別町9条', '01', '01434', '0782109', '北海道', 'ホッカイドウ', '雨竜郡秩父別町', 'ウリュウグンチップベツチョウ', '9条', '09ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道雨竜郡秩父別町南1条', '01', '01434', '0782111', '北海道', 'ホッカイドウ', '雨竜郡秩父別町', 'ウリュウグンチップベツチョウ', '南1条', 'ミナミ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道雨竜郡秩父別町南2条', '01', '01434', '0782112', '北海道', 'ホッカイドウ', '雨竜郡秩父別町', 'ウリュウグンチップベツチョウ', '南2条', 'ミナミ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道雨竜郡秩父別町滝の上', '01', '01434', '0782121', '北海道', 'ホッカイドウ', '雨竜郡秩父別町', 'ウリュウグンチップベツチョウ', '滝の上', 'タキノカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道雨竜郡秩父別町中山', '01', '01434', '0782122', '北海道', 'ホッカイドウ', '雨竜郡秩父別町', 'ウリュウグンチップベツチョウ', '中山', 'ナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道雨竜郡秩父別町東山', '01', '01434', '0782123', '北海道', 'ホッカイドウ', '雨竜郡秩父別町', 'ウリュウグンチップベツチョウ', '東山', 'ヒガシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道雨竜郡秩父別町南山', '01', '01434', '0782124', '北海道', 'ホッカイドウ', '雨竜郡秩父別町', 'ウリュウグンチップベツチョウ', '南山', 'ミナミヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道雨竜郡沼田町', '01', '01438', '0782200', '北海道', 'ホッカイドウ', '雨竜郡沼田町', 'ウリュウグンヌマタチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('99034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道雨竜郡沼田町旭町', '01', '01438', '0782201', '北海道', 'ホッカイドウ', '雨竜郡沼田町', 'ウリュウグンヌマタチョウ', '旭町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道雨竜郡沼田町南1条', '01', '01438', '0782202', '北海道', 'ホッカイドウ', '雨竜郡沼田町', 'ウリュウグンヌマタチョウ', '南1条', 'ミナミ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道雨竜郡沼田町本通', '01', '01438', '0782203', '北海道', 'ホッカイドウ', '雨竜郡沼田町', 'ウリュウグンヌマタチョウ', '本通', 'ホンドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道雨竜郡沼田町西町', '01', '01438', '0782204', '北海道', 'ホッカイドウ', '雨竜郡沼田町', 'ウリュウグンヌマタチョウ', '西町', 'ニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道雨竜郡沼田町北1条', '01', '01438', '0782205', '北海道', 'ホッカイドウ', '雨竜郡沼田町', 'ウリュウグンヌマタチョウ', '北1条', 'キタ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道雨竜郡沼田町緑町', '01', '01438', '0782206', '北海道', 'ホッカイドウ', '雨竜郡沼田町', 'ウリュウグンヌマタチョウ', '緑町', 'ミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道雨竜郡沼田町更新', '01', '01438', '0782211', '北海道', 'ホッカイドウ', '雨竜郡沼田町', 'ウリュウグンヌマタチョウ', '更新', 'コウシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道雨竜郡沼田町東予', '01', '01438', '0782212', '北海道', 'ホッカイドウ', '雨竜郡沼田町', 'ウリュウグンヌマタチョウ', '東予', 'トウヨ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道雨竜郡沼田町共成', '01', '01438', '0782213', '北海道', 'ホッカイドウ', '雨竜郡沼田町', 'ウリュウグンヌマタチョウ', '共成', 'キョウセイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道雨竜郡沼田町高穂', '01', '01438', '0782214', '北海道', 'ホッカイドウ', '雨竜郡沼田町', 'ウリュウグンヌマタチョウ', '高穂', 'タカホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道雨竜郡沼田町真布', '01', '01438', '0782221', '北海道', 'ホッカイドウ', '雨竜郡沼田町', 'ウリュウグンヌマタチョウ', '真布', 'マップ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道雨竜郡沼田町沼田', '01', '01438', '0782222', '北海道', 'ホッカイドウ', '雨竜郡沼田町', 'ウリュウグンヌマタチョウ', '沼田', 'ヌマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道雨竜郡沼田町北竜', '01', '01438', '0782223', '北海道', 'ホッカイドウ', '雨竜郡沼田町', 'ウリュウグンヌマタチョウ', '北竜', 'ホクリュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道雨竜郡沼田町恵比島', '01', '01438', '0782224', '北海道', 'ホッカイドウ', '雨竜郡沼田町', 'ウリュウグンヌマタチョウ', '恵比島', 'エビシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道雨竜郡沼田町幌新', '01', '01438', '0782225', '北海道', 'ホッカイドウ', '雨竜郡沼田町', 'ウリュウグンヌマタチョウ', '幌新', 'ホロシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道雨竜郡北竜町', '01', '01437', '0782500', '北海道', 'ホッカイドウ', '雨竜郡北竜町', 'ウリュウグンホクリュウチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('99050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道雨竜郡北竜町美葉牛', '01', '01437', '0782501', '北海道', 'ホッカイドウ', '雨竜郡北竜町', 'ウリュウグンホクリュウチョウ', '美葉牛', 'ビバウシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道雨竜郡北竜町岩村', '01', '01437', '0782502', '北海道', 'ホッカイドウ', '雨竜郡北竜町', 'ウリュウグンホクリュウチョウ', '岩村', 'イワムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道雨竜郡北竜町碧水', '01', '01437', '0782503', '北海道', 'ホッカイドウ', '雨竜郡北竜町', 'ウリュウグンホクリュウチョウ', '碧水', 'ヘキスイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道雨竜郡北竜町板谷', '01', '01437', '0782511', '北海道', 'ホッカイドウ', '雨竜郡北竜町', 'ウリュウグンホクリュウチョウ', '板谷', 'イタヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道雨竜郡北竜町和', '01', '01437', '0782512', '北海道', 'ホッカイドウ', '雨竜郡北竜町', 'ウリュウグンホクリュウチョウ', '和', 'ヤワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道雨竜郡北竜町三谷', '01', '01437', '0782513', '北海道', 'ホッカイドウ', '雨竜郡北竜町', 'ウリュウグンホクリュウチョウ', '三谷', 'ミタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道雨竜郡北竜町恵岱別', '01', '01437', '0782514', '北海道', 'ホッカイドウ', '雨竜郡北竜町', 'ウリュウグンホクリュウチョウ', '恵岱別', 'エタイベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道雨竜郡北竜町竜西', '01', '01437', '0782515', '北海道', 'ホッカイドウ', '雨竜郡北竜町', 'ウリュウグンホクリュウチョウ', '竜西', 'リュウサイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道雨竜郡北竜町西川', '01', '01437', '0782516', '北海道', 'ホッカイドウ', '雨竜郡北竜町', 'ウリュウグンホクリュウチョウ', '西川', 'ニシカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道雨竜郡雨竜町第5町内', '01', '01436', '0782531', '北海道', 'ホッカイドウ', '雨竜郡雨竜町', 'ウリュウグンウリュウチョウ', '第5町内', 'ダイ05チョウナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道雨竜郡雨竜町', '01', '01436', '0782600', '北海道', 'ホッカイドウ', '雨竜郡雨竜町', 'ウリュウグンウリュウチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('99061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道雨竜郡雨竜町第1町内', '01', '01436', '0782631', '北海道', 'ホッカイドウ', '雨竜郡雨竜町', 'ウリュウグンウリュウチョウ', '第1町内', 'ダイ01チョウナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道雨竜郡雨竜町第2町内', '01', '01436', '0782632', '北海道', 'ホッカイドウ', '雨竜郡雨竜町', 'ウリュウグンウリュウチョウ', '第2町内', 'ダイ02チョウナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道雨竜郡雨竜町第3町内', '01', '01436', '0782633', '北海道', 'ホッカイドウ', '雨竜郡雨竜町', 'ウリュウグンウリュウチョウ', '第3町内', 'ダイ03チョウナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道雨竜郡雨竜町第4町内', '01', '01436', '0782634', '北海道', 'ホッカイドウ', '雨竜郡雨竜町', 'ウリュウグンウリュウチョウ', '第4町内', 'ダイ04チョウナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道雨竜郡雨竜町第5町内', '01', '01436', '0782635', '北海道', 'ホッカイドウ', '雨竜郡雨竜町', 'ウリュウグンウリュウチョウ', '第5町内', 'ダイ05チョウナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道雨竜郡雨竜町第6町内', '01', '01436', '0782636', '北海道', 'ホッカイドウ', '雨竜郡雨竜町', 'ウリュウグンウリュウチョウ', '第6町内', 'ダイ06チョウナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道雨竜郡雨竜町第7町内', '01', '01436', '0782637', '北海道', 'ホッカイドウ', '雨竜郡雨竜町', 'ウリュウグンウリュウチョウ', '第7町内', 'ダイ07チョウナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道雨竜郡雨竜町第8町内', '01', '01436', '0782638', '北海道', 'ホッカイドウ', '雨竜郡雨竜町', 'ウリュウグンウリュウチョウ', '第8町内', 'ダイ08チョウナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道雨竜郡雨竜町第9町内', '01', '01436', '0782639', '北海道', 'ホッカイドウ', '雨竜郡雨竜町', 'ウリュウグンウリュウチョウ', '第9町内', 'ダイ09チョウナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道雨竜郡雨竜町第10町内', '01', '01436', '0782641', '北海道', 'ホッカイドウ', '雨竜郡雨竜町', 'ウリュウグンウリュウチョウ', '第10町内', 'ダイ10チョウナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道雨竜郡雨竜町第11町内', '01', '01436', '0782642', '北海道', 'ホッカイドウ', '雨竜郡雨竜町', 'ウリュウグンウリュウチョウ', '第11町内', 'ダイ11チョウナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道樺戸郡新十津川町美沢', '01', '01432', '0782651', '北海道', 'ホッカイドウ', '樺戸郡新十津川町', 'カバトグンシントツカワチョウ', '美沢', 'ミサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県南国市', '39', '39204', '7830000', '高知県', 'コウチケン', '南国市', 'ナンコクシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('99076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県南国市日吉町', '39', '39204', '7830001', '高知県', 'コウチケン', '南国市', 'ナンコクシ', '日吉町', 'ヒヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県南国市駅前町', '39', '39204', '7830002', '高知県', 'コウチケン', '南国市', 'ナンコクシ', '駅前町', 'エキマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県南国市西野田町', '39', '39204', '7830003', '高知県', 'コウチケン', '南国市', 'ナンコクシ', '西野田町', 'ニシノダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県南国市大そね甲', '39', '39204', '7830004', '高知県', 'コウチケン', '南国市', 'ナンコクシ', '大そね甲', 'オオソネコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県南国市大そね乙', '39', '39204', '7830005', '高知県', 'コウチケン', '南国市', 'ナンコクシ', '大そね乙', 'オオソネオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県南国市篠原', '39', '39204', '7830006', '高知県', 'コウチケン', '南国市', 'ナンコクシ', '篠原', 'シノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県南国市明見', '39', '39204', '7830007', '高知県', 'コウチケン', '南国市', 'ナンコクシ', '明見', 'ミョウケン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県南国市伊達野', '39', '39204', '7830008', '高知県', 'コウチケン', '南国市', 'ナンコクシ', '伊達野', 'イタチノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県南国市後免町', '39', '39204', '7830011', '高知県', 'コウチケン', '南国市', 'ナンコクシ', '後免町', 'ゴメンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県南国市東山町', '39', '39204', '7830012', '高知県', 'コウチケン', '南国市', 'ナンコクシ', '東山町', 'ヒガシヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県南国市幸町', '39', '39204', '7830013', '高知県', 'コウチケン', '南国市', 'ナンコクシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県南国市元町', '39', '39204', '7830014', '高知県', 'コウチケン', '南国市', 'ナンコクシ', '元町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県南国市野中', '39', '39204', '7830021', '高知県', 'コウチケン', '南国市', 'ナンコクシ', '野中', 'ノナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県南国市小籠', '39', '39204', '7830022', '高知県', 'コウチケン', '南国市', 'ナンコクシ', '小籠', 'コゴメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県南国市廿枝', '39', '39204', '7830023', '高知県', 'コウチケン', '南国市', 'ナンコクシ', '廿枝', 'ハタエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県南国市東崎', '39', '39204', '7830024', '高知県', 'コウチケン', '南国市', 'ナンコクシ', '東崎', 'ヒガシザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県南国市下末松', '39', '39204', '7830025', '高知県', 'コウチケン', '南国市', 'ナンコクシ', '下末松', 'シモスエマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県南国市上末松', '39', '39204', '7830026', '高知県', 'コウチケン', '南国市', 'ナンコクシ', '上末松', 'カミスエマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県南国市三畠', '39', '39204', '7830027', '高知県', 'コウチケン', '南国市', 'ナンコクシ', '三畠', 'サンバク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県南国市陣山', '39', '39204', '7830028', '高知県', 'コウチケン', '南国市', 'ナンコクシ', '陣山', 'ジンヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県南国市西山', '39', '39204', '7830029', '高知県', 'コウチケン', '南国市', 'ナンコクシ', '西山', 'ニシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県南国市下野田', '39', '39204', '7830031', '高知県', 'コウチケン', '南国市', 'ナンコクシ', '下野田', 'シモノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県南国市上野田', '39', '39204', '7830032', '高知県', 'コウチケン', '南国市', 'ナンコクシ', '上野田', 'カミノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県南国市包末', '39', '39204', '7830033', '高知県', 'コウチケン', '南国市', 'ナンコクシ', '包末', 'カノスエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県南国市堀ノ内', '39', '39204', '7830034', '高知県', 'コウチケン', '南国市', 'ナンコクシ', '堀ノ内', 'ホリノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県南国市金地', '39', '39204', '7830035', '高知県', 'コウチケン', '南国市', 'ナンコクシ', '金地', 'カナジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県南国市福船', '39', '39204', '7830036', '高知県', 'コウチケン', '南国市', 'ナンコクシ', '福船', 'フクブネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県南国市蔵福寺島', '39', '39204', '7830037', '高知県', 'コウチケン', '南国市', 'ナンコクシ', '蔵福寺島', 'ゾウフクジジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県南国市岡豊町滝本', '39', '39204', '7830040', '高知県', 'コウチケン', '南国市', 'ナンコクシ', '岡豊町滝本', 'オコウチョウタキモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県南国市岡豊町定林寺', '39', '39204', '7830041', '高知県', 'コウチケン', '南国市', 'ナンコクシ', '岡豊町定林寺', 'オコウチョウジョウリンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県南国市岡豊町蒲原', '39', '39204', '7830042', '高知県', 'コウチケン', '南国市', 'ナンコクシ', '岡豊町蒲原', 'オコウチョウカモハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県南国市岡豊町小蓮', '39', '39204', '7830043', '高知県', 'コウチケン', '南国市', 'ナンコクシ', '岡豊町小蓮', 'オコウチョウコハス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県南国市岡豊町八幡', '39', '39204', '7830044', '高知県', 'コウチケン', '南国市', 'ナンコクシ', '岡豊町八幡', 'オコウチョウヤハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県南国市岡豊町吉田', '39', '39204', '7830045', '高知県', 'コウチケン', '南国市', 'ナンコクシ', '岡豊町吉田', 'オコウチョウヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県南国市岡豊町江村', '39', '39204', '7830046', '高知県', 'コウチケン', '南国市', 'ナンコクシ', '岡豊町江村', 'オコウチョウエムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県南国市岡豊町常通寺島', '39', '39204', '7830047', '高知県', 'コウチケン', '南国市', 'ナンコクシ', '岡豊町常通寺島', 'オコウチョウジョウツウジシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県南国市岡豊町小篭', '39', '39204', '7830048', '高知県', 'コウチケン', '南国市', 'ナンコクシ', '岡豊町小篭', 'オコウチョウコゴメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県南国市岡豊町中島', '39', '39204', '7830049', '高知県', 'コウチケン', '南国市', 'ナンコクシ', '岡豊町中島', 'オコウチョウナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県南国市岡豊町笠ノ川', '39', '39204', '7830051', '高知県', 'コウチケン', '南国市', 'ナンコクシ', '岡豊町笠ノ川', 'オコウチョウカサノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県南国市左右山', '39', '39204', '7830052', '高知県', 'コウチケン', '南国市', 'ナンコクシ', '左右山', 'ソヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県南国市国分', '39', '39204', '7830053', '高知県', 'コウチケン', '南国市', 'ナンコクシ', '国分', 'コクブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県南国市比江', '39', '39204', '7830054', '高知県', 'コウチケン', '南国市', 'ナンコクシ', '比江', 'ヒエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県南国市双葉台', '39', '39204', '7830055', '高知県', 'コウチケン', '南国市', 'ナンコクシ', '双葉台', 'フタバダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県南国市領石', '39', '39204', '7830056', '高知県', 'コウチケン', '南国市', 'ナンコクシ', '領石', 'リョウセキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県南国市八京', '39', '39204', '7830057', '高知県', 'コウチケン', '南国市', 'ナンコクシ', '八京', 'ヤキョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県南国市白木谷', '39', '39204', '7830058', '高知県', 'コウチケン', '南国市', 'ナンコクシ', '白木谷', 'シラキダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県南国市蛍が丘', '39', '39204', '7830060', '高知県', 'コウチケン', '南国市', 'ナンコクシ', '蛍が丘', 'ホタルガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県南国市植野', '39', '39204', '7830061', '高知県', 'コウチケン', '南国市', 'ナンコクシ', '植野', 'ウエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県南国市久礼田', '39', '39204', '7830062', '高知県', 'コウチケン', '南国市', 'ナンコクシ', '久礼田', 'クレダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県南国市植田', '39', '39204', '7830063', '高知県', 'コウチケン', '南国市', 'ナンコクシ', '植田', 'ウエタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県南国市宍崎', '39', '39204', '7830064', '高知県', 'コウチケン', '南国市', 'ナンコクシ', '宍崎', 'シシザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県南国市外山', '39', '39204', '7830065', '高知県', 'コウチケン', '南国市', 'ナンコクシ', '外山', 'トヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県南国市成合', '39', '39204', '7830066', '高知県', 'コウチケン', '南国市', 'ナンコクシ', '成合', 'ナレアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県南国市天行寺', '39', '39204', '7830067', '高知県', 'コウチケン', '南国市', 'ナンコクシ', '天行寺', 'テンギョウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県南国市才谷', '39', '39204', '7830068', '高知県', 'コウチケン', '南国市', 'ナンコクシ', '才谷', 'サイダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県南国市亀岩', '39', '39204', '7830071', '高知県', 'コウチケン', '南国市', 'ナンコクシ', '亀岩', 'カメイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県南国市奈路', '39', '39204', '7830072', '高知県', 'コウチケン', '南国市', 'ナンコクシ', '奈路', 'ナロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県南国市中谷', '39', '39204', '7830073', '高知県', 'コウチケン', '南国市', 'ナンコクシ', '中谷', 'ナカダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県南国市上倉', '39', '39204', '7830074', '高知県', 'コウチケン', '南国市', 'ナンコクシ', '上倉', 'アゲクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県南国市桑ノ川', '39', '39204', '7830075', '高知県', 'コウチケン', '南国市', 'ナンコクシ', '桑ノ川', 'クワノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県南国市黒滝', '39', '39204', '7830076', '高知県', 'コウチケン', '南国市', 'ナンコクシ', '黒滝', 'クロタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県南国市大改野', '39', '39204', '7830077', '高知県', 'コウチケン', '南国市', 'ナンコクシ', '大改野', 'オオガイノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県南国市中ノ川', '39', '39204', '7830078', '高知県', 'コウチケン', '南国市', 'ナンコクシ', '中ノ川', 'ナカノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県南国市片山', '39', '39204', '7830081', '高知県', 'コウチケン', '南国市', 'ナンコクシ', '片山', 'カタヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県南国市里改田', '39', '39204', '7830082', '高知県', 'コウチケン', '南国市', 'ナンコクシ', '里改田', 'サトカイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県南国市浜改田', '39', '39204', '7830083', '高知県', 'コウチケン', '南国市', 'ナンコクシ', '浜改田', 'ハマカイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県南国市稲生', '39', '39204', '7830084', '高知県', 'コウチケン', '南国市', 'ナンコクシ', '稲生', 'イナブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県南国市十市', '39', '39204', '7830085', '高知県', 'コウチケン', '南国市', 'ナンコクシ', '十市', 'トオチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県南国市緑ケ丘', '39', '39204', '7830086', '高知県', 'コウチケン', '南国市', 'ナンコクシ', '緑ケ丘', 'ミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県南国市三和琴平', '39', '39204', '7830087', '高知県', 'コウチケン', '南国市', 'ナンコクシ', '三和琴平', 'ミワコトヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県南国市立田', '39', '39204', '7830091', '高知県', 'コウチケン', '南国市', 'ナンコクシ', '立田', 'タテダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県南国市田村', '39', '39204', '7830092', '高知県', 'コウチケン', '南国市', 'ナンコクシ', '田村', 'タムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県南国市物部', '39', '39204', '7830093', '高知県', 'コウチケン', '南国市', 'ナンコクシ', '物部', 'モノベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県南国市前浜', '39', '39204', '7830094', '高知県', 'コウチケン', '南国市', 'ナンコクシ', '前浜', 'マエハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県南国市下島', '39', '39204', '7830095', '高知県', 'コウチケン', '南国市', 'ナンコクシ', '下島', 'シモジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県南国市久枝', '39', '39204', '7830096', '高知県', 'コウチケン', '南国市', 'ナンコクシ', '久枝', 'ヒサエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道留萌市留萌村峠下', '01', '01212', '0783161', '北海道', 'ホッカイドウ', '留萌市', 'ルモイシ', '留萌村', 'ルモイムラ', null, null, '峠下', 'トウゲシタ');
INSERT INTO `ms_addresses` VALUES ('99153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道留萌市東幌町', '01', '01212', '0783162', '北海道', 'ホッカイドウ', '留萌市', 'ルモイシ', '東幌町', 'ヒガシホロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道留萌市南幌町', '01', '01212', '0783163', '北海道', 'ホッカイドウ', '留萌市', 'ルモイシ', '南幌町', 'ミナミホロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道留萌市留萌村幌糠', '01', '01212', '0783164', '北海道', 'ホッカイドウ', '留萌市', 'ルモイシ', '留萌村', 'ルモイムラ', null, null, '幌糠', 'ホロヌカ');
INSERT INTO `ms_addresses` VALUES ('99156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道留萌市藤山町', '01', '01212', '0783165', '北海道', 'ホッカイドウ', '留萌市', 'ルモイシ', '藤山町', 'フジヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道留萌市留萌原野', '01', '01212', '0783165', '北海道', 'ホッカイドウ', '留萌市', 'ルモイシ', '留萌原野', 'ルモイゲンヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道留萌市中幌町', '01', '01212', '0783166', '北海道', 'ホッカイドウ', '留萌市', 'ルモイシ', '中幌町', 'ナカホロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道留萌市樽真布町', '01', '01212', '0783167', '北海道', 'ホッカイドウ', '留萌市', 'ルモイシ', '樽真布町', 'タルマップチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道留萌市幌糠町', '01', '01212', '0783168', '北海道', 'ホッカイドウ', '留萌市', 'ルモイシ', '幌糠町', 'ホロヌカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道留萌郡小平町', '01', '01482', '0783300', '北海道', 'ホッカイドウ', '留萌郡小平町', 'ルモイグンオビラチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('99162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道留萌郡小平町小平町', '01', '01482', '0783301', '北海道', 'ホッカイドウ', '留萌郡小平町', 'ルモイグンオビラチョウ', '小平町', 'オビラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道留萌郡小平町臼谷', '01', '01482', '0783302', '北海道', 'ホッカイドウ', '留萌郡小平町', 'ルモイグンオビラチョウ', '臼谷', 'ウスヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道留萌郡小平町豊平', '01', '01482', '0783303', '北海道', 'ホッカイドウ', '留萌郡小平町', 'ルモイグンオビラチョウ', '豊平', 'トヨヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道留萌郡小平町本郷', '01', '01482', '0783304', '北海道', 'ホッカイドウ', '留萌郡小平町', 'ルモイグンオビラチョウ', '本郷', 'ホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道留萌郡小平町桑園', '01', '01482', '0783305', '北海道', 'ホッカイドウ', '留萌郡小平町', 'ルモイグンオビラチョウ', '桑園', 'ソウエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道留萌郡小平町菊岡', '01', '01482', '0783306', '北海道', 'ホッカイドウ', '留萌郡小平町', 'ルモイグンオビラチョウ', '菊岡', 'キクオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道留萌郡小平町豊岡', '01', '01482', '0783307', '北海道', 'ホッカイドウ', '留萌郡小平町', 'ルモイグンオビラチョウ', '豊岡', 'トヨオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道留萌郡小平町岐富', '01', '01482', '0783308', '北海道', 'ホッカイドウ', '留萌郡小平町', 'ルモイグンオビラチョウ', '岐富', 'キフ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道留萌郡小平町沖内', '01', '01482', '0783309', '北海道', 'ホッカイドウ', '留萌郡小平町', 'ルモイグンオビラチョウ', '沖内', 'オキナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道留萌郡小平町花岡', '01', '01482', '0783311', '北海道', 'ホッカイドウ', '留萌郡小平町', 'ルモイグンオビラチョウ', '花岡', 'ハナオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道留萌郡小平町富里', '01', '01482', '0783312', '北海道', 'ホッカイドウ', '留萌郡小平町', 'ルモイグンオビラチョウ', '富里', 'トミサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道留萌郡小平町平和1区', '01', '01482', '0783313', '北海道', 'ホッカイドウ', '留萌郡小平町', 'ルモイグンオビラチョウ', '平和', 'ヘイワ', null, null, '1区', '01ク');
INSERT INTO `ms_addresses` VALUES ('99177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道留萌郡小平町鬼鹿港町', '01', '01482', '0783441', '北海道', 'ホッカイドウ', '留萌郡小平町', 'ルモイグンオビラチョウ', '鬼鹿港町', 'オニシカミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道留萌郡小平町鬼鹿田代', '01', '01482', '0783442', '北海道', 'ホッカイドウ', '留萌郡小平町', 'ルモイグンオビラチョウ', '鬼鹿田代', 'オニシカタシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道留萌郡小平町鬼鹿豊浜', '01', '01482', '0783451', '北海道', 'ホッカイドウ', '留萌郡小平町', 'ルモイグンオビラチョウ', '鬼鹿豊浜', 'オニシカトヨハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道留萌郡小平町鬼鹿千松', '01', '01482', '0783452', '北海道', 'ホッカイドウ', '留萌郡小平町', 'ルモイグンオビラチョウ', '鬼鹿千松', 'オニシカセンマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道留萌郡小平町鬼鹿元浜', '01', '01482', '0783453', '北海道', 'ホッカイドウ', '留萌郡小平町', 'ルモイグンオビラチョウ', '鬼鹿元浜', 'オニシカモトハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道留萌郡小平町鬼鹿広富', '01', '01482', '0783454', '北海道', 'ホッカイドウ', '留萌郡小平町', 'ルモイグンオビラチョウ', '鬼鹿広富', 'オニシカヒロトミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道留萌郡小平町鬼鹿秀浦', '01', '01482', '0783455', '北海道', 'ホッカイドウ', '留萌郡小平町', 'ルモイグンオビラチョウ', '鬼鹿秀浦', 'オニシカヒデウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道留萌郡小平町鬼鹿富岡', '01', '01482', '0783456', '北海道', 'ホッカイドウ', '留萌郡小平町', 'ルモイグンオビラチョウ', '鬼鹿富岡', 'オニシカトミオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道留萌郡小平町大椴', '01', '01482', '0783457', '北海道', 'ホッカイドウ', '留萌郡小平町', 'ルモイグンオビラチョウ', '大椴', 'オオトド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫前郡苫前町力昼', '01', '01483', '0783541', '北海道', 'ホッカイドウ', '苫前郡苫前町', 'トママエグントママエチョウ', '力昼', 'リキビル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫前郡苫前町古丹別', '01', '01483', '0783621', '北海道', 'ホッカイドウ', '苫前郡苫前町', 'トママエグントママエチョウ', '古丹別', 'コタンベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫前郡苫前町香川', '01', '01483', '0783631', '北海道', 'ホッカイドウ', '苫前郡苫前町', 'トママエグントママエチョウ', '香川', 'カガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫前郡苫前町長島', '01', '01483', '0783632', '北海道', 'ホッカイドウ', '苫前郡苫前町', 'トママエグントママエチョウ', '長島', 'ナガシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫前郡苫前町小川', '01', '01483', '0783633', '北海道', 'ホッカイドウ', '苫前郡苫前町', 'トママエグントママエチョウ', '小川', 'コガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫前郡苫前町岩見', '01', '01483', '0783634', '北海道', 'ホッカイドウ', '苫前郡苫前町', 'トママエグントママエチョウ', '岩見', 'イワミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫前郡苫前町東川', '01', '01483', '0783635', '北海道', 'ホッカイドウ', '苫前郡苫前町', 'トママエグントママエチョウ', '東川', 'ヒガシカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫前郡苫前町霧立', '01', '01483', '0783636', '北海道', 'ホッカイドウ', '苫前郡苫前町', 'トママエグントママエチョウ', '霧立', 'キリタチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫前郡苫前町九重', '01', '01483', '0783637', '北海道', 'ホッカイドウ', '苫前郡苫前町', 'トママエグントママエチョウ', '九重', 'ココノエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫前郡苫前町三渓', '01', '01483', '0783638', '北海道', 'ホッカイドウ', '苫前郡苫前町', 'トママエグントママエチョウ', '三渓', 'サンケイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫前郡苫前町', '01', '01483', '0783700', '北海道', 'ホッカイドウ', '苫前郡苫前町', 'トママエグントママエチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('99197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫前郡苫前町苫前', '01', '01483', '0783701', '北海道', 'ホッカイドウ', '苫前郡苫前町', 'トママエグントママエチョウ', '苫前', 'トママエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫前郡苫前町栄浜', '01', '01483', '0783702', '北海道', 'ホッカイドウ', '苫前郡苫前町', 'トママエグントママエチョウ', '栄浜', 'サカエハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫前郡苫前町旭', '01', '01483', '0783711', '北海道', 'ホッカイドウ', '苫前郡苫前町', 'トママエグントママエチョウ', '旭', 'アサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫前郡苫前町上平', '01', '01483', '0783712', '北海道', 'ホッカイドウ', '苫前郡苫前町', 'トママエグントママエチョウ', '上平', 'ウエヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫前郡苫前町興津', '01', '01483', '0783713', '北海道', 'ホッカイドウ', '苫前郡苫前町', 'トママエグントママエチョウ', '興津', 'オコツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫前郡苫前町香川', '01', '01483', '0783714', '北海道', 'ホッカイドウ', '苫前郡苫前町', 'トママエグントママエチョウ', '香川', 'カガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫前郡苫前町昭和', '01', '01483', '0783715', '北海道', 'ホッカイドウ', '苫前郡苫前町', 'トママエグントママエチョウ', '昭和', 'ショウワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫前郡苫前町豊浦', '01', '01483', '0783716', '北海道', 'ホッカイドウ', '苫前郡苫前町', 'トママエグントママエチョウ', '豊浦', 'トヨウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫前郡苫前町三豊', '01', '01483', '0783717', '北海道', 'ホッカイドウ', '苫前郡苫前町', 'トママエグントママエチョウ', '三豊', 'ミトヨ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫前郡羽幌町焼尻', '01', '01484', '0783871', '北海道', 'ホッカイドウ', '苫前郡羽幌町', 'トママエグンハボロチョウ', '焼尻', 'ヤギシリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫前郡羽幌町天売相影', '01', '01484', '0783951', '北海道', 'ホッカイドウ', '苫前郡羽幌町', 'トママエグンハボロチョウ', '天売', 'テウリ', null, null, '相影', 'アイカゲ');
INSERT INTO `ms_addresses` VALUES ('99217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫前郡羽幌町天売富磯', '01', '01484', '0783952', '北海道', 'ホッカイドウ', '苫前郡羽幌町', 'トママエグンハボロチョウ', '天売', 'テウリ', null, null, '富磯', 'トミイソ');
INSERT INTO `ms_addresses` VALUES ('99218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫前郡羽幌町天売和浦', '01', '01484', '0783953', '北海道', 'ホッカイドウ', '苫前郡羽幌町', 'トママエグンハボロチョウ', '天売', 'テウリ', null, null, '和浦', 'カズウラ');
INSERT INTO `ms_addresses` VALUES ('99219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫前郡羽幌町天売前浜', '01', '01484', '0783954', '北海道', 'ホッカイドウ', '苫前郡羽幌町', 'トママエグンハボロチョウ', '天売', 'テウリ', null, null, '前浜', 'マエハマ');
INSERT INTO `ms_addresses` VALUES ('99220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫前郡羽幌町天売弁天', '01', '01484', '0783955', '北海道', 'ホッカイドウ', '苫前郡羽幌町', 'トママエグンハボロチョウ', '天売', 'テウリ', null, null, '弁天', 'ベンテン');
INSERT INTO `ms_addresses` VALUES ('99221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸市', '39', '39203', '7840000', '高知県', 'コウチケン', '安芸市', 'アキシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('99222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸市矢ノ丸', '39', '39203', '7840001', '高知県', 'コウチケン', '安芸市', 'アキシ', '矢ノ丸', 'ヤノマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸市花園町', '39', '39203', '7840002', '高知県', 'コウチケン', '安芸市', 'アキシ', '花園町', 'ハナゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸市久世町', '39', '39203', '7840003', '高知県', 'コウチケン', '安芸市', 'アキシ', '久世町', 'クセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸市本町', '39', '39203', '7840004', '高知県', 'コウチケン', '安芸市', 'アキシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸市港町', '39', '39203', '7840005', '高知県', 'コウチケン', '安芸市', 'アキシ', '港町', 'ミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸市日ノ出町', '39', '39203', '7840006', '高知県', 'コウチケン', '安芸市', 'アキシ', '日ノ出町', 'ヒノデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸市寿町', '39', '39203', '7840007', '高知県', 'コウチケン', '安芸市', 'アキシ', '寿町', 'コトブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸市清和町', '39', '39203', '7840008', '高知県', 'コウチケン', '安芸市', 'アキシ', '清和町', 'セイワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸市東浜', '39', '39203', '7840010', '高知県', 'コウチケン', '安芸市', 'アキシ', '東浜', 'ヒガシハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸市西浜', '39', '39203', '7840020', '高知県', 'コウチケン', '安芸市', 'アキシ', '西浜', 'ニシハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸市幸町', '39', '39203', '7840021', '高知県', 'コウチケン', '安芸市', 'アキシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸市庄之芝町', '39', '39203', '7840022', '高知県', 'コウチケン', '安芸市', 'アキシ', '庄之芝町', 'ショウノシバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸市染井町', '39', '39203', '7840023', '高知県', 'コウチケン', '安芸市', 'アキシ', '染井町', 'ソメイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸市千歳町', '39', '39203', '7840024', '高知県', 'コウチケン', '安芸市', 'アキシ', '千歳町', 'チトセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸市津久茂町', '39', '39203', '7840025', '高知県', 'コウチケン', '安芸市', 'アキシ', '津久茂町', 'ツクモチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸市桜ケ丘町', '39', '39203', '7840026', '高知県', 'コウチケン', '安芸市', 'アキシ', '桜ケ丘町', 'サクラガオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸市宝永町', '39', '39203', '7840027', '高知県', 'コウチケン', '安芸市', 'アキシ', '宝永町', 'ホウエイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸市黒鳥', '39', '39203', '7840028', '高知県', 'コウチケン', '安芸市', 'アキシ', '黒鳥', 'クロドリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸市植野', '39', '39203', '7840029', '高知県', 'コウチケン', '安芸市', 'アキシ', '植野', 'ウエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸市穴内甲', '39', '39203', '7840031', '高知県', 'コウチケン', '安芸市', 'アキシ', '穴内甲', 'アナナイコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸市穴内乙', '39', '39203', '7840032', '高知県', 'コウチケン', '安芸市', 'アキシ', '穴内乙', 'アナナイオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸市赤野甲', '39', '39203', '7840033', '高知県', 'コウチケン', '安芸市', 'アキシ', '赤野甲', 'アカノコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸市赤野乙', '39', '39203', '7840034', '高知県', 'コウチケン', '安芸市', 'アキシ', '赤野乙', 'アカノオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸市僧津', '39', '39203', '7840041', '高知県', 'コウチケン', '安芸市', 'アキシ', '僧津', 'ソウヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸市土居', '39', '39203', '7840042', '高知県', 'コウチケン', '安芸市', 'アキシ', '土居', 'ドイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸市川北甲', '39', '39203', '7840043', '高知県', 'コウチケン', '安芸市', 'アキシ', '川北甲', 'カワキタコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸市川北乙', '39', '39203', '7840044', '高知県', 'コウチケン', '安芸市', 'アキシ', '川北乙', 'カワキタオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸市伊尾木', '39', '39203', '7840045', '高知県', 'コウチケン', '安芸市', 'アキシ', '伊尾木', 'イオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸市下山', '39', '39203', '7840046', '高知県', 'コウチケン', '安芸市', 'アキシ', '下山', 'シモヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸市井ノ口甲', '39', '39203', '7840051', '高知県', 'コウチケン', '安芸市', 'アキシ', '井ノ口甲', 'イノクチコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸市井ノ口乙', '39', '39203', '7840052', '高知県', 'コウチケン', '安芸市', 'アキシ', '井ノ口乙', 'イノクチオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸市小谷', '39', '39203', '7840053', '高知県', 'コウチケン', '安芸市', 'アキシ', '小谷', 'オダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸市栃ノ木', '39', '39203', '7840054', '高知県', 'コウチケン', '安芸市', 'アキシ', '栃ノ木', 'トチノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸市尾川甲', '39', '39203', '7840055', '高知県', 'コウチケン', '安芸市', 'アキシ', '尾川甲', 'オガワコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸市尾川乙', '39', '39203', '7840056', '高知県', 'コウチケン', '安芸市', 'アキシ', '尾川乙', 'オガワオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸市安芸ノ川甲', '39', '39203', '7840057', '高知県', 'コウチケン', '安芸市', 'アキシ', '安芸ノ川甲', 'アキノカワコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸市安芸ノ川乙', '39', '39203', '7840058', '高知県', 'コウチケン', '安芸市', 'アキシ', '安芸ノ川乙', 'アキノカワオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸市畑山甲', '39', '39203', '7840061', '高知県', 'コウチケン', '安芸市', 'アキシ', '畑山甲', 'ハタヤマコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸市畑山乙', '39', '39203', '7840062', '高知県', 'コウチケン', '安芸市', 'アキシ', '畑山乙', 'ハタヤマオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸市畑山丙', '39', '39203', '7840063', '高知県', 'コウチケン', '安芸市', 'アキシ', '畑山丙', 'ハタヤマヘイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸市舞川', '39', '39203', '7840064', '高知県', 'コウチケン', '安芸市', 'アキシ', '舞川', 'マイカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市物部町中津尾', '39', '39212', '7840065', '高知県', 'コウチケン', '香美市', 'カミシ', '物部町中津尾', 'モノベチョウナカツオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸市奈比賀', '39', '39203', '7840271', '高知県', 'コウチケン', '安芸市', 'アキシ', '奈比賀', 'ナビカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸市入河内', '39', '39203', '7840272', '高知県', 'コウチケン', '安芸市', 'アキシ', '入河内', 'ニュウガウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸市黒瀬', '39', '39203', '7840273', '高知県', 'コウチケン', '安芸市', 'アキシ', '黒瀬', 'クロセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸市大井甲', '39', '39203', '7840274', '高知県', 'コウチケン', '安芸市', 'アキシ', '大井甲', 'オオイコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸市大井乙', '39', '39203', '7840275', '高知県', 'コウチケン', '安芸市', 'アキシ', '大井乙', 'オオイオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸市古井', '39', '39203', '7840276', '高知県', 'コウチケン', '安芸市', 'アキシ', '古井', 'コイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸市島', '39', '39203', '7840277', '高知県', 'コウチケン', '安芸市', 'アキシ', '島', 'シマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県安芸市別役', '39', '39203', '7840278', '高知県', 'コウチケン', '安芸市', 'アキシ', '別役', 'ベッチャク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫前郡羽幌町', '01', '01484', '0784100', '北海道', 'ホッカイドウ', '苫前郡羽幌町', 'トママエグンハボロチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('99273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫前郡羽幌町南1条', '01', '01484', '0784101', '北海道', 'ホッカイドウ', '苫前郡羽幌町', 'トママエグンハボロチョウ', '南1条', 'ミナミ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫前郡羽幌町南2条', '01', '01484', '0784102', '北海道', 'ホッカイドウ', '苫前郡羽幌町', 'トママエグンハボロチョウ', '南2条', 'ミナミ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫前郡羽幌町南3条', '01', '01484', '0784103', '北海道', 'ホッカイドウ', '苫前郡羽幌町', 'トママエグンハボロチョウ', '南3条', 'ミナミ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫前郡羽幌町南4条', '01', '01484', '0784104', '北海道', 'ホッカイドウ', '苫前郡羽幌町', 'トママエグンハボロチョウ', '南4条', 'ミナミ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫前郡羽幌町南5条', '01', '01484', '0784105', '北海道', 'ホッカイドウ', '苫前郡羽幌町', 'トママエグンハボロチョウ', '南5条', 'ミナミ05ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫前郡羽幌町南6条', '01', '01484', '0784106', '北海道', 'ホッカイドウ', '苫前郡羽幌町', 'トママエグンハボロチョウ', '南6条', 'ミナミ06ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫前郡羽幌町南7条', '01', '01484', '0784107', '北海道', 'ホッカイドウ', '苫前郡羽幌町', 'トママエグンハボロチョウ', '南7条', 'ミナミ07ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫前郡羽幌町南大通', '01', '01484', '0784108', '北海道', 'ホッカイドウ', '苫前郡羽幌町', 'トママエグンハボロチョウ', '南大通', 'ミナミオオドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫前郡羽幌町北大通', '01', '01484', '0784110', '北海道', 'ホッカイドウ', '苫前郡羽幌町', 'トママエグンハボロチョウ', '北大通', 'キタオオドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫前郡羽幌町北1条', '01', '01484', '0784111', '北海道', 'ホッカイドウ', '苫前郡羽幌町', 'トママエグンハボロチョウ', '北1条', 'キタ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫前郡羽幌町北2条', '01', '01484', '0784112', '北海道', 'ホッカイドウ', '苫前郡羽幌町', 'トママエグンハボロチョウ', '北2条', 'キタ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫前郡羽幌町北3条', '01', '01484', '0784113', '北海道', 'ホッカイドウ', '苫前郡羽幌町', 'トママエグンハボロチョウ', '北3条', 'キタ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫前郡羽幌町北4条', '01', '01484', '0784114', '北海道', 'ホッカイドウ', '苫前郡羽幌町', 'トママエグンハボロチョウ', '北4条', 'キタ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫前郡羽幌町北5条', '01', '01484', '0784115', '北海道', 'ホッカイドウ', '苫前郡羽幌町', 'トママエグンハボロチョウ', '北5条', 'キタ05ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫前郡羽幌町北6条', '01', '01484', '0784116', '北海道', 'ホッカイドウ', '苫前郡羽幌町', 'トママエグンハボロチョウ', '北6条', 'キタ06ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫前郡羽幌町朝日', '01', '01484', '0784117', '北海道', 'ホッカイドウ', '苫前郡羽幌町', 'トママエグンハボロチョウ', '朝日', 'アサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫前郡羽幌町浜町', '01', '01484', '0784118', '北海道', 'ホッカイドウ', '苫前郡羽幌町', 'トママエグンハボロチョウ', '浜町', 'ハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫前郡羽幌町北町', '01', '01484', '0784119', '北海道', 'ホッカイドウ', '苫前郡羽幌町', 'トママエグンハボロチョウ', '北町', 'キタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫前郡羽幌町港町', '01', '01484', '0784120', '北海道', 'ホッカイドウ', '苫前郡羽幌町', 'トママエグンハボロチョウ', '港町', 'ミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫前郡羽幌町幸町', '01', '01484', '0784121', '北海道', 'ホッカイドウ', '苫前郡羽幌町', 'トママエグンハボロチョウ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫前郡羽幌町南町', '01', '01484', '0784122', '北海道', 'ホッカイドウ', '苫前郡羽幌町', 'トママエグンハボロチョウ', '南町', 'ミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫前郡羽幌町栄町', '01', '01484', '0784123', '北海道', 'ホッカイドウ', '苫前郡羽幌町', 'トママエグンハボロチョウ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫前郡羽幌町緑町', '01', '01484', '0784130', '北海道', 'ホッカイドウ', '苫前郡羽幌町', 'トママエグンハボロチョウ', '緑町', 'ミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫前郡羽幌町寿町', '01', '01484', '0784131', '北海道', 'ホッカイドウ', '苫前郡羽幌町', 'トママエグンハボロチョウ', '寿町', 'コトブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫前郡羽幌町中央', '01', '01484', '0784132', '北海道', 'ホッカイドウ', '苫前郡羽幌町', 'トママエグンハボロチョウ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫前郡羽幌町平', '01', '01484', '0784133', '北海道', 'ホッカイドウ', '苫前郡羽幌町', 'トママエグンハボロチョウ', '平', 'タイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫前郡羽幌町上羽幌', '01', '01484', '0784134', '北海道', 'ホッカイドウ', '苫前郡羽幌町', 'トママエグンハボロチョウ', '上羽幌', 'カミハボロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫前郡羽幌町汐見', '01', '01484', '0784140', '北海道', 'ホッカイドウ', '苫前郡羽幌町', 'トママエグンハボロチョウ', '汐見', 'シオミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫前郡羽幌町築別', '01', '01484', '0784141', '北海道', 'ホッカイドウ', '苫前郡羽幌町', 'トママエグンハボロチョウ', '築別', 'チクベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫前郡羽幌町上築', '01', '01484', '0784142', '北海道', 'ホッカイドウ', '苫前郡羽幌町', 'トママエグンハボロチョウ', '上築', 'カミチク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫前郡羽幌町高台', '01', '01484', '0784143', '北海道', 'ホッカイドウ', '苫前郡羽幌町', 'トママエグンハボロチョウ', '高台', 'タカダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫前郡羽幌町曙', '01', '01484', '0784144', '北海道', 'ホッカイドウ', '苫前郡羽幌町', 'トママエグンハボロチョウ', '曙', 'アケボノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫前郡羽幌町築別炭砿', '01', '01484', '0784145', '北海道', 'ホッカイドウ', '苫前郡羽幌町', 'トママエグンハボロチョウ', '築別炭砿', 'チクベツタンコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫前郡初山別村', '01', '01485', '0784400', '北海道', 'ホッカイドウ', '苫前郡初山別村', 'トママエグンショサンベツムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('99311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫前郡初山別村有明', '01', '01485', '0784411', '北海道', 'ホッカイドウ', '苫前郡初山別村', 'トママエグンショサンベツムラ', '有明', 'アリアケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫前郡初山別村栄', '01', '01485', '0784412', '北海道', 'ホッカイドウ', '苫前郡初山別村', 'トママエグンショサンベツムラ', '栄', 'サカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫前郡初山別村初山別', '01', '01485', '0784421', '北海道', 'ホッカイドウ', '苫前郡初山別村', 'トママエグンショサンベツムラ', '初山別', 'ショサンベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫前郡初山別村千代田', '01', '01485', '0784422', '北海道', 'ホッカイドウ', '苫前郡初山別村', 'トママエグンショサンベツムラ', '千代田', 'チヨダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫前郡初山別村豊岬', '01', '01485', '0784431', '北海道', 'ホッカイドウ', '苫前郡初山別村', 'トママエグンショサンベツムラ', '豊岬', 'トヨサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫前郡初山別村明里', '01', '01485', '0784432', '北海道', 'ホッカイドウ', '苫前郡初山別村', 'トママエグンショサンベツムラ', '明里', 'アケサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道苫前郡初山別村共成', '01', '01485', '0784433', '北海道', 'ホッカイドウ', '苫前郡初山別村', 'トママエグンショサンベツムラ', '共成', 'キョウセイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県須崎市', '39', '39206', '7850000', '高知県', 'コウチケン', '須崎市', 'スサキシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('99323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県須崎市原町', '39', '39206', '7850001', '高知県', 'コウチケン', '須崎市', 'スサキシ', '原町', 'ハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県須崎市港町', '39', '39206', '7850002', '高知県', 'コウチケン', '須崎市', 'スサキシ', '港町', 'ミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県須崎市新町', '39', '39206', '7850003', '高知県', 'コウチケン', '須崎市', 'スサキシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県須崎市青木町', '39', '39206', '7850004', '高知県', 'コウチケン', '須崎市', 'スサキシ', '青木町', 'アオキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県須崎市東古市町', '39', '39206', '7850005', '高知県', 'コウチケン', '須崎市', 'スサキシ', '東古市町', 'ヒガシフルイチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県須崎市浜町', '39', '39206', '7850006', '高知県', 'コウチケン', '須崎市', 'スサキシ', '浜町', 'ハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県須崎市南古市町', '39', '39206', '7850007', '高知県', 'コウチケン', '須崎市', 'スサキシ', '南古市町', 'ミナミフルイチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県須崎市中町', '39', '39206', '7850008', '高知県', 'コウチケン', '須崎市', 'スサキシ', '中町', 'ナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県須崎市西町', '39', '39206', '7850009', '高知県', 'コウチケン', '須崎市', 'スサキシ', '西町', 'ニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県須崎市鍛冶町', '39', '39206', '7850010', '高知県', 'コウチケン', '須崎市', 'スサキシ', '鍛冶町', 'カジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県須崎市東糺町', '39', '39206', '7850011', '高知県', 'コウチケン', '須崎市', 'スサキシ', '東糺町', 'ヒガシタダスマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県須崎市西糺町', '39', '39206', '7850012', '高知県', 'コウチケン', '須崎市', 'スサキシ', '西糺町', 'ニシタダスマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県須崎市西古市町', '39', '39206', '7850013', '高知県', 'コウチケン', '須崎市', 'スサキシ', '西古市町', 'ニシフルイチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県須崎市横町', '39', '39206', '7850014', '高知県', 'コウチケン', '須崎市', 'スサキシ', '横町', 'ヨコマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県須崎市幸町', '39', '39206', '7850015', '高知県', 'コウチケン', '須崎市', 'スサキシ', '幸町', 'サイワイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県須崎市栄町', '39', '39206', '7850016', '高知県', 'コウチケン', '須崎市', 'スサキシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県須崎市泉町', '39', '39206', '7850017', '高知県', 'コウチケン', '須崎市', 'スサキシ', '泉町', 'イズミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県須崎市須崎', '39', '39206', '7850018', '高知県', 'コウチケン', '須崎市', 'スサキシ', '須崎', 'スサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県須崎市池ノ内', '39', '39206', '7850021', '高知県', 'コウチケン', '須崎市', 'スサキシ', '池ノ内', 'イケノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県須崎市下分甲', '39', '39206', '7850022', '高知県', 'コウチケン', '須崎市', 'スサキシ', '下分甲', 'シモブンコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県須崎市下分乙', '39', '39206', '7850023', '高知県', 'コウチケン', '須崎市', 'スサキシ', '下分乙', 'シモブンオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県須崎市安和', '39', '39206', '7850024', '高知県', 'コウチケン', '須崎市', 'スサキシ', '安和', 'アワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県須崎市下郷', '39', '39206', '7850025', '高知県', 'コウチケン', '須崎市', 'スサキシ', '下郷', 'シモゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県須崎市上分甲', '39', '39206', '7850026', '高知県', 'コウチケン', '須崎市', 'スサキシ', '上分甲', 'カミブンコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県須崎市上分乙', '39', '39206', '7850027', '高知県', 'コウチケン', '須崎市', 'スサキシ', '上分乙', 'カミブンオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県須崎市上分丙', '39', '39206', '7850028', '高知県', 'コウチケン', '須崎市', 'スサキシ', '上分丙', 'カミブンヘイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県須崎市多ノ郷甲', '39', '39206', '7850030', '高知県', 'コウチケン', '須崎市', 'スサキシ', '多ノ郷甲', 'オオノゴウコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県須崎市山手町', '39', '39206', '7850031', '高知県', 'コウチケン', '須崎市', 'スサキシ', '山手町', 'ヤマテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県須崎市潮田町', '39', '39206', '7850032', '高知県', 'コウチケン', '須崎市', 'スサキシ', '潮田町', 'シオタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県須崎市大間西町', '39', '39206', '7850033', '高知県', 'コウチケン', '須崎市', 'スサキシ', '大間西町', 'オオマニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県須崎市大間本町', '39', '39206', '7850034', '高知県', 'コウチケン', '須崎市', 'スサキシ', '大間本町', 'オオマホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県須崎市大間東町', '39', '39206', '7850035', '高知県', 'コウチケン', '須崎市', 'スサキシ', '大間東町', 'オオマヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県須崎市緑町', '39', '39206', '7850036', '高知県', 'コウチケン', '須崎市', 'スサキシ', '緑町', 'ミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県須崎市赤崎町', '39', '39206', '7850037', '高知県', 'コウチケン', '須崎市', 'スサキシ', '赤崎町', 'アカザキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県須崎市西崎町', '39', '39206', '7850041', '高知県', 'コウチケン', '須崎市', 'スサキシ', '西崎町', 'ニシザキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県須崎市妙見町', '39', '39206', '7850042', '高知県', 'コウチケン', '須崎市', 'スサキシ', '妙見町', 'ミョウケンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県須崎市土崎町', '39', '39206', '7850043', '高知県', 'コウチケン', '須崎市', 'スサキシ', '土崎町', 'ツチザキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県須崎市吾井郷乙', '39', '39206', '7850044', '高知県', 'コウチケン', '須崎市', 'スサキシ', '吾井郷乙', 'アイノゴウオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県須崎市桑田山乙', '39', '39206', '7850045', '高知県', 'コウチケン', '須崎市', 'スサキシ', '桑田山乙', 'ソウダヤマオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県須崎市桑田山甲', '39', '39206', '7850046', '高知県', 'コウチケン', '須崎市', 'スサキシ', '桑田山甲', 'ソウダヤマコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県須崎市吾井郷甲', '39', '39206', '7850047', '高知県', 'コウチケン', '須崎市', 'スサキシ', '吾井郷甲', 'アイノゴウコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県須崎市神田', '39', '39206', '7850051', '高知県', 'コウチケン', '須崎市', 'スサキシ', '神田', 'コウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県須崎市押岡', '39', '39206', '7850052', '高知県', 'コウチケン', '須崎市', 'スサキシ', '押岡', 'オシオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県須崎市久通', '39', '39206', '7850053', '高知県', 'コウチケン', '須崎市', 'スサキシ', '久通', 'クツウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県須崎市多ノ郷乙', '39', '39206', '7850054', '高知県', 'コウチケン', '須崎市', 'スサキシ', '多ノ郷乙', 'オオノゴウオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県須崎市大谷', '39', '39206', '7850055', '高知県', 'コウチケン', '須崎市', 'スサキシ', '大谷', 'オオタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県須崎市野見', '39', '39206', '7850056', '高知県', 'コウチケン', '須崎市', 'スサキシ', '野見', 'ノミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県須崎市浦ノ内西分', '39', '39206', '7850161', '高知県', 'コウチケン', '須崎市', 'スサキシ', '浦ノ内西分', 'ウラノウチニシブン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県須崎市浦ノ内東分', '39', '39206', '7850162', '高知県', 'コウチケン', '須崎市', 'スサキシ', '浦ノ内東分', 'ウラノウチヒガシブン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県須崎市浦ノ内東分', '39', '39206', '7850163', '高知県', 'コウチケン', '須崎市', 'スサキシ', '浦ノ内東分', 'ウラノウチヒガシブン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県須崎市浦ノ内立目摺木', '39', '39206', '7850164', '高知県', 'コウチケン', '須崎市', 'スサキシ', '浦ノ内立目摺木', 'ウラノウチタチメスルギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県須崎市浦ノ内出見', '39', '39206', '7850165', '高知県', 'コウチケン', '須崎市', 'スサキシ', '浦ノ内出見', 'ウラノウチイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県須崎市浦ノ内塩間', '39', '39206', '7850166', '高知県', 'コウチケン', '須崎市', 'スサキシ', '浦ノ内塩間', 'ウラノウチシワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県須崎市浦ノ内灰方', '39', '39206', '7850167', '高知県', 'コウチケン', '須崎市', 'スサキシ', '浦ノ内灰方', 'ウラノウチハイガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県須崎市浦ノ内須ノ浦', '39', '39206', '7850171', '高知県', 'コウチケン', '須崎市', 'スサキシ', '浦ノ内須ノ浦', 'ウラノウチスノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県須崎市浦ノ内福良', '39', '39206', '7850172', '高知県', 'コウチケン', '須崎市', 'スサキシ', '浦ノ内福良', 'ウラノウチフクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県須崎市浦ノ内今川内', '39', '39206', '7850173', '高知県', 'コウチケン', '須崎市', 'スサキシ', '浦ノ内今川内', 'ウラノウチコンガワウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県須崎市浦ノ内下中山', '39', '39206', '7850174', '高知県', 'コウチケン', '須崎市', 'スサキシ', '浦ノ内下中山', 'ウラノウチシモナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡津野町', '39', '39411', '7850200', '高知県', 'コウチケン', '高岡郡津野町', 'タカオカグンツノチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('99384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡津野町永野', '39', '39411', '7850201', '高知県', 'コウチケン', '高岡郡津野町', 'タカオカグンツノチョウ', '永野', 'ナガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡津野町姫野々', '39', '39411', '7850202', '高知県', 'コウチケン', '高岡郡津野町', 'タカオカグンツノチョウ', '姫野々', 'ヒメノノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡津野町貝ノ川', '39', '39411', '7850203', '高知県', 'コウチケン', '高岡郡津野町', 'タカオカグンツノチョウ', '貝ノ川', 'カイノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡津野町久保川', '39', '39411', '7850204', '高知県', 'コウチケン', '高岡郡津野町', 'タカオカグンツノチョウ', '久保川', 'クボカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡津野町西谷甲', '39', '39411', '7850205', '高知県', 'コウチケン', '高岡郡津野町', 'タカオカグンツノチョウ', '西谷甲', 'ニシダニコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡津野町樺の川', '39', '39411', '7850206', '高知県', 'コウチケン', '高岡郡津野町', 'タカオカグンツノチョウ', '樺の川', 'カバノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡津野町新土居', '39', '39411', '7850207', '高知県', 'コウチケン', '高岡郡津野町', 'タカオカグンツノチョウ', '新土居', 'シンドイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡津野町三間川', '39', '39411', '7850208', '高知県', 'コウチケン', '高岡郡津野町', 'タカオカグンツノチョウ', '三間川', 'ミマノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡津野町西谷乙', '39', '39411', '7850209', '高知県', 'コウチケン', '高岡郡津野町', 'タカオカグンツノチョウ', '西谷乙', 'ニシダニオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡津野町貝ノ川床鍋', '39', '39411', '7850210', '高知県', 'コウチケン', '高岡郡津野町', 'タカオカグンツノチョウ', '貝ノ川床鍋', 'カイノカワトコナベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡津野町白石甲', '39', '39411', '7850211', '高知県', 'コウチケン', '高岡郡津野町', 'タカオカグンツノチョウ', '白石甲', 'シライシコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡津野町白石乙', '39', '39411', '7850212', '高知県', 'コウチケン', '高岡郡津野町', 'タカオカグンツノチョウ', '白石乙', 'シライシオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡津野町白石丙', '39', '39411', '7850213', '高知県', 'コウチケン', '高岡郡津野町', 'タカオカグンツノチョウ', '白石丙', 'シライシヘイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡津野町杉ノ川甲', '39', '39411', '7850214', '高知県', 'コウチケン', '高岡郡津野町', 'タカオカグンツノチョウ', '杉ノ川甲', 'スギノカワコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡津野町杉ノ川乙', '39', '39411', '7850215', '高知県', 'コウチケン', '高岡郡津野町', 'タカオカグンツノチョウ', '杉ノ川乙', 'スギノカワオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡津野町杉ノ川丙', '39', '39411', '7850216', '高知県', 'コウチケン', '高岡郡津野町', 'タカオカグンツノチョウ', '杉ノ川丙', 'スギノカワヘイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡津野町黒川', '39', '39411', '7850217', '高知県', 'コウチケン', '高岡郡津野町', 'タカオカグンツノチョウ', '黒川', 'クロカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡津野町大野', '39', '39411', '7850218', '高知県', 'コウチケン', '高岡郡津野町', 'タカオカグンツノチョウ', '大野', 'オオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡津野町赤木', '39', '39411', '7850219', '高知県', 'コウチケン', '高岡郡津野町', 'タカオカグンツノチョウ', '赤木', 'アカギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡津野町船戸', '39', '39411', '7850411', '高知県', 'コウチケン', '高岡郡津野町', 'タカオカグンツノチョウ', '船戸', 'フナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡津野町桑ケ市', '39', '39411', '7850412', '高知県', 'コウチケン', '高岡郡津野町', 'タカオカグンツノチョウ', '桑ケ市', 'クワガイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡津野町烏出川', '39', '39411', '7850413', '高知県', 'コウチケン', '高岡郡津野町', 'タカオカグンツノチョウ', '烏出川', 'カラスデガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡津野町力石', '39', '39411', '7850501', '高知県', 'コウチケン', '高岡郡津野町', 'タカオカグンツノチョウ', '力石', 'チカライシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡津野町北川', '39', '39411', '7850502', '高知県', 'コウチケン', '高岡郡津野町', 'タカオカグンツノチョウ', '北川', 'キタガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡津野町芳生野甲', '39', '39411', '7850503', '高知県', 'コウチケン', '高岡郡津野町', 'タカオカグンツノチョウ', '芳生野甲', 'ヨシウノコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡津野町芳生野乙', '39', '39411', '7850504', '高知県', 'コウチケン', '高岡郡津野町', 'タカオカグンツノチョウ', '芳生野乙', 'ヨシウノオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡津野町芳生野丙', '39', '39411', '7850505', '高知県', 'コウチケン', '高岡郡津野町', 'タカオカグンツノチョウ', '芳生野丙', 'ヨシウノヘイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡檮原町', '39', '39405', '7850600', '高知県', 'コウチケン', '高岡郡檮原町', 'タカオカグンユスハラチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('99415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡檮原町永野', '39', '39405', '7850601', '高知県', 'コウチケン', '高岡郡檮原町', 'タカオカグンユスハラチョウ', '永野', 'ナガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡檮原町井の谷', '39', '39405', '7850602', '高知県', 'コウチケン', '高岡郡檮原町', 'タカオカグンユスハラチョウ', '井の谷', 'イノタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡檮原町太田戸', '39', '39405', '7850603', '高知県', 'コウチケン', '高岡郡檮原町', 'タカオカグンユスハラチョウ', '太田戸', 'オオタド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡檮原町横貝', '39', '39405', '7850604', '高知県', 'コウチケン', '高岡郡檮原町', 'タカオカグンユスハラチョウ', '横貝', 'ヨコガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡檮原町下本村', '39', '39405', '7850605', '高知県', 'コウチケン', '高岡郡檮原町', 'タカオカグンユスハラチョウ', '下本村', 'シモホンムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡檮原町上本村', '39', '39405', '7850606', '高知県', 'コウチケン', '高岡郡檮原町', 'タカオカグンユスハラチョウ', '上本村', 'カミホンムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡檮原町田野々', '39', '39405', '7850607', '高知県', 'コウチケン', '高岡郡檮原町', 'タカオカグンユスハラチョウ', '田野々', 'タノノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡檮原町後別当', '39', '39405', '7850608', '高知県', 'コウチケン', '高岡郡檮原町', 'タカオカグンユスハラチョウ', '後別当', 'ゴベットウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡檮原町檮原', '39', '39405', '7850610', '高知県', 'コウチケン', '高岡郡檮原町', 'タカオカグンユスハラチョウ', '檮原', 'ユスハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡檮原町飯母', '39', '39405', '7850611', '高知県', 'コウチケン', '高岡郡檮原町', 'タカオカグンユスハラチョウ', '飯母', 'イイボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡檮原町川西路', '39', '39405', '7850612', '高知県', 'コウチケン', '高岡郡檮原町', 'タカオカグンユスハラチョウ', '川西路', 'カワニシジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡檮原町大蔵谷', '39', '39405', '7850613', '高知県', 'コウチケン', '高岡郡檮原町', 'タカオカグンユスハラチョウ', '大蔵谷', 'オゾウタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡檮原町太郎川', '39', '39405', '7850621', '高知県', 'コウチケン', '高岡郡檮原町', 'タカオカグンユスハラチョウ', '太郎川', 'タロウガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡檮原町神在居', '39', '39405', '7850622', '高知県', 'コウチケン', '高岡郡檮原町', 'タカオカグンユスハラチョウ', '神在居', 'カンザイコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡檮原町仲洞', '39', '39405', '7850623', '高知県', 'コウチケン', '高岡郡檮原町', 'タカオカグンユスハラチョウ', '仲洞', 'ナカトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡檮原町下折渡', '39', '39405', '7850624', '高知県', 'コウチケン', '高岡郡檮原町', 'タカオカグンユスハラチョウ', '下折渡', 'シモオリワタリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡檮原町上折渡', '39', '39405', '7850625', '高知県', 'コウチケン', '高岡郡檮原町', 'タカオカグンユスハラチョウ', '上折渡', 'カミオリワタリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡檮原町大野地', '39', '39405', '7850626', '高知県', 'コウチケン', '高岡郡檮原町', 'タカオカグンユスハラチョウ', '大野地', 'オオノジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡檮原町影野地', '39', '39405', '7850627', '高知県', 'コウチケン', '高岡郡檮原町', 'タカオカグンユスハラチョウ', '影野地', 'カゲノジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡檮原町佐渡', '39', '39405', '7850631', '高知県', 'コウチケン', '高岡郡檮原町', 'タカオカグンユスハラチョウ', '佐渡', 'サワタリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡檮原町初瀬本村', '39', '39405', '7850632', '高知県', 'コウチケン', '高岡郡檮原町', 'タカオカグンユスハラチョウ', '初瀬本村', 'ハツセホンムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡檮原町豊原', '39', '39405', '7850633', '高知県', 'コウチケン', '高岡郡檮原町', 'タカオカグンユスハラチョウ', '豊原', 'トヨハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡檮原町仲久保', '39', '39405', '7850634', '高知県', 'コウチケン', '高岡郡檮原町', 'タカオカグンユスハラチョウ', '仲久保', 'ナカクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡檮原町川井', '39', '39405', '7850635', '高知県', 'コウチケン', '高岡郡檮原町', 'タカオカグンユスハラチョウ', '川井', 'カワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡檮原町川口', '39', '39405', '7850636', '高知県', 'コウチケン', '高岡郡檮原町', 'タカオカグンユスハラチョウ', '川口', 'カワグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡檮原町上成', '39', '39405', '7850641', '高知県', 'コウチケン', '高岡郡檮原町', 'タカオカグンユスハラチョウ', '上成', 'ウワナロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡檮原町松谷', '39', '39405', '7850642', '高知県', 'コウチケン', '高岡郡檮原町', 'タカオカグンユスハラチョウ', '松谷', 'マツダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡檮原町宮野々', '39', '39405', '7850643', '高知県', 'コウチケン', '高岡郡檮原町', 'タカオカグンユスハラチョウ', '宮野々', 'ミヤノノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡檮原町広野', '39', '39405', '7850644', '高知県', 'コウチケン', '高岡郡檮原町', 'タカオカグンユスハラチョウ', '広野', 'ヒロノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡檮原町竹の薮', '39', '39405', '7850645', '高知県', 'コウチケン', '高岡郡檮原町', 'タカオカグンユスハラチョウ', '竹の薮', 'タケノヤブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡檮原町上西の川', '39', '39405', '7850646', '高知県', 'コウチケン', '高岡郡檮原町', 'タカオカグンユスハラチョウ', '上西の川', 'カミニシノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡檮原町下西の川', '39', '39405', '7850647', '高知県', 'コウチケン', '高岡郡檮原町', 'タカオカグンユスハラチョウ', '下西の川', 'シモニシノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡檮原町仲間', '39', '39405', '7850648', '高知県', 'コウチケン', '高岡郡檮原町', 'タカオカグンユスハラチョウ', '仲間', 'ナカイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡檮原町茶や谷', '39', '39405', '7850651', '高知県', 'コウチケン', '高岡郡檮原町', 'タカオカグンユスハラチョウ', '茶や谷', 'チャヤダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡檮原町本も谷', '39', '39405', '7850652', '高知県', 'コウチケン', '高岡郡檮原町', 'タカオカグンユスハラチョウ', '本も谷', 'オモダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡檮原町中の川', '39', '39405', '7850653', '高知県', 'コウチケン', '高岡郡檮原町', 'タカオカグンユスハラチョウ', '中の川', 'ナカノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡檮原町上組', '39', '39405', '7850654', '高知県', 'コウチケン', '高岡郡檮原町', 'タカオカグンユスハラチョウ', '上組', 'カミグミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡檮原町下組', '39', '39405', '7850655', '高知県', 'コウチケン', '高岡郡檮原町', 'タカオカグンユスハラチョウ', '下組', 'シモグミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡檮原町東川', '39', '39405', '7850656', '高知県', 'コウチケン', '高岡郡檮原町', 'タカオカグンユスハラチョウ', '東川', 'ヒガシガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡檮原町東向', '39', '39405', '7850657', '高知県', 'コウチケン', '高岡郡檮原町', 'タカオカグンユスハラチョウ', '東向', 'コチムキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡檮原町富永', '39', '39405', '7850658', '高知県', 'コウチケン', '高岡郡檮原町', 'タカオカグンユスハラチョウ', '富永', 'トミナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡檮原町六丁', '39', '39405', '7850661', '高知県', 'コウチケン', '高岡郡檮原町', 'タカオカグンユスハラチョウ', '六丁', 'ロクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡檮原町坂本川', '39', '39405', '7850662', '高知県', 'コウチケン', '高岡郡檮原町', 'タカオカグンユスハラチョウ', '坂本川', 'サカモトガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡檮原町文丸', '39', '39405', '7850663', '高知県', 'コウチケン', '高岡郡檮原町', 'タカオカグンユスハラチョウ', '文丸', 'ブンマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡檮原町神の山', '39', '39405', '7850664', '高知県', 'コウチケン', '高岡郡檮原町', 'タカオカグンユスハラチョウ', '神の山', 'カミノヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡檮原町坪野田', '39', '39405', '7850665', '高知県', 'コウチケン', '高岡郡檮原町', 'タカオカグンユスハラチョウ', '坪野田', 'ツボノタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡檮原町井高', '39', '39405', '7850666', '高知県', 'コウチケン', '高岡郡檮原町', 'タカオカグンユスハラチョウ', '井高', 'イコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡檮原町大向', '39', '39405', '7850771', '高知県', 'コウチケン', '高岡郡檮原町', 'タカオカグンユスハラチョウ', '大向', 'オオムカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡檮原町中平', '39', '39405', '7850772', '高知県', 'コウチケン', '高岡郡檮原町', 'タカオカグンユスハラチョウ', '中平', 'ナカヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡檮原町松原', '39', '39405', '7850773', '高知県', 'コウチケン', '高岡郡檮原町', 'タカオカグンユスハラチョウ', '松原', 'マツバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡檮原町久保谷', '39', '39405', '7850774', '高知県', 'コウチケン', '高岡郡檮原町', 'タカオカグンユスハラチョウ', '久保谷', 'クボタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡檮原町島中', '39', '39405', '7850775', '高知県', 'コウチケン', '高岡郡檮原町', 'タカオカグンユスハラチョウ', '島中', 'シマジュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡檮原町家籠戸', '39', '39405', '7850776', '高知県', 'コウチケン', '高岡郡檮原町', 'タカオカグンユスハラチョウ', '家籠戸', 'カロウト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町', '39', '39412', '7860000', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('99487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町藤ノ川', '39', '39412', '7860001', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '藤ノ川', 'フジノガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町見付', '39', '39412', '7860002', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '見付', 'ミツケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町金上野', '39', '39412', '7860003', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '金上野', 'キンジョウノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町茂串町', '39', '39412', '7860004', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '茂串町', 'シゲクシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町本町', '39', '39412', '7860005', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町東町', '39', '39412', '7860006', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '東町', 'ヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町古市町', '39', '39412', '7860007', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '古市町', 'フルイチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町榊山町', '39', '39412', '7860008', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '榊山町', 'サカキヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町窪川', '39', '39412', '7860010', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '窪川', 'クボカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町香月が丘', '39', '39412', '7860011', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '香月が丘', 'カゲツガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町北琴平町', '39', '39412', '7860012', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '北琴平町', 'キタコトヒラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町琴平町', '39', '39412', '7860013', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '琴平町', 'コトヒラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町新開町', '39', '39412', '7860014', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '新開町', 'シンガイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町西原', '39', '39412', '7860015', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '西原', 'サイバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町大井野', '39', '39412', '7860016', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '大井野', 'オオイノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町神ノ西', '39', '39412', '7860017', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '神ノ西', 'コウノサイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町仕出原', '39', '39412', '7860018', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '仕出原', 'シデハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町仁井田', '39', '39412', '7860021', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '仁井田', 'ニイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町小向', '39', '39412', '7860022', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '小向', 'コムカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町中ノ越', '39', '39412', '7860023', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '中ノ越', 'ナカノコエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町向川', '39', '39412', '7860024', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '向川', 'ムカイガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町富岡', '39', '39412', '7860025', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '富岡', 'トミオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町平串', '39', '39412', '7860026', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '平串', 'ヒラグシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町東大奈路', '39', '39412', '7860027', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '東大奈路', 'ヒガシオオナロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町根元原', '39', '39412', '7860028', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '根元原', 'ゴンゲンバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町床鍋', '39', '39412', '7860031', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '床鍋', 'トコナベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町影野', '39', '39412', '7860032', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '影野', 'カゲノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町道徳', '39', '39412', '7860033', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '道徳', 'ドウトク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町替坂本', '39', '39412', '7860034', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '替坂本', 'カエザカモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町六反地', '39', '39412', '7860035', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '六反地', 'ロクタンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町下呉地', '39', '39412', '7860036', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '下呉地', 'シモクレジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町魚の川', '39', '39412', '7860037', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '魚の川', 'ウオノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町奥呉地', '39', '39412', '7860038', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '奥呉地', 'オククレジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町奈路', '39', '39412', '7860041', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '奈路', 'ナロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町黒石', '39', '39412', '7860042', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '黒石', 'クロイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町本堂', '39', '39412', '7860043', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '本堂', 'ホンドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町与津地', '39', '39412', '7860044', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '与津地', 'ヨツジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町興津', '39', '39412', '7860045', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '興津', 'オキツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町興津', '39', '39412', '7860046', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '興津', 'オキツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町八千数', '39', '39412', '7860047', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '八千数', 'ハッセンズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町親ケ内', '39', '39412', '7860048', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '親ケ内', 'オヤガウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町数神', '39', '39412', '7860049', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '数神', 'カズコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町平野', '39', '39412', '7860051', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '平野', 'ヒラノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町土居', '39', '39412', '7860052', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '土居', 'ドイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町弘見', '39', '39412', '7860053', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '弘見', 'ヒロミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町飯ノ川', '39', '39412', '7860054', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '飯ノ川', 'ハンノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町志和峰', '39', '39412', '7860055', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '志和峰', 'シワミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町志和', '39', '39412', '7860056', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '志和', 'シワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町小鶴津', '39', '39412', '7860057', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '小鶴津', 'コヅルツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町大鶴津', '39', '39412', '7860058', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '大鶴津', 'オオツルツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町峰ノ上', '39', '39412', '7860061', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '峰ノ上', 'ミネノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町若井川', '39', '39412', '7860062', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '若井川', 'ワカイガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町高野', '39', '39412', '7860063', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '高野', 'タカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町家地川', '39', '39412', '7860064', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '家地川', 'イエジガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町野地', '39', '39412', '7860065', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '野地', 'ノジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町天の川', '39', '39412', '7860066', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '天の川', 'ソラノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町大向', '39', '39412', '7860067', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '大向', 'オオムカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町若井', '39', '39412', '7860068', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '若井', 'ワカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町奥神ノ川', '39', '39412', '7860071', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '奥神ノ川', 'オクゴウノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町中神ノ川', '39', '39412', '7860072', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '中神ノ川', 'ナカゴウノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町口神ノ川', '39', '39412', '7860073', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '口神ノ川', 'クチゴウノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町南川口', '39', '39412', '7860074', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '南川口', 'ミナミカワグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町秋丸', '39', '39412', '7860075', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '秋丸', 'アキマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町寺野', '39', '39412', '7860076', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '寺野', 'テラノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町桧生原', '39', '39412', '7860077', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '桧生原', 'ヒサハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町折合', '39', '39412', '7860078', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '折合', 'オレアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町中村', '39', '39412', '7860081', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '中村', 'ナカムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町七里', '39', '39412', '7860082', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '七里', 'ナナサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町西川角', '39', '39412', '7860083', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '西川角', 'ニシカワヅノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町東川角', '39', '39412', '7860084', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '東川角', 'ヒガシカワヅノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町根々崎', '39', '39412', '7860085', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '根々崎', 'ネネザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町宮内', '39', '39412', '7860086', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '宮内', 'ミヤウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町作屋', '39', '39412', '7860087', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '作屋', 'サクヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町市生原', '39', '39412', '7860088', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '市生原', 'イチウバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町川ノ内', '39', '39412', '7860091', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '川ノ内', 'カワノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町勝賀野', '39', '39412', '7860092', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '勝賀野', 'ショウガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町東北ノ川', '39', '39412', '7860093', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '東北ノ川', 'ヒガシキタノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町一斗俵', '39', '39412', '7860094', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '一斗俵', 'イットヒョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町米奥', '39', '39412', '7860095', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '米奥', 'ヨネオク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町窪川中津川', '39', '39412', '7860096', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '窪川中津川', 'クボカワナカツガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町日野地', '39', '39412', '7860097', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '日野地', 'ヒノジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町上秋丸', '39', '39412', '7860098', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '上秋丸', 'カミアキマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町大正', '39', '39412', '7860301', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '大正', 'タイショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町大正葛籠川', '39', '39412', '7860301', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '大正', 'タイショウ', null, null, '葛籠川', 'ツヅラガワ');
INSERT INTO `ms_addresses` VALUES ('99571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町瀬里', '39', '39412', '7860302', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '瀬里', 'セリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町希ノ川', '39', '39412', '7860303', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '希ノ川', 'キノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町下岡', '39', '39412', '7860304', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '下岡', 'シモオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町上岡', '39', '39412', '7860305', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '上岡', 'カミオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町小石', '39', '39412', '7860306', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '小石', 'コイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町江師', '39', '39412', '7860307', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '江師', 'エシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町芳川', '39', '39412', '7860308', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '芳川', 'ヨシカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町西ノ川', '39', '39412', '7860311', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '西ノ川', 'ニシノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町大正大奈路', '39', '39412', '7860312', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '大正大奈路', 'タイショウオオナロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町木屋ケ内', '39', '39412', '7860313', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '木屋ケ内', 'コヤガウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町下道', '39', '39412', '7860314', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '下道', 'シモドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町下津井', '39', '39412', '7860315', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '下津井', 'シモツイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町大正中津川', '39', '39412', '7860316', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '大正中津川', 'タイショウナカツガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町大正北ノ川', '39', '39412', '7860321', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '大正北ノ川', 'タイショウキタノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町打井川', '39', '39412', '7860322', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '打井川', 'ウツイガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町上宮', '39', '39412', '7860323', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '上宮', 'ジョウグウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町弘瀬', '39', '39412', '7860324', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '弘瀬', 'ヒロセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町市ノ又', '39', '39412', '7860325', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '市ノ又', 'イチノマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町烏手', '39', '39412', '7860326', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '烏手', 'カラスデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町相去', '39', '39412', '7860327', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '相去', 'アイザレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町地吉', '39', '39412', '7860501', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '地吉', 'ジヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町古城', '39', '39412', '7860502', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '古城', 'コジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町戸川', '39', '39412', '7860503', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '戸川', 'トガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町十川', '39', '39412', '7860504', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '十川', 'トオカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町昭和', '39', '39412', '7860511', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '昭和', 'ショウワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町昭和甲', '39', '39412', '7860512', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '昭和甲', 'ショウワコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町昭和乙', '39', '39412', '7860513', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '昭和乙', 'ショウワオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町河内', '39', '39412', '7860514', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '河内', 'カワウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町久保川', '39', '39412', '7860515', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '久保川', 'クボカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町口大道', '39', '39412', '7860516', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '口大道', 'クチオオドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町奥大道', '39', '39412', '7860517', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '奥大道', 'オクオオドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町津賀', '39', '39412', '7860521', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '津賀', 'ツガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町茅吹手', '39', '39412', '7860522', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '茅吹手', 'カヤブクテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町浦越', '39', '39412', '7860523', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '浦越', 'ウラゴシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町里川', '39', '39412', '7860524', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '里川', 'サトカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町野々川', '39', '39412', '7860525', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '野々川', 'ノノガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町小野', '39', '39412', '7860531', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '小野', 'オノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町大井川', '39', '39412', '7860532', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '大井川', 'オオイガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町井崎', '39', '39412', '7860533', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '井崎', 'イサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町広瀬', '39', '39412', '7860534', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '広瀬', 'ヒロセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡四万十町十和川口', '39', '39412', '7860535', '高知県', 'コウチケン', '高岡郡四万十町', 'タカオカグンシマントチョウ', '十和川口', 'トオワカワグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市', '39', '39210', '7870000', '高知県', 'コウチケン', '四万十市', 'シマントシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('99616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市中村本町', '39', '39210', '7870001', '高知県', 'コウチケン', '四万十市', 'シマントシ', '中村本町', 'ナカムラホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市中村桜町', '39', '39210', '7870002', '高知県', 'コウチケン', '四万十市', 'シマントシ', '中村桜町', 'ナカムラサクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市中村丸の内', '39', '39210', '7870003', '高知県', 'コウチケン', '四万十市', 'シマントシ', '中村丸の内', 'ナカムラマルノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市中村丸の内丸の内ハイランド', '39', '39210', '7870004', '高知県', 'コウチケン', '四万十市', 'シマントシ', '中村丸の内', 'ナカムラマルノウチ', null, null, '丸の内ハイランド', 'マルノウチハイランド');
INSERT INTO `ms_addresses` VALUES ('99620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市中村桂山団地', '39', '39210', '7870005', '高知県', 'コウチケン', '四万十市', 'シマントシ', '中村', 'ナカムラ', null, null, '桂山団地', 'カツラヤマダンチ');
INSERT INTO `ms_addresses` VALUES ('99621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市麻生', '39', '39210', '7870006', '高知県', 'コウチケン', '四万十市', 'シマントシ', '麻生', 'アソウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市秋田', '39', '39210', '7870007', '高知県', 'コウチケン', '四万十市', 'シマントシ', '秋田', 'アイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市安並', '39', '39210', '7870008', '高知県', 'コウチケン', '四万十市', 'シマントシ', '安並', 'ヤスナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市佐岡', '39', '39210', '7870009', '高知県', 'コウチケン', '四万十市', 'シマントシ', '佐岡', 'サオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市古津賀', '39', '39210', '7870010', '高知県', 'コウチケン', '四万十市', 'シマントシ', '古津賀', 'コツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市右山元町', '39', '39210', '7870011', '高知県', 'コウチケン', '四万十市', 'シマントシ', '右山元町', 'ウヤマモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市右山五月町', '39', '39210', '7870012', '高知県', 'コウチケン', '四万十市', 'シマントシ', '右山五月町', 'ウヤマサツキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市右山天神町', '39', '39210', '7870013', '高知県', 'コウチケン', '四万十市', 'シマントシ', '右山天神町', 'ウヤマテンジンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市駅前町', '39', '39210', '7870014', '高知県', 'コウチケン', '四万十市', 'シマントシ', '駅前町', 'エキマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市右山', '39', '39210', '7870015', '高知県', 'コウチケン', '四万十市', 'シマントシ', '右山', 'ウヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市角崎', '39', '39210', '7870016', '高知県', 'コウチケン', '四万十市', 'シマントシ', '角崎', 'ツノサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市不破', '39', '39210', '7870017', '高知県', 'コウチケン', '四万十市', 'シマントシ', '不破', 'フバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市不破上町', '39', '39210', '7870018', '高知県', 'コウチケン', '四万十市', 'シマントシ', '不破上町', 'フバカミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市具同', '39', '39210', '7870019', '高知県', 'コウチケン', '四万十市', 'シマントシ', '具同', 'グドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市入田', '39', '39210', '7870020', '高知県', 'コウチケン', '四万十市', 'シマントシ', '入田', 'ニュウタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市中村京町', '39', '39210', '7870021', '高知県', 'コウチケン', '四万十市', 'シマントシ', '中村京町', 'ナカムラキョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市中村新町', '39', '39210', '7870022', '高知県', 'コウチケン', '四万十市', 'シマントシ', '中村新町', 'ナカムラシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市中村東町', '39', '39210', '7870023', '高知県', 'コウチケン', '四万十市', 'シマントシ', '中村東町', 'ナカムラヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市中村於東町', '39', '39210', '7870024', '高知県', 'コウチケン', '四万十市', 'シマントシ', '中村於東町', 'ナカムラオヒガシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市中村一条通', '39', '39210', '7870025', '高知県', 'コウチケン', '四万十市', 'シマントシ', '中村一条通', 'ナカムライチジョウドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市中村愛宕町', '39', '39210', '7870026', '高知県', 'コウチケン', '四万十市', 'シマントシ', '中村愛宕町', 'ナカムラアタゴマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市中村天神橋', '39', '39210', '7870027', '高知県', 'コウチケン', '四万十市', 'シマントシ', '中村天神橋', 'ナカムラテンジンバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市中村山手通', '39', '39210', '7870028', '高知県', 'コウチケン', '四万十市', 'シマントシ', '中村山手通', 'ナカムラヤマテドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市中村小姓町', '39', '39210', '7870029', '高知県', 'コウチケン', '四万十市', 'シマントシ', '中村小姓町', 'ナカムラコショウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市中村上小姓町', '39', '39210', '7870030', '高知県', 'コウチケン', '四万十市', 'シマントシ', '中村上小姓町', 'ナカムラカミコショウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市中村東下町', '39', '39210', '7870031', '高知県', 'コウチケン', '四万十市', 'シマントシ', '中村東下町', 'ナカムラヒガシシモマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市中村栄町', '39', '39210', '7870032', '高知県', 'コウチケン', '四万十市', 'シマントシ', '中村栄町', 'ナカムラサカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市中村大橋通', '39', '39210', '7870033', '高知県', 'コウチケン', '四万十市', 'シマントシ', '中村大橋通', 'ナカムラオオハシドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市中村弥生町', '39', '39210', '7870034', '高知県', 'コウチケン', '四万十市', 'シマントシ', '中村弥生町', 'ナカムラヤヨイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市中村羽生小路', '39', '39210', '7870035', '高知県', 'コウチケン', '四万十市', 'シマントシ', '中村羽生小路', 'ナカムラハブショウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市中村岩崎町', '39', '39210', '7870036', '高知県', 'コウチケン', '四万十市', 'シマントシ', '中村岩崎町', 'ナカムライワサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市中村四万十町', '39', '39210', '7870037', '高知県', 'コウチケン', '四万十市', 'シマントシ', '中村四万十町', 'ナカムラシマントチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市中村百笑町', '39', '39210', '7870038', '高知県', 'コウチケン', '四万十市', 'シマントシ', '中村百笑町', 'ナカムラドウメキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市渡川', '39', '39210', '7870050', '高知県', 'コウチケン', '四万十市', 'シマントシ', '渡川', 'ワタリガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市具同田黒', '39', '39210', '7870051', '高知県', 'コウチケン', '四万十市', 'シマントシ', '具同田黒', 'グドウタグロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市赤松町', '39', '39210', '7870052', '高知県', 'コウチケン', '四万十市', 'シマントシ', '赤松町', 'アカマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市井沢', '39', '39210', '7870150', '高知県', 'コウチケン', '四万十市', 'シマントシ', '井沢', 'イサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市竹島', '39', '39210', '7870151', '高知県', 'コウチケン', '四万十市', 'シマントシ', '竹島', 'タケシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市鍋島', '39', '39210', '7870152', '高知県', 'コウチケン', '四万十市', 'シマントシ', '鍋島', 'ナベシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市双海', '39', '39210', '7870153', '高知県', 'コウチケン', '四万十市', 'シマントシ', '双海', 'フタミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市平野', '39', '39210', '7870154', '高知県', 'コウチケン', '四万十市', 'シマントシ', '平野', 'ヒラノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市下田', '39', '39210', '7870155', '高知県', 'コウチケン', '四万十市', 'シマントシ', '下田', 'シモダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市坂本', '39', '39210', '7870156', '高知県', 'コウチケン', '四万十市', 'シマントシ', '坂本', 'サカモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市山路', '39', '39210', '7870157', '高知県', 'コウチケン', '四万十市', 'シマントシ', '山路', 'ヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市実崎', '39', '39210', '7870158', '高知県', 'コウチケン', '四万十市', 'シマントシ', '実崎', 'サンザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市深木', '39', '39210', '7870159', '高知県', 'コウチケン', '四万十市', 'シマントシ', '深木', 'フカキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市間崎', '39', '39210', '7870160', '高知県', 'コウチケン', '四万十市', 'シマントシ', '間崎', 'マサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市津蔵渕', '39', '39210', '7870161', '高知県', 'コウチケン', '四万十市', 'シマントシ', '津蔵渕', 'ツクラブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市初崎', '39', '39210', '7870162', '高知県', 'コウチケン', '四万十市', 'シマントシ', '初崎', 'ハツザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市名鹿', '39', '39210', '7870163', '高知県', 'コウチケン', '四万十市', 'シマントシ', '名鹿', 'ナシシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐清水市立石', '39', '39209', '7870240', '高知県', 'コウチケン', '土佐清水市', 'トサシミズシ', '立石', 'タテイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐清水市布', '39', '39209', '7870241', '高知県', 'コウチケン', '土佐清水市', 'トサシミズシ', '布', 'ヌノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐清水市下ノ加江', '39', '39209', '7870242', '高知県', 'コウチケン', '土佐清水市', 'トサシミズシ', '下ノ加江', 'シモノカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐清水市鍵掛', '39', '39209', '7870243', '高知県', 'コウチケン', '土佐清水市', 'トサシミズシ', '鍵掛', 'カイカケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐清水市久百々', '39', '39209', '7870244', '高知県', 'コウチケン', '土佐清水市', 'トサシミズシ', '久百々', 'クモモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐清水市', '39', '39209', '7870300', '高知県', 'コウチケン', '土佐清水市', 'トサシミズシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('99677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐清水市大岐', '39', '39209', '7870301', '高知県', 'コウチケン', '土佐清水市', 'トサシミズシ', '大岐', 'オオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐清水市以布利', '39', '39209', '7870302', '高知県', 'コウチケン', '土佐清水市', 'トサシミズシ', '以布利', 'イブリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐清水市旭町', '39', '39209', '7870303', '高知県', 'コウチケン', '土佐清水市', 'トサシミズシ', '旭町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐清水市元町', '39', '39209', '7870304', '高知県', 'コウチケン', '土佐清水市', 'トサシミズシ', '元町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐清水市天神町', '39', '39209', '7870305', '高知県', 'コウチケン', '土佐清水市', 'トサシミズシ', '天神町', 'テンジンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐清水市幸町', '39', '39209', '7870306', '高知県', 'コウチケン', '土佐清水市', 'トサシミズシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐清水市緑ケ丘', '39', '39209', '7870307', '高知県', 'コウチケン', '土佐清水市', 'トサシミズシ', '緑ケ丘', 'ミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐清水市厚生町', '39', '39209', '7870308', '高知県', 'コウチケン', '土佐清水市', 'トサシミズシ', '厚生町', 'コウセイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐清水市浦尻', '39', '39209', '7870310', '高知県', 'コウチケン', '土佐清水市', 'トサシミズシ', '浦尻', 'ウラジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐清水市グリーンハイツ', '39', '39209', '7870311', '高知県', 'コウチケン', '土佐清水市', 'トサシミズシ', 'グリーンハイツ', 'グリーンハイツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐清水市窪津', '39', '39209', '7870312', '高知県', 'コウチケン', '土佐清水市', 'トサシミズシ', '窪津', 'クボツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐清水市津呂', '39', '39209', '7870313', '高知県', 'コウチケン', '土佐清水市', 'トサシミズシ', '津呂', 'ツロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐清水市大谷', '39', '39209', '7870314', '高知県', 'コウチケン', '土佐清水市', 'トサシミズシ', '大谷', 'オオタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐清水市足摺岬', '39', '39209', '7870315', '高知県', 'コウチケン', '土佐清水市', 'トサシミズシ', '足摺岬', 'アシズリミサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐清水市松尾', '39', '39209', '7870316', '高知県', 'コウチケン', '土佐清水市', 'トサシミズシ', '松尾', 'マツオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐清水市大浜', '39', '39209', '7870317', '高知県', 'コウチケン', '土佐清水市', 'トサシミズシ', '大浜', 'オオハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐清水市中浜', '39', '39209', '7870318', '高知県', 'コウチケン', '土佐清水市', 'トサシミズシ', '中浜', 'ナカノハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐清水市清水', '39', '39209', '7870320', '高知県', 'コウチケン', '土佐清水市', 'トサシミズシ', '清水', 'シミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐清水市浜町', '39', '39209', '7870321', '高知県', 'コウチケン', '土佐清水市', 'トサシミズシ', '浜町', 'ハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐清水市小江町', '39', '39209', '7870322', '高知県', 'コウチケン', '土佐清水市', 'トサシミズシ', '小江町', 'コエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐清水市寿町', '39', '39209', '7870323', '高知県', 'コウチケン', '土佐清水市', 'トサシミズシ', '寿町', 'コトブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐清水市中央町', '39', '39209', '7870324', '高知県', 'コウチケン', '土佐清水市', 'トサシミズシ', '中央町', 'チュウオウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐清水市栄町', '39', '39209', '7870325', '高知県', 'コウチケン', '土佐清水市', 'トサシミズシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐清水市本町', '39', '39209', '7870326', '高知県', 'コウチケン', '土佐清水市', 'トサシミズシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐清水市市場町', '39', '39209', '7870327', '高知県', 'コウチケン', '土佐清水市', 'トサシミズシ', '市場町', 'イチバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐清水市戎町', '39', '39209', '7870328', '高知県', 'コウチケン', '土佐清水市', 'トサシミズシ', '戎町', 'エビスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐清水市越前町', '39', '39209', '7870331', '高知県', 'コウチケン', '土佐清水市', 'トサシミズシ', '越前町', 'エチゼンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐清水市汐見町', '39', '39209', '7870332', '高知県', 'コウチケン', '土佐清水市', 'トサシミズシ', '汐見町', 'シオミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐清水市西町', '39', '39209', '7870333', '高知県', 'コウチケン', '土佐清水市', 'トサシミズシ', '西町', 'ニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐清水市加久見入沢町', '39', '39209', '7870334', '高知県', 'コウチケン', '土佐清水市', 'トサシミズシ', '加久見入沢町', 'カグミイリサワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐清水市加久見新町', '39', '39209', '7870335', '高知県', 'コウチケン', '土佐清水市', 'トサシミズシ', '加久見新町', 'カグミシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐清水市加久見', '39', '39209', '7870336', '高知県', 'コウチケン', '土佐清水市', 'トサシミズシ', '加久見', 'カグミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐清水市養老', '39', '39209', '7870337', '高知県', 'コウチケン', '土佐清水市', 'トサシミズシ', '養老', 'ヨウロウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐清水市加久見松崎', '39', '39209', '7870338', '高知県', 'コウチケン', '土佐清水市', 'トサシミズシ', '加久見', 'カグミ', null, null, '松崎', 'マツザキ');
INSERT INTO `ms_addresses` VALUES ('99711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐清水市横道', '39', '39209', '7870339', '高知県', 'コウチケン', '土佐清水市', 'トサシミズシ', '横道', 'ヨコミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐清水市下益野', '39', '39209', '7870445', '高知県', 'コウチケン', '土佐清水市', 'トサシミズシ', '下益野', 'シモマシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐清水市斧積', '39', '39209', '7870446', '高知県', 'コウチケン', '土佐清水市', 'トサシミズシ', '斧積', 'オノズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐清水市上野', '39', '39209', '7870447', '高知県', 'コウチケン', '土佐清水市', 'トサシミズシ', '上野', 'ウエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐清水市三崎', '39', '39209', '7870450', '高知県', 'コウチケン', '土佐清水市', 'トサシミズシ', '三崎', 'ミサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐清水市三崎浦', '39', '39209', '7870451', '高知県', 'コウチケン', '土佐清水市', 'トサシミズシ', '三崎浦', 'ミサキウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐清水市竜串', '39', '39209', '7870452', '高知県', 'コウチケン', '土佐清水市', 'トサシミズシ', '竜串', 'タツクシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐清水市爪白', '39', '39209', '7870453', '高知県', 'コウチケン', '土佐清水市', 'トサシミズシ', '爪白', 'ツマジロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐清水市有永', '39', '39209', '7870556', '高知県', 'コウチケン', '土佐清水市', 'トサシミズシ', '有永', 'アリナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐清水市宗呂乙', '39', '39209', '7870557', '高知県', 'コウチケン', '土佐清水市', 'トサシミズシ', '宗呂乙', 'ソウロオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐清水市宗呂丙', '39', '39209', '7870558', '高知県', 'コウチケン', '土佐清水市', 'トサシミズシ', '宗呂丙', 'ソウロヘイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐清水市下川口', '39', '39209', '7870559', '高知県', 'コウチケン', '土佐清水市', 'トサシミズシ', '下川口', 'シモカワグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐清水市片粕', '39', '39209', '7870560', '高知県', 'コウチケン', '土佐清水市', 'トサシミズシ', '片粕', 'カタカス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐清水市貝ノ川', '39', '39209', '7870561', '高知県', 'コウチケン', '土佐清水市', 'トサシミズシ', '貝ノ川', 'カイノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐清水市大津', '39', '39209', '7870562', '高知県', 'コウチケン', '土佐清水市', 'トサシミズシ', '大津', 'オオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県土佐清水市宗呂甲', '39', '39209', '7870563', '高知県', 'コウチケン', '土佐清水市', 'トサシミズシ', '宗呂甲', 'ソウロコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市森沢', '39', '39210', '7870665', '高知県', 'コウチケン', '四万十市', 'シマントシ', '森沢', 'モリサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市楠島', '39', '39210', '7870666', '高知県', 'コウチケン', '四万十市', 'シマントシ', '楠島', 'クスシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市国見', '39', '39210', '7870667', '高知県', 'コウチケン', '四万十市', 'シマントシ', '国見', 'クニミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市荒川', '39', '39210', '7870668', '高知県', 'コウチケン', '四万十市', 'シマントシ', '荒川', 'アラカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市江ノ村', '39', '39210', '7870669', '高知県', 'コウチケン', '四万十市', 'シマントシ', '江ノ村', 'エノムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市有岡', '39', '39210', '7870771', '高知県', 'コウチケン', '四万十市', 'シマントシ', '有岡', 'アリオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市横瀬', '39', '39210', '7870772', '高知県', 'コウチケン', '四万十市', 'シマントシ', '横瀬', 'ヨコゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市磯ノ川', '39', '39210', '7870773', '高知県', 'コウチケン', '四万十市', 'シマントシ', '磯ノ川', 'イソノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市生ノ川', '39', '39210', '7870774', '高知県', 'コウチケン', '四万十市', 'シマントシ', '生ノ川', 'オイノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市九樹', '39', '39210', '7870775', '高知県', 'コウチケン', '四万十市', 'シマントシ', '九樹', 'クジュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市上ノ土居', '39', '39210', '7870776', '高知県', 'コウチケン', '四万十市', 'シマントシ', '上ノ土居', 'カミノドイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県幡多郡三原村', '39', '39427', '7870800', '高知県', 'コウチケン', '幡多郡三原村', 'ハタグンミハラムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('99740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県幡多郡三原村柚ノ木', '39', '39427', '7870801', '高知県', 'コウチケン', '幡多郡三原村', 'ハタグンミハラムラ', '柚ノ木', 'ユノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県幡多郡三原村宮ノ川', '39', '39427', '7870802', '高知県', 'コウチケン', '幡多郡三原村', 'ハタグンミハラムラ', '宮ノ川', 'ミヤノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県幡多郡三原村来栖野', '39', '39427', '7870803', '高知県', 'コウチケン', '幡多郡三原村', 'ハタグンミハラムラ', '来栖野', 'クルスノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県幡多郡三原村上下長谷', '39', '39427', '7870804', '高知県', 'コウチケン', '幡多郡三原村', 'ハタグンミハラムラ', '上下長谷', 'カミシモナガタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県幡多郡三原村上長谷', '39', '39427', '7870805', '高知県', 'コウチケン', '幡多郡三原村', 'ハタグンミハラムラ', '上長谷', 'カミナガタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県幡多郡三原村狼内', '39', '39427', '7870806', '高知県', 'コウチケン', '幡多郡三原村', 'ハタグンミハラムラ', '狼内', 'オオカミウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県幡多郡三原村成山', '39', '39427', '7870807', '高知県', 'コウチケン', '幡多郡三原村', 'ハタグンミハラムラ', '成山', 'ナルヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県幡多郡三原村芳井', '39', '39427', '7870811', '高知県', 'コウチケン', '幡多郡三原村', 'ハタグンミハラムラ', '芳井', 'ヨシイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県幡多郡三原村下長谷', '39', '39427', '7870812', '高知県', 'コウチケン', '幡多郡三原村', 'ハタグンミハラムラ', '下長谷', 'シモナガタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県幡多郡三原村皆尾', '39', '39427', '7870813', '高知県', 'コウチケン', '幡多郡三原村', 'ハタグンミハラムラ', '皆尾', 'ミナオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県幡多郡三原村広野', '39', '39427', '7870814', '高知県', 'コウチケン', '幡多郡三原村', 'ハタグンミハラムラ', '広野', 'ヒロノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県幡多郡三原村亀ノ川', '39', '39427', '7870815', '高知県', 'コウチケン', '幡多郡三原村', 'ハタグンミハラムラ', '亀ノ川', 'カメノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県幡多郡三原村下切', '39', '39427', '7870816', '高知県', 'コウチケン', '幡多郡三原村', 'ハタグンミハラムラ', '下切', 'シタギリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市奥鴨川', '39', '39210', '7871101', '高知県', 'コウチケン', '四万十市', 'シマントシ', '奥鴨川', 'オクカモガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市口鴨川', '39', '39210', '7871102', '高知県', 'コウチケン', '四万十市', 'シマントシ', '口鴨川', 'クチカモガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市板ノ川', '39', '39210', '7871103', '高知県', 'コウチケン', '四万十市', 'シマントシ', '板ノ川', 'イタノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市若藤', '39', '39210', '7871104', '高知県', 'コウチケン', '四万十市', 'シマントシ', '若藤', 'ワカフジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市利岡', '39', '39210', '7871105', '高知県', 'コウチケン', '四万十市', 'シマントシ', '利岡', 'トシオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市佐田', '39', '39210', '7871106', '高知県', 'コウチケン', '四万十市', 'シマントシ', '佐田', 'サダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市岩田', '39', '39210', '7871107', '高知県', 'コウチケン', '四万十市', 'シマントシ', '岩田', 'イワタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市中村大用寺', '39', '39210', '7871107', '高知県', 'コウチケン', '四万十市', 'シマントシ', '中村', 'ナカムラ', null, null, '大用寺', 'ダイヨウジ');
INSERT INTO `ms_addresses` VALUES ('99762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市敷地', '39', '39210', '7871108', '高知県', 'コウチケン', '四万十市', 'シマントシ', '敷地', 'シキジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市田野川', '39', '39210', '7871109', '高知県', 'コウチケン', '四万十市', 'シマントシ', '田野川', 'タノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市川登', '39', '39210', '7871220', '高知県', 'コウチケン', '四万十市', 'シマントシ', '川登', 'カワノボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市三里', '39', '39210', '7871221', '高知県', 'コウチケン', '四万十市', 'シマントシ', '三里', 'ミサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市手洗川', '39', '39210', '7871222', '高知県', 'コウチケン', '四万十市', 'シマントシ', '手洗川', 'タライガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市勝間勝間川', '39', '39210', '7871223', '高知県', 'コウチケン', '四万十市', 'シマントシ', '勝間', 'カツマ', null, null, '勝間川', 'カツマガワ');
INSERT INTO `ms_addresses` VALUES ('99768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市勝間', '39', '39210', '7871224', '高知県', 'コウチケン', '四万十市', 'シマントシ', '勝間', 'カツマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市久保川', '39', '39210', '7871225', '高知県', 'コウチケン', '四万十市', 'シマントシ', '久保川', 'クボカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市鵜ノ江', '39', '39210', '7871226', '高知県', 'コウチケン', '四万十市', 'シマントシ', '鵜ノ江', 'ウノエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市楠', '39', '39210', '7871227', '高知県', 'コウチケン', '四万十市', 'シマントシ', '楠', 'クス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市高瀬', '39', '39210', '7871228', '高知県', 'コウチケン', '四万十市', 'シマントシ', '高瀬', 'タカセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市田出ノ川', '39', '39210', '7871229', '高知県', 'コウチケン', '四万十市', 'シマントシ', '田出ノ川', 'タデノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市西土佐岩間', '39', '39210', '7871321', '高知県', 'コウチケン', '四万十市', 'シマントシ', '西土佐岩間', 'ニシトサイワマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市西土佐茅生', '39', '39210', '7871322', '高知県', 'コウチケン', '四万十市', 'シマントシ', '西土佐茅生', 'ニシトサカヨウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市西土佐中半', '39', '39210', '7871323', '高知県', 'コウチケン', '四万十市', 'シマントシ', '西土佐中半', 'ニシトサナカバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市西土佐口屋内', '39', '39210', '7871324', '高知県', 'コウチケン', '四万十市', 'シマントシ', '西土佐口屋内', 'ニシトサクチヤナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市西土佐玖木', '39', '39210', '7871325', '高知県', 'コウチケン', '四万十市', 'シマントシ', '西土佐玖木', 'ニシトサクキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市西土佐奥屋内', '39', '39210', '7871326', '高知県', 'コウチケン', '四万十市', 'シマントシ', '西土佐奥屋内', 'ニシトサオクヤナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市伊才原', '39', '39210', '7871441', '高知県', 'コウチケン', '四万十市', 'シマントシ', '伊才原', 'イサイバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市蕨岡甲', '39', '39210', '7871442', '高知県', 'コウチケン', '四万十市', 'シマントシ', '蕨岡甲', 'ワラビオカコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市蕨岡乙', '39', '39210', '7871443', '高知県', 'コウチケン', '四万十市', 'シマントシ', '蕨岡乙', 'ワラビオカオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市藤', '39', '39210', '7871444', '高知県', 'コウチケン', '四万十市', 'シマントシ', '藤', 'フジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市大用', '39', '39210', '7871550', '高知県', 'コウチケン', '四万十市', 'シマントシ', '大用', 'オオユウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市住次郎', '39', '39210', '7871551', '高知県', 'コウチケン', '四万十市', 'シマントシ', '住次郎', 'ジュウジロウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市片魚', '39', '39210', '7871552', '高知県', 'コウチケン', '四万十市', 'シマントシ', '片魚', 'カタウオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市大屋敷', '39', '39210', '7871553', '高知県', 'コウチケン', '四万十市', 'シマントシ', '大屋敷', 'オオヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市常六', '39', '39210', '7871554', '高知県', 'コウチケン', '四万十市', 'シマントシ', '常六', 'ジョウロク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市三ツ又', '39', '39210', '7871555', '高知県', 'コウチケン', '四万十市', 'シマントシ', '三ツ又', 'ミツマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市小西ノ川', '39', '39210', '7871556', '高知県', 'コウチケン', '四万十市', 'シマントシ', '小西ノ川', 'コニシノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市大西ノ川', '39', '39210', '7871557', '高知県', 'コウチケン', '四万十市', 'シマントシ', '大西ノ川', 'オオニシノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市古尾', '39', '39210', '7871558', '高知県', 'コウチケン', '四万十市', 'シマントシ', '古尾', 'コビ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市竹屋敷', '39', '39210', '7871559', '高知県', 'コウチケン', '四万十市', 'シマントシ', '竹屋敷', 'タケヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市西土佐江川崎', '39', '39210', '7871601', '高知県', 'コウチケン', '四万十市', 'シマントシ', '西土佐江川崎', 'ニシトサエカワサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市西土佐西ケ方', '39', '39210', '7871602', '高知県', 'コウチケン', '四万十市', 'シマントシ', '西土佐西ケ方', 'ニシトサニシガホウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市西土佐用井', '39', '39210', '7871603', '高知県', 'コウチケン', '四万十市', 'シマントシ', '西土佐用井', 'ニシトサモチイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市西土佐藤ノ川', '39', '39210', '7871604', '高知県', 'コウチケン', '四万十市', 'シマントシ', '西土佐藤ノ川', 'ニシトサフジノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市西土佐長生', '39', '39210', '7871605', '高知県', 'コウチケン', '四万十市', 'シマントシ', '西土佐長生', 'ニシトサナガオイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市西土佐半家', '39', '39210', '7871606', '高知県', 'コウチケン', '四万十市', 'シマントシ', '西土佐半家', 'ニシトサハゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市西土佐江川', '39', '39210', '7871607', '高知県', 'コウチケン', '四万十市', 'シマントシ', '西土佐江川', 'ニシトサエカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市西土佐橘', '39', '39210', '7871611', '高知県', 'コウチケン', '四万十市', 'シマントシ', '西土佐橘', 'ニシトサタチバナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市西土佐津野川', '39', '39210', '7871612', '高知県', 'コウチケン', '四万十市', 'シマントシ', '西土佐津野川', 'ニシトサツノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市西土佐津賀', '39', '39210', '7871613', '高知県', 'コウチケン', '四万十市', 'シマントシ', '西土佐津賀', 'ニシトサツガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市西土佐薮ケ市', '39', '39210', '7871614', '高知県', 'コウチケン', '四万十市', 'シマントシ', '西土佐薮ケ市', 'ニシトサヤブガイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市西土佐大宮', '39', '39210', '7871615', '高知県', 'コウチケン', '四万十市', 'シマントシ', '西土佐大宮', 'ニシトサオオミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市西土佐須崎', '39', '39210', '7871616', '高知県', 'コウチケン', '四万十市', 'シマントシ', '西土佐須崎', 'ニシトサスサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市西土佐下家地', '39', '39210', '7871617', '高知県', 'コウチケン', '四万十市', 'シマントシ', '西土佐下家地', 'ニシトサシモイエジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県四万十市西土佐中家地', '39', '39210', '7871618', '高知県', 'コウチケン', '四万十市', 'シマントシ', '西土佐中家地', 'ニシトサナカイエジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県宿毛市', '39', '39208', '7880000', '高知県', 'コウチケン', '宿毛市', 'スクモシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('99811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県宿毛市中央', '39', '39208', '7880001', '高知県', 'コウチケン', '宿毛市', 'スクモシ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県宿毛市南沖須賀', '39', '39208', '7880002', '高知県', 'コウチケン', '宿毛市', 'スクモシ', '南沖須賀', 'ミナミオキスガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県宿毛市幸町', '39', '39208', '7880003', '高知県', 'コウチケン', '宿毛市', 'スクモシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県宿毛市長田町', '39', '39208', '7880004', '高知県', 'コウチケン', '宿毛市', 'スクモシ', '長田町', 'ナガタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県宿毛市萩原', '39', '39208', '7880005', '高知県', 'コウチケン', '宿毛市', 'スクモシ', '萩原', 'ハギワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県宿毛市桜町', '39', '39208', '7880006', '高知県', 'コウチケン', '宿毛市', 'スクモシ', '桜町', 'サクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県宿毛市松田町', '39', '39208', '7880007', '高知県', 'コウチケン', '宿毛市', 'スクモシ', '松田町', 'マツダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県宿毛市与市明', '39', '39208', '7880008', '高知県', 'コウチケン', '宿毛市', 'スクモシ', '与市明', 'ヨイチミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県宿毛市駅前町', '39', '39208', '7880010', '高知県', 'コウチケン', '宿毛市', 'スクモシ', '駅前町', 'エキマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県宿毛市新田', '39', '39208', '7880011', '高知県', 'コウチケン', '宿毛市', 'スクモシ', '新田', 'シンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県宿毛市高砂', '39', '39208', '7880012', '高知県', 'コウチケン', '宿毛市', 'スクモシ', '高砂', 'タカサゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県宿毛市片島', '39', '39208', '7880013', '高知県', 'コウチケン', '宿毛市', 'スクモシ', '片島', 'カタシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県宿毛市大島', '39', '39208', '7880014', '高知県', 'コウチケン', '宿毛市', 'スクモシ', '大島', 'オオシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県宿毛市西片島', '39', '39208', '7880015', '高知県', 'コウチケン', '宿毛市', 'スクモシ', '西片島', 'ニシカタシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県宿毛市池島', '39', '39208', '7880021', '高知県', 'コウチケン', '宿毛市', 'スクモシ', '池島', 'イケシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県宿毛市藻津', '39', '39208', '7880022', '高知県', 'コウチケン', '宿毛市', 'スクモシ', '藻津', 'ムクヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県宿毛市宇須々木', '39', '39208', '7880023', '高知県', 'コウチケン', '宿毛市', 'スクモシ', '宇須々木', 'ウススキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県宿毛市樺', '39', '39208', '7880024', '高知県', 'コウチケン', '宿毛市', 'スクモシ', '樺', 'カバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県宿毛市西町', '39', '39208', '7880025', '高知県', 'コウチケン', '宿毛市', 'スクモシ', '西町', 'ニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県宿毛市自由ケ丘', '39', '39208', '7880026', '高知県', 'コウチケン', '宿毛市', 'スクモシ', '自由ケ丘', 'ジユウガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県宿毛市港南台', '39', '39208', '7880027', '高知県', 'コウチケン', '宿毛市', 'スクモシ', '港南台', 'コウナンダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県宿毛市新港', '39', '39208', '7880028', '高知県', 'コウチケン', '宿毛市', 'スクモシ', '新港', 'シンコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県宿毛市四季の丘', '39', '39208', '7880030', '高知県', 'コウチケン', '宿毛市', 'スクモシ', '四季の丘', 'シキノオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県宿毛市貝塚', '39', '39208', '7880031', '高知県', 'コウチケン', '宿毛市', 'スクモシ', '貝塚', 'カイヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県宿毛市錦', '39', '39208', '7880032', '高知県', 'コウチケン', '宿毛市', 'スクモシ', '錦', 'ニシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県宿毛市小深浦', '39', '39208', '7880033', '高知県', 'コウチケン', '宿毛市', 'スクモシ', '小深浦', 'コブカウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県宿毛市大深浦', '39', '39208', '7880034', '高知県', 'コウチケン', '宿毛市', 'スクモシ', '大深浦', 'オオブカウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県宿毛市草木薮', '39', '39208', '7880035', '高知県', 'コウチケン', '宿毛市', 'スクモシ', '草木薮', 'クサギヤブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県宿毛市野地', '39', '39208', '7880036', '高知県', 'コウチケン', '宿毛市', 'スクモシ', '野地', 'ノジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県宿毛市山北', '39', '39208', '7880037', '高知県', 'コウチケン', '宿毛市', 'スクモシ', '山北', 'ヤマキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県宿毛市二ノ宮', '39', '39208', '7880038', '高知県', 'コウチケン', '宿毛市', 'スクモシ', '二ノ宮', 'ニノミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県宿毛市中角', '39', '39208', '7880039', '高知県', 'コウチケン', '宿毛市', 'スクモシ', '中角', 'ナカツノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県宿毛市橋上町出井', '39', '39208', '7880041', '高知県', 'コウチケン', '宿毛市', 'スクモシ', '橋上町出井', 'ハシカミチョウイデイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県宿毛市橋上町楠山', '39', '39208', '7880042', '高知県', 'コウチケン', '宿毛市', 'スクモシ', '橋上町楠山', 'ハシカミチョウクスヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県宿毛市橋上町坂本', '39', '39208', '7880043', '高知県', 'コウチケン', '宿毛市', 'スクモシ', '橋上町坂本', 'ハシカミチョウサカモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県宿毛市橋上町神有', '39', '39208', '7880044', '高知県', 'コウチケン', '宿毛市', 'スクモシ', '橋上町神有', 'ハシカミチョウカミアリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県宿毛市橋上町奥奈路', '39', '39208', '7880045', '高知県', 'コウチケン', '宿毛市', 'スクモシ', '橋上町奥奈路', 'ハシカミチョウオクナロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県宿毛市橋上町橋上', '39', '39208', '7880046', '高知県', 'コウチケン', '宿毛市', 'スクモシ', '橋上町橋上', 'ハシカミチョウハシカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県宿毛市橋上町平野', '39', '39208', '7880047', '高知県', 'コウチケン', '宿毛市', 'スクモシ', '橋上町平野', 'ハシカミチョウヒラノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県宿毛市橋上町京法', '39', '39208', '7880048', '高知県', 'コウチケン', '宿毛市', 'スクモシ', '橋上町京法', 'ハシカミチョウキョウホウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県宿毛市橋上町還住薮', '39', '39208', '7880049', '高知県', 'コウチケン', '宿毛市', 'スクモシ', '橋上町還住薮', 'ハシカミチョウゲンジュヤブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県宿毛市押ノ川', '39', '39208', '7880051', '高知県', 'コウチケン', '宿毛市', 'スクモシ', '押ノ川', 'オシノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県宿毛市和田', '39', '39208', '7880052', '高知県', 'コウチケン', '宿毛市', 'スクモシ', '和田', 'ワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県宿毛市坂ノ下', '39', '39208', '7880053', '高知県', 'コウチケン', '宿毛市', 'スクモシ', '坂ノ下', 'サカノシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県宿毛市さくらが丘', '39', '39208', '7880054', '高知県', 'コウチケン', '宿毛市', 'スクモシ', 'さくらが丘', 'サクラガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県宿毛市小筑紫町田ノ浦', '39', '39208', '7880261', '高知県', 'コウチケン', '宿毛市', 'スクモシ', '小筑紫町田ノ浦', 'コヅクシチョウタノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県宿毛市小筑紫町小浦', '39', '39208', '7880262', '高知県', 'コウチケン', '宿毛市', 'スクモシ', '小筑紫町小浦', 'コヅクシチョウコウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県宿毛市小筑紫町内外ノ浦', '39', '39208', '7880263', '高知県', 'コウチケン', '宿毛市', 'スクモシ', '小筑紫町内外ノ浦', 'コヅクシチョウナイガイノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県宿毛市小筑紫町呼崎', '39', '39208', '7880264', '高知県', 'コウチケン', '宿毛市', 'スクモシ', '小筑紫町呼崎', 'コヅクシチョウヨビサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県宿毛市小筑紫町湊', '39', '39208', '7880265', '高知県', 'コウチケン', '宿毛市', 'スクモシ', '小筑紫町湊', 'コヅクシチョウミナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県宿毛市小筑紫町大海', '39', '39208', '7880266', '高知県', 'コウチケン', '宿毛市', 'スクモシ', '小筑紫町大海', 'コヅクシチョウオオミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県宿毛市小筑紫町伊与野', '39', '39208', '7880267', '高知県', 'コウチケン', '宿毛市', 'スクモシ', '小筑紫町伊与野', 'コヅクシチョウイヨノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県宿毛市小筑紫町都賀ノ川', '39', '39208', '7880268', '高知県', 'コウチケン', '宿毛市', 'スクモシ', '小筑紫町都賀ノ川', 'コヅクシチョウツガノガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県宿毛市小筑紫町小筑紫', '39', '39208', '7880271', '高知県', 'コウチケン', '宿毛市', 'スクモシ', '小筑紫町小筑紫', 'コヅクシチョウコヅクシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県宿毛市小筑紫町石原', '39', '39208', '7880272', '高知県', 'コウチケン', '宿毛市', 'スクモシ', '小筑紫町石原', 'コヅクシチョウイシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県宿毛市小筑紫町福良', '39', '39208', '7880273', '高知県', 'コウチケン', '宿毛市', 'スクモシ', '小筑紫町福良', 'コヅクシチョウフクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県宿毛市小筑紫町栄喜', '39', '39208', '7880274', '高知県', 'コウチケン', '宿毛市', 'スクモシ', '小筑紫町栄喜', 'コヅクシチョウサカキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県幡多郡大月町', '39', '39424', '7880300', '高知県', 'コウチケン', '幡多郡大月町', 'ハタグンオオツキチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('99869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県幡多郡大月町弘見', '39', '39424', '7880302', '高知県', 'コウチケン', '幡多郡大月町', 'ハタグンオオツキチョウ', '弘見', 'ヒロミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県幡多郡大月町鉾土', '39', '39424', '7880311', '高知県', 'コウチケン', '幡多郡大月町', 'ハタグンオオツキチョウ', '鉾土', 'ホコツチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県幡多郡大月町清王', '39', '39424', '7880312', '高知県', 'コウチケン', '幡多郡大月町', 'ハタグンオオツキチョウ', '清王', 'セイオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県幡多郡大月町周防形', '39', '39424', '7880313', '高知県', 'コウチケン', '幡多郡大月町', 'ハタグンオオツキチョウ', '周防形', 'スボウガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県幡多郡大月町頭集', '39', '39424', '7880314', '高知県', 'コウチケン', '幡多郡大月町', 'ハタグンオオツキチョウ', '頭集', 'カシラツドイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県幡多郡大月町古満目', '39', '39424', '7880315', '高知県', 'コウチケン', '幡多郡大月町', 'ハタグンオオツキチョウ', '古満目', 'コマメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県幡多郡大月町春遠', '39', '39424', '7880321', '高知県', 'コウチケン', '幡多郡大月町', 'ハタグンオオツキチョウ', '春遠', 'ハルドオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県幡多郡大月町小才角', '39', '39424', '7880322', '高知県', 'コウチケン', '幡多郡大月町', 'ハタグンオオツキチョウ', '小才角', 'コサイツノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県幡多郡大月町才角', '39', '39424', '7880323', '高知県', 'コウチケン', '幡多郡大月町', 'ハタグンオオツキチョウ', '才角', 'サイツノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県幡多郡大月町大浦', '39', '39424', '7880324', '高知県', 'コウチケン', '幡多郡大月町', 'ハタグンオオツキチョウ', '大浦', 'オオウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県幡多郡大月町月ケ丘', '39', '39424', '7880325', '高知県', 'コウチケン', '幡多郡大月町', 'ハタグンオオツキチョウ', '月ケ丘', 'ツキガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県幡多郡大月町口目塚', '39', '39424', '7880331', '高知県', 'コウチケン', '幡多郡大月町', 'ハタグンオオツキチョウ', '口目塚', 'クチメヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県幡多郡大月町姫ノ井', '39', '39424', '7880331', '高知県', 'コウチケン', '幡多郡大月町', 'ハタグンオオツキチョウ', '姫ノ井', 'ヒメノイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県幡多郡大月町赤泊', '39', '39424', '7880332', '高知県', 'コウチケン', '幡多郡大月町', 'ハタグンオオツキチョウ', '赤泊', 'アカドマリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県幡多郡大月町西泊', '39', '39424', '7880333', '高知県', 'コウチケン', '幡多郡大月町', 'ハタグンオオツキチョウ', '西泊', 'ニシドマリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県幡多郡大月町樫ノ浦', '39', '39424', '7880334', '高知県', 'コウチケン', '幡多郡大月町', 'ハタグンオオツキチョウ', '樫ノ浦', 'カシノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県幡多郡大月町唐岩', '39', '39424', '7880335', '高知県', 'コウチケン', '幡多郡大月町', 'ハタグンオオツキチョウ', '唐岩', 'カライワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県幡多郡大月町平山', '39', '39424', '7880341', '高知県', 'コウチケン', '幡多郡大月町', 'ハタグンオオツキチョウ', '平山', 'ヒラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県幡多郡大月町一切', '39', '39424', '7880342', '高知県', 'コウチケン', '幡多郡大月町', 'ハタグンオオツキチョウ', '一切', 'イッサイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県幡多郡大月町柏島', '39', '39424', '7880343', '高知県', 'コウチケン', '幡多郡大月町', 'ハタグンオオツキチョウ', '柏島', 'カシワジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県幡多郡大月町安満地', '39', '39424', '7880351', '高知県', 'コウチケン', '幡多郡大月町', 'ハタグンオオツキチョウ', '安満地', 'アマジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県幡多郡大月町橘浦', '39', '39424', '7880352', '高知県', 'コウチケン', '幡多郡大月町', 'ハタグンオオツキチョウ', '橘浦', 'タチバナウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県幡多郡大月町泊浦', '39', '39424', '7880353', '高知県', 'コウチケン', '幡多郡大月町', 'ハタグンオオツキチョウ', '泊浦', 'トマリウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県幡多郡大月町龍ケ迫', '39', '39424', '7880361', '高知県', 'コウチケン', '幡多郡大月町', 'ハタグンオオツキチョウ', '龍ケ迫', 'タツガサコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県幡多郡大月町芳ノ沢', '39', '39424', '7880362', '高知県', 'コウチケン', '幡多郡大月町', 'ハタグンオオツキチョウ', '芳ノ沢', 'ヨシノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県幡多郡大月町添ノ川', '39', '39424', '7880363', '高知県', 'コウチケン', '幡多郡大月町', 'ハタグンオオツキチョウ', '添ノ川', 'ソイノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県宿毛市沖の島町母島', '39', '39208', '7880677', '高知県', 'コウチケン', '宿毛市', 'スクモシ', '沖の島町母島', 'オキノシマチョウモシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県宿毛市沖の島町弘瀬', '39', '39208', '7880678', '高知県', 'コウチケン', '宿毛市', 'スクモシ', '沖の島町弘瀬', 'オキノシマチョウヒロセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県宿毛市沖の島町鵜来島', '39', '39208', '7880679', '高知県', 'コウチケン', '宿毛市', 'スクモシ', '沖の島町鵜来島', 'オキノシマチョウウグルシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県宿毛市平田町黒川', '39', '39208', '7880781', '高知県', 'コウチケン', '宿毛市', 'スクモシ', '平田町黒川', 'ヒラタチョウクロカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県宿毛市平田町中山', '39', '39208', '7880782', '高知県', 'コウチケン', '宿毛市', 'スクモシ', '平田町中山', 'ヒラタチョウナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県宿毛市平田町戸内', '39', '39208', '7880783', '高知県', 'コウチケン', '宿毛市', 'スクモシ', '平田町戸内', 'ヒラタチョウヘナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県宿毛市山奈町山田', '39', '39208', '7880784', '高知県', 'コウチケン', '宿毛市', 'スクモシ', '山奈町山田', 'ヤマナチョウヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県宿毛市山奈町芳奈', '39', '39208', '7880785', '高知県', 'コウチケン', '宿毛市', 'スクモシ', '山奈町芳奈', 'ヤマナチョウヨシナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県宿毛市平田町東平', '39', '39208', '7880786', '高知県', 'コウチケン', '宿毛市', 'スクモシ', '平田町東平', 'ヒラタチョウヒガシダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市東旭川町東桜岡', '01', '01204', '0788201', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '東旭川町東桜岡', 'ヒガシアサヒカワチョウヒガシサクラオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市東旭川町豊田', '01', '01204', '0788202', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '東旭川町豊田', 'ヒガシアサヒカワチョウトヨタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市東旭川町日ノ出', '01', '01204', '0788203', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '東旭川町日ノ出', 'ヒガシアサヒカワチョウヒノデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市東旭川町桜岡', '01', '01204', '0788204', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '東旭川町桜岡', 'ヒガシアサヒカワチョウサクラオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市東旭川町倉沼', '01', '01204', '0788205', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '東旭川町倉沼', 'ヒガシアサヒカワチョウクラヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市東旭川町忠別', '01', '01204', '0788206', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '東旭川町忠別', 'ヒガシアサヒカワチョウチュウベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市東旭川町上兵村', '01', '01204', '0788207', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '東旭川町上兵村', 'ヒガシアサヒカワチョウカミヘイソン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市東旭川町下兵村', '01', '01204', '0788208', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '東旭川町下兵村', 'ヒガシアサヒカワチョウシモヘイソン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市1条通18丁目', '01', '01204', '0788211', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '1条通', '01ジョウドオリ', null, null, '18丁目', '18チョウメ');
INSERT INTO `ms_addresses` VALUES ('99913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市1条通19丁目', '01', '01204', '0788211', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '1条通', '01ジョウドオリ', null, null, '19丁目', '19チョウメ');
INSERT INTO `ms_addresses` VALUES ('99914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市1条通20丁目', '01', '01204', '0788211', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '1条通', '01ジョウドオリ', null, null, '20丁目', '20チョウメ');
INSERT INTO `ms_addresses` VALUES ('99915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市1条通21丁目', '01', '01204', '0788211', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '1条通', '01ジョウドオリ', null, null, '21丁目', '21チョウメ');
INSERT INTO `ms_addresses` VALUES ('99916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市1条通22丁目', '01', '01204', '0788211', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '1条通', '01ジョウドオリ', null, null, '22丁目', '22チョウメ');
INSERT INTO `ms_addresses` VALUES ('99917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市1条通23丁目', '01', '01204', '0788211', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '1条通', '01ジョウドオリ', null, null, '23丁目', '23チョウメ');
INSERT INTO `ms_addresses` VALUES ('99918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市1条通24丁目', '01', '01204', '0788211', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '1条通', '01ジョウドオリ', null, null, '24丁目', '24チョウメ');
INSERT INTO `ms_addresses` VALUES ('99919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市1条通25丁目', '01', '01204', '0788211', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '1条通', '01ジョウドオリ', null, null, '25丁目', '25チョウメ');
INSERT INTO `ms_addresses` VALUES ('99920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市2条通18丁目', '01', '01204', '0788212', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '2条通', '02ジョウドオリ', null, null, '18丁目', '18チョウメ');
INSERT INTO `ms_addresses` VALUES ('99921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市2条通19丁目', '01', '01204', '0788212', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '2条通', '02ジョウドオリ', null, null, '19丁目', '19チョウメ');
INSERT INTO `ms_addresses` VALUES ('99922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市2条通20丁目', '01', '01204', '0788212', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '2条通', '02ジョウドオリ', null, null, '20丁目', '20チョウメ');
INSERT INTO `ms_addresses` VALUES ('99923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市2条通21丁目', '01', '01204', '0788212', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '2条通', '02ジョウドオリ', null, null, '21丁目', '21チョウメ');
INSERT INTO `ms_addresses` VALUES ('99924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市2条通22丁目', '01', '01204', '0788212', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '2条通', '02ジョウドオリ', null, null, '22丁目', '22チョウメ');
INSERT INTO `ms_addresses` VALUES ('99925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市2条通23丁目', '01', '01204', '0788212', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '2条通', '02ジョウドオリ', null, null, '23丁目', '23チョウメ');
INSERT INTO `ms_addresses` VALUES ('99926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市2条通24丁目', '01', '01204', '0788212', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '2条通', '02ジョウドオリ', null, null, '24丁目', '24チョウメ');
INSERT INTO `ms_addresses` VALUES ('99927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市2条通25丁目', '01', '01204', '0788212', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '2条通', '02ジョウドオリ', null, null, '25丁目', '25チョウメ');
INSERT INTO `ms_addresses` VALUES ('99928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市3条通18丁目', '01', '01204', '0788213', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '3条通', '03ジョウドオリ', null, null, '18丁目', '18チョウメ');
INSERT INTO `ms_addresses` VALUES ('99929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市3条通19丁目', '01', '01204', '0788213', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '3条通', '03ジョウドオリ', null, null, '19丁目', '19チョウメ');
INSERT INTO `ms_addresses` VALUES ('99930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市3条通20丁目', '01', '01204', '0788213', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '3条通', '03ジョウドオリ', null, null, '20丁目', '20チョウメ');
INSERT INTO `ms_addresses` VALUES ('99931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市3条通21丁目', '01', '01204', '0788213', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '3条通', '03ジョウドオリ', null, null, '21丁目', '21チョウメ');
INSERT INTO `ms_addresses` VALUES ('99932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市3条通22丁目', '01', '01204', '0788213', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '3条通', '03ジョウドオリ', null, null, '22丁目', '22チョウメ');
INSERT INTO `ms_addresses` VALUES ('99933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市3条通23丁目', '01', '01204', '0788213', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '3条通', '03ジョウドオリ', null, null, '23丁目', '23チョウメ');
INSERT INTO `ms_addresses` VALUES ('99934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市3条通24丁目', '01', '01204', '0788213', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '3条通', '03ジョウドオリ', null, null, '24丁目', '24チョウメ');
INSERT INTO `ms_addresses` VALUES ('99935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市3条通25丁目', '01', '01204', '0788213', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '3条通', '03ジョウドオリ', null, null, '25丁目', '25チョウメ');
INSERT INTO `ms_addresses` VALUES ('99936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市4条通18丁目', '01', '01204', '0788214', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '4条通', '04ジョウドオリ', null, null, '18丁目', '18チョウメ');
INSERT INTO `ms_addresses` VALUES ('99937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市4条通19丁目', '01', '01204', '0788214', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '4条通', '04ジョウドオリ', null, null, '19丁目', '19チョウメ');
INSERT INTO `ms_addresses` VALUES ('99938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市4条通20丁目', '01', '01204', '0788214', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '4条通', '04ジョウドオリ', null, null, '20丁目', '20チョウメ');
INSERT INTO `ms_addresses` VALUES ('99939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市4条通21丁目', '01', '01204', '0788214', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '4条通', '04ジョウドオリ', null, null, '21丁目', '21チョウメ');
INSERT INTO `ms_addresses` VALUES ('99940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市4条通22丁目', '01', '01204', '0788214', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '4条通', '04ジョウドオリ', null, null, '22丁目', '22チョウメ');
INSERT INTO `ms_addresses` VALUES ('99941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市4条通23丁目', '01', '01204', '0788214', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '4条通', '04ジョウドオリ', null, null, '23丁目', '23チョウメ');
INSERT INTO `ms_addresses` VALUES ('99942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市4条通24丁目', '01', '01204', '0788214', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '4条通', '04ジョウドオリ', null, null, '24丁目', '24チョウメ');
INSERT INTO `ms_addresses` VALUES ('99943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市4条通25丁目', '01', '01204', '0788214', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '4条通', '04ジョウドオリ', null, null, '25丁目', '25チョウメ');
INSERT INTO `ms_addresses` VALUES ('99944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市5条通18丁目', '01', '01204', '0788215', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '5条通', '05ジョウドオリ', null, null, '18丁目', '18チョウメ');
INSERT INTO `ms_addresses` VALUES ('99945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市5条通19丁目', '01', '01204', '0788215', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '5条通', '05ジョウドオリ', null, null, '19丁目', '19チョウメ');
INSERT INTO `ms_addresses` VALUES ('99946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市5条通20丁目', '01', '01204', '0788215', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '5条通', '05ジョウドオリ', null, null, '20丁目', '20チョウメ');
INSERT INTO `ms_addresses` VALUES ('99947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市5条通21丁目', '01', '01204', '0788215', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '5条通', '05ジョウドオリ', null, null, '21丁目', '21チョウメ');
INSERT INTO `ms_addresses` VALUES ('99948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市5条通22丁目', '01', '01204', '0788215', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '5条通', '05ジョウドオリ', null, null, '22丁目', '22チョウメ');
INSERT INTO `ms_addresses` VALUES ('99949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市5条通23丁目', '01', '01204', '0788215', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '5条通', '05ジョウドオリ', null, null, '23丁目', '23チョウメ');
INSERT INTO `ms_addresses` VALUES ('99950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市5条通24丁目', '01', '01204', '0788215', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '5条通', '05ジョウドオリ', null, null, '24丁目', '24チョウメ');
INSERT INTO `ms_addresses` VALUES ('99951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市5条通25丁目', '01', '01204', '0788215', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '5条通', '05ジョウドオリ', null, null, '25丁目', '25チョウメ');
INSERT INTO `ms_addresses` VALUES ('99952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市6条通18丁目', '01', '01204', '0788216', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '6条通', '06ジョウドオリ', null, null, '18丁目', '18チョウメ');
INSERT INTO `ms_addresses` VALUES ('99953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市6条通19丁目', '01', '01204', '0788216', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '6条通', '06ジョウドオリ', null, null, '19丁目', '19チョウメ');
INSERT INTO `ms_addresses` VALUES ('99954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市6条通20丁目', '01', '01204', '0788216', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '6条通', '06ジョウドオリ', null, null, '20丁目', '20チョウメ');
INSERT INTO `ms_addresses` VALUES ('99955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市6条通21丁目', '01', '01204', '0788216', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '6条通', '06ジョウドオリ', null, null, '21丁目', '21チョウメ');
INSERT INTO `ms_addresses` VALUES ('99956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市6条通22丁目', '01', '01204', '0788216', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '6条通', '06ジョウドオリ', null, null, '22丁目', '22チョウメ');
INSERT INTO `ms_addresses` VALUES ('99957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市6条通23丁目', '01', '01204', '0788216', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '6条通', '06ジョウドオリ', null, null, '23丁目', '23チョウメ');
INSERT INTO `ms_addresses` VALUES ('99958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市6条通24丁目', '01', '01204', '0788216', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '6条通', '06ジョウドオリ', null, null, '24丁目', '24チョウメ');
INSERT INTO `ms_addresses` VALUES ('99959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市6条通25丁目', '01', '01204', '0788216', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '6条通', '06ジョウドオリ', null, null, '25丁目', '25チョウメ');
INSERT INTO `ms_addresses` VALUES ('99960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市7条通18丁目', '01', '01204', '0788217', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '7条通', '07ジョウドオリ', null, null, '18丁目', '18チョウメ');
INSERT INTO `ms_addresses` VALUES ('99961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市7条通19丁目', '01', '01204', '0788217', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '7条通', '07ジョウドオリ', null, null, '19丁目', '19チョウメ');
INSERT INTO `ms_addresses` VALUES ('99962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市7条通20丁目', '01', '01204', '0788217', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '7条通', '07ジョウドオリ', null, null, '20丁目', '20チョウメ');
INSERT INTO `ms_addresses` VALUES ('99963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市7条通21丁目', '01', '01204', '0788217', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '7条通', '07ジョウドオリ', null, null, '21丁目', '21チョウメ');
INSERT INTO `ms_addresses` VALUES ('99964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市7条通22丁目', '01', '01204', '0788217', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '7条通', '07ジョウドオリ', null, null, '22丁目', '22チョウメ');
INSERT INTO `ms_addresses` VALUES ('99965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市7条通23丁目', '01', '01204', '0788217', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '7条通', '07ジョウドオリ', null, null, '23丁目', '23チョウメ');
INSERT INTO `ms_addresses` VALUES ('99966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市7条通24丁目', '01', '01204', '0788217', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '7条通', '07ジョウドオリ', null, null, '24丁目', '24チョウメ');
INSERT INTO `ms_addresses` VALUES ('99967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市7条通25丁目', '01', '01204', '0788217', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '7条通', '07ジョウドオリ', null, null, '25丁目', '25チョウメ');
INSERT INTO `ms_addresses` VALUES ('99968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市8条通18丁目', '01', '01204', '0788218', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '8条通', '08ジョウドオリ', null, null, '18丁目', '18チョウメ');
INSERT INTO `ms_addresses` VALUES ('99969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市8条通19丁目', '01', '01204', '0788218', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '8条通', '08ジョウドオリ', null, null, '19丁目', '19チョウメ');
INSERT INTO `ms_addresses` VALUES ('99970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市8条通20丁目', '01', '01204', '0788218', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '8条通', '08ジョウドオリ', null, null, '20丁目', '20チョウメ');
INSERT INTO `ms_addresses` VALUES ('99971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市8条通21丁目', '01', '01204', '0788218', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '8条通', '08ジョウドオリ', null, null, '21丁目', '21チョウメ');
INSERT INTO `ms_addresses` VALUES ('99972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市8条通22丁目', '01', '01204', '0788218', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '8条通', '08ジョウドオリ', null, null, '22丁目', '22チョウメ');
INSERT INTO `ms_addresses` VALUES ('99973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市8条通23丁目', '01', '01204', '0788218', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '8条通', '08ジョウドオリ', null, null, '23丁目', '23チョウメ');
INSERT INTO `ms_addresses` VALUES ('99974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市8条通24丁目', '01', '01204', '0788218', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '8条通', '08ジョウドオリ', null, null, '24丁目', '24チョウメ');
INSERT INTO `ms_addresses` VALUES ('99975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市8条通25丁目', '01', '01204', '0788218', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '8条通', '08ジョウドオリ', null, null, '25丁目', '25チョウメ');
INSERT INTO `ms_addresses` VALUES ('99976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市9条通18丁目', '01', '01204', '0788219', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '9条通', '09ジョウドオリ', null, null, '18丁目', '18チョウメ');
INSERT INTO `ms_addresses` VALUES ('99977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市9条通19丁目', '01', '01204', '0788219', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '9条通', '09ジョウドオリ', null, null, '19丁目', '19チョウメ');
INSERT INTO `ms_addresses` VALUES ('99978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市9条通20丁目', '01', '01204', '0788219', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '9条通', '09ジョウドオリ', null, null, '20丁目', '20チョウメ');
INSERT INTO `ms_addresses` VALUES ('99979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市9条通21丁目', '01', '01204', '0788219', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '9条通', '09ジョウドオリ', null, null, '21丁目', '21チョウメ');
INSERT INTO `ms_addresses` VALUES ('99980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市9条通22丁目', '01', '01204', '0788219', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '9条通', '09ジョウドオリ', null, null, '22丁目', '22チョウメ');
INSERT INTO `ms_addresses` VALUES ('99981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市9条通23丁目', '01', '01204', '0788219', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '9条通', '09ジョウドオリ', null, null, '23丁目', '23チョウメ');
INSERT INTO `ms_addresses` VALUES ('99982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市9条通24丁目', '01', '01204', '0788219', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '9条通', '09ジョウドオリ', null, null, '24丁目', '24チョウメ');
INSERT INTO `ms_addresses` VALUES ('99983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市9条通25丁目', '01', '01204', '0788219', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '9条通', '09ジョウドオリ', null, null, '25丁目', '25チョウメ');
INSERT INTO `ms_addresses` VALUES ('99984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市10条通18丁目', '01', '01204', '0788220', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '10条通', '10ジョウドオリ', null, null, '18丁目', '18チョウメ');
INSERT INTO `ms_addresses` VALUES ('99985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市10条通19丁目', '01', '01204', '0788220', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '10条通', '10ジョウドオリ', null, null, '19丁目', '19チョウメ');
INSERT INTO `ms_addresses` VALUES ('99986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市10条通20丁目', '01', '01204', '0788220', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '10条通', '10ジョウドオリ', null, null, '20丁目', '20チョウメ');
INSERT INTO `ms_addresses` VALUES ('99987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市10条通21丁目', '01', '01204', '0788220', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '10条通', '10ジョウドオリ', null, null, '21丁目', '21チョウメ');
INSERT INTO `ms_addresses` VALUES ('99988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市10条通22丁目', '01', '01204', '0788220', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '10条通', '10ジョウドオリ', null, null, '22丁目', '22チョウメ');
INSERT INTO `ms_addresses` VALUES ('99989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市10条通23丁目', '01', '01204', '0788220', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '10条通', '10ジョウドオリ', null, null, '23丁目', '23チョウメ');
INSERT INTO `ms_addresses` VALUES ('99990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市10条通24丁目', '01', '01204', '0788220', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '10条通', '10ジョウドオリ', null, null, '24丁目', '24チョウメ');
INSERT INTO `ms_addresses` VALUES ('99991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市10条通25丁目', '01', '01204', '0788220', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '10条通', '10ジョウドオリ', null, null, '25丁目', '25チョウメ');
INSERT INTO `ms_addresses` VALUES ('99992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市11条通', '01', '01204', '0788221', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '11条通', '11ジョウドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市豊岡1条', '01', '01204', '0788231', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '豊岡1条', 'トヨオカ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市豊岡2条', '01', '01204', '0788232', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '豊岡2条', 'トヨオカ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市豊岡3条', '01', '01204', '0788233', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '豊岡3条', 'トヨオカ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市豊岡4条', '01', '01204', '0788234', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '豊岡4条', 'トヨオカ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市豊岡5条', '01', '01204', '0788235', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '豊岡5条', 'トヨオカ05ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市豊岡6条', '01', '01204', '0788236', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '豊岡6条', 'トヨオカ06ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('99999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市豊岡7条', '01', '01204', '0788237', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '豊岡7条', 'トヨオカ07ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市豊岡8条', '01', '01204', '0788238', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '豊岡8条', 'トヨオカ08ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市豊岡9条', '01', '01204', '0788239', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '豊岡9条', 'トヨオカ09ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市豊岡10条', '01', '01204', '0788240', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '豊岡10条', 'トヨオカ10ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市豊岡11条', '01', '01204', '0788241', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '豊岡11条', 'トヨオカ11ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市豊岡12条', '01', '01204', '0788242', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '豊岡12条', 'トヨオカ12ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市豊岡13条', '01', '01204', '0788243', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '豊岡13条', 'トヨオカ13ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市豊岡14条', '01', '01204', '0788244', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '豊岡14条', 'トヨオカ14ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市豊岡15条', '01', '01204', '0788245', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '豊岡15条', 'トヨオカ15ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市豊岡16条', '01', '01204', '0788246', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '豊岡16条', 'トヨオカ16ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市東旭川北1条', '01', '01204', '0788251', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '東旭川北1条', 'ヒガシアサヒカワキタ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市東旭川北2条', '01', '01204', '0788252', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '東旭川北2条', 'ヒガシアサヒカワキタ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市東旭川北3条', '01', '01204', '0788253', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '東旭川北3条', 'ヒガシアサヒカワキタ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市東旭川南1条', '01', '01204', '0788261', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '東旭川南1条', 'ヒガシアサヒカワミナミ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市東旭川南2条', '01', '01204', '0788262', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '東旭川南2条', 'ヒガシアサヒカワミナミ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市工業団地1条', '01', '01204', '0788271', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '工業団地1条', 'コウギョウダンチ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市工業団地2条', '01', '01204', '0788272', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '工業団地2条', 'コウギョウダンチ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市工業団地3条', '01', '01204', '0788273', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '工業団地3条', 'コウギョウダンチ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市工業団地4条', '01', '01204', '0788274', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '工業団地4条', 'コウギョウダンチ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市工業団地5条', '01', '01204', '0788275', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '工業団地5条', 'コウギョウダンチ05ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市緑が丘1条', '01', '01204', '0788301', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '緑が丘1条', 'ミドリガオカ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市緑が丘2条', '01', '01204', '0788302', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '緑が丘2条', 'ミドリガオカ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市緑が丘3条', '01', '01204', '0788303', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '緑が丘3条', 'ミドリガオカ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市緑が丘4条', '01', '01204', '0788304', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '緑が丘4条', 'ミドリガオカ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市緑が丘5条', '01', '01204', '0788305', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '緑が丘5条', 'ミドリガオカ05ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市旭神町', '01', '01204', '0788308', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '旭神町', 'キョクシンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市神楽岡1条', '01', '01204', '0788311', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '神楽岡1条', 'カグラオカ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市神楽岡2条', '01', '01204', '0788312', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '神楽岡2条', 'カグラオカ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市神楽岡3条', '01', '01204', '0788313', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '神楽岡3条', 'カグラオカ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市神楽岡4条', '01', '01204', '0788314', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '神楽岡4条', 'カグラオカ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市神楽岡5条', '01', '01204', '0788315', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '神楽岡5条', 'カグラオカ05ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市神楽岡6条', '01', '01204', '0788316', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '神楽岡6条', 'カグラオカ06ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市神楽岡7条', '01', '01204', '0788317', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '神楽岡7条', 'カグラオカ07ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市神楽岡8条', '01', '01204', '0788318', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '神楽岡8条', 'カグラオカ08ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市神楽岡9条', '01', '01204', '0788319', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '神楽岡9条', 'カグラオカ09ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市神楽岡10条', '01', '01204', '0788320', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '神楽岡10条', 'カグラオカ10ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市神楽岡11条', '01', '01204', '0788321', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '神楽岡11条', 'カグラオカ11ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市神楽岡12条', '01', '01204', '0788322', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '神楽岡12条', 'カグラオカ12ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市神楽岡13条', '01', '01204', '0788323', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '神楽岡13条', 'カグラオカ13ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市神楽岡14条', '01', '01204', '0788324', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '神楽岡14条', 'カグラオカ14ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市神楽岡15条', '01', '01204', '0788325', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '神楽岡15条', 'カグラオカ15ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市神楽岡16条', '01', '01204', '0788326', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '神楽岡16条', 'カグラオカ16ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市神楽岡公園', '01', '01204', '0788327', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '神楽岡公園', 'カグラオカコウエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市宮前通西', '01', '01204', '0788328', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '宮前通西', 'ミヤマエドオリニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市宮前通東', '01', '01204', '0788329', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '宮前通東', 'ミヤマエドオリヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市宮下通18丁目', '01', '01204', '0788330', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '宮下通', 'ミヤシタドオリ', null, null, '18丁目', '18チョウメ');
INSERT INTO `ms_addresses` VALUES ('100045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市宮下通19丁目', '01', '01204', '0788330', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '宮下通', 'ミヤシタドオリ', null, null, '19丁目', '19チョウメ');
INSERT INTO `ms_addresses` VALUES ('100046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市宮下通20丁目', '01', '01204', '0788330', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '宮下通', 'ミヤシタドオリ', null, null, '20丁目', '20チョウメ');
INSERT INTO `ms_addresses` VALUES ('100047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市宮下通21丁目', '01', '01204', '0788330', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '宮下通', 'ミヤシタドオリ', null, null, '21丁目', '21チョウメ');
INSERT INTO `ms_addresses` VALUES ('100048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市宮下通22丁目', '01', '01204', '0788330', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '宮下通', 'ミヤシタドオリ', null, null, '22丁目', '22チョウメ');
INSERT INTO `ms_addresses` VALUES ('100049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市宮下通23丁目', '01', '01204', '0788330', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '宮下通', 'ミヤシタドオリ', null, null, '23丁目', '23チョウメ');
INSERT INTO `ms_addresses` VALUES ('100050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市宮下通24丁目', '01', '01204', '0788330', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '宮下通', 'ミヤシタドオリ', null, null, '24丁目', '24チョウメ');
INSERT INTO `ms_addresses` VALUES ('100051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市宮下通25丁目', '01', '01204', '0788330', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '宮下通', 'ミヤシタドオリ', null, null, '25丁目', '25チョウメ');
INSERT INTO `ms_addresses` VALUES ('100052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市宮下通26丁目', '01', '01204', '0788330', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '宮下通', 'ミヤシタドオリ', null, null, '26丁目', '26チョウメ');
INSERT INTO `ms_addresses` VALUES ('100053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市南1条通', '01', '01204', '0788331', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '南1条通', 'ミナミ01ジョウドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市南2条通', '01', '01204', '0788332', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '南2条通', 'ミナミ02ジョウドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市南3条通', '01', '01204', '0788333', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '南3条通', 'ミナミ03ジョウドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市南4条通', '01', '01204', '0788334', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '南4条通', 'ミナミ04ジョウドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市南5条通', '01', '01204', '0788335', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '南5条通', 'ミナミ05ジョウドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市南6条通', '01', '01204', '0788336', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '南6条通', 'ミナミ06ジョウドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市南7条通', '01', '01204', '0788337', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '南7条通', 'ミナミ07ジョウドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市南8条通', '01', '01204', '0788338', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '南8条通', 'ミナミ08ジョウドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市南9条通', '01', '01204', '0788339', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '南9条通', 'ミナミ09ジョウドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市東旭川町共栄', '01', '01204', '0788340', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '東旭川町共栄', 'ヒガシアサヒカワチョウキョウエイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市東光1条', '01', '01204', '0788341', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '東光1条', 'トウコウ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市東光2条', '01', '01204', '0788342', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '東光2条', 'トウコウ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市東光3条', '01', '01204', '0788343', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '東光3条', 'トウコウ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市東光4条', '01', '01204', '0788344', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '東光4条', 'トウコウ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市東光5条', '01', '01204', '0788345', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '東光5条', 'トウコウ05ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市東光6条', '01', '01204', '0788346', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '東光6条', 'トウコウ06ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市東光7条', '01', '01204', '0788347', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '東光7条', 'トウコウ07ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市東光8条', '01', '01204', '0788348', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '東光8条', 'トウコウ08ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市東光9条', '01', '01204', '0788349', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '東光9条', 'トウコウ09ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市東光10条', '01', '01204', '0788350', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '東光10条', 'トウコウ10ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市東光11条', '01', '01204', '0788351', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '東光11条', 'トウコウ11ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市東光12条', '01', '01204', '0788352', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '東光12条', 'トウコウ12ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市東光13条', '01', '01204', '0788353', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '東光13条', 'トウコウ13ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市東光14条', '01', '01204', '0788354', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '東光14条', 'トウコウ14ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市東光15条', '01', '01204', '0788355', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '東光15条', 'トウコウ15ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市東光16条', '01', '01204', '0788356', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '東光16条', 'トウコウ16ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市東光17条', '01', '01204', '0788357', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '東光17条', 'トウコウ17ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市東光18条', '01', '01204', '0788358', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '東光18条', 'トウコウ18ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市東光19条', '01', '01204', '0788359', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '東光19条', 'トウコウ19ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市東光20条', '01', '01204', '0788360', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '東光20条', 'トウコウ20ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市東光21条', '01', '01204', '0788361', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '東光21条', 'トウコウ21ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市東光22条', '01', '01204', '0788362', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '東光22条', 'トウコウ22ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市東光23条', '01', '01204', '0788363', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '東光23条', 'トウコウ23ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市東光24条', '01', '01204', '0788364', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '東光24条', 'トウコウ24ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市東光25条', '01', '01204', '0788365', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '東光25条', 'トウコウ25ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市東光26条', '01', '01204', '0788366', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '東光26条', 'トウコウ26ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市東光27条', '01', '01204', '0788367', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '東光27条', 'トウコウ27ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市東旭川町旭正', '01', '01204', '0788368', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '東旭川町旭正', 'ヒガシアサヒカワチョウキョクセイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市旭神1条', '01', '01204', '0788371', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '旭神1条', 'キョクシン01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市旭神2条', '01', '01204', '0788372', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '旭神2条', 'キョクシン02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市旭神3条', '01', '01204', '0788373', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '旭神3条', 'キョクシン03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市西神楽1線', '01', '01204', '0788381', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '西神楽1線', 'ニシカグラ01セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市西神楽2線', '01', '01204', '0788382', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '西神楽2線', 'ニシカグラ02セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市西神楽3線', '01', '01204', '0788383', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '西神楽3線', 'ニシカグラ03セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市緑が丘東1条', '01', '01204', '0788801', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '緑が丘東1条', 'ミドリガオカヒガシ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市緑が丘東2条', '01', '01204', '0788802', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '緑が丘東2条', 'ミドリガオカヒガシ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市緑が丘東3条', '01', '01204', '0788803', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '緑が丘東3条', 'ミドリガオカヒガシ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市緑が丘東4条', '01', '01204', '0788804', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '緑が丘東4条', 'ミドリガオカヒガシ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市緑が丘東5条', '01', '01204', '0788805', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '緑が丘東5条', 'ミドリガオカヒガシ05ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市緑が丘南1条', '01', '01204', '0788811', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '緑が丘南1条', 'ミドリガオカミナミ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市緑が丘南2条', '01', '01204', '0788812', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '緑が丘南2条', 'ミドリガオカミナミ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市緑が丘南3条', '01', '01204', '0788813', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '緑が丘南3条', 'ミドリガオカミナミ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市緑が丘南4条', '01', '01204', '0788814', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '緑が丘南4条', 'ミドリガオカミナミ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市緑が丘南5条', '01', '01204', '0788815', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '緑が丘南5条', 'ミドリガオカミナミ05ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市西御料1条', '01', '01204', '0788821', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '西御料1条', 'ニシゴリョウ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市西御料2条', '01', '01204', '0788822', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '西御料2条', 'ニシゴリョウ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市西御料3条', '01', '01204', '0788823', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '西御料3条', 'ニシゴリョウ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市西御料4条', '01', '01204', '0788824', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '西御料4条', 'ニシゴリョウ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市西御料5条', '01', '01204', '0788825', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '西御料5条', 'ニシゴリョウ05ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県長岡郡大豊町八川', '39', '39344', '7890156', '高知県', 'コウチケン', '長岡郡大豊町', 'ナガオカグンオオトヨチョウ', '八川', 'ヤカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県長岡郡大豊町筏木', '39', '39344', '7890157', '高知県', 'コウチケン', '長岡郡大豊町', 'ナガオカグンオオトヨチョウ', '筏木', 'イカダギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県長岡郡大豊町岩原', '39', '39344', '7890158', '高知県', 'コウチケン', '長岡郡大豊町', 'ナガオカグンオオトヨチョウ', '岩原', 'イワハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県長岡郡大豊町西峰三谷', '39', '39344', '7890159', '高知県', 'コウチケン', '長岡郡大豊町', 'ナガオカグンオオトヨチョウ', '西峰', 'ニシミネ', null, null, '三谷', 'ミタニ');
INSERT INTO `ms_addresses` VALUES ('100128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県長岡郡大豊町西峰', '39', '39344', '7890160', '高知県', 'コウチケン', '長岡郡大豊町', 'ナガオカグンオオトヨチョウ', '西峰', 'ニシミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県長岡郡大豊町柚木', '39', '39344', '7890161', '高知県', 'コウチケン', '長岡郡大豊町', 'ナガオカグンオオトヨチョウ', '柚木', 'ユノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県長岡郡大豊町怒田', '39', '39344', '7890162', '高知県', 'コウチケン', '長岡郡大豊町', 'ナガオカグンオオトヨチョウ', '怒田', 'ヌタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県長岡郡大豊町南大王', '39', '39344', '7890163', '高知県', 'コウチケン', '長岡郡大豊町', 'ナガオカグンオオトヨチョウ', '南大王', 'ミナミダイオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県長岡郡大豊町八畝', '39', '39344', '7890164', '高知県', 'コウチケン', '長岡郡大豊町', 'ナガオカグンオオトヨチョウ', '八畝', 'ヨウネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県長岡郡大豊町西川', '39', '39344', '7890165', '高知県', 'コウチケン', '長岡郡大豊町', 'ナガオカグンオオトヨチョウ', '西川', 'ニシガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県長岡郡大豊町東土居', '39', '39344', '7890166', '高知県', 'コウチケン', '長岡郡大豊町', 'ナガオカグンオオトヨチョウ', '東土居', 'ヒガシドイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県長岡郡大豊町粟生', '39', '39344', '7890167', '高知県', 'コウチケン', '長岡郡大豊町', 'ナガオカグンオオトヨチョウ', '粟生', 'アオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県長岡郡大豊町立野', '39', '39344', '7890168', '高知県', 'コウチケン', '長岡郡大豊町', 'ナガオカグンオオトヨチョウ', '立野', 'タツノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県長岡郡大豊町大平', '39', '39344', '7890169', '高知県', 'コウチケン', '長岡郡大豊町', 'ナガオカグンオオトヨチョウ', '大平', 'オオダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県長岡郡大豊町大滝落合', '39', '39344', '7890170', '高知県', 'コウチケン', '長岡郡大豊町', 'ナガオカグンオオトヨチョウ', '大滝', 'オオダキ', null, null, '落合', 'オチアイ');
INSERT INTO `ms_addresses` VALUES ('100139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県長岡郡大豊町大滝', '39', '39344', '7890171', '高知県', 'コウチケン', '長岡郡大豊町', 'ナガオカグンオオトヨチョウ', '大滝', 'オオダキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県長岡郡大豊町川井', '39', '39344', '7890172', '高知県', 'コウチケン', '長岡郡大豊町', 'ナガオカグンオオトヨチョウ', '川井', 'カワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県長岡郡大豊町大平高原', '39', '39344', '7890173', '高知県', 'コウチケン', '長岡郡大豊町', 'ナガオカグンオオトヨチョウ', '大平', 'オオダイラ', null, null, '高原', 'タカハラ');
INSERT INTO `ms_addresses` VALUES ('100142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県長岡郡大豊町中内', '39', '39344', '7890174', '高知県', 'コウチケン', '長岡郡大豊町', 'ナガオカグンオオトヨチョウ', '中内', 'ナカウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県長岡郡大豊町奥大田', '39', '39344', '7890231', '高知県', 'コウチケン', '長岡郡大豊町', 'ナガオカグンオオトヨチョウ', '奥大田', 'オクオオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県長岡郡大豊町梶ケ内石堂', '39', '39344', '7890232', '高知県', 'コウチケン', '長岡郡大豊町', 'ナガオカグンオオトヨチョウ', '梶ケ内', 'カジガウチ', null, null, '石堂', 'イシドウ');
INSERT INTO `ms_addresses` VALUES ('100145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県長岡郡大豊町梶ケ内佐賀井', '39', '39344', '7890232', '高知県', 'コウチケン', '長岡郡大豊町', 'ナガオカグンオオトヨチョウ', '梶ケ内', 'カジガウチ', null, null, '佐賀井', 'サガイ');
INSERT INTO `ms_addresses` VALUES ('100146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県長岡郡大豊町磯谷', '39', '39344', '7890233', '高知県', 'コウチケン', '長岡郡大豊町', 'ナガオカグンオオトヨチョウ', '磯谷', 'イソダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県長岡郡大豊町寺内大田口', '39', '39344', '7890234', '高知県', 'コウチケン', '長岡郡大豊町', 'ナガオカグンオオトヨチョウ', '寺内', 'テラウチ', null, null, '大田口', 'オオタグチ');
INSERT INTO `ms_addresses` VALUES ('100148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県長岡郡大豊町船戸', '39', '39344', '7890235', '高知県', 'コウチケン', '長岡郡大豊町', 'ナガオカグンオオトヨチョウ', '船戸', 'フナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県長岡郡大豊町和田目付', '39', '39344', '7890236', '高知県', 'コウチケン', '長岡郡大豊町', 'ナガオカグンオオトヨチョウ', '和田', 'ワダ', null, null, '目付', 'メツケ');
INSERT INTO `ms_addresses` VALUES ('100150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県長岡郡大豊町庵谷', '39', '39344', '7890237', '高知県', 'コウチケン', '長岡郡大豊町', 'ナガオカグンオオトヨチョウ', '庵谷', 'イオノタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県長岡郡大豊町川戸', '39', '39344', '7890241', '高知県', 'コウチケン', '長岡郡大豊町', 'ナガオカグンオオトヨチョウ', '川戸', 'カワド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県長岡郡大豊町連火', '39', '39344', '7890242', '高知県', 'コウチケン', '長岡郡大豊町', 'ナガオカグンオオトヨチョウ', '連火', 'ツレビ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県長岡郡大豊町西久保', '39', '39344', '7890243', '高知県', 'コウチケン', '長岡郡大豊町', 'ナガオカグンオオトヨチョウ', '西久保', 'ニシクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県長岡郡大豊町桃原', '39', '39344', '7890244', '高知県', 'コウチケン', '長岡郡大豊町', 'ナガオカグンオオトヨチョウ', '桃原', 'モモハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県長岡郡大豊町永淵', '39', '39344', '7890245', '高知県', 'コウチケン', '長岡郡大豊町', 'ナガオカグンオオトヨチョウ', '永淵', 'ナガフチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県長岡郡大豊町柳野', '39', '39344', '7890246', '高知県', 'コウチケン', '長岡郡大豊町', 'ナガオカグンオオトヨチョウ', '柳野', 'ヤナギノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県長岡郡大豊町大砂子', '39', '39344', '7890247', '高知県', 'コウチケン', '長岡郡大豊町', 'ナガオカグンオオトヨチョウ', '大砂子', 'オオスナゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県長岡郡大豊町大久保', '39', '39344', '7890248', '高知県', 'コウチケン', '長岡郡大豊町', 'ナガオカグンオオトヨチョウ', '大久保', 'オオクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県長岡郡大豊町黒石', '39', '39344', '7890250', '高知県', 'コウチケン', '長岡郡大豊町', 'ナガオカグンオオトヨチョウ', '黒石', 'クロイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県長岡郡大豊町中屋', '39', '39344', '7890251', '高知県', 'コウチケン', '長岡郡大豊町', 'ナガオカグンオオトヨチョウ', '中屋', 'ナカヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県長岡郡大豊町上東', '39', '39344', '7890252', '高知県', 'コウチケン', '長岡郡大豊町', 'ナガオカグンオオトヨチョウ', '上東', 'カミヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県長岡郡大豊町安野々', '39', '39344', '7890253', '高知県', 'コウチケン', '長岡郡大豊町', 'ナガオカグンオオトヨチョウ', '安野々', 'ヤスノノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県長岡郡大豊町西土居', '39', '39344', '7890254', '高知県', 'コウチケン', '長岡郡大豊町', 'ナガオカグンオオトヨチョウ', '西土居', 'ニシドイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県長岡郡大豊町佐賀山', '39', '39344', '7890255', '高知県', 'コウチケン', '長岡郡大豊町', 'ナガオカグンオオトヨチョウ', '佐賀山', 'サガヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県長岡郡大豊町', '39', '39344', '7890300', '高知県', 'コウチケン', '長岡郡大豊町', 'ナガオカグンオオトヨチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('100166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県長岡郡大豊町津家桧生', '39', '39344', '7890301', '高知県', 'コウチケン', '長岡郡大豊町', 'ナガオカグンオオトヨチョウ', '津家', 'ツゲ', null, null, '桧生', 'ヒノキオ');
INSERT INTO `ms_addresses` VALUES ('100167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県長岡郡大豊町葛原', '39', '39344', '7890302', '高知県', 'コウチケン', '長岡郡大豊町', 'ナガオカグンオオトヨチョウ', '葛原', 'カズラワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県長岡郡大豊町川口', '39', '39344', '7890303', '高知県', 'コウチケン', '長岡郡大豊町', 'ナガオカグンオオトヨチョウ', '川口', 'カワグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県長岡郡大豊町谷', '39', '39344', '7890304', '高知県', 'コウチケン', '長岡郡大豊町', 'ナガオカグンオオトヨチョウ', '谷', 'タニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県長岡郡大豊町式岩', '39', '39344', '7890305', '高知県', 'コウチケン', '長岡郡大豊町', 'ナガオカグンオオトヨチョウ', '式岩', 'シキノイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県長岡郡大豊町尾生', '39', '39344', '7890306', '高知県', 'コウチケン', '長岡郡大豊町', 'ナガオカグンオオトヨチョウ', '尾生', 'オウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県長岡郡大豊町穴内', '39', '39344', '7890307', '高知県', 'コウチケン', '長岡郡大豊町', 'ナガオカグンオオトヨチョウ', '穴内', 'アナナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県長岡郡大豊町杉', '39', '39344', '7890311', '高知県', 'コウチケン', '長岡郡大豊町', 'ナガオカグンオオトヨチョウ', '杉', 'スギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県長岡郡大豊町高須', '39', '39344', '7890312', '高知県', 'コウチケン', '長岡郡大豊町', 'ナガオカグンオオトヨチョウ', '高須', 'タカズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県長岡郡大豊町川口南', '39', '39344', '7890313', '高知県', 'コウチケン', '長岡郡大豊町', 'ナガオカグンオオトヨチョウ', '川口南', 'カワグチミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県長岡郡大豊町日浦', '39', '39344', '7890314', '高知県', 'コウチケン', '長岡郡大豊町', 'ナガオカグンオオトヨチョウ', '日浦', 'ヒウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県長岡郡大豊町中村大王', '39', '39344', '7890315', '高知県', 'コウチケン', '長岡郡大豊町', 'ナガオカグンオオトヨチョウ', '中村大王', 'ナカムラダイオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県長岡郡大豊町小川', '39', '39344', '7890316', '高知県', 'コウチケン', '長岡郡大豊町', 'ナガオカグンオオトヨチョウ', '小川', 'オガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県長岡郡大豊町角茂谷', '39', '39344', '7890321', '高知県', 'コウチケン', '長岡郡大豊町', 'ナガオカグンオオトヨチョウ', '角茂谷', 'カクモダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県長岡郡大豊町戸手野', '39', '39344', '7890322', '高知県', 'コウチケン', '長岡郡大豊町', 'ナガオカグンオオトヨチョウ', '戸手野', 'トデノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県長岡郡大豊町馬瀬', '39', '39344', '7890323', '高知県', 'コウチケン', '長岡郡大豊町', 'ナガオカグンオオトヨチョウ', '馬瀬', 'ウマゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県長岡郡大豊町久寿軒', '39', '39344', '7890324', '高知県', 'コウチケン', '長岡郡大豊町', 'ナガオカグンオオトヨチョウ', '久寿軒', 'クスノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県長岡郡大豊町北川', '39', '39344', '7890325', '高知県', 'コウチケン', '長岡郡大豊町', 'ナガオカグンオオトヨチョウ', '北川', 'キタガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県長岡郡大豊町立川上名', '39', '39344', '7890426', '高知県', 'コウチケン', '長岡郡大豊町', 'ナガオカグンオオトヨチョウ', '立川上名', 'タジカワカミミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県長岡郡大豊町立川下名', '39', '39344', '7890427', '高知県', 'コウチケン', '長岡郡大豊町', 'ナガオカグンオオトヨチョウ', '立川下名', 'タジカワシモミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県長岡郡大豊町葛原千野々', '39', '39344', '7890428', '高知県', 'コウチケン', '長岡郡大豊町', 'ナガオカグンオオトヨチョウ', '葛原', 'カズラワラ', null, null, '千野々', 'チノノ');
INSERT INTO `ms_addresses` VALUES ('100188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市土佐山田町西又', '39', '39212', '7890581', '高知県', 'コウチケン', '香美市', 'カミシ', '土佐山田町西又', 'トサヤマダチョウニシマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市土佐山田町角茂谷', '39', '39212', '7890582', '高知県', 'コウチケン', '香美市', 'カミシ', '土佐山田町角茂谷', 'トサヤマダチョウカクモダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市土佐山田町平山岡田丸', '39', '39212', '7890583', '高知県', 'コウチケン', '香美市', 'カミシ', '土佐山田町平山', 'トサヤマダチョウヒラヤマ', null, null, '岡田丸', 'オカダマル');
INSERT INTO `ms_addresses` VALUES ('100191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市土佐山田町平山双子岩', '39', '39212', '7890583', '高知県', 'コウチケン', '香美市', 'カミシ', '土佐山田町平山', 'トサヤマダチョウヒラヤマ', null, null, '双子岩', 'フタゴイワ');
INSERT INTO `ms_addresses` VALUES ('100192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市土佐山田町平山向田', '39', '39212', '7890583', '高知県', 'コウチケン', '香美市', 'カミシ', '土佐山田町平山', 'トサヤマダチョウヒラヤマ', null, null, '向田', 'ムカイダ');
INSERT INTO `ms_addresses` VALUES ('100193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市土佐山田町北滝本', '39', '39212', '7890584', '高知県', 'コウチケン', '香美市', 'カミシ', '土佐山田町北滝本', 'トサヤマダチョウキタタキモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市土佐山田町繁藤', '39', '39212', '7890585', '高知県', 'コウチケン', '香美市', 'カミシ', '土佐山田町繁藤', 'トサヤマダチョウシゲトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市土佐山田町樫谷', '39', '39212', '7890586', '高知県', 'コウチケン', '香美市', 'カミシ', '土佐山田町樫谷', 'トサヤマダチョウカシノタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県香美市土佐山田町上穴内', '39', '39212', '7890587', '高知県', 'コウチケン', '香美市', 'カミシ', '土佐山田町上穴内', 'トサヤマダチョウカミアナナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡佐川町', '39', '39402', '7891200', '高知県', 'コウチケン', '高岡郡佐川町', 'タカオカグンサカワチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('100198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡佐川町甲', '39', '39402', '7891201', '高知県', 'コウチケン', '高岡郡佐川町', 'タカオカグンサカワチョウ', '甲', 'コウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡佐川町乙', '39', '39402', '7891202', '高知県', 'コウチケン', '高岡郡佐川町', 'タカオカグンサカワチョウ', '乙', 'オツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡佐川町丙', '39', '39402', '7891203', '高知県', 'コウチケン', '高岡郡佐川町', 'タカオカグンサカワチョウ', '丙', 'ヘイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡佐川町加茂', '39', '39402', '7891204', '高知県', 'コウチケン', '高岡郡佐川町', 'タカオカグンサカワチョウ', '加茂', 'カモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡佐川町室原', '39', '39402', '7891205', '高知県', 'コウチケン', '高岡郡佐川町', 'タカオカグンサカワチョウ', '室原', 'ムロハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡佐川町黒原', '39', '39402', '7891211', '高知県', 'コウチケン', '高岡郡佐川町', 'タカオカグンサカワチョウ', '黒原', 'クロハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡佐川町四ツ白', '39', '39402', '7891212', '高知県', 'コウチケン', '高岡郡佐川町', 'タカオカグンサカワチョウ', '四ツ白', 'ヨツジロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡佐川町二ツ野', '39', '39402', '7891213', '高知県', 'コウチケン', '高岡郡佐川町', 'タカオカグンサカワチョウ', '二ツ野', 'フタツノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡佐川町中野', '39', '39402', '7891214', '高知県', 'コウチケン', '高岡郡佐川町', 'タカオカグンサカワチョウ', '中野', 'ナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡佐川町瑞応', '39', '39402', '7891215', '高知県', 'コウチケン', '高岡郡佐川町', 'タカオカグンサカワチョウ', '瑞応', 'ズイオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡佐川町庄田', '39', '39402', '7891216', '高知県', 'コウチケン', '高岡郡佐川町', 'タカオカグンサカワチョウ', '庄田', 'ショウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡佐川町大田川', '39', '39402', '7891217', '高知県', 'コウチケン', '高岡郡佐川町', 'タカオカグンサカワチョウ', '大田川', 'オオタカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡佐川町平野', '39', '39402', '7891218', '高知県', 'コウチケン', '高岡郡佐川町', 'タカオカグンサカワチョウ', '平野', 'ヒラノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡佐川町本郷耕', '39', '39402', '7891221', '高知県', 'コウチケン', '高岡郡佐川町', 'タカオカグンサカワチョウ', '本郷耕', 'ホンゴウコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡佐川町西山組', '39', '39402', '7891222', '高知県', 'コウチケン', '高岡郡佐川町', 'タカオカグンサカワチョウ', '西山組', 'ニシヤマグミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡佐川町西山耕', '39', '39402', '7891223', '高知県', 'コウチケン', '高岡郡佐川町', 'タカオカグンサカワチョウ', '西山耕', 'ニシヤマコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡佐川町古畑耕', '39', '39402', '7891224', '高知県', 'コウチケン', '高岡郡佐川町', 'タカオカグンサカワチョウ', '古畑耕', 'フルハタコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡佐川町峰耕', '39', '39402', '7891225', '高知県', 'コウチケン', '高岡郡佐川町', 'タカオカグンサカワチョウ', '峰耕', 'ミネコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡佐川町永野', '39', '39402', '7891231', '高知県', 'コウチケン', '高岡郡佐川町', 'タカオカグンサカワチョウ', '永野', 'ナガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡佐川町東組', '39', '39402', '7891232', '高知県', 'コウチケン', '高岡郡佐川町', 'タカオカグンサカワチョウ', '東組', 'ヒガシグミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡佐川町中組', '39', '39402', '7891233', '高知県', 'コウチケン', '高岡郡佐川町', 'タカオカグンサカワチョウ', '中組', 'ナカグミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡佐川町西組', '39', '39402', '7891234', '高知県', 'コウチケン', '高岡郡佐川町', 'タカオカグンサカワチョウ', '西組', 'ニシグミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡佐川町川ノ内組', '39', '39402', '7891235', '高知県', 'コウチケン', '高岡郡佐川町', 'タカオカグンサカワチョウ', '川ノ内組', 'カワノウチグミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡中土佐町', '39', '39401', '7891300', '高知県', 'コウチケン', '高岡郡中土佐町', 'タカオカグンナカトサチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('100223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡中土佐町久礼', '39', '39401', '7891301', '高知県', 'コウチケン', '高岡郡中土佐町', 'タカオカグンナカトサチョウ', '久礼', 'クレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡中土佐町上ノ加江', '39', '39401', '7891302', '高知県', 'コウチケン', '高岡郡中土佐町', 'タカオカグンナカトサチョウ', '上ノ加江', 'カミノカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡中土佐町矢井賀甲', '39', '39401', '7891303', '高知県', 'コウチケン', '高岡郡中土佐町', 'タカオカグンナカトサチョウ', '矢井賀甲', 'ヤイカコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡中土佐町矢井賀乙', '39', '39401', '7891304', '高知県', 'コウチケン', '高岡郡中土佐町', 'タカオカグンナカトサチョウ', '矢井賀乙', 'ヤイカオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡中土佐町大野見吉野', '39', '39401', '7891401', '高知県', 'コウチケン', '高岡郡中土佐町', 'タカオカグンナカトサチョウ', '大野見吉野', 'オオノミヨシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡中土佐町大野見橋谷', '39', '39401', '7891402', '高知県', 'コウチケン', '高岡郡中土佐町', 'タカオカグンナカトサチョウ', '大野見橋谷', 'オオノミハシダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡中土佐町大野見久万秋', '39', '39401', '7891403', '高知県', 'コウチケン', '高岡郡中土佐町', 'タカオカグンナカトサチョウ', '大野見久万秋', 'オオノミクマアキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡中土佐町大野見奈路', '39', '39401', '7891404', '高知県', 'コウチケン', '高岡郡中土佐町', 'タカオカグンナカトサチョウ', '大野見奈路', 'オオノミナロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡中土佐町大野見伊勢川', '39', '39401', '7891405', '高知県', 'コウチケン', '高岡郡中土佐町', 'タカオカグンナカトサチョウ', '大野見伊勢川', 'オオノミイセガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡中土佐町大野見槇野々', '39', '39401', '7891406', '高知県', 'コウチケン', '高岡郡中土佐町', 'タカオカグンナカトサチョウ', '大野見槇野々', 'オオノミマキノノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡中土佐町大野見三ツ又', '39', '39401', '7891407', '高知県', 'コウチケン', '高岡郡中土佐町', 'タカオカグンナカトサチョウ', '大野見三ツ又', 'オオノミミツマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡中土佐町大野見長野', '39', '39401', '7891408', '高知県', 'コウチケン', '高岡郡中土佐町', 'タカオカグンナカトサチョウ', '大野見長野', 'オオノミナガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡中土佐町大野見竹原', '39', '39401', '7891409', '高知県', 'コウチケン', '高岡郡中土佐町', 'タカオカグンナカトサチョウ', '大野見竹原', 'オオノミタケハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡中土佐町大野見栂ノ川', '39', '39401', '7891410', '高知県', 'コウチケン', '高岡郡中土佐町', 'タカオカグンナカトサチョウ', '大野見栂ノ川', 'オオノミツガノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡中土佐町大野見野老野', '39', '39401', '7891411', '高知県', 'コウチケン', '高岡郡中土佐町', 'タカオカグンナカトサチョウ', '大野見野老野', 'オオノミトコロノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡中土佐町大野見川奥', '39', '39401', '7891412', '高知県', 'コウチケン', '高岡郡中土佐町', 'タカオカグンナカトサチョウ', '大野見川奥', 'オオノミカワオク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡中土佐町大野見荒瀬', '39', '39401', '7891413', '高知県', 'コウチケン', '高岡郡中土佐町', 'タカオカグンナカトサチョウ', '大野見荒瀬', 'オオノミアラセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡中土佐町大野見神母野', '39', '39401', '7891414', '高知県', 'コウチケン', '高岡郡中土佐町', 'タカオカグンナカトサチョウ', '大野見神母野', 'オオノミイゲノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡中土佐町大野見寺野', '39', '39401', '7891415', '高知県', 'コウチケン', '高岡郡中土佐町', 'タカオカグンナカトサチョウ', '大野見寺野', 'オオノミテラノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡中土佐町大野見下ル川', '39', '39401', '7891416', '高知県', 'コウチケン', '高岡郡中土佐町', 'タカオカグンナカトサチョウ', '大野見下ル川', 'オオノミクダルカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡中土佐町大野見萩中', '39', '39401', '7891417', '高知県', 'コウチケン', '高岡郡中土佐町', 'タカオカグンナカトサチョウ', '大野見萩中', 'オオノミハギナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡中土佐町大野見大股', '39', '39401', '7891418', '高知県', 'コウチケン', '高岡郡中土佐町', 'タカオカグンナカトサチョウ', '大野見大股', 'オオノミオオマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県高岡郡中土佐町大野見島ノ川', '39', '39401', '7891419', '高知県', 'コウチケン', '高岡郡中土佐町', 'タカオカグンナカトサチョウ', '大野見島ノ川', 'オオノミシマノガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県幡多郡黒潮町市野瀬', '39', '39428', '7891701', '高知県', 'コウチケン', '幡多郡黒潮町', 'ハタグンクロシオチョウ', '市野瀬', 'イチノセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県幡多郡黒潮町佐賀橘川', '39', '39428', '7891702', '高知県', 'コウチケン', '幡多郡黒潮町', 'ハタグンクロシオチョウ', '佐賀橘川', 'サガタチバナガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県幡多郡黒潮町拳ノ川', '39', '39428', '7891703', '高知県', 'コウチケン', '幡多郡黒潮町', 'ハタグンクロシオチョウ', '拳ノ川', 'コブシノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県幡多郡黒潮町川奥', '39', '39428', '7891704', '高知県', 'コウチケン', '幡多郡黒潮町', 'ハタグンクロシオチョウ', '川奥', 'カワオク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県幡多郡黒潮町荷稲', '39', '39428', '7891705', '高知県', 'コウチケン', '幡多郡黒潮町', 'ハタグンクロシオチョウ', '荷稲', 'カイナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県幡多郡黒潮町小黒ノ川', '39', '39428', '7891706', '高知県', 'コウチケン', '幡多郡黒潮町', 'ハタグンクロシオチョウ', '小黒ノ川', 'コグロノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県幡多郡黒潮町中ノ川', '39', '39428', '7891707', '高知県', 'コウチケン', '幡多郡黒潮町', 'ハタグンクロシオチョウ', '中ノ川', 'ナカノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県幡多郡黒潮町鈴', '39', '39428', '7891708', '高知県', 'コウチケン', '幡多郡黒潮町', 'ハタグンクロシオチョウ', '鈴', 'スズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県幡多郡黒潮町市野々川', '39', '39428', '7891711', '高知県', 'コウチケン', '幡多郡黒潮町', 'ハタグンクロシオチョウ', '市野々川', 'イチノノガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県幡多郡黒潮町不破原', '39', '39428', '7891712', '高知県', 'コウチケン', '幡多郡黒潮町', 'ハタグンクロシオチョウ', '不破原', 'フバハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県幡多郡黒潮町伊与喜', '39', '39428', '7891713', '高知県', 'コウチケン', '幡多郡黒潮町', 'ハタグンクロシオチョウ', '伊与喜', 'イヨキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県幡多郡黒潮町藤縄', '39', '39428', '7891714', '高知県', 'コウチケン', '幡多郡黒潮町', 'ハタグンクロシオチョウ', '藤縄', 'フジナワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県幡多郡黒潮町熊井', '39', '39428', '7891715', '高知県', 'コウチケン', '幡多郡黒潮町', 'ハタグンクロシオチョウ', '熊井', 'クマイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県幡多郡黒潮町熊野浦', '39', '39428', '7891716', '高知県', 'コウチケン', '幡多郡黒潮町', 'ハタグンクロシオチョウ', '熊野浦', 'クマノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県幡多郡黒潮町佐賀', '39', '39428', '7891720', '高知県', 'コウチケン', '幡多郡黒潮町', 'ハタグンクロシオチョウ', '佐賀', 'サガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県幡多郡黒潮町佐賀中角', '39', '39428', '7891721', '高知県', 'コウチケン', '幡多郡黒潮町', 'ハタグンクロシオチョウ', '佐賀', 'サガ', null, null, '中角', 'ナカカド');
INSERT INTO `ms_addresses` VALUES ('100262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県幡多郡黒潮町佐賀坂折', '39', '39428', '7891722', '高知県', 'コウチケン', '幡多郡黒潮町', 'ハタグンクロシオチョウ', '佐賀', 'サガ', null, null, '坂折', 'サカオリ');
INSERT INTO `ms_addresses` VALUES ('100263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県幡多郡黒潮町佐賀馬路', '39', '39428', '7891723', '高知県', 'コウチケン', '幡多郡黒潮町', 'ハタグンクロシオチョウ', '佐賀', 'サガ', null, null, '馬路', 'ウマジ');
INSERT INTO `ms_addresses` VALUES ('100264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県幡多郡黒潮町佐賀横浜', '39', '39428', '7891724', '高知県', 'コウチケン', '幡多郡黒潮町', 'ハタグンクロシオチョウ', '佐賀', 'サガ', null, null, '横浜', 'ヨコハマ');
INSERT INTO `ms_addresses` VALUES ('100265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県幡多郡黒潮町白浜', '39', '39428', '7891725', '高知県', 'コウチケン', '幡多郡黒潮町', 'ハタグンクロシオチョウ', '白浜', 'シラハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県幡多郡黒潮町', '39', '39428', '7891900', '高知県', 'コウチケン', '幡多郡黒潮町', 'ハタグンクロシオチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('100268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県幡多郡黒潮町上川口', '39', '39428', '7891901', '高知県', 'コウチケン', '幡多郡黒潮町', 'ハタグンクロシオチョウ', '上川口', 'カミカワグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県幡多郡黒潮町蜷川', '39', '39428', '7891902', '高知県', 'コウチケン', '幡多郡黒潮町', 'ハタグンクロシオチョウ', '蜷川', 'ミナガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県幡多郡黒潮町有井川', '39', '39428', '7891903', '高知県', 'コウチケン', '幡多郡黒潮町', 'ハタグンクロシオチョウ', '有井川', 'アリイガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県幡多郡黒潮町伊田', '39', '39428', '7891904', '高知県', 'コウチケン', '幡多郡黒潮町', 'ハタグンクロシオチョウ', '伊田', 'イダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県幡多郡黒潮町灘', '39', '39428', '7891905', '高知県', 'コウチケン', '幡多郡黒潮町', 'ハタグンクロシオチョウ', '灘', 'ナダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県幡多郡黒潮町浮鞭', '39', '39428', '7891911', '高知県', 'コウチケン', '幡多郡黒潮町', 'ハタグンクロシオチョウ', '浮鞭', 'ウキブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県幡多郡黒潮町口湊川', '39', '39428', '7891912', '高知県', 'コウチケン', '幡多郡黒潮町', 'ハタグンクロシオチョウ', '口湊川', 'クチミナトガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県幡多郡黒潮町奥湊川', '39', '39428', '7891913', '高知県', 'コウチケン', '幡多郡黒潮町', 'ハタグンクロシオチョウ', '奥湊川', 'オクミナトガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県幡多郡黒潮町加持', '39', '39428', '7891921', '高知県', 'コウチケン', '幡多郡黒潮町', 'ハタグンクロシオチョウ', '加持', 'カモチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県幡多郡黒潮町加持川', '39', '39428', '7891922', '高知県', 'コウチケン', '幡多郡黒潮町', 'ハタグンクロシオチョウ', '加持川', 'カモチガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県幡多郡黒潮町大井川', '39', '39428', '7891923', '高知県', 'コウチケン', '幡多郡黒潮町', 'ハタグンクロシオチョウ', '大井川', 'オオイガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県幡多郡黒潮町馬荷', '39', '39428', '7891924', '高知県', 'コウチケン', '幡多郡黒潮町', 'ハタグンクロシオチョウ', '馬荷', 'ウマニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県幡多郡黒潮町大方橘川', '39', '39428', '7891925', '高知県', 'コウチケン', '幡多郡黒潮町', 'ハタグンクロシオチョウ', '大方橘川', 'オオガタタチバナガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県幡多郡黒潮町入野', '39', '39428', '7891931', '高知県', 'コウチケン', '幡多郡黒潮町', 'ハタグンクロシオチョウ', '入野', 'イリノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県幡多郡黒潮町下田の口', '39', '39428', '7891932', '高知県', 'コウチケン', '幡多郡黒潮町', 'ハタグンクロシオチョウ', '下田の口', 'シモタノクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県幡多郡黒潮町田野浦', '39', '39428', '7891933', '高知県', 'コウチケン', '幡多郡黒潮町', 'ハタグンクロシオチョウ', '田野浦', 'タノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県幡多郡黒潮町出口', '39', '39428', '7891934', '高知県', 'コウチケン', '幡多郡黒潮町', 'ハタグンクロシオチョウ', '出口', 'イデグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県幡多郡黒潮町上田の口', '39', '39428', '7891935', '高知県', 'コウチケン', '幡多郡黒潮町', 'ハタグンクロシオチョウ', '上田の口', 'カミタノクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '高知県幡多郡黒潮町御坊畑', '39', '39428', '7891936', '高知県', 'コウチケン', '幡多郡黒潮町', 'ハタグンクロシオチョウ', '御坊畑', 'オンボウバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市一番町', '38', '38201', '7900001', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '一番町', 'イチバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市二番町', '38', '38201', '7900002', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '二番町', 'ニバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市三番町', '38', '38201', '7900003', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '三番町', 'サンバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市大街道', '38', '38201', '7900004', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '大街道', 'オオカイドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市花園町', '38', '38201', '7900005', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '花園町', 'ハナゾノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市南堀端町', '38', '38201', '7900006', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '南堀端町', 'ミナミホリバタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市堀之内', '38', '38201', '7900007', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '堀之内', 'ホリノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市丸之内', '38', '38201', '7900008', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '丸之内', 'マルノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市千舟町', '38', '38201', '7900011', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '千舟町', 'チフネマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市湊町', '38', '38201', '7900012', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '湊町', 'ミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市河原町', '38', '38201', '7900013', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '河原町', 'カワラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市柳井町', '38', '38201', '7900014', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '柳井町', 'ヤナイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市真砂町', '38', '38201', '7900021', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '真砂町', 'マサゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市永代町', '38', '38201', '7900022', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '永代町', 'エイダイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市末広町', '38', '38201', '7900023', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '末広町', 'スエヒロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市春日町', '38', '38201', '7900024', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '春日町', 'カスガマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市泉町', '38', '38201', '7900025', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '泉町', 'イズミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市室町', '38', '38201', '7900026', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '室町', 'ムロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市雄郡', '38', '38201', '7900031', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '雄郡', 'ユウグン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市土橋町', '38', '38201', '7900032', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '土橋町', 'ドバシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市北藤原町', '38', '38201', '7900033', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '北藤原町', 'キタフジワラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市藤原町', '38', '38201', '7900034', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '藤原町', 'フジワラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市藤原', '38', '38201', '7900035', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '藤原', 'フジワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市小栗', '38', '38201', '7900036', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '小栗', 'オグリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市小栗町', '38', '38201', '7900037', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '小栗町', 'オグリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市和泉北', '38', '38201', '7900038', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '和泉北', 'イズミキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市保免上', '38', '38201', '7900041', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '保免上', 'ホウメンカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市保免中', '38', '38201', '7900042', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '保免中', 'ホウメンナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市保免西', '38', '38201', '7900043', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '保免西', 'ホウメンニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市余戸東', '38', '38201', '7900044', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '余戸東', 'ヨウゴヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市余戸中', '38', '38201', '7900045', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '余戸中', 'ヨウゴナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市余戸西', '38', '38201', '7900046', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '余戸西', 'ヨウゴニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市余戸南', '38', '38201', '7900047', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '余戸南', 'ヨウゴミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市出合', '38', '38201', '7900048', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '出合', 'デアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市生石町', '38', '38201', '7900051', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '生石町', 'イクシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市竹原町', '38', '38201', '7900052', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '竹原町', 'タケワラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市竹原', '38', '38201', '7900053', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '竹原', 'タケワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市空港通1丁目', '38', '38201', '7900054', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '空港通', 'クウコウドオリ', null, null, '1丁目', '01チョウメ');
INSERT INTO `ms_addresses` VALUES ('100326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市空港通2丁目', '38', '38201', '7900054', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '空港通', 'クウコウドオリ', null, null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('100327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市針田町', '38', '38201', '7900055', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '針田町', 'ハリタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市土居田町', '38', '38201', '7900056', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '土居田町', 'ドイダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市南江戸町', '38', '38201', '7900061', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '南江戸町', 'ミナミエドマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市南江戸', '38', '38201', '7900062', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '南江戸', 'ミナミエド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市辻町', '38', '38201', '7900063', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '辻町', 'ツジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市愛光町', '38', '38201', '7900064', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '愛光町', 'アイコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市宮西', '38', '38201', '7900065', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '宮西', 'ミヤニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市宮田町', '38', '38201', '7900066', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '宮田町', 'ミヤタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市大手町', '38', '38201', '7900067', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '大手町', 'オオテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市歩行町', '38', '38201', '7900801', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '歩行町', 'カチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市喜与町', '38', '38201', '7900802', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '喜与町', 'キヨマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市東雲町', '38', '38201', '7900803', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '東雲町', 'シノノメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市中一万町', '38', '38201', '7900804', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '中一万町', 'ナカイチマンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市西一万町', '38', '38201', '7900805', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '西一万町', 'ニシイチマンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市緑町', '38', '38201', '7900806', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '緑町', 'ミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市平和通', '38', '38201', '7900807', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '平和通', 'ヘイワドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市若草町', '38', '38201', '7900808', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '若草町', 'ワカクサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市本町', '38', '38201', '7900811', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市松前町', '38', '38201', '7900812', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '松前町', 'マサキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市萱町', '38', '38201', '7900813', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '萱町', 'カヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市味酒町', '38', '38201', '7900814', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '味酒町', 'ミサケマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市木屋町', '38', '38201', '7900821', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '木屋町', 'キヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市高砂町', '38', '38201', '7900822', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '高砂町', 'タカサゴマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市清水町', '38', '38201', '7900823', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '清水町', 'シミズマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市御幸', '38', '38201', '7900824', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '御幸', 'ミユキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市道後樋又', '38', '38201', '7900825', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '道後樋又', 'ドウゴヒマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市文京町', '38', '38201', '7900826', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '文京町', 'ブンキョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市鉄砲町', '38', '38201', '7900827', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '鉄砲町', 'テッポウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市山田町', '38', '38201', '7900831', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '山田町', 'ヤマダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市祝谷西町', '38', '38201', '7900832', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '祝谷西町', 'イワイダニニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市祝谷', '38', '38201', '7900833', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '祝谷', 'イワイダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市祝谷町', '38', '38201', '7900834', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '祝谷町', 'イワイダニマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市祝谷東町', '38', '38201', '7900835', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '祝谷東町', 'イワイダニヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市道後鷺谷町', '38', '38201', '7900836', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '道後鷺谷町', 'ドウゴサギダニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市道後湯月町', '38', '38201', '7900837', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '道後湯月町', 'ドウゴユヅキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市桜谷町', '38', '38201', '7900838', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '桜谷町', 'サクラダニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市道後多幸町', '38', '38201', '7900841', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '道後多幸町', 'ドウゴタコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市道後湯之町', '38', '38201', '7900842', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '道後湯之町', 'ドウゴユノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市道後町1丁目', '38', '38201', '7900843', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '道後町', 'ドウゴマチ', null, null, '1丁目', '01チョウメ');
INSERT INTO `ms_addresses` VALUES ('100366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市道後町2丁目', '38', '38201', '7900843', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '道後町', 'ドウゴマチ', null, null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('100367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市道後一万', '38', '38201', '7900844', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '道後一万', 'ドウゴイチマン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市道後今市', '38', '38201', '7900845', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '道後今市', 'ドウゴイマイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市道後北代', '38', '38201', '7900846', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '道後北代', 'ドウゴキタシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市道後緑台', '38', '38201', '7900847', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '道後緑台', 'ドウゴミドリダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市道後喜多町', '38', '38201', '7900848', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '道後喜多町', 'ドウゴキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市常光寺町', '38', '38201', '7900851', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '常光寺町', 'ジョウコウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市石手', '38', '38201', '7900852', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '石手', 'イシテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市上市', '38', '38201', '7900853', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '上市', 'カミイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市岩崎町', '38', '38201', '7900854', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '岩崎町', 'イワサキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市持田町', '38', '38201', '7900855', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '持田町', 'モチダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市南町', '38', '38201', '7900856', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '南町', 'ミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市道後公園', '38', '38201', '7900857', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '道後公園', 'ドウゴコウエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市道後姫塚', '38', '38201', '7900858', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '道後姫塚', 'ドウゴヒメヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市紅葉町', '38', '38201', '7900861', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '紅葉町', 'モミジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市湯渡町', '38', '38201', '7900862', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '湯渡町', 'ユワタリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市此花町', '38', '38201', '7900863', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '此花町', 'コノハナマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市築山町', '38', '38201', '7900864', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '築山町', 'ツキヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市新立町', '38', '38201', '7900865', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '新立町', 'シンダテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市永木町', '38', '38201', '7900866', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '永木町', 'ナガキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市北立花町', '38', '38201', '7900867', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '北立花町', 'キタタチバナマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市東一万町', '38', '38201', '7900871', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '東一万町', 'ヒガシイチマンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市昭和町', '38', '38201', '7900872', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '昭和町', 'ショウワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市北持田町', '38', '38201', '7900873', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '北持田町', 'キタモチダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市南持田町', '38', '38201', '7900874', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '南持田町', 'ミナミモチダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市御宝町', '38', '38201', '7900875', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '御宝町', 'ミタカラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市旭町', '38', '38201', '7900876', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '旭町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市錦町', '38', '38201', '7900877', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '錦町', 'ニシキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市勝山町', '38', '38201', '7900878', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '勝山町', 'カツヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市新石手', '38', '38201', '7900901', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '新石手', 'シンイシテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市石手白石', '38', '38201', '7900902', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '石手白石', 'イシテシライシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市東野', '38', '38201', '7900903', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '東野', 'ヒガシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市正円寺', '38', '38201', '7900904', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '正円寺', 'ショウエンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市樽味', '38', '38201', '7900905', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '樽味', 'タルミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市桑原', '38', '38201', '7900911', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '桑原', 'クワバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市畑寺町', '38', '38201', '7900912', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '畑寺町', 'ハタデラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市畑寺', '38', '38201', '7900913', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '畑寺', 'ハタデラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市三町', '38', '38201', '7900914', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '三町', 'サンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市松末', '38', '38201', '7900915', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '松末', 'マツスエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市束本', '38', '38201', '7900916', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '束本', 'ツカモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市福音寺町', '38', '38201', '7900921', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '福音寺町', 'フクオンジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市星岡', '38', '38201', '7900922', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '星岡', 'ホシオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市星岡町', '38', '38201', '7900922', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '星岡町', 'ホシオカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市北久米町', '38', '38201', '7900923', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '北久米町', 'キタクメマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市南久米町', '38', '38201', '7900924', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '南久米町', 'ミナミクメマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市鷹子町', '38', '38201', '7900925', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '鷹子町', 'タカノコマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市西石井', '38', '38201', '7900931', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '西石井', 'ニシイシイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市東石井', '38', '38201', '7900932', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '東石井', 'ヒガシイシイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市越智', '38', '38201', '7900933', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '越智', 'オチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市居相', '38', '38201', '7900934', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '居相', 'イアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市和泉南', '38', '38201', '7900941', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '和泉南', 'イズミミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市古川北', '38', '38201', '7900942', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '古川北', 'フルカワキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市古川南', '38', '38201', '7900943', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '古川南', 'フルカワミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市古川西', '38', '38201', '7900944', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '古川西', 'フルカワニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市古川町', '38', '38201', '7900945', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '古川町', 'フルカワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市市坪北', '38', '38201', '7900946', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '市坪北', 'イチツボキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市市坪南', '38', '38201', '7900947', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '市坪南', 'イチツボミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市市坪西町', '38', '38201', '7900948', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '市坪西町', 'イチツボニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市天山', '38', '38201', '7900951', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '天山', 'アマヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市天山町', '38', '38201', '7900951', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '天山町', 'アマヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市朝生田町', '38', '38201', '7900952', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '朝生田町', 'アソダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市日の出町', '38', '38201', '7900961', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '日の出町', 'ヒノデマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市枝松', '38', '38201', '7900962', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '枝松', 'エダマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市小坂', '38', '38201', '7900963', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '小坂', 'コサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市中村', '38', '38201', '7900964', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '中村', 'ナカムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市祇園町', '38', '38201', '7900965', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '祇園町', 'ギオンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市立花', '38', '38201', '7900966', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '立花', 'タチバナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市拓川町', '38', '38201', '7900967', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '拓川町', 'タクセンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市光珠内拓北', '01', '01215', '0790161', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '光珠内拓北', 'コウシュナイタクホク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市光珠内北', '01', '01215', '0790162', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '光珠内北', 'コウシュナイキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市光珠内下中の沢', '01', '01215', '0790164', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '光珠内下中の沢', 'コウシウナイシモナカノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市光珠内上中の沢', '01', '01215', '0790165', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '光珠内上中の沢', 'コウシウナイカミナカノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市光珠内東山', '01', '01215', '0790166', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '光珠内東山', 'コウシュナイヒガシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市光珠内町南', '01', '01215', '0790167', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '光珠内町南', 'コウシュナイチョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市光珠内中央', '01', '01215', '0790171', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '光珠内中央', 'コウシュナイチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市峰延町東', '01', '01215', '0790172', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '峰延町東', 'ミネノブチョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市峰延町公園', '01', '01215', '0790173', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '峰延町公園', 'ミネノブチョウコウエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市峰延町本町', '01', '01215', '0790174', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '峰延町本町', 'ミネノブチョウホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市峰延町峰樺', '01', '01215', '0790175', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '峰延町峰樺', 'ミネノブチョウミネカバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市豊葦町', '01', '01215', '0790176', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '豊葦町', 'トヨアシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市上美唄町協和', '01', '01215', '0790177', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '上美唄町', 'カミビバイチョウ', null, null, '協和', 'キョウワ');
INSERT INTO `ms_addresses` VALUES ('100450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市上美唄町南', '01', '01215', '0790177', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '上美唄町', 'カミビバイチョウ', null, null, '南', 'ミナミ');
INSERT INTO `ms_addresses` VALUES ('100451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市岡山町', '01', '01210', '0790181', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '岡山町', 'オカヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市峰延町', '01', '01210', '0790182', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '峰延町', 'ミネノブチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道岩見沢市大願町', '01', '01210', '0790183', '北海道', 'ホッカイドウ', '岩見沢市', 'イワミザワシ', '大願町', 'オオネガイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市茶志内町', '01', '01215', '0790261', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '茶志内町', 'チャシナイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市日東町栄町', '01', '01215', '0790262', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '日東町栄町', 'ニットウチョウサカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市日東町住吉', '01', '01215', '0790263', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '日東町住吉', 'ニットウチョウスミヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市日東町本町', '01', '01215', '0790264', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '日東町本町', 'ニットウチョウホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市日東町富の郷', '01', '01215', '0790265', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '日東町富の郷', 'ニットウチョウトミノゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市茶志内町本町', '01', '01215', '0790266', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '茶志内町本町', 'チャシナイチョウホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市茶志内町協和', '01', '01215', '0790267', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '茶志内町協和', 'チャシナイチョウキョウワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市中村町南', '01', '01215', '0790271', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '中村町南', 'ナカムラチョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市中村町中央', '01', '01215', '0790272', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '中村町中央', 'ナカムラチョウチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市中村町北', '01', '01215', '0790273', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '中村町北', 'ナカムラチョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道美唄市北美唄町', '01', '01215', '0790274', '北海道', 'ホッカイドウ', '美唄市', 'ビバイシ', '北美唄町', 'キタビバイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡奈井江町', '01', '01424', '0790300', '北海道', 'ホッカイドウ', '空知郡奈井江町', 'ソラチグンナイエチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('100469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡奈井江町厳島', '01', '01424', '0790301', '北海道', 'ホッカイドウ', '空知郡奈井江町', 'ソラチグンナイエチョウ', '厳島', 'イツクシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡奈井江町白山', '01', '01424', '0790302', '北海道', 'ホッカイドウ', '空知郡奈井江町', 'ソラチグンナイエチョウ', '白山', 'ハクサン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡奈井江町向ケ丘', '01', '01424', '0790303', '北海道', 'ホッカイドウ', '空知郡奈井江町', 'ソラチグンナイエチョウ', '向ケ丘', 'ムコウガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡奈井江町宮村', '01', '01424', '0790304', '北海道', 'ホッカイドウ', '空知郡奈井江町', 'ソラチグンナイエチョウ', '宮村', 'ミヤムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡奈井江町茶志内', '01', '01424', '0790305', '北海道', 'ホッカイドウ', '空知郡奈井江町', 'ソラチグンナイエチョウ', '茶志内', 'チャシナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡奈井江町東町', '01', '01424', '0790306', '北海道', 'ホッカイドウ', '空知郡奈井江町', 'ソラチグンナイエチョウ', '東町', 'ヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡奈井江町大和', '01', '01424', '0790311', '北海道', 'ホッカイドウ', '空知郡奈井江町', 'ソラチグンナイエチョウ', '大和', 'ヤマト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡奈井江町北町', '01', '01424', '0790312', '北海道', 'ホッカイドウ', '空知郡奈井江町', 'ソラチグンナイエチョウ', '北町', 'キタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡奈井江町本町', '01', '01424', '0790313', '北海道', 'ホッカイドウ', '空知郡奈井江町', 'ソラチグンナイエチョウ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡奈井江町南町', '01', '01424', '0790314', '北海道', 'ホッカイドウ', '空知郡奈井江町', 'ソラチグンナイエチョウ', '南町', 'ミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡奈井江町高島', '01', '01424', '0790315', '北海道', 'ホッカイドウ', '空知郡奈井江町', 'ソラチグンナイエチョウ', '高島', 'タカシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡奈井江町キナウスナイ', '01', '01424', '0790316', '北海道', 'ホッカイドウ', '空知郡奈井江町', 'ソラチグンナイエチョウ', 'キナウスナイ', 'キナウスナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡奈井江町瑞穂', '01', '01424', '0790317', '北海道', 'ホッカイドウ', '空知郡奈井江町', 'ソラチグンナイエチョウ', '瑞穂', 'ミズホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道滝川市江部乙町', '01', '01225', '0790461', '北海道', 'ホッカイドウ', '滝川市', 'タキカワシ', '江部乙町', 'エベオツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道滝川市江部乙町西', '01', '01225', '0790462', '北海道', 'ホッカイドウ', '滝川市', 'タキカワシ', '江部乙町西', 'エベオツチョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道滝川市江部乙町東', '01', '01225', '0790463', '北海道', 'ホッカイドウ', '滝川市', 'タキカワシ', '江部乙町東', 'エベオツチョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道雨竜郡妹背牛町', '01', '01433', '0790500', '北海道', 'ホッカイドウ', '雨竜郡妹背牛町', 'ウリュウグンモセウシチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('100490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道雨竜郡妹背牛町1区', '01', '01433', '0790501', '北海道', 'ホッカイドウ', '雨竜郡妹背牛町', 'ウリュウグンモセウシチョウ', '1区', '01ク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道雨竜郡妹背牛町2区', '01', '01433', '0790502', '北海道', 'ホッカイドウ', '雨竜郡妹背牛町', 'ウリュウグンモセウシチョウ', '2区', '02ク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道雨竜郡妹背牛町3区', '01', '01433', '0790503', '北海道', 'ホッカイドウ', '雨竜郡妹背牛町', 'ウリュウグンモセウシチョウ', '3区', '03ク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道雨竜郡妹背牛町4区', '01', '01433', '0790504', '北海道', 'ホッカイドウ', '雨竜郡妹背牛町', 'ウリュウグンモセウシチョウ', '4区', '04ク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道雨竜郡妹背牛町5区', '01', '01433', '0790505', '北海道', 'ホッカイドウ', '雨竜郡妹背牛町', 'ウリュウグンモセウシチョウ', '5区', '05ク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道雨竜郡妹背牛町6区', '01', '01433', '0790506', '北海道', 'ホッカイドウ', '雨竜郡妹背牛町', 'ウリュウグンモセウシチョウ', '6区', '06ク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道雨竜郡妹背牛町7区', '01', '01433', '0790507', '北海道', 'ホッカイドウ', '雨竜郡妹背牛町', 'ウリュウグンモセウシチョウ', '7区', '07ク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道雨竜郡妹背牛町8区', '01', '01433', '0790508', '北海道', 'ホッカイドウ', '雨竜郡妹背牛町', 'ウリュウグンモセウシチョウ', '8区', '08ク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道雨竜郡妹背牛町9区', '01', '01433', '0790509', '北海道', 'ホッカイドウ', '雨竜郡妹背牛町', 'ウリュウグンモセウシチョウ', '9区', '09ク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道雨竜郡妹背牛町10区', '01', '01433', '0790510', '北海道', 'ホッカイドウ', '雨竜郡妹背牛町', 'ウリュウグンモセウシチョウ', '10区', '10ク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道雨竜郡妹背牛町11区', '01', '01433', '0790511', '北海道', 'ホッカイドウ', '雨竜郡妹背牛町', 'ウリュウグンモセウシチョウ', '11区', '11ク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市', '38', '38201', '7910000', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('100598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市空港通3丁目', '38', '38201', '7910054', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '空港通', 'クウコウドオリ', null, null, '3丁目', '03チョウメ');
INSERT INTO `ms_addresses` VALUES ('100599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市空港通4丁目', '38', '38201', '7910054', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '空港通', 'クウコウドオリ', null, null, '4丁目', '04チョウメ');
INSERT INTO `ms_addresses` VALUES ('100600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市空港通5丁目', '38', '38201', '7910054', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '空港通', 'クウコウドオリ', null, null, '5丁目', '05チョウメ');
INSERT INTO `ms_addresses` VALUES ('100601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市空港通6丁目', '38', '38201', '7910054', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '空港通', 'クウコウドオリ', null, null, '6丁目', '06チョウメ');
INSERT INTO `ms_addresses` VALUES ('100602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市空港通7丁目', '38', '38201', '7910054', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '空港通', 'クウコウドオリ', null, null, '7丁目', '07チョウメ');
INSERT INTO `ms_addresses` VALUES ('100603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市溝辺町', '38', '38201', '7910101', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '溝辺町', 'ミゾノベマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市高野町', '38', '38201', '7910102', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '高野町', 'タカノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市上高野町', '38', '38201', '7910103', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '上高野町', 'カミタカノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市食場町', '38', '38201', '7910104', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '食場町', 'ジキバマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市杉立町', '38', '38201', '7910105', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '杉立町', 'スギタテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市上伊台町', '38', '38201', '7910111', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '上伊台町', 'カミイダイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市下伊台町', '38', '38201', '7910112', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '下伊台町', 'シモイダイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市白水台', '38', '38201', '7910113', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '白水台', 'ハクスイダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市南白水', '38', '38201', '7910114', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '南白水', 'ミナミハクスイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市湯の山東', '38', '38201', '7910120', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '湯の山東', 'ユノヤマヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市湯の山', '38', '38201', '7910121', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '湯の山', 'ユノヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市末町', '38', '38201', '7910122', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '末町', 'スエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市宿野町', '38', '38201', '7910123', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '宿野町', 'シュクノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市青波町', '38', '38201', '7910124', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '青波町', 'アオナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市湯山柳', '38', '38201', '7910125', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '湯山柳', 'ユヤマヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市玉谷町', '38', '38201', '7910126', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '玉谷町', 'タマタニマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市藤野町', '38', '38201', '7910127', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '藤野町', 'フジノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市福見川町', '38', '38201', '7910128', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '福見川町', 'フクミガワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市川の郷町', '38', '38201', '7910129', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '川の郷町', 'カワノゴウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市水口町', '38', '38201', '7910131', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '水口町', 'ミナクチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市河中町', '38', '38201', '7910132', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '河中町', 'カワナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市東川町', '38', '38201', '7910133', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '東川町', 'ヒガシガワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市大井野町', '38', '38201', '7910134', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '大井野町', 'オオイノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市米野町', '38', '38201', '7910135', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '米野町', 'コメノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市九川', '38', '38201', '7910150', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '九川', 'クガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県東温市', '38', '38215', '7910200', '愛媛県', 'エヒメケン', '東温市', 'トウオンシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('100629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県東温市山之内', '38', '38215', '7910201', '愛媛県', 'エヒメケン', '東温市', 'トウオンシ', '山之内', 'ヤマノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県東温市樋口', '38', '38215', '7910202', '愛媛県', 'エヒメケン', '東温市', 'トウオンシ', '樋口', 'ヒノクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県東温市横河原', '38', '38215', '7910203', '愛媛県', 'エヒメケン', '東温市', 'トウオンシ', '横河原', 'ヨコガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県東温市志津川', '38', '38215', '7910204', '愛媛県', 'エヒメケン', '東温市', 'トウオンシ', '志津川', 'シツカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県東温市西岡', '38', '38215', '7910205', '愛媛県', 'エヒメケン', '東温市', 'トウオンシ', '西岡', 'ニシオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県東温市見奈良', '38', '38215', '7910211', '愛媛県', 'エヒメケン', '東温市', 'トウオンシ', '見奈良', 'ミナラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県東温市田窪', '38', '38215', '7910212', '愛媛県', 'エヒメケン', '東温市', 'トウオンシ', '田窪', 'タノクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県東温市牛渕', '38', '38215', '7910213', '愛媛県', 'エヒメケン', '東温市', 'トウオンシ', '牛渕', 'ウシブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県東温市南野田', '38', '38215', '7910214', '愛媛県', 'エヒメケン', '東温市', 'トウオンシ', '南野田', 'ミナミノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県東温市北野田', '38', '38215', '7910215', '愛媛県', 'エヒメケン', '東温市', 'トウオンシ', '北野田', 'キタノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県東温市野田', '38', '38215', '7910216', '愛媛県', 'エヒメケン', '東温市', 'トウオンシ', '野田', 'ノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県東温市上村', '38', '38215', '7910221', '愛媛県', 'エヒメケン', '東温市', 'トウオンシ', '上村', 'ウエムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県東温市下林', '38', '38215', '7910222', '愛媛県', 'エヒメケン', '東温市', 'トウオンシ', '下林', 'シモバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県東温市上林', '38', '38215', '7910223', '愛媛県', 'エヒメケン', '東温市', 'トウオンシ', '上林', 'カミバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市小野町', '38', '38201', '7910241', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '小野町', 'オノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市北梅本町', '38', '38201', '7910242', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '北梅本町', 'キタウメモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市平井町', '38', '38201', '7910243', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '平井町', 'ヒライマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市水泥町', '38', '38201', '7910244', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '水泥町', 'ミドロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市南梅本町', '38', '38201', '7910245', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '南梅本町', 'ミナミウメモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県東温市南方', '38', '38215', '7910301', '愛媛県', 'エヒメケン', '東温市', 'トウオンシ', '南方', 'ミナミガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県東温市吉久', '38', '38215', '7910302', '愛媛県', 'エヒメケン', '東温市', 'トウオンシ', '吉久', 'ヨシヒサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県東温市北方', '38', '38215', '7910303', '愛媛県', 'エヒメケン', '東温市', 'トウオンシ', '北方', 'キタガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県東温市則之内甲', '38', '38215', '7910311', '愛媛県', 'エヒメケン', '東温市', 'トウオンシ', '則之内甲', 'スノウチコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県東温市則之内乙', '38', '38215', '7910312', '愛媛県', 'エヒメケン', '東温市', 'トウオンシ', '則之内乙', 'スノウチオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県東温市則之内丙', '38', '38215', '7910313', '愛媛県', 'エヒメケン', '東温市', 'トウオンシ', '則之内丙', 'スノウチヘイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県東温市松瀬川', '38', '38215', '7910314', '愛媛県', 'エヒメケン', '東温市', 'トウオンシ', '松瀬川', 'マセカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県東温市井内', '38', '38215', '7910315', '愛媛県', 'エヒメケン', '東温市', 'トウオンシ', '井内', 'イウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県東温市河之内', '38', '38215', '7910321', '愛媛県', 'エヒメケン', '東温市', 'トウオンシ', '河之内', 'カワノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県東温市滑川', '38', '38215', '7910322', '愛媛県', 'エヒメケン', '東温市', 'トウオンシ', '滑川', 'ナメガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県東温市明河', '38', '38215', '7910323', '愛媛県', 'エヒメケン', '東温市', 'トウオンシ', '明河', 'ミョウガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市丹原町徳能出作', '38', '38206', '7910501', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '丹原町徳能出作', 'タンバラチョウトクノデサク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市丹原町願連寺', '38', '38206', '7910502', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '丹原町願連寺', 'タンバラチョウガンレンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市丹原町今井', '38', '38206', '7910503', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '丹原町今井', 'タンバラチョウイマイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市丹原町久妙寺', '38', '38206', '7910504', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '丹原町久妙寺', 'タンバラチョウクミョウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市丹原町古田', '38', '38206', '7910505', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '丹原町古田', 'タンバラチョウコタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市丹原町徳能', '38', '38206', '7910506', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '丹原町徳能', 'タンバラチョウトクノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市丹原町高知', '38', '38206', '7910507', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '丹原町高知', 'タンバラチョウコウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市丹原町池田', '38', '38206', '7910508', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '丹原町池田', 'タンバラチョウイケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市丹原町丹原', '38', '38206', '7910510', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '丹原町丹原', 'タンバラチョウタンバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市丹原町長野', '38', '38206', '7910521', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '丹原町長野', 'タンバラチョウナガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市丹原町田野上方', '38', '38206', '7910522', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '丹原町田野上方', 'タンバラチョウタノウワガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市丹原町北田野', '38', '38206', '7910523', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '丹原町北田野', 'タンバラチョウキタタノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市丹原町高松', '38', '38206', '7910524', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '丹原町高松', 'タンバラチョウタカマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市丹原町川根', '38', '38206', '7910525', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '丹原町川根', 'タンバラチョウカワネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市丹原町田滝', '38', '38206', '7910526', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '丹原町田滝', 'タンバラチョウタタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市丹原町関屋', '38', '38206', '7910527', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '丹原町関屋', 'タンバラチョウセキヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市丹原町来見', '38', '38206', '7910531', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '丹原町来見', 'タンバラチョウクルミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市丹原町石経', '38', '38206', '7910532', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '丹原町石経', 'タンバラチョウイシキョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市丹原町明穂', '38', '38206', '7910533', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '丹原町明穂', 'タンバラチョウアカオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市丹原町寺尾', '38', '38206', '7910534', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '丹原町寺尾', 'タンバラチョウテラオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市丹原町志川', '38', '38206', '7910535', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '丹原町志川', 'タンバラチョウシカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市丹原町湯谷口', '38', '38206', '7910536', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '丹原町湯谷口', 'タンバラチョウユヤグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市丹原町臼坂', '38', '38206', '7910537', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '丹原町臼坂', 'タンバラチョウウスザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市丹原町千原', '38', '38206', '7910538', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '丹原町千原', 'タンバラチョウチハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市丹原町鞍瀬', '38', '38206', '7910541', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '丹原町鞍瀬', 'タンバラチョウクラセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市丹原町楠窪', '38', '38206', '7910542', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '丹原町楠窪', 'タンバラチョウクスクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市丹原町明河', '38', '38206', '7910543', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '丹原町明河', 'タンバラチョウミョウガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市小松町石鎚上戸石', '38', '38206', '7910562', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '小松町石鎚', 'コマツチョウイシヅチ', null, null, '上戸石', 'カミトイシ');
INSERT INTO `ms_addresses` VALUES ('100701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道赤平市', '01', '01218', '0791100', '北海道', 'ホッカイドウ', '赤平市', 'アカビラシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('100702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道赤平市共和町', '01', '01218', '0791101', '北海道', 'ホッカイドウ', '赤平市', 'アカビラシ', '共和町', 'キョウワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道赤平市幌岡町', '01', '01218', '0791102', '北海道', 'ホッカイドウ', '赤平市', 'アカビラシ', '幌岡町', 'ホロオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市久米窪田町', '38', '38201', '7911101', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '久米窪田町', 'クメクボタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市来住町', '38', '38201', '7911102', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '来住町', 'キシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市今在家町', '38', '38201', '7911103', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '今在家町', 'イマザイケマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市北土居', '38', '38201', '7911104', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '北土居', 'キタドイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市北井門', '38', '38201', '7911105', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '北井門', 'キタイド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市今在家', '38', '38201', '7911106', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '今在家', 'イマザイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道赤平市若木町北', '01', '01218', '0791111', '北海道', 'ホッカイドウ', '赤平市', 'アカビラシ', '若木町北', 'ワカキチョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市高井町', '38', '38201', '7911111', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '高井町', 'タカイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市南高井町', '38', '38201', '7911112', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '南高井町', 'ミナミタカイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市森松町', '38', '38201', '7911113', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '森松町', 'モリマツマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市井門町', '38', '38201', '7911114', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '井門町', 'イドマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市土居町', '38', '38201', '7911115', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '土居町', 'ドイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市南土居町', '38', '38201', '7911116', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '南土居町', 'ミナミドイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道赤平市若木町西', '01', '01218', '0791112', '北海道', 'ホッカイドウ', '赤平市', 'アカビラシ', '若木町西', 'ワカキチョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市中野町', '38', '38201', '7911121', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '中野町', 'ナカノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市津吉町', '38', '38201', '7911122', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '津吉町', 'ツヨシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市東方町', '38', '38201', '7911123', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '東方町', 'ヒガシガタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市上川原町', '38', '38201', '7911124', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '上川原町', 'カミガワラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市小村町', '38', '38201', '7911125', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '小村町', 'コムラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市大橋町', '38', '38201', '7911126', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '大橋町', 'オオハシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道赤平市若木町東', '01', '01218', '0791113', '北海道', 'ホッカイドウ', '赤平市', 'アカビラシ', '若木町東', 'ワカキチョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市窪野町', '38', '38201', '7911131', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '窪野町', 'クボノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市久谷町', '38', '38201', '7911132', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '久谷町', 'クタニマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市浄瑠璃町', '38', '38201', '7911133', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '浄瑠璃町', 'ジョウルリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市恵原町', '38', '38201', '7911134', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '恵原町', 'エバラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市西野町', '38', '38201', '7911135', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '西野町', 'ニシノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市上野町', '38', '38201', '7911136', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '上野町', 'ウエノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道赤平市若木町南', '01', '01218', '0791114', '北海道', 'ホッカイドウ', '赤平市', 'アカビラシ', '若木町南', 'ワカキチョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県上浮穴郡久万高原町', '38', '38386', '7911200', '愛媛県', 'エヒメケン', '上浮穴郡久万高原町', 'カミウケナグンクマコウゲンチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('100736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県上浮穴郡久万高原町久万', '38', '38386', '7911201', '愛媛県', 'エヒメケン', '上浮穴郡久万高原町', 'カミウケナグンクマコウゲンチョウ', '久万', 'クマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県上浮穴郡久万高原町入野', '38', '38386', '7911202', '愛媛県', 'エヒメケン', '上浮穴郡久万高原町', 'カミウケナグンクマコウゲンチョウ', '入野', 'イリノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県上浮穴郡久万高原町西明神', '38', '38386', '7911203', '愛媛県', 'エヒメケン', '上浮穴郡久万高原町', 'カミウケナグンクマコウゲンチョウ', '西明神', 'ニシミョウジン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県上浮穴郡久万高原町東明神', '38', '38386', '7911204', '愛媛県', 'エヒメケン', '上浮穴郡久万高原町', 'カミウケナグンクマコウゲンチョウ', '東明神', 'ヒガシミョウジン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県上浮穴郡久万高原町菅生', '38', '38386', '7911205', '愛媛県', 'エヒメケン', '上浮穴郡久万高原町', 'カミウケナグンクマコウゲンチョウ', '菅生', 'スゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県上浮穴郡久万高原町上野尻', '38', '38386', '7911206', '愛媛県', 'エヒメケン', '上浮穴郡久万高原町', 'カミウケナグンクマコウゲンチョウ', '上野尻', 'カミノジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県上浮穴郡久万高原町下野尻', '38', '38386', '7911207', '愛媛県', 'エヒメケン', '上浮穴郡久万高原町', 'カミウケナグンクマコウゲンチョウ', '下野尻', 'シモノジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道赤平市北文京町', '01', '01218', '0791121', '北海道', 'ホッカイドウ', '赤平市', 'アカビラシ', '北文京町', 'キタブンキョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県上浮穴郡久万高原町上畑野川', '38', '38386', '7911211', '愛媛県', 'エヒメケン', '上浮穴郡久万高原町', 'カミウケナグンクマコウゲンチョウ', '上畑野川', 'カミハタノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県上浮穴郡久万高原町下畑野川', '38', '38386', '7911212', '愛媛県', 'エヒメケン', '上浮穴郡久万高原町', 'カミウケナグンクマコウゲンチョウ', '下畑野川', 'シモハタノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県上浮穴郡久万高原町直瀬', '38', '38386', '7911213', '愛媛県', 'エヒメケン', '上浮穴郡久万高原町', 'カミウケナグンクマコウゲンチョウ', '直瀬', 'ナオセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道赤平市西文京町', '01', '01218', '0791122', '北海道', 'ホッカイドウ', '赤平市', 'アカビラシ', '西文京町', 'ニシブンキョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県上浮穴郡久万高原町露峰', '38', '38386', '7911221', '愛媛県', 'エヒメケン', '上浮穴郡久万高原町', 'カミウケナグンクマコウゲンチョウ', '露峰', 'ツユミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県上浮穴郡久万高原町二名', '38', '38386', '7911222', '愛媛県', 'エヒメケン', '上浮穴郡久万高原町', 'カミウケナグンクマコウゲンチョウ', '二名', 'ニミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県上浮穴郡久万高原町父野川', '38', '38386', '7911223', '愛媛県', 'エヒメケン', '上浮穴郡久万高原町', 'カミウケナグンクマコウゲンチョウ', '父野川', 'チチノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道赤平市東文京町', '01', '01218', '0791123', '北海道', 'ホッカイドウ', '赤平市', 'アカビラシ', '東文京町', 'ヒガシブンキョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道赤平市豊丘町', '01', '01218', '0791124', '北海道', 'ホッカイドウ', '赤平市', 'アカビラシ', '豊丘町', 'トヨオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道赤平市西豊里町', '01', '01218', '0791131', '北海道', 'ホッカイドウ', '赤平市', 'アカビラシ', '西豊里町', 'ニシトヨサトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道赤平市東豊里町', '01', '01218', '0791132', '北海道', 'ホッカイドウ', '赤平市', 'アカビラシ', '東豊里町', 'ヒガシトヨサトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道赤平市豊里', '01', '01218', '0791133', '北海道', 'ホッカイドウ', '赤平市', 'アカビラシ', '豊里', 'トヨサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道赤平市泉町', '01', '01218', '0791134', '北海道', 'ホッカイドウ', '赤平市', 'アカビラシ', '泉町', 'イズミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道赤平市錦町', '01', '01218', '0791135', '北海道', 'ホッカイドウ', '赤平市', 'アカビラシ', '錦町', 'ニシキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道赤平市本町', '01', '01218', '0791136', '北海道', 'ホッカイドウ', '赤平市', 'アカビラシ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道赤平市大町', '01', '01218', '0791141', '北海道', 'ホッカイドウ', '赤平市', 'アカビラシ', '大町', 'オオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道赤平市東大町', '01', '01218', '0791142', '北海道', 'ホッカイドウ', '赤平市', 'アカビラシ', '東大町', 'ヒガシオオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道赤平市赤平', '01', '01218', '0791143', '北海道', 'ホッカイドウ', '赤平市', 'アカビラシ', '赤平', 'アカビラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道赤平市美園町', '01', '01218', '0791144', '北海道', 'ホッカイドウ', '赤平市', 'アカビラシ', '美園町', 'ミソノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県上浮穴郡久万高原町上黒岩', '38', '38386', '7911501', '愛媛県', 'エヒメケン', '上浮穴郡久万高原町', 'カミウケナグンクマコウゲンチョウ', '上黒岩', 'カミクロイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県上浮穴郡久万高原町中黒岩', '38', '38386', '7911502', '愛媛県', 'エヒメケン', '上浮穴郡久万高原町', 'カミウケナグンクマコウゲンチョウ', '中黒岩', 'ナカクロイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県上浮穴郡久万高原町日野浦', '38', '38386', '7911503', '愛媛県', 'エヒメケン', '上浮穴郡久万高原町', 'カミウケナグンクマコウゲンチョウ', '日野浦', 'ヒノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県上浮穴郡久万高原町大川', '38', '38386', '7911504', '愛媛県', 'エヒメケン', '上浮穴郡久万高原町', 'カミウケナグンクマコウゲンチョウ', '大川', 'オオガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県上浮穴郡久万高原町有枝', '38', '38386', '7911505', '愛媛県', 'エヒメケン', '上浮穴郡久万高原町', 'カミウケナグンクマコウゲンチョウ', '有枝', 'アリエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道赤平市宮下町', '01', '01218', '0791151', '北海道', 'ホッカイドウ', '赤平市', 'アカビラシ', '宮下町', 'ミヤシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県上浮穴郡久万高原町七鳥', '38', '38386', '7911511', '愛媛県', 'エヒメケン', '上浮穴郡久万高原町', 'カミウケナグンクマコウゲンチョウ', '七鳥', 'ナナトリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県上浮穴郡久万高原町東川', '38', '38386', '7911512', '愛媛県', 'エヒメケン', '上浮穴郡久万高原町', 'カミウケナグンクマコウゲンチョウ', '東川', 'ヒガシガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県上浮穴郡久万高原町仕出', '38', '38386', '7911513', '愛媛県', 'エヒメケン', '上浮穴郡久万高原町', 'カミウケナグンクマコウゲンチョウ', '仕出', 'シデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県上浮穴郡久万高原町沢渡', '38', '38386', '7911514', '愛媛県', 'エヒメケン', '上浮穴郡久万高原町', 'カミウケナグンクマコウゲンチョウ', '沢渡', 'サワタリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県上浮穴郡久万高原町黒藤川', '38', '38386', '7911515', '愛媛県', 'エヒメケン', '上浮穴郡久万高原町', 'カミウケナグンクマコウゲンチョウ', '黒藤川', 'クロフジガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道赤平市桜木町', '01', '01218', '0791152', '北海道', 'ホッカイドウ', '赤平市', 'アカビラシ', '桜木町', 'サクラギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道赤平市豊栄町', '01', '01218', '0791153', '北海道', 'ホッカイドウ', '赤平市', 'アカビラシ', '豊栄町', 'ホウエイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道赤平市幸町', '01', '01218', '0791154', '北海道', 'ホッカイドウ', '赤平市', 'アカビラシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道赤平市昭和町', '01', '01218', '0791155', '北海道', 'ホッカイドウ', '赤平市', 'アカビラシ', '昭和町', 'ショウワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道赤平市住吉町', '01', '01218', '0791156', '北海道', 'ホッカイドウ', '赤平市', 'アカビラシ', '住吉町', 'スミヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県上浮穴郡久万高原町渋草', '38', '38386', '7911701', '愛媛県', 'エヒメケン', '上浮穴郡久万高原町', 'カミウケナグンクマコウゲンチョウ', '渋草', 'シブクサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県上浮穴郡久万高原町大成', '38', '38386', '7911702', '愛媛県', 'エヒメケン', '上浮穴郡久万高原町', 'カミウケナグンクマコウゲンチョウ', '大成', 'オオナル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県上浮穴郡久万高原町笠方', '38', '38386', '7911703', '愛媛県', 'エヒメケン', '上浮穴郡久万高原町', 'カミウケナグンクマコウゲンチョウ', '笠方', 'カサガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県上浮穴郡久万高原町前組', '38', '38386', '7911704', '愛媛県', 'エヒメケン', '上浮穴郡久万高原町', 'カミウケナグンクマコウゲンチョウ', '前組', 'マエグミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県上浮穴郡久万高原町相の峰', '38', '38386', '7911705', '愛媛県', 'エヒメケン', '上浮穴郡久万高原町', 'カミウケナグンクマコウゲンチョウ', '相の峰', 'アイノミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県上浮穴郡久万高原町本組', '38', '38386', '7911706', '愛媛県', 'エヒメケン', '上浮穴郡久万高原町', 'カミウケナグンクマコウゲンチョウ', '本組', 'ホングミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県上浮穴郡久万高原町中組', '38', '38386', '7911707', '愛媛県', 'エヒメケン', '上浮穴郡久万高原町', 'カミウケナグンクマコウゲンチョウ', '中組', 'ナカグミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県上浮穴郡久万高原町河の子', '38', '38386', '7911708', '愛媛県', 'エヒメケン', '上浮穴郡久万高原町', 'カミウケナグンクマコウゲンチョウ', '河の子', 'コウノコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県上浮穴郡久万高原町相の木', '38', '38386', '7911709', '愛媛県', 'エヒメケン', '上浮穴郡久万高原町', 'カミウケナグンクマコウゲンチョウ', '相の木', 'アイノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県上浮穴郡久万高原町若山', '38', '38386', '7911710', '愛媛県', 'エヒメケン', '上浮穴郡久万高原町', 'カミウケナグンクマコウゲンチョウ', '若山', 'ワカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県上浮穴郡久万高原町柳井川', '38', '38386', '7911801', '愛媛県', 'エヒメケン', '上浮穴郡久万高原町', 'カミウケナグンクマコウゲンチョウ', '柳井川', 'ヤナイガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県上浮穴郡久万高原町西谷', '38', '38386', '7911802', '愛媛県', 'エヒメケン', '上浮穴郡久万高原町', 'カミウケナグンクマコウゲンチョウ', '西谷', 'ニシダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県上浮穴郡久万高原町中津', '38', '38386', '7911803', '愛媛県', 'エヒメケン', '上浮穴郡久万高原町', 'カミウケナグンクマコウゲンチョウ', '中津', 'ナカツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道砂川市富平', '01', '01226', '0791181', '北海道', 'ホッカイドウ', '砂川市', 'スナガワシ', '富平', 'トミヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県伊予郡砥部町', '38', '38402', '7912100', '愛媛県', 'エヒメケン', '伊予郡砥部町', 'イヨグントベチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('100796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県伊予郡砥部町高尾田', '38', '38402', '7912101', '愛媛県', 'エヒメケン', '伊予郡砥部町', 'イヨグントベチョウ', '高尾田', 'タコウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県伊予郡砥部町高尾田砥部団地', '38', '38402', '7912102', '愛媛県', 'エヒメケン', '伊予郡砥部町', 'イヨグントベチョウ', '高尾田', 'タコウダ', null, null, '砥部団地', 'トベダンチ');
INSERT INTO `ms_addresses` VALUES ('100798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県伊予郡砥部町高尾田上野団地', '38', '38402', '7912103', '愛媛県', 'エヒメケン', '伊予郡砥部町', 'イヨグントベチョウ', '高尾田', 'タコウダ', null, null, '上野団地', 'ウエノダンチ');
INSERT INTO `ms_addresses` VALUES ('100799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県伊予郡砥部町八倉', '38', '38402', '7912111', '愛媛県', 'エヒメケン', '伊予郡砥部町', 'イヨグントベチョウ', '八倉', 'ヤクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県伊予郡砥部町重光', '38', '38402', '7912112', '愛媛県', 'エヒメケン', '伊予郡砥部町', 'イヨグントベチョウ', '重光', 'シゲミツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県伊予郡砥部町拾町', '38', '38402', '7912113', '愛媛県', 'エヒメケン', '伊予郡砥部町', 'イヨグントベチョウ', '拾町', 'ジツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県伊予郡砥部町麻生', '38', '38402', '7912114', '愛媛県', 'エヒメケン', '伊予郡砥部町', 'イヨグントベチョウ', '麻生', 'アソウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県伊予郡砥部町三角', '38', '38402', '7912115', '愛媛県', 'エヒメケン', '伊予郡砥部町', 'イヨグントベチョウ', '三角', 'ミョウカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県伊予郡砥部町原町', '38', '38402', '7912116', '愛媛県', 'エヒメケン', '伊予郡砥部町', 'イヨグントベチョウ', '原町', 'ハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県伊予郡砥部町上原町', '38', '38402', '7912117', '愛媛県', 'エヒメケン', '伊予郡砥部町', 'イヨグントベチョウ', '上原町', 'カミハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県伊予郡砥部町宮内', '38', '38402', '7912120', '愛媛県', 'エヒメケン', '伊予郡砥部町', 'イヨグントベチョウ', '宮内', 'ミヤウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県伊予郡砥部町宮内山並', '38', '38402', '7912121', '愛媛県', 'エヒメケン', '伊予郡砥部町', 'イヨグントベチョウ', '宮内', 'ミヤウチ', null, null, '山並', 'ヤマナミ');
INSERT INTO `ms_addresses` VALUES ('100808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県伊予郡砥部町千足', '38', '38402', '7912122', '愛媛県', 'エヒメケン', '伊予郡砥部町', 'イヨグントベチョウ', '千足', 'センゾク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県伊予郡砥部町川井', '38', '38402', '7912123', '愛媛県', 'エヒメケン', '伊予郡砥部町', 'イヨグントベチョウ', '川井', 'カワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県伊予郡砥部町田ノ浦', '38', '38402', '7912124', '愛媛県', 'エヒメケン', '伊予郡砥部町', 'イヨグントベチョウ', '田ノ浦', 'タノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県伊予郡砥部町七折', '38', '38402', '7912125', '愛媛県', 'エヒメケン', '伊予郡砥部町', 'イヨグントベチョウ', '七折', 'ナナオレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県伊予郡砥部町大角蔵', '38', '38402', '7912126', '愛媛県', 'エヒメケン', '伊予郡砥部町', 'イヨグントベチョウ', '大角蔵', 'オオカクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県伊予郡砥部町北川毛', '38', '38402', '7912131', '愛媛県', 'エヒメケン', '伊予郡砥部町', 'イヨグントベチョウ', '北川毛', 'キタカワゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県伊予郡砥部町大南', '38', '38402', '7912132', '愛媛県', 'エヒメケン', '伊予郡砥部町', 'イヨグントベチョウ', '大南', 'オオミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県伊予郡砥部町五本松', '38', '38402', '7912133', '愛媛県', 'エヒメケン', '伊予郡砥部町', 'イヨグントベチョウ', '五本松', 'ゴホンマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県伊予郡砥部町外山', '38', '38402', '7912134', '愛媛県', 'エヒメケン', '伊予郡砥部町', 'イヨグントベチョウ', '外山', 'トヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県伊予郡砥部町鵜ノ崎', '38', '38402', '7912135', '愛媛県', 'エヒメケン', '伊予郡砥部町', 'イヨグントベチョウ', '鵜ノ崎', 'ウノサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県伊予郡砥部町岩谷口', '38', '38402', '7912141', '愛媛県', 'エヒメケン', '伊予郡砥部町', 'イヨグントベチョウ', '岩谷口', 'イワヤグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県伊予郡砥部町岩谷', '38', '38402', '7912142', '愛媛県', 'エヒメケン', '伊予郡砥部町', 'イヨグントベチョウ', '岩谷', 'イワヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県伊予郡砥部町川登', '38', '38402', '7912143', '愛媛県', 'エヒメケン', '伊予郡砥部町', 'イヨグントベチョウ', '川登', 'カワノボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県伊予郡砥部町万年', '38', '38402', '7912144', '愛媛県', 'エヒメケン', '伊予郡砥部町', 'イヨグントベチョウ', '万年', 'マンネン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県伊予郡砥部町大平', '38', '38402', '7912145', '愛媛県', 'エヒメケン', '伊予郡砥部町', 'イヨグントベチョウ', '大平', 'オオヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県伊予郡砥部町満穂', '38', '38402', '7912201', '愛媛県', 'エヒメケン', '伊予郡砥部町', 'イヨグントベチョウ', '満穂', 'ミツホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県伊予郡砥部町玉谷', '38', '38402', '7912202', '愛媛県', 'エヒメケン', '伊予郡砥部町', 'イヨグントベチョウ', '玉谷', 'タマタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県伊予郡砥部町中野川', '38', '38402', '7912203', '愛媛県', 'エヒメケン', '伊予郡砥部町', 'イヨグントベチョウ', '中野川', 'ナカノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県伊予郡砥部町高市', '38', '38402', '7912204', '愛媛県', 'エヒメケン', '伊予郡砥部町', 'イヨグントベチョウ', '高市', 'タカイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県伊予郡砥部町総津', '38', '38402', '7912205', '愛媛県', 'エヒメケン', '伊予郡砥部町', 'イヨグントベチョウ', '総津', 'ソウヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県伊予郡砥部町多居谷', '38', '38402', '7912206', '愛媛県', 'エヒメケン', '伊予郡砥部町', 'イヨグントベチョウ', '多居谷', 'オオイダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県伊予郡砥部町仙波', '38', '38402', '7912207', '愛媛県', 'エヒメケン', '伊予郡砥部町', 'イヨグントベチョウ', '仙波', 'センバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道赤平市茂尻中央町北', '01', '01218', '0791261', '北海道', 'ホッカイドウ', '赤平市', 'アカビラシ', '茂尻中央町北', 'モジリチュウオウチョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道赤平市茂尻中央町南', '01', '01218', '0791261', '北海道', 'ホッカイドウ', '赤平市', 'アカビラシ', '茂尻中央町南', 'モジリチュウオウチョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道赤平市茂尻春日町', '01', '01218', '0791262', '北海道', 'ホッカイドウ', '赤平市', 'アカビラシ', '茂尻春日町', 'モジリカスガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道赤平市茂尻新春日町', '01', '01218', '0791262', '北海道', 'ホッカイドウ', '赤平市', 'アカビラシ', '茂尻新春日町', 'モジリシンカスガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道赤平市茂尻本町', '01', '01218', '0791263', '北海道', 'ホッカイドウ', '赤平市', 'アカビラシ', '茂尻本町', 'モジリホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道赤平市茂尻旭町', '01', '01218', '0791264', '北海道', 'ホッカイドウ', '赤平市', 'アカビラシ', '茂尻旭町', 'モジリアサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道赤平市茂尻宮下町', '01', '01218', '0791264', '北海道', 'ホッカイドウ', '赤平市', 'アカビラシ', '茂尻宮下町', 'モジリミヤシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道赤平市茂尻新町', '01', '01218', '0791265', '北海道', 'ホッカイドウ', '赤平市', 'アカビラシ', '茂尻新町', 'モジリシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道赤平市茂尻', '01', '01218', '0791266', '北海道', 'ホッカイドウ', '赤平市', 'アカビラシ', '茂尻', 'モジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道赤平市茂尻栄町', '01', '01218', '0791266', '北海道', 'ホッカイドウ', '赤平市', 'アカビラシ', '茂尻栄町', 'モジリサカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道赤平市茂尻元町南', '01', '01218', '0791267', '北海道', 'ホッカイドウ', '赤平市', 'アカビラシ', '茂尻元町南', 'モジリモトマチミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道赤平市茂尻元町北', '01', '01218', '0791268', '北海道', 'ホッカイドウ', '赤平市', 'アカビラシ', '茂尻元町北', 'モジリモトマチキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道赤平市百戸町北', '01', '01218', '0791271', '北海道', 'ホッカイドウ', '赤平市', 'アカビラシ', '百戸町北', 'ヒャッコチョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道赤平市百戸町東', '01', '01218', '0791272', '北海道', 'ホッカイドウ', '赤平市', 'アカビラシ', '百戸町東', 'ヒャッコチョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道赤平市百戸町西', '01', '01218', '0791273', '北海道', 'ホッカイドウ', '赤平市', 'アカビラシ', '百戸町西', 'ヒャッコチョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道赤平市エルム町', '01', '01218', '0791274', '北海道', 'ホッカイドウ', '赤平市', 'アカビラシ', 'エルム町', 'エルムチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道赤平市平岸新光町', '01', '01218', '0791281', '北海道', 'ホッカイドウ', '赤平市', 'アカビラシ', '平岸新光町', 'ヒラギシシンコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道赤平市平岸仲町', '01', '01218', '0791282', '北海道', 'ホッカイドウ', '赤平市', 'アカビラシ', '平岸仲町', 'ヒラギシナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道赤平市平岸東町', '01', '01218', '0791283', '北海道', 'ホッカイドウ', '赤平市', 'アカビラシ', '平岸東町', 'ヒラギシヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道赤平市平岸南町', '01', '01218', '0791284', '北海道', 'ホッカイドウ', '赤平市', 'アカビラシ', '平岸南町', 'ヒラギシミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道赤平市平岸曙町', '01', '01218', '0791285', '北海道', 'ホッカイドウ', '赤平市', 'アカビラシ', '平岸曙町', 'ヒラギシアケボノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道赤平市平岸西町', '01', '01218', '0791286', '北海道', 'ホッカイドウ', '赤平市', 'アカビラシ', '平岸西町', 'ヒラギシニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道赤平市平岸桂町', '01', '01218', '0791287', '北海道', 'ホッカイドウ', '赤平市', 'アカビラシ', '平岸桂町', 'ヒラギシカツラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県伊予郡松前町', '38', '38401', '7913100', '愛媛県', 'エヒメケン', '伊予郡松前町', 'イヨグンマサキチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('100857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県伊予郡松前町南黒田', '38', '38401', '7913101', '愛媛県', 'エヒメケン', '伊予郡松前町', 'イヨグンマサキチョウ', '南黒田', 'ミナミクロダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県伊予郡松前町北黒田', '38', '38401', '7913102', '愛媛県', 'エヒメケン', '伊予郡松前町', 'イヨグンマサキチョウ', '北黒田', 'キタクロダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県伊予郡松前町浜', '38', '38401', '7913110', '愛媛県', 'エヒメケン', '伊予郡松前町', 'イヨグンマサキチョウ', '浜', 'ハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県伊予郡松前町筒井', '38', '38401', '7913120', '愛媛県', 'エヒメケン', '伊予郡松前町', 'イヨグンマサキチョウ', '筒井', 'ツツイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県伊予郡松前町北川原', '38', '38401', '7913131', '愛媛県', 'エヒメケン', '伊予郡松前町', 'イヨグンマサキチョウ', '北川原', 'キタガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県伊予郡松前町西高柳', '38', '38401', '7913132', '愛媛県', 'エヒメケン', '伊予郡松前町', 'イヨグンマサキチョウ', '西高柳', 'ニシタカヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県伊予郡松前町昌農内', '38', '38401', '7913133', '愛媛県', 'エヒメケン', '伊予郡松前町', 'イヨグンマサキチョウ', '昌農内', 'ショウノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県伊予郡松前町西古泉', '38', '38401', '7913134', '愛媛県', 'エヒメケン', '伊予郡松前町', 'イヨグンマサキチョウ', '西古泉', 'ニシコイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県伊予郡松前町恵久美', '38', '38401', '7913141', '愛媛県', 'エヒメケン', '伊予郡松前町', 'イヨグンマサキチョウ', '恵久美', 'エクビ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県伊予郡松前町上高柳', '38', '38401', '7913142', '愛媛県', 'エヒメケン', '伊予郡松前町', 'イヨグンマサキチョウ', '上高柳', 'カミタカヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県伊予郡松前町大間', '38', '38401', '7913143', '愛媛県', 'エヒメケン', '伊予郡松前町', 'イヨグンマサキチョウ', '大間', 'ダイマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県伊予郡松前町東古泉', '38', '38401', '7913151', '愛媛県', 'エヒメケン', '伊予郡松前町', 'イヨグンマサキチョウ', '東古泉', 'ヒガシコイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県伊予郡松前町永田', '38', '38401', '7913152', '愛媛県', 'エヒメケン', '伊予郡松前町', 'イヨグンマサキチョウ', '永田', 'ナガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県伊予郡松前町大溝', '38', '38401', '7913153', '愛媛県', 'エヒメケン', '伊予郡松前町', 'イヨグンマサキチョウ', '大溝', 'オオミゾ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県伊予郡松前町横田', '38', '38401', '7913154', '愛媛県', 'エヒメケン', '伊予郡松前町', 'イヨグンマサキチョウ', '横田', 'ヨコタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県伊予郡松前町鶴吉', '38', '38401', '7913155', '愛媛県', 'エヒメケン', '伊予郡松前町', 'イヨグンマサキチョウ', '鶴吉', 'ツルヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県伊予郡松前町神崎', '38', '38401', '7913161', '愛媛県', 'エヒメケン', '伊予郡松前町', 'イヨグンマサキチョウ', '神崎', 'カンザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県伊予郡松前町出作', '38', '38401', '7913162', '愛媛県', 'エヒメケン', '伊予郡松前町', 'イヨグンマサキチョウ', '出作', 'シュツサク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県伊予郡松前町徳丸', '38', '38401', '7913163', '愛媛県', 'エヒメケン', '伊予郡松前町', 'イヨグンマサキチョウ', '徳丸', 'トクマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県伊予郡松前町中川原', '38', '38401', '7913164', '愛媛県', 'エヒメケン', '伊予郡松前町', 'イヨグンマサキチョウ', '中川原', 'ナカガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県伊予市中山町佐礼谷', '38', '38210', '7913201', '愛媛県', 'エヒメケン', '伊予市', 'イヨシ', '中山町佐礼谷', 'ナカヤマチョウサレタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県伊予市中山町栗田', '38', '38210', '7913202', '愛媛県', 'エヒメケン', '伊予市', 'イヨシ', '中山町栗田', 'ナカヤマチョウクリダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県伊予市中山町出渕', '38', '38210', '7913203', '愛媛県', 'エヒメケン', '伊予市', 'イヨシ', '中山町出渕', 'ナカヤマチョウイズブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県伊予市中山町出渕', '38', '38210', '7913204', '愛媛県', 'エヒメケン', '伊予市', 'イヨシ', '中山町出渕', 'ナカヤマチョウイズブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県伊予市中山町中山泉町', '38', '38210', '7913205', '愛媛県', 'エヒメケン', '伊予市', 'イヨシ', '中山町中山', 'ナカヤマチョウナカヤマ', null, null, '泉町', 'イズミマチ');
INSERT INTO `ms_addresses` VALUES ('100889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県伊予市中山町中山', '38', '38210', '7913206', '愛媛県', 'エヒメケン', '伊予市', 'イヨシ', '中山町中山', 'ナカヤマチョウナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県喜多郡内子町', '38', '38422', '7913300', '愛媛県', 'エヒメケン', '喜多郡内子町', 'キタグンウチコチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('100894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県喜多郡内子町内子', '38', '38422', '7913301', '愛媛県', 'エヒメケン', '喜多郡内子町', 'キタグンウチコチョウ', '内子', 'ウチコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県喜多郡内子町城廻', '38', '38422', '7913310', '愛媛県', 'エヒメケン', '喜多郡内子町', 'キタグンウチコチョウ', '城廻', 'シロマワリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県喜多郡内子町川中', '38', '38422', '7913321', '愛媛県', 'エヒメケン', '喜多郡内子町', 'キタグンウチコチョウ', '川中', 'カワナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県喜多郡内子町知清', '38', '38422', '7913322', '愛媛県', 'エヒメケン', '喜多郡内子町', 'キタグンウチコチョウ', '知清', 'チセイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県喜多郡内子町立山', '38', '38422', '7913331', '愛媛県', 'エヒメケン', '喜多郡内子町', 'キタグンウチコチョウ', '立山', 'タチヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県喜多郡内子町袋口', '38', '38422', '7913332', '愛媛県', 'エヒメケン', '喜多郡内子町', 'キタグンウチコチョウ', '袋口', 'フロク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県喜多郡内子町論田', '38', '38422', '7913341', '愛媛県', 'エヒメケン', '喜多郡内子町', 'キタグンウチコチョウ', '論田', 'ロンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県喜多郡内子町河内', '38', '38422', '7913342', '愛媛県', 'エヒメケン', '喜多郡内子町', 'キタグンウチコチョウ', '河内', 'カワノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県喜多郡内子町石畳', '38', '38422', '7913343', '愛媛県', 'エヒメケン', '喜多郡内子町', 'キタグンウチコチョウ', '石畳', 'イシダタミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県喜多郡内子町五百木', '38', '38422', '7913351', '愛媛県', 'エヒメケン', '喜多郡内子町', 'キタグンウチコチョウ', '五百木', 'イヨキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県喜多郡内子町村前', '38', '38422', '7913352', '愛媛県', 'エヒメケン', '喜多郡内子町', 'キタグンウチコチョウ', '村前', 'ムラサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県喜多郡内子町大瀬', '38', '38422', '7913360', '愛媛県', 'エヒメケン', '喜多郡内子町', 'キタグンウチコチョウ', '大瀬', 'オオセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県喜多郡内子町大瀬中央鵜川', '38', '38422', '7913361', '愛媛県', 'エヒメケン', '喜多郡内子町', 'キタグンウチコチョウ', '大瀬中央', 'オオセチュウオウ', null, null, '鵜川', 'ウカワ');
INSERT INTO `ms_addresses` VALUES ('100907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県喜多郡内子町大瀬中央大久保', '38', '38422', '7913361', '愛媛県', 'エヒメケン', '喜多郡内子町', 'キタグンウチコチョウ', '大瀬中央', 'オオセチュウオウ', null, null, '大久保', 'オオクボ');
INSERT INTO `ms_addresses` VALUES ('100908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県喜多郡内子町大瀬中央乙成', '38', '38422', '7913361', '愛媛県', 'エヒメケン', '喜多郡内子町', 'キタグンウチコチョウ', '大瀬中央', 'オオセチュウオウ', null, null, '乙成', 'オツナリ');
INSERT INTO `ms_addresses` VALUES ('100909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県喜多郡内子町大瀬中央中野', '38', '38422', '7913361', '愛媛県', 'エヒメケン', '喜多郡内子町', 'キタグンウチコチョウ', '大瀬中央', 'オオセチュウオウ', null, null, '中野', 'ナカノ');
INSERT INTO `ms_addresses` VALUES ('100910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県喜多郡内子町大瀬中央本町', '38', '38422', '7913361', '愛媛県', 'エヒメケン', '喜多郡内子町', 'キタグンウチコチョウ', '大瀬中央', 'オオセチュウオウ', null, null, '本町', 'ホンマチ');
INSERT INTO `ms_addresses` VALUES ('100911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県喜多郡内子町大瀬北乙影山', '38', '38422', '7913362', '愛媛県', 'エヒメケン', '喜多郡内子町', 'キタグンウチコチョウ', '大瀬北', 'オオセキタ', null, null, '乙影山', 'オツカゲヤマ');
INSERT INTO `ms_addresses` VALUES ('100912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県喜多郡内子町大瀬北熊の滝', '38', '38422', '7913362', '愛媛県', 'エヒメケン', '喜多郡内子町', 'キタグンウチコチョウ', '大瀬北', 'オオセキタ', null, null, '熊の滝', 'クマノタキ');
INSERT INTO `ms_addresses` VALUES ('100913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県喜多郡内子町大瀬北甲影山', '38', '38422', '7913362', '愛媛県', 'エヒメケン', '喜多郡内子町', 'キタグンウチコチョウ', '大瀬北', 'オオセキタ', null, null, '甲影山', 'コウガケヤマ');
INSERT INTO `ms_addresses` VALUES ('100914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県喜多郡内子町大瀬北程内', '38', '38422', '7913362', '愛媛県', 'エヒメケン', '喜多郡内子町', 'キタグンウチコチョウ', '大瀬北', 'オオセキタ', null, null, '程内', 'ホドウチ');
INSERT INTO `ms_addresses` VALUES ('100915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県喜多郡内子町大瀬東', '38', '38422', '7913363', '愛媛県', 'エヒメケン', '喜多郡内子町', 'キタグンウチコチョウ', '大瀬東', 'オオセヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県喜多郡内子町大瀬南', '38', '38422', '7913364', '愛媛県', 'エヒメケン', '喜多郡内子町', 'キタグンウチコチョウ', '大瀬南', 'オオセミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県喜多郡内子町小田', '38', '38422', '7913501', '愛媛県', 'エヒメケン', '喜多郡内子町', 'キタグンウチコチョウ', '小田', 'オダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県喜多郡内子町寺村', '38', '38422', '7913502', '愛媛県', 'エヒメケン', '喜多郡内子町', 'キタグンウチコチョウ', '寺村', 'テラムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県喜多郡内子町日野川', '38', '38422', '7913503', '愛媛県', 'エヒメケン', '喜多郡内子町', 'キタグンウチコチョウ', '日野川', 'ヒノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県喜多郡内子町大平', '38', '38422', '7913504', '愛媛県', 'エヒメケン', '喜多郡内子町', 'キタグンウチコチョウ', '大平', 'オオヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県喜多郡内子町立石', '38', '38422', '7913505', '愛媛県', 'エヒメケン', '喜多郡内子町', 'キタグンウチコチョウ', '立石', 'タテイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県喜多郡内子町南山', '38', '38422', '7913506', '愛媛県', 'エヒメケン', '喜多郡内子町', 'キタグンウチコチョウ', '南山', 'ミナミヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県喜多郡内子町吉野川', '38', '38422', '7913511', '愛媛県', 'エヒメケン', '喜多郡内子町', 'キタグンウチコチョウ', '吉野川', 'ヨシノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県喜多郡内子町中田渡', '38', '38422', '7913512', '愛媛県', 'エヒメケン', '喜多郡内子町', 'キタグンウチコチョウ', '中田渡', 'ナカタド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県喜多郡内子町上田渡', '38', '38422', '7913513', '愛媛県', 'エヒメケン', '喜多郡内子町', 'キタグンウチコチョウ', '上田渡', 'カミタド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県喜多郡内子町臼杵', '38', '38422', '7913514', '愛媛県', 'エヒメケン', '喜多郡内子町', 'キタグンウチコチョウ', '臼杵', 'ウスキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県喜多郡内子町本川', '38', '38422', '7913521', '愛媛県', 'エヒメケン', '喜多郡内子町', 'キタグンウチコチョウ', '本川', 'ホンガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県喜多郡内子町中川', '38', '38422', '7913522', '愛媛県', 'エヒメケン', '喜多郡内子町', 'キタグンウチコチョウ', '中川', 'ナカガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県喜多郡内子町上川', '38', '38422', '7913523', '愛媛県', 'エヒメケン', '喜多郡内子町', 'キタグンウチコチョウ', '上川', 'カミガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県喜多郡内子町小田深山', '38', '38422', '7913524', '愛媛県', 'エヒメケン', '喜多郡内子町', 'キタグンウチコチョウ', '小田深山', 'オダミヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道芦別市上芦別町', '01', '01216', '0791371', '北海道', 'ホッカイドウ', '芦別市', 'アシベツシ', '上芦別町', 'カミアシベツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道芦別市野花南町', '01', '01216', '0791372', '北海道', 'ホッカイドウ', '芦別市', 'アシベツシ', '野花南町', 'ノカナンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市元怒和', '38', '38201', '7914321', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '元怒和', 'モトヌワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市上怒和', '38', '38201', '7914322', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '上怒和', 'カミヌワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市二神', '38', '38201', '7914323', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '二神', 'フタガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市津和地', '38', '38201', '7914324', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '津和地', 'ツワジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市睦月', '38', '38201', '7914431', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '睦月', 'ムヅキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市野忽那', '38', '38201', '7914432', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '野忽那', 'ノグツナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市中島大浦', '38', '38201', '7914501', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '中島大浦', 'ナカジマオオウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市小浜', '38', '38201', '7914502', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '小浜', 'オバマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市長師', '38', '38201', '7914503', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '長師', 'ナガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市宮野', '38', '38201', '7914504', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '宮野', 'ミヤノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市神浦', '38', '38201', '7914505', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '神浦', 'コウノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市宇和間', '38', '38201', '7914506', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '宇和間', 'ウワマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市熊田', '38', '38201', '7914507', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '熊田', 'クマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市吉木', '38', '38201', '7914508', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '吉木', 'ヨシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市饒', '38', '38201', '7914509', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '饒', 'ニョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市畑里', '38', '38201', '7914510', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '畑里', 'ハタリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市中島粟井', '38', '38201', '7914511', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '中島粟井', 'ナカジマアワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市山部市街地', '01', '01229', '0791561', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', '山部市街地', 'ヤマベシガイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市山部西12線', '01', '01229', '0791571', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', '山部西12線', 'ヤマベニシ12セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市山部西13線', '01', '01229', '0791571', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', '山部西13線', 'ヤマベニシ13セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市山部西14線', '01', '01229', '0791571', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', '山部西14線', 'ヤマベニシ14セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市山部西15線', '01', '01229', '0791571', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', '山部西15線', 'ヤマベニシ15セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市山部西16線', '01', '01229', '0791571', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', '山部西16線', 'ヤマベニシ16セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市山部西17線', '01', '01229', '0791571', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', '山部西17線', 'ヤマベニシ17セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市山部西18線', '01', '01229', '0791571', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', '山部西18線', 'ヤマベニシ18セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市山部西19線', '01', '01229', '0791571', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', '山部西19線', 'ヤマベニシ19セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市山部西20線', '01', '01229', '0791572', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', '山部西20線', 'ヤマベニシ20セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市山部西21線', '01', '01229', '0791572', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', '山部西21線', 'ヤマベニシ21セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市山部西22線', '01', '01229', '0791572', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', '山部西22線', 'ヤマベニシ22セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市山部西23線', '01', '01229', '0791572', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', '山部西23線', 'ヤマベニシ23セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市山部西24線', '01', '01229', '0791572', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', '山部西24線', 'ヤマベニシ24セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市山部西25線', '01', '01229', '0791573', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', '山部西25線', 'ヤマベニシ25セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市山部西26線', '01', '01229', '0791573', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', '山部西26線', 'ヤマベニシ26セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市山部西27線', '01', '01229', '0791573', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', '山部西27線', 'ヤマベニシ27セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市山部西28線', '01', '01229', '0791573', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', '山部西28線', 'ヤマベニシ28セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市山部東12線', '01', '01229', '0791581', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', '山部東12線', 'ヤマベヒガシ12セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市山部東13線', '01', '01229', '0791581', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', '山部東13線', 'ヤマベヒガシ13セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市山部東14線', '01', '01229', '0791581', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', '山部東14線', 'ヤマベヒガシ14セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市山部東15線', '01', '01229', '0791581', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', '山部東15線', 'ヤマベヒガシ15セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市山部東16線', '01', '01229', '0791581', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', '山部東16線', 'ヤマベヒガシ16セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市山部東17線', '01', '01229', '0791581', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', '山部東17線', 'ヤマベヒガシ17セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市山部東18線', '01', '01229', '0791581', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', '山部東18線', 'ヤマベヒガシ18セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市山部東19線', '01', '01229', '0791581', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', '山部東19線', 'ヤマベヒガシ19セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市山部東20線', '01', '01229', '0791582', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', '山部東20線', 'ヤマベヒガシ20セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市山部東21線', '01', '01229', '0791582', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', '山部東21線', 'ヤマベヒガシ21セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市山部東22線', '01', '01229', '0791582', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', '山部東22線', 'ヤマベヒガシ22セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市山部東23線', '01', '01229', '0791582', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', '山部東23線', 'ヤマベヒガシ23セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市山部東24線', '01', '01229', '0791582', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', '山部東24線', 'ヤマベヒガシ24セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市山部東25線', '01', '01229', '0791582', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', '山部東25線', 'ヤマベヒガシ25セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市山部東26線', '01', '01229', '0791582', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', '山部東26線', 'ヤマベヒガシ26セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市山部東27線', '01', '01229', '0791582', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', '山部東27線', 'ヤマベヒガシ27セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市平田町', '38', '38201', '7918001', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '平田町', 'ヒラタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市谷町', '38', '38201', '7918002', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '谷町', 'タニマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市志津川町', '38', '38201', '7918003', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '志津川町', 'シツカワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市鴨川', '38', '38201', '7918004', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '鴨川', 'カモガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市東長戸', '38', '38201', '7918005', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '東長戸', 'ヒガシナガト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市安城寺町', '38', '38201', '7918006', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '安城寺町', 'アンジョウジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市高木町', '38', '38201', '7918007', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '高木町', 'タカギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市吉藤', '38', '38201', '7918011', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '吉藤', 'ヨシフジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市姫原', '38', '38201', '7918012', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '姫原', 'ヒメバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('100999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市山越', '38', '38201', '7918013', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '山越', 'ヤマゴエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市山越町', '38', '38201', '7918014', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '山越町', 'ヤマゴエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市中央', '38', '38201', '7918015', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市久万ノ台', '38', '38201', '7918016', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '久万ノ台', 'クマノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市西長戸町', '38', '38201', '7918017', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '西長戸町', 'ニシナガトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市問屋町', '38', '38201', '7918018', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '問屋町', 'トイヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市青葉台', '38', '38201', '7918019', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '青葉台', 'アオバダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市六軒家町', '38', '38201', '7918021', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '六軒家町', 'ロッケンヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市美沢', '38', '38201', '7918022', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '美沢', 'ミサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市朝美', '38', '38201', '7918023', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '朝美', 'アサミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市朝日ケ丘', '38', '38201', '7918024', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '朝日ケ丘', 'アサヒガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市衣山', '38', '38201', '7918025', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '衣山', 'キヌヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市山西町', '38', '38201', '7918026', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '山西町', 'ヤマニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市明神丘', '38', '38201', '7918027', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '明神丘', 'ミョウジンオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市北斎院町', '38', '38201', '7918031', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '北斎院町', 'キタサヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市南斎院町', '38', '38201', '7918032', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '南斎院町', 'ミナミサヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市富久町', '38', '38201', '7918034', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '富久町', 'トミヒサマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市久保田町', '38', '38201', '7918035', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '久保田町', 'クボタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市高岡町', '38', '38201', '7918036', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '高岡町', 'タカオカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市北吉田町', '38', '38201', '7918041', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '北吉田町', 'キタヨシダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市南吉田町', '38', '38201', '7918042', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '南吉田町', 'ミナミヨシダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市東垣生町', '38', '38201', '7918043', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '東垣生町', 'ヒガシハブマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市西垣生町', '38', '38201', '7918044', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '西垣生町', 'ニシハブマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市梅田町', '38', '38201', '7918051', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '梅田町', 'ウメダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市須賀町', '38', '38201', '7918052', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '須賀町', 'スガマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市若葉町', '38', '38201', '7918053', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '若葉町', 'ワカバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市松江町', '38', '38201', '7918054', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '松江町', 'マツエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市清住', '38', '38201', '7918055', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '清住', 'キヨスミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市別府町', '38', '38201', '7918056', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '別府町', 'ベフチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市大可賀', '38', '38201', '7918057', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '大可賀', 'オオカガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市海岸通', '38', '38201', '7918058', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '海岸通', 'カイガンドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市三津ふ頭', '38', '38201', '7918060', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '三津ふ頭', 'ミツフトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市三津', '38', '38201', '7918061', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '三津', 'ミツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市住吉', '38', '38201', '7918062', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '住吉', 'スミヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市神田町', '38', '38201', '7918063', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '神田町', 'カンダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市元町', '38', '38201', '7918064', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '元町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市三杉町', '38', '38201', '7918065', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '三杉町', 'ミスギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市祓川', '38', '38201', '7918066', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '祓川', 'ハライカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市古三津', '38', '38201', '7918067', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '古三津', 'フルミツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市古三津町', '38', '38201', '7918067', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '古三津町', 'フルミツマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市みどりケ丘', '38', '38201', '7918068', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', 'みどりケ丘', 'ミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市吉野町', '38', '38201', '7918069', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '吉野町', 'ヨシノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市松ノ木', '38', '38201', '7918071', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '松ノ木', 'マツノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市桜ケ丘', '38', '38201', '7918072', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '桜ケ丘', 'サクラガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市船ケ谷町', '38', '38201', '7918073', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '船ケ谷町', 'フネガタニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市東山町', '38', '38201', '7918074', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '東山町', 'ヒガシヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市ひばりケ丘', '38', '38201', '7918075', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', 'ひばりケ丘', 'ヒバリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市会津町', '38', '38201', '7918076', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '会津町', 'アイヅマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市内浜町', '38', '38201', '7918077', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '内浜町', 'ウチハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市中須賀', '38', '38201', '7918078', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '中須賀', 'ナカスガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市高山町', '38', '38201', '7918079', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '高山町', 'タカヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市高浜町', '38', '38201', '7918081', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '高浜町', 'タカハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市梅津寺町', '38', '38201', '7918082', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '梅津寺町', 'バイシンジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市新浜町', '38', '38201', '7918083', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '新浜町', 'シンハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市石風呂町', '38', '38201', '7918084', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '石風呂町', 'イシフロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市港山町', '38', '38201', '7918085', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '港山町', 'ミナトヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市辰巳町', '38', '38201', '7918086', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '辰巳町', 'タツミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市春美町', '38', '38201', '7918087', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '春美町', 'ハルミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市門田町', '38', '38201', '7918091', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '門田町', 'カドタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市由良町', '38', '38201', '7918092', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '由良町', 'ユラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市泊町', '38', '38201', '7918093', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '泊町', 'トマリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市', '38', '38205', '7920000', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('101092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市惣開町', '38', '38205', '7920001', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '惣開町', 'ソウビラキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市磯浦町', '38', '38205', '7920002', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '磯浦町', 'イソウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市新田町', '38', '38205', '7920003', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '新田町', 'シンデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市北新町', '38', '38205', '7920004', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '北新町', 'キタシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市江口町', '38', '38205', '7920005', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '江口町', 'エグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市河内町', '38', '38205', '7920006', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '河内町', 'コウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市前田町', '38', '38205', '7920007', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '前田町', 'マエダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市王子町', '38', '38205', '7920008', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '王子町', 'オウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市星越町', '38', '38205', '7920009', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '星越町', 'ホシゴエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市西原町', '38', '38205', '7920011', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '西原町', 'ニシバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市中須賀町', '38', '38205', '7920012', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '中須賀町', 'ナカスカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市泉池町', '38', '38205', '7920013', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '泉池町', 'イズミイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市西町', '38', '38205', '7920014', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '西町', 'ニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市大江町', '38', '38205', '7920015', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '大江町', 'オオエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市港町', '38', '38205', '7920016', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '港町', 'ミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市若水町', '38', '38205', '7920017', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '若水町', 'ワカミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市泉宮町', '38', '38205', '7920021', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '泉宮町', 'イズミミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市徳常町', '38', '38205', '7920022', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '徳常町', 'トクツネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市繁本町', '38', '38205', '7920023', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '繁本町', 'シゲモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市宮西町', '38', '38205', '7920024', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '宮西町', 'ミヤニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市一宮町', '38', '38205', '7920025', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '一宮町', 'イックチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市久保田町', '38', '38205', '7920026', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '久保田町', 'クボタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市高木町', '38', '38205', '7920031', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '高木町', 'タカギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市政枝町', '38', '38205', '7920032', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '政枝町', 'マサエダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市横水町', '38', '38205', '7920033', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '横水町', 'ヨコズイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市滝の宮町', '38', '38205', '7920034', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '滝の宮町', 'タキノミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市西の土居町', '38', '38205', '7920035', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '西の土居町', 'ニシノドイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市中村松木', '38', '38205', '7920041', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '中村松木', 'ナカムラマツギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市本郷', '38', '38205', '7920042', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '本郷', 'ホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市土橋', '38', '38205', '7920043', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '土橋', 'ツチハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市中村', '38', '38205', '7920044', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '中村', 'ナカムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市中萩町', '38', '38205', '7920045', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '中萩町', 'ナカハギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市上原', '38', '38205', '7920046', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '上原', 'ウワバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市御蔵町', '38', '38205', '7920047', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '御蔵町', 'オクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市萩生', '38', '38205', '7920050', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '萩生', 'ハギュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市大生院', '38', '38205', '7920060', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '大生院', 'オオジョウイン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市金子丙', '38', '38205', '7920071', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '金子丙', 'カネコヘイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市新居浜乙', '38', '38205', '7920072', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '新居浜乙', 'ニイハマオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市宮窪町四阪島', '38', '38202', '7920080', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '宮窪町四阪島', 'ミヤクボチョウシサカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市菊本町', '38', '38205', '7920801', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '菊本町', 'キクモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市新須賀町', '38', '38205', '7920802', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '新須賀町', 'シンスカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市平形町', '38', '38205', '7920803', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '平形町', 'ヒラカタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市田所町', '38', '38205', '7920804', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '田所町', 'タドコロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市八雲町', '38', '38205', '7920805', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '八雲町', 'ヤグモチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市庄内町', '38', '38205', '7920811', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '庄内町', 'ショウナイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市坂井町', '38', '38205', '7920812', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '坂井町', 'サカイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市下泉町', '38', '38205', '7920813', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '下泉町', 'シモイズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市城下町', '38', '38205', '7920814', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '城下町', 'シロシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市岸の上町', '38', '38205', '7920815', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '岸の上町', 'キシノウエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市瀬戸町', '38', '38205', '7920821', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '瀬戸町', 'セトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市寿町', '38', '38205', '7920822', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '寿町', 'コトブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市外山町', '38', '38205', '7920823', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '外山町', 'トヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市上泉町', '38', '38205', '7920824', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '上泉町', 'カミイズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市星原町', '38', '38205', '7920825', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '星原町', 'ホシバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市喜光地町', '38', '38205', '7920826', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '喜光地町', 'キコウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市西喜光地町', '38', '38205', '7920827', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '西喜光地町', 'ニシキコウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市松原町', '38', '38205', '7920828', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '松原町', 'マツバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市松木町', '38', '38205', '7920829', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '松木町', 'マツギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市西連寺町', '38', '38205', '7920831', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '西連寺町', 'サイレンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市西泉町', '38', '38205', '7920832', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '西泉町', 'ニシイズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市宮原町', '38', '38205', '7920833', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '宮原町', 'ミヤバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市中西町', '38', '38205', '7920834', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '中西町', 'ナカニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市山根町', '38', '38205', '7920835', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '山根町', 'ヤマネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市篠場町', '38', '38205', '7920836', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '篠場町', 'シノバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市山田町', '38', '38205', '7920837', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '山田町', 'ヤマダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市中筋町', '38', '38205', '7920841', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '中筋町', 'ナカスジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市北内町', '38', '38205', '7920842', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '北内町', 'キタウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市吉岡町', '38', '38205', '7920843', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '吉岡町', 'ヨシオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市角野新田町', '38', '38205', '7920844', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '角野新田町', 'スミノシンデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市種子川町', '38', '38205', '7920845', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '種子川町', 'タネガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市立川町', '38', '38205', '7920846', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '立川町', 'タツカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市大永山', '38', '38205', '7920847', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '大永山', 'ダイエイヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市種子川山', '38', '38205', '7920848', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '種子川山', 'タネガワヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市観音原町', '38', '38205', '7920851', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '観音原町', 'カンノンバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市東田', '38', '38205', '7920852', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '東田', 'トウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市光明寺', '38', '38205', '7920853', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '光明寺', 'コウミョウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市国領', '38', '38205', '7920854', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '国領', 'コクリョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市七宝台町', '38', '38205', '7920855', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '七宝台町', 'シッポウダイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市船木', '38', '38205', '7920856', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '船木', 'フナキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市角野', '38', '38205', '7920857', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '角野', 'スミノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市清水町', '38', '38205', '7920861', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '清水町', 'シミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市沢津町', '38', '38205', '7920862', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '沢津町', 'サワヅチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市南小松原町', '38', '38205', '7920863', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '南小松原町', 'ミナミコマツバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市東雲町', '38', '38205', '7920864', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '東雲町', 'シノノメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市桜木町', '38', '38205', '7920865', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '桜木町', 'サクラギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市宇高町', '38', '38205', '7920866', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '宇高町', 'ウダカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市高津町', '38', '38205', '7920867', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '高津町', 'タカツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市松の木町', '38', '38205', '7920868', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '松の木町', 'マツノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市八幡', '38', '38205', '7920871', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '八幡', 'ハチマン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市垣生', '38', '38205', '7920872', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '垣生', 'ハブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市垣生', '38', '38205', '7920873', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '垣生', 'ハブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市長岩町', '38', '38205', '7920874', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '長岩町', 'ナガイワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市松神子', '38', '38205', '7920881', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '松神子', 'マツミコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市又野', '38', '38205', '7920882', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '又野', 'マタノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市落神町', '38', '38205', '7920883', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '落神町', 'オチガミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市神郷', '38', '38205', '7920884', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '神郷', 'コウザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市清住町', '38', '38205', '7920885', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '清住町', 'キヨズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市郷', '38', '38205', '7920886', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '郷', 'ゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市高田', '38', '38205', '7920887', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '高田', 'タカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市田の上', '38', '38205', '7920888', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '田の上', 'タノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市楠崎', '38', '38205', '7920890', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '楠崎', 'クッサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市大島', '38', '38205', '7920891', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '大島', 'オオシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市黒島', '38', '38205', '7920892', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '黒島', 'クロシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市多喜浜', '38', '38205', '7920893', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '多喜浜', 'タキハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市郷', '38', '38205', '7920894', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '郷', 'ゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市郷乙', '38', '38205', '7920895', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '郷乙', 'ゴウオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市阿島', '38', '38205', '7920896', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '阿島', 'アシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市阿島乙', '38', '38205', '7920897', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '阿島乙', 'アシマオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市荷内町', '38', '38205', '7920898', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '荷内町', 'ニナイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡南富良野町金山', '01', '01462', '0792131', '北海道', 'ホッカイドウ', '空知郡南富良野町', 'ソラチグンミナミフラノチョウ', '金山', 'カナヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡南富良野町下金山', '01', '01462', '0792132', '北海道', 'ホッカイドウ', '空知郡南富良野町', 'ソラチグンミナミフラノチョウ', '下金山', 'シモカナヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道富良野市東山', '01', '01229', '0792133', '北海道', 'ホッカイドウ', '富良野市', 'フラノシ', '東山', 'ヒガシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡占冠村', '01', '01463', '0792200', '北海道', 'ホッカイドウ', '勇払郡占冠村', 'ユウフツグンシムカップムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('101205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡占冠村中央', '01', '01463', '0792201', '北海道', 'ホッカイドウ', '勇払郡占冠村', 'ユウフツグンシムカップムラ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡占冠村占冠', '01', '01463', '0792202', '北海道', 'ホッカイドウ', '勇払郡占冠村', 'ユウフツグンシムカップムラ', '占冠', 'シムカップ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡占冠村下トマム', '01', '01463', '0792203', '北海道', 'ホッカイドウ', '勇払郡占冠村', 'ユウフツグンシムカップムラ', '下トマム', 'シモトマム', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡占冠村中トマム', '01', '01463', '0792204', '北海道', 'ホッカイドウ', '勇払郡占冠村', 'ユウフツグンシムカップムラ', '中トマム', 'ナカトマム', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡占冠村上トマム', '01', '01463', '0792205', '北海道', 'ホッカイドウ', '勇払郡占冠村', 'ユウフツグンシムカップムラ', '上トマム', 'カミトマム', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡占冠村双珠別', '01', '01463', '0792206', '北海道', 'ホッカイドウ', '勇払郡占冠村', 'ユウフツグンシムカップムラ', '双珠別', 'ソウシュベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道勇払郡占冠村ニニウ', '01', '01463', '0792207', '北海道', 'ホッカイドウ', '勇払郡占冠村', 'ユウフツグンシムカップムラ', 'ニニウ', 'ニニウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡南富良野町', '01', '01462', '0792400', '北海道', 'ホッカイドウ', '空知郡南富良野町', 'ソラチグンミナミフラノチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('101213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡南富良野町幾寅栄町', '01', '01462', '0792401', '北海道', 'ホッカイドウ', '空知郡南富良野町', 'ソラチグンミナミフラノチョウ', '幾寅', 'イクトラ', null, null, '栄町', 'サカエマチ');
INSERT INTO `ms_addresses` VALUES ('101214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡南富良野町幾寅住吉町', '01', '01462', '0792401', '北海道', 'ホッカイドウ', '空知郡南富良野町', 'ソラチグンミナミフラノチョウ', '幾寅', 'イクトラ', null, null, '住吉町', 'スミヨシチョウ');
INSERT INTO `ms_addresses` VALUES ('101215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡南富良野町幾寅内藤', '01', '01462', '0792401', '北海道', 'ホッカイドウ', '空知郡南富良野町', 'ソラチグンミナミフラノチョウ', '幾寅', 'イクトラ', null, null, '内藤', 'ナイトウ');
INSERT INTO `ms_addresses` VALUES ('101216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡南富良野町幾寅仲町', '01', '01462', '0792401', '北海道', 'ホッカイドウ', '空知郡南富良野町', 'ソラチグンミナミフラノチョウ', '幾寅', 'イクトラ', null, null, '仲町', 'ナカマチ');
INSERT INTO `ms_addresses` VALUES ('101217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡南富良野町幾寅西町', '01', '01462', '0792402', '北海道', 'ホッカイドウ', '空知郡南富良野町', 'ソラチグンミナミフラノチョウ', '幾寅', 'イクトラ', null, null, '西町', 'ニシマチ');
INSERT INTO `ms_addresses` VALUES ('101218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡南富良野町幾寅浅野', '01', '01462', '0792403', '北海道', 'ホッカイドウ', '空知郡南富良野町', 'ソラチグンミナミフラノチョウ', '幾寅', 'イクトラ', null, null, '浅野', 'アサノ');
INSERT INTO `ms_addresses` VALUES ('101219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡南富良野町幾寅岐阜', '01', '01462', '0792403', '北海道', 'ホッカイドウ', '空知郡南富良野町', 'ソラチグンミナミフラノチョウ', '幾寅', 'イクトラ', null, null, '岐阜', 'ギフ');
INSERT INTO `ms_addresses` VALUES ('101220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡南富良野町幾寅久住', '01', '01462', '0792403', '北海道', 'ホッカイドウ', '空知郡南富良野町', 'ソラチグンミナミフラノチョウ', '幾寅', 'イクトラ', null, null, '久住', 'クスミ');
INSERT INTO `ms_addresses` VALUES ('101221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡南富良野町幾寅松井', '01', '01462', '0792403', '北海道', 'ホッカイドウ', '空知郡南富良野町', 'ソラチグンミナミフラノチョウ', '幾寅', 'イクトラ', null, null, '松井', 'マツイ');
INSERT INTO `ms_addresses` VALUES ('101222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡南富良野町幾寅山畔', '01', '01462', '0792403', '北海道', 'ホッカイドウ', '空知郡南富良野町', 'ソラチグンミナミフラノチョウ', '幾寅', 'イクトラ', null, null, '山畔', 'ヤマクロ');
INSERT INTO `ms_addresses` VALUES ('101223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡南富良野町幾寅朝日町', '01', '01462', '0792404', '北海道', 'ホッカイドウ', '空知郡南富良野町', 'ソラチグンミナミフラノチョウ', '幾寅', 'イクトラ', null, null, '朝日町', 'アサヒマチ');
INSERT INTO `ms_addresses` VALUES ('101224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡南富良野町幾寅千木町', '01', '01462', '0792404', '北海道', 'ホッカイドウ', '空知郡南富良野町', 'ソラチグンミナミフラノチョウ', '幾寅', 'イクトラ', null, null, '千木町', 'センボクチョウ');
INSERT INTO `ms_addresses` VALUES ('101225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡南富良野町幾寅東町', '01', '01462', '0792404', '北海道', 'ホッカイドウ', '空知郡南富良野町', 'ソラチグンミナミフラノチョウ', '幾寅', 'イクトラ', null, null, '東町', 'ヒガシマチ');
INSERT INTO `ms_addresses` VALUES ('101226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡南富良野町東鹿越', '01', '01462', '0792411', '北海道', 'ホッカイドウ', '空知郡南富良野町', 'ソラチグンミナミフラノチョウ', '東鹿越', 'ヒガシシカゴエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡南富良野町東幾寅', '01', '01462', '0792412', '北海道', 'ホッカイドウ', '空知郡南富良野町', 'ソラチグンミナミフラノチョウ', '東幾寅', 'ヒガシイクトラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡南富良野町落合', '01', '01462', '0792551', '北海道', 'ホッカイドウ', '空知郡南富良野町', 'ソラチグンミナミフラノチョウ', '落合', 'オチアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道空知郡南富良野町北落合', '01', '01462', '0792552', '北海道', 'ホッカイドウ', '空知郡南富良野町', 'ソラチグンミナミフラノチョウ', '北落合', 'キタオチアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市', '38', '38206', '7930000', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('101249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市玉津', '38', '38206', '7930001', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '玉津', 'タマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市天神', '38', '38206', '7930002', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '天神', 'テンジン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市ひうち', '38', '38206', '7930003', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', 'ひうち', 'ヒウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市船屋甲', '38', '38206', '7930004', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '船屋甲', 'フナヤコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市船屋乙', '38', '38206', '7930005', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '船屋乙', 'フナヤオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市下島山甲', '38', '38206', '7930006', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '下島山甲', 'シモシマヤマコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市下島山乙', '38', '38206', '7930007', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '下島山乙', 'シモシマヤマオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市飯岡', '38', '38206', '7930010', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '飯岡', 'イイオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市大浜', '38', '38206', '7930016', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '大浜', 'オオハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市早川', '38', '38206', '7930017', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '早川', 'ハイガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市神拝乙', '38', '38206', '7930021', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '神拝乙', 'カンバイオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市本町', '38', '38206', '7930022', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市明屋敷', '38', '38206', '7930023', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '明屋敷', 'アケヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市大師町', '38', '38206', '7930024', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '大師町', 'ダイシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市栄町', '38', '38206', '7930025', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市東町', '38', '38206', '7930026', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '東町', 'ヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市朔日市', '38', '38206', '7930027', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '朔日市', 'ツイタチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市新田', '38', '38206', '7930028', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '新田', 'シンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市大町', '38', '38206', '7930030', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '大町', 'オオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市明神木', '38', '38206', '7930034', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '明神木', 'ミョウジンギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市福武甲', '38', '38206', '7930035', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '福武甲', 'フクタケコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市福武乙', '38', '38206', '7930036', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '福武乙', 'フクタケオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市市之川', '38', '38206', '7930037', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '市之川', 'イチノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市丸野', '38', '38206', '7930038', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '丸野', 'マルノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市保野', '38', '38206', '7930039', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '保野', 'ホウノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市神拝甲', '38', '38206', '7930041', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '神拝甲', 'カンバイコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市喜多川', '38', '38206', '7930042', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '喜多川', 'キタガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市樋之口', '38', '38206', '7930043', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '樋之口', 'ヒノクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市古川甲', '38', '38206', '7930044', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '古川甲', 'フルカワコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市古川乙', '38', '38206', '7930045', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '古川乙', 'フルカワオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市港', '38', '38206', '7930046', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '港', 'ミナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市安知生', '38', '38206', '7930051', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '安知生', 'アンジュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市中西', '38', '38206', '7930052', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '中西', 'ナカニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市洲之内甲', '38', '38206', '7930053', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '洲之内甲', 'スノウチコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市中野甲', '38', '38206', '7930054', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '中野甲', 'ナカノコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市中野乙', '38', '38206', '7930055', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '中野乙', 'ナカノオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市中野丙', '38', '38206', '7930056', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '中野丙', 'ナカノヘイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市津越', '38', '38206', '7930057', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '津越', 'ツゴエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市禎瑞', '38', '38206', '7930061', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '禎瑞', 'テイズイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市西田甲', '38', '38206', '7930062', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '西田甲', 'ニシダコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市西泉甲', '38', '38206', '7930063', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '西泉甲', 'ニシイズミコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市西泉乙', '38', '38206', '7930064', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '西泉乙', 'ニシイズミオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市楢木', '38', '38206', '7930065', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '楢木', 'ナラノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市野々市', '38', '38206', '7930066', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '野々市', 'ノノイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市坂元甲', '38', '38206', '7930067', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '坂元甲', 'サカモトコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市氷見甲', '38', '38206', '7930071', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '氷見甲', 'ヒミコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市氷見乙', '38', '38206', '7930072', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '氷見乙', 'ヒミオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市氷見丙', '38', '38206', '7930073', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '氷見丙', 'ヒミヘイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市氷見丁', '38', '38206', '7930074', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '氷見丁', 'ヒミテイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市氷見戊', '38', '38206', '7930075', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '氷見戊', 'ヒミボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市千町', '38', '38206', '7930101', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '千町', 'センジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市藤之石', '38', '38206', '7930102', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '藤之石', 'フジノイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市荒川', '38', '38206', '7930103', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '荒川', 'アラカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市大保木', '38', '38206', '7930211', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '大保木', 'オオフキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市黒瀬', '38', '38206', '7930212', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '黒瀬', 'クロセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市兎之山', '38', '38206', '7930213', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '兎之山', 'トノヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市中奥', '38', '38206', '7930214', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '中奥', 'ナカオク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市西之川', '38', '38206', '7930215', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '西之川', 'ニシノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市東之川', '38', '38206', '7930216', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '東之川', 'ヒガシノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市', '38', '38202', '7940000', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('101316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市砂場町', '38', '38202', '7940001', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '砂場町', 'スナバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市大浜町', '38', '38202', '7940002', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '大浜町', 'オオハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市湊町', '38', '38202', '7940003', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '湊町', 'ミナトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市鐘場町', '38', '38202', '7940004', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '鐘場町', 'カネバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市大新田町', '38', '38202', '7940005', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '大新田町', 'オオシンデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市石井町', '38', '38202', '7940006', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '石井町', 'イシイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市近見町', '38', '38202', '7940007', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '近見町', 'チカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市北浜町', '38', '38202', '7940011', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '北浜町', 'キタハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市美保町', '38', '38202', '7940012', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '美保町', 'ミホチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市片原町', '38', '38202', '7940013', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '片原町', 'カタハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市今治村比岐島', '38', '38202', '7940014', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '今治村', 'イマバリムラ', null, null, '比岐島', 'ヒキジマ');
INSERT INTO `ms_addresses` VALUES ('101327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市常盤町', '38', '38202', '7940015', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '常盤町', 'トキワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市中浜町', '38', '38202', '7940016', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '中浜町', 'ナカバマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市風早町', '38', '38202', '7940017', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '風早町', 'カザハヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市本町', '38', '38202', '7940018', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市米屋町', '38', '38202', '7940021', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '米屋町', 'コメヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市室屋町', '38', '38202', '7940022', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '室屋町', 'ムロヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市栄町', '38', '38202', '7940023', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市共栄町', '38', '38202', '7940024', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '共栄町', 'キョウエイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市大正町', '38', '38202', '7940025', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '大正町', 'タイショウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市別宮町', '38', '38202', '7940026', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '別宮町', 'ベックチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市南大門町', '38', '38202', '7940027', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '南大門町', 'ミナミダイモンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市北宝来町', '38', '38202', '7940028', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '北宝来町', 'キタホウライチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市恵美須町', '38', '38202', '7940031', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '恵美須町', 'エビスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市天保山町', '38', '38202', '7940032', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '天保山町', 'テンポウザンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市東門町', '38', '38202', '7940033', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '東門町', 'ヒガシモンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市美須賀町', '38', '38202', '7940034', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '美須賀町', 'ミスカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市枝堀町', '38', '38202', '7940035', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '枝堀町', 'エダボリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市通町', '38', '38202', '7940036', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '通町', 'トオリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市黄金町', '38', '38202', '7940037', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '黄金町', 'コガネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市末広町', '38', '38202', '7940038', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '末広町', 'スエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市松本町', '38', '38202', '7940041', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '松本町', 'マツモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市旭町', '38', '38202', '7940042', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '旭町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市南宝来町', '38', '38202', '7940043', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '南宝来町', 'ミナミホウライチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市蔵敷町', '38', '38202', '7940044', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '蔵敷町', 'クラシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市高地町', '38', '38202', '7940051', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '高地町', 'コウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市宮下町', '38', '38202', '7940052', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '宮下町', 'ミヤシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市山方町', '38', '38202', '7940053', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '山方町', 'ヤマカタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市北日吉町', '38', '38202', '7940054', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '北日吉町', 'キタヒヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市中日吉町', '38', '38202', '7940055', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '中日吉町', 'ナカヒヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市南日吉町', '38', '38202', '7940056', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '南日吉町', 'ミナミヒヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市泉川町', '38', '38202', '7940057', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '泉川町', 'イズミガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市蒼社町', '38', '38202', '7940058', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '蒼社町', 'ソウシャチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市鯉池町', '38', '38202', '7940059', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '鯉池町', 'コイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市馬越二番耕地', '38', '38202', '7940061', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '馬越二番耕地', 'ウマゴエニバンコウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市馬越町', '38', '38202', '7940062', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '馬越町', 'ウマゴエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市片山', '38', '38202', '7940063', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '片山', 'カタヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市小泉', '38', '38202', '7940064', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '小泉', 'コイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市別名', '38', '38202', '7940065', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '別名', 'ベツミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市高橋', '38', '38202', '7940066', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '高橋', 'タカハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市山路町', '38', '38202', '7940071', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '山路町', 'ヤマジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市山路', '38', '38202', '7940072', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '山路', 'ヤマジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市矢田', '38', '38202', '7940073', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '矢田', 'ヤタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市神宮', '38', '38202', '7940074', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '神宮', 'カンノミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市阿方', '38', '38202', '7940081', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '阿方', 'アガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市野間', '38', '38202', '7940082', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '野間', 'ノマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市宅間', '38', '38202', '7940083', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '宅間', 'タクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市延喜', '38', '38202', '7940084', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '延喜', 'エンギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市玉川町三反地', '38', '38202', '7940101', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '玉川町三反地', 'タマガワチョウサンダンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市玉川町大野', '38', '38202', '7940102', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '玉川町大野', 'タマガワチョウオオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市玉川町法界寺', '38', '38202', '7940103', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '玉川町法界寺', 'タマガワチョウホウカイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市玉川町摺木', '38', '38202', '7940104', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '玉川町摺木', 'タマガワチョウスルギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市玉川町與和木', '38', '38202', '7940105', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '玉川町與和木', 'タマガワチョウヨワギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市玉川町鍋地', '38', '38202', '7940106', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '玉川町鍋地', 'タマガワチョウナベジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市玉川町桂', '38', '38202', '7940107', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '玉川町桂', 'タマガワチョウカツラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市玉川町御厩', '38', '38202', '7940108', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '玉川町御厩', 'タマガワチョウミマヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市玉川町長谷', '38', '38202', '7940109', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '玉川町長谷', 'タマガワチョウナガタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市玉川町中村', '38', '38202', '7940111', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '玉川町中村', 'タマガワチョウナカムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市玉川町小鴨部', '38', '38202', '7940112', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '玉川町小鴨部', 'タマガワチョウコカンベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市玉川町別所', '38', '38202', '7940113', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '玉川町別所', 'タマガワチョウベッショ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市玉川町八幡', '38', '38202', '7940114', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '玉川町八幡', 'タマガワチョウヤワタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市玉川町高野', '38', '38202', '7940115', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '玉川町高野', 'タマガワチョウコウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市玉川町畑寺', '38', '38202', '7940116', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '玉川町畑寺', 'タマガワチョウハタデラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市玉川町鬼原', '38', '38202', '7940117', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '玉川町鬼原', 'タマガワチョウオニバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市玉川町鈍川', '38', '38202', '7940121', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '玉川町鈍川', 'タマガワチョウニブカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市玉川町木地', '38', '38202', '7940122', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '玉川町木地', 'タマガワチョウキジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市玉川町龍岡下', '38', '38202', '7940123', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '玉川町龍岡下', 'タマガワチョウリュウオカシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市玉川町龍岡上', '38', '38202', '7940124', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '玉川町龍岡上', 'タマガワチョウリュウオカカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市玉川町葛谷', '38', '38202', '7940125', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '玉川町葛谷', 'タマガワチョウカズラタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市東鳥生町', '38', '38202', '7940801', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '東鳥生町', 'ヒガシトリウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市南鳥生町', '38', '38202', '7940802', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '南鳥生町', 'ミナミトリウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市北鳥生町', '38', '38202', '7940803', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '北鳥生町', 'キタトリウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市祇園町', '38', '38202', '7940804', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '祇園町', 'ギオンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市広紹寺町', '38', '38202', '7940805', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '広紹寺町', 'コウジョウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市南高下町', '38', '38202', '7940811', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '南高下町', 'ミナミコウゲチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市北高下町', '38', '38202', '7940812', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '北高下町', 'キタコウゲチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市衣干町', '38', '38202', '7940813', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '衣干町', 'キヌボシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市横田町', '38', '38202', '7940814', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '横田町', 'ヨコタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市土橋町', '38', '38202', '7940815', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '土橋町', 'ツチバシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市立花町', '38', '38202', '7940821', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '立花町', 'タチバナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市河南町', '38', '38202', '7940822', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '河南町', 'カナンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市郷本町', '38', '38202', '7940823', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '郷本町', 'ゴウホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市石橋町', '38', '38202', '7940824', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '石橋町', 'イシバシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市郷六ケ内町', '38', '38202', '7940825', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '郷六ケ内町', 'ゴウロクガウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市郷新屋敷町', '38', '38202', '7940826', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '郷新屋敷町', 'ゴウシンヤシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市辻堂', '38', '38202', '7940827', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '辻堂', 'ツジドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市八町東', '38', '38202', '7940831', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '八町東', 'ハッチョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市八町西', '38', '38202', '7940832', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '八町西', 'ハッチョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市中寺', '38', '38202', '7940840', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '中寺', 'ナカデラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市新谷', '38', '38202', '7940850', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '新谷', 'ニヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市五十嵐', '38', '38202', '7940861', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '五十嵐', 'イカナシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市四村', '38', '38202', '7940862', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '四村', 'ヨムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市徳重', '38', '38202', '7940863', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '徳重', 'トクシゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市関前岡村', '38', '38202', '7941101', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '関前岡村', 'セキゼンオカムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市関前小大下', '38', '38202', '7941102', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '関前小大下', 'セキゼンコオゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市関前大下', '38', '38202', '7941103', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '関前大下', 'セキゼンオオゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市大三島町肥海', '38', '38202', '7941301', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '大三島町肥海', 'オオミシマチョウヒガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市大三島町大見', '38', '38202', '7941302', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '大三島町大見', 'オオミシマチョウオオミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市大三島町明日', '38', '38202', '7941303', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '大三島町明日', 'オオミシマチョウアケビ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市大三島町宮浦', '38', '38202', '7941304', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '大三島町宮浦', 'オオミシマチョウミヤウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市大三島町台', '38', '38202', '7941305', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '大三島町台', 'オオミシマチョウウテナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市大三島町野々江', '38', '38202', '7941306', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '大三島町野々江', 'オオミシマチョウノノエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市大三島町口総', '38', '38202', '7941307', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '大三島町口総', 'オオミシマチョウクチスボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市大三島町浦戸', '38', '38202', '7941308', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '大三島町浦戸', 'オオミシマチョウウラド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市大三島町宗方', '38', '38202', '7941309', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '大三島町宗方', 'オオミシマチョウムナガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市上浦町盛', '38', '38202', '7941401', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '上浦町盛', 'カミウラチョウサカリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市上浦町井口', '38', '38202', '7941402', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '上浦町井口', 'カミウラチョウイノクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市上浦町甘崎', '38', '38202', '7941403', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '上浦町甘崎', 'カミウラチョウアマザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市上浦町瀬戸', '38', '38202', '7941404', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '上浦町瀬戸', 'カミウラチョウセト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市吉海町田浦', '38', '38202', '7942101', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '吉海町田浦', 'ヨシウミチョウタノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市吉海町泊', '38', '38202', '7942102', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '吉海町泊', 'ヨシウミチョウトマリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市吉海町福田', '38', '38202', '7942103', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '吉海町福田', 'ヨシウミチョウフクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市吉海町仁江', '38', '38202', '7942104', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '吉海町仁江', 'ヨシウミチョウニエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市吉海町八幡', '38', '38202', '7942110', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '吉海町八幡', 'ヨシウミチョウヤワタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市吉海町幸新田', '38', '38202', '7942111', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '吉海町幸新田', 'ヨシウミチョウサイワイシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市吉海町本庄', '38', '38202', '7942112', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '吉海町本庄', 'ヨシウミチョウホンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市吉海町椋名', '38', '38202', '7942113', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '吉海町椋名', 'ヨシウミチョウムクナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市吉海町名', '38', '38202', '7942114', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '吉海町名', 'ヨシウミチョウミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市吉海町南浦', '38', '38202', '7942115', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '吉海町南浦', 'ヨシウミチョウミナミウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市吉海町名駒', '38', '38202', '7942116', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '吉海町名駒', 'ヨシウミチョウナゴマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市吉海町正味', '38', '38202', '7942117', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '吉海町正味', 'ヨシウミチョウショウミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市吉海町臥間', '38', '38202', '7942118', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '吉海町臥間', 'ヨシウミチョウフスマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市吉海町津島', '38', '38202', '7942119', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '吉海町津島', 'ヨシウミチョウツシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市宮窪町早川', '38', '38202', '7942201', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '宮窪町早川', 'ミヤクボチョウハヤカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市宮窪町余所国', '38', '38202', '7942202', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '宮窪町余所国', 'ミヤクボチョウヨソクニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市宮窪町宮窪', '38', '38202', '7942203', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '宮窪町宮窪', 'ミヤクボチョウミヤクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市宮窪町友浦', '38', '38202', '7942204', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '宮窪町友浦', 'ミヤクボチョウトモウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市伯方町有津', '38', '38202', '7942301', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '伯方町有津', 'ハカタチョウアロウヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市伯方町叶浦', '38', '38202', '7942302', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '伯方町叶浦', 'ハカタチョウカノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市伯方町伊方', '38', '38202', '7942303', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '伯方町伊方', 'ハカタチョウイカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市伯方町北浦', '38', '38202', '7942304', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '伯方町北浦', 'ハカタチョウキタウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市伯方町木浦', '38', '38202', '7942305', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '伯方町木浦', 'ハカタチョウキノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県越智郡上島町岩城', '38', '38356', '7942410', '愛媛県', 'エヒメケン', '越智郡上島町', 'オチグンカミジマチョウ', '岩城', 'イワギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県越智郡上島町', '38', '38356', '7942500', '愛媛県', 'エヒメケン', '越智郡上島町', 'オチグンカミジマチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('101467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県越智郡上島町弓削久司浦', '38', '38356', '7942501', '愛媛県', 'エヒメケン', '越智郡上島町', 'オチグンカミジマチョウ', '弓削久司浦', 'ユゲクジウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県越智郡上島町弓削沢津', '38', '38356', '7942502', '愛媛県', 'エヒメケン', '越智郡上島町', 'オチグンカミジマチョウ', '弓削沢津', 'ユゲサワヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県越智郡上島町弓削上弓削', '38', '38356', '7942503', '愛媛県', 'エヒメケン', '越智郡上島町', 'オチグンカミジマチョウ', '弓削上弓削', 'ユゲカミユゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県越智郡上島町弓削百貫', '38', '38356', '7942503', '愛媛県', 'エヒメケン', '越智郡上島町', 'オチグンカミジマチョウ', '弓削百貫', 'ユゲヒャッカン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県越智郡上島町弓削引野', '38', '38356', '7942504', '愛媛県', 'エヒメケン', '越智郡上島町', 'オチグンカミジマチョウ', '弓削引野', 'ユゲヒキノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県越智郡上島町弓削明神', '38', '38356', '7942505', '愛媛県', 'エヒメケン', '越智郡上島町', 'オチグンカミジマチョウ', '弓削明神', 'ユゲミョウジン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県越智郡上島町弓削下弓削', '38', '38356', '7942506', '愛媛県', 'エヒメケン', '越智郡上島町', 'オチグンカミジマチョウ', '弓削下弓削', 'ユゲシモユゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県越智郡上島町弓削藤谷', '38', '38356', '7942507', '愛媛県', 'エヒメケン', '越智郡上島町', 'オチグンカミジマチョウ', '弓削藤谷', 'ユゲフジタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県越智郡上島町弓削太田', '38', '38356', '7942508', '愛媛県', 'エヒメケン', '越智郡上島町', 'オチグンカミジマチョウ', '弓削太田', 'ユゲオオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県越智郡上島町弓削土生', '38', '38356', '7942509', '愛媛県', 'エヒメケン', '越智郡上島町', 'オチグンカミジマチョウ', '弓削土生', 'ユゲハブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県越智郡上島町弓削鎌田', '38', '38356', '7942510', '愛媛県', 'エヒメケン', '越智郡上島町', 'オチグンカミジマチョウ', '弓削鎌田', 'ユゲカマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県越智郡上島町弓削日比', '38', '38356', '7942511', '愛媛県', 'エヒメケン', '越智郡上島町', 'オチグンカミジマチョウ', '弓削日比', 'ユゲヒビ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県越智郡上島町弓削狩尾', '38', '38356', '7942512', '愛媛県', 'エヒメケン', '越智郡上島町', 'オチグンカミジマチョウ', '弓削狩尾', 'ユゲカリオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県越智郡上島町弓削大谷', '38', '38356', '7942513', '愛媛県', 'エヒメケン', '越智郡上島町', 'オチグンカミジマチョウ', '弓削大谷', 'ユゲオオタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県越智郡上島町弓削佐島', '38', '38356', '7942520', '愛媛県', 'エヒメケン', '越智郡上島町', 'オチグンカミジマチョウ', '弓削佐島', 'ユゲサシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県越智郡上島町弓削豊島', '38', '38356', '7942530', '愛媛県', 'エヒメケン', '越智郡上島町', 'オチグンカミジマチョウ', '弓削豊島', 'ユゲトヨシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県越智郡上島町魚島一番耕地', '38', '38356', '7942540', '愛媛県', 'エヒメケン', '越智郡上島町', 'オチグンカミジマチョウ', '魚島一番耕地', 'ウオシマイチバンコウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県越智郡上島町魚島二番耕地', '38', '38356', '7942541', '愛媛県', 'エヒメケン', '越智郡上島町', 'オチグンカミジマチョウ', '魚島二番耕地', 'ウオシマニバンコウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県越智郡上島町魚島三番耕地', '38', '38356', '7942542', '愛媛県', 'エヒメケン', '越智郡上島町', 'オチグンカミジマチョウ', '魚島三番耕地', 'ウオシマサンバンコウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県越智郡上島町生名', '38', '38356', '7942550', '愛媛県', 'エヒメケン', '越智郡上島町', 'オチグンカミジマチョウ', '生名', 'イキナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県大洲市', '38', '38207', '7950000', '愛媛県', 'エヒメケン', '大洲市', 'オオズシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('101501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県大洲市北只', '38', '38207', '7950001', '愛媛県', 'エヒメケン', '大洲市', 'オオズシ', '北只', 'キタタダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県大洲市松尾', '38', '38207', '7950002', '愛媛県', 'エヒメケン', '大洲市', 'オオズシ', '松尾', 'マツオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県大洲市梅川', '38', '38207', '7950003', '愛媛県', 'エヒメケン', '大洲市', 'オオズシ', '梅川', 'ウメガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県大洲市長谷', '38', '38207', '7950004', '愛媛県', 'エヒメケン', '大洲市', 'オオズシ', '長谷', 'ナガタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県大洲市横野久保', '38', '38207', '7950005', '愛媛県', 'エヒメケン', '大洲市', 'オオズシ', '横野', 'ヨコノ', null, null, '久保', 'クボ');
INSERT INTO `ms_addresses` VALUES ('101506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県大洲市野佐来', '38', '38207', '7950006', '愛媛県', 'エヒメケン', '大洲市', 'オオズシ', '野佐来', 'ヤサライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県大洲市稲積', '38', '38207', '7950007', '愛媛県', 'エヒメケン', '大洲市', 'オオズシ', '稲積', 'イナズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県大洲市黒木', '38', '38207', '7950008', '愛媛県', 'エヒメケン', '大洲市', 'オオズシ', '黒木', 'クロギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県大洲市北裏', '38', '38207', '7950009', '愛媛県', 'エヒメケン', '大洲市', 'オオズシ', '北裏', 'キタウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県大洲市柚木', '38', '38207', '7950011', '愛媛県', 'エヒメケン', '大洲市', 'オオズシ', '柚木', 'ユノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県大洲市大洲', '38', '38207', '7950012', '愛媛県', 'エヒメケン', '大洲市', 'オオズシ', '大洲', 'オオズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県大洲市西大洲', '38', '38207', '7950013', '愛媛県', 'エヒメケン', '大洲市', 'オオズシ', '西大洲', 'ニシオオズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県大洲市平野町野田', '38', '38207', '7950021', '愛媛県', 'エヒメケン', '大洲市', 'オオズシ', '平野町野田', 'ヒラノチョウノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県大洲市平野町平地', '38', '38207', '7950022', '愛媛県', 'エヒメケン', '大洲市', 'オオズシ', '平野町平地', 'ヒラノチョウヒラジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県大洲市平野町平地横野', '38', '38207', '7950023', '愛媛県', 'エヒメケン', '大洲市', 'オオズシ', '平野町平地', 'ヒラノチョウヒラジ', null, null, '横野', 'ヨコノ');
INSERT INTO `ms_addresses` VALUES ('101516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県大洲市高山', '38', '38207', '7950024', '愛媛県', 'エヒメケン', '大洲市', 'オオズシ', '高山', 'タカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県大洲市阿蔵', '38', '38207', '7950025', '愛媛県', 'エヒメケン', '大洲市', 'オオズシ', '阿蔵', 'アゾウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県大洲市多田', '38', '38207', '7950031', '愛媛県', 'エヒメケン', '大洲市', 'オオズシ', '多田', 'タダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県大洲市上須戒', '38', '38207', '7950032', '愛媛県', 'エヒメケン', '大洲市', 'オオズシ', '上須戒', 'カミスガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県大洲市八多喜町', '38', '38207', '7950041', '愛媛県', 'エヒメケン', '大洲市', 'オオズシ', '八多喜町', 'ハタキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県大洲市米津', '38', '38207', '7950042', '愛媛県', 'エヒメケン', '大洲市', 'オオズシ', '米津', 'ヨナヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県大洲市米津甲', '38', '38207', '7950043', '愛媛県', 'エヒメケン', '大洲市', 'オオズシ', '米津', 'ヨナヅ', null, null, '甲', 'コウ');
INSERT INTO `ms_addresses` VALUES ('101523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県大洲市手成', '38', '38207', '7950044', '愛媛県', 'エヒメケン', '大洲市', 'オオズシ', '手成', 'テナル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県大洲市東宇山', '38', '38207', '7950045', '愛媛県', 'エヒメケン', '大洲市', 'オオズシ', '東宇山', 'ヒガシウヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県大洲市春賀', '38', '38207', '7950046', '愛媛県', 'エヒメケン', '大洲市', 'オオズシ', '春賀', 'ハルカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県大洲市五郎', '38', '38207', '7950051', '愛媛県', 'エヒメケン', '大洲市', 'オオズシ', '五郎', 'ゴロウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県大洲市若宮', '38', '38207', '7950052', '愛媛県', 'エヒメケン', '大洲市', 'オオズシ', '若宮', 'ワカミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県大洲市常磐町', '38', '38207', '7950053', '愛媛県', 'エヒメケン', '大洲市', 'オオズシ', '常磐町', 'トキワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県大洲市中村', '38', '38207', '7950054', '愛媛県', 'エヒメケン', '大洲市', 'オオズシ', '中村', 'ナカムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県大洲市徳森', '38', '38207', '7950061', '愛媛県', 'エヒメケン', '大洲市', 'オオズシ', '徳森', 'トクノモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県大洲市市木', '38', '38207', '7950062', '愛媛県', 'エヒメケン', '大洲市', 'オオズシ', '市木', 'イチギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県大洲市田口', '38', '38207', '7950063', '愛媛県', 'エヒメケン', '大洲市', 'オオズシ', '田口', 'タノクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県大洲市東大洲', '38', '38207', '7950064', '愛媛県', 'エヒメケン', '大洲市', 'オオズシ', '東大洲', 'ヒガシオオズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県大洲市東若宮', '38', '38207', '7950065', '愛媛県', 'エヒメケン', '大洲市', 'オオズシ', '東若宮', 'ヒガシワカミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県大洲市新谷乙', '38', '38207', '7950071', '愛媛県', 'エヒメケン', '大洲市', 'オオズシ', '新谷乙', 'ニイヤオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県大洲市新谷甲', '38', '38207', '7950072', '愛媛県', 'エヒメケン', '大洲市', 'オオズシ', '新谷甲', 'ニイヤコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県大洲市新谷町', '38', '38207', '7950073', '愛媛県', 'エヒメケン', '大洲市', 'オオズシ', '新谷町', 'ニイヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県大洲市恋木', '38', '38207', '7950074', '愛媛県', 'エヒメケン', '大洲市', 'オオズシ', '恋木', 'コイノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県大洲市喜多山', '38', '38207', '7950075', '愛媛県', 'エヒメケン', '大洲市', 'オオズシ', '喜多山', 'キタヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県大洲市藤縄', '38', '38207', '7950076', '愛媛県', 'エヒメケン', '大洲市', 'オオズシ', '藤縄', 'フジナワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県大洲市柳沢', '38', '38207', '7950077', '愛媛県', 'エヒメケン', '大洲市', 'オオズシ', '柳沢', 'ヤナギサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県大洲市田処', '38', '38207', '7950078', '愛媛県', 'エヒメケン', '大洲市', 'オオズシ', '田処', 'タドコロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県大洲市菅田町菅田甲', '38', '38207', '7950081', '愛媛県', 'エヒメケン', '大洲市', 'オオズシ', '菅田町菅田甲', 'スゲタチョウスゲタコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県大洲市菅田町菅田乙', '38', '38207', '7950082', '愛媛県', 'エヒメケン', '大洲市', 'オオズシ', '菅田町菅田乙', 'スゲタチョウスゲタオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県大洲市菅田町大竹', '38', '38207', '7950083', '愛媛県', 'エヒメケン', '大洲市', 'オオズシ', '菅田町大竹', 'スゲタチョウオオダケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県大洲市菅田町宇津甲', '38', '38207', '7950084', '愛媛県', 'エヒメケン', '大洲市', 'オオズシ', '菅田町宇津甲', 'スゲタチョウウズコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県大洲市菅田町宇津乙', '38', '38207', '7950085', '愛媛県', 'エヒメケン', '大洲市', 'オオズシ', '菅田町宇津乙', 'スゲタチョウウズオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県大洲市成能', '38', '38207', '7950086', '愛媛県', 'エヒメケン', '大洲市', 'オオズシ', '成能', 'ナルノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県大洲市森山', '38', '38207', '7950087', '愛媛県', 'エヒメケン', '大洲市', 'オオズシ', '森山', 'モリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県大洲市宇和川', '38', '38207', '7950088', '愛媛県', 'エヒメケン', '大洲市', 'オオズシ', '宇和川', 'ウワガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県大洲市蔵川', '38', '38207', '7950089', '愛媛県', 'エヒメケン', '大洲市', 'オオズシ', '蔵川', 'クラカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県喜多郡内子町五十崎', '38', '38422', '7950301', '愛媛県', 'エヒメケン', '喜多郡内子町', 'キタグンウチコチョウ', '五十崎', 'イカザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県喜多郡内子町大久喜', '38', '38422', '7950302', '愛媛県', 'エヒメケン', '喜多郡内子町', 'キタグンウチコチョウ', '大久喜', 'オオグキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県喜多郡内子町平岡', '38', '38422', '7950303', '愛媛県', 'エヒメケン', '喜多郡内子町', 'キタグンウチコチョウ', '平岡', 'ヒラオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県喜多郡内子町重松', '38', '38422', '7950304', '愛媛県', 'エヒメケン', '喜多郡内子町', 'キタグンウチコチョウ', '重松', 'シゲマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県喜多郡内子町宿間', '38', '38422', '7950305', '愛媛県', 'エヒメケン', '喜多郡内子町', 'キタグンウチコチョウ', '宿間', 'シュクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県喜多郡内子町福岡', '38', '38422', '7950306', '愛媛県', 'エヒメケン', '喜多郡内子町', 'キタグンウチコチョウ', '福岡', 'フクオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県喜多郡内子町北表', '38', '38422', '7950307', '愛媛県', 'エヒメケン', '喜多郡内子町', 'キタグンウチコチョウ', '北表', 'キタオモテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県喜多郡内子町山鳥坂', '38', '38422', '7950308', '愛媛県', 'エヒメケン', '喜多郡内子町', 'キタグンウチコチョウ', '山鳥坂', 'ヤマトサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県喜多郡内子町只海', '38', '38422', '7950309', '愛媛県', 'エヒメケン', '喜多郡内子町', 'キタグンウチコチョウ', '只海', 'タダノウミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県八幡浜市', '38', '38204', '7960000', '愛媛県', 'エヒメケン', '八幡浜市', 'ヤワタハマシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('101575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県八幡浜市向灘', '38', '38204', '7960001', '愛媛県', 'エヒメケン', '八幡浜市', 'ヤワタハマシ', '向灘', 'ムカイナダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県八幡浜市大平花園町', '38', '38204', '7960002', '愛媛県', 'エヒメケン', '八幡浜市', 'ヤワタハマシ', '大平', 'オオヒラ', null, null, '花園町', 'ハナゾノチョウ');
INSERT INTO `ms_addresses` VALUES ('101577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県八幡浜市大平', '38', '38204', '7960003', '愛媛県', 'エヒメケン', '八幡浜市', 'ヤワタハマシ', '大平', 'オオヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県八幡浜市大平津羽井', '38', '38204', '7960004', '愛媛県', 'エヒメケン', '八幡浜市', 'ヤワタハマシ', '大平', 'オオヒラ', null, null, '津羽井', 'ツバイ');
INSERT INTO `ms_addresses` VALUES ('101579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県八幡浜市高野地', '38', '38204', '7960005', '愛媛県', 'エヒメケン', '八幡浜市', 'ヤワタハマシ', '高野地', 'タカノジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県八幡浜市松柏', '38', '38204', '7960010', '愛媛県', 'エヒメケン', '八幡浜市', 'ヤワタハマシ', '松柏', 'マツカヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県八幡浜市木多町', '38', '38204', '7960011', '愛媛県', 'エヒメケン', '八幡浜市', 'ヤワタハマシ', '木多町', 'キタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県八幡浜市南柏', '38', '38204', '7960012', '愛媛県', 'エヒメケン', '八幡浜市', 'ヤワタハマシ', '南柏', 'ミナミガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県八幡浜市山越', '38', '38204', '7960013', '愛媛県', 'エヒメケン', '八幡浜市', 'ヤワタハマシ', '山越', 'ヤマグイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県八幡浜市新和田町', '38', '38204', '7960014', '愛媛県', 'エヒメケン', '八幡浜市', 'ヤワタハマシ', '新和田町', 'シンワダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県八幡浜市桧谷', '38', '38204', '7960021', '愛媛県', 'エヒメケン', '八幡浜市', 'ヤワタハマシ', '桧谷', 'ヒノキダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県八幡浜市駅前', '38', '38204', '7960022', '愛媛県', 'エヒメケン', '八幡浜市', 'ヤワタハマシ', '駅前', 'エキマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県八幡浜市神宮前', '38', '38204', '7960023', '愛媛県', 'エヒメケン', '八幡浜市', 'ヤワタハマシ', '神宮前', 'ジングウマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県八幡浜市神宮通', '38', '38204', '7960024', '愛媛県', 'エヒメケン', '八幡浜市', 'ヤワタハマシ', '神宮通', 'ジングウドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県八幡浜市東矢野町', '38', '38204', '7960025', '愛媛県', 'エヒメケン', '八幡浜市', 'ヤワタハマシ', '東矢野町', 'ヒガシヤノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県八幡浜市矢野町', '38', '38204', '7960026', '愛媛県', 'エヒメケン', '八幡浜市', 'ヤワタハマシ', '矢野町', 'ヤノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県八幡浜市松蔭町', '38', '38204', '7960027', '愛媛県', 'エヒメケン', '八幡浜市', 'ヤワタハマシ', '松蔭町', 'マツカゲチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県八幡浜市清水町', '38', '38204', '7960028', '愛媛県', 'エヒメケン', '八幡浜市', 'ヤワタハマシ', '清水町', 'シミズマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県八幡浜市花小路', '38', '38204', '7960029', '愛媛県', 'エヒメケン', '八幡浜市', 'ヤワタハマシ', '花小路', 'ハナコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県八幡浜市江戸岡', '38', '38204', '7960031', '愛媛県', 'エヒメケン', '八幡浜市', 'ヤワタハマシ', '江戸岡', 'エドオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県八幡浜市東新川', '38', '38204', '7960032', '愛媛県', 'エヒメケン', '八幡浜市', 'ヤワタハマシ', '東新川', 'ヒガシシンカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県八幡浜市大正町', '38', '38204', '7960033', '愛媛県', 'エヒメケン', '八幡浜市', 'ヤワタハマシ', '大正町', 'タイショウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県八幡浜市浜田町', '38', '38204', '7960034', '愛媛県', 'エヒメケン', '八幡浜市', 'ヤワタハマシ', '浜田町', 'ハマダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県八幡浜市須崎', '38', '38204', '7960035', '愛媛県', 'エヒメケン', '八幡浜市', 'ヤワタハマシ', '須崎', 'スサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県八幡浜市新川', '38', '38204', '7960036', '愛媛県', 'エヒメケン', '八幡浜市', 'ヤワタハマシ', '新川', 'シンカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県八幡浜市昭和通', '38', '38204', '7960037', '愛媛県', 'エヒメケン', '八幡浜市', 'ヤワタハマシ', '昭和通', 'ショウワドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県八幡浜市裁判所通', '38', '38204', '7960041', '愛媛県', 'エヒメケン', '八幡浜市', 'ヤワタハマシ', '裁判所通', 'サイバンショドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県八幡浜市喜多町', '38', '38204', '7960042', '愛媛県', 'エヒメケン', '八幡浜市', 'ヤワタハマシ', '喜多町', 'キタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県八幡浜市東近江屋町', '38', '38204', '7960043', '愛媛県', 'エヒメケン', '八幡浜市', 'ヤワタハマシ', '東近江屋町', 'ヒガシオオミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県八幡浜市西近江屋町', '38', '38204', '7960044', '愛媛県', 'エヒメケン', '八幡浜市', 'ヤワタハマシ', '西近江屋町', 'ニシオオミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県八幡浜市西近江屋町浜通', '38', '38204', '7960045', '愛媛県', 'エヒメケン', '八幡浜市', 'ヤワタハマシ', '西近江屋町浜通', 'ニシオオミヤチョウハマドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県八幡浜市旧港', '38', '38204', '7960046', '愛媛県', 'エヒメケン', '八幡浜市', 'ヤワタハマシ', '旧港', 'キュウミナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県八幡浜市白浜通', '38', '38204', '7960047', '愛媛県', 'エヒメケン', '八幡浜市', 'ヤワタハマシ', '白浜通', 'シロハマドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県八幡浜市北浜', '38', '38204', '7960048', '愛媛県', 'エヒメケン', '八幡浜市', 'ヤワタハマシ', '北浜', 'キタハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県八幡浜市幸町', '38', '38204', '7960051', '愛媛県', 'エヒメケン', '八幡浜市', 'ヤワタハマシ', '幸町', 'サイワイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県八幡浜市松本町', '38', '38204', '7960052', '愛媛県', 'エヒメケン', '八幡浜市', 'ヤワタハマシ', '松本町', 'マツモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県八幡浜市海望園', '38', '38204', '7960053', '愛媛県', 'エヒメケン', '八幡浜市', 'ヤワタハマシ', '海望園', 'カイボウエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県八幡浜市琴平町', '38', '38204', '7960054', '愛媛県', 'エヒメケン', '八幡浜市', 'ヤワタハマシ', '琴平町', 'コトヒラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県八幡浜市大門', '38', '38204', '7960055', '愛媛県', 'エヒメケン', '八幡浜市', 'ヤワタハマシ', '大門', 'ダイモン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県八幡浜市愛宕', '38', '38204', '7960056', '愛媛県', 'エヒメケン', '八幡浜市', 'ヤワタハマシ', '愛宕', 'アタゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県八幡浜市海老崎', '38', '38204', '7960061', '愛媛県', 'エヒメケン', '八幡浜市', 'ヤワタハマシ', '海老崎', 'エビサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県八幡浜市新栄町', '38', '38204', '7960062', '愛媛県', 'エヒメケン', '八幡浜市', 'ヤワタハマシ', '新栄町', 'シンエイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県八幡浜市横町', '38', '38204', '7960063', '愛媛県', 'エヒメケン', '八幡浜市', 'ヤワタハマシ', '横町', 'ヨコマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県八幡浜市船場通', '38', '38204', '7960064', '愛媛県', 'エヒメケン', '八幡浜市', 'ヤワタハマシ', '船場通', 'センバドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県八幡浜市片山町', '38', '38204', '7960065', '愛媛県', 'エヒメケン', '八幡浜市', 'ヤワタハマシ', '片山町', 'カタヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県八幡浜市本町', '38', '38204', '7960066', '愛媛県', 'エヒメケン', '八幡浜市', 'ヤワタハマシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県八幡浜市中央', '38', '38204', '7960067', '愛媛県', 'エヒメケン', '八幡浜市', 'ヤワタハマシ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県八幡浜市浜之町', '38', '38204', '7960068', '愛媛県', 'エヒメケン', '八幡浜市', 'ヤワタハマシ', '浜之町', 'ハマノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県八幡浜市下道', '38', '38204', '7960069', '愛媛県', 'エヒメケン', '八幡浜市', 'ヤワタハマシ', '下道', 'シタミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県八幡浜市新町', '38', '38204', '7960071', '愛媛県', 'エヒメケン', '八幡浜市', 'ヤワタハマシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県八幡浜市港町', '38', '38204', '7960072', '愛媛県', 'エヒメケン', '八幡浜市', 'ヤワタハマシ', '港町', 'ミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県八幡浜市戎町', '38', '38204', '7960073', '愛媛県', 'エヒメケン', '八幡浜市', 'ヤワタハマシ', '戎町', 'エビスマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県八幡浜市新港', '38', '38204', '7960074', '愛媛県', 'エヒメケン', '八幡浜市', 'ヤワタハマシ', '新港', 'シンミナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県八幡浜市仲之町', '38', '38204', '7960075', '愛媛県', 'エヒメケン', '八幡浜市', 'ヤワタハマシ', '仲之町', 'ナカノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県八幡浜市千代田町', '38', '38204', '7960076', '愛媛県', 'エヒメケン', '八幡浜市', 'ヤワタハマシ', '千代田町', 'チヨダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県八幡浜市旧役場前通', '38', '38204', '7960077', '愛媛県', 'エヒメケン', '八幡浜市', 'ヤワタハマシ', '旧役場前通', 'キュウヤクバマエドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県八幡浜市中央マーケット', '38', '38204', '7960078', '愛媛県', 'エヒメケン', '八幡浜市', 'ヤワタハマシ', '中央マーケット', 'チュウオウマーケット', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県八幡浜市朝汐橋', '38', '38204', '7960081', '愛媛県', 'エヒメケン', '八幡浜市', 'ヤワタハマシ', '朝汐橋', 'アサシオバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県八幡浜市北大黒町', '38', '38204', '7960082', '愛媛県', 'エヒメケン', '八幡浜市', 'ヤワタハマシ', '北大黒町', 'キタダイコクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県八幡浜市大黒町', '38', '38204', '7960083', '愛媛県', 'エヒメケン', '八幡浜市', 'ヤワタハマシ', '大黒町', 'ダイコクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県八幡浜市南大黒町', '38', '38204', '7960084', '愛媛県', 'エヒメケン', '八幡浜市', 'ヤワタハマシ', '南大黒町', 'ミナミダイコクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県八幡浜市天神通', '38', '38204', '7960085', '愛媛県', 'エヒメケン', '八幡浜市', 'ヤワタハマシ', '天神通', 'テンジンドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県八幡浜市旭町', '38', '38204', '7960086', '愛媛県', 'エヒメケン', '八幡浜市', 'ヤワタハマシ', '旭町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県八幡浜市沖新田', '38', '38204', '7960087', '愛媛県', 'エヒメケン', '八幡浜市', 'ヤワタハマシ', '沖新田', 'オキシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県八幡浜市', '38', '38204', '7960088', '愛媛県', 'エヒメケン', '八幡浜市', 'ヤワタハマシ', null, '　', '（直番地）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('101640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県八幡浜市保内町喜木', '38', '38204', '7960111', '愛媛県', 'エヒメケン', '八幡浜市', 'ヤワタハマシ', '保内町喜木', 'ホナイチョウキキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県八幡浜市保内町須川', '38', '38204', '7960112', '愛媛県', 'エヒメケン', '八幡浜市', 'ヤワタハマシ', '保内町須川', 'ホナイチョウスガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県八幡浜市日土町', '38', '38204', '7960170', '愛媛県', 'エヒメケン', '八幡浜市', 'ヤワタハマシ', '日土町', 'ヒヅチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県八幡浜市保内町川之石', '38', '38204', '7960201', '愛媛県', 'エヒメケン', '八幡浜市', 'ヤワタハマシ', '保内町川之石', 'ホナイチョウカワノイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県八幡浜市保内町宮内', '38', '38204', '7960202', '愛媛県', 'エヒメケン', '八幡浜市', 'ヤワタハマシ', '保内町宮内', 'ホナイチョウミヤウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県八幡浜市保内町磯崎', '38', '38204', '7960203', '愛媛県', 'エヒメケン', '八幡浜市', 'ヤワタハマシ', '保内町磯崎', 'ホナイチョウイサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県八幡浜市保内町喜木津', '38', '38204', '7960204', '愛媛県', 'エヒメケン', '八幡浜市', 'ヤワタハマシ', '保内町喜木津', 'ホナイチョウキキツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県八幡浜市保内町広早', '38', '38204', '7960205', '愛媛県', 'エヒメケン', '八幡浜市', 'ヤワタハマシ', '保内町広早', 'ホナイチョウヒロハヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西宇和郡伊方町', '38', '38442', '7960300', '愛媛県', 'エヒメケン', '西宇和郡伊方町', 'ニシウワグンイカタチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('101652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西宇和郡伊方町湊浦', '38', '38442', '7960301', '愛媛県', 'エヒメケン', '西宇和郡伊方町', 'ニシウワグンイカタチョウ', '湊浦', 'ミナトウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西宇和郡伊方町小中浦', '38', '38442', '7960302', '愛媛県', 'エヒメケン', '西宇和郡伊方町', 'ニシウワグンイカタチョウ', '小中浦', 'コナカウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西宇和郡伊方町亀浦', '38', '38442', '7960303', '愛媛県', 'エヒメケン', '西宇和郡伊方町', 'ニシウワグンイカタチョウ', '亀浦', 'カメウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西宇和郡伊方町伊方越', '38', '38442', '7960304', '愛媛県', 'エヒメケン', '西宇和郡伊方町', 'ニシウワグンイカタチョウ', '伊方越', 'イカタゴシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西宇和郡伊方町河内', '38', '38442', '7960305', '愛媛県', 'エヒメケン', '西宇和郡伊方町', 'ニシウワグンイカタチョウ', '河内', 'カワウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西宇和郡伊方町仁田之浜', '38', '38442', '7960306', '愛媛県', 'エヒメケン', '西宇和郡伊方町', 'ニシウワグンイカタチョウ', '仁田之浜', 'ニタノハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西宇和郡伊方町中之浜', '38', '38442', '7960307', '愛媛県', 'エヒメケン', '西宇和郡伊方町', 'ニシウワグンイカタチョウ', '中之浜', 'ナカノハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西宇和郡伊方町大浜', '38', '38442', '7960308', '愛媛県', 'エヒメケン', '西宇和郡伊方町', 'ニシウワグンイカタチョウ', '大浜', 'オオハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西宇和郡伊方町中浦', '38', '38442', '7960311', '愛媛県', 'エヒメケン', '西宇和郡伊方町', 'ニシウワグンイカタチョウ', '中浦', 'ナカウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西宇和郡伊方町川永田', '38', '38442', '7960312', '愛媛県', 'エヒメケン', '西宇和郡伊方町', 'ニシウワグンイカタチョウ', '川永田', 'カワナガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西宇和郡伊方町豊之浦', '38', '38442', '7960313', '愛媛県', 'エヒメケン', '西宇和郡伊方町', 'ニシウワグンイカタチョウ', '豊之浦', 'トヨノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西宇和郡伊方町九町', '38', '38442', '7960421', '愛媛県', 'エヒメケン', '西宇和郡伊方町', 'ニシウワグンイカタチョウ', '九町', 'クチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西宇和郡伊方町二見', '38', '38442', '7960422', '愛媛県', 'エヒメケン', '西宇和郡伊方町', 'ニシウワグンイカタチョウ', '二見', 'フタミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西宇和郡伊方町足成', '38', '38442', '7960501', '愛媛県', 'エヒメケン', '西宇和郡伊方町', 'ニシウワグンイカタチョウ', '足成', 'アシナル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西宇和郡伊方町三机', '38', '38442', '7960502', '愛媛県', 'エヒメケン', '西宇和郡伊方町', 'ニシウワグンイカタチョウ', '三机', 'ミツクエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西宇和郡伊方町大江', '38', '38442', '7960503', '愛媛県', 'エヒメケン', '西宇和郡伊方町', 'ニシウワグンイカタチョウ', '大江', 'オオエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西宇和郡伊方町志津', '38', '38442', '7960504', '愛媛県', 'エヒメケン', '西宇和郡伊方町', 'ニシウワグンイカタチョウ', '志津', 'シツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西宇和郡伊方町小島', '38', '38442', '7960505', '愛媛県', 'エヒメケン', '西宇和郡伊方町', 'ニシウワグンイカタチョウ', '小島', 'コジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西宇和郡伊方町塩成', '38', '38442', '7960506', '愛媛県', 'エヒメケン', '西宇和郡伊方町', 'ニシウワグンイカタチョウ', '塩成', 'シオナシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西宇和郡伊方町川之浜', '38', '38442', '7960611', '愛媛県', 'エヒメケン', '西宇和郡伊方町', 'ニシウワグンイカタチョウ', '川之浜', 'カワノハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西宇和郡伊方町大久', '38', '38442', '7960612', '愛媛県', 'エヒメケン', '西宇和郡伊方町', 'ニシウワグンイカタチョウ', '大久', 'オオク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西宇和郡伊方町神崎', '38', '38442', '7960613', '愛媛県', 'エヒメケン', '西宇和郡伊方町', 'ニシウワグンイカタチョウ', '神崎', 'コウザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西宇和郡伊方町田部', '38', '38442', '7960614', '愛媛県', 'エヒメケン', '西宇和郡伊方町', 'ニシウワグンイカタチョウ', '田部', 'タブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西宇和郡伊方町高茂', '38', '38442', '7960615', '愛媛県', 'エヒメケン', '西宇和郡伊方町', 'ニシウワグンイカタチョウ', '高茂', 'コウモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西宇和郡伊方町三崎', '38', '38442', '7960801', '愛媛県', 'エヒメケン', '西宇和郡伊方町', 'ニシウワグンイカタチョウ', '三崎', 'ミサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西宇和郡伊方町高浦', '38', '38442', '7960802', '愛媛県', 'エヒメケン', '西宇和郡伊方町', 'ニシウワグンイカタチョウ', '高浦', 'タカウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西宇和郡伊方町佐田', '38', '38442', '7960803', '愛媛県', 'エヒメケン', '西宇和郡伊方町', 'ニシウワグンイカタチョウ', '佐田', 'サダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西宇和郡伊方町大佐田', '38', '38442', '7960804', '愛媛県', 'エヒメケン', '西宇和郡伊方町', 'ニシウワグンイカタチョウ', '大佐田', 'オオサダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西宇和郡伊方町井野浦', '38', '38442', '7960805', '愛媛県', 'エヒメケン', '西宇和郡伊方町', 'ニシウワグンイカタチョウ', '井野浦', 'イノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西宇和郡伊方町松', '38', '38442', '7960811', '愛媛県', 'エヒメケン', '西宇和郡伊方町', 'ニシウワグンイカタチョウ', '松', 'マツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西宇和郡伊方町明神', '38', '38442', '7960812', '愛媛県', 'エヒメケン', '西宇和郡伊方町', 'ニシウワグンイカタチョウ', '明神', 'ミョウジン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西宇和郡伊方町二名津', '38', '38442', '7960813', '愛媛県', 'エヒメケン', '西宇和郡伊方町', 'ニシウワグンイカタチョウ', '二名津', 'フタナヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西宇和郡伊方町平礒', '38', '38442', '7960814', '愛媛県', 'エヒメケン', '西宇和郡伊方町', 'ニシウワグンイカタチョウ', '平礒', 'ヒライソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西宇和郡伊方町釜木', '38', '38442', '7960815', '愛媛県', 'エヒメケン', '西宇和郡伊方町', 'ニシウワグンイカタチョウ', '釜木', 'カマギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西宇和郡伊方町名取', '38', '38442', '7960816', '愛媛県', 'エヒメケン', '西宇和郡伊方町', 'ニシウワグンイカタチョウ', '名取', 'ナトリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西宇和郡伊方町与侈', '38', '38442', '7960821', '愛媛県', 'エヒメケン', '西宇和郡伊方町', 'ニシウワグンイカタチョウ', '与侈', 'ヨボコリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西宇和郡伊方町串', '38', '38442', '7960822', '愛媛県', 'エヒメケン', '西宇和郡伊方町', 'ニシウワグンイカタチョウ', '串', 'クシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西宇和郡伊方町正野', '38', '38442', '7960823', '愛媛県', 'エヒメケン', '西宇和郡伊方町', 'ニシウワグンイカタチョウ', '正野', 'ショウノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西予市三瓶町周木', '38', '38214', '7960901', '愛媛県', 'エヒメケン', '西予市', 'セイヨシ', '三瓶町周木', 'ミカメチョウシュウキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西予市三瓶町長早', '38', '38214', '7960902', '愛媛県', 'エヒメケン', '西予市', 'セイヨシ', '三瓶町長早', 'ミカメチョウナガハヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西予市三瓶町二及', '38', '38214', '7960903', '愛媛県', 'エヒメケン', '西予市', 'セイヨシ', '三瓶町二及', 'ミカメチョウニギュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西予市三瓶町垣生', '38', '38214', '7960904', '愛媛県', 'エヒメケン', '西予市', 'セイヨシ', '三瓶町垣生', 'ミカメチョウハブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西予市三瓶町鴫山', '38', '38214', '7960905', '愛媛県', 'エヒメケン', '西予市', 'セイヨシ', '三瓶町鴫山', 'ミカメチョウシギヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西予市三瓶町和泉', '38', '38214', '7960906', '愛媛県', 'エヒメケン', '西予市', 'セイヨシ', '三瓶町和泉', 'ミカメチョウイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西予市三瓶町朝立', '38', '38214', '7960907', '愛媛県', 'エヒメケン', '西予市', 'セイヨシ', '三瓶町朝立', 'ミカメチョウアサダツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西予市三瓶町津布理', '38', '38214', '7960908', '愛媛県', 'エヒメケン', '西予市', 'セイヨシ', '三瓶町津布理', 'ミカメチョウツブリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西予市三瓶町安土', '38', '38214', '7960909', '愛媛県', 'エヒメケン', '西予市', 'セイヨシ', '三瓶町安土', 'ミカメチョウアヅチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西予市三瓶町有網代', '38', '38214', '7960910', '愛媛県', 'エヒメケン', '西予市', 'セイヨシ', '三瓶町有網代', 'ミカメチョウアラジロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西予市三瓶町有太刀', '38', '38214', '7960911', '愛媛県', 'エヒメケン', '西予市', 'セイヨシ', '三瓶町有太刀', 'ミカメチョウアラタチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西予市三瓶町蔵貫浦', '38', '38214', '7960912', '愛媛県', 'エヒメケン', '西予市', 'セイヨシ', '三瓶町蔵貫浦', 'ミカメチョウクラヌキウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西予市三瓶町蔵貫', '38', '38214', '7960913', '愛媛県', 'エヒメケン', '西予市', 'セイヨシ', '三瓶町蔵貫', 'ミカメチョウクラヌキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西予市三瓶町皆江', '38', '38214', '7960914', '愛媛県', 'エヒメケン', '西予市', 'セイヨシ', '三瓶町皆江', 'ミカメチョウミナエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西予市三瓶町下泊', '38', '38214', '7960915', '愛媛県', 'エヒメケン', '西予市', 'セイヨシ', '三瓶町下泊', 'ミカメチョウシモドマリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県八幡浜市大谷口', '38', '38204', '7968001', '愛媛県', 'エヒメケン', '八幡浜市', 'ヤワタハマシ', '大谷口', 'オオタニグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県八幡浜市広瀬', '38', '38204', '7968002', '愛媛県', 'エヒメケン', '八幡浜市', 'ヤワタハマシ', '広瀬', 'ヒロセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県八幡浜市古町', '38', '38204', '7968003', '愛媛県', 'エヒメケン', '八幡浜市', 'ヤワタハマシ', '古町', 'フルマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県八幡浜市産業通', '38', '38204', '7968004', '愛媛県', 'エヒメケン', '八幡浜市', 'ヤワタハマシ', '産業通', 'サンギョウドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県八幡浜市矢野町徳雲坊', '38', '38204', '7968005', '愛媛県', 'エヒメケン', '八幡浜市', 'ヤワタハマシ', '矢野町', 'ヤノマチ', null, null, '徳雲坊', 'トクウンボウ');
INSERT INTO `ms_addresses` VALUES ('101712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県八幡浜市八代', '38', '38204', '7968006', '愛媛県', 'エヒメケン', '八幡浜市', 'ヤワタハマシ', '八代', 'ヤシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県八幡浜市八代', '38', '38204', '7968007', '愛媛県', 'エヒメケン', '八幡浜市', 'ヤワタハマシ', '八代', 'ヤシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県八幡浜市栗野浦', '38', '38204', '7968008', '愛媛県', 'エヒメケン', '八幡浜市', 'ヤワタハマシ', '栗野浦', 'クリノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県八幡浜市五反田', '38', '38204', '7968010', '愛媛県', 'エヒメケン', '八幡浜市', 'ヤワタハマシ', '五反田', 'ゴタンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県八幡浜市元城団地', '38', '38204', '7968011', '愛媛県', 'エヒメケン', '八幡浜市', 'ヤワタハマシ', '元城団地', 'モトジョウダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県八幡浜市国木', '38', '38204', '7968015', '愛媛県', 'エヒメケン', '八幡浜市', 'ヤワタハマシ', '国木', 'クニギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県八幡浜市郷', '38', '38204', '7968020', '愛媛県', 'エヒメケン', '八幡浜市', 'ヤワタハマシ', '郷', 'ゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県八幡浜市川之内', '38', '38204', '7968025', '愛媛県', 'エヒメケン', '八幡浜市', 'ヤワタハマシ', '川之内', 'カワノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県八幡浜市中津川', '38', '38204', '7968030', '愛媛県', 'エヒメケン', '八幡浜市', 'ヤワタハマシ', '中津川', 'ナカツカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県八幡浜市若山', '38', '38204', '7968035', '愛媛県', 'エヒメケン', '八幡浜市', 'ヤワタハマシ', '若山', 'ワカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県八幡浜市釜倉', '38', '38204', '7968036', '愛媛県', 'エヒメケン', '八幡浜市', 'ヤワタハマシ', '釜倉', 'カマノクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県八幡浜市谷', '38', '38204', '7968037', '愛媛県', 'エヒメケン', '八幡浜市', 'ヤワタハマシ', '谷', 'タニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県八幡浜市横平', '38', '38204', '7968038', '愛媛県', 'エヒメケン', '八幡浜市', 'ヤワタハマシ', '横平', 'ヨコヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県八幡浜市布喜川', '38', '38204', '7968039', '愛媛県', 'エヒメケン', '八幡浜市', 'ヤワタハマシ', '布喜川', 'フキノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県八幡浜市舌間', '38', '38204', '7968040', '愛媛県', 'エヒメケン', '八幡浜市', 'ヤワタハマシ', '舌間', 'シタマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県八幡浜市合田', '38', '38204', '7968041', '愛媛県', 'エヒメケン', '八幡浜市', 'ヤワタハマシ', '合田', 'ゴウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県八幡浜市川上町川名津', '38', '38204', '7968050', '愛媛県', 'エヒメケン', '八幡浜市', 'ヤワタハマシ', '川上町川名津', 'カワカミチョウカワナヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県八幡浜市川上町上泊', '38', '38204', '7968051', '愛媛県', 'エヒメケン', '八幡浜市', 'ヤワタハマシ', '川上町上泊', 'カワカミチョウカミドマリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県八幡浜市川上町白石', '38', '38204', '7968052', '愛媛県', 'エヒメケン', '八幡浜市', 'ヤワタハマシ', '川上町白石', 'カワカミチョウシライシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県八幡浜市真網代', '38', '38204', '7968053', '愛媛県', 'エヒメケン', '八幡浜市', 'ヤワタハマシ', '真網代', 'マアジロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県八幡浜市穴井', '38', '38204', '7968054', '愛媛県', 'エヒメケン', '八幡浜市', 'ヤワタハマシ', '穴井', 'アナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県八幡浜市大島', '38', '38204', '7968060', '愛媛県', 'エヒメケン', '八幡浜市', 'ヤワタハマシ', '大島', 'オオシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西予市', '38', '38214', '7970000', '愛媛県', 'エヒメケン', '西予市', 'セイヨシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('101737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西予市宇和町田野中', '38', '38214', '7970001', '愛媛県', 'エヒメケン', '西予市', 'セイヨシ', '宇和町田野中', 'ウワチョウタノナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西予市宇和町平野', '38', '38214', '7970002', '愛媛県', 'エヒメケン', '西予市', 'セイヨシ', '宇和町平野', 'ウワチョウヒラノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西予市宇和町窪', '38', '38214', '7970003', '愛媛県', 'エヒメケン', '西予市', 'セイヨシ', '宇和町窪', 'ウワチョウクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西予市宇和町伊崎', '38', '38214', '7970004', '愛媛県', 'エヒメケン', '西予市', 'セイヨシ', '宇和町伊崎', 'ウワチョウイサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西予市宇和町常定寺', '38', '38214', '7970005', '愛媛県', 'エヒメケン', '西予市', 'セイヨシ', '宇和町常定寺', 'ウワチョウジョウジョウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西予市宇和町新城', '38', '38214', '7970006', '愛媛県', 'エヒメケン', '西予市', 'セイヨシ', '宇和町新城', 'ウワチョウシンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西予市宇和町明石', '38', '38214', '7970007', '愛媛県', 'エヒメケン', '西予市', 'セイヨシ', '宇和町明石', 'ウワチョウアゲイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西予市宇和町明間', '38', '38214', '7970010', '愛媛県', 'エヒメケン', '西予市', 'セイヨシ', '宇和町明間', 'ウワチョウアカンマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西予市宇和町下川', '38', '38214', '7970011', '愛媛県', 'エヒメケン', '西予市', 'セイヨシ', '宇和町下川', 'ウワチョウヒトウガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西予市宇和町皆田', '38', '38214', '7970012', '愛媛県', 'エヒメケン', '西予市', 'セイヨシ', '宇和町皆田', 'ウワチョウカイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西予市宇和町稲生', '38', '38214', '7970013', '愛媛県', 'エヒメケン', '西予市', 'セイヨシ', '宇和町稲生', 'ウワチョウイノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西予市宇和町伊賀上', '38', '38214', '7970014', '愛媛県', 'エヒメケン', '西予市', 'セイヨシ', '宇和町伊賀上', 'ウワチョウイガジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西予市宇和町卯之町', '38', '38214', '7970015', '愛媛県', 'エヒメケン', '西予市', 'セイヨシ', '宇和町卯之町', 'ウワチョウウノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西予市宇和町神領', '38', '38214', '7970016', '愛媛県', 'エヒメケン', '西予市', 'セイヨシ', '宇和町神領', 'ウワチョウジンリョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西予市宇和町ひまわり', '38', '38214', '7970017', '愛媛県', 'エヒメケン', '西予市', 'セイヨシ', '宇和町ひまわり', 'ウワチョウヒマワリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西予市宇和町下松葉', '38', '38214', '7970018', '愛媛県', 'エヒメケン', '西予市', 'セイヨシ', '宇和町下松葉', 'ウワチョウシモマツバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西予市宇和町久枝', '38', '38214', '7970020', '愛媛県', 'エヒメケン', '西予市', 'セイヨシ', '宇和町久枝', 'ウワチョウヒサエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西予市宇和町野田', '38', '38214', '7970021', '愛媛県', 'エヒメケン', '西予市', 'セイヨシ', '宇和町野田', 'ウワチョウノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西予市宇和町小野田', '38', '38214', '7970022', '愛媛県', 'エヒメケン', '西予市', 'セイヨシ', '宇和町小野田', 'ウワチョウオノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西予市宇和町山田', '38', '38214', '7970023', '愛媛県', 'エヒメケン', '西予市', 'セイヨシ', '宇和町山田', 'ウワチョウヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西予市宇和町西山田', '38', '38214', '7970024', '愛媛県', 'エヒメケン', '西予市', 'セイヨシ', '宇和町西山田', 'ウワチョウニシヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西予市宇和町郷内', '38', '38214', '7970025', '愛媛県', 'エヒメケン', '西予市', 'セイヨシ', '宇和町郷内', 'ウワチョウゴウナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西予市宇和町岩木', '38', '38214', '7970026', '愛媛県', 'エヒメケン', '西予市', 'セイヨシ', '宇和町岩木', 'ウワチョウイワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西予市宇和町小原', '38', '38214', '7970027', '愛媛県', 'エヒメケン', '西予市', 'セイヨシ', '宇和町小原', 'ウワチョウオバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西予市宇和町れんげ', '38', '38214', '7970028', '愛媛県', 'エヒメケン', '西予市', 'セイヨシ', '宇和町れんげ', 'ウワチョウレンゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西予市宇和町永長', '38', '38214', '7970029', '愛媛県', 'エヒメケン', '西予市', 'セイヨシ', '宇和町永長', 'ウワチョウナガオサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西予市宇和町清沢', '38', '38214', '7970030', '愛媛県', 'エヒメケン', '西予市', 'セイヨシ', '宇和町清沢', 'ウワチョウキヨサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西予市宇和町杢所', '38', '38214', '7970031', '愛媛県', 'エヒメケン', '西予市', 'セイヨシ', '宇和町杢所', 'ウワチョウモクショ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西予市宇和町田苗真土', '38', '38214', '7970032', '愛媛県', 'エヒメケン', '西予市', 'セイヨシ', '宇和町田苗真土', 'ウワチョウタナエマツチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西予市宇和町岡山', '38', '38214', '7970033', '愛媛県', 'エヒメケン', '西予市', 'セイヨシ', '宇和町岡山', 'ウワチョウオカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西予市宇和町伊延', '38', '38214', '7970034', '愛媛県', 'エヒメケン', '西予市', 'セイヨシ', '宇和町伊延', 'ウワチョウイノベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西予市宇和町河内', '38', '38214', '7970035', '愛媛県', 'エヒメケン', '西予市', 'セイヨシ', '宇和町河内', 'ウワチョウカワチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西予市宇和町久保', '38', '38214', '7970036', '愛媛県', 'エヒメケン', '西予市', 'セイヨシ', '宇和町久保', 'ウワチョウクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西予市宇和町信里', '38', '38214', '7970037', '愛媛県', 'エヒメケン', '西予市', 'セイヨシ', '宇和町信里', 'ウワチョウノブサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西予市宇和町東多田', '38', '38214', '7970041', '愛媛県', 'エヒメケン', '西予市', 'セイヨシ', '宇和町東多田', 'ウワチョウヒガシタダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西予市宇和町瀬戸', '38', '38214', '7970042', '愛媛県', 'エヒメケン', '西予市', 'セイヨシ', '宇和町瀬戸', 'ウワチョウセト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西予市宇和町大江', '38', '38214', '7970043', '愛媛県', 'エヒメケン', '西予市', 'セイヨシ', '宇和町大江', 'ウワチョウオオエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西予市宇和町加茂', '38', '38214', '7970044', '愛媛県', 'エヒメケン', '西予市', 'セイヨシ', '宇和町加茂', 'ウワチョウカモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西予市宇和町坂戸', '38', '38214', '7970045', '愛媛県', 'エヒメケン', '西予市', 'セイヨシ', '宇和町坂戸', 'ウワチョウサカド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西予市宇和町上松葉', '38', '38214', '7970046', '愛媛県', 'エヒメケン', '西予市', 'セイヨシ', '宇和町上松葉', 'ウワチョウカミマツバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西予市明浜町俵津', '38', '38214', '7970111', '愛媛県', 'エヒメケン', '西予市', 'セイヨシ', '明浜町俵津', 'アケハマチョウタワラヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西予市明浜町渡江', '38', '38214', '7970112', '愛媛県', 'エヒメケン', '西予市', 'セイヨシ', '明浜町渡江', 'アケハマチョウトノエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西予市明浜町狩浜', '38', '38214', '7970113', '愛媛県', 'エヒメケン', '西予市', 'セイヨシ', '明浜町狩浜', 'アケハマチョウカリハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西予市明浜町高山', '38', '38214', '7970201', '愛媛県', 'エヒメケン', '西予市', 'セイヨシ', '明浜町高山', 'アケハマチョウタカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西予市明浜町宮野浦', '38', '38214', '7970202', '愛媛県', 'エヒメケン', '西予市', 'セイヨシ', '明浜町宮野浦', 'アケハマチョウミヤノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西予市明浜町田之浜', '38', '38214', '7970203', '愛媛県', 'エヒメケン', '西予市', 'セイヨシ', '明浜町田之浜', 'アケハマチョウタノハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西予市野村町白髭', '38', '38214', '7971101', '愛媛県', 'エヒメケン', '西予市', 'セイヨシ', '野村町白髭', 'ノムラチョウシラヒゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西予市野村町松渓', '38', '38214', '7971102', '愛媛県', 'エヒメケン', '西予市', 'セイヨシ', '野村町松渓', 'ノムラチョウマツタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西予市野村町四郎谷', '38', '38214', '7971103', '愛媛県', 'エヒメケン', '西予市', 'セイヨシ', '野村町四郎谷', 'ノムラチョウシロウタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西予市野村町河西', '38', '38214', '7971104', '愛媛県', 'エヒメケン', '西予市', 'セイヨシ', '野村町河西', 'ノムラチョウカワサイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西予市野村町長谷', '38', '38214', '7971105', '愛媛県', 'エヒメケン', '西予市', 'セイヨシ', '野村町長谷', 'ノムラチョウナガタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西予市野村町旭', '38', '38214', '7971106', '愛媛県', 'エヒメケン', '西予市', 'セイヨシ', '野村町旭', 'ノムラチョウアサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西予市野村町鳥鹿野', '38', '38214', '7971107', '愛媛県', 'エヒメケン', '西予市', 'セイヨシ', '野村町鳥鹿野', 'ノムラチョウトジガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西予市野村町阿下', '38', '38214', '7971211', '愛媛県', 'エヒメケン', '西予市', 'セイヨシ', '野村町阿下', 'ノムラチョウアゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西予市野村町野村', '38', '38214', '7971212', '愛媛県', 'エヒメケン', '西予市', 'セイヨシ', '野村町野村', 'ノムラチョウノムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西予市野村町片川', '38', '38214', '7971213', '愛媛県', 'エヒメケン', '西予市', 'セイヨシ', '野村町片川', 'ノムラチョウカタカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西予市野村町富野川', '38', '38214', '7971214', '愛媛県', 'エヒメケン', '西予市', 'セイヨシ', '野村町富野川', 'ノムラチョウトミノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西予市野村町高瀬', '38', '38214', '7971215', '愛媛県', 'エヒメケン', '西予市', 'セイヨシ', '野村町高瀬', 'ノムラチョウタカセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西予市野村町蔵良', '38', '38214', '7971216', '愛媛県', 'エヒメケン', '西予市', 'セイヨシ', '野村町蔵良', 'ノムラチョウクララ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西予市野村町平野', '38', '38214', '7971217', '愛媛県', 'エヒメケン', '西予市', 'セイヨシ', '野村町平野', 'ノムラチョウヒラノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西予市野村町予子林', '38', '38214', '7971321', '愛媛県', 'エヒメケン', '西予市', 'セイヨシ', '野村町予子林', 'ノムラチョウヨコバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西予市野村町坂石', '38', '38214', '7971322', '愛媛県', 'エヒメケン', '西予市', 'セイヨシ', '野村町坂石', 'ノムラチョウサカイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西予市野村町釜川', '38', '38214', '7971323', '愛媛県', 'エヒメケン', '西予市', 'セイヨシ', '野村町釜川', 'ノムラチョウカマガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西予市野村町大西', '38', '38214', '7971324', '愛媛県', 'エヒメケン', '西予市', 'セイヨシ', '野村町大西', 'ノムラチョウオオニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西予市野村町中通川', '38', '38214', '7971325', '愛媛県', 'エヒメケン', '西予市', 'セイヨシ', '野村町中通川', 'ノムラチョウナカトオガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西予市野村町鎌田', '38', '38214', '7971326', '愛媛県', 'エヒメケン', '西予市', 'セイヨシ', '野村町鎌田', 'ノムラチョウカマンタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西予市野村町栗木', '38', '38214', '7971327', '愛媛県', 'エヒメケン', '西予市', 'セイヨシ', '野村町栗木', 'ノムラチョウクリノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西予市野村町西', '38', '38214', '7971328', '愛媛県', 'エヒメケン', '西予市', 'セイヨシ', '野村町西', 'ノムラチョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西予市野村町舟戸', '38', '38214', '7971431', '愛媛県', 'エヒメケン', '西予市', 'セイヨシ', '野村町舟戸', 'ノムラチョウフナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西予市野村町惣川', '38', '38214', '7971432', '愛媛県', 'エヒメケン', '西予市', 'セイヨシ', '野村町惣川', 'ノムラチョウソウガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西予市野村町小松', '38', '38214', '7971433', '愛媛県', 'エヒメケン', '西予市', 'セイヨシ', '野村町小松', 'ノムラチョウコマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西予市野村町大野ケ原', '38', '38214', '7971434', '愛媛県', 'エヒメケン', '西予市', 'セイヨシ', '野村町大野ケ原', 'ノムラチョウオオノガハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県大洲市肱川町中居谷', '38', '38207', '7971501', '愛媛県', 'エヒメケン', '大洲市', 'オオズシ', '肱川町中居谷', 'ヒジカワチョウナカイダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県大洲市肱川町名荷谷', '38', '38207', '7971502', '愛媛県', 'エヒメケン', '大洲市', 'オオズシ', '肱川町名荷谷', 'ヒジカワチョウミョウガダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県大洲市肱川町宇和川', '38', '38207', '7971503', '愛媛県', 'エヒメケン', '大洲市', 'オオズシ', '肱川町宇和川', 'ヒジカワチョウウワガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県大洲市肱川町山鳥坂', '38', '38207', '7971504', '愛媛県', 'エヒメケン', '大洲市', 'オオズシ', '肱川町山鳥坂', 'ヒジカワチョウヤマトサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県大洲市肱川町予子林', '38', '38207', '7971505', '愛媛県', 'エヒメケン', '大洲市', 'オオズシ', '肱川町予子林', 'ヒジカワチョウヨコハヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県大洲市肱川町中津', '38', '38207', '7971506', '愛媛県', 'エヒメケン', '大洲市', 'オオズシ', '肱川町中津', 'ヒジカワチョウナカツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県大洲市肱川町大谷', '38', '38207', '7971507', '愛媛県', 'エヒメケン', '大洲市', 'オオズシ', '肱川町大谷', 'ヒジカワチョウオオタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県大洲市肱川町西', '38', '38207', '7971508', '愛媛県', 'エヒメケン', '大洲市', 'オオズシ', '肱川町西', 'ヒジカワチョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県大洲市河辺町植松', '38', '38207', '7971601', '愛媛県', 'エヒメケン', '大洲市', 'オオズシ', '河辺町植松', 'カワベチョウウエマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県大洲市河辺町山鳥坂', '38', '38207', '7971602', '愛媛県', 'エヒメケン', '大洲市', 'オオズシ', '河辺町山鳥坂', 'カワベチョウヤマトサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県大洲市河辺町横山', '38', '38207', '7971603', '愛媛県', 'エヒメケン', '大洲市', 'オオズシ', '河辺町横山', 'カワベチョウヨコヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県大洲市河辺町川崎', '38', '38207', '7971604', '愛媛県', 'エヒメケン', '大洲市', 'オオズシ', '河辺町川崎', 'カワベチョウカワサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県大洲市河辺町河都', '38', '38207', '7971605', '愛媛県', 'エヒメケン', '大洲市', 'オオズシ', '河辺町河都', 'カワベチョウカワト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県大洲市河辺町三嶋', '38', '38207', '7971606', '愛媛県', 'エヒメケン', '大洲市', 'オオズシ', '河辺町三嶋', 'カワベチョウミシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県大洲市河辺町川上', '38', '38207', '7971607', '愛媛県', 'エヒメケン', '大洲市', 'オオズシ', '河辺町川上', 'カワベチョウカワカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県大洲市河辺町北平', '38', '38207', '7971608', '愛媛県', 'エヒメケン', '大洲市', 'オオズシ', '河辺町北平', 'カワベチョウキタヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西予市城川町土居', '38', '38214', '7971701', '愛媛県', 'エヒメケン', '西予市', 'セイヨシ', '城川町土居', 'シロカワチョウドイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西予市城川町古市', '38', '38214', '7971702', '愛媛県', 'エヒメケン', '西予市', 'セイヨシ', '城川町古市', 'シロカワチョウフルイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西予市城川町窪野', '38', '38214', '7971703', '愛媛県', 'エヒメケン', '西予市', 'セイヨシ', '城川町窪野', 'シロカワチョウクボノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西予市城川町川津南', '38', '38214', '7971704', '愛媛県', 'エヒメケン', '西予市', 'セイヨシ', '城川町川津南', 'シロカワチョウカワヅミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西予市城川町高野子', '38', '38214', '7971705', '愛媛県', 'エヒメケン', '西予市', 'セイヨシ', '城川町高野子', 'シロカワチョウタカノコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西予市城川町野井川', '38', '38214', '7971711', '愛媛県', 'エヒメケン', '西予市', 'セイヨシ', '城川町野井川', 'シロカワチョウノイガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西予市城川町遊子谷', '38', '38214', '7971712', '愛媛県', 'エヒメケン', '西予市', 'セイヨシ', '城川町遊子谷', 'シロカワチョウユスタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西予市城川町嘉喜尾', '38', '38214', '7971713', '愛媛県', 'エヒメケン', '西予市', 'セイヨシ', '城川町嘉喜尾', 'シロカワチョウカギオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西予市城川町男河内', '38', '38214', '7971714', '愛媛県', 'エヒメケン', '西予市', 'セイヨシ', '城川町男河内', 'シロカワチョウオンガワチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西予市城川町田穂', '38', '38214', '7971715', '愛媛県', 'エヒメケン', '西予市', 'セイヨシ', '城川町田穂', 'シロカワチョウタオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西予市城川町魚成', '38', '38214', '7971716', '愛媛県', 'エヒメケン', '西予市', 'セイヨシ', '城川町魚成', 'シロカワチョウウオナシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西予市城川町下相', '38', '38214', '7971717', '愛媛県', 'エヒメケン', '西予市', 'セイヨシ', '城川町下相', 'シロカワチョウオリアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市', '38', '38203', '7980000', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('101844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市大浦赤松', '38', '38203', '7980001', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '大浦', 'オオウラ', null, null, '赤松', 'アカマツ');
INSERT INTO `ms_addresses` VALUES ('101845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市大浦', '38', '38203', '7980002', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '大浦', 'オオウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市住吉町', '38', '38203', '7980003', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '住吉町', 'スミヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市朝日町', '38', '38203', '7980004', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '朝日町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市築地町', '38', '38203', '7980005', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '築地町', 'ツキジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市弁天町', '38', '38203', '7980006', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '弁天町', 'ベンテンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市寿町', '38', '38203', '7980007', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '寿町', 'コトブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市北新町', '38', '38203', '7980010', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '北新町', 'キタシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市藤江', '38', '38203', '7980010', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '藤江', 'フジエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市須賀通', '38', '38203', '7980011', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '須賀通', 'スカドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市和霊町', '38', '38203', '7980012', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '和霊町', 'ワレイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市御幸町', '38', '38203', '7980013', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '御幸町', 'ミユキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市和霊公園', '38', '38203', '7980014', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '和霊公園', 'ワレイコウエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市和霊元町', '38', '38203', '7980015', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '和霊元町', 'ワレイモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市和霊中町', '38', '38203', '7980016', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '和霊中町', 'ワレイナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市和霊東町', '38', '38203', '7980017', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '和霊東町', 'ワレイヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市高串', '38', '38203', '7980020', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '高串', 'タカグシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市光満', '38', '38203', '7980021', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '光満', 'ミツマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市伊吹町', '38', '38203', '7980022', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '伊吹町', 'イブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市伊吹町北宇和島町', '38', '38203', '7980023', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '伊吹町', 'イブキチョウ', null, null, '北宇和島町', 'キタウワジマチョウ');
INSERT INTO `ms_addresses` VALUES ('101864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市伊吹町北通', '38', '38203', '7980024', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '伊吹町', 'イブキチョウ', null, null, '北通', 'キタドオリ');
INSERT INTO `ms_addresses` VALUES ('101865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市伊吹町東通', '38', '38203', '7980025', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '伊吹町', 'イブキチョウ', null, null, '東通', 'ヒガシドオリ');
INSERT INTO `ms_addresses` VALUES ('101866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市泉町', '38', '38203', '7980026', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '泉町', 'イズミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市柿原', '38', '38203', '7980027', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '柿原', 'カキハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市曙町', '38', '38203', '7980030', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '曙町', 'アケボノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市栄町港', '38', '38203', '7980031', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '栄町港', 'サカエマチミナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市恵美須町', '38', '38203', '7980032', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '恵美須町', 'エビスマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市鶴島町', '38', '38203', '7980033', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '鶴島町', 'ツルシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市錦町', '38', '38203', '7980034', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '錦町', 'ニシキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市新町', '38', '38203', '7980035', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市天神町', '38', '38203', '7980036', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '天神町', 'テンジンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市丸穂町', '38', '38203', '7980037', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '丸穂町', 'マルオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市丸穂', '38', '38203', '7980038', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '丸穂', 'マルオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市大宮町', '38', '38203', '7980039', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '大宮町', 'オオミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市中央町', '38', '38203', '7980040', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '中央町', 'チュウオウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市本町追手', '38', '38203', '7980041', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '本町追手', 'ホンマチオウテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市愛宕町', '38', '38203', '7980042', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '愛宕町', 'アタゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市宇和津町', '38', '38203', '7980043', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '宇和津町', 'ウワツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市野川', '38', '38203', '7980044', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '野川', 'ノガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市大超寺奥', '38', '38203', '7980045', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '大超寺奥', 'ダイチョウジオク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市堀端町', '38', '38203', '7980050', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '堀端町', 'ホリバタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市広小路', '38', '38203', '7980051', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '広小路', 'ヒロコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市京町', '38', '38203', '7980052', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '京町', 'キョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市賀古町', '38', '38203', '7980053', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '賀古町', 'カコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市笹町', '38', '38203', '7980054', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '笹町', 'ササマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市丸之内', '38', '38203', '7980060', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '丸之内', 'マルノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市御殿町', '38', '38203', '7980061', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '御殿町', 'ゴテンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市桜町', '38', '38203', '7980062', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '桜町', 'サクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市御徒町', '38', '38203', '7980063', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '御徒町', 'オカチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市佐伯町', '38', '38203', '7980064', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '佐伯町', 'サイキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市天赦公園', '38', '38203', '7980065', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '天赦公園', 'テンシャコウエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市文京町', '38', '38203', '7980066', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '文京町', 'ブンキョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市桝形町', '38', '38203', '7980067', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '桝形町', 'マスガタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市明倫町', '38', '38203', '7980068', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '明倫町', 'メイリンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市神田川原', '38', '38203', '7980070', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '神田川原', 'ジンデンガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市妙典寺前', '38', '38203', '7980071', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '妙典寺前', 'ミョウデンジマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市元結掛', '38', '38203', '7980072', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '元結掛', 'モトユイギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市山際', '38', '38203', '7980073', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '山際', 'ヤマギワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市並松', '38', '38203', '7980074', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '並松', 'ナミマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市川内', '38', '38203', '7980075', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '川内', 'カワチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市川内薬師谷', '38', '38203', '7980076', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '川内', 'カワチ', null, null, '薬師谷', 'ヤクシダニ');
INSERT INTO `ms_addresses` VALUES ('101905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市保田', '38', '38203', '7980077', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '保田', 'ヤスダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市祝森', '38', '38203', '7980078', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '祝森', 'イワイノモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市新田町', '38', '38203', '7980080', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '新田町', 'シンデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市中沢町', '38', '38203', '7980081', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '中沢町', 'ナカザワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市長堀', '38', '38203', '7980082', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '長堀', 'ナガホリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市夏目町', '38', '38203', '7980083', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '夏目町', 'ナツメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市寄松', '38', '38203', '7980084', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '寄松', 'ヨリマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市宮下', '38', '38203', '7980085', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '宮下', 'ミヤシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市別当', '38', '38203', '7980086', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '別当', 'ベツトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市坂下津', '38', '38203', '7980087', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '坂下津', 'サカシヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市保手', '38', '38203', '7980088', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '保手', 'ホデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市白浜', '38', '38203', '7980090', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '白浜', 'シラハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市石応', '38', '38203', '7980091', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '石応', 'コクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市小浜', '38', '38203', '7980092', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '小浜', 'コハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市小池', '38', '38203', '7980093', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '小池', 'コイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市蕨', '38', '38203', '7980094', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '蕨', 'ワラビ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市平浦', '38', '38203', '7980095', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '平浦', 'ヒラウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市本九島', '38', '38203', '7980096', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '本九島', 'ホンクシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市百之浦', '38', '38203', '7980097', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '百之浦', 'ヒャクノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市蛤', '38', '38203', '7980098', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '蛤', 'ハマグリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市日振島', '38', '38203', '7980099', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '日振島', 'ヒブリシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市三浦東', '38', '38203', '7980101', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '三浦東', 'ミウラヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市三浦西', '38', '38203', '7980102', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '三浦西', 'ミウラニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市遊子', '38', '38203', '7980103', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '遊子', 'ユス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市下波', '38', '38203', '7980104', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '下波', 'シタバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市蒋渕', '38', '38203', '7980211', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '蒋渕', 'コモブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市戸島', '38', '38203', '7980212', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '戸島', 'トジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市三間町大藤', '38', '38203', '7981101', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '三間町大藤', 'ミマチョウオオフジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市三間町則', '38', '38203', '7981102', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '三間町則', 'ミマチョウスナワチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市三間町成家', '38', '38203', '7981103', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '三間町成家', 'ミマチョウナルイエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市三間町曽根', '38', '38203', '7981104', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '三間町曽根', 'ミマチョウソネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市三間町是能', '38', '38203', '7981105', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '三間町是能', 'ミマチョウコレヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市三間町北増穂', '38', '38203', '7981111', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '三間町北増穂', 'ミマチョウキタマスオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市三間町宮野下', '38', '38203', '7981112', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '三間町宮野下', 'ミマチョウミヤノシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市三間町迫目', '38', '38203', '7981113', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '三間町迫目', 'ミマチョウハザメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市三間町務田', '38', '38203', '7981114', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '三間町務田', 'ミマチョウムデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市三間町戸雁', '38', '38203', '7981115', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '三間町戸雁', 'ミマチョウトガリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市三間町黒井地', '38', '38203', '7981116', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '三間町黒井地', 'ミマチョウクロイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市三間町川之内', '38', '38203', '7981121', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '三間町川之内', 'ミマチョウカワノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市三間町小沢川', '38', '38203', '7981122', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '三間町小沢川', 'ミマチョウコソウガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市三間町元宗', '38', '38203', '7981123', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '三間町元宗', 'ミマチョウモトムネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市三間町増田', '38', '38203', '7981124', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '三間町増田', 'ミマチョウマスダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市三間町土居中', '38', '38203', '7981125', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '三間町土居中', 'ミマチョウドイナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市三間町田川', '38', '38203', '7981131', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '三間町田川', 'ミマチョウタガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市三間町波岡', '38', '38203', '7981132', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '三間町波岡', 'ミマチョウナミオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市三間町中野中', '38', '38203', '7981133', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '三間町中野中', 'ミマチョウナカノナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市三間町金銅', '38', '38203', '7981134', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '三間町金銅', 'ミマチョウカナドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市三間町古藤田', '38', '38203', '7981135', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '三間町古藤田', 'ミマチョウコトウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市三間町大内', '38', '38203', '7981136', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '三間町大内', 'ミマチョウオオウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市三間町兼近', '38', '38203', '7981137', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '三間町兼近', 'ミマチョウカネチカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市三間町土居垣内', '38', '38203', '7981138', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '三間町土居垣内', 'ミマチョウドイカキウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市三間町是延', '38', '38203', '7981139', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '三間町是延', 'ミマチョウコレノブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市三間町音地', '38', '38203', '7981141', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '三間町音地', 'ミマチョウオンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市三間町三間中間', '38', '38203', '7981142', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '三間町三間中間', 'ミマチョウミマナカイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市三間町黒川', '38', '38203', '7981143', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '三間町黒川', 'ミマチョウクロカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県北宇和郡鬼北町', '38', '38488', '7981300', '愛媛県', 'エヒメケン', '北宇和郡鬼北町', 'キタウワグンキホクチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('101962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県北宇和郡鬼北町大宿', '38', '38488', '7981301', '愛媛県', 'エヒメケン', '北宇和郡鬼北町', 'キタウワグンキホクチョウ', '大宿', 'オオジク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県北宇和郡鬼北町下大野', '38', '38488', '7981302', '愛媛県', 'エヒメケン', '北宇和郡鬼北町', 'キタウワグンキホクチョウ', '下大野', 'シモオオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県北宇和郡鬼北町広見', '38', '38488', '7981303', '愛媛県', 'エヒメケン', '北宇和郡鬼北町', 'キタウワグンキホクチョウ', '広見', 'ヒロミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県北宇和郡鬼北町小松', '38', '38488', '7981311', '愛媛県', 'エヒメケン', '北宇和郡鬼北町', 'キタウワグンキホクチョウ', '小松', 'コマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県北宇和郡鬼北町川上', '38', '38488', '7981312', '愛媛県', 'エヒメケン', '北宇和郡鬼北町', 'キタウワグンキホクチョウ', '川上', 'カワカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県北宇和郡鬼北町延川', '38', '38488', '7981313', '愛媛県', 'エヒメケン', '北宇和郡鬼北町', 'キタウワグンキホクチョウ', '延川', 'ノブカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県北宇和郡鬼北町久保', '38', '38488', '7981314', '愛媛県', 'エヒメケン', '北宇和郡鬼北町', 'キタウワグンキホクチョウ', '久保', 'クボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県北宇和郡鬼北町小倉', '38', '38488', '7981321', '愛媛県', 'エヒメケン', '北宇和郡鬼北町', 'キタウワグンキホクチョウ', '小倉', 'オグワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県北宇和郡鬼北町上川', '38', '38488', '7981322', '愛媛県', 'エヒメケン', '北宇和郡鬼北町', 'キタウワグンキホクチョウ', '上川', 'カミカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県北宇和郡鬼北町岩谷', '38', '38488', '7981323', '愛媛県', 'エヒメケン', '北宇和郡鬼北町', 'キタウワグンキホクチョウ', '岩谷', 'イワヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県北宇和郡鬼北町小西野々', '38', '38488', '7981324', '愛媛県', 'エヒメケン', '北宇和郡鬼北町', 'キタウワグンキホクチョウ', '小西野々', 'コニシノノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県北宇和郡鬼北町興野々', '38', '38488', '7981331', '愛媛県', 'エヒメケン', '北宇和郡鬼北町', 'キタウワグンキホクチョウ', '興野々', 'オキノノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県北宇和郡鬼北町出目', '38', '38488', '7981332', '愛媛県', 'エヒメケン', '北宇和郡鬼北町', 'キタウワグンキホクチョウ', '出目', 'イズメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県北宇和郡鬼北町永野市', '38', '38488', '7981333', '愛媛県', 'エヒメケン', '北宇和郡鬼北町', 'キタウワグンキホクチョウ', '永野市', 'ナガノイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県北宇和郡鬼北町近永旭町', '38', '38488', '7981341', '愛媛県', 'エヒメケン', '北宇和郡鬼北町', 'キタウワグンキホクチョウ', '近永', 'チカナガ', null, null, '旭町', 'アサヒマチ');
INSERT INTO `ms_addresses` VALUES ('101977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県北宇和郡鬼北町近永栄町', '38', '38488', '7981342', '愛媛県', 'エヒメケン', '北宇和郡鬼北町', 'キタウワグンキホクチョウ', '近永', 'チカナガ', null, null, '栄町', 'サカエマチ');
INSERT INTO `ms_addresses` VALUES ('101978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県北宇和郡鬼北町近永新町', '38', '38488', '7981343', '愛媛県', 'エヒメケン', '北宇和郡鬼北町', 'キタウワグンキホクチョウ', '近永', 'チカナガ', null, null, '新町', 'シンマチ');
INSERT INTO `ms_addresses` VALUES ('101979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県北宇和郡鬼北町近永本町', '38', '38488', '7981344', '愛媛県', 'エヒメケン', '北宇和郡鬼北町', 'キタウワグンキホクチョウ', '近永', 'チカナガ', null, null, '本町', 'ホンマチ');
INSERT INTO `ms_addresses` VALUES ('101980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県北宇和郡鬼北町近永南町', '38', '38488', '7981345', '愛媛県', 'エヒメケン', '北宇和郡鬼北町', 'キタウワグンキホクチョウ', '近永', 'チカナガ', null, null, '南町', 'ミナミマチ');
INSERT INTO `ms_addresses` VALUES ('101981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県北宇和郡鬼北町奈良', '38', '38488', '7981351', '愛媛県', 'エヒメケン', '北宇和郡鬼北町', 'キタウワグンキホクチョウ', '奈良', 'ナラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県北宇和郡鬼北町奈良成川', '38', '38488', '7981352', '愛媛県', 'エヒメケン', '北宇和郡鬼北町', 'キタウワグンキホクチョウ', '奈良', 'ナラ', null, null, '成川', 'ナルカワ');
INSERT INTO `ms_addresses` VALUES ('101983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県北宇和郡鬼北町奈良水分', '38', '38488', '7981353', '愛媛県', 'エヒメケン', '北宇和郡鬼北町', 'キタウワグンキホクチョウ', '奈良', 'ナラ', null, null, '水分', 'ミズワカレ');
INSERT INTO `ms_addresses` VALUES ('101984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県北宇和郡鬼北町北川', '38', '38488', '7981354', '愛媛県', 'エヒメケン', '北宇和郡鬼北町', 'キタウワグンキホクチョウ', '北川', 'キタガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県北宇和郡鬼北町芝', '38', '38488', '7981355', '愛媛県', 'エヒメケン', '北宇和郡鬼北町', 'キタウワグンキホクチョウ', '芝', 'シバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県北宇和郡鬼北町中野川', '38', '38488', '7981356', '愛媛県', 'エヒメケン', '北宇和郡鬼北町', 'キタウワグンキホクチョウ', '中野川', 'ナカノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県北宇和郡鬼北町国遠', '38', '38488', '7981361', '愛媛県', 'エヒメケン', '北宇和郡鬼北町', 'キタウワグンキホクチョウ', '国遠', 'クニトオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県北宇和郡鬼北町清延', '38', '38488', '7981362', '愛媛県', 'エヒメケン', '北宇和郡鬼北町', 'キタウワグンキホクチョウ', '清延', 'キヨノブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県北宇和郡鬼北町内深田', '38', '38488', '7981363', '愛媛県', 'エヒメケン', '北宇和郡鬼北町', 'キタウワグンキホクチョウ', '内深田', 'ウチフカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県北宇和郡鬼北町吉波', '38', '38488', '7981364', '愛媛県', 'エヒメケン', '北宇和郡鬼北町', 'キタウワグンキホクチョウ', '吉波', 'ヨシナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県北宇和郡鬼北町西仲', '38', '38488', '7981365', '愛媛県', 'エヒメケン', '北宇和郡鬼北町', 'キタウワグンキホクチョウ', '西仲', 'ニシナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県北宇和郡鬼北町東仲', '38', '38488', '7981366', '愛媛県', 'エヒメケン', '北宇和郡鬼北町', 'キタウワグンキホクチョウ', '東仲', 'ヒガシナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県北宇和郡鬼北町沢松', '38', '38488', '7981367', '愛媛県', 'エヒメケン', '北宇和郡鬼北町', 'キタウワグンキホクチョウ', '沢松', 'サワマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県北宇和郡鬼北町生田', '38', '38488', '7981371', '愛媛県', 'エヒメケン', '北宇和郡鬼北町', 'キタウワグンキホクチョウ', '生田', 'イクタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県北宇和郡鬼北町西野々', '38', '38488', '7981372', '愛媛県', 'エヒメケン', '北宇和郡鬼北町', 'キタウワグンキホクチョウ', '西野々', 'ニシノノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県北宇和郡鬼北町清水', '38', '38488', '7981373', '愛媛県', 'エヒメケン', '北宇和郡鬼北町', 'キタウワグンキホクチョウ', '清水', 'セイズイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県北宇和郡鬼北町成藤', '38', '38488', '7981374', '愛媛県', 'エヒメケン', '北宇和郡鬼北町', 'キタウワグンキホクチョウ', '成藤', 'ナリフジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('101998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県北宇和郡鬼北町畔屋', '38', '38488', '7981375', '愛媛県', 'エヒメケン', '北宇和郡鬼北町', 'キタウワグンキホクチョウ', '畔屋', 'アゼヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県北宇和郡鬼北町上鍵山', '38', '38488', '7981501', '愛媛県', 'エヒメケン', '北宇和郡鬼北町', 'キタウワグンキホクチョウ', '上鍵山', 'カミカギヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県北宇和郡鬼北町下鍵山', '38', '38488', '7981502', '愛媛県', 'エヒメケン', '北宇和郡鬼北町', 'キタウワグンキホクチョウ', '下鍵山', 'シモカギヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県北宇和郡鬼北町上大野', '38', '38488', '7981503', '愛媛県', 'エヒメケン', '北宇和郡鬼北町', 'キタウワグンキホクチョウ', '上大野', 'カミオオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県北宇和郡鬼北町日向谷', '38', '38488', '7981504', '愛媛県', 'エヒメケン', '北宇和郡鬼北町', 'キタウワグンキホクチョウ', '日向谷', 'ヒュウガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県北宇和郡鬼北町父野川上', '38', '38488', '7981505', '愛媛県', 'エヒメケン', '北宇和郡鬼北町', 'キタウワグンキホクチョウ', '父野川上', 'チチノカワカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県北宇和郡鬼北町父野川中', '38', '38488', '7981506', '愛媛県', 'エヒメケン', '北宇和郡鬼北町', 'キタウワグンキホクチョウ', '父野川中', 'チチノカワナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県北宇和郡鬼北町父野川下', '38', '38488', '7981507', '愛媛県', 'エヒメケン', '北宇和郡鬼北町', 'キタウワグンキホクチョウ', '父野川下', 'チチノカワシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県北宇和郡松野町', '38', '38484', '7982100', '愛媛県', 'エヒメケン', '北宇和郡松野町', 'キタウワグンマツノチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('102011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県北宇和郡松野町松丸', '38', '38484', '7982101', '愛媛県', 'エヒメケン', '北宇和郡松野町', 'キタウワグンマツノチョウ', '松丸', 'マツマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県北宇和郡松野町延野々', '38', '38484', '7982102', '愛媛県', 'エヒメケン', '北宇和郡松野町', 'キタウワグンマツノチョウ', '延野々', 'ノビノノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県北宇和郡松野町豊岡', '38', '38484', '7982103', '愛媛県', 'エヒメケン', '北宇和郡松野町', 'キタウワグンマツノチョウ', '豊岡', 'トヨオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県北宇和郡松野町富岡', '38', '38484', '7982104', '愛媛県', 'エヒメケン', '北宇和郡松野町', 'キタウワグンマツノチョウ', '富岡', 'トミオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県北宇和郡松野町上家地', '38', '38484', '7982105', '愛媛県', 'エヒメケン', '北宇和郡松野町', 'キタウワグンマツノチョウ', '上家地', 'カミイエジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県北宇和郡松野町目黒', '38', '38484', '7982106', '愛媛県', 'エヒメケン', '北宇和郡松野町', 'キタウワグンマツノチョウ', '目黒', 'メグロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県北宇和郡松野町吉野', '38', '38484', '7982111', '愛媛県', 'エヒメケン', '北宇和郡松野町', 'キタウワグンマツノチョウ', '吉野', 'ヨシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県北宇和郡松野町蕨生', '38', '38484', '7982112', '愛媛県', 'エヒメケン', '北宇和郡松野町', 'キタウワグンマツノチョウ', '蕨生', 'ワラビョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県北宇和郡松野町奥野川', '38', '38484', '7982113', '愛媛県', 'エヒメケン', '北宇和郡松野町', 'キタウワグンマツノチョウ', '奥野川', 'オクノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市野川滑床', '38', '38203', '7982146', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '野川', 'ノガワ', null, null, '滑床', 'ナメトコ');
INSERT INTO `ms_addresses` VALUES ('102022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市津島町御内', '38', '38203', '7983271', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '津島町御内', 'ツシマチョウミウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市津島町槇川', '38', '38203', '7983272', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '津島町槇川', 'ツシマチョウマキガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市津島町岩松', '38', '38203', '7983301', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '津島町岩松', 'ツシマチョウイワマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市津島町高田', '38', '38203', '7983302', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '津島町高田', 'ツシマチョウタカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市津島町近家', '38', '38203', '7983303', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '津島町近家', 'ツシマチョウチカイエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市津島町岩淵', '38', '38203', '7983311', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '津島町岩淵', 'ツシマチョウイワブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市津島町山財', '38', '38203', '7983312', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '津島町山財', 'ツシマチョウサンザイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市津島町増穂', '38', '38203', '7983313', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '津島町増穂', 'ツシマチョウマスホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市津島町下畑地', '38', '38203', '7983321', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '津島町下畑地', 'ツシマチョウシモハタジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市津島町下畑地乙上槇', '38', '38203', '7983322', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '津島町下畑地乙', 'ツシマチョウシモハタジオツ', null, null, '上槇', 'カミマキ');
INSERT INTO `ms_addresses` VALUES ('102032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市津島町上畑地', '38', '38203', '7983323', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '津島町上畑地', 'ツシマチョウカミハタジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市津島町後', '38', '38203', '7983331', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '津島町後', 'ツシマチョウウシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市津島町須下', '38', '38203', '7983332', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '津島町須下', 'ツシマチョウスゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市津島町成', '38', '38203', '7983333', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '津島町成', 'ツシマチョウナル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市津島町漁家', '38', '38203', '7983334', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '津島町漁家', 'ツシマチョウリョウケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市津島町平井', '38', '38203', '7983335', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '津島町平井', 'ツシマチョウヒライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市津島町曲烏', '38', '38203', '7983336', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '津島町曲烏', 'ツシマチョウマガラス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市津島町大浦', '38', '38203', '7983337', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '津島町大浦', 'ツシマチョウオオウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市津島町柿之浦', '38', '38203', '7983338', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '津島町柿之浦', 'ツシマチョウカキノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市津島町塩定', '38', '38203', '7983341', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '津島町塩定', 'ツシマチョウエンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市津島町浦知', '38', '38203', '7983342', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '津島町浦知', 'ツシマチョウウラシリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市津島町針木', '38', '38203', '7983343', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '津島町針木', 'ツシマチョウハリギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市津島町嵐', '38', '38203', '7983344', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '津島町嵐', 'ツシマチョウアラシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市津島町横浦', '38', '38203', '7983345', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '津島町横浦', 'ツシマチョウヨコウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市津島町鼠鳴', '38', '38203', '7983346', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '津島町鼠鳴', 'ツシマチョウネヅナキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市津島町弓立', '38', '38203', '7983351', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '津島町弓立', 'ツシマチョウユダチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市津島町坪井', '38', '38203', '7983352', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '津島町坪井', 'ツシマチョウツボイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市津島町泥目水', '38', '38203', '7983353', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '津島町泥目水', 'ツシマチョウドロメズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市津島町田颪', '38', '38203', '7983354', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '津島町田颪', 'ツシマチョウタオロシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市津島町脇', '38', '38203', '7983355', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '津島町脇', 'ツシマチョウワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市津島町曽根', '38', '38203', '7983356', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '津島町曽根', 'ツシマチョウソネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市津島町田之浜', '38', '38203', '7983357', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '津島町田之浜', 'ツシマチョウタノハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市津島町竹ケ島', '38', '38203', '7983358', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '津島町竹ケ島', 'ツシマチョウタケガシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市津島町北灘甲', '38', '38203', '7983361', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '津島町北灘甲', 'ツシマチョウキタナダコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市津島町北灘乙', '38', '38203', '7983362', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '津島町北灘乙', 'ツシマチョウキタナダオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市津島町北灘丙', '38', '38203', '7983363', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '津島町北灘丙', 'ツシマチョウキタナダヘイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市津島町北灘丁大日提', '38', '38203', '7983364', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '津島町北灘丁', 'ツシマチョウキタナダテイ', null, null, '大日提', 'オオヒサゲ');
INSERT INTO `ms_addresses` VALUES ('102059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市津島町北灘丁小日提', '38', '38203', '7983364', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '津島町北灘丁', 'ツシマチョウキタナダテイ', null, null, '小日提', 'コヒサゲ');
INSERT INTO `ms_addresses` VALUES ('102062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県南宇和郡愛南町柏', '38', '38506', '7983701', '愛媛県', 'エヒメケン', '南宇和郡愛南町', 'ミナミウワグンアイナンチョウ', '柏', 'カシワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県南宇和郡愛南町柏崎', '38', '38506', '7983702', '愛媛県', 'エヒメケン', '南宇和郡愛南町', 'ミナミウワグンアイナンチョウ', '柏崎', 'カシワザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県南宇和郡愛南町須ノ川', '38', '38506', '7983703', '愛媛県', 'エヒメケン', '南宇和郡愛南町', 'ミナミウワグンアイナンチョウ', '須ノ川', 'スノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県南宇和郡愛南町平碆', '38', '38506', '7983704', '愛媛県', 'エヒメケン', '南宇和郡愛南町', 'ミナミウワグンアイナンチョウ', '平碆', 'ヒラバエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県南宇和郡愛南町家串', '38', '38506', '7983705', '愛媛県', 'エヒメケン', '南宇和郡愛南町', 'ミナミウワグンアイナンチョウ', '家串', 'イエクシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県南宇和郡愛南町油袋', '38', '38506', '7983706', '愛媛県', 'エヒメケン', '南宇和郡愛南町', 'ミナミウワグンアイナンチョウ', '油袋', 'ユタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県南宇和郡愛南町魚神山', '38', '38506', '7983707', '愛媛県', 'エヒメケン', '南宇和郡愛南町', 'ミナミウワグンアイナンチョウ', '魚神山', 'ナガミヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県南宇和郡愛南町網代', '38', '38506', '7983708', '愛媛県', 'エヒメケン', '南宇和郡愛南町', 'ミナミウワグンアイナンチョウ', '網代', 'アジロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市秋月1条', '01', '01204', '0798401', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '秋月1条', 'アキツキ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市秋月2条', '01', '01204', '0798402', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '秋月2条', 'アキツキ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市秋月3条', '01', '01204', '0798403', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '秋月3条', 'アキツキ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県南宇和郡愛南町', '38', '38506', '7984100', '愛媛県', 'エヒメケン', '南宇和郡愛南町', 'ミナミウワグンアイナンチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('102075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県南宇和郡愛南町御荘菊川', '38', '38506', '7984101', '愛媛県', 'エヒメケン', '南宇和郡愛南町', 'ミナミウワグンアイナンチョウ', '御荘菊川', 'ミショウキクガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県南宇和郡愛南町御荘平山', '38', '38506', '7984102', '愛媛県', 'エヒメケン', '南宇和郡愛南町', 'ミナミウワグンアイナンチョウ', '御荘平山', 'ミショウヒラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県南宇和郡愛南町御荘長洲', '38', '38506', '7984103', '愛媛県', 'エヒメケン', '南宇和郡愛南町', 'ミナミウワグンアイナンチョウ', '御荘長洲', 'ミショウナガス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県南宇和郡愛南町御荘和口', '38', '38506', '7984104', '愛媛県', 'エヒメケン', '南宇和郡愛南町', 'ミナミウワグンアイナンチョウ', '御荘和口', 'ミショウワグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県南宇和郡愛南町御荘長月', '38', '38506', '7984105', '愛媛県', 'エヒメケン', '南宇和郡愛南町', 'ミナミウワグンアイナンチョウ', '御荘長月', 'ミショウナガツキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市永山1条', '01', '01204', '0798411', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '永山1条', 'ナガヤマ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県南宇和郡愛南町御荘平城', '38', '38506', '7984110', '愛媛県', 'エヒメケン', '南宇和郡愛南町', 'ミナミウワグンアイナンチョウ', '御荘平城', 'ミショウヒラジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市永山2条', '01', '01204', '0798412', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '永山2条', 'ナガヤマ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県南宇和郡愛南町御荘深泥', '38', '38506', '7984121', '愛媛県', 'エヒメケン', '南宇和郡愛南町', 'ミナミウワグンアイナンチョウ', '御荘深泥', 'ミショウミドロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県南宇和郡愛南町防城成川', '38', '38506', '7984122', '愛媛県', 'エヒメケン', '南宇和郡愛南町', 'ミナミウワグンアイナンチョウ', '防城成川', 'ボウジョウナルカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県南宇和郡愛南町赤水', '38', '38506', '7984123', '愛媛県', 'エヒメケン', '南宇和郡愛南町', 'ミナミウワグンアイナンチョウ', '赤水', 'アカミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県南宇和郡愛南町高畑', '38', '38506', '7984124', '愛媛県', 'エヒメケン', '南宇和郡愛南町', 'ミナミウワグンアイナンチョウ', '高畑', 'タカハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県南宇和郡愛南町中浦', '38', '38506', '7984125', '愛媛県', 'エヒメケン', '南宇和郡愛南町', 'ミナミウワグンアイナンチョウ', '中浦', 'ナカウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県南宇和郡愛南町猿鳴', '38', '38506', '7984126', '愛媛県', 'エヒメケン', '南宇和郡愛南町', 'ミナミウワグンアイナンチョウ', '猿鳴', 'サルナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市永山3条', '01', '01204', '0798413', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '永山3条', 'ナガヤマ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県南宇和郡愛南町城辺甲', '38', '38506', '7984131', '愛媛県', 'エヒメケン', '南宇和郡愛南町', 'ミナミウワグンアイナンチョウ', '城辺甲', 'ジョウヘンコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県南宇和郡愛南町城辺乙', '38', '38506', '7984132', '愛媛県', 'エヒメケン', '南宇和郡愛南町', 'ミナミウワグンアイナンチョウ', '城辺乙', 'ジョウヘンオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県南宇和郡愛南町緑乙', '38', '38506', '7984133', '愛媛県', 'エヒメケン', '南宇和郡愛南町', 'ミナミウワグンアイナンチョウ', '緑乙', 'ミドリオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県南宇和郡愛南町緑甲', '38', '38506', '7984134', '愛媛県', 'エヒメケン', '南宇和郡愛南町', 'ミナミウワグンアイナンチョウ', '緑甲', 'ミドリコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県南宇和郡愛南町緑丙', '38', '38506', '7984135', '愛媛県', 'エヒメケン', '南宇和郡愛南町', 'ミナミウワグンアイナンチョウ', '緑丙', 'ミドリヘイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県南宇和郡愛南町僧都', '38', '38506', '7984136', '愛媛県', 'エヒメケン', '南宇和郡愛南町', 'ミナミウワグンアイナンチョウ', '僧都', 'ソウヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市永山4条', '01', '01204', '0798414', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '永山4条', 'ナガヤマ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市永山5条', '01', '01204', '0798415', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '永山5条', 'ナガヤマ05ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市永山6条', '01', '01204', '0798416', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '永山6条', 'ナガヤマ06ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市永山7条', '01', '01204', '0798417', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '永山7条', 'ナガヤマ07ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市永山8条', '01', '01204', '0798418', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '永山8条', 'ナガヤマ08ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市永山9条', '01', '01204', '0798419', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '永山9条', 'ナガヤマ09ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市永山10条', '01', '01204', '0798420', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '永山10条', 'ナガヤマ10ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県南宇和郡愛南町越田', '38', '38506', '7984201', '愛媛県', 'エヒメケン', '南宇和郡愛南町', 'ミナミウワグンアイナンチョウ', '越田', 'コシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県南宇和郡愛南町弓立', '38', '38506', '7984202', '愛媛県', 'エヒメケン', '南宇和郡愛南町', 'ミナミウワグンアイナンチョウ', '弓立', 'ユダチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県南宇和郡愛南町小浦', '38', '38506', '7984203', '愛媛県', 'エヒメケン', '南宇和郡愛南町', 'ミナミウワグンアイナンチョウ', '小浦', 'コウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県南宇和郡愛南町樫月', '38', '38506', '7984204', '愛媛県', 'エヒメケン', '南宇和郡愛南町', 'ミナミウワグンアイナンチョウ', '樫月', 'カシヅク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県南宇和郡愛南町船越', '38', '38506', '7984205', '愛媛県', 'エヒメケン', '南宇和郡愛南町', 'ミナミウワグンアイナンチョウ', '船越', 'フナコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県南宇和郡愛南町内泊', '38', '38506', '7984206', '愛媛県', 'エヒメケン', '南宇和郡愛南町', 'ミナミウワグンアイナンチョウ', '内泊', 'ウチドマリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県南宇和郡愛南町中泊', '38', '38506', '7984207', '愛媛県', 'エヒメケン', '南宇和郡愛南町', 'ミナミウワグンアイナンチョウ', '中泊', 'ナカドマリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県南宇和郡愛南町外泊', '38', '38506', '7984208', '愛媛県', 'エヒメケン', '南宇和郡愛南町', 'ミナミウワグンアイナンチョウ', '外泊', 'ソトドマリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県南宇和郡愛南町鹿島', '38', '38506', '7984209', '愛媛県', 'エヒメケン', '南宇和郡愛南町', 'ミナミウワグンアイナンチョウ', '鹿島', 'カシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市永山11条', '01', '01204', '0798421', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '永山11条', 'ナガヤマ11ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県南宇和郡愛南町久家', '38', '38506', '7984211', '愛媛県', 'エヒメケン', '南宇和郡愛南町', 'ミナミウワグンアイナンチョウ', '久家', 'ヒサゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県南宇和郡愛南町下久家', '38', '38506', '7984212', '愛媛県', 'エヒメケン', '南宇和郡愛南町', 'ミナミウワグンアイナンチョウ', '下久家', 'シモヒサゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県南宇和郡愛南町樽見', '38', '38506', '7984213', '愛媛県', 'エヒメケン', '南宇和郡愛南町', 'ミナミウワグンアイナンチョウ', '樽見', 'タルミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県南宇和郡愛南町大成川', '38', '38506', '7984214', '愛媛県', 'エヒメケン', '南宇和郡愛南町', 'ミナミウワグンアイナンチョウ', '大成川', 'オオナルカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県南宇和郡愛南町小成川', '38', '38506', '7984215', '愛媛県', 'エヒメケン', '南宇和郡愛南町', 'ミナミウワグンアイナンチョウ', '小成川', 'コナルカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県南宇和郡愛南町福浦', '38', '38506', '7984216', '愛媛県', 'エヒメケン', '南宇和郡愛南町', 'ミナミウワグンアイナンチョウ', '福浦', 'フクウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県南宇和郡愛南町麦ケ浦', '38', '38506', '7984217', '愛媛県', 'エヒメケン', '南宇和郡愛南町', 'ミナミウワグンアイナンチョウ', '麦ケ浦', 'ムギガウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県南宇和郡愛南町武者泊', '38', '38506', '7984218', '愛媛県', 'エヒメケン', '南宇和郡愛南町', 'ミナミウワグンアイナンチョウ', '武者泊', 'ムシャドマリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県南宇和郡愛南町高茂', '38', '38506', '7984219', '愛媛県', 'エヒメケン', '南宇和郡愛南町', 'ミナミウワグンアイナンチョウ', '高茂', 'コウモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市永山12条', '01', '01204', '0798422', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '永山12条', 'ナガヤマ12ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市永山13条', '01', '01204', '0798423', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '永山13条', 'ナガヤマ13ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市永山14条', '01', '01204', '0798424', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '永山14条', 'ナガヤマ14ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市永山町', '01', '01204', '0798431', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '永山町', 'ナガヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県南宇和郡愛南町蓮乗寺', '38', '38506', '7984341', '愛媛県', 'エヒメケン', '南宇和郡愛南町', 'ミナミウワグンアイナンチョウ', '蓮乗寺', 'レンジョウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県南宇和郡愛南町深浦', '38', '38506', '7984342', '愛媛県', 'エヒメケン', '南宇和郡愛南町', 'ミナミウワグンアイナンチョウ', '深浦', 'フカウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県南宇和郡愛南町垣内', '38', '38506', '7984343', '愛媛県', 'エヒメケン', '南宇和郡愛南町', 'ミナミウワグンアイナンチョウ', '垣内', 'カキウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県南宇和郡愛南町岩水', '38', '38506', '7984344', '愛媛県', 'エヒメケン', '南宇和郡愛南町', 'ミナミウワグンアイナンチョウ', '岩水', 'イワミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県南宇和郡愛南町敦盛', '38', '38506', '7984345', '愛媛県', 'エヒメケン', '南宇和郡愛南町', 'ミナミウワグンアイナンチョウ', '敦盛', 'アツモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県南宇和郡愛南町柿ノ浦', '38', '38506', '7984346', '愛媛県', 'エヒメケン', '南宇和郡愛南町', 'ミナミウワグンアイナンチョウ', '柿ノ浦', 'カキノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県南宇和郡愛南町大浜', '38', '38506', '7984347', '愛媛県', 'エヒメケン', '南宇和郡愛南町', 'ミナミウワグンアイナンチョウ', '大浜', 'オオハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県南宇和郡愛南町中玉', '38', '38506', '7984348', '愛媛県', 'エヒメケン', '南宇和郡愛南町', 'ミナミウワグンアイナンチョウ', '中玉', 'ナカタマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県南宇和郡愛南町脇本', '38', '38506', '7984349', '愛媛県', 'エヒメケン', '南宇和郡愛南町', 'ミナミウワグンアイナンチョウ', '脇本', 'ワキモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県南宇和郡愛南町鯆越', '38', '38506', '7984351', '愛媛県', 'エヒメケン', '南宇和郡愛南町', 'ミナミウワグンアイナンチョウ', '鯆越', 'イルカゴエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県南宇和郡愛南町古月', '38', '38506', '7984352', '愛媛県', 'エヒメケン', '南宇和郡愛南町', 'ミナミウワグンアイナンチョウ', '古月', 'フルツキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県南宇和郡愛南町久良', '38', '38506', '7984353', '愛媛県', 'エヒメケン', '南宇和郡愛南町', 'ミナミウワグンアイナンチョウ', '久良', 'ヒサヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県南宇和郡愛南町正木', '38', '38506', '7984401', '愛媛県', 'エヒメケン', '南宇和郡愛南町', 'ミナミウワグンアイナンチョウ', '正木', 'マサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県南宇和郡愛南町増田', '38', '38506', '7984402', '愛媛県', 'エヒメケン', '南宇和郡愛南町', 'ミナミウワグンアイナンチョウ', '増田', 'マスダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県南宇和郡愛南町小山', '38', '38506', '7984403', '愛媛県', 'エヒメケン', '南宇和郡愛南町', 'ミナミウワグンアイナンチョウ', '小山', 'コヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県南宇和郡愛南町中川', '38', '38506', '7984404', '愛媛県', 'エヒメケン', '南宇和郡愛南町', 'ミナミウワグンアイナンチョウ', '中川', 'ナカノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県南宇和郡愛南町満倉', '38', '38506', '7984405', '愛媛県', 'エヒメケン', '南宇和郡愛南町', 'ミナミウワグンアイナンチョウ', '満倉', 'ミチクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県南宇和郡愛南町広見', '38', '38506', '7984406', '愛媛県', 'エヒメケン', '南宇和郡愛南町', 'ミナミウワグンアイナンチョウ', '広見', 'ヒロミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県南宇和郡愛南町上大道', '38', '38506', '7984407', '愛媛県', 'エヒメケン', '南宇和郡愛南町', 'ミナミウワグンアイナンチョウ', '上大道', 'ウワオオドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県南宇和郡愛南町一本松', '38', '38506', '7984408', '愛媛県', 'エヒメケン', '南宇和郡愛南町', 'ミナミウワグンアイナンチョウ', '一本松', 'イッポンマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市流通団地1条', '01', '01204', '0798441', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '流通団地1条', 'リュウツウダンチ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市流通団地2条', '01', '01204', '0798442', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '流通団地2条', 'リュウツウダンチ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市流通団地3条', '01', '01204', '0798443', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '流通団地3条', 'リュウツウダンチ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道旭川市流通団地4条', '01', '01204', '0798444', '北海道', 'ホッカイドウ', '旭川市', 'アサヒカワシ', '流通団地4条', 'リュウツウダンチ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県四国中央市川之江町', '38', '38213', '7990101', '愛媛県', 'エヒメケン', '四国中央市', 'シコクチュウオウシ', '川之江町', 'カワノエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県四国中央市川之江町長須', '38', '38213', '7990102', '愛媛県', 'エヒメケン', '四国中央市', 'シコクチュウオウシ', '川之江町長須', 'カワノエチョウナガス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県四国中央市川之江町余木', '38', '38213', '7990103', '愛媛県', 'エヒメケン', '四国中央市', 'シコクチュウオウシ', '川之江町余木', 'カワノエチョウヨキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県四国中央市金生町下分', '38', '38213', '7990111', '愛媛県', 'エヒメケン', '四国中央市', 'シコクチュウオウシ', '金生町下分', 'キンセイチョウシモブン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県四国中央市金生町山田井', '38', '38213', '7990112', '愛媛県', 'エヒメケン', '四国中央市', 'シコクチュウオウシ', '金生町山田井', 'キンセイチョウヤマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県四国中央市妻鳥町', '38', '38213', '7990113', '愛媛県', 'エヒメケン', '四国中央市', 'シコクチュウオウシ', '妻鳥町', 'メンドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県四国中央市上分町', '38', '38213', '7990121', '愛媛県', 'エヒメケン', '四国中央市', 'シコクチュウオウシ', '上分町', 'カミブンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県四国中央市金田町半田', '38', '38213', '7990122', '愛媛県', 'エヒメケン', '四国中央市', 'シコクチュウオウシ', '金田町半田', 'カナダチョウハンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県四国中央市金田町金川', '38', '38213', '7990123', '愛媛県', 'エヒメケン', '四国中央市', 'シコクチュウオウシ', '金田町金川', 'カナダチョウカナガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県四国中央市金田町三角寺', '38', '38213', '7990124', '愛媛県', 'エヒメケン', '四国中央市', 'シコクチュウオウシ', '金田町三角寺', 'カナダチョウサンカクジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県四国中央市柴生町', '38', '38213', '7990125', '愛媛県', 'エヒメケン', '四国中央市', 'シコクチュウオウシ', '柴生町', 'シボウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県四国中央市下川町', '38', '38213', '7990126', '愛媛県', 'エヒメケン', '四国中央市', 'シコクチュウオウシ', '下川町', 'シモカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県四国中央市川滝町下山', '38', '38213', '7990127', '愛媛県', 'エヒメケン', '四国中央市', 'シコクチュウオウシ', '川滝町下山', 'カワタキチョウシモヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県四国中央市川滝町領家', '38', '38213', '7990128', '愛媛県', 'エヒメケン', '四国中央市', 'シコクチュウオウシ', '川滝町領家', 'カワタキチョウリョウケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県四国中央市新宮町馬立', '38', '38213', '7990301', '愛媛県', 'エヒメケン', '四国中央市', 'シコクチュウオウシ', '新宮町馬立', 'シングウチョウウマタテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県四国中央市新宮町上山', '38', '38213', '7990302', '愛媛県', 'エヒメケン', '四国中央市', 'シコクチュウオウシ', '新宮町上山', 'シングウチョウカミヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県四国中央市新宮町新宮', '38', '38213', '7990303', '愛媛県', 'エヒメケン', '四国中央市', 'シコクチュウオウシ', '新宮町新宮', 'シングウチョウシングウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県四国中央市新宮町新瀬川', '38', '38213', '7990304', '愛媛県', 'エヒメケン', '四国中央市', 'シコクチュウオウシ', '新宮町新瀬川', 'シングウチョウシンセガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県四国中央市', '38', '38213', '7990400', '愛媛県', 'エヒメケン', '四国中央市', 'シコクチュウオウシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('102216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県四国中央市村松町', '38', '38213', '7990401', '愛媛県', 'エヒメケン', '四国中央市', 'シコクチュウオウシ', '村松町', 'ムラマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県四国中央市三島紙屋町', '38', '38213', '7990402', '愛媛県', 'エヒメケン', '四国中央市', 'シコクチュウオウシ', '三島紙屋町', 'ミシマカミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県四国中央市三島朝日', '38', '38213', '7990403', '愛媛県', 'エヒメケン', '四国中央市', 'シコクチュウオウシ', '三島朝日', 'ミシマアサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県四国中央市三島宮川', '38', '38213', '7990404', '愛媛県', 'エヒメケン', '四国中央市', 'シコクチュウオウシ', '三島宮川', 'ミシマミヤガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県四国中央市三島中央', '38', '38213', '7990405', '愛媛県', 'エヒメケン', '四国中央市', 'シコクチュウオウシ', '三島中央', 'ミシマチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県四国中央市下柏町', '38', '38213', '7990411', '愛媛県', 'エヒメケン', '四国中央市', 'シコクチュウオウシ', '下柏町', 'シモガシワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県四国中央市上柏町', '38', '38213', '7990412', '愛媛県', 'エヒメケン', '四国中央市', 'シコクチュウオウシ', '上柏町', 'カミガシワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県四国中央市中曽根町', '38', '38213', '7990413', '愛媛県', 'エヒメケン', '四国中央市', 'シコクチュウオウシ', '中曽根町', 'ナカゾネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県四国中央市三島金子', '38', '38213', '7990421', '愛媛県', 'エヒメケン', '四国中央市', 'シコクチュウオウシ', '三島金子', 'ミシマカネコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県四国中央市中之庄町', '38', '38213', '7990422', '愛媛県', 'エヒメケン', '四国中央市', 'シコクチュウオウシ', '中之庄町', 'ナカノショウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県四国中央市具定町', '38', '38213', '7990423', '愛媛県', 'エヒメケン', '四国中央市', 'シコクチュウオウシ', '具定町', 'グジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県四国中央市寒川町', '38', '38213', '7990431', '愛媛県', 'エヒメケン', '四国中央市', 'シコクチュウオウシ', '寒川町', 'サンガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県四国中央市豊岡町大町', '38', '38213', '7990432', '愛媛県', 'エヒメケン', '四国中央市', 'シコクチュウオウシ', '豊岡町大町', 'トヨオカチョウオオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県四国中央市豊岡町豊田', '38', '38213', '7990433', '愛媛県', 'エヒメケン', '四国中央市', 'シコクチュウオウシ', '豊岡町豊田', 'トヨオカチョウトヨダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県四国中央市豊岡町五良野', '38', '38213', '7990434', '愛媛県', 'エヒメケン', '四国中央市', 'シコクチュウオウシ', '豊岡町五良野', 'トヨオカチョウイラノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県四国中央市豊岡町長田', '38', '38213', '7990435', '愛媛県', 'エヒメケン', '四国中央市', 'シコクチュウオウシ', '豊岡町長田', 'トヨオカチョウオサダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県四国中央市豊岡町岡銅', '38', '38213', '7990436', '愛媛県', 'エヒメケン', '四国中央市', 'シコクチュウオウシ', '豊岡町岡銅', 'トヨオカチョウオカドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県四国中央市金砂町小川山', '38', '38213', '7990641', '愛媛県', 'エヒメケン', '四国中央市', 'シコクチュウオウシ', '金砂町小川山', 'キンシャチョウオガワヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県四国中央市金砂町平野山', '38', '38213', '7990642', '愛媛県', 'エヒメケン', '四国中央市', 'シコクチュウオウシ', '金砂町平野山', 'キンシャチョウヒラノヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県四国中央市富郷町寒川山', '38', '38213', '7990643', '愛媛県', 'エヒメケン', '四国中央市', 'シコクチュウオウシ', '富郷町寒川山', 'トミサトチョウサンガワヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県四国中央市富郷町豊坂', '38', '38213', '7990644', '愛媛県', 'エヒメケン', '四国中央市', 'シコクチュウオウシ', '富郷町豊坂', 'トミサトチョウトヨサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県四国中央市富郷町津根山', '38', '38213', '7990645', '愛媛県', 'エヒメケン', '四国中央市', 'シコクチュウオウシ', '富郷町津根山', 'トミサトチョウツネヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県新居浜市別子山', '38', '38205', '7990650', '愛媛県', 'エヒメケン', '新居浜市', 'ニイハマシ', '別子山', 'ベッシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県四国中央市土居町中村', '38', '38213', '7990701', '愛媛県', 'エヒメケン', '四国中央市', 'シコクチュウオウシ', '土居町中村', 'ドイチョウナカムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県四国中央市土居町小林', '38', '38213', '7990702', '愛媛県', 'エヒメケン', '四国中央市', 'シコクチュウオウシ', '土居町小林', 'ドイチョウコバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県四国中央市土居町藤原', '38', '38213', '7990703', '愛媛県', 'エヒメケン', '四国中央市', 'シコクチュウオウシ', '土居町藤原', 'ドイチョウフジワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県四国中央市土居町津根', '38', '38213', '7990704', '愛媛県', 'エヒメケン', '四国中央市', 'シコクチュウオウシ', '土居町津根', 'ドイチョウツネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県四国中央市土居町野田', '38', '38213', '7990705', '愛媛県', 'エヒメケン', '四国中央市', 'シコクチュウオウシ', '土居町野田', 'ドイチョウノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県四国中央市土居町土居', '38', '38213', '7990711', '愛媛県', 'エヒメケン', '四国中央市', 'シコクチュウオウシ', '土居町土居', 'ドイチョウドイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県四国中央市土居町入野', '38', '38213', '7990712', '愛媛県', 'エヒメケン', '四国中央市', 'シコクチュウオウシ', '土居町入野', 'ドイチョウイリノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県四国中央市土居町浦山', '38', '38213', '7990713', '愛媛県', 'エヒメケン', '四国中央市', 'シコクチュウオウシ', '土居町浦山', 'ドイチョウウラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県四国中央市土居町畑野', '38', '38213', '7990714', '愛媛県', 'エヒメケン', '四国中央市', 'シコクチュウオウシ', '土居町畑野', 'ドイチョウハタノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県四国中央市土居町上野', '38', '38213', '7990721', '愛媛県', 'エヒメケン', '四国中央市', 'シコクチュウオウシ', '土居町上野', 'ドイチョウウエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県四国中央市土居町北野', '38', '38213', '7990722', '愛媛県', 'エヒメケン', '四国中央市', 'シコクチュウオウシ', '土居町北野', 'ドイチョウキタノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県四国中央市土居町天満', '38', '38213', '7990723', '愛媛県', 'エヒメケン', '四国中央市', 'シコクチュウオウシ', '土居町天満', 'ドイチョウテンマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県四国中央市土居町蕪崎', '38', '38213', '7990724', '愛媛県', 'エヒメケン', '四国中央市', 'シコクチュウオウシ', '土居町蕪崎', 'ドイチョウカブラサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市小松町新屋敷', '38', '38206', '7991101', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '小松町新屋敷', 'コマツチョウシンヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市小松町南川', '38', '38206', '7991102', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '小松町南川', 'コマツチョウミナミガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市小松町北川', '38', '38206', '7991103', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '小松町北川', 'コマツチョウキタガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市小松町妙口', '38', '38206', '7991104', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '小松町妙口', 'コマツチョウミョウグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市小松町大郷', '38', '38206', '7991105', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '小松町大郷', 'コマツチョウオオゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市小松町大頭', '38', '38206', '7991106', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '小松町大頭', 'コマツチョウオオト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市小松町明穂', '38', '38206', '7991107', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '小松町明穂', 'コマツチョウアカオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市小松町安井', '38', '38206', '7991108', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '小松町安井', 'コマツチョウヤスイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市小松町石鎚湯波', '38', '38206', '7991111', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '小松町石鎚', 'コマツチョウイシヅチ', null, null, '湯波', 'ユウナミ');
INSERT INTO `ms_addresses` VALUES ('102267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市小松町石鎚', '38', '38206', '7991112', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '小松町石鎚', 'コマツチョウイシヅチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市三芳', '38', '38206', '7991301', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '三芳', 'ミヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市楠', '38', '38206', '7991302', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '楠', 'クスノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市河原津', '38', '38206', '7991303', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '河原津', 'カワラヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市河原津新田', '38', '38206', '7991304', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '河原津新田', 'カワラヅシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市宮之内', '38', '38206', '7991311', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '宮之内', 'ミヤノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市大野', '38', '38206', '7991312', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '大野', 'オオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市旦之上', '38', '38206', '7991313', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '旦之上', 'ダンノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市河之内', '38', '38206', '7991314', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '河之内', 'カワノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市黒谷', '38', '38206', '7991315', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '黒谷', 'クロダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市福成寺', '38', '38206', '7991316', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '福成寺', 'フクジョウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市実報寺', '38', '38206', '7991317', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '実報寺', 'ジツポウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市高田', '38', '38206', '7991321', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '高田', 'タカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市国安', '38', '38206', '7991322', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '国安', 'クニヤス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市桑村', '38', '38206', '7991323', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '桑村', 'クワムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市高田正法寺', '38', '38206', '7991324', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '高田', 'タカタ', null, null, '正法寺', 'ショウホウジ');
INSERT INTO `ms_addresses` VALUES ('102284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市新市', '38', '38206', '7991325', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '新市', 'シンイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市新町', '38', '38206', '7991331', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市安用出作', '38', '38206', '7991332', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '安用出作', 'ヤスモチデサク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市安用', '38', '38206', '7991333', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '安用', 'ヤスモチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市広岡', '38', '38206', '7991334', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '広岡', 'ヒロオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市石延', '38', '38206', '7991335', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '石延', 'イシノベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市上市', '38', '38206', '7991336', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '上市', 'カミイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市壬生川', '38', '38206', '7991341', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '壬生川', 'ニュウガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市大新田', '38', '38206', '7991342', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '大新田', 'オオシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市喜多台', '38', '38206', '7991343', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '喜多台', 'キタダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市円海寺', '38', '38206', '7991344', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '円海寺', 'エンカイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市明理川', '38', '38206', '7991345', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '明理川', 'アカリガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市三津屋', '38', '38206', '7991351', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '三津屋', 'ミツヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市三津屋東', '38', '38206', '7991352', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '三津屋東', 'ミツヤヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市三津屋南', '38', '38206', '7991353', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '三津屋南', 'ミツヤミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市北条', '38', '38206', '7991354', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '北条', 'ホウジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市広江', '38', '38206', '7991361', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '広江', 'ヒロエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市今在家', '38', '38206', '7991362', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '今在家', 'イマザイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市玉之江', '38', '38206', '7991363', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '玉之江', 'タマノエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市石田', '38', '38206', '7991364', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '石田', 'イシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市周布', '38', '38206', '7991371', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '周布', 'シュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県西条市吉田', '38', '38206', '7991372', '愛媛県', 'エヒメケン', '西条市', 'サイジョウシ', '吉田', 'ヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市喜田村', '38', '38202', '7991501', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '喜田村', 'キタムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市喜田村', '38', '38202', '7991502', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '喜田村', 'キタムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市富田新港', '38', '38202', '7991503', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '富田新港', 'トミタシンミナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市拝志', '38', '38202', '7991504', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '拝志', 'ハイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市東村', '38', '38202', '7991505', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '東村', 'ヒガシムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市東村', '38', '38202', '7991506', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '東村', 'ヒガシムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市東村南', '38', '38202', '7991507', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '東村南', 'ヒガシムラミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市上徳', '38', '38202', '7991511', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '上徳', 'カミトク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市高市', '38', '38202', '7991512', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '高市', 'タカイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市松木', '38', '38202', '7991513', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '松木', 'マツギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市町谷', '38', '38202', '7991514', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '町谷', 'マチヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市古国分', '38', '38202', '7991521', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '古国分', 'フルコクブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市桜井', '38', '38202', '7991522', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '桜井', 'サクライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市郷桜井', '38', '38202', '7991523', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '郷桜井', 'ゴウザクライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市桜井', '38', '38202', '7991524', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '桜井', 'サクライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市湯ノ浦', '38', '38202', '7991525', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '湯ノ浦', 'ユノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市孫兵衛作', '38', '38202', '7991526', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '孫兵衛作', 'マゴベエサク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市長沢', '38', '38202', '7991527', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '長沢', 'ナガサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市唐子台東', '38', '38202', '7991531', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '唐子台東', 'カラコダイヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市唐子台西', '38', '38202', '7991532', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '唐子台西', 'カラコダイニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市国分', '38', '38202', '7991533', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '国分', 'コクブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市桜井団地', '38', '38202', '7991534', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '桜井団地', 'サクライダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市登畑', '38', '38202', '7991535', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '登畑', 'ノボリバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市旦', '38', '38202', '7991536', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '旦', 'ダン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市宮ケ崎', '38', '38202', '7991537', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '宮ケ崎', 'ミヤガザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市古谷', '38', '38202', '7991601', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '古谷', 'コヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市山口', '38', '38202', '7991602', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '山口', 'ヤマグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市朝倉下', '38', '38202', '7991603', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '朝倉下', 'アサクラシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市朝倉北', '38', '38202', '7991604', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '朝倉北', 'アサクラキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市朝倉南甲', '38', '38202', '7991605', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '朝倉南甲', 'アサクラミナミコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市朝倉南乙', '38', '38202', '7991606', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '朝倉南乙', 'アサクラミナミオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市朝倉上', '38', '38202', '7991607', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '朝倉上', 'アサクラカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市波方町波方', '38', '38202', '7992101', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '波方町波方', 'ナミカタチョウナミカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市波方町樋口', '38', '38202', '7992102', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '波方町樋口', 'ナミカタチョウヒノグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市波方町小部', '38', '38202', '7992103', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '波方町小部', 'ナミカタチョウオベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市波方町宮崎', '38', '38202', '7992104', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '波方町宮崎', 'ナミカタチョウミヤザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市波方町馬刀潟', '38', '38202', '7992105', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '波方町馬刀潟', 'ナミカタチョウマテガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市波方町森上', '38', '38202', '7992106', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '波方町森上', 'ナミカタチョウモリアゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市波方町西浦', '38', '38202', '7992107', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '波方町西浦', 'ナミカタチョウニシウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市波方町岡', '38', '38202', '7992108', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '波方町岡', 'ナミカタチョウオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市波方町養老', '38', '38202', '7992109', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '波方町養老', 'ナミカタチョウヨウロウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市波方町大浦', '38', '38202', '7992110', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '波方町大浦', 'ナミカタチョウオオウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市波方町郷', '38', '38202', '7992110', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '波方町郷', 'ナミカタチョウゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市小浦町', '38', '38202', '7992111', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '小浦町', 'コウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市波止浜', '38', '38202', '7992112', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '波止浜', 'ハシハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市高部', '38', '38202', '7992113', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '高部', 'タカベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市杣田', '38', '38202', '7992114', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '杣田', 'ソマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市中堀', '38', '38202', '7992115', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '中堀', 'ナカボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市内堀', '38', '38202', '7992116', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '内堀', 'ウチボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市地堀', '38', '38202', '7992117', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '地堀', 'ジボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市波止浜', '38', '38202', '7992118', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '波止浜', 'ハシハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市来島', '38', '38202', '7992121', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '来島', 'クルシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市来島小島', '38', '38202', '7992122', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '来島', 'クルシマ', null, null, '小島', 'オシマ');
INSERT INTO `ms_addresses` VALUES ('102372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市馬島', '38', '38202', '7992123', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '馬島', 'ウマシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市大西町九王', '38', '38202', '7992201', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '大西町九王', 'オオニシチョウクオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市大西町紺原', '38', '38202', '7992202', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '大西町紺原', 'オオニシチョウコンバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市大西町新町', '38', '38202', '7992203', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '大西町新町', 'オオニシチョウシンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市大西町大井浜', '38', '38202', '7992204', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '大西町大井浜', 'オオニシチョウオオイハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市大西町宮脇', '38', '38202', '7992205', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '大西町宮脇', 'オオニシチョウミヤワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市大西町脇', '38', '38202', '7992206', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '大西町脇', 'オオニシチョウワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市大西町山之内', '38', '38202', '7992207', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '大西町山之内', 'オオニシチョウヤマノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市大西町星浦', '38', '38202', '7992208', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '大西町星浦', 'オオニシチョウホシノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市大西町別府', '38', '38202', '7992209', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '大西町別府', 'オオニシチョウベフ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市菊間町佐方', '38', '38202', '7992301', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '菊間町佐方', 'キクマチョウサガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市菊間町種', '38', '38202', '7992302', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '菊間町種', 'キクマチョウタネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市菊間町浜', '38', '38202', '7992303', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '菊間町浜', 'キクマチョウハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市菊間町池原', '38', '38202', '7992304', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '菊間町池原', 'キクマチョウイケノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市菊間町松尾', '38', '38202', '7992305', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '菊間町松尾', 'キクマチョウマツオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市菊間町河之内', '38', '38202', '7992306', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '菊間町河之内', 'キクマチョウカワノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市菊間町川上', '38', '38202', '7992307', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '菊間町川上', 'キクマチョウカワカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市菊間町中川', '38', '38202', '7992308', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '菊間町中川', 'キクマチョウナカノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市菊間町高田', '38', '38202', '7992309', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '菊間町高田', 'キクマチョウコウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市菊間町長坂', '38', '38202', '7992310', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '菊間町長坂', 'キクマチョウナガサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市菊間町西山', '38', '38202', '7992311', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '菊間町西山', 'キクマチョウニシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県今治市菊間町田之尻', '38', '38202', '7992312', '愛媛県', 'エヒメケン', '今治市', 'イマバリシ', '菊間町田之尻', 'キクマチョウタノシリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市浅海原', '38', '38201', '7992401', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '浅海原', 'アサナミハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市浅海本谷', '38', '38201', '7992402', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '浅海本谷', 'アサナミホンダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市萩原', '38', '38201', '7992403', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '萩原', 'ハギワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市庄', '38', '38201', '7992404', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '庄', 'ショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市上難波', '38', '38201', '7992405', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '上難波', 'カミナンバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市中通', '38', '38201', '7992406', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '中通', 'ナカドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市下難波', '38', '38201', '7992407', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '下難波', 'シモナンバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市大浦', '38', '38201', '7992408', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '大浦', 'オオウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市小山田', '38', '38201', '7992410', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '小山田', 'オヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市儀式', '38', '38201', '7992411', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '儀式', 'ギシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市庄府', '38', '38201', '7992412', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '庄府', 'ショウブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市立岩米之野', '38', '38201', '7992413', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '立岩米之野', 'タテイワコメノノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市立岩中村', '38', '38201', '7992414', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '立岩中村', 'タテイワナカムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市猿川', '38', '38201', '7992415', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '猿川', 'サルカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市猪木', '38', '38201', '7992416', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '猪木', 'イノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市滝本', '38', '38201', '7992416', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '滝本', 'タキモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市才之原', '38', '38201', '7992417', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '才之原', 'サイノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市尾儀原', '38', '38201', '7992418', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '尾儀原', 'オギハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市猿川原', '38', '38201', '7992419', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '猿川原', 'サルカワバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市正岡神田', '38', '38201', '7992421', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '正岡神田', 'マサオカカンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市高田', '38', '38201', '7992422', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '高田', 'タカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市院内', '38', '38201', '7992423', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '院内', 'インナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市八反地', '38', '38201', '7992424', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '八反地', 'ハッタンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市中西外', '38', '38201', '7992425', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '中西外', 'ナカニシソト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市中西内', '38', '38201', '7992426', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '中西内', 'ナカニシウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市北条辻', '38', '38201', '7992430', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '北条辻', 'ホウジョウツジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市北条', '38', '38201', '7992431', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '北条', 'ホウジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市土手内', '38', '38201', '7992432', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '土手内', 'ドテウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市安居島', '38', '38201', '7992433', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '安居島', 'アイジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市柳原', '38', '38201', '7992434', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '柳原', 'ヤナギハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市府中', '38', '38201', '7992435', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '府中', 'フチュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市河野別府', '38', '38201', '7992436', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '河野別府', 'コウノベップ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市夏目', '38', '38201', '7992437', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '夏目', 'ナツメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市河野中須賀', '38', '38201', '7992438', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '河野中須賀', 'コウノナカスガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市片山', '38', '38201', '7992439', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '片山', 'カタヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市宮内', '38', '38201', '7992441', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '宮内', 'ミヤウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市常保免', '38', '38201', '7992442', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '常保免', 'ジョウホウメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市善応寺', '38', '38201', '7992443', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '善応寺', 'ゼンオウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市横谷', '38', '38201', '7992444', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '横谷', 'ヨコダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市河野高山', '38', '38201', '7992445', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '河野高山', 'コウノコヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市牛谷', '38', '38201', '7992446', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '牛谷', 'ウシダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市佐古', '38', '38201', '7992447', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '佐古', 'サコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市小川谷', '38', '38201', '7992451', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '小川谷', 'コガダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市平林', '38', '38201', '7992452', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '平林', 'ヒラバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市麓', '38', '38201', '7992453', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '麓', 'フモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市客', '38', '38201', '7992454', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '客', 'キャク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市常竹', '38', '38201', '7992455', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '常竹', 'ツネタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市本谷', '38', '38201', '7992456', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '本谷', 'ホンダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市西谷', '38', '38201', '7992457', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '西谷', 'ニシダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市大西谷', '38', '38201', '7992458', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '大西谷', 'オオニシダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市苞木', '38', '38201', '7992460', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '苞木', 'スボキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市鹿峰', '38', '38201', '7992461', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '鹿峰', 'カノミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市久保', '38', '38201', '7992462', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '久保', 'クボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市粟井河原', '38', '38201', '7992463', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '粟井河原', 'アワイカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市安岡', '38', '38201', '7992464', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '安岡', 'ヤスオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市和田', '38', '38201', '7992465', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '和田', 'ワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市鴨之池', '38', '38201', '7992466', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '鴨之池', 'カモノイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市磯河内', '38', '38201', '7992467', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '磯河内', 'イソコウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市小川', '38', '38201', '7992468', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '小川', 'オガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市光洋台', '38', '38201', '7992469', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '光洋台', 'コウヨウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市柳谷町', '38', '38201', '7992641', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '柳谷町', 'ヤナイダニマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市恩地町', '38', '38201', '7992642', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '恩地町', 'オンジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市梅木町', '38', '38201', '7992643', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '梅木町', 'ウメキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市上総町', '38', '38201', '7992644', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '上総町', 'カズサマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市小屋町', '38', '38201', '7992645', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '小屋町', 'コヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市神次郎町', '38', '38201', '7992646', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '神次郎町', 'ジンジロウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市城山町', '38', '38201', '7992647', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '城山町', 'ジョウザンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市菅沢町', '38', '38201', '7992648', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '菅沢町', 'スゲザワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市東大栗町', '38', '38201', '7992649', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '東大栗町', 'ヒガシオオグリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市堀江町', '38', '38201', '7992651', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '堀江町', 'ホリエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市福角町', '38', '38201', '7992652', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '福角町', 'フクズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市権現町', '38', '38201', '7992653', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '権現町', 'ゴンゲンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市内宮町', '38', '38201', '7992654', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '内宮町', 'ウチミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市馬木町', '38', '38201', '7992655', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '馬木町', 'ウマキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市和気町', '38', '38201', '7992656', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '和気町', 'ワケマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市勝岡町', '38', '38201', '7992661', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '勝岡町', 'カツオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県松山市太山寺町', '38', '38201', '7992662', '愛媛県', 'エヒメケン', '松山市', 'マツヤマシ', '太山寺町', 'タイサンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県伊予市', '38', '38210', '7993100', '愛媛県', 'エヒメケン', '伊予市', 'イヨシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('102485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県伊予市八倉', '38', '38210', '7993101', '愛媛県', 'エヒメケン', '伊予市', 'イヨシ', '八倉', 'ヤクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県伊予市宮下', '38', '38210', '7993102', '愛媛県', 'エヒメケン', '伊予市', 'イヨシ', '宮下', 'ミヤシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県伊予市上野', '38', '38210', '7993103', '愛媛県', 'エヒメケン', '伊予市', 'イヨシ', '上野', 'ウエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県伊予市上三谷', '38', '38210', '7993104', '愛媛県', 'エヒメケン', '伊予市', 'イヨシ', '上三谷', 'カミミタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県伊予市下三谷', '38', '38210', '7993105', '愛媛県', 'エヒメケン', '伊予市', 'イヨシ', '下三谷', 'シモミタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県伊予市下吾川', '38', '38210', '7993111', '愛媛県', 'エヒメケン', '伊予市', 'イヨシ', '下吾川', 'シモアガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県伊予市上吾川', '38', '38210', '7993112', '愛媛県', 'エヒメケン', '伊予市', 'イヨシ', '上吾川', 'カミアガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県伊予市米湊', '38', '38210', '7993113', '愛媛県', 'エヒメケン', '伊予市', 'イヨシ', '米湊', 'コミナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県伊予市灘町', '38', '38210', '7993114', '愛媛県', 'エヒメケン', '伊予市', 'イヨシ', '灘町', 'ナダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県伊予市湊町', '38', '38210', '7993115', '愛媛県', 'エヒメケン', '伊予市', 'イヨシ', '湊町', 'ミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県伊予市稲荷', '38', '38210', '7993121', '愛媛県', 'エヒメケン', '伊予市', 'イヨシ', '稲荷', 'イナリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県伊予市市場', '38', '38210', '7993122', '愛媛県', 'エヒメケン', '伊予市', 'イヨシ', '市場', 'イチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県伊予市中村', '38', '38210', '7993123', '愛媛県', 'エヒメケン', '伊予市', 'イヨシ', '中村', 'ナカムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県伊予市三秋', '38', '38210', '7993124', '愛媛県', 'エヒメケン', '伊予市', 'イヨシ', '三秋', 'ミアキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県伊予市森', '38', '38210', '7993125', '愛媛県', 'エヒメケン', '伊予市', 'イヨシ', '森', 'モリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県伊予市本郡', '38', '38210', '7993126', '愛媛県', 'エヒメケン', '伊予市', 'イヨシ', '本郡', 'ホング', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県伊予市尾崎', '38', '38210', '7993127', '愛媛県', 'エヒメケン', '伊予市', 'イヨシ', '尾崎', 'オサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県伊予市三島町', '38', '38210', '7993128', '愛媛県', 'エヒメケン', '伊予市', 'イヨシ', '三島町', 'ミシママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県伊予市大平', '38', '38210', '7993131', '愛媛県', 'エヒメケン', '伊予市', 'イヨシ', '大平', 'オオヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県伊予市平岡', '38', '38210', '7993132', '愛媛県', 'エヒメケン', '伊予市', 'イヨシ', '平岡', 'ヒラオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県伊予市下唐川', '38', '38210', '7993133', '愛媛県', 'エヒメケン', '伊予市', 'イヨシ', '下唐川', 'シモカラカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県伊予市上唐川', '38', '38210', '7993134', '愛媛県', 'エヒメケン', '伊予市', 'イヨシ', '上唐川', 'カミカラカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県伊予市両沢', '38', '38210', '7993135', '愛媛県', 'エヒメケン', '伊予市', 'イヨシ', '両沢', 'リョウザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県伊予市鵜崎', '38', '38210', '7993136', '愛媛県', 'エヒメケン', '伊予市', 'イヨシ', '鵜崎', 'ウノサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県伊予市双海町高野川', '38', '38210', '7993201', '愛媛県', 'エヒメケン', '伊予市', 'イヨシ', '双海町高野川', 'フタミチョウコウノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県伊予市双海町上灘', '38', '38210', '7993202', '愛媛県', 'エヒメケン', '伊予市', 'イヨシ', '双海町上灘', 'フタミチョウカミナダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県伊予市双海町高岸', '38', '38210', '7993207', '愛媛県', 'エヒメケン', '伊予市', 'イヨシ', '双海町高岸', 'フタミチョウタカギシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県伊予市双海町大久保', '38', '38210', '7993311', '愛媛県', 'エヒメケン', '伊予市', 'イヨシ', '双海町大久保', 'フタミチョウオオクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県伊予市双海町串', '38', '38210', '7993312', '愛媛県', 'エヒメケン', '伊予市', 'イヨシ', '双海町串', 'フタミチョウクシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県伊予市双海町串上浜', '38', '38210', '7993313', '愛媛県', 'エヒメケン', '伊予市', 'イヨシ', '双海町串', 'フタミチョウクシ', null, null, '上浜', 'カミハマ');
INSERT INTO `ms_addresses` VALUES ('102521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県伊予市双海町串下浜', '38', '38210', '7993314', '愛媛県', 'エヒメケン', '伊予市', 'イヨシ', '双海町串', 'フタミチョウクシ', null, null, '下浜', 'シモハマ');
INSERT INTO `ms_addresses` VALUES ('102522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県大洲市長浜甲', '38', '38207', '7993401', '愛媛県', 'エヒメケン', '大洲市', 'オオズシ', '長浜甲', 'ナガハマコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県大洲市長浜乙', '38', '38207', '7993402', '愛媛県', 'エヒメケン', '大洲市', 'オオズシ', '長浜乙', 'ナガハマオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県大洲市長浜町仁久甲', '38', '38207', '7993403', '愛媛県', 'エヒメケン', '大洲市', 'オオズシ', '長浜町仁久甲', 'ナガハマチョウニギュウコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県大洲市長浜町沖浦甲', '38', '38207', '7993404', '愛媛県', 'エヒメケン', '大洲市', 'オオズシ', '長浜町沖浦甲', 'ナガハマチョウオキウラコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県大洲市長浜町沖浦乙', '38', '38207', '7993405', '愛媛県', 'エヒメケン', '大洲市', 'オオズシ', '長浜町沖浦乙', 'ナガハマチョウオキウラオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県大洲市長浜町沖浦丙', '38', '38207', '7993406', '愛媛県', 'エヒメケン', '大洲市', 'オオズシ', '長浜町沖浦丙', 'ナガハマチョウオキウラヘイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県大洲市長浜町黒田甲', '38', '38207', '7993407', '愛媛県', 'エヒメケン', '大洲市', 'オオズシ', '長浜町黒田甲', 'ナガハマチョウクロンタコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県大洲市長浜町今坊甲', '38', '38207', '7993411', '愛媛県', 'エヒメケン', '大洲市', 'オオズシ', '長浜町今坊甲', 'ナガハマチョウコンボウコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県大洲市長浜町晴海', '38', '38207', '7993412', '愛媛県', 'エヒメケン', '大洲市', 'オオズシ', '長浜町晴海', 'ナガハマチョウハルミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県大洲市長浜町拓海', '38', '38207', '7993413', '愛媛県', 'エヒメケン', '大洲市', 'オオズシ', '長浜町拓海', 'ナガハマチョウタクミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県大洲市戒川甲', '38', '38207', '7993421', '愛媛県', 'エヒメケン', '大洲市', 'オオズシ', '戒川甲', 'カイカワコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県大洲市長浜町大越甲', '38', '38207', '7993422', '愛媛県', 'エヒメケン', '大洲市', 'オオズシ', '長浜町大越甲', 'ナガハマチョウオオゴシコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県大洲市白滝甲', '38', '38207', '7993431', '愛媛県', 'エヒメケン', '大洲市', 'オオズシ', '白滝甲', 'シラタキコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県大洲市柴甲', '38', '38207', '7993432', '愛媛県', 'エヒメケン', '大洲市', 'オオズシ', '柴甲', 'シバコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県大洲市柴乙', '38', '38207', '7993433', '愛媛県', 'エヒメケン', '大洲市', 'オオズシ', '柴乙', 'シバオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県大洲市長浜町下須戒甲', '38', '38207', '7993441', '愛媛県', 'エヒメケン', '大洲市', 'オオズシ', '長浜町下須戒甲', 'ナガハマチョウシモスカイコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県大洲市長浜町穂積甲', '38', '38207', '7993442', '愛媛県', 'エヒメケン', '大洲市', 'オオズシ', '長浜町穂積甲', 'ナガハマチョウホズミコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県大洲市長浜町穂積乙', '38', '38207', '7993443', '愛媛県', 'エヒメケン', '大洲市', 'オオズシ', '長浜町穂積乙', 'ナガハマチョウホヅミオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県大洲市長浜町上老松甲', '38', '38207', '7993444', '愛媛県', 'エヒメケン', '大洲市', 'オオズシ', '長浜町上老松甲', 'ナガハマチョウジョロマツコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県大洲市長浜町須沢丙', '38', '38207', '7993451', '愛媛県', 'エヒメケン', '大洲市', 'オオズシ', '長浜町須沢丙', 'ナガハマチョウスサワヘイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県大洲市長浜町櫛生甲', '38', '38207', '7993452', '愛媛県', 'エヒメケン', '大洲市', 'オオズシ', '長浜町櫛生甲', 'ナガハマチョウクシュウコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県大洲市長浜町櫛生乙', '38', '38207', '7993453', '愛媛県', 'エヒメケン', '大洲市', 'オオズシ', '長浜町櫛生乙', 'ナガハマチョウクシュウオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県大洲市長浜町櫛生丙', '38', '38207', '7993454', '愛媛県', 'エヒメケン', '大洲市', 'オオズシ', '長浜町櫛生丙', 'ナガハマチョウクシュウヘイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県大洲市長浜町出海甲', '38', '38207', '7993455', '愛媛県', 'エヒメケン', '大洲市', 'オオズシ', '長浜町出海甲', 'ナガハマチョウイズミコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県大洲市長浜町出海乙', '38', '38207', '7993456', '愛媛県', 'エヒメケン', '大洲市', 'オオズシ', '長浜町出海乙', 'ナガハマチョウイズミオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県大洲市豊茂甲', '38', '38207', '7993461', '愛媛県', 'エヒメケン', '大洲市', 'オオズシ', '豊茂甲', 'トヨシゲコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県大洲市豊茂乙', '38', '38207', '7993462', '愛媛県', 'エヒメケン', '大洲市', 'オオズシ', '豊茂乙', 'トヨシゲオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県大洲市豊茂丙', '38', '38207', '7993463', '愛媛県', 'エヒメケン', '大洲市', 'オオズシ', '豊茂丙', 'トヨシゲヘイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県大洲市豊茂丁', '38', '38207', '7993464', '愛媛県', 'エヒメケン', '大洲市', 'オオズシ', '豊茂丁', 'トヨシゲテイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県大洲市長浜町青島', '38', '38207', '7993470', '愛媛県', 'エヒメケン', '大洲市', 'オオズシ', '長浜町青島', 'ナガハマチョウアオシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市吉田町北小路', '38', '38203', '7993701', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '吉田町北小路', 'ヨシダチョウキタコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市吉田町西小路', '38', '38203', '7993702', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '吉田町西小路', 'ヨシダチョウニシコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市吉田町東小路', '38', '38203', '7993703', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '吉田町東小路', 'ヨシダチョウヒガシコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市吉田町魚棚', '38', '38203', '7993704', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '吉田町魚棚', 'ヨシダチョウウオタナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市吉田町本町', '38', '38203', '7993705', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '吉田町本町', 'ヨシダチョウホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市吉田町裡町', '38', '38203', '7993706', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '吉田町裡町', 'ヨシダチョウウラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市吉田町鶴間御殿内', '38', '38203', '7993707', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '吉田町鶴間', 'ヨシダチョウツルマ', null, null, '御殿内', 'ゴテンウチ');
INSERT INTO `ms_addresses` VALUES ('102559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市吉田町立間尻', '38', '38203', '7993710', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '吉田町立間尻', 'ヨシダチョウタチマジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市吉田町知永', '38', '38203', '7993720', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '吉田町知永', 'ヨシダチョウチナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市吉田町立間', '38', '38203', '7993730', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '吉田町立間', 'ヨシダチョウタチマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市吉田町白浦', '38', '38203', '7993741', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '吉田町白浦', 'ヨシダチョウシロウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市吉田町法花津', '38', '38203', '7993742', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '吉田町法花津', 'ヨシダチョウホケヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市吉田町深浦', '38', '38203', '7993743', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '吉田町深浦', 'ヨシダチョウフカウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市吉田町沖村', '38', '38203', '7993751', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '吉田町沖村', 'ヨシダチョウオキムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市吉田町河内', '38', '38203', '7993752', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '吉田町河内', 'ヨシダチョウカワチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市吉田町鶴間', '38', '38203', '7993761', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '吉田町鶴間', 'ヨシダチョウツルマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市吉田町鶴間鶴間団地', '38', '38203', '7993762', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '吉田町鶴間', 'ヨシダチョウツルマ', null, null, '鶴間団地', 'ツルマダンチ');
INSERT INTO `ms_addresses` VALUES ('102569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市吉田町浅川', '38', '38203', '7993763', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '吉田町浅川', 'ヨシダチョウアサカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市吉田町南君', '38', '38203', '7993771', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '吉田町南君', 'ヨシダチョウナギミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '愛媛県宇和島市吉田町奥浦', '38', '38203', '7993772', '愛媛県', 'エヒメケン', '宇和島市', 'ウワジマシ', '吉田町奥浦', 'ヨシダチョウオクウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市', '01', '01207', '0800000', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('102575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区', '40', '40101', '8000000', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('102576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区風師4丁目', '40', '40101', '8000001', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '風師', 'カザシ', null, null, '4丁目', '04チョウメ');
INSERT INTO `ms_addresses` VALUES ('102577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区二タ松町', '40', '40101', '8000002', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '二タ松町', 'フタマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区片上町', '40', '40101', '8000003', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '片上町', 'カタガミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区北川町', '40', '40101', '8000004', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '北川町', 'キタガワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区羽山', '40', '40101', '8000005', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '羽山', 'ハヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区矢筈町', '40', '40101', '8000006', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '矢筈町', 'ヤハズマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区小森江', '40', '40101', '8000007', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '小森江', 'コモリエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区葛葉2丁目', '40', '40101', '8000008', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '葛葉', 'クズハ', null, null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('102584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区葛葉3丁目', '40', '40101', '8000008', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '葛葉', 'クズハ', null, null, '3丁目', '03チョウメ');
INSERT INTO `ms_addresses` VALUES ('102585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区奥田', '40', '40101', '8000011', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '奥田', 'オクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区松崎町', '40', '40101', '8000012', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '松崎町', 'マツザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区城山町', '40', '40101', '8000013', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '城山町', 'シロヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区大里', '40', '40101', '8000014', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '大里', 'ダイリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区寺内', '40', '40101', '8000015', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '寺内', 'ジナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区上二十町', '40', '40101', '8000016', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '上二十町', 'カミニジッチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区永黒', '40', '40101', '8000017', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '永黒', 'ナガグロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区大里桜ケ丘', '40', '40101', '8000018', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '大里桜ケ丘', 'ダイリサクラガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区南本町', '40', '40101', '8000021', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '南本町', 'ミナミホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区大里東', '40', '40101', '8000022', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '大里東', 'ダイリヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区中二十町', '40', '40101', '8000023', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '中二十町', 'ナカニジッチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区大里戸ノ上', '40', '40101', '8000024', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '大里戸ノ上', 'ダイリトノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区柳町', '40', '40101', '8000025', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '柳町', 'ヤナギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区梅ノ木町', '40', '40101', '8000026', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '梅ノ木町', 'ウメノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区黄金町', '40', '40101', '8000027', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '黄金町', 'コガネマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区下二十町', '40', '40101', '8000028', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '下二十町', 'シモニジッチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区大里東口', '40', '40101', '8000029', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '大里東口', 'ダイリヒガシグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区桃山台', '40', '40101', '8000030', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '桃山台', 'モモヤマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区高田', '40', '40101', '8000031', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '高田', 'タカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区不老町', '40', '40101', '8000032', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '不老町', 'フロウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区大里桃山町', '40', '40101', '8000033', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '大里桃山町', 'ダイリモモヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区小松町', '40', '40101', '8000034', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '小松町', 'コマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区別院', '40', '40101', '8000035', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '別院', 'ベツイン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区柳原町', '40', '40101', '8000036', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '柳原町', 'ヤナギハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区原町別院', '40', '40101', '8000037', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '原町別院', 'ハラマチベツイン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区大里原町', '40', '40101', '8000038', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '大里原町', 'ダイリハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区中町', '40', '40101', '8000039', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '中町', 'ナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区泉ケ丘', '40', '40101', '8000041', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '泉ケ丘', 'イズミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区上馬寄', '40', '40101', '8000042', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '上馬寄', 'カミマイソウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区緑ケ丘', '40', '40101', '8000043', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '緑ケ丘', 'ミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区上藤松', '40', '40101', '8000044', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '上藤松', 'カミフジマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区青葉台', '40', '40101', '8000045', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '青葉台', 'アオバダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区光町', '40', '40101', '8000046', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '光町', 'ヒカリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区藤松', '40', '40101', '8000047', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '藤松', 'フジマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区稲積', '40', '40101', '8000048', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '稲積', 'イナヅミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区下馬寄', '40', '40101', '8000051', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '下馬寄', 'シモマイソウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区東馬寄', '40', '40101', '8000052', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '東馬寄', 'ヒガシマイソウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区新原町', '40', '40101', '8000053', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '新原町', 'シンハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区社ノ木', '40', '40101', '8000054', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '社ノ木', 'シャノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区東新町', '40', '40101', '8000055', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '東新町', 'ヒガシシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区西新町', '40', '40101', '8000056', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '西新町', 'ニシシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区大里新町', '40', '40101', '8000057', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '大里新町', 'ダイリシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区片上海岸', '40', '40101', '8000061', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '片上海岸', 'カタガミカイガン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区大里元町', '40', '40101', '8000062', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '大里元町', 'ダイリモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区大里本町', '40', '40101', '8000063', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '大里本町', 'ダイリホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区松原', '40', '40101', '8000064', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '松原', 'マツバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市大通南', '01', '01207', '0800010', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '大通南', 'オオドオリミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区伊川', '40', '40101', '8000101', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '伊川', 'イカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区猿喰', '40', '40101', '8000102', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '猿喰', 'サルハミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市西1条南', '01', '01207', '0800011', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '西1条南', 'ニシ01ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区今津', '40', '40101', '8000111', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '今津', 'イマヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区畑', '40', '40101', '8000112', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '畑', 'ハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区新門司北', '40', '40101', '8000113', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '新門司北', 'シンモジキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区吉志', '40', '40101', '8000114', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '吉志', 'キシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区新門司', '40', '40101', '8000115', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '新門司', 'シンモジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区恒見町', '40', '40101', '8000116', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '恒見町', 'ツネミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区恒見', '40', '40101', '8000117', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '恒見', 'ツネミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区吉志新町', '40', '40101', '8000118', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '吉志新町', 'キシシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市西2条南', '01', '01207', '0800012', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '西2条南', 'ニシ02ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市西3条南', '01', '01207', '0800013', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '西3条南', 'ニシ03ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市西4条南', '01', '01207', '0800014', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '西4条南', 'ニシ04ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市西5条南', '01', '01207', '0800015', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '西5条南', 'ニシ05ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市西6条南', '01', '01207', '0800016', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '西6条南', 'ニシ06ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市西7条南', '01', '01207', '0800017', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '西7条南', 'ニシ07ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市西8条南', '01', '01207', '0800018', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '西8条南', 'ニシ08ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市西9条南', '01', '01207', '0800019', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '西9条南', 'ニシ09ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市西10条南', '01', '01207', '0800020', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '西10条南', 'ニシ10ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区上吉田', '40', '40107', '8000201', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '上吉田', 'カミヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区吉田', '40', '40107', '8000202', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '吉田', 'ヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区下吉田', '40', '40107', '8000203', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '下吉田', 'シモヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区中吉田', '40', '40107', '8000204', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '中吉田', 'ナカヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区沼南町', '40', '40107', '8000205', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '沼南町', 'ヌマミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区葛原東', '40', '40107', '8000206', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '葛原東', 'クズハラヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区沼緑町', '40', '40107', '8000207', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '沼緑町', 'ヌマミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区沼本町', '40', '40107', '8000208', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '沼本町', 'ヌマホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区沼', '40', '40107', '8000209', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '沼', 'ヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市西11条南', '01', '01207', '0800021', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '西11条南', 'ニシ11ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区吉田にれの木坂', '40', '40107', '8000210', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '吉田にれの木坂', 'ヨシダニレノキザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区新曽根', '40', '40107', '8000211', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '新曽根', 'シンソネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区曽根', '40', '40107', '8000212', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '曽根', 'ソネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区中曽根東', '40', '40107', '8000213', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '中曽根東', 'ナカソネヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区曽根新田', '40', '40107', '8000214', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '曽根新田', 'ソネシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区上曽根新町', '40', '40107', '8000215', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '上曽根新町', 'カミソネシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区中曽根新町', '40', '40107', '8000216', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '中曽根新町', 'ナカソネシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区下曽根', '40', '40107', '8000217', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '下曽根', 'シモソネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区沼新町', '40', '40107', '8000218', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '沼新町', 'ヌマシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区曽根新田北', '40', '40107', '8000219', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '曽根新田北', 'ソネシンデンキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市西12条南', '01', '01207', '0800022', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '西12条南', 'ニシ12ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区曽根新田南', '40', '40107', '8000220', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '曽根新田南', 'ソネシンデンミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区下曽根新町', '40', '40107', '8000221', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '下曽根新町', 'シモソネシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区中曽根', '40', '40107', '8000222', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '中曽根', 'ナカソネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区上曽根', '40', '40107', '8000223', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '上曽根', 'カミソネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区東貫', '40', '40107', '8000224', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '東貫', 'ヒガシヌキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区田原', '40', '40107', '8000225', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '田原', 'タハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区田原新町', '40', '40107', '8000226', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '田原新町', 'タハラシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区津田新町', '40', '40107', '8000227', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '津田新町', 'ツダシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区長野', '40', '40107', '8000228', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '長野', 'ナガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市西13条南', '01', '01207', '0800023', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '西13条南', 'ニシ13ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区朽網', '40', '40107', '8000231', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '朽網', 'クサミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区朽網東', '40', '40107', '8000232', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '朽網東', 'クサミヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区朽網西', '40', '40107', '8000233', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '朽網西', 'クサミニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区貫弥生が丘', '40', '40107', '8000234', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '貫弥生が丘', 'ヌキヤヨイガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区中貫本町', '40', '40107', '8000235', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '中貫本町', 'ナカヌキホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区下貫', '40', '40107', '8000236', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '下貫', 'シモヌキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区中貫', '40', '40107', '8000237', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '中貫', 'ナカヌキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市西14条南', '01', '01207', '0800024', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '西14条南', 'ニシ14ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区長野本町', '40', '40107', '8000241', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '長野本町', 'ナガノホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区津田', '40', '40107', '8000242', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '津田', 'ツダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区西貫', '40', '40107', '8000243', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '西貫', 'ニシヌキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区上貫', '40', '40107', '8000244', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '上貫', 'カミヌキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区貫', '40', '40107', '8000245', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '貫', 'ヌキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区長野', '40', '40107', '8000246', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '長野', 'ナガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区長野東町', '40', '40107', '8000247', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '長野東町', 'ナガノヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区津田南町', '40', '40107', '8000248', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '津田南町', 'ツダミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市西15条南', '01', '01207', '0800025', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '西15条南', 'ニシ15ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区葛原', '40', '40107', '8000251', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '葛原', 'クズハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区葛原高松', '40', '40107', '8000252', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '葛原高松', 'クズハラタカマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区葛原本町', '40', '40107', '8000253', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '葛原本町', 'クズハラホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区葛原元町', '40', '40107', '8000254', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '葛原元町', 'クズハラモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区上葛原', '40', '40107', '8000255', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '上葛原', 'カミクズハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区湯川新町', '40', '40107', '8000256', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '湯川新町', 'ユガワシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区湯川', '40', '40107', '8000257', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '湯川', 'ユガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区安部山', '40', '40107', '8000258', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '安部山', 'アベヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市西16条南', '01', '01207', '0800026', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '西16条南', 'ニシ16ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市西17条南', '01', '01207', '0800027', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '西17条南', 'ニシ17ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市西18条南', '01', '01207', '0800028', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '西18条南', 'ニシ18ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市西19条南35丁目', '01', '01207', '0800029', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '西19条南', 'ニシ19ジョウミナミ', null, null, '35丁目', '35チョウメ');
INSERT INTO `ms_addresses` VALUES ('102715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市西19条南36丁目', '01', '01207', '0800029', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '西19条南', 'ニシ19ジョウミナミ', null, null, '36丁目', '36チョウメ');
INSERT INTO `ms_addresses` VALUES ('102716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市西19条南37丁目', '01', '01207', '0800029', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '西19条南', 'ニシ19ジョウミナミ', null, null, '37丁目', '37チョウメ');
INSERT INTO `ms_addresses` VALUES ('102717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市西19条南38丁目', '01', '01207', '0800029', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '西19条南', 'ニシ19ジョウミナミ', null, null, '38丁目', '38チョウメ');
INSERT INTO `ms_addresses` VALUES ('102718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市西19条南41丁目', '01', '01207', '0800029', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '西19条南', 'ニシ19ジョウミナミ', null, null, '41丁目', '41チョウメ');
INSERT INTO `ms_addresses` VALUES ('102719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市西19条南42丁目', '01', '01207', '0800029', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '西19条南', 'ニシ19ジョウミナミ', null, null, '42丁目', '42チョウメ');
INSERT INTO `ms_addresses` VALUES ('102726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市大通北', '01', '01207', '0800030', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '大通北', 'オオドオリキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県京都郡苅田町', '40', '40621', '8000300', '福岡県', 'フクオカケン', '京都郡苅田町', 'ミヤコグンカンダマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('102728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県京都郡苅田町松原町', '40', '40621', '8000301', '福岡県', 'フクオカケン', '京都郡苅田町', 'ミヤコグンカンダマチ', '松原町', 'マツバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県京都郡苅田町若久町', '40', '40621', '8000302', '福岡県', 'フクオカケン', '京都郡苅田町', 'ミヤコグンカンダマチ', '若久町', 'ワカヒサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県京都郡苅田町松山', '40', '40621', '8000303', '福岡県', 'フクオカケン', '京都郡苅田町', 'ミヤコグンカンダマチ', '松山', 'マツヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県京都郡苅田町鳥越町', '40', '40621', '8000304', '福岡県', 'フクオカケン', '京都郡苅田町', 'ミヤコグンカンダマチ', '鳥越町', 'トリゴエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県京都郡苅田町空港南町', '40', '40621', '8000305', '福岡県', 'フクオカケン', '京都郡苅田町', 'ミヤコグンカンダマチ', '空港南町', 'クウコウミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区空港北町', '40', '40107', '8000306', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '空港北町', 'クウコウキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市西1条北', '01', '01207', '0800031', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '西1条北', 'ニシ01ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県京都郡苅田町長浜町', '40', '40621', '8000311', '福岡県', 'フクオカケン', '京都郡苅田町', 'ミヤコグンカンダマチ', '長浜町', 'ナガハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県京都郡苅田町殿川町', '40', '40621', '8000312', '福岡県', 'フクオカケン', '京都郡苅田町', 'ミヤコグンカンダマチ', '殿川町', 'トノガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県京都郡苅田町磯浜町', '40', '40621', '8000313', '福岡県', 'フクオカケン', '京都郡苅田町', 'ミヤコグンカンダマチ', '磯浜町', 'イソハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県京都郡苅田町幸町', '40', '40621', '8000314', '福岡県', 'フクオカケン', '京都郡苅田町', 'ミヤコグンカンダマチ', '幸町', 'サイワイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県京都郡苅田町港町', '40', '40621', '8000315', '福岡県', 'フクオカケン', '京都郡苅田町', 'ミヤコグンカンダマチ', '港町', 'ミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市西2条北', '01', '01207', '0800032', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '西2条北', 'ニシ02ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県京都郡苅田町新浜町', '40', '40621', '8000321', '福岡県', 'フクオカケン', '京都郡苅田町', 'ミヤコグンカンダマチ', '新浜町', 'シンハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県京都郡苅田町二崎', '40', '40621', '8000322', '福岡県', 'フクオカケン', '京都郡苅田町', 'ミヤコグンカンダマチ', '二崎', 'フタザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県京都郡苅田町与原', '40', '40621', '8000323', '福岡県', 'フクオカケン', '京都郡苅田町', 'ミヤコグンカンダマチ', '与原', 'ヨバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県京都郡苅田町浜町', '40', '40621', '8000324', '福岡県', 'フクオカケン', '京都郡苅田町', 'ミヤコグンカンダマチ', '浜町', 'ハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市西3条北', '01', '01207', '0800033', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '西3条北', 'ニシ03ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県京都郡苅田町岡崎', '40', '40621', '8000331', '福岡県', 'フクオカケン', '京都郡苅田町', 'ミヤコグンカンダマチ', '岡崎', 'オカザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県京都郡苅田町鋤崎', '40', '40621', '8000332', '福岡県', 'フクオカケン', '京都郡苅田町', 'ミヤコグンカンダマチ', '鋤崎', 'スキザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県京都郡苅田町黒添', '40', '40621', '8000333', '福岡県', 'フクオカケン', '京都郡苅田町', 'ミヤコグンカンダマチ', '黒添', 'クロゾエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県京都郡苅田町法正寺', '40', '40621', '8000334', '福岡県', 'フクオカケン', '京都郡苅田町', 'ミヤコグンカンダマチ', '法正寺', 'ホウショウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県京都郡苅田町谷', '40', '40621', '8000335', '福岡県', 'フクオカケン', '京都郡苅田町', 'ミヤコグンカンダマチ', '谷', 'タニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県京都郡苅田町山口', '40', '40621', '8000336', '福岡県', 'フクオカケン', '京都郡苅田町', 'ミヤコグンカンダマチ', '山口', 'ヤマグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県京都郡苅田町稲光', '40', '40621', '8000337', '福岡県', 'フクオカケン', '京都郡苅田町', 'ミヤコグンカンダマチ', '稲光', 'イナミツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県京都郡苅田町葛川', '40', '40621', '8000338', '福岡県', 'フクオカケン', '京都郡苅田町', 'ミヤコグンカンダマチ', '葛川', 'クズガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市西4条北', '01', '01207', '0800034', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '西4条北', 'ニシ04ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県京都郡苅田町下新津', '40', '40621', '8000341', '福岡県', 'フクオカケン', '京都郡苅田町', 'ミヤコグンカンダマチ', '下新津', 'シモアラツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県京都郡苅田町下片島', '40', '40621', '8000342', '福岡県', 'フクオカケン', '京都郡苅田町', 'ミヤコグンカンダマチ', '下片島', 'シモカタシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県京都郡苅田町上片島', '40', '40621', '8000343', '福岡県', 'フクオカケン', '京都郡苅田町', 'ミヤコグンカンダマチ', '上片島', 'カミカタシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県京都郡苅田町新津', '40', '40621', '8000344', '福岡県', 'フクオカケン', '京都郡苅田町', 'ミヤコグンカンダマチ', '新津', 'アラツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県京都郡苅田町小波瀬', '40', '40621', '8000345', '福岡県', 'フクオカケン', '京都郡苅田町', 'ミヤコグンカンダマチ', '小波瀬', 'オバセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市西5条北', '01', '01207', '0800035', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '西5条北', 'ニシ05ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県京都郡苅田町京町', '40', '40621', '8000351', '福岡県', 'フクオカケン', '京都郡苅田町', 'ミヤコグンカンダマチ', '京町', 'キョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県京都郡苅田町富久町', '40', '40621', '8000352', '福岡県', 'フクオカケン', '京都郡苅田町', 'ミヤコグンカンダマチ', '富久町', 'トミヒサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県京都郡苅田町尾倉', '40', '40621', '8000353', '福岡県', 'フクオカケン', '京都郡苅田町', 'ミヤコグンカンダマチ', '尾倉', 'オグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県京都郡苅田町集', '40', '40621', '8000354', '福岡県', 'フクオカケン', '京都郡苅田町', 'ミヤコグンカンダマチ', '集', 'アツマリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県京都郡苅田町南原', '40', '40621', '8000355', '福岡県', 'フクオカケン', '京都郡苅田町', 'ミヤコグンカンダマチ', '南原', 'ミナミバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県京都郡苅田町近衛ケ丘', '40', '40621', '8000356', '福岡県', 'フクオカケン', '京都郡苅田町', 'ミヤコグンカンダマチ', '近衛ケ丘', 'コノエガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県京都郡苅田町桜ケ丘', '40', '40621', '8000357', '福岡県', 'フクオカケン', '京都郡苅田町', 'ミヤコグンカンダマチ', '桜ケ丘', 'サクラガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市西6条北', '01', '01207', '0800036', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '西6条北', 'ニシ06ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県京都郡苅田町神田町', '40', '40621', '8000361', '福岡県', 'フクオカケン', '京都郡苅田町', 'ミヤコグンカンダマチ', '神田町', 'ジンデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県京都郡苅田町馬場', '40', '40621', '8000362', '福岡県', 'フクオカケン', '京都郡苅田町', 'ミヤコグンカンダマチ', '馬場', 'ババ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県京都郡苅田町光国', '40', '40621', '8000363', '福岡県', 'フクオカケン', '京都郡苅田町', 'ミヤコグンカンダマチ', '光国', 'ミツクニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県京都郡苅田町提', '40', '40621', '8000364', '福岡県', 'フクオカケン', '京都郡苅田町', 'ミヤコグンカンダマチ', '提', 'ヒサゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県京都郡苅田町苅田', '40', '40621', '8000365', '福岡県', 'フクオカケン', '京都郡苅田町', 'ミヤコグンカンダマチ', '苅田', 'カンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県京都郡苅田町雨窪', '40', '40621', '8000366', '福岡県', 'フクオカケン', '京都郡苅田町', 'ミヤコグンカンダマチ', '雨窪', 'アマクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市西7条北', '01', '01207', '0800037', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '西7条北', 'ニシ07ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市西8条北', '01', '01207', '0800038', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '西8条北', 'ニシ08ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市西9条北', '01', '01207', '0800039', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '西9条北', 'ニシ09ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市西10条北', '01', '01207', '0800040', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '西10条北', 'ニシ10ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市西11条北', '01', '01207', '0800041', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '西11条北', 'ニシ11ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市西12条北', '01', '01207', '0800042', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '西12条北', 'ニシ12ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市西13条北', '01', '01207', '0800043', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '西13条北', 'ニシ13ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市西14条北', '01', '01207', '0800044', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '西14条北', 'ニシ14ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市西15条北', '01', '01207', '0800045', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '西15条北', 'ニシ15ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市西16条北', '01', '01207', '0800046', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '西16条北', 'ニシ16ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市西17条北', '01', '01207', '0800047', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '西17条北', 'ニシ17ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市西18条北', '01', '01207', '0800048', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '西18条北', 'ニシ18ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市白樺16条東', '01', '01207', '0800050', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '白樺16条東', 'シラカバ16ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市白樺16条西', '01', '01207', '0800051', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '白樺16条西', 'シラカバ16ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市新町東', '01', '01207', '0800052', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '新町東', 'シンマチヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市新町西', '01', '01207', '0800053', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '新町西', 'シンマチニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市柏林台北町', '01', '01207', '0800054', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '柏林台北町', 'ハクリンダイキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市柏林台東町', '01', '01207', '0800055', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '柏林台東町', 'ハクリンダイヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市柏林台南町', '01', '01207', '0800056', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '柏林台南町', 'ハクリンダイミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市柏林台中町', '01', '01207', '0800057', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '柏林台中町', 'ハクリンダイナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市柏林台西町', '01', '01207', '0800058', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '柏林台西町', 'ハクリンダイニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡音更町', '01', '01631', '0800100', '北海道', 'ホッカイドウ', '河東郡音更町', 'カトウグンオトフケチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('102802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡音更町大通', '01', '01631', '0800101', '北海道', 'ホッカイドウ', '河東郡音更町', 'カトウグンオトフケチョウ', '大通', 'オオドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡音更町大通北', '01', '01631', '0800102', '北海道', 'ホッカイドウ', '河東郡音更町', 'カトウグンオトフケチョウ', '大通北', 'オオドオリキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡音更町元町', '01', '01631', '0800103', '北海道', 'ホッカイドウ', '河東郡音更町', 'カトウグンオトフケチョウ', '元町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡音更町新通', '01', '01631', '0800104', '北海道', 'ホッカイドウ', '河東郡音更町', 'カトウグンオトフケチョウ', '新通', 'シンドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡音更町新通北', '01', '01631', '0800105', '北海道', 'ホッカイドウ', '河東郡音更町', 'カトウグンオトフケチョウ', '新通北', 'シンドオリキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡音更町東通', '01', '01631', '0800106', '北海道', 'ホッカイドウ', '河東郡音更町', 'カトウグンオトフケチョウ', '東通', 'ヒガシドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡音更町木野大通東', '01', '01631', '0800111', '北海道', 'ホッカイドウ', '河東郡音更町', 'カトウグンオトフケチョウ', '木野大通東', 'キノオオドオリヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡音更町木野東通', '01', '01631', '0800112', '北海道', 'ホッカイドウ', '河東郡音更町', 'カトウグンオトフケチョウ', '木野東通', 'キノヒガシドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡音更町柳町北区', '01', '01631', '0800121', '北海道', 'ホッカイドウ', '河東郡音更町', 'カトウグンオトフケチョウ', '柳町北区', 'ヤナギマチキタク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡音更町柳町仲区', '01', '01631', '0800122', '北海道', 'ホッカイドウ', '河東郡音更町', 'カトウグンオトフケチョウ', '柳町仲区', 'ヤナギマチナカク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡音更町柳町南区', '01', '01631', '0800123', '北海道', 'ホッカイドウ', '河東郡音更町', 'カトウグンオトフケチョウ', '柳町南区', 'ヤナギマチミナミク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡音更町宝来本通', '01', '01631', '0800131', '北海道', 'ホッカイドウ', '河東郡音更町', 'カトウグンオトフケチョウ', '宝来本通', 'ホウライホンドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡音更町宝来仲町北', '01', '01631', '0800132', '北海道', 'ホッカイドウ', '河東郡音更町', 'カトウグンオトフケチョウ', '宝来仲町北', 'ホウライナカマチキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡音更町宝来東町北', '01', '01631', '0800133', '北海道', 'ホッカイドウ', '河東郡音更町', 'カトウグンオトフケチョウ', '宝来東町北', 'ホウライヒガシマチキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡音更町宝来西町南', '01', '01631', '0800134', '北海道', 'ホッカイドウ', '河東郡音更町', 'カトウグンオトフケチョウ', '宝来西町南', 'ホウライニシマチミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡音更町宝来仲町南', '01', '01631', '0800135', '北海道', 'ホッカイドウ', '河東郡音更町', 'カトウグンオトフケチョウ', '宝来仲町南', 'ホウライナカマチミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡音更町宝来東町南', '01', '01631', '0800136', '北海道', 'ホッカイドウ', '河東郡音更町', 'カトウグンオトフケチョウ', '宝来東町南', 'ホウライヒガシマチミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡音更町宝来南1条', '01', '01631', '0800137', '北海道', 'ホッカイドウ', '河東郡音更町', 'カトウグンオトフケチョウ', '宝来南1条', 'ホウライミナミ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡音更町宝来南2条', '01', '01631', '0800138', '北海道', 'ホッカイドウ', '河東郡音更町', 'カトウグンオトフケチョウ', '宝来南2条', 'ホウライミナミ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡音更町宝来西町北', '01', '01631', '0800139', '北海道', 'ホッカイドウ', '河東郡音更町', 'カトウグンオトフケチョウ', '宝来西町北', 'ホウライニシマチキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡音更町宝来北1条', '01', '01631', '0800141', '北海道', 'ホッカイドウ', '河東郡音更町', 'カトウグンオトフケチョウ', '宝来北1条', 'ホウライキタ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡音更町宝来北2条', '01', '01631', '0800142', '北海道', 'ホッカイドウ', '河東郡音更町', 'カトウグンオトフケチョウ', '宝来北2条', 'ホウライキタ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡音更町宝来北3条', '01', '01631', '0800143', '北海道', 'ホッカイドウ', '河東郡音更町', 'カトウグンオトフケチョウ', '宝来北3条', 'ホウライキタ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡音更町宝来北4条', '01', '01631', '0800144', '北海道', 'ホッカイドウ', '河東郡音更町', 'カトウグンオトフケチョウ', '宝来北4条', 'ホウライキタ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡音更町宝来北5条', '01', '01631', '0800145', '北海道', 'ホッカイドウ', '河東郡音更町', 'カトウグンオトフケチョウ', '宝来北5条', 'ホウライキタ05ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡音更町宝来北6条', '01', '01631', '0800146', '北海道', 'ホッカイドウ', '河東郡音更町', 'カトウグンオトフケチョウ', '宝来北6条', 'ホウライキタ06ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡音更町東和', '01', '01631', '0800151', '北海道', 'ホッカイドウ', '河東郡音更町', 'カトウグンオトフケチョウ', '東和', 'トウワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡音更町ひびき野東町', '01', '01631', '0800161', '北海道', 'ホッカイドウ', '河東郡音更町', 'カトウグンオトフケチョウ', 'ひびき野東町', 'ヒビキノヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡音更町ひびき野仲町', '01', '01631', '0800162', '北海道', 'ホッカイドウ', '河東郡音更町', 'カトウグンオトフケチョウ', 'ひびき野仲町', 'ヒビキノナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡音更町ひびき野西町', '01', '01631', '0800163', '北海道', 'ホッカイドウ', '河東郡音更町', 'カトウグンオトフケチョウ', 'ひびき野西町', 'ヒビキノニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡音更町十勝川温泉', '01', '01631', '0800261', '北海道', 'ホッカイドウ', '河東郡音更町', 'カトウグンオトフケチョウ', '十勝川温泉', 'トカチガワオンセン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡音更町十勝川温泉北', '01', '01631', '0800262', '北海道', 'ホッカイドウ', '河東郡音更町', 'カトウグンオトフケチョウ', '十勝川温泉北', 'トカチガワオンセンキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡音更町十勝川温泉南', '01', '01631', '0800263', '北海道', 'ホッカイドウ', '河東郡音更町', 'カトウグンオトフケチョウ', '十勝川温泉南', 'トカチガワオンセンミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡音更町長流枝', '01', '01631', '0800271', '北海道', 'ホッカイドウ', '河東郡音更町', 'カトウグンオトフケチョウ', '長流枝', 'オサルシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡音更町長流枝幹線', '01', '01631', '0800271', '北海道', 'ホッカイドウ', '河東郡音更町', 'カトウグンオトフケチョウ', '長流枝幹線', 'オサルシカンセン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡音更町下士幌', '01', '01631', '0800272', '北海道', 'ホッカイドウ', '河東郡音更町', 'カトウグンオトフケチョウ', '下士幌', 'シモシホロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡音更町下士幌幹線', '01', '01631', '0800272', '北海道', 'ホッカイドウ', '河東郡音更町', 'カトウグンオトフケチョウ', '下士幌幹線', 'シモシホロカンセン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡音更町木野大通西', '01', '01631', '0800301', '北海道', 'ホッカイドウ', '河東郡音更町', 'カトウグンオトフケチョウ', '木野大通西', 'キノオオドオリニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡音更町木野西通', '01', '01631', '0800302', '北海道', 'ホッカイドウ', '河東郡音更町', 'カトウグンオトフケチョウ', '木野西通', 'キノニシドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡音更町木野公園下町', '01', '01631', '0800303', '北海道', 'ホッカイドウ', '河東郡音更町', 'カトウグンオトフケチョウ', '木野公園下町', 'キノコウエンシタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡音更町木野新町', '01', '01631', '0800304', '北海道', 'ホッカイドウ', '河東郡音更町', 'カトウグンオトフケチョウ', '木野新町', 'キノシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡音更町北鈴蘭北', '01', '01631', '0800305', '北海道', 'ホッカイドウ', '河東郡音更町', 'カトウグンオトフケチョウ', '北鈴蘭北', 'キタスズランキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡音更町北鈴蘭南', '01', '01631', '0800306', '北海道', 'ホッカイドウ', '河東郡音更町', 'カトウグンオトフケチョウ', '北鈴蘭南', 'キタスズランミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡音更町中鈴蘭北', '01', '01631', '0800307', '北海道', 'ホッカイドウ', '河東郡音更町', 'カトウグンオトフケチョウ', '中鈴蘭北', 'ナカスズランキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡音更町中鈴蘭南', '01', '01631', '0800308', '北海道', 'ホッカイドウ', '河東郡音更町', 'カトウグンオトフケチョウ', '中鈴蘭南', 'ナカスズランミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡音更町中鈴蘭元町', '01', '01631', '0800309', '北海道', 'ホッカイドウ', '河東郡音更町', 'カトウグンオトフケチョウ', '中鈴蘭元町', 'ナカスズランモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡音更町南鈴蘭北', '01', '01631', '0800311', '北海道', 'ホッカイドウ', '河東郡音更町', 'カトウグンオトフケチョウ', '南鈴蘭北', 'ミナミスズランキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡音更町南鈴蘭南', '01', '01631', '0800312', '北海道', 'ホッカイドウ', '河東郡音更町', 'カトウグンオトフケチョウ', '南鈴蘭南', 'ミナミスズランミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡音更町鈴蘭公園', '01', '01631', '0800313', '北海道', 'ホッカイドウ', '河東郡音更町', 'カトウグンオトフケチョウ', '鈴蘭公園', 'スズランコウエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡音更町共栄台西', '01', '01631', '0800314', '北海道', 'ホッカイドウ', '河東郡音更町', 'カトウグンオトフケチョウ', '共栄台西', 'キョウエイダイニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡音更町共栄台東', '01', '01631', '0800315', '北海道', 'ホッカイドウ', '河東郡音更町', 'カトウグンオトフケチョウ', '共栄台東', 'キョウエイダイヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡音更町緑陽台北区', '01', '01631', '0800316', '北海道', 'ホッカイドウ', '河東郡音更町', 'カトウグンオトフケチョウ', '緑陽台北区', 'リョクヨウダイキタク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡音更町緑陽台仲区', '01', '01631', '0800317', '北海道', 'ホッカイドウ', '河東郡音更町', 'カトウグンオトフケチョウ', '緑陽台仲区', 'リョクヨウダイナカク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡音更町緑陽台南区', '01', '01631', '0800318', '北海道', 'ホッカイドウ', '河東郡音更町', 'カトウグンオトフケチョウ', '緑陽台南区', 'リョクヨウダイミナミク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡音更町桜が丘', '01', '01631', '0800321', '北海道', 'ホッカイドウ', '河東郡音更町', 'カトウグンオトフケチョウ', '桜が丘', 'サクラガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡音更町桜が丘西', '01', '01631', '0800322', '北海道', 'ホッカイドウ', '河東郡音更町', 'カトウグンオトフケチョウ', '桜が丘西', 'サクラガオカニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡音更町住吉台', '01', '01631', '0800323', '北海道', 'ホッカイドウ', '河東郡音更町', 'カトウグンオトフケチョウ', '住吉台', 'スミヨシダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡音更町南住吉台', '01', '01631', '0800324', '北海道', 'ホッカイドウ', '河東郡音更町', 'カトウグンオトフケチョウ', '南住吉台', 'ミナミスミヨシダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡音更町柏寿台', '01', '01631', '0800325', '北海道', 'ホッカイドウ', '河東郡音更町', 'カトウグンオトフケチョウ', '柏寿台', 'ハクジュダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡音更町北明台', '01', '01631', '0800326', '北海道', 'ホッカイドウ', '河東郡音更町', 'カトウグンオトフケチョウ', '北明台', 'ホクメイダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡音更町北陽台', '01', '01631', '0800327', '北海道', 'ホッカイドウ', '河東郡音更町', 'カトウグンオトフケチョウ', '北陽台', 'ホクヨウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡音更町雄飛が丘', '01', '01631', '0800330', '北海道', 'ホッカイドウ', '河東郡音更町', 'カトウグンオトフケチョウ', '雄飛が丘', 'ユウヒガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡音更町雄飛が丘北区', '01', '01631', '0800331', '北海道', 'ホッカイドウ', '河東郡音更町', 'カトウグンオトフケチョウ', '雄飛が丘北区', 'ユウヒガオカキタク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡音更町雄飛が丘仲区', '01', '01631', '0800332', '北海道', 'ホッカイドウ', '河東郡音更町', 'カトウグンオトフケチョウ', '雄飛が丘仲区', 'ユウヒガオカナカク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡音更町雄飛が丘南区', '01', '01631', '0800333', '北海道', 'ホッカイドウ', '河東郡音更町', 'カトウグンオトフケチョウ', '雄飛が丘南区', 'ユウヒガオカミナミク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡音更町緑が丘', '01', '01631', '0800334', '北海道', 'ホッカイドウ', '河東郡音更町', 'カトウグンオトフケチョウ', '緑が丘', 'ミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡音更町希望が丘', '01', '01631', '0800335', '北海道', 'ホッカイドウ', '河東郡音更町', 'カトウグンオトフケチョウ', '希望が丘', 'キボウガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡音更町音更', '01', '01631', '0800341', '北海道', 'ホッカイドウ', '河東郡音更町', 'カトウグンオトフケチョウ', '音更', 'オトフケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡音更町下音更', '01', '01631', '0800342', '北海道', 'ホッカイドウ', '河東郡音更町', 'カトウグンオトフケチョウ', '下音更', 'シモオトフケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡音更町東士狩', '01', '01631', '0800343', '北海道', 'ホッカイドウ', '河東郡音更町', 'カトウグンオトフケチョウ', '東士狩', 'ヒガシシカリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡音更町万年', '01', '01631', '0800344', '北海道', 'ホッカイドウ', '河東郡音更町', 'カトウグンオトフケチョウ', '万年', 'マンネン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡音更町高倉', '01', '01631', '0800345', '北海道', 'ホッカイドウ', '河東郡音更町', 'カトウグンオトフケチョウ', '高倉', 'タカクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡音更町然別', '01', '01631', '0800351', '北海道', 'ホッカイドウ', '河東郡音更町', 'カトウグンオトフケチョウ', '然別', 'シカリベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡音更町すずらん台北町', '01', '01631', '0800361', '北海道', 'ホッカイドウ', '河東郡音更町', 'カトウグンオトフケチョウ', 'すずらん台北町', 'スズランダイキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡音更町すずらん台仲町', '01', '01631', '0800362', '北海道', 'ホッカイドウ', '河東郡音更町', 'カトウグンオトフケチョウ', 'すずらん台仲町', 'スズランダイナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡音更町すずらん台南町', '01', '01631', '0800363', '北海道', 'ホッカイドウ', '河東郡音更町', 'カトウグンオトフケチョウ', 'すずらん台南町', 'スズランダイミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡音更町豊田', '01', '01631', '0800561', '北海道', 'ホッカイドウ', '河東郡音更町', 'カトウグンオトフケチョウ', '豊田', 'トヨタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡音更町東音更', '01', '01631', '0800562', '北海道', 'ホッカイドウ', '河東郡音更町', 'カトウグンオトフケチョウ', '東音更', 'ヒガシオトフケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡音更町駒場平和台', '01', '01631', '0800563', '北海道', 'ホッカイドウ', '河東郡音更町', 'カトウグンオトフケチョウ', '駒場平和台', 'コマバヘイワダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡音更町駒場北1条通', '01', '01631', '0800564', '北海道', 'ホッカイドウ', '河東郡音更町', 'カトウグンオトフケチョウ', '駒場北1条通', 'コマバキタ01ジョウドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡音更町駒場北2条通', '01', '01631', '0800564', '北海道', 'ホッカイドウ', '河東郡音更町', 'カトウグンオトフケチョウ', '駒場北2条通', 'コマバキタ02ジョウドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡音更町駒場北町', '01', '01631', '0800564', '北海道', 'ホッカイドウ', '河東郡音更町', 'カトウグンオトフケチョウ', '駒場北町', 'コマバキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡音更町駒場本通', '01', '01631', '0800565', '北海道', 'ホッカイドウ', '河東郡音更町', 'カトウグンオトフケチョウ', '駒場本通', 'コマバホンドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡音更町駒場南1条通', '01', '01631', '0800566', '北海道', 'ホッカイドウ', '河東郡音更町', 'カトウグンオトフケチョウ', '駒場南1条通', 'コマバミナミ01ジョウドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡音更町駒場南2条通', '01', '01631', '0800566', '北海道', 'ホッカイドウ', '河東郡音更町', 'カトウグンオトフケチョウ', '駒場南2条通', 'コマバミナミ02ジョウドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡音更町駒場南3条通', '01', '01631', '0800567', '北海道', 'ホッカイドウ', '河東郡音更町', 'カトウグンオトフケチョウ', '駒場南3条通', 'コマバミナミ03ジョウドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡音更町駒場南4条通', '01', '01631', '0800567', '北海道', 'ホッカイドウ', '河東郡音更町', 'カトウグンオトフケチョウ', '駒場南4条通', 'コマバミナミ04ジョウドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡音更町駒場東', '01', '01631', '0800568', '北海道', 'ホッカイドウ', '河東郡音更町', 'カトウグンオトフケチョウ', '駒場東', 'コマバヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡音更町駒場', '01', '01631', '0800571', '北海道', 'ホッカイドウ', '河東郡音更町', 'カトウグンオトフケチョウ', '駒場', 'コマバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡音更町駒場並木', '01', '01631', '0800572', '北海道', 'ホッカイドウ', '河東郡音更町', 'カトウグンオトフケチョウ', '駒場並木', 'コマバナミキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡音更町駒場南', '01', '01631', '0800573', '北海道', 'ホッカイドウ', '河東郡音更町', 'カトウグンオトフケチョウ', '駒場南', 'コマバミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡音更町駒場西', '01', '01631', '0800574', '北海道', 'ホッカイドウ', '河東郡音更町', 'カトウグンオトフケチョウ', '駒場西', 'コマバニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡音更町上然別', '01', '01631', '0800575', '北海道', 'ホッカイドウ', '河東郡音更町', 'カトウグンオトフケチョウ', '上然別', 'カミシカリベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡音更町南中音更', '01', '01631', '0800576', '北海道', 'ホッカイドウ', '河東郡音更町', 'カトウグンオトフケチョウ', '南中音更', 'ミナミナカオトフケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡音更町西中音更', '01', '01631', '0800577', '北海道', 'ホッカイドウ', '河東郡音更町', 'カトウグンオトフケチョウ', '西中音更', 'ニシナカオトフケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡音更町中音更', '01', '01631', '0800578', '北海道', 'ホッカイドウ', '河東郡音更町', 'カトウグンオトフケチョウ', '中音更', 'ナカオトフケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市東1条南', '01', '01207', '0800801', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '東1条南', 'ヒガシ01ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市東2条南', '01', '01207', '0800802', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '東2条南', 'ヒガシ02ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市東3条南', '01', '01207', '0800803', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '東3条南', 'ヒガシ03ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市東4条南', '01', '01207', '0800804', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '東4条南', 'ヒガシ04ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市東5条南', '01', '01207', '0800805', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '東5条南', 'ヒガシ05ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市東6条南', '01', '01207', '0800806', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '東6条南', 'ヒガシ06ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市東7条南', '01', '01207', '0800807', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '東7条南', 'ヒガシ07ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市東8条南', '01', '01207', '0800808', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '東8条南', 'ヒガシ08ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市東9条南', '01', '01207', '0800809', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '東9条南', 'ヒガシ09ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市東10条南', '01', '01207', '0800810', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '東10条南', 'ヒガシ10ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市東11条南', '01', '01207', '0800811', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '東11条南', 'ヒガシ11ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市東12条南', '01', '01207', '0800812', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '東12条南', 'ヒガシ12ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市東13条南', '01', '01207', '0800813', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '東13条南', 'ヒガシ13ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市東14条南', '01', '01207', '0800814', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '東14条南', 'ヒガシ14ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市東15条南', '01', '01207', '0800815', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '東15条南', 'ヒガシ15ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市大川町', '01', '01207', '0800816', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '大川町', 'オオカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市依田町', '01', '01207', '0800817', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '依田町', 'ヨダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市東1条北', '01', '01207', '0800821', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '東1条北', 'ヒガシ01ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市東2条北', '01', '01207', '0800822', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '東2条北', 'ヒガシ02ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市東3条北', '01', '01207', '0800823', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '東3条北', 'ヒガシ03ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市東4条北', '01', '01207', '0800824', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '東4条北', 'ヒガシ04ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市稲田町南', '01', '01207', '0800831', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '稲田町南', 'イナダチョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市稲田町東', '01', '01207', '0800832', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '稲田町東', 'イナダチョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市稲田町基線', '01', '01207', '0800833', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '稲田町基線', 'イナダチョウキセン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市稲田町西', '01', '01207', '0800834', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '稲田町西', 'イナダチョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市稲田町', '01', '01207', '0800835', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '稲田町', 'イナダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市空港南町', '01', '01207', '0800836', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '空港南町', 'クウコウミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市空港南町南', '01', '01207', '0800837', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '空港南町南', 'クウコウミナミマチミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市大空町', '01', '01207', '0800838', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '大空町', 'オオゾラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市緑ケ丘1条通', '01', '01207', '0800841', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '緑ケ丘1条通', 'ミドリガオカ01ジョウドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市緑ケ丘2条通', '01', '01207', '0800842', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '緑ケ丘2条通', 'ミドリガオカ02ジョウドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市緑ケ丘3条通', '01', '01207', '0800843', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '緑ケ丘3条通', 'ミドリガオカ03ジョウドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市緑ケ丘東通東', '01', '01207', '0800844', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '緑ケ丘東通東', 'ミドリガオカヒガシドオリヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市緑ケ丘東通西', '01', '01207', '0800845', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '緑ケ丘東通西', 'ミドリガオカヒガシドオリニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市緑ケ丘', '01', '01207', '0800846', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '緑ケ丘', 'ミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市公園東町', '01', '01207', '0800847', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '公園東町', 'コウエンヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市自由が丘1丁目', '01', '01207', '0800848', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '自由が丘', 'ジユウガオカ', null, null, '1丁目', '01チョウメ');
INSERT INTO `ms_addresses` VALUES ('102938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市自由が丘2丁目', '01', '01207', '0800848', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '自由が丘', 'ジユウガオカ', null, null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('102939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市南町東1条', '01', '01207', '0800851', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '南町東1条', 'ミナミマチヒガシ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市南町東2条', '01', '01207', '0800852', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '南町東2条', 'ミナミマチヒガシ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市南町東3条', '01', '01207', '0800853', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '南町東3条', 'ミナミマチヒガシ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市南町東4条', '01', '01207', '0800854', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '南町東4条', 'ミナミマチヒガシ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市南町東5条', '01', '01207', '0800855', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '南町東5条', 'ミナミマチヒガシ05ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市南町南', '01', '01207', '0800856', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '南町南', 'ミナミマチミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市南町', '01', '01207', '0800857', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '南町', 'ミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市南の森東', '01', '01207', '0800861', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '南の森東', 'ミナミノモリヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市南の森西', '01', '01207', '0800862', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '南の森西', 'ミナミノモリニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区風師1丁目', '40', '40101', '8010801', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '風師', 'カザシ', null, null, '1丁目', '01チョウメ');
INSERT INTO `ms_addresses` VALUES ('102957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区風師2丁目', '40', '40101', '8010801', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '風師', 'カザシ', null, null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('102958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区風師3丁目', '40', '40101', '8010801', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '風師', 'カザシ', null, null, '3丁目', '03チョウメ');
INSERT INTO `ms_addresses` VALUES ('102959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区白野江', '40', '40101', '8010802', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '白野江', 'シラノエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区田野浦', '40', '40101', '8010803', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '田野浦', 'タノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区田野浦海岸', '40', '40101', '8010804', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '田野浦海岸', 'タノウラカイガン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区太刀浦海岸', '40', '40101', '8010805', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '太刀浦海岸', 'タチノウラカイガン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区葛葉1丁目', '40', '40101', '8010808', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '葛葉', 'クズハ', null, null, '1丁目', '01チョウメ');
INSERT INTO `ms_addresses` VALUES ('102964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区大積', '40', '40101', '8010811', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '大積', 'オオツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区喜多久', '40', '40101', '8010812', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '喜多久', 'キタク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区柄杓田', '40', '40101', '8010813', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '柄杓田', 'ヒシャクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区柄杓田町', '40', '40101', '8010814', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '柄杓田町', 'ヒシャクダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区黒川', '40', '40101', '8010821', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '黒川', 'クロガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区高砂町', '40', '40101', '8010822', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '高砂町', 'タカサゴマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区春日町', '40', '40101', '8010823', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '春日町', 'カスガマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区丸山吉野町', '40', '40101', '8010824', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '丸山吉野町', 'マルヤマヨシノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区黒川西', '40', '40101', '8010825', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '黒川西', 'クロガワニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区黒川東', '40', '40101', '8010826', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '黒川東', 'クロガワヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区丸山', '40', '40101', '8010831', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '丸山', 'マルヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区元清滝', '40', '40101', '8010832', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '元清滝', 'モトキヨタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区清滝', '40', '40101', '8010833', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '清滝', 'キヨタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区本町', '40', '40101', '8010834', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区西海岸', '40', '40101', '8010841', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '西海岸', 'ニシカイガン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区広石', '40', '40101', '8010842', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '広石', 'ヒロイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区東本町', '40', '40101', '8010851', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '東本町', 'ヒガシホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区港町', '40', '40101', '8010852', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '港町', 'ミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区東港町', '40', '40101', '8010853', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '東港町', 'ヒガシミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区旧門司', '40', '40101', '8010854', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '旧門司', 'キュウモジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区門司', '40', '40101', '8010855', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '門司', 'モジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区浜町', '40', '40101', '8010856', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '浜町', 'ハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区長谷', '40', '40101', '8010861', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '長谷', 'ナガタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区錦町', '40', '40101', '8010862', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '錦町', 'ニシキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区栄町', '40', '40101', '8010863', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区老松町', '40', '40101', '8010864', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '老松町', 'オイマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区庄司町', '40', '40101', '8010865', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '庄司町', 'ショウジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区上本町', '40', '40101', '8010871', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '上本町', 'カミホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区谷町', '40', '40101', '8010872', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '谷町', 'タニマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区東門司', '40', '40101', '8010873', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '東門司', 'ヒガシモジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区畑田町', '40', '40101', '8010874', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '畑田町', 'ハタケダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区法師庵', '40', '40101', '8010875', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '法師庵', 'ホウシアン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区花月園', '40', '40101', '8010876', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '花月園', 'カゲツエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区鳴竹', '40', '40101', '8010881', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '鳴竹', 'ナルタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区清見', '40', '40101', '8010882', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '清見', 'キヨミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('102999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区大久保', '40', '40101', '8010883', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '大久保', 'オオクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区瀬戸町', '40', '40101', '8010884', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '瀬戸町', 'セトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区新開', '40', '40101', '8010885', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '新開', 'シンカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市門司区清見佐夜町', '40', '40101', '8010886', '福岡県', 'フクオカケン', '北九州市門司区', 'キタキュウシュウシモジク', '清見佐夜町', 'キヨミサヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡士幌町共豊', '01', '01632', '0801189', '北海道', 'ホッカイドウ', '河東郡士幌町', 'カトウグンシホロチョウ', '共豊', 'キョウホウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡士幌町士幌南一区', '01', '01632', '0801189', '北海道', 'ホッカイドウ', '河東郡士幌町', 'カトウグンシホロチョウ', '士幌', 'シホロ', null, null, '南一区', 'ミナミイック');
INSERT INTO `ms_addresses` VALUES ('103005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡士幌町東台', '01', '01632', '0801189', '北海道', 'ホッカイドウ', '河東郡士幌町', 'カトウグンシホロチョウ', '東台', 'トウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡士幌町富秋', '01', '01632', '0801189', '北海道', 'ホッカイドウ', '河東郡士幌町', 'カトウグンシホロチョウ', '富秋', 'トミアキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡士幌町中士幌', '01', '01632', '0801189', '北海道', 'ホッカイドウ', '河東郡士幌町', 'カトウグンシホロチョウ', '中士幌', 'ナカシホロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡士幌町中士幌勝和', '01', '01632', '0801189', '北海道', 'ホッカイドウ', '河東郡士幌町', 'カトウグンシホロチョウ', '中士幌勝和', 'ナカシホロカツワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡士幌町中士幌北', '01', '01632', '0801189', '北海道', 'ホッカイドウ', '河東郡士幌町', 'カトウグンシホロチョウ', '中士幌北', 'ナカシホロキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡士幌町中士幌北団地', '01', '01632', '0801189', '北海道', 'ホッカイドウ', '河東郡士幌町', 'カトウグンシホロチョウ', '中士幌北団地', 'ナカシホロキタダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡士幌町中士幌共進', '01', '01632', '0801189', '北海道', 'ホッカイドウ', '河東郡士幌町', 'カトウグンシホロチョウ', '中士幌共進', 'ナカシホロキョウシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡士幌町中士幌新東団地', '01', '01632', '0801189', '北海道', 'ホッカイドウ', '河東郡士幌町', 'カトウグンシホロチョウ', '中士幌新東団地', 'ナカシホロシンヒガシダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡士幌町中士幌新南', '01', '01632', '0801189', '北海道', 'ホッカイドウ', '河東郡士幌町', 'カトウグンシホロチョウ', '中士幌新南', 'ナカシホロシンミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡士幌町中士幌西', '01', '01632', '0801189', '北海道', 'ホッカイドウ', '河東郡士幌町', 'カトウグンシホロチョウ', '中士幌西', 'ナカシホロニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡士幌町中士幌東団地', '01', '01632', '0801189', '北海道', 'ホッカイドウ', '河東郡士幌町', 'カトウグンシホロチョウ', '中士幌東団地', 'ナカシホロヒガシダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡士幌町中士幌文化', '01', '01632', '0801189', '北海道', 'ホッカイドウ', '河東郡士幌町', 'カトウグンシホロチョウ', '中士幌文化', 'ナカシホロブンカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡士幌町中士幌豊進', '01', '01632', '0801189', '北海道', 'ホッカイドウ', '河東郡士幌町', 'カトウグンシホロチョウ', '中士幌豊進', 'ナカシホロホウシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡士幌町中士幌南', '01', '01632', '0801189', '北海道', 'ホッカイドウ', '河東郡士幌町', 'カトウグンシホロチョウ', '中士幌南', 'ナカシホロミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡士幌町中士幌明生', '01', '01632', '0801189', '北海道', 'ホッカイドウ', '河東郡士幌町', 'カトウグンシホロチョウ', '中士幌明生', 'ナカシホロメイセイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡士幌町', '01', '01632', '0801200', '北海道', 'ホッカイドウ', '河東郡士幌町', 'カトウグンシホロチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('103021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡士幌町平原第一', '01', '01632', '0801201', '北海道', 'ホッカイドウ', '河東郡士幌町', 'カトウグンシホロチョウ', '平原第一', 'ヘイゲンダイイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡士幌町平原', '01', '01632', '0801202', '北海道', 'ホッカイドウ', '河東郡士幌町', 'カトウグンシホロチョウ', '平原', 'ヘイゲン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡士幌町いこい', '01', '01632', '0801203', '北海道', 'ホッカイドウ', '河東郡士幌町', 'カトウグンシホロチョウ', 'いこい', 'イコイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡士幌町松並', '01', '01632', '0801204', '北海道', 'ホッカイドウ', '河東郡士幌町', 'カトウグンシホロチョウ', '松並', 'マツナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡士幌町若葉第一', '01', '01632', '0801211', '北海道', 'ホッカイドウ', '河東郡士幌町', 'カトウグンシホロチョウ', '若葉第一', 'ワカバダイイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡士幌町若葉東', '01', '01632', '0801212', '北海道', 'ホッカイドウ', '河東郡士幌町', 'カトウグンシホロチョウ', '若葉東', 'ワカバヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡士幌町新生', '01', '01632', '0801213', '北海道', 'ホッカイドウ', '河東郡士幌町', 'カトウグンシホロチョウ', '新生', 'シンセイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡士幌町本通', '01', '01632', '0801214', '北海道', 'ホッカイドウ', '河東郡士幌町', 'カトウグンシホロチョウ', '本通', 'ホンドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡士幌町仲通', '01', '01632', '0801215', '北海道', 'ホッカイドウ', '河東郡士幌町', 'カトウグンシホロチョウ', '仲通', 'ナカドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡士幌町高徳', '01', '01632', '0801216', '北海道', 'ホッカイドウ', '河東郡士幌町', 'カトウグンシホロチョウ', '高徳', 'コウトク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡士幌町若葉', '01', '01632', '0801217', '北海道', 'ホッカイドウ', '河東郡士幌町', 'カトウグンシホロチョウ', '若葉', 'ワカバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡士幌町互譲', '01', '01632', '0801221', '北海道', 'ホッカイドウ', '河東郡士幌町', 'カトウグンシホロチョウ', '互譲', 'ゴジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡士幌町神苑', '01', '01632', '0801222', '北海道', 'ホッカイドウ', '河東郡士幌町', 'カトウグンシホロチョウ', '神苑', 'シンエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡士幌町大通', '01', '01632', '0801223', '北海道', 'ホッカイドウ', '河東郡士幌町', 'カトウグンシホロチョウ', '大通', 'オオドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡士幌町柏葉', '01', '01632', '0801224', '北海道', 'ホッカイドウ', '河東郡士幌町', 'カトウグンシホロチョウ', '柏葉', 'ハクヨウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡士幌町みどり', '01', '01632', '0801225', '北海道', 'ホッカイドウ', '河東郡士幌町', 'カトウグンシホロチョウ', 'みどり', 'ミドリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡士幌町大通西', '01', '01632', '0801226', '北海道', 'ホッカイドウ', '河東郡士幌町', 'カトウグンシホロチョウ', '大通西', 'オオドオリニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡士幌町中央', '01', '01632', '0801227', '北海道', 'ホッカイドウ', '河東郡士幌町', 'カトウグンシホロチョウ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡士幌町睦', '01', '01632', '0801231', '北海道', 'ホッカイドウ', '河東郡士幌町', 'カトウグンシホロチョウ', '睦', 'ムツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡士幌町睦西', '01', '01632', '0801232', '北海道', 'ホッカイドウ', '河東郡士幌町', 'カトウグンシホロチョウ', '睦西', 'ムツミニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡士幌町睦南', '01', '01632', '0801233', '北海道', 'ホッカイドウ', '河東郡士幌町', 'カトウグンシホロチョウ', '睦南', 'ムツミミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡士幌町南団地', '01', '01632', '0801234', '北海道', 'ホッカイドウ', '河東郡士幌町', 'カトウグンシホロチョウ', '南団地', 'ミナミダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡士幌町緑光', '01', '01632', '0801235', '北海道', 'ホッカイドウ', '河東郡士幌町', 'カトウグンシホロチョウ', '緑光', 'リョクコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡士幌町美園', '01', '01632', '0801236', '北海道', 'ホッカイドウ', '河東郡士幌町', 'カトウグンシホロチョウ', '美園', 'ミソノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡士幌町西居辺北', '01', '01632', '0801241', '北海道', 'ホッカイドウ', '河東郡士幌町', 'カトウグンシホロチョウ', '西居辺北', 'ニシオリベキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡士幌町松室', '01', '01632', '0801242', '北海道', 'ホッカイドウ', '河東郡士幌町', 'カトウグンシホロチョウ', '松室', 'マツムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡士幌町西居辺', '01', '01632', '0801243', '北海道', 'ホッカイドウ', '河東郡士幌町', 'カトウグンシホロチョウ', '西居辺', 'ニシオリベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡士幌町柏', '01', '01632', '0801244', '北海道', 'ホッカイドウ', '河東郡士幌町', 'カトウグンシホロチョウ', '柏', 'カシワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡士幌町共成', '01', '01632', '0801245', '北海道', 'ホッカイドウ', '河東郡士幌町', 'カトウグンシホロチョウ', '共成', 'キョウセイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡士幌町士幌北一区', '01', '01632', '0801246', '北海道', 'ホッカイドウ', '河東郡士幌町', 'カトウグンシホロチョウ', '士幌', 'シホロ', null, null, '北一区', 'キタ01ク');
INSERT INTO `ms_addresses` VALUES ('103051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡士幌町平和', '01', '01632', '0801247', '北海道', 'ホッカイドウ', '河東郡士幌町', 'カトウグンシホロチョウ', '平和', 'ヘイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡士幌町柏野', '01', '01632', '0801248', '北海道', 'ホッカイドウ', '河東郡士幌町', 'カトウグンシホロチョウ', '柏野', 'カシワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡士幌町新盛', '01', '01632', '0801251', '北海道', 'ホッカイドウ', '河東郡士幌町', 'カトウグンシホロチョウ', '新盛', 'シンセイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡士幌町豊年', '01', '01632', '0801252', '北海道', 'ホッカイドウ', '河東郡士幌町', 'カトウグンシホロチョウ', '豊年', 'ホウネン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡士幌町士幌南一区', '01', '01632', '0801253', '北海道', 'ホッカイドウ', '河東郡士幌町', 'カトウグンシホロチョウ', '士幌', 'シホロ', null, null, '南一区', 'ミナミイック');
INSERT INTO `ms_addresses` VALUES ('103056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡士幌町士幌南旭区', '01', '01632', '0801254', '北海道', 'ホッカイドウ', '河東郡士幌町', 'カトウグンシホロチョウ', '士幌', 'シホロ', null, null, '南旭区', 'ミナミアサヒク');
INSERT INTO `ms_addresses` VALUES ('103057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡士幌町新光', '01', '01632', '0801255', '北海道', 'ホッカイドウ', '河東郡士幌町', 'カトウグンシホロチョウ', '新光', 'シンコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡士幌町佐倉', '01', '01632', '0801256', '北海道', 'ホッカイドウ', '河東郡士幌町', 'カトウグンシホロチョウ', '佐倉', 'サクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡士幌町双葉', '01', '01632', '0801257', '北海道', 'ホッカイドウ', '河東郡士幌町', 'カトウグンシホロチョウ', '双葉', 'フタバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡士幌町西士幌', '01', '01632', '0801261', '北海道', 'ホッカイドウ', '河東郡士幌町', 'カトウグンシホロチョウ', '西士幌', 'ニシシホロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡士幌町常盤', '01', '01632', '0801262', '北海道', 'ホッカイドウ', '河東郡士幌町', 'カトウグンシホロチョウ', '常盤', 'トキワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡士幌町吉野', '01', '01632', '0801263', '北海道', 'ホッカイドウ', '河東郡士幌町', 'カトウグンシホロチョウ', '吉野', 'ヨシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡士幌町西吉野', '01', '01632', '0801264', '北海道', 'ホッカイドウ', '河東郡士幌町', 'カトウグンシホロチョウ', '西吉野', 'ニシヨシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡士幌町新栄', '01', '01632', '0801265', '北海道', 'ホッカイドウ', '河東郡士幌町', 'カトウグンシホロチョウ', '新栄', 'シンエイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡士幌町新田', '01', '01632', '0801266', '北海道', 'ホッカイドウ', '河東郡士幌町', 'カトウグンシホロチョウ', '新田', 'ニツタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡士幌町共立', '01', '01632', '0801267', '北海道', 'ホッカイドウ', '河東郡士幌町', 'カトウグンシホロチョウ', '共立', 'キョウリツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡士幌町西上', '01', '01632', '0801271', '北海道', 'ホッカイドウ', '河東郡士幌町', 'カトウグンシホロチョウ', '西上', 'ニシカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡士幌町百戸', '01', '01632', '0801272', '北海道', 'ホッカイドウ', '河東郡士幌町', 'カトウグンシホロチョウ', '百戸', 'ヒャッコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡士幌町中音更', '01', '01632', '0801273', '北海道', 'ホッカイドウ', '河東郡士幌町', 'カトウグンシホロチョウ', '中音更', 'ナカオトフケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡士幌町共益', '01', '01632', '0801274', '北海道', 'ホッカイドウ', '河東郡士幌町', 'カトウグンシホロチョウ', '共益', 'キョウエキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡士幌町コマクサ', '01', '01632', '0801275', '北海道', 'ホッカイドウ', '河東郡士幌町', 'カトウグンシホロチョウ', 'コマクサ', 'コマクサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡士幌町新田第一', '01', '01632', '0801276', '北海道', 'ホッカイドウ', '河東郡士幌町', 'カトウグンシホロチョウ', '新田第一', 'ニッタダイイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡士幌町新田第二', '01', '01632', '0801277', '北海道', 'ホッカイドウ', '河東郡士幌町', 'カトウグンシホロチョウ', '新田第二', 'ニッタダイニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡士幌町栄進', '01', '01632', '0801278', '北海道', 'ホッカイドウ', '河東郡士幌町', 'カトウグンシホロチョウ', '栄進', 'エイシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡士幌町朝陽', '01', '01632', '0801281', '北海道', 'ホッカイドウ', '河東郡士幌町', 'カトウグンシホロチョウ', '朝陽', 'チョウヨウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡士幌町友愛', '01', '01632', '0801282', '北海道', 'ホッカイドウ', '河東郡士幌町', 'カトウグンシホロチョウ', '友愛', 'ユウアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡士幌町高砂', '01', '01632', '0801283', '北海道', 'ホッカイドウ', '河東郡士幌町', 'カトウグンシホロチョウ', '高砂', 'タカサゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡士幌町清澄', '01', '01632', '0801284', '北海道', 'ホッカイドウ', '河東郡士幌町', 'カトウグンシホロチョウ', '清澄', 'キヨズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡士幌町下居辺', '01', '01632', '0801285', '北海道', 'ホッカイドウ', '河東郡士幌町', 'カトウグンシホロチョウ', '下居辺', 'シモオリベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡士幌町開運', '01', '01632', '0801286', '北海道', 'ホッカイドウ', '河東郡士幌町', 'カトウグンシホロチョウ', '開運', 'カイウン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡士幌町北開', '01', '01632', '0801287', '北海道', 'ホッカイドウ', '河東郡士幌町', 'カトウグンシホロチョウ', '北開', 'ホッカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡士幌町北上居辺', '01', '01632', '0801288', '北海道', 'ホッカイドウ', '河東郡士幌町', 'カトウグンシホロチョウ', '北上居辺', 'キタカミオリベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡上士幌町', '01', '01633', '0801400', '北海道', 'ホッカイドウ', '河東郡上士幌町', 'カトウグンカミシホロチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('103084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡上士幌町三股', '01', '01633', '0801401', '北海道', 'ホッカイドウ', '河東郡上士幌町', 'カトウグンカミシホロチョウ', '三股', 'ミツマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡上士幌町幌加', '01', '01633', '0801402', '北海道', 'ホッカイドウ', '河東郡上士幌町', 'カトウグンカミシホロチョウ', '幌加', 'ホロカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡上士幌町糠平', '01', '01633', '0801403', '北海道', 'ホッカイドウ', '河東郡上士幌町', 'カトウグンカミシホロチョウ', '糠平', 'ヌカビラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡上士幌町黒石平', '01', '01633', '0801404', '北海道', 'ホッカイドウ', '河東郡上士幌町', 'カトウグンカミシホロチョウ', '黒石平', 'クロイシダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡上士幌町清水谷', '01', '01633', '0801405', '北海道', 'ホッカイドウ', '河東郡上士幌町', 'カトウグンカミシホロチョウ', '清水谷', 'シミズダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡上士幌町居辺', '01', '01633', '0801406', '北海道', 'ホッカイドウ', '河東郡上士幌町', 'カトウグンカミシホロチョウ', '居辺', 'オリベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡上士幌町上音更', '01', '01633', '0801407', '北海道', 'ホッカイドウ', '河東郡上士幌町', 'カトウグンカミシホロチョウ', '上音更', 'カミオトフケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡上士幌町上士幌', '01', '01633', '0801408', '北海道', 'ホッカイドウ', '河東郡上士幌町', 'カトウグンカミシホロチョウ', '上士幌', 'カミシホロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区', '40', '40106', '8020000', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('103104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区', '40', '40107', '8020000', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('103105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区浅野', '40', '40106', '8020001', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '浅野', 'アサノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区京町', '40', '40106', '8020002', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '京町', 'キョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区米町', '40', '40106', '8020003', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '米町', 'コメマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区鍛冶町', '40', '40106', '8020004', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '鍛冶町', 'カジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区堺町', '40', '40106', '8020005', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '堺町', 'サカイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区魚町', '40', '40106', '8020006', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '魚町', 'ウオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区船場町', '40', '40106', '8020007', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '船場町', 'センバマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区船頭町', '40', '40106', '8020008', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '船頭町', 'センドウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区重住', '40', '40106', '8020011', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '重住', 'シゲズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区末広', '40', '40106', '8020012', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '末広', 'スエヒロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区長浜町', '40', '40106', '8020013', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '長浜町', 'ナガハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区砂津', '40', '40106', '8020014', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '砂津', 'スナツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区大田町', '40', '40106', '8020015', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '大田町', 'オオタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区宇佐町', '40', '40106', '8020016', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '宇佐町', 'ウサマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区明和町', '40', '40106', '8020017', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '明和町', 'メイワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区中津口', '40', '40106', '8020018', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '中津口', 'ナカツグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区高浜', '40', '40106', '8020021', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '高浜', 'タカハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区上富野', '40', '40106', '8020022', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '上富野', 'カミトミノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区下富野', '40', '40106', '8020023', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '下富野', 'シモトミノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区山門町', '40', '40106', '8020024', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '山門町', 'サンモンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区寿山町', '40', '40106', '8020025', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '寿山町', 'ジュザンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区大畠', '40', '40106', '8020026', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '大畠', 'オオバタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区赤坂海岸', '40', '40106', '8020031', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '赤坂海岸', 'アカサカカイガン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区赤坂', '40', '40106', '8020032', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '赤坂', 'アカサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区富野台', '40', '40106', '8020033', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '富野台', 'トミノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区須賀町', '40', '40106', '8020034', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '須賀町', 'スガマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区常盤町', '40', '40106', '8020035', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '常盤町', 'トキワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区富野', '40', '40106', '8020036', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '富野', 'トミノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区小文字', '40', '40106', '8020037', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '小文字', 'コモンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区神幸町', '40', '40106', '8020038', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '神幸町', 'シンコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区妙見町', '40', '40106', '8020041', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '妙見町', 'ミョウケンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区足立', '40', '40106', '8020042', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '足立', 'アダチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区足原', '40', '40106', '8020043', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '足原', 'アシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区熊本', '40', '40106', '8020044', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '熊本', 'クマモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区神岳', '40', '40106', '8020045', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '神岳', 'カンタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区黒原', '40', '40106', '8020051', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '黒原', 'クロバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区霧ケ丘', '40', '40106', '8020052', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '霧ケ丘', 'キリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区高坊', '40', '40106', '8020053', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '高坊', 'タカボウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区東城野町', '40', '40106', '8020054', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '東城野町', 'ヒガシジョウノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区城野団地', '40', '40106', '8020055', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '城野団地', 'ジョウノダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区黒住町', '40', '40106', '8020056', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '黒住町', 'クロズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区三郎丸', '40', '40106', '8020061', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '三郎丸', 'サブロウマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区片野新町', '40', '40106', '8020062', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '片野新町', 'カタノシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区若富士町', '40', '40106', '8020063', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '若富士町', 'ワカフジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区片野', '40', '40106', '8020064', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '片野', 'カタノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区三萩野', '40', '40106', '8020065', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '三萩野', 'ミハギノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区萩崎町', '40', '40106', '8020066', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '萩崎町', 'ハギザキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区黄金', '40', '40106', '8020071', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '黄金', 'コガネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区東篠崎', '40', '40106', '8020072', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '東篠崎', 'ヒガシシノザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区貴船町', '40', '40106', '8020073', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '貴船町', 'キフネマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区白銀', '40', '40106', '8020074', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '白銀', 'シラガネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区昭和町', '40', '40106', '8020075', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '昭和町', 'ショウワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区中島', '40', '40106', '8020076', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '中島', 'ナカシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区馬借', '40', '40106', '8020077', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '馬借', 'バシャク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区紺屋町', '40', '40106', '8020081', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '紺屋町', 'コンヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区古船場町', '40', '40106', '8020082', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '古船場町', 'フルセンバマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区江南町', '40', '40106', '8020083', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '江南町', 'エナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区香春口', '40', '40106', '8020084', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '香春口', 'カワラグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区吉野町', '40', '40106', '8020085', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '吉野町', 'ヨシノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区藍島', '40', '40106', '8020091', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '藍島', 'アイノシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区馬島', '40', '40106', '8020092', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '馬島', 'ウマシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区富士見', '40', '40107', '8020801', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '富士見', 'フジミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区城野', '40', '40107', '8020802', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '城野', 'ジョウノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区春ケ丘', '40', '40107', '8020803', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '春ケ丘', 'ハルガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区下城野', '40', '40107', '8020804', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '下城野', 'シモジョウノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区八幡町', '40', '40107', '8020805', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '八幡町', 'ハチマンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区重住', '40', '40107', '8020811', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '重住', 'シゲズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区西水町', '40', '40107', '8020812', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '西水町', 'ニシミズマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区東水町', '40', '40107', '8020813', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '東水町', 'ヒガシミズマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区蜷田若園', '40', '40107', '8020814', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '蜷田若園', 'ニナタワカゾノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区南若園町', '40', '40107', '8020815', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '南若園町', 'ミナミワカゾノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区若園', '40', '40107', '8020816', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '若園', 'ワカゾノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区横代北町', '40', '40107', '8020821', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '横代北町', 'ヨコシロキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区横代東町', '40', '40107', '8020822', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '横代東町', 'ヨコシロヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区舞ケ丘', '40', '40107', '8020823', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '舞ケ丘', 'マイガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区横代', '40', '40107', '8020824', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '横代', 'ヨコシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区横代葉山', '40', '40107', '8020825', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '横代葉山', 'ヨコシロハヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区横代南町', '40', '40107', '8020826', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '横代南町', 'ヨコシロミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区八重洲町', '40', '40107', '8020831', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '八重洲町', 'ヤエスマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区下石田', '40', '40107', '8020832', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '下石田', 'シモイシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区上石田', '40', '40107', '8020833', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '上石田', 'カミイシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区隠蓑', '40', '40107', '8020834', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '隠蓑', 'カクレミノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区堀越', '40', '40107', '8020835', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '堀越', 'ホリコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区石田南', '40', '40107', '8020836', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '石田南', 'イシダミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区葉山町', '40', '40107', '8020837', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '葉山町', 'ハヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区石田町', '40', '40107', '8020838', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '石田町', 'イシダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区北方', '40', '40107', '8020841', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '北方', 'キタガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区日の出町', '40', '40107', '8020842', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '日の出町', 'ヒノデマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区守恒本町', '40', '40107', '8020971', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '守恒本町', 'モリツネホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区守恒', '40', '40107', '8020972', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '守恒', 'モリツネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区星和台', '40', '40107', '8020973', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '星和台', 'セイワダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区徳力', '40', '40107', '8020974', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '徳力', 'トクリキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区徳力団地', '40', '40107', '8020975', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '徳力団地', 'トクリキダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区南方', '40', '40107', '8020976', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '南方', 'ミナミガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区下南方', '40', '40107', '8020977', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '下南方', 'シモミナミガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区蒲生', '40', '40107', '8020978', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '蒲生', 'ガモウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区徳力新町', '40', '40107', '8020979', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '徳力新町', 'トクリキシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区企救丘', '40', '40107', '8020981', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '企救丘', 'キクガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区山手', '40', '40107', '8020982', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '山手', 'ヤマテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区志徳', '40', '40107', '8020983', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '志徳', 'シトク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区志井公園', '40', '40107', '8020984', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '志井公園', 'シイコウエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区志井', '40', '40107', '8020985', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '志井', 'シイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区志井鷹羽台', '40', '40107', '8020986', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '志井鷹羽台', 'シイタカハダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市清川町', '01', '01207', '0802101', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '清川町', 'キヨカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市清川町基線', '01', '01207', '0802102', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '清川町基線', 'キヨカワチョウキセン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市清川町西', '01', '01207', '0802103', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '清川町西', 'キヨカワチョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市清川町東', '01', '01207', '0802104', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '清川町東', 'キヨカワチョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市太平町', '01', '01207', '0802105', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '太平町', 'タイヘイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市美栄町', '01', '01207', '0802106', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '美栄町', 'ビエイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市上清川町', '01', '01207', '0802111', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '上清川町', 'カミキヨカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市上清川町基線', '01', '01207', '0802112', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '上清川町基線', 'カミキヨカワチョウキセン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市上清川町西', '01', '01207', '0802113', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '上清川町西', 'カミキヨカワチョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市上清川町東', '01', '01207', '0802114', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '上清川町東', 'カミキヨカワチョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市清川町仲通', '01', '01207', '0802115', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '清川町仲通', 'キヨカワチョウナカドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市清川町本通', '01', '01207', '0802116', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '清川町本通', 'キヨカワチョウホンドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市太平町西', '01', '01207', '0802117', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '太平町西', 'タイヘイチョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市岩内町', '01', '01207', '0802121', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '岩内町', 'イワナイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市岩内町第1基線', '01', '01207', '0802122', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '岩内町第1基線', 'イワナイチョウダイ01キセン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市岩内町西', '01', '01207', '0802123', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '岩内町西', 'イワナイチョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市岩内町東', '01', '01207', '0802124', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '岩内町東', 'イワナイチョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市基松町', '01', '01207', '0802331', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '基松町', 'モトイマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市富士町', '01', '01207', '0802332', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '富士町', 'フジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市美栄町', '01', '01207', '0802333', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '美栄町', 'ビエイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市上帯広町', '01', '01207', '0802334', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '上帯広町', 'カミオビヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市広野町', '01', '01207', '0802335', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '広野町', 'ヒロノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市八千代町', '01', '01207', '0802336', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '八千代町', 'ヤチヨチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市拓成町', '01', '01207', '0802337', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '拓成町', 'タクセイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市西19条北', '01', '01207', '0802459', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '西19条北', 'ニシ19ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市西20条北', '01', '01207', '0802460', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '西20条北', 'ニシ20ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市西21条北', '01', '01207', '0802461', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '西21条北', 'ニシ21ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市西22条北', '01', '01207', '0802462', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '西22条北', 'ニシ22ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市西23条北', '01', '01207', '0802463', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '西23条北', 'ニシ23ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市西24条北', '01', '01207', '0802464', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '西24条北', 'ニシ24ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市西25条北', '01', '01207', '0802465', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '西25条北', 'ニシ25ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市西19条南1丁目', '01', '01207', '0802469', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '西19条南', 'ニシ19ジョウミナミ', null, null, '1丁目', '01チョウメ');
INSERT INTO `ms_addresses` VALUES ('103240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市西19条南2丁目', '01', '01207', '0802469', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '西19条南', 'ニシ19ジョウミナミ', null, null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('103241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市西19条南3丁目', '01', '01207', '0802469', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '西19条南', 'ニシ19ジョウミナミ', null, null, '3丁目', '03チョウメ');
INSERT INTO `ms_addresses` VALUES ('103242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市西19条南4丁目', '01', '01207', '0802469', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '西19条南', 'ニシ19ジョウミナミ', null, null, '4丁目', '04チョウメ');
INSERT INTO `ms_addresses` VALUES ('103243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市西19条南5丁目', '01', '01207', '0802469', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '西19条南', 'ニシ19ジョウミナミ', null, null, '5丁目', '05チョウメ');
INSERT INTO `ms_addresses` VALUES ('103244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市西20条南', '01', '01207', '0802470', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '西20条南', 'ニシ20ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市西21条南', '01', '01207', '0802471', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '西21条南', 'ニシ21ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市西22条南', '01', '01207', '0802472', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '西22条南', 'ニシ22ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市西23条南', '01', '01207', '0802473', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '西23条南', 'ニシ23ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市西24条南', '01', '01207', '0802474', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '西24条南', 'ニシ24ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市西25条南', '01', '01207', '0802475', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '西25条南', 'ニシ25ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市自由が丘3丁目', '01', '01207', '0802476', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '自由が丘', 'ジユウガオカ', null, null, '3丁目', '03チョウメ');
INSERT INTO `ms_addresses` VALUES ('103251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市自由が丘4丁目', '01', '01207', '0802476', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '自由が丘', 'ジユウガオカ', null, null, '4丁目', '04チョウメ');
INSERT INTO `ms_addresses` VALUES ('103252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市自由が丘5丁目', '01', '01207', '0802476', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '自由が丘', 'ジユウガオカ', null, null, '5丁目', '05チョウメ');
INSERT INTO `ms_addresses` VALUES ('103253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市自由が丘6丁目', '01', '01207', '0802476', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '自由が丘', 'ジユウガオカ', null, null, '6丁目', '06チョウメ');
INSERT INTO `ms_addresses` VALUES ('103254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市自由が丘7丁目', '01', '01207', '0802476', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '自由が丘', 'ジユウガオカ', null, null, '7丁目', '07チョウメ');
INSERT INTO `ms_addresses` VALUES ('103291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区平尾台', '40', '40107', '8030180', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '平尾台', 'ヒラオダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区呼野', '40', '40107', '8030181', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '呼野', 'ヨブノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区小森', '40', '40107', '8030182', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '小森', 'コモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区市丸', '40', '40107', '8030183', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '市丸', 'イチマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区木下', '40', '40107', '8030184', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '木下', 'キノシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区石原町', '40', '40107', '8030185', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '石原町', 'イシハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区新道寺', '40', '40107', '8030186', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '新道寺', 'シンドウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区母原', '40', '40107', '8030187', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '母原', 'モハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区母原紫水団地', '40', '40107', '8030188', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '母原', 'モハラ', null, null, '紫水団地', 'シスイダンチ');
INSERT INTO `ms_addresses` VALUES ('103300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区井手浦', '40', '40107', '8030189', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '井手浦', 'イデウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区合馬', '40', '40107', '8030261', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '合馬', 'オウマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区田代', '40', '40107', '8030262', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '田代', 'タシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区辻三', '40', '40107', '8030263', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '辻三', 'ツジミツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区山本', '40', '40107', '8030264', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '山本', 'ヤマモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区春吉', '40', '40107', '8030265', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '春吉', 'ハルヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区道原', '40', '40107', '8030266', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '道原', 'ドウバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区頂吉', '40', '40107', '8030267', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '頂吉', 'カグメヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区高津尾', '40', '40107', '8030268', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '高津尾', 'タカツオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区長行', '40', '40107', '8030271', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '長行', 'オサユキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区長行西', '40', '40107', '8030272', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '長行西', 'オサユキニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区長行東', '40', '40107', '8030273', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '長行東', 'オサユキヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区長尾', '40', '40107', '8030274', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '長尾', 'ナガオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区高野', '40', '40107', '8030275', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '高野', 'タカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区徳吉', '40', '40107', '8030276', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '徳吉', 'トクヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区徳吉東', '40', '40107', '8030277', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '徳吉東', 'トクヨシヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区徳吉西', '40', '40107', '8030278', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '徳吉西', 'トクヨシニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉南区徳吉南', '40', '40107', '8030279', '福岡県', 'フクオカケン', '北九州市小倉南区', 'キタキュウシュウシコクラミナミク', '徳吉南', 'トクヨシミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区西港町', '40', '40106', '8030801', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '西港町', 'ニシミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区東港', '40', '40106', '8030802', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '東港', 'ヒガシミナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区許斐町', '40', '40106', '8030803', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '許斐町', 'コノミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区中井浜', '40', '40106', '8030804', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '中井浜', 'ナカイハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区親和町', '40', '40106', '8030805', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '親和町', 'シンワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区大門', '40', '40106', '8030811', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '大門', 'ダイモン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区室町', '40', '40106', '8030812', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '室町', 'ムロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区城内', '40', '40106', '8030813', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '城内', 'ジョウナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区大手町', '40', '40106', '8030814', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '大手町', 'オオテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区原町', '40', '40106', '8030815', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '原町', 'ハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区金田', '40', '40106', '8030816', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '金田', 'カナダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区田町', '40', '40106', '8030817', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '田町', 'タマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区竪町', '40', '40106', '8030818', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '竪町', 'タテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区鋳物師町', '40', '40106', '8030821', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '鋳物師町', 'イモジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区青葉', '40', '40106', '8030822', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '青葉', 'アオバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区菜園場', '40', '40106', '8030823', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '菜園場', 'サエンバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区板櫃町', '40', '40106', '8030824', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '板櫃町', 'イタビツマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区白萩町', '40', '40106', '8030825', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '白萩町', 'シラハギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区高峰町', '40', '40106', '8030826', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '高峰町', 'タカミネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区緑ケ丘', '40', '40106', '8030827', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '緑ケ丘', 'ミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区愛宕', '40', '40106', '8030828', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '愛宕', 'アタゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区日明', '40', '40106', '8030831', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '日明', 'ヒアガリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区平松町', '40', '40106', '8030832', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '平松町', 'ヒラマツマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区朝日ケ丘', '40', '40106', '8030833', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '朝日ケ丘', 'アサヒガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区都', '40', '40106', '8030834', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '都', 'ミヤコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区井堀', '40', '40106', '8030835', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '井堀', 'イボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区中井', '40', '40106', '8030836', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '中井', 'ナカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区中井口', '40', '40106', '8030837', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '中井口', 'ナカイグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区高見台', '40', '40106', '8030838', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '高見台', 'タカミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区清水', '40', '40106', '8030841', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '清水', 'キヨミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区泉台', '40', '40106', '8030842', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '泉台', 'イズミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区金鶏町', '40', '40106', '8030843', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '金鶏町', 'キンケイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区真鶴', '40', '40106', '8030844', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '真鶴', 'マナヅル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区上到津', '40', '40106', '8030845', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '上到津', 'カミイトウヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区下到津', '40', '40106', '8030846', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '下到津', 'シモイトウヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区木町', '40', '40106', '8030851', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '木町', 'キマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区新高田', '40', '40106', '8030852', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '新高田', 'シンタカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区高尾', '40', '40106', '8030853', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '高尾', 'タカオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区皿山町', '40', '40106', '8030854', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '皿山町', 'サラヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区竪林町', '40', '40106', '8030855', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '竪林町', 'タテバヤシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区弁天町', '40', '40106', '8030856', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '弁天町', 'ベンテンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区篠崎', '40', '40106', '8030861', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '篠崎', 'シノザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区今町', '40', '40106', '8030862', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '今町', 'イママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区南丘', '40', '40106', '8030863', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '南丘', 'ミナミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区熊谷', '40', '40106', '8030864', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '熊谷', 'クマガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市小倉北区山田町', '40', '40106', '8030865', '福岡県', 'フクオカケン', '北九州市小倉北区', 'キタキュウシュウシコクラキタク', '山田町', 'ヤマダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市戸畑区', '40', '40105', '8040000', '福岡県', 'フクオカケン', '北九州市戸畑区', 'キタキュウシュウシトバタク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('103395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市戸畑区飛幡町', '40', '40105', '8040001', '福岡県', 'フクオカケン', '北九州市戸畑区', 'キタキュウシュウシトバタク', '飛幡町', 'トビハタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市戸畑区中原先の浜', '40', '40105', '8040002', '福岡県', 'フクオカケン', '北九州市戸畑区', 'キタキュウシュウシトバタク', '中原', 'ナカバル', null, null, '先の浜', 'サキノハマ');
INSERT INTO `ms_addresses` VALUES ('103397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市戸畑区中原新町', '40', '40105', '8040003', '福岡県', 'フクオカケン', '北九州市戸畑区', 'キタキュウシュウシトバタク', '中原新町', 'ナカバルシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市戸畑区戸畑', '40', '40105', '8040004', '福岡県', 'フクオカケン', '北九州市戸畑区', 'キタキュウシュウシトバタク', '戸畑', 'トバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市戸畑区中原西', '40', '40105', '8040011', '福岡県', 'フクオカケン', '北九州市戸畑区', 'キタキュウシュウシトバタク', '中原西', 'ナカバルニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市戸畑区中原東', '40', '40105', '8040012', '福岡県', 'フクオカケン', '北九州市戸畑区', 'キタキュウシュウシトバタク', '中原東', 'ナカバルヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市戸畑区境川', '40', '40105', '8040013', '福岡県', 'フクオカケン', '北九州市戸畑区', 'キタキュウシュウシトバタク', '境川', 'サカイガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市戸畑区土取町', '40', '40105', '8040014', '福岡県', 'フクオカケン', '北九州市戸畑区', 'キタキュウシュウシトバタク', '土取町', 'ツチトリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市戸畑区仙水町', '40', '40105', '8040015', '福岡県', 'フクオカケン', '北九州市戸畑区', 'キタキュウシュウシトバタク', '仙水町', 'センスイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市戸畑区一枝', '40', '40105', '8040021', '福岡県', 'フクオカケン', '北九州市戸畑区', 'キタキュウシュウシトバタク', '一枝', 'イチエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市戸畑区金比羅町', '40', '40105', '8040022', '福岡県', 'フクオカケン', '北九州市戸畑区', 'キタキュウシュウシトバタク', '金比羅町', 'コンピラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市戸畑区東鞘ケ谷町', '40', '40105', '8040023', '福岡県', 'フクオカケン', '北九州市戸畑区', 'キタキュウシュウシトバタク', '東鞘ケ谷町', 'ヒガシサヤガタニマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市戸畑区西鞘ケ谷町', '40', '40105', '8040024', '福岡県', 'フクオカケン', '北九州市戸畑区', 'キタキュウシュウシトバタク', '西鞘ケ谷町', 'ニシサヤガタニマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市戸畑区福柳木', '40', '40105', '8040025', '福岡県', 'フクオカケン', '北九州市戸畑区', 'キタキュウシュウシトバタク', '福柳木', 'フクリュウギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市戸畑区東大谷', '40', '40105', '8040031', '福岡県', 'フクオカケン', '北九州市戸畑区', 'キタキュウシュウシトバタク', '東大谷', 'ヒガシオオタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市戸畑区西大谷', '40', '40105', '8040032', '福岡県', 'フクオカケン', '北九州市戸畑区', 'キタキュウシュウシトバタク', '西大谷', 'ニシオオタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市戸畑区椎ノ木町', '40', '40105', '8040033', '福岡県', 'フクオカケン', '北九州市戸畑区', 'キタキュウシュウシトバタク', '椎ノ木町', 'シイノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市戸畑区天籟寺', '40', '40105', '8040041', '福岡県', 'フクオカケン', '北九州市戸畑区', 'キタキュウシュウシトバタク', '天籟寺', 'テンライジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市戸畑区夜宮', '40', '40105', '8040042', '福岡県', 'フクオカケン', '北九州市戸畑区', 'キタキュウシュウシトバタク', '夜宮', 'ヨミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市戸畑区観音寺町', '40', '40105', '8040043', '福岡県', 'フクオカケン', '北九州市戸畑区', 'キタキュウシュウシトバタク', '観音寺町', 'カンノンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市戸畑区菅原', '40', '40105', '8040044', '福岡県', 'フクオカケン', '北九州市戸畑区', 'キタキュウシュウシトバタク', '菅原', 'スガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市戸畑区高峰', '40', '40105', '8040051', '福岡県', 'フクオカケン', '北九州市戸畑区', 'キタキュウシュウシトバタク', '高峰', 'タカミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市戸畑区丸町', '40', '40105', '8040052', '福岡県', 'フクオカケン', '北九州市戸畑区', 'キタキュウシュウシトバタク', '丸町', 'マルマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市戸畑区牧山', '40', '40105', '8040053', '福岡県', 'フクオカケン', '北九州市戸畑区', 'キタキュウシュウシトバタク', '牧山', 'マキヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市戸畑区牧山新町', '40', '40105', '8040054', '福岡県', 'フクオカケン', '北九州市戸畑区', 'キタキュウシュウシトバタク', '牧山新町', 'マキヤマシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市戸畑区中本町', '40', '40105', '8040061', '福岡県', 'フクオカケン', '北九州市戸畑区', 'キタキュウシュウシトバタク', '中本町', 'ナカホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市戸畑区浅生', '40', '40105', '8040062', '福岡県', 'フクオカケン', '北九州市戸畑区', 'キタキュウシュウシトバタク', '浅生', 'アソウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市戸畑区正津町', '40', '40105', '8040063', '福岡県', 'フクオカケン', '北九州市戸畑区', 'キタキュウシュウシトバタク', '正津町', 'ショウヅマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市戸畑区沖台', '40', '40105', '8040064', '福岡県', 'フクオカケン', '北九州市戸畑区', 'キタキュウシュウシトバタク', '沖台', 'オキダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市戸畑区新川町', '40', '40105', '8040065', '福岡県', 'フクオカケン', '北九州市戸畑区', 'キタキュウシュウシトバタク', '新川町', 'シンカワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市戸畑区初音町', '40', '40105', '8040066', '福岡県', 'フクオカケン', '北九州市戸畑区', 'キタキュウシュウシトバタク', '初音町', 'ハツネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市戸畑区汐井町', '40', '40105', '8040067', '福岡県', 'フクオカケン', '北九州市戸畑区', 'キタキュウシュウシトバタク', '汐井町', 'シオイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市戸畑区川代', '40', '40105', '8040071', '福岡県', 'フクオカケン', '北九州市戸畑区', 'キタキュウシュウシトバタク', '川代', 'カワシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市戸畑区元宮町', '40', '40105', '8040072', '福岡県', 'フクオカケン', '北九州市戸畑区', 'キタキュウシュウシトバタク', '元宮町', 'モトミヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市戸畑区明治町', '40', '40105', '8040073', '福岡県', 'フクオカケン', '北九州市戸畑区', 'キタキュウシュウシトバタク', '明治町', 'メイジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市戸畑区南鳥旗町', '40', '40105', '8040074', '福岡県', 'フクオカケン', '北九州市戸畑区', 'キタキュウシュウシトバタク', '南鳥旗町', 'ミナミトリハタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市戸畑区北鳥旗町', '40', '40105', '8040075', '福岡県', 'フクオカケン', '北九州市戸畑区', 'キタキュウシュウシトバタク', '北鳥旗町', 'キタトリハタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市戸畑区銀座', '40', '40105', '8040076', '福岡県', 'フクオカケン', '北九州市戸畑区', 'キタキュウシュウシトバタク', '銀座', 'ギンザ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市戸畑区牧山海岸', '40', '40105', '8040077', '福岡県', 'フクオカケン', '北九州市戸畑区', 'キタキュウシュウシトバタク', '牧山海岸', 'マキヤマカイガン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市戸畑区千防', '40', '40105', '8040081', '福岡県', 'フクオカケン', '北九州市戸畑区', 'キタキュウシュウシトバタク', '千防', 'センボウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市戸畑区新池', '40', '40105', '8040082', '福岡県', 'フクオカケン', '北九州市戸畑区', 'キタキュウシュウシトバタク', '新池', 'シンイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市戸畑区旭町', '40', '40105', '8040083', '福岡県', 'フクオカケン', '北九州市戸畑区', 'キタキュウシュウシトバタク', '旭町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市戸畑区幸町', '40', '40105', '8040084', '福岡県', 'フクオカケン', '北九州市戸畑区', 'キタキュウシュウシトバタク', '幸町', 'サイワイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市戸畑区三六町', '40', '40105', '8040091', '福岡県', 'フクオカケン', '北九州市戸畑区', 'キタキュウシュウシトバタク', '三六町', 'サンロクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市戸畑区小芝', '40', '40105', '8040092', '福岡県', 'フクオカケン', '北九州市戸畑区', 'キタキュウシュウシトバタク', '小芝', 'コシバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市戸畑区沢見', '40', '40105', '8040093', '福岡県', 'フクオカケン', '北九州市戸畑区', 'キタキュウシュウシトバタク', '沢見', 'サワミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市戸畑区天神', '40', '40105', '8040094', '福岡県', 'フクオカケン', '北九州市戸畑区', 'キタキュウシュウシトバタク', '天神', 'テンジン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡東区', '40', '40108', '8050000', '福岡県', 'フクオカケン', '北九州市八幡東区', 'キタキュウシュウシヤハタヒガシク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('103456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡東区荒手', '40', '40108', '8050001', '福岡県', 'フクオカケン', '北九州市八幡東区', 'キタキュウシュウシヤハタヒガシク', '荒手', 'アラテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡東区枝光', '40', '40108', '8050002', '福岡県', 'フクオカケン', '北九州市八幡東区', 'キタキュウシュウシヤハタヒガシク', '枝光', 'エダミツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡東区大宮町', '40', '40108', '8050003', '福岡県', 'フクオカケン', '北九州市八幡東区', 'キタキュウシュウシヤハタヒガシク', '大宮町', 'オオミヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡東区日の出', '40', '40108', '8050004', '福岡県', 'フクオカケン', '北九州市八幡東区', 'キタキュウシュウシヤハタヒガシク', '日の出', 'ヒノデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡東区藤見町', '40', '40108', '8050005', '福岡県', 'フクオカケン', '北九州市八幡東区', 'キタキュウシュウシヤハタヒガシク', '藤見町', 'フジミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡東区諏訪', '40', '40108', '8050006', '福岡県', 'フクオカケン', '北九州市八幡東区', 'キタキュウシュウシヤハタヒガシク', '諏訪', 'スワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡東区白川町', '40', '40108', '8050007', '福岡県', 'フクオカケン', '北九州市八幡東区', 'キタキュウシュウシヤハタヒガシク', '白川町', 'シラカワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡東区枝光本町', '40', '40108', '8050008', '福岡県', 'フクオカケン', '北九州市八幡東区', 'キタキュウシュウシヤハタヒガシク', '枝光本町', 'エダミツホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡東区宮田町', '40', '40108', '8050009', '福岡県', 'フクオカケン', '北九州市八幡東区', 'キタキュウシュウシヤハタヒガシク', '宮田町', 'ミヤタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡東区八王寺町', '40', '40108', '8050011', '福岡県', 'フクオカケン', '北九州市八幡東区', 'キタキュウシュウシヤハタヒガシク', '八王寺町', 'ハチオウジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡東区川淵町', '40', '40108', '8050012', '福岡県', 'フクオカケン', '北九州市八幡東区', 'キタキュウシュウシヤハタヒガシク', '川淵町', 'カワブチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡東区昭和', '40', '40108', '8050013', '福岡県', 'フクオカケン', '北九州市八幡東区', 'キタキュウシュウシヤハタヒガシク', '昭和', 'ショウワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡東区茶屋町', '40', '40108', '8050014', '福岡県', 'フクオカケン', '北九州市八幡東区', 'キタキュウシュウシヤハタヒガシク', '茶屋町', 'チャヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡東区荒生田', '40', '40108', '8050015', '福岡県', 'フクオカケン', '北九州市八幡東区', 'キタキュウシュウシヤハタヒガシク', '荒生田', 'アロウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡東区高見', '40', '40108', '8050016', '福岡県', 'フクオカケン', '北九州市八幡東区', 'キタキュウシュウシヤハタヒガシク', '高見', 'タカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡東区山王', '40', '40108', '8050017', '福岡県', 'フクオカケン', '北九州市八幡東区', 'キタキュウシュウシヤハタヒガシク', '山王', 'サンノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡東区上本町', '40', '40108', '8050018', '福岡県', 'フクオカケン', '北九州市八幡東区', 'キタキュウシュウシヤハタヒガシク', '上本町', 'カミホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡東区中央', '40', '40108', '8050019', '福岡県', 'フクオカケン', '北九州市八幡東区', 'キタキュウシュウシヤハタヒガシク', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡東区石坪町', '40', '40108', '8050021', '福岡県', 'フクオカケン', '北九州市八幡東区', 'キタキュウシュウシヤハタヒガシク', '石坪町', 'イシツボマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡東区竹下町', '40', '40108', '8050022', '福岡県', 'フクオカケン', '北九州市八幡東区', 'キタキュウシュウシヤハタヒガシク', '竹下町', 'タケシタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡東区宮の町', '40', '40108', '8050023', '福岡県', 'フクオカケン', '北九州市八幡東区', 'キタキュウシュウシヤハタヒガシク', '宮の町', 'ミヤノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡東区中畑', '40', '40108', '8050024', '福岡県', 'フクオカケン', '北九州市八幡東区', 'キタキュウシュウシヤハタヒガシク', '中畑', 'ナカハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡東区中尾', '40', '40108', '8050025', '福岡県', 'フクオカケン', '北九州市八幡東区', 'キタキュウシュウシヤハタヒガシク', '中尾', 'ナカオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡東区東山', '40', '40108', '8050026', '福岡県', 'フクオカケン', '北九州市八幡東区', 'キタキュウシュウシヤハタヒガシク', '東山', 'ヒガシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡東区東鉄町', '40', '40108', '8050027', '福岡県', 'フクオカケン', '北九州市八幡東区', 'キタキュウシュウシヤハタヒガシク', '東鉄町', 'ヒガシテツマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡東区槻田', '40', '40108', '8050031', '福岡県', 'フクオカケン', '北九州市八幡東区', 'キタキュウシュウシヤハタヒガシク', '槻田', 'ツキダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡東区松尾町', '40', '40108', '8050032', '福岡県', 'フクオカケン', '北九州市八幡東区', 'キタキュウシュウシヤハタヒガシク', '松尾町', 'マツオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡東区山路松尾町', '40', '40108', '8050033', '福岡県', 'フクオカケン', '北九州市八幡東区', 'キタキュウシュウシヤハタヒガシク', '山路松尾町', 'サンジマツオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡東区清田', '40', '40108', '8050034', '福岡県', 'フクオカケン', '北九州市八幡東区', 'キタキュウシュウシヤハタヒガシク', '清田', 'キヨタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡東区山路', '40', '40108', '8050035', '福岡県', 'フクオカケン', '北九州市八幡東区', 'キタキュウシュウシヤハタヒガシク', '山路', 'サンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡東区小熊野', '40', '40108', '8050036', '福岡県', 'フクオカケン', '北九州市八幡東区', 'キタキュウシュウシヤハタヒガシク', '小熊野', 'コグマノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡東区猪倉町', '40', '40108', '8050037', '福岡県', 'フクオカケン', '北九州市八幡東区', 'キタキュウシュウシヤハタヒガシク', '猪倉町', 'イノクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡東区大平町', '40', '40108', '8050038', '福岡県', 'フクオカケン', '北九州市八幡東区', 'キタキュウシュウシヤハタヒガシク', '大平町', 'オオヒラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡東区祝町', '40', '40108', '8050041', '福岡県', 'フクオカケン', '北九州市八幡東区', 'キタキュウシュウシヤハタヒガシク', '祝町', 'イワイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡東区羽衣町', '40', '40108', '8050042', '福岡県', 'フクオカケン', '北九州市八幡東区', 'キタキュウシュウシヤハタヒガシク', '羽衣町', 'ハゴロモマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡東区勝山', '40', '40108', '8050043', '福岡県', 'フクオカケン', '北九州市八幡東区', 'キタキュウシュウシヤハタヒガシク', '勝山', 'カツヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡東区豊町', '40', '40108', '8050044', '福岡県', 'フクオカケン', '北九州市八幡東区', 'キタキュウシュウシヤハタヒガシク', '豊町', 'ユタカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡東区河内', '40', '40108', '8050045', '福岡県', 'フクオカケン', '北九州市八幡東区', 'キタキュウシュウシヤハタヒガシク', '河内', 'カワチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡東区田代', '40', '40108', '8050046', '福岡県', 'フクオカケン', '北九州市八幡東区', 'キタキュウシュウシヤハタヒガシク', '田代', 'タシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡東区景勝町', '40', '40108', '8050047', '福岡県', 'フクオカケン', '北九州市八幡東区', 'キタキュウシュウシヤハタヒガシク', '景勝町', 'ケイショウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡東区大蔵', '40', '40108', '8050048', '福岡県', 'フクオカケン', '北九州市八幡東区', 'キタキュウシュウシヤハタヒガシク', '大蔵', 'オオクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡東区末広町', '40', '40108', '8050049', '福岡県', 'フクオカケン', '北九州市八幡東区', 'キタキュウシュウシヤハタヒガシク', '末広町', 'スエヒロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡東区春の町', '40', '40108', '8050050', '福岡県', 'フクオカケン', '北九州市八幡東区', 'キタキュウシュウシヤハタヒガシク', '春の町', 'ハルノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡東区東丸山町', '40', '40108', '8050051', '福岡県', 'フクオカケン', '北九州市八幡東区', 'キタキュウシュウシヤハタヒガシク', '東丸山町', 'ヒガシマルヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡東区西丸山町', '40', '40108', '8050052', '福岡県', 'フクオカケン', '北九州市八幡東区', 'キタキュウシュウシヤハタヒガシク', '西丸山町', 'ニシマルヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡東区大谷', '40', '40108', '8050053', '福岡県', 'フクオカケン', '北九州市八幡東区', 'キタキュウシュウシヤハタヒガシク', '大谷', 'オオタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡東区天神町', '40', '40108', '8050054', '福岡県', 'フクオカケン', '北九州市八幡東区', 'キタキュウシュウシヤハタヒガシク', '天神町', 'テンジンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡東区神山町', '40', '40108', '8050055', '福岡県', 'フクオカケン', '北九州市八幡東区', 'キタキュウシュウシヤハタヒガシク', '神山町', 'カミヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡東区帆柱', '40', '40108', '8050056', '福岡県', 'フクオカケン', '北九州市八幡東区', 'キタキュウシュウシヤハタヒガシク', '帆柱', 'ホバシラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡東区尾倉', '40', '40108', '8050057', '福岡県', 'フクオカケン', '北九州市八幡東区', 'キタキュウシュウシヤハタヒガシク', '尾倉', 'オグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡東区前田', '40', '40108', '8050058', '福岡県', 'フクオカケン', '北九州市八幡東区', 'キタキュウシュウシヤハタヒガシク', '前田', 'マエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡東区尾倉', '40', '40108', '8050059', '福岡県', 'フクオカケン', '北九州市八幡東区', 'キタキュウシュウシヤハタヒガシク', '尾倉', 'オグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡東区西本町', '40', '40108', '8050061', '福岡県', 'フクオカケン', '北九州市八幡東区', 'キタキュウシュウシヤハタヒガシク', '西本町', 'ニシホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡東区平野', '40', '40108', '8050062', '福岡県', 'フクオカケン', '北九州市八幡東区', 'キタキュウシュウシヤハタヒガシク', '平野', 'ヒラノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡東区東台良町', '40', '40108', '8050063', '福岡県', 'フクオカケン', '北九州市八幡東区', 'キタキュウシュウシヤハタヒガシク', '東台良町', 'ヒガシダイラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡東区西台良町', '40', '40108', '8050064', '福岡県', 'フクオカケン', '北九州市八幡東区', 'キタキュウシュウシヤハタヒガシク', '西台良町', 'ニシダイラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡東区花尾町', '40', '40108', '8050065', '福岡県', 'フクオカケン', '北九州市八幡東区', 'キタキュウシュウシヤハタヒガシク', '花尾町', 'ハナオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡東区祇園原町', '40', '40108', '8050066', '福岡県', 'フクオカケン', '北九州市八幡東区', 'キタキュウシュウシヤハタヒガシク', '祇園原町', 'ギオンバラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡東区祇園', '40', '40108', '8050067', '福岡県', 'フクオカケン', '北九州市八幡東区', 'キタキュウシュウシヤハタヒガシク', '祇園', 'ギオン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡東区桃園', '40', '40108', '8050068', '福岡県', 'フクオカケン', '北九州市八幡東区', 'キタキュウシュウシヤハタヒガシク', '桃園', 'モモゾノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡東区前田', '40', '40108', '8050069', '福岡県', 'フクオカケン', '北九州市八幡東区', 'キタキュウシュウシヤハタヒガシク', '前田', 'マエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡東区東田', '40', '40108', '8050071', '福岡県', 'フクオカケン', '北九州市八幡東区', 'キタキュウシュウシヤハタヒガシク', '東田', 'ヒガシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区', '40', '40109', '8060000', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('103547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区築地町', '40', '40109', '8060001', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '築地町', 'ツキジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区東浜町', '40', '40109', '8060002', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '東浜町', 'ヒガシハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区田町', '40', '40109', '8060003', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '田町', 'タマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区黒崎城石', '40', '40109', '8060004', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '黒崎城石', 'クロサキシロイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区舟町', '40', '40109', '8060005', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '舟町', 'フナマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区屋敷', '40', '40109', '8060006', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '屋敷', 'ヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区紅梅', '40', '40109', '8060011', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '紅梅', 'コウバイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区陣山', '40', '40109', '8060012', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '陣山', 'ジンヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区清納', '40', '40109', '8060013', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '清納', 'セイノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区東川頭町', '40', '40109', '8060014', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '東川頭町', 'ヒガシカワガシラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区元城町', '40', '40109', '8060015', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '元城町', 'モトシロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区河桃町', '40', '40109', '8060016', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '河桃町', 'コウトウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区西川頭町', '40', '40109', '8060017', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '西川頭町', 'ニシカワガシラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区平尾町', '40', '40109', '8060018', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '平尾町', 'ヒラオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区黒崎', '40', '40109', '8060021', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '黒崎', 'クロサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区藤田', '40', '40109', '8060022', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '藤田', 'フジタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区八千代町', '40', '40109', '8060023', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '八千代町', 'ヤチヨマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区南八千代町', '40', '40109', '8060024', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '南八千代町', 'ミナミヤチヨマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区東神原町', '40', '40109', '8060025', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '東神原町', 'ヒガシカンバラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区西神原町', '40', '40109', '8060026', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '西神原町', 'ニシカンバラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区菅原町', '40', '40109', '8060027', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '菅原町', 'スガワラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区熊手', '40', '40109', '8060028', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '熊手', 'クマデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区山寺町', '40', '40109', '8060030', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '山寺町', 'ヤマデラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区熊西', '40', '40109', '8060031', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '熊西', 'クマニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区筒井町', '40', '40109', '8060032', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '筒井町', 'ツツイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区岡田町', '40', '40109', '8060033', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '岡田町', 'オカダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区岸の浦', '40', '40109', '8060034', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '岸の浦', 'キシノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区東曲里町', '40', '40109', '8060035', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '東曲里町', 'ヒガシマガリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区西曲里町', '40', '40109', '8060036', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '西曲里町', 'ニシマガリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区東王子町', '40', '40109', '8060037', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '東王子町', 'ヒガシオウジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区南王子町', '40', '40109', '8060038', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '南王子町', 'ミナミオウジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区西王子町', '40', '40109', '8060039', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '西王子町', 'ニシオウジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区皇后崎町', '40', '40109', '8060041', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '皇后崎町', 'コウガサキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区桜ケ丘町', '40', '40109', '8060042', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '桜ケ丘町', 'サクラガオカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区青山', '40', '40109', '8060043', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '青山', 'アオヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区相生町', '40', '40109', '8060044', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '相生町', 'アイオイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区竹末', '40', '40109', '8060045', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '竹末', 'タケスエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区森下町', '40', '40109', '8060046', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '森下町', 'モリシタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区鷹の巣', '40', '40109', '8060047', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '鷹の巣', 'タカノス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区樋口町', '40', '40109', '8060048', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '樋口町', 'ヒグチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区穴生', '40', '40109', '8060049', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '穴生', 'アノオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区東鳴水', '40', '40109', '8060051', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '東鳴水', 'ヒガシナルミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区鳴水町', '40', '40109', '8060052', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '鳴水町', 'ナルミズマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区大畑町', '40', '40109', '8060053', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '大畑町', 'オオハタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区西鳴水', '40', '40109', '8060054', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '西鳴水', 'ニシナルミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区幸神', '40', '40109', '8060055', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '幸神', 'サイノカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区小鷺田町', '40', '40109', '8060056', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '小鷺田町', 'コサギダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区鉄王', '40', '40109', '8060057', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '鉄王', 'テツオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区鉄竜', '40', '40109', '8060058', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '鉄竜', 'テツリュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区萩原', '40', '40109', '8060059', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '萩原', 'ハギワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区京良城町', '40', '40109', '8060061', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '京良城町', 'キョウラギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区別当町', '40', '40109', '8060062', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '別当町', 'ベットウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区市瀬', '40', '40109', '8060063', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '市瀬', 'イチノセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区割子川', '40', '40109', '8060064', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '割子川', 'ワリコガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区養福寺町', '40', '40109', '8060065', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '養福寺町', 'ヨウフクジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区若葉', '40', '40109', '8060066', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '若葉', 'ワカバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区引野', '40', '40109', '8060067', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '引野', 'ヒキノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区別所町', '40', '40109', '8060068', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '別所町', 'ベッショマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区茶売町', '40', '40109', '8060069', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '茶売町', 'チャウリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県遠賀郡水巻町', '40', '40382', '8070000', '福岡県', 'フクオカケン', '遠賀郡水巻町', 'オンガグンミズマキマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('103624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県遠賀郡水巻町猪熊', '40', '40382', '8070001', '福岡県', 'フクオカケン', '遠賀郡水巻町', 'オンガグンミズマキマチ', '猪熊', 'イノクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県遠賀郡水巻町樋口', '40', '40382', '8070002', '福岡県', 'フクオカケン', '遠賀郡水巻町', 'オンガグンミズマキマチ', '樋口', 'ヒグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県遠賀郡水巻町おかの台', '40', '40382', '8070003', '福岡県', 'フクオカケン', '遠賀郡水巻町', 'オンガグンミズマキマチ', 'おかの台', 'オカノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県遠賀郡水巻町樋口東', '40', '40382', '8070004', '福岡県', 'フクオカケン', '遠賀郡水巻町', 'オンガグンミズマキマチ', '樋口東', 'ヒグチヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県遠賀郡水巻町高松', '40', '40382', '8070005', '福岡県', 'フクオカケン', '遠賀郡水巻町', 'オンガグンミズマキマチ', '高松', 'タカマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県遠賀郡水巻町梅ノ木団地', '40', '40382', '8070006', '福岡県', 'フクオカケン', '遠賀郡水巻町', 'オンガグンミズマキマチ', '梅ノ木団地', 'ウメノキダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県遠賀郡水巻町牟田', '40', '40382', '8070007', '福岡県', 'フクオカケン', '遠賀郡水巻町', 'オンガグンミズマキマチ', '牟田', 'ムタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県遠賀郡水巻町緑ケ丘', '40', '40382', '8070011', '福岡県', 'フクオカケン', '遠賀郡水巻町', 'オンガグンミズマキマチ', '緑ケ丘', 'ミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県遠賀郡水巻町古賀', '40', '40382', '8070012', '福岡県', 'フクオカケン', '遠賀郡水巻町', 'オンガグンミズマキマチ', '古賀', 'コガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県遠賀郡水巻町頃末', '40', '40382', '8070021', '福岡県', 'フクオカケン', '遠賀郡水巻町', 'オンガグンミズマキマチ', '頃末', 'コロスエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県遠賀郡水巻町頃末北', '40', '40382', '8070022', '福岡県', 'フクオカケン', '遠賀郡水巻町', 'オンガグンミズマキマチ', '頃末北', 'コロスエキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県遠賀郡水巻町中央', '40', '40382', '8070023', '福岡県', 'フクオカケン', '遠賀郡水巻町', 'オンガグンミズマキマチ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県遠賀郡水巻町高尾', '40', '40382', '8070024', '福岡県', 'フクオカケン', '遠賀郡水巻町', 'オンガグンミズマキマチ', '高尾', 'タカオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県遠賀郡水巻町頃末南', '40', '40382', '8070025', '福岡県', 'フクオカケン', '遠賀郡水巻町', 'オンガグンミズマキマチ', '頃末南', 'コロスエミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県遠賀郡水巻町杁', '40', '40382', '8070031', '福岡県', 'フクオカケン', '遠賀郡水巻町', 'オンガグンミズマキマチ', '杁', 'エブリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県遠賀郡水巻町宮尾台', '40', '40382', '8070041', '福岡県', 'フクオカケン', '遠賀郡水巻町', 'オンガグンミズマキマチ', '宮尾台', 'ミヤオダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県遠賀郡水巻町吉田', '40', '40382', '8070042', '福岡県', 'フクオカケン', '遠賀郡水巻町', 'オンガグンミズマキマチ', '吉田', 'ヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県遠賀郡水巻町吉田団地', '40', '40382', '8070042', '福岡県', 'フクオカケン', '遠賀郡水巻町', 'オンガグンミズマキマチ', '吉田団地', 'ヨシダダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県遠賀郡水巻町下二', '40', '40382', '8070043', '福岡県', 'フクオカケン', '遠賀郡水巻町', 'オンガグンミズマキマチ', '下二', 'シモフタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県遠賀郡水巻町美吉野', '40', '40382', '8070044', '福岡県', 'フクオカケン', '遠賀郡水巻町', 'オンガグンミズマキマチ', '美吉野', 'ミヨシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県遠賀郡水巻町吉田東', '40', '40382', '8070045', '福岡県', 'フクオカケン', '遠賀郡水巻町', 'オンガグンミズマキマチ', '吉田東', 'ヨシダヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県遠賀郡水巻町吉田西', '40', '40382', '8070046', '福岡県', 'フクオカケン', '遠賀郡水巻町', 'オンガグンミズマキマチ', '吉田西', 'ヨシダニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県遠賀郡水巻町鯉口', '40', '40382', '8070047', '福岡県', 'フクオカケン', '遠賀郡水巻町', 'オンガグンミズマキマチ', '鯉口', 'コイグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県遠賀郡水巻町吉田南', '40', '40382', '8070048', '福岡県', 'フクオカケン', '遠賀郡水巻町', 'オンガグンミズマキマチ', '吉田南', 'ヨシダミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県遠賀郡水巻町立屋敷', '40', '40382', '8070051', '福岡県', 'フクオカケン', '遠賀郡水巻町', 'オンガグンミズマキマチ', '立屋敷', 'タテヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県遠賀郡水巻町下二西', '40', '40382', '8070052', '福岡県', 'フクオカケン', '遠賀郡水巻町', 'オンガグンミズマキマチ', '下二西', 'シモフタニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県遠賀郡水巻町下二東', '40', '40382', '8070053', '福岡県', 'フクオカケン', '遠賀郡水巻町', 'オンガグンミズマキマチ', '下二東', 'シモフタヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県遠賀郡水巻町二東', '40', '40382', '8070054', '福岡県', 'フクオカケン', '遠賀郡水巻町', 'オンガグンミズマキマチ', '二東', 'フタヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県遠賀郡水巻町二西', '40', '40382', '8070055', '福岡県', 'フクオカケン', '遠賀郡水巻町', 'オンガグンミズマキマチ', '二西', 'フタニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県遠賀郡水巻町伊左座', '40', '40382', '8070056', '福岡県', 'フクオカケン', '遠賀郡水巻町', 'オンガグンミズマキマチ', '伊左座', 'イサザ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区上の原', '40', '40109', '8070071', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '上の原', 'ウエノハル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区上上津役', '40', '40109', '8070072', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '上上津役', 'カミコウジャク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区町上津役東', '40', '40109', '8070073', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '町上津役東', 'マチコウジャクヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区町上津役西', '40', '40109', '8070074', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '町上津役西', 'マチコウジャクニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区下上津役', '40', '40109', '8070075', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '下上津役', 'シモコウジャク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区下上津役元町', '40', '40109', '8070076', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '下上津役元町', 'シモコウジャクモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区沖田', '40', '40109', '8070077', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '沖田', 'オキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区中の原', '40', '40109', '8070078', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '中の原', 'ナカノハル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区小嶺', '40', '40109', '8070081', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '小嶺', 'コミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区小嶺台', '40', '40109', '8070082', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '小嶺台', 'コミネダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区大平', '40', '40109', '8070083', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '大平', 'オオヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区大平台', '40', '40109', '8070084', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '大平台', 'オオヒラダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区塔野', '40', '40109', '8070085', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '塔野', 'トウノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県遠賀郡芦屋町', '40', '40381', '8070100', '福岡県', 'フクオカケン', '遠賀郡芦屋町', 'オンガグンアシヤマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('103668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県遠賀郡芦屋町幸町', '40', '40381', '8070101', '福岡県', 'フクオカケン', '遠賀郡芦屋町', 'オンガグンアシヤマチ', '幸町', 'サイワイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県遠賀郡芦屋町西浜町', '40', '40381', '8070102', '福岡県', 'フクオカケン', '遠賀郡芦屋町', 'オンガグンアシヤマチ', '西浜町', 'ニシハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県遠賀郡芦屋町白浜町', '40', '40381', '8070111', '福岡県', 'フクオカケン', '遠賀郡芦屋町', 'オンガグンアシヤマチ', '白浜町', 'シラハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県遠賀郡芦屋町正門町', '40', '40381', '8070112', '福岡県', 'フクオカケン', '遠賀郡芦屋町', 'オンガグンアシヤマチ', '正門町', 'セイモンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県遠賀郡芦屋町中ノ浜', '40', '40381', '8070113', '福岡県', 'フクオカケン', '遠賀郡芦屋町', 'オンガグンアシヤマチ', '中ノ浜', 'ナカノハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県遠賀郡芦屋町船頭町', '40', '40381', '8070121', '福岡県', 'フクオカケン', '遠賀郡芦屋町', 'オンガグンアシヤマチ', '船頭町', 'センドウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県遠賀郡芦屋町高浜町', '40', '40381', '8070122', '福岡県', 'フクオカケン', '遠賀郡芦屋町', 'オンガグンアシヤマチ', '高浜町', 'タカハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県遠賀郡芦屋町祇園町', '40', '40381', '8070123', '福岡県', 'フクオカケン', '遠賀郡芦屋町', 'オンガグンアシヤマチ', '祇園町', 'ギオンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県遠賀郡芦屋町緑ケ丘', '40', '40381', '8070131', '福岡県', 'フクオカケン', '遠賀郡芦屋町', 'オンガグンアシヤマチ', '緑ケ丘', 'ミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県遠賀郡芦屋町浜口町', '40', '40381', '8070132', '福岡県', 'フクオカケン', '遠賀郡芦屋町', 'オンガグンアシヤマチ', '浜口町', 'ハマグチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県遠賀郡芦屋町芦屋', '40', '40381', '8070133', '福岡県', 'フクオカケン', '遠賀郡芦屋町', 'オンガグンアシヤマチ', '芦屋', 'アシヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県遠賀郡芦屋町山鹿', '40', '40381', '8070141', '福岡県', 'フクオカケン', '遠賀郡芦屋町', 'オンガグンアシヤマチ', '山鹿', 'ヤマガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県遠賀郡芦屋町江川台', '40', '40381', '8070142', '福岡県', 'フクオカケン', '遠賀郡芦屋町', 'オンガグンアシヤマチ', '江川台', 'エガワダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県遠賀郡芦屋町花美坂', '40', '40381', '8070143', '福岡県', 'フクオカケン', '遠賀郡芦屋町', 'オンガグンアシヤマチ', '花美坂', 'ハナミザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区本城', '40', '40109', '8070801', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '本城', 'ホンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区力丸町', '40', '40109', '8070802', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '力丸町', 'リキマルマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区千代ケ崎', '40', '40109', '8070803', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '千代ケ崎', 'チヨガサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区医生ケ丘', '40', '40109', '8070804', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '医生ケ丘', 'イセイガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区光貞台', '40', '40109', '8070805', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '光貞台', 'ミツサダダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区御開', '40', '40109', '8070806', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '御開', 'オヒラキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区本城学研台', '40', '40109', '8070807', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '本城学研台', 'ホンジョウガッケンダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区洞北町', '40', '40109', '8070811', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '洞北町', 'ドウホクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区洞南町', '40', '40109', '8070812', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '洞南町', 'クキナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区夕原町', '40', '40109', '8070813', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '夕原町', 'ユウバルマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区貴船台', '40', '40109', '8070814', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '貴船台', 'キフネダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区本城東', '40', '40109', '8070815', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '本城東', 'ホンジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区陣原', '40', '40109', '8070821', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '陣原', 'ジンノハル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区瀬板', '40', '40109', '8070822', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '瀬板', 'セイタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区中須', '40', '40109', '8070823', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '中須', 'ナカス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区光明', '40', '40109', '8070824', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '光明', 'コウミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区折尾', '40', '40109', '8070825', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '折尾', 'オリオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区丸尾町', '40', '40109', '8070826', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '丸尾町', 'マルオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区楠木', '40', '40109', '8070827', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '楠木', 'クスノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区友田', '40', '40109', '8070828', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '友田', 'トモダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区星和町', '40', '40109', '8070829', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '星和町', 'セイワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区則松', '40', '40109', '8070831', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '則松', 'ノリマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区東筑', '40', '40109', '8070832', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '東筑', 'トウチク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区南鷹見町', '40', '40109', '8070833', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '南鷹見町', 'ミナミタカミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区北鷹見町', '40', '40109', '8070834', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '北鷹見町', 'キタタカミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区東折尾町', '40', '40109', '8070835', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '東折尾町', 'ヒガシオリオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区長崎町', '40', '40109', '8070836', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '長崎町', 'ナガサキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区的場町', '40', '40109', '8070841', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '的場町', 'マトバマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区永犬丸東町', '40', '40109', '8070842', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '永犬丸東町', 'エイノマルヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区三ケ森', '40', '40109', '8070843', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '三ケ森', 'サンガモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区春日台', '40', '40109', '8070844', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '春日台', 'カスガダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区永犬丸南町', '40', '40109', '8070845', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '永犬丸南町', 'エイノマルミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区里中', '40', '40109', '8070846', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '里中', 'サトナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区美原町', '40', '40109', '8070847', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '美原町', 'ミハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区永犬丸', '40', '40109', '8070851', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '永犬丸', 'エイノマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区永犬丸西町', '40', '40109', '8070852', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '永犬丸西町', 'エイノマルニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区鷹見台', '40', '40109', '8070853', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '鷹見台', 'タカミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区泉ケ浦', '40', '40109', '8070854', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '泉ケ浦', 'イズミガウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区松寿山', '40', '40109', '8070855', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '松寿山', 'ショウジュサン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区八枝', '40', '40109', '8070856', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '八枝', 'ヤツエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区北筑', '40', '40109', '8070857', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '北筑', 'ホクチク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区堀川町', '40', '40109', '8070861', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '堀川町', 'ホリカワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区西折尾町', '40', '40109', '8070862', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '西折尾町', 'ニシオリオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区大膳', '40', '40109', '8070863', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '大膳', 'ダイゼン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区折尾', '40', '40109', '8070864', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '折尾', 'オリオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区美吉野町', '40', '40109', '8070865', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '美吉野町', 'ミヨシノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区日吉台', '40', '40109', '8070866', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '日吉台', 'ヒヨシダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区自由ケ丘', '40', '40109', '8070867', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '自由ケ丘', 'ジユウガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区さつき台', '40', '40109', '8070868', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', 'さつき台', 'サツキダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区浅川学園台', '40', '40109', '8070871', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '浅川学園台', 'アサカワガクエンダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区浅川', '40', '40109', '8070872', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '浅川', 'アサカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区藤原', '40', '40109', '8070873', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '藤原', 'フジワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区大浦', '40', '40109', '8070874', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '大浦', 'オオウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区浅川台', '40', '40109', '8070875', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '浅川台', 'アサカワダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区浅川日の峯', '40', '40109', '8070876', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '浅川日の峯', 'アサカワヒノミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区浅川', '40', '40109', '8070877', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '浅川', 'アサカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区三ツ頭', '40', '40109', '8070878', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '三ツ頭', 'ミツガシラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区浅川町', '40', '40109', '8070879', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '浅川町', 'アサカワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区上香月', '40', '40109', '8071101', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '上香月', 'カミカツキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区香月中央', '40', '40109', '8071102', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '香月中央', 'カツキチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区香月西', '40', '40109', '8071103', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '香月西', 'カツキニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区船越', '40', '40109', '8071111', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '船越', 'フナコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区千代', '40', '40109', '8071112', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '千代', 'チヨ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区白岩町', '40', '40109', '8071113', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '白岩町', 'シライワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区吉祥寺町', '40', '40109', '8071114', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '吉祥寺町', 'キッショウジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区椋枝', '40', '40109', '8071115', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '椋枝', 'ムクエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区石坂', '40', '40109', '8071121', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '石坂', 'イシサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区東石坂町', '40', '40109', '8071122', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '東石坂町', 'ヒガシイシザカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区下畑町', '40', '40109', '8071123', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '下畑町', 'シモハタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区畑', '40', '40109', '8071124', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '畑', 'ハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区池田', '40', '40109', '8071125', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '池田', 'イケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区馬場山東', '40', '40109', '8071131', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '馬場山東', 'ババヤマヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区馬場山西', '40', '40109', '8071132', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '馬場山西', 'ババヤマニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区馬場山緑', '40', '40109', '8071133', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '馬場山緑', 'ババヤマミドリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区茶屋の原', '40', '40109', '8071134', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '茶屋の原', 'チャヤノハル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区馬場山原', '40', '40109', '8071135', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '馬場山原', 'ババヤマハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区馬場山', '40', '40109', '8071136', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '馬場山', 'ババヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区楠橋上方', '40', '40109', '8071141', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '楠橋上方', 'クスバシカミカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区楠橋東', '40', '40109', '8071142', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '楠橋東', 'クスバシヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区楠橋南', '40', '40109', '8071143', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '楠橋南', 'クスバシミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区真名子', '40', '40109', '8071144', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '真名子', 'マナゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区楠橋西', '40', '40109', '8071145', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '楠橋西', 'クスバシニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区楠橋下方', '40', '40109', '8071146', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '楠橋下方', 'クスバシシモカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区楠橋', '40', '40109', '8071151', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '楠橋', 'クスバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区高江', '40', '40109', '8071152', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '高江', 'タカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区岩崎', '40', '40109', '8071153', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '岩崎', 'イワサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区楠北', '40', '40109', '8071154', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '楠北', 'クスキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区木屋瀬', '40', '40109', '8071261', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '木屋瀬', 'コヤノセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区野面', '40', '40109', '8071262', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '野面', 'ノブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区金剛', '40', '40109', '8071263', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '金剛', 'コンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区星ケ丘', '40', '40109', '8071264', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '星ケ丘', 'ホシガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市八幡西区笹田', '40', '40109', '8071265', '福岡県', 'フクオカケン', '北九州市八幡西区', 'キタキュウシュウシヤハタニシク', '笹田', 'ササダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県鞍手郡鞍手町', '40', '40402', '8071300', '福岡県', 'フクオカケン', '鞍手郡鞍手町', 'クラテグンクラテマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('103777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県鞍手郡鞍手町猪倉', '40', '40402', '8071301', '福岡県', 'フクオカケン', '鞍手郡鞍手町', 'クラテグンクラテマチ', '猪倉', 'イノクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県鞍手郡鞍手町上木月', '40', '40402', '8071302', '福岡県', 'フクオカケン', '鞍手郡鞍手町', 'クラテグンクラテマチ', '上木月', 'カミキヅキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県鞍手郡鞍手町木月', '40', '40402', '8071303', '福岡県', 'フクオカケン', '鞍手郡鞍手町', 'クラテグンクラテマチ', '木月', 'キヅキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県鞍手郡鞍手町永谷', '40', '40402', '8071304', '福岡県', 'フクオカケン', '鞍手郡鞍手町', 'クラテグンクラテマチ', '永谷', 'ナガタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県鞍手郡鞍手町新延', '40', '40402', '8071305', '福岡県', 'フクオカケン', '鞍手郡鞍手町', 'クラテグンクラテマチ', '新延', 'ニノブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県鞍手郡鞍手町古門', '40', '40402', '8071306', '福岡県', 'フクオカケン', '鞍手郡鞍手町', 'クラテグンクラテマチ', '古門', 'フルモン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県鞍手郡鞍手町室木', '40', '40402', '8071307', '福岡県', 'フクオカケン', '鞍手郡鞍手町', 'クラテグンクラテマチ', '室木', 'ムロキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県鞍手郡鞍手町八尋', '40', '40402', '8071308', '福岡県', 'フクオカケン', '鞍手郡鞍手町', 'クラテグンクラテマチ', '八尋', 'ヤヒロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県鞍手郡鞍手町小牧', '40', '40402', '8071311', '福岡県', 'フクオカケン', '鞍手郡鞍手町', 'クラテグンクラテマチ', '小牧', 'オマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県鞍手郡鞍手町中山', '40', '40402', '8071312', '福岡県', 'フクオカケン', '鞍手郡鞍手町', 'クラテグンクラテマチ', '中山', 'ナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県鞍手郡鞍手町新北', '40', '40402', '8071313', '福岡県', 'フクオカケン', '鞍手郡鞍手町', 'クラテグンクラテマチ', '新北', 'ニギタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県鞍手郡鞍手町長谷', '40', '40402', '8071314', '福岡県', 'フクオカケン', '鞍手郡鞍手町', 'クラテグンクラテマチ', '長谷', 'ハセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県鞍手郡鞍手町弥生', '40', '40402', '8071315', '福岡県', 'フクオカケン', '鞍手郡鞍手町', 'クラテグンクラテマチ', '弥生', 'ヤヨイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市若松区', '40', '40103', '8080000', '福岡県', 'フクオカケン', '北九州市若松区', 'キタキュウシュウシワカマツク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('103797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市若松区小石本村町', '40', '40103', '8080001', '福岡県', 'フクオカケン', '北九州市若松区', 'キタキュウシュウシワカマツク', '小石本村町', 'コイシホンムラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市若松区向洋町', '40', '40103', '8080002', '福岡県', 'フクオカケン', '北九州市若松区', 'キタキュウシュウシワカマツク', '向洋町', 'コウヨウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市若松区赤崎町', '40', '40103', '8080003', '福岡県', 'フクオカケン', '北九州市若松区', 'キタキュウシュウシワカマツク', '赤崎町', 'アカサキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市若松区西小石町', '40', '40103', '8080004', '福岡県', 'フクオカケン', '北九州市若松区', 'キタキュウシュウシワカマツク', '西小石町', 'ニシコイシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市若松区下原町', '40', '40103', '8080005', '福岡県', 'フクオカケン', '北九州市若松区', 'キタキュウシュウシワカマツク', '下原町', 'シモハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市若松区宮前町', '40', '40103', '8080006', '福岡県', 'フクオカケン', '北九州市若松区', 'キタキュウシュウシワカマツク', '宮前町', 'ミヤマエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市若松区小石', '40', '40103', '8080007', '福岡県', 'フクオカケン', '北九州市若松区', 'キタキュウシュウシワカマツク', '小石', 'コイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市若松区小竹', '40', '40103', '8080008', '福岡県', 'フクオカケン', '北九州市若松区', 'キタキュウシュウシワカマツク', '小竹', 'オダケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市若松区小竹相川', '40', '40103', '8080008', '福岡県', 'フクオカケン', '北九州市若松区', 'キタキュウシュウシワカマツク', '小竹', 'オダケ', null, null, '相川', 'アイカワ');
INSERT INTO `ms_addresses` VALUES ('103806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市若松区小竹鬼ケ坂', '40', '40103', '8080008', '福岡県', 'フクオカケン', '北九州市若松区', 'キタキュウシュウシワカマツク', '小竹', 'オダケ', null, null, '鬼ケ坂', 'オニガサカ');
INSERT INTO `ms_addresses` VALUES ('103807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市若松区小竹唐木', '40', '40103', '8080008', '福岡県', 'フクオカケン', '北九州市若松区', 'キタキュウシュウシワカマツク', '小竹', 'オダケ', null, null, '唐木', 'カラキ');
INSERT INTO `ms_addresses` VALUES ('103808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市若松区小竹椿', '40', '40103', '8080008', '福岡県', 'フクオカケン', '北九州市若松区', 'キタキュウシュウシワカマツク', '小竹', 'オダケ', null, null, '椿', 'ツバキ');
INSERT INTO `ms_addresses` VALUES ('103809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市若松区小竹脇ノ浦', '40', '40103', '8080008', '福岡県', 'フクオカケン', '北九州市若松区', 'キタキュウシュウシワカマツク', '小竹', 'オダケ', null, null, '脇ノ浦', 'ワキノウラ');
INSERT INTO `ms_addresses` VALUES ('103810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市若松区響南町', '40', '40103', '8080011', '福岡県', 'フクオカケン', '北九州市若松区', 'キタキュウシュウシワカマツク', '響南町', 'キョウナンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市若松区深町', '40', '40103', '8080012', '福岡県', 'フクオカケン', '北九州市若松区', 'キタキュウシュウシワカマツク', '深町', 'フカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市若松区波打町', '40', '40103', '8080013', '福岡県', 'フクオカケン', '北九州市若松区', 'キタキュウシュウシワカマツク', '波打町', 'ナミウチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市若松区栄盛川町', '40', '40103', '8080014', '福岡県', 'フクオカケン', '北九州市若松区', 'キタキュウシュウシワカマツク', '栄盛川町', 'エイセイガワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市若松区上原町', '40', '40103', '8080015', '福岡県', 'フクオカケン', '北九州市若松区', 'キタキュウシュウシワカマツク', '上原町', 'カミハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市若松区原町', '40', '40103', '8080016', '福岡県', 'フクオカケン', '北九州市若松区', 'キタキュウシュウシワカマツク', '原町', 'ハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市若松区東小石町', '40', '40103', '8080017', '福岡県', 'フクオカケン', '北九州市若松区', 'キタキュウシュウシワカマツク', '東小石町', 'ヒガシコイシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市若松区響町', '40', '40103', '8080021', '福岡県', 'フクオカケン', '北九州市若松区', 'キタキュウシュウシワカマツク', '響町', 'ヒビキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市若松区安瀬', '40', '40103', '8080022', '福岡県', 'フクオカケン', '北九州市若松区', 'キタキュウシュウシワカマツク', '安瀬', 'アンセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市若松区北浜', '40', '40103', '8080023', '福岡県', 'フクオカケン', '北九州市若松区', 'キタキュウシュウシワカマツク', '北浜', 'キタハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市若松区浜町', '40', '40103', '8080024', '福岡県', 'フクオカケン', '北九州市若松区', 'キタキュウシュウシワカマツク', '浜町', 'ハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市若松区中川町', '40', '40103', '8080025', '福岡県', 'フクオカケン', '北九州市若松区', 'キタキュウシュウシワカマツク', '中川町', 'ナカガワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市若松区桜町', '40', '40103', '8080026', '福岡県', 'フクオカケン', '北九州市若松区', 'キタキュウシュウシワカマツク', '桜町', 'サクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市若松区北湊町', '40', '40103', '8080027', '福岡県', 'フクオカケン', '北九州市若松区', 'キタキュウシュウシワカマツク', '北湊町', 'キタミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市若松区西園町', '40', '40103', '8080031', '福岡県', 'フクオカケン', '北九州市若松区', 'キタキュウシュウシワカマツク', '西園町', 'ニシゾノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市若松区老松', '40', '40103', '8080032', '福岡県', 'フクオカケン', '北九州市若松区', 'キタキュウシュウシワカマツク', '老松', 'オイマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市若松区大井戸町', '40', '40103', '8080033', '福岡県', 'フクオカケン', '北九州市若松区', 'キタキュウシュウシワカマツク', '大井戸町', 'オオイドマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市若松区本町', '40', '40103', '8080034', '福岡県', 'フクオカケン', '北九州市若松区', 'キタキュウシュウシワカマツク', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市若松区白山', '40', '40103', '8080035', '福岡県', 'フクオカケン', '北九州市若松区', 'キタキュウシュウシワカマツク', '白山', 'ハクサン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市若松区山手町', '40', '40103', '8080036', '福岡県', 'フクオカケン', '北九州市若松区', 'キタキュウシュウシワカマツク', '山手町', 'ヤマテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市若松区迫田町', '40', '40103', '8080041', '福岡県', 'フクオカケン', '北九州市若松区', 'キタキュウシュウシワカマツク', '迫田町', 'サコダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市若松区棚田町', '40', '40103', '8080042', '福岡県', 'フクオカケン', '北九州市若松区', 'キタキュウシュウシワカマツク', '棚田町', 'タナダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市若松区西畑町', '40', '40103', '8080043', '福岡県', 'フクオカケン', '北九州市若松区', 'キタキュウシュウシワカマツク', '西畑町', 'ニシハタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市若松区東畑町', '40', '40103', '8080044', '福岡県', 'フクオカケン', '北九州市若松区', 'キタキュウシュウシワカマツク', '東畑町', 'ヒガシハタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市若松区山ノ堂町', '40', '40103', '8080045', '福岡県', 'フクオカケン', '北九州市若松区', 'キタキュウシュウシワカマツク', '山ノ堂町', 'ヤマノドウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市若松区小糸町', '40', '40103', '8080046', '福岡県', 'フクオカケン', '北九州市若松区', 'キタキュウシュウシワカマツク', '小糸町', 'コイトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市若松区中畑町', '40', '40103', '8080047', '福岡県', 'フクオカケン', '北九州市若松区', 'キタキュウシュウシワカマツク', '中畑町', 'ナカハタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市若松区大谷町', '40', '40103', '8080051', '福岡県', 'フクオカケン', '北九州市若松区', 'キタキュウシュウシワカマツク', '大谷町', 'オオタニマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市若松区新大谷町', '40', '40103', '8080052', '福岡県', 'フクオカケン', '北九州市若松区', 'キタキュウシュウシワカマツク', '新大谷町', 'シンオオタニマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市若松区修多羅', '40', '40103', '8080053', '福岡県', 'フクオカケン', '北九州市若松区', 'キタキュウシュウシワカマツク', '修多羅', 'スタラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市若松区久岐の浜', '40', '40103', '8080054', '福岡県', 'フクオカケン', '北九州市若松区', 'キタキュウシュウシワカマツク', '久岐の浜', 'クキノハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市若松区畑谷町', '40', '40103', '8080055', '福岡県', 'フクオカケン', '北九州市若松区', 'キタキュウシュウシワカマツク', '畑谷町', 'ハタダニマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市若松区大池町', '40', '40103', '8080061', '福岡県', 'フクオカケン', '北九州市若松区', 'キタキュウシュウシワカマツク', '大池町', 'オオイケマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市若松区古前', '40', '40103', '8080062', '福岡県', 'フクオカケン', '北九州市若松区', 'キタキュウシュウシワカマツク', '古前', 'フルマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市若松区和田町', '40', '40103', '8080063', '福岡県', 'フクオカケン', '北九州市若松区', 'キタキュウシュウシワカマツク', '和田町', 'ワダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市若松区宮丸', '40', '40103', '8080064', '福岡県', 'フクオカケン', '北九州市若松区', 'キタキュウシュウシワカマツク', '宮丸', 'ミヤマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市若松区藤木', '40', '40103', '8080065', '福岡県', 'フクオカケン', '北九州市若松区', 'キタキュウシュウシワカマツク', '藤木', 'フジノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市若松区今光', '40', '40103', '8080071', '福岡県', 'フクオカケン', '北九州市若松区', 'キタキュウシュウシワカマツク', '今光', 'イマミツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市若松区百合野町', '40', '40103', '8080072', '福岡県', 'フクオカケン', '北九州市若松区', 'キタキュウシュウシワカマツク', '百合野町', 'ユリノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市若松区赤島町', '40', '40103', '8080073', '福岡県', 'フクオカケン', '北九州市若松区', 'キタキュウシュウシワカマツク', '赤島町', 'アカシママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市若松区藤ノ木', '40', '40103', '8080074', '福岡県', 'フクオカケン', '北九州市若松区', 'キタキュウシュウシワカマツク', '藤ノ木', 'フジノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市若松区赤岩町', '40', '40103', '8080075', '福岡県', 'フクオカケン', '北九州市若松区', 'キタキュウシュウシワカマツク', '赤岩町', 'アカイワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市若松区童子丸', '40', '40103', '8080076', '福岡県', 'フクオカケン', '北九州市若松区', 'キタキュウシュウシワカマツク', '童子丸', 'ドウジマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市若松区用勺町', '40', '40103', '8080077', '福岡県', 'フクオカケン', '北九州市若松区', 'キタキュウシュウシワカマツク', '用勺町', 'ヨウジャクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市若松区西天神町', '40', '40103', '8080101', '福岡県', 'フクオカケン', '北九州市若松区', 'キタキュウシュウシワカマツク', '西天神町', 'ニシテンジンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市若松区東二島', '40', '40103', '8080102', '福岡県', 'フクオカケン', '北九州市若松区', 'キタキュウシュウシワカマツク', '東二島', 'ヒガシフタジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市若松区二島', '40', '40103', '8080103', '福岡県', 'フクオカケン', '北九州市若松区', 'キタキュウシュウシワカマツク', '二島', 'フタジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市若松区畠田', '40', '40103', '8080104', '福岡県', 'フクオカケン', '北九州市若松区', 'キタキュウシュウシワカマツク', '畠田', 'ハタケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市若松区鴨生田', '40', '40103', '8080105', '福岡県', 'フクオカケン', '北九州市若松区', 'キタキュウシュウシワカマツク', '鴨生田', 'カモオダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市若松区片山', '40', '40103', '8080106', '福岡県', 'フクオカケン', '北九州市若松区', 'キタキュウシュウシワカマツク', '片山', 'カタヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市若松区小竹', '40', '40103', '8080108', '福岡県', 'フクオカケン', '北九州市若松区', 'キタキュウシュウシワカマツク', '小竹', 'オダケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市若松区南二島', '40', '40103', '8080109', '福岡県', 'フクオカケン', '北九州市若松区', 'キタキュウシュウシワカマツク', '南二島', 'ミナミフタジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市若松区柳崎町', '40', '40103', '8080111', '福岡県', 'フクオカケン', '北九州市若松区', 'キタキュウシュウシワカマツク', '柳崎町', 'ヤナガサキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市若松区頓田', '40', '40103', '8080112', '福岡県', 'フクオカケン', '北九州市若松区', 'キタキュウシュウシワカマツク', '頓田', 'トンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市若松区払川', '40', '40103', '8080113', '福岡県', 'フクオカケン', '北九州市若松区', 'キタキュウシュウシワカマツク', '払川', 'ハライガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市若松区竹並', '40', '40103', '8080121', '福岡県', 'フクオカケン', '北九州市若松区', 'キタキュウシュウシワカマツク', '竹並', 'タケナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市若松区蜑住', '40', '40103', '8080122', '福岡県', 'フクオカケン', '北九州市若松区', 'キタキュウシュウシワカマツク', '蜑住', 'アマスミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市若松区有毛', '40', '40103', '8080123', '福岡県', 'フクオカケン', '北九州市若松区', 'キタキュウシュウシワカマツク', '有毛', 'アリゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市若松区安屋', '40', '40103', '8080124', '福岡県', 'フクオカケン', '北九州市若松区', 'キタキュウシュウシワカマツク', '安屋', 'アンヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市若松区塩屋', '40', '40103', '8080131', '福岡県', 'フクオカケン', '北九州市若松区', 'キタキュウシュウシワカマツク', '塩屋', 'シオヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市若松区小敷', '40', '40103', '8080132', '福岡県', 'フクオカケン', '北九州市若松区', 'キタキュウシュウシワカマツク', '小敷', 'コシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市若松区大鳥居', '40', '40103', '8080133', '福岡県', 'フクオカケン', '北九州市若松区', 'キタキュウシュウシワカマツク', '大鳥居', 'オオトリイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市若松区乙丸', '40', '40103', '8080134', '福岡県', 'フクオカケン', '北九州市若松区', 'キタキュウシュウシワカマツク', '乙丸', 'オトマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市若松区ひびきの', '40', '40103', '8080135', '福岡県', 'フクオカケン', '北九州市若松区', 'キタキュウシュウシワカマツク', 'ひびきの', 'ヒビキノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市若松区花野路', '40', '40103', '8080136', '福岡県', 'フクオカケン', '北九州市若松区', 'キタキュウシュウシワカマツク', '花野路', 'ハナノジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市若松区ひびきの南', '40', '40103', '8080137', '福岡県', 'フクオカケン', '北九州市若松区', 'キタキュウシュウシワカマツク', 'ひびきの南', 'ヒビキノミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市若松区ひびきの北', '40', '40103', '8080138', '福岡県', 'フクオカケン', '北九州市若松区', 'キタキュウシュウシワカマツク', 'ひびきの北', 'ヒビキノキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市若松区小敷ひびきの', '40', '40103', '8080139', '福岡県', 'フクオカケン', '北九州市若松区', 'キタキュウシュウシワカマツク', '小敷ひびきの', 'コシキヒビキノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市若松区青葉台東', '40', '40103', '8080141', '福岡県', 'フクオカケン', '北九州市若松区', 'キタキュウシュウシワカマツク', '青葉台東', 'アオバダイヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市若松区青葉台南', '40', '40103', '8080142', '福岡県', 'フクオカケン', '北九州市若松区', 'キタキュウシュウシワカマツク', '青葉台南', 'アオバダイミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市若松区青葉台西', '40', '40103', '8080143', '福岡県', 'フクオカケン', '北九州市若松区', 'キタキュウシュウシワカマツク', '青葉台西', 'アオバダイニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市若松区高須東', '40', '40103', '8080144', '福岡県', 'フクオカケン', '北九州市若松区', 'キタキュウシュウシワカマツク', '高須東', 'タカスヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市若松区高須南', '40', '40103', '8080145', '福岡県', 'フクオカケン', '北九州市若松区', 'キタキュウシュウシワカマツク', '高須南', 'タカスミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市若松区高須西', '40', '40103', '8080146', '福岡県', 'フクオカケン', '北九州市若松区', 'キタキュウシュウシワカマツク', '高須西', 'タカスニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市若松区高須北', '40', '40103', '8080147', '福岡県', 'フクオカケン', '北九州市若松区', 'キタキュウシュウシワカマツク', '高須北', 'タカスキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市若松区高須', '40', '40103', '8080148', '福岡県', 'フクオカケン', '北九州市若松区', 'キタキュウシュウシワカマツク', '高須', 'タカス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県北九州市若松区赤岩町', '40', '40103', '8080175', '福岡県', 'フクオカケン', '北九州市若松区', 'キタキュウシュウシワカマツク', '赤岩町', 'アカイワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県中間市', '40', '40215', '8090000', '福岡県', 'フクオカケン', '中間市', 'ナカマシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('103932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県中間市垣生', '40', '40215', '8090001', '福岡県', 'フクオカケン', '中間市', 'ナカマシ', '垣生', 'ハブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県中間市中底井野', '40', '40215', '8090002', '福岡県', 'フクオカケン', '中間市', 'ナカマシ', '中底井野', 'ナカソコイノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県中間市上底井野', '40', '40215', '8090003', '福岡県', 'フクオカケン', '中間市', 'ナカマシ', '上底井野', 'カミソコイノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県中間市下大隈', '40', '40215', '8090004', '福岡県', 'フクオカケン', '中間市', 'ナカマシ', '下大隈', 'シモオオクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県中間市岩瀬', '40', '40215', '8090011', '福岡県', 'フクオカケン', '中間市', 'ナカマシ', '岩瀬', 'イワセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県中間市下蓮花寺', '40', '40215', '8090012', '福岡県', 'フクオカケン', '中間市', 'ナカマシ', '下蓮花寺', 'シモレンゲジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県中間市上蓮花寺', '40', '40215', '8090013', '福岡県', 'フクオカケン', '中間市', 'ナカマシ', '上蓮花寺', 'カミレンゲジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県中間市蓮花寺', '40', '40215', '8090014', '福岡県', 'フクオカケン', '中間市', 'ナカマシ', '蓮花寺', 'レンゲジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県中間市太賀', '40', '40215', '8090015', '福岡県', 'フクオカケン', '中間市', 'ナカマシ', '太賀', 'タガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県中間市星ケ丘', '40', '40215', '8090016', '福岡県', 'フクオカケン', '中間市', 'ナカマシ', '星ケ丘', 'ホシガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県中間市桜台', '40', '40215', '8090017', '福岡県', 'フクオカケン', '中間市', 'ナカマシ', '桜台', 'サクラダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県中間市通谷', '40', '40215', '8090018', '福岡県', 'フクオカケン', '中間市', 'ナカマシ', '通谷', 'トオリタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県中間市東中間', '40', '40215', '8090019', '福岡県', 'フクオカケン', '中間市', 'ナカマシ', '東中間', 'ヒガシナカマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県中間市朝霧', '40', '40215', '8090021', '福岡県', 'フクオカケン', '中間市', 'ナカマシ', '朝霧', 'アサギリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県中間市鍋山町', '40', '40215', '8090022', '福岡県', 'フクオカケン', '中間市', 'ナカマシ', '鍋山町', 'ナベヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県中間市扇ケ浦', '40', '40215', '8090023', '福岡県', 'フクオカケン', '中間市', 'ナカマシ', '扇ケ浦', 'オウギガウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県中間市池田', '40', '40215', '8090024', '福岡県', 'フクオカケン', '中間市', 'ナカマシ', '池田', 'イケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県中間市深坂', '40', '40215', '8090025', '福岡県', 'フクオカケン', '中間市', 'ナカマシ', '深坂', 'フカサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県中間市大辻町', '40', '40215', '8090026', '福岡県', 'フクオカケン', '中間市', 'ナカマシ', '大辻町', 'オオツジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県中間市七重町', '40', '40215', '8090027', '福岡県', 'フクオカケン', '中間市', 'ナカマシ', '七重町', 'ナナエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県中間市弥生', '40', '40215', '8090028', '福岡県', 'フクオカケン', '中間市', 'ナカマシ', '弥生', 'ヤヨイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県中間市中央', '40', '40215', '8090030', '福岡県', 'フクオカケン', '中間市', 'ナカマシ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県中間市小田ケ浦', '40', '40215', '8090031', '福岡県', 'フクオカケン', '中間市', 'ナカマシ', '小田ケ浦', 'オダガウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県中間市中尾', '40', '40215', '8090032', '福岡県', 'フクオカケン', '中間市', 'ナカマシ', '中尾', 'ナカオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県中間市土手ノ内', '40', '40215', '8090033', '福岡県', 'フクオカケン', '中間市', 'ナカマシ', '土手ノ内', 'ドテノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県中間市中間', '40', '40215', '8090034', '福岡県', 'フクオカケン', '中間市', 'ナカマシ', '中間', 'ナカマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県中間市松ケ岡', '40', '40215', '8090035', '福岡県', 'フクオカケン', '中間市', 'ナカマシ', '松ケ岡', 'マツガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県中間市長津', '40', '40215', '8090036', '福岡県', 'フクオカケン', '中間市', 'ナカマシ', '長津', 'ナガツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県中間市中鶴', '40', '40215', '8090037', '福岡県', 'フクオカケン', '中間市', 'ナカマシ', '中鶴', 'ナカヅル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県中間市浄花町', '40', '40215', '8090038', '福岡県', 'フクオカケン', '中間市', 'ナカマシ', '浄花町', 'ジョウカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県中間市大根土', '40', '40215', '8090039', '福岡県', 'フクオカケン', '中間市', 'ナカマシ', '大根土', 'オオネト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県中間市岩瀬西町', '40', '40215', '8090041', '福岡県', 'フクオカケン', '中間市', 'ナカマシ', '岩瀬西町', 'イワセニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡新得町', '01', '01635', '0810000', '北海道', 'ホッカイドウ', '上川郡新得町', 'カミカワグンシントクチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('103966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市中央区', '40', '40133', '8100000', '福岡県', 'フクオカケン', '福岡市中央区', 'フクオカシチュウオウク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('103967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市中央区天神', '40', '40133', '8100001', '福岡県', 'フクオカケン', '福岡市中央区', 'フクオカシチュウオウク', '天神', 'テンジン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市中央区西中洲', '40', '40133', '8100002', '福岡県', 'フクオカケン', '福岡市中央区', 'フクオカシチュウオウク', '西中洲', 'ニシナカス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市中央区春吉', '40', '40133', '8100003', '福岡県', 'フクオカケン', '福岡市中央区', 'フクオカシチュウオウク', '春吉', 'ハルヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市中央区渡辺通', '40', '40133', '8100004', '福岡県', 'フクオカケン', '福岡市中央区', 'フクオカシチュウオウク', '渡辺通', 'ワタナベドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市中央区清川', '40', '40133', '8100005', '福岡県', 'フクオカケン', '福岡市中央区', 'フクオカシチュウオウク', '清川', 'キヨカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡新得町1条北', '01', '01635', '0810001', '北海道', 'ホッカイドウ', '上川郡新得町', 'カミカワグンシントクチョウ', '1条北', '01ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市中央区高砂', '40', '40133', '8100011', '福岡県', 'フクオカケン', '福岡市中央区', 'フクオカシチュウオウク', '高砂', 'タカサゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市中央区白金', '40', '40133', '8100012', '福岡県', 'フクオカケン', '福岡市中央区', 'フクオカシチュウオウク', '白金', 'シロガネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市中央区大宮', '40', '40133', '8100013', '福岡県', 'フクオカケン', '福岡市中央区', 'フクオカシチュウオウク', '大宮', 'オオミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市中央区平尾', '40', '40133', '8100014', '福岡県', 'フクオカケン', '福岡市中央区', 'フクオカシチュウオウク', '平尾', 'ヒラオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市中央区那の川', '40', '40133', '8100015', '福岡県', 'フクオカケン', '福岡市中央区', 'フクオカシチュウオウク', '那の川', 'ナノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市中央区平和', '40', '40133', '8100016', '福岡県', 'フクオカケン', '福岡市中央区', 'フクオカシチュウオウク', '平和', 'ヘイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市中央区平丘町', '40', '40133', '8100017', '福岡県', 'フクオカケン', '福岡市中央区', 'フクオカシチュウオウク', '平丘町', 'ヒラオカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市中央区山荘通', '40', '40133', '8100018', '福岡県', 'フクオカケン', '福岡市中央区', 'フクオカシチュウオウク', '山荘通', 'サンソウドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡新得町2条北', '01', '01635', '0810002', '北海道', 'ホッカイドウ', '上川郡新得町', 'カミカワグンシントクチョウ', '2条北', '02ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市中央区今泉', '40', '40133', '8100021', '福岡県', 'フクオカケン', '福岡市中央区', 'フクオカシチュウオウク', '今泉', 'イマイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市中央区薬院', '40', '40133', '8100022', '福岡県', 'フクオカケン', '福岡市中央区', 'フクオカシチュウオウク', '薬院', 'ヤクイン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市中央区警固', '40', '40133', '8100023', '福岡県', 'フクオカケン', '福岡市中央区', 'フクオカシチュウオウク', '警固', 'ケゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市中央区桜坂', '40', '40133', '8100024', '福岡県', 'フクオカケン', '福岡市中央区', 'フクオカシチュウオウク', '桜坂', 'サクラザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市中央区薬院伊福町', '40', '40133', '8100025', '福岡県', 'フクオカケン', '福岡市中央区', 'フクオカシチュウオウク', '薬院伊福町', 'ヤクインイフクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市中央区古小烏町', '40', '40133', '8100026', '福岡県', 'フクオカケン', '福岡市中央区', 'フクオカシチュウオウク', '古小烏町', 'フルコガラスマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市中央区御所ケ谷', '40', '40133', '8100027', '福岡県', 'フクオカケン', '福岡市中央区', 'フクオカシチュウオウク', '御所ケ谷', 'ゴショガダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市中央区浄水通', '40', '40133', '8100028', '福岡県', 'フクオカケン', '福岡市中央区', 'フクオカシチュウオウク', '浄水通', 'ジョウスイドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市中央区平尾浄水町', '40', '40133', '8100029', '福岡県', 'フクオカケン', '福岡市中央区', 'フクオカシチュウオウク', '平尾浄水町', 'ヒラオジョウスイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡新得町3条北', '01', '01635', '0810003', '北海道', 'ホッカイドウ', '上川郡新得町', 'カミカワグンシントクチョウ', '3条北', '03ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市中央区谷', '40', '40133', '8100031', '福岡県', 'フクオカケン', '福岡市中央区', 'フクオカシチュウオウク', '谷', 'タニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市中央区輝国', '40', '40133', '8100032', '福岡県', 'フクオカケン', '福岡市中央区', 'フクオカシチュウオウク', '輝国', 'テルクニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市中央区小笹', '40', '40133', '8100033', '福岡県', 'フクオカケン', '福岡市中央区', 'フクオカシチュウオウク', '小笹', 'オザサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市中央区笹丘', '40', '40133', '8100034', '福岡県', 'フクオカケン', '福岡市中央区', 'フクオカシチュウオウク', '笹丘', 'ササオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市中央区梅光園', '40', '40133', '8100035', '福岡県', 'フクオカケン', '福岡市中央区', 'フクオカシチュウオウク', '梅光園', 'バイコウエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市中央区梅光園団地', '40', '40133', '8100036', '福岡県', 'フクオカケン', '福岡市中央区', 'フクオカシチュウオウク', '梅光園団地', 'バイコウエンダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市中央区南公園', '40', '40133', '8100037', '福岡県', 'フクオカケン', '福岡市中央区', 'フクオカシチュウオウク', '南公園', 'ミナミコウエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('103999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市中央区大名', '40', '40133', '8100041', '福岡県', 'フクオカケン', '福岡市中央区', 'フクオカシチュウオウク', '大名', 'ダイミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市中央区赤坂', '40', '40133', '8100042', '福岡県', 'フクオカケン', '福岡市中央区', 'フクオカシチュウオウク', '赤坂', 'アカサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市中央区城内', '40', '40133', '8100043', '福岡県', 'フクオカケン', '福岡市中央区', 'フクオカシチュウオウク', '城内', 'ジョウナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市中央区六本松', '40', '40133', '8100044', '福岡県', 'フクオカケン', '福岡市中央区', 'フクオカシチュウオウク', '六本松', 'ロッポンマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市中央区草香江', '40', '40133', '8100045', '福岡県', 'フクオカケン', '福岡市中央区', 'フクオカシチュウオウク', '草香江', 'クサガエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡新得町本通北', '01', '01635', '0810005', '北海道', 'ホッカイドウ', '上川郡新得町', 'カミカワグンシントクチョウ', '本通北', 'ホンドオリキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市中央区大濠公園', '40', '40133', '8100051', '福岡県', 'フクオカケン', '福岡市中央区', 'フクオカシチュウオウク', '大濠公園', 'オオホリコウエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市中央区大濠', '40', '40133', '8100052', '福岡県', 'フクオカケン', '福岡市中央区', 'フクオカシチュウオウク', '大濠', 'オオホリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市中央区鳥飼', '40', '40133', '8100053', '福岡県', 'フクオカケン', '福岡市中央区', 'フクオカシチュウオウク', '鳥飼', 'トリカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市中央区今川', '40', '40133', '8100054', '福岡県', 'フクオカケン', '福岡市中央区', 'フクオカシチュウオウク', '今川', 'イマガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市中央区黒門', '40', '40133', '8100055', '福岡県', 'フクオカケン', '福岡市中央区', 'フクオカシチュウオウク', '黒門', 'クロモン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡新得町栄町', '01', '01635', '0810006', '北海道', 'ホッカイドウ', '上川郡新得町', 'カミカワグンシントクチョウ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市中央区西公園', '40', '40133', '8100061', '福岡県', 'フクオカケン', '福岡市中央区', 'フクオカシチュウオウク', '西公園', 'ニシコウエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市中央区荒戸', '40', '40133', '8100062', '福岡県', 'フクオカケン', '福岡市中央区', 'フクオカシチュウオウク', '荒戸', 'アラト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市中央区唐人町', '40', '40133', '8100063', '福岡県', 'フクオカケン', '福岡市中央区', 'フクオカシチュウオウク', '唐人町', 'トウジンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市中央区地行', '40', '40133', '8100064', '福岡県', 'フクオカケン', '福岡市中央区', 'フクオカシチュウオウク', '地行', 'ジギョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市中央区地行浜', '40', '40133', '8100065', '福岡県', 'フクオカケン', '福岡市中央区', 'フクオカシチュウオウク', '地行浜', 'ジギョウハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市中央区福浜', '40', '40133', '8100066', '福岡県', 'フクオカケン', '福岡市中央区', 'フクオカシチュウオウク', '福浜', 'フクハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市中央区伊崎', '40', '40133', '8100067', '福岡県', 'フクオカケン', '福岡市中央区', 'フクオカシチュウオウク', '伊崎', 'イザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡新得町元町', '01', '01635', '0810007', '北海道', 'ホッカイドウ', '上川郡新得町', 'カミカワグンシントクチョウ', '元町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市中央区那の津', '40', '40133', '8100071', '福岡県', 'フクオカケン', '福岡市中央区', 'フクオカシチュウオウク', '那の津', 'ナノツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市中央区長浜', '40', '40133', '8100072', '福岡県', 'フクオカケン', '福岡市中央区', 'フクオカシチュウオウク', '長浜', 'ナガハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市中央区舞鶴', '40', '40133', '8100073', '福岡県', 'フクオカケン', '福岡市中央区', 'フクオカシチュウオウク', '舞鶴', 'マイヅル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市中央区大手門', '40', '40133', '8100074', '福岡県', 'フクオカケン', '福岡市中央区', 'フクオカシチュウオウク', '大手門', 'オオテモン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市中央区港', '40', '40133', '8100075', '福岡県', 'フクオカケン', '福岡市中央区', 'フクオカシチュウオウク', '港', 'ミナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市中央区荒津', '40', '40133', '8100076', '福岡県', 'フクオカケン', '福岡市中央区', 'フクオカシチュウオウク', '荒津', 'アラツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡新得町本通南', '01', '01635', '0810008', '北海道', 'ホッカイドウ', '上川郡新得町', 'カミカワグンシントクチョウ', '本通南', 'ホンドオリミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡新得町1条南', '01', '01635', '0810011', '北海道', 'ホッカイドウ', '上川郡新得町', 'カミカワグンシントクチョウ', '1条南', '01ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡新得町2条南', '01', '01635', '0810012', '北海道', 'ホッカイドウ', '上川郡新得町', 'カミカワグンシントクチョウ', '2条南', '02ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡新得町3条南', '01', '01635', '0810013', '北海道', 'ホッカイドウ', '上川郡新得町', 'カミカワグンシントクチョウ', '3条南', '03ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡新得町4条南', '01', '01635', '0810014', '北海道', 'ホッカイドウ', '上川郡新得町', 'カミカワグンシントクチョウ', '4条南', '04ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡新得町5条南', '01', '01635', '0810015', '北海道', 'ホッカイドウ', '上川郡新得町', 'カミカワグンシントクチョウ', '5条南', '05ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡新得町西1条北', '01', '01635', '0810021', '北海道', 'ホッカイドウ', '上川郡新得町', 'カミカワグンシントクチョウ', '西1条北', 'ニシ01ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡新得町西2条北', '01', '01635', '0810022', '北海道', 'ホッカイドウ', '上川郡新得町', 'カミカワグンシントクチョウ', '西2条北', 'ニシ02ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡新得町西3条北', '01', '01635', '0810023', '北海道', 'ホッカイドウ', '上川郡新得町', 'カミカワグンシントクチョウ', '西3条北', 'ニシ03ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡新得町西1条南', '01', '01635', '0810031', '北海道', 'ホッカイドウ', '上川郡新得町', 'カミカワグンシントクチョウ', '西1条南', 'ニシ01ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡新得町西2条南', '01', '01635', '0810032', '北海道', 'ホッカイドウ', '上川郡新得町', 'カミカワグンシントクチョウ', '西2条南', 'ニシ02ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡新得町西3条南', '01', '01635', '0810033', '北海道', 'ホッカイドウ', '上川郡新得町', 'カミカワグンシントクチョウ', '西3条南', 'ニシ03ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡新得町西4条南', '01', '01635', '0810034', '北海道', 'ホッカイドウ', '上川郡新得町', 'カミカワグンシントクチョウ', '西4条南', 'ニシ04ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡新得町上佐幌', '01', '01635', '0810035', '北海道', 'ホッカイドウ', '上川郡新得町', 'カミカワグンシントクチョウ', '上佐幌', 'カミサホロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡新得町下佐幌', '01', '01635', '0810036', '北海道', 'ホッカイドウ', '上川郡新得町', 'カミカワグンシントクチョウ', '下佐幌', 'シモサホロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡新得町拓鉄', '01', '01635', '0810037', '北海道', 'ホッカイドウ', '上川郡新得町', 'カミカワグンシントクチョウ', '拓鉄', 'タクテツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡新得町新得', '01', '01635', '0810038', '北海道', 'ホッカイドウ', '上川郡新得町', 'カミカワグンシントクチョウ', '新得', 'シントク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡新得町新内', '01', '01635', '0810039', '北海道', 'ホッカイドウ', '上川郡新得町', 'カミカワグンシントクチョウ', '新内', 'ニイナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市博多区中洲', '40', '40132', '8100801', '福岡県', 'フクオカケン', '福岡市博多区', 'フクオカシハカタク', '中洲', 'ナカス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市博多区中洲中島町', '40', '40132', '8100802', '福岡県', 'フクオカケン', '福岡市博多区', 'フクオカシハカタク', '中洲中島町', 'ナカスナカシママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡新得町屈足旭町', '01', '01635', '0810151', '北海道', 'ホッカイドウ', '上川郡新得町', 'カミカワグンシントクチョウ', '屈足旭町', 'クッタリアサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡新得町屈足旭町東', '01', '01635', '0810152', '北海道', 'ホッカイドウ', '上川郡新得町', 'カミカワグンシントクチョウ', '屈足旭町東', 'クッタリアサヒマチヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡新得町屈足南町', '01', '01635', '0810153', '北海道', 'ホッカイドウ', '上川郡新得町', 'カミカワグンシントクチョウ', '屈足南町', 'クッタリミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡新得町屈足', '01', '01635', '0810154', '北海道', 'ホッカイドウ', '上川郡新得町', 'カミカワグンシントクチョウ', '屈足', 'クッタリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡新得町屈足幸町', '01', '01635', '0810155', '北海道', 'ホッカイドウ', '上川郡新得町', 'カミカワグンシントクチョウ', '屈足幸町', 'クッタリサイワイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡新得町屈足幸町西', '01', '01635', '0810156', '北海道', 'ホッカイドウ', '上川郡新得町', 'カミカワグンシントクチョウ', '屈足幸町西', 'クッタリサイワイマチニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡新得町屈足柏町', '01', '01635', '0810161', '北海道', 'ホッカイドウ', '上川郡新得町', 'カミカワグンシントクチョウ', '屈足柏町', 'クッタリカシワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡新得町屈足柏町東', '01', '01635', '0810162', '北海道', 'ホッカイドウ', '上川郡新得町', 'カミカワグンシントクチョウ', '屈足柏町東', 'クッタリカシワマチヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡新得町屈足緑町', '01', '01635', '0810163', '北海道', 'ホッカイドウ', '上川郡新得町', 'カミカワグンシントクチョウ', '屈足緑町', 'クッタリミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡新得町屈足緑町西', '01', '01635', '0810164', '北海道', 'ホッカイドウ', '上川郡新得町', 'カミカワグンシントクチョウ', '屈足緑町西', 'クッタリミドリマチニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡鹿追町', '01', '01634', '0810200', '北海道', 'ホッカイドウ', '河東郡鹿追町', 'カトウグンシカオイチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('104056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡鹿追町新町', '01', '01634', '0810201', '北海道', 'ホッカイドウ', '河東郡鹿追町', 'カトウグンシカオイチョウ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡鹿追町北町', '01', '01634', '0810202', '北海道', 'ホッカイドウ', '河東郡鹿追町', 'カトウグンシカオイチョウ', '北町', 'キタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡鹿追町緑町', '01', '01634', '0810203', '北海道', 'ホッカイドウ', '河東郡鹿追町', 'カトウグンシカオイチョウ', '緑町', 'ミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡鹿追町笹川北', '01', '01634', '0810204', '北海道', 'ホッカイドウ', '河東郡鹿追町', 'カトウグンシカオイチョウ', '笹川北', 'ササガワキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡鹿追町西笹川', '01', '01634', '0810205', '北海道', 'ホッカイドウ', '河東郡鹿追町', 'カトウグンシカオイチョウ', '西笹川', 'ニシササガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡鹿追町仲町', '01', '01634', '0810211', '北海道', 'ホッカイドウ', '河東郡鹿追町', 'カトウグンシカオイチョウ', '仲町', 'ナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡鹿追町泉町', '01', '01634', '0810212', '北海道', 'ホッカイドウ', '河東郡鹿追町', 'カトウグンシカオイチョウ', '泉町', 'イズミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡鹿追町西町', '01', '01634', '0810213', '北海道', 'ホッカイドウ', '河東郡鹿追町', 'カトウグンシカオイチョウ', '西町', 'ニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡鹿追町北鹿追北', '01', '01634', '0810214', '北海道', 'ホッカイドウ', '河東郡鹿追町', 'カトウグンシカオイチョウ', '北鹿追北', 'キタシカオイキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡鹿追町鹿追南', '01', '01634', '0810215', '北海道', 'ホッカイドウ', '河東郡鹿追町', 'カトウグンシカオイチョウ', '鹿追南', 'シカオイミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡鹿追町鹿追北', '01', '01634', '0810216', '北海道', 'ホッカイドウ', '河東郡鹿追町', 'カトウグンシカオイチョウ', '鹿追北', 'シカオイキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡鹿追町鹿追基線', '01', '01634', '0810217', '北海道', 'ホッカイドウ', '河東郡鹿追町', 'カトウグンシカオイチョウ', '鹿追基線', 'シカオイキセン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡鹿追町上然別西', '01', '01634', '0810218', '北海道', 'ホッカイドウ', '河東郡鹿追町', 'カトウグンシカオイチョウ', '上然別西', 'カミシカリベツニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡鹿追町栄町', '01', '01634', '0810221', '北海道', 'ホッカイドウ', '河東郡鹿追町', 'カトウグンシカオイチョウ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡鹿追町東町', '01', '01634', '0810222', '北海道', 'ホッカイドウ', '河東郡鹿追町', 'カトウグンシカオイチョウ', '東町', 'ヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡鹿追町南町', '01', '01634', '0810223', '北海道', 'ホッカイドウ', '河東郡鹿追町', 'カトウグンシカオイチョウ', '南町', 'ミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡鹿追町元町', '01', '01634', '0810224', '北海道', 'ホッカイドウ', '河東郡鹿追町', 'カトウグンシカオイチョウ', '元町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡鹿追町柏ケ丘', '01', '01634', '0810225', '北海道', 'ホッカイドウ', '河東郡鹿追町', 'カトウグンシカオイチョウ', '柏ケ丘', 'カシワガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡鹿追町上幌内', '01', '01634', '0810226', '北海道', 'ホッカイドウ', '河東郡鹿追町', 'カトウグンシカオイチョウ', '上幌内', 'カミホロナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡鹿追町幌内西', '01', '01634', '0810227', '北海道', 'ホッカイドウ', '河東郡鹿追町', 'カトウグンシカオイチョウ', '幌内西', 'ホロナイニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡鹿追町美蔓西', '01', '01634', '0810228', '北海道', 'ホッカイドウ', '河東郡鹿追町', 'カトウグンシカオイチョウ', '美蔓西', 'ビマンニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡鹿追町瓜幕西', '01', '01634', '0810341', '北海道', 'ホッカイドウ', '河東郡鹿追町', 'カトウグンシカオイチョウ', '瓜幕西', 'ウリマクニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡鹿追町瓜幕東', '01', '01634', '0810342', '北海道', 'ホッカイドウ', '河東郡鹿追町', 'カトウグンシカオイチョウ', '瓜幕東', 'ウリマクヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡鹿追町瓜幕南', '01', '01634', '0810343', '北海道', 'ホッカイドウ', '河東郡鹿追町', 'カトウグンシカオイチョウ', '瓜幕南', 'ウリマクミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡鹿追町北瓜幕', '01', '01634', '0810344', '北海道', 'ホッカイドウ', '河東郡鹿追町', 'カトウグンシカオイチョウ', '北瓜幕', 'キタウリマク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡鹿追町中瓜幕西', '01', '01634', '0810345', '北海道', 'ホッカイドウ', '河東郡鹿追町', 'カトウグンシカオイチョウ', '中瓜幕西', 'ナカウリマクニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河東郡鹿追町東瓜幕西', '01', '01634', '0810346', '北海道', 'ホッカイドウ', '河東郡鹿追町', 'カトウグンシカオイチョウ', '東瓜幕西', 'ヒガシウリマクニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糟屋郡新宮町', '40', '40345', '8110100', '福岡県', 'フクオカケン', '糟屋郡新宮町', 'カスヤグンシングウマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('104222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糟屋郡新宮町原上', '40', '40345', '8110101', '福岡県', 'フクオカケン', '糟屋郡新宮町', 'カスヤグンシングウマチ', '原上', 'ハルガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糟屋郡新宮町立花口', '40', '40345', '8110102', '福岡県', 'フクオカケン', '糟屋郡新宮町', 'カスヤグンシングウマチ', '立花口', 'タチバナグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糟屋郡新宮町花立花', '40', '40345', '8110103', '福岡県', 'フクオカケン', '糟屋郡新宮町', 'カスヤグンシングウマチ', '花立花', 'ハナタチバナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糟屋郡新宮町的野', '40', '40345', '8110104', '福岡県', 'フクオカケン', '糟屋郡新宮町', 'カスヤグンシングウマチ', '的野', 'マトノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糟屋郡新宮町夜臼', '40', '40345', '8110110', '福岡県', 'フクオカケン', '糟屋郡新宮町', 'カスヤグンシングウマチ', '夜臼', 'ユウス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糟屋郡新宮町三代', '40', '40345', '8110111', '福岡県', 'フクオカケン', '糟屋郡新宮町', 'カスヤグンシングウマチ', '三代', 'ミシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糟屋郡新宮町下府', '40', '40345', '8110112', '福岡県', 'フクオカケン', '糟屋郡新宮町', 'カスヤグンシングウマチ', '下府', 'シモノフ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糟屋郡新宮町桜山手', '40', '40345', '8110113', '福岡県', 'フクオカケン', '糟屋郡新宮町', 'カスヤグンシングウマチ', '桜山手', 'サクラヤマテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糟屋郡新宮町湊坂', '40', '40345', '8110114', '福岡県', 'フクオカケン', '糟屋郡新宮町', 'カスヤグンシングウマチ', '湊坂', 'ミナトザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糟屋郡新宮町新宮', '40', '40345', '8110115', '福岡県', 'フクオカケン', '糟屋郡新宮町', 'カスヤグンシングウマチ', '新宮', 'シングウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糟屋郡新宮町湊', '40', '40345', '8110116', '福岡県', 'フクオカケン', '糟屋郡新宮町', 'カスヤグンシングウマチ', '湊', 'ミナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糟屋郡新宮町上府', '40', '40345', '8110117', '福岡県', 'フクオカケン', '糟屋郡新宮町', 'カスヤグンシングウマチ', '上府', 'カミノフ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糟屋郡新宮町相島', '40', '40345', '8110118', '福岡県', 'フクオカケン', '糟屋郡新宮町', 'カスヤグンシングウマチ', '相島', 'アイノシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糟屋郡新宮町緑ケ浜', '40', '40345', '8110119', '福岡県', 'フクオカケン', '糟屋郡新宮町', 'カスヤグンシングウマチ', '緑ケ浜', 'ミドリガハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糟屋郡新宮町美咲', '40', '40345', '8110121', '福岡県', 'フクオカケン', '糟屋郡新宮町', 'カスヤグンシングウマチ', '美咲', 'ミサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糟屋郡新宮町杜の宮', '40', '40345', '8110122', '福岡県', 'フクオカケン', '糟屋郡新宮町', 'カスヤグンシングウマチ', '杜の宮', 'モリノミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市東区三苫', '40', '40131', '8110201', '福岡県', 'フクオカケン', '福岡市東区', 'フクオカシヒガシク', '三苫', 'ミトマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市東区和白', '40', '40131', '8110202', '福岡県', 'フクオカケン', '福岡市東区', 'フクオカシヒガシク', '和白', 'ワジロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市東区塩浜', '40', '40131', '8110203', '福岡県', 'フクオカケン', '福岡市東区', 'フクオカシヒガシク', '塩浜', 'シオハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市東区奈多', '40', '40131', '8110204', '福岡県', 'フクオカケン', '福岡市東区', 'フクオカシヒガシク', '奈多', 'ナタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市東区奈多団地', '40', '40131', '8110205', '福岡県', 'フクオカケン', '福岡市東区', 'フクオカシヒガシク', '奈多団地', 'ナタダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市東区雁の巣', '40', '40131', '8110206', '福岡県', 'フクオカケン', '福岡市東区', 'フクオカシヒガシク', '雁の巣', 'ガンノス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市東区美和台新町', '40', '40131', '8110211', '福岡県', 'フクオカケン', '福岡市東区', 'フクオカシヒガシク', '美和台新町', 'ミワダイシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市東区美和台', '40', '40131', '8110212', '福岡県', 'フクオカケン', '福岡市東区', 'フクオカシヒガシク', '美和台', 'ミワダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市東区和白丘', '40', '40131', '8110213', '福岡県', 'フクオカケン', '福岡市東区', 'フクオカシヒガシク', '和白丘', 'ワジロガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市東区和白東', '40', '40131', '8110214', '福岡県', 'フクオカケン', '福岡市東区', 'フクオカシヒガシク', '和白東', 'ワジロヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市東区高美台', '40', '40131', '8110215', '福岡県', 'フクオカケン', '福岡市東区', 'フクオカシヒガシク', '高美台', 'タカミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市東区上和白', '40', '40131', '8110216', '福岡県', 'フクオカケン', '福岡市東区', 'フクオカシヒガシク', '上和白', 'カミワジロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市東区西戸崎', '40', '40131', '8110321', '福岡県', 'フクオカケン', '福岡市東区', 'フクオカシヒガシク', '西戸崎', 'サイトザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市東区大岳', '40', '40131', '8110322', '福岡県', 'フクオカケン', '福岡市東区', 'フクオカシヒガシク', '大岳', 'オオタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市東区志賀島', '40', '40131', '8110323', '福岡県', 'フクオカケン', '福岡市東区', 'フクオカシヒガシク', '志賀島', 'シカシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市東区弘', '40', '40131', '8110324', '福岡県', 'フクオカケン', '福岡市東区', 'フクオカシヒガシク', '弘', 'ヒロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市東区勝馬', '40', '40131', '8110325', '福岡県', 'フクオカケン', '福岡市東区', 'フクオカシヒガシク', '勝馬', 'カツマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市早良区重留', '40', '40137', '8111101', '福岡県', 'フクオカケン', '福岡市早良区', 'フクオカシサワラク', '重留', 'シゲドメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市早良区東入部', '40', '40137', '8111102', '福岡県', 'フクオカケン', '福岡市早良区', 'フクオカシサワラク', '東入部', 'ヒガシイルベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市早良区四箇', '40', '40137', '8111103', '福岡県', 'フクオカケン', '福岡市早良区', 'フクオカシサワラク', '四箇', 'シカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市早良区脇山', '40', '40137', '8111111', '福岡県', 'フクオカケン', '福岡市早良区', 'フクオカシサワラク', '脇山', 'ワキヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市早良区小笠木', '40', '40137', '8111112', '福岡県', 'フクオカケン', '福岡市早良区', 'フクオカシサワラク', '小笠木', 'オカサギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市早良区板屋', '40', '40137', '8111113', '福岡県', 'フクオカケン', '福岡市早良区', 'フクオカシサワラク', '板屋', 'イタヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市早良区椎原', '40', '40137', '8111114', '福岡県', 'フクオカケン', '福岡市早良区', 'フクオカシサワラク', '椎原', 'シイバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市早良区西入部', '40', '40137', '8111121', '福岡県', 'フクオカケン', '福岡市早良区', 'フクオカシサワラク', '西入部', 'ニシイルベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市早良区早良', '40', '40137', '8111122', '福岡県', 'フクオカケン', '福岡市早良区', 'フクオカシサワラク', '早良', 'サワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市早良区内野', '40', '40137', '8111123', '福岡県', 'フクオカケン', '福岡市早良区', 'フクオカシサワラク', '内野', 'ウチノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市早良区金武', '40', '40137', '8111124', '福岡県', 'フクオカケン', '福岡市早良区', 'フクオカシサワラク', '金武', 'カナタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市早良区西', '40', '40137', '8111131', '福岡県', 'フクオカケン', '福岡市早良区', 'フクオカシサワラク', '西', 'ニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市早良区石釜', '40', '40137', '8111132', '福岡県', 'フクオカケン', '福岡市早良区', 'フクオカシサワラク', '石釜', 'イシガマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市早良区曲渕', '40', '40137', '8111133', '福岡県', 'フクオカケン', '福岡市早良区', 'フクオカシサワラク', '曲渕', 'マガリブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市早良区飯場', '40', '40137', '8111134', '福岡県', 'フクオカケン', '福岡市早良区', 'フクオカシサワラク', '飯場', 'イイバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑紫郡那珂川町', '40', '40305', '8111200', '福岡県', 'フクオカケン', '筑紫郡那珂川町', 'チクシグンナカガワマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('104276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑紫郡那珂川町片縄', '40', '40305', '8111201', '福岡県', 'フクオカケン', '筑紫郡那珂川町', 'チクシグンナカガワマチ', '片縄', 'カタナワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑紫郡那珂川町片縄西', '40', '40305', '8111202', '福岡県', 'フクオカケン', '筑紫郡那珂川町', 'チクシグンナカガワマチ', '片縄西', 'カタナワニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑紫郡那珂川町片縄北', '40', '40305', '8111203', '福岡県', 'フクオカケン', '筑紫郡那珂川町', 'チクシグンナカガワマチ', '片縄北', 'カタナワキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑紫郡那珂川町片縄東', '40', '40305', '8111204', '福岡県', 'フクオカケン', '筑紫郡那珂川町', 'チクシグンナカガワマチ', '片縄東', 'カタナワヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑紫郡那珂川町今光', '40', '40305', '8111211', '福岡県', 'フクオカケン', '筑紫郡那珂川町', 'チクシグンナカガワマチ', '今光', 'イマミツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑紫郡那珂川町中原観晴が丘', '40', '40305', '8111212', '福岡県', 'フクオカケン', '筑紫郡那珂川町', 'チクシグンナカガワマチ', '中原観晴が丘', 'ナカバルミハルガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑紫郡那珂川町中原', '40', '40305', '8111213', '福岡県', 'フクオカケン', '筑紫郡那珂川町', 'チクシグンナカガワマチ', '中原', 'ナカバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑紫郡那珂川町中原東', '40', '40305', '8111214', '福岡県', 'フクオカケン', '筑紫郡那珂川町', 'チクシグンナカガワマチ', '中原東', 'ナカバルヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑紫郡那珂川町松原', '40', '40305', '8111215', '福岡県', 'フクオカケン', '筑紫郡那珂川町', 'チクシグンナカガワマチ', '松原', 'マツバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑紫郡那珂川町観晴が丘', '40', '40305', '8111216', '福岡県', 'フクオカケン', '筑紫郡那珂川町', 'チクシグンナカガワマチ', '観晴が丘', 'ミハルガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑紫郡那珂川町王塚台', '40', '40305', '8111221', '福岡県', 'フクオカケン', '筑紫郡那珂川町', 'チクシグンナカガワマチ', '王塚台', 'オウツカダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑紫郡那珂川町下梶原', '40', '40305', '8111222', '福岡県', 'フクオカケン', '筑紫郡那珂川町', 'チクシグンナカガワマチ', '下梶原', 'シモカジワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑紫郡那珂川町上梶原', '40', '40305', '8111223', '福岡県', 'フクオカケン', '筑紫郡那珂川町', 'チクシグンナカガワマチ', '上梶原', 'カミカジワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑紫郡那珂川町安徳', '40', '40305', '8111224', '福岡県', 'フクオカケン', '筑紫郡那珂川町', 'チクシグンナカガワマチ', '安徳', 'アントク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑紫郡那珂川町不入道', '40', '40305', '8111231', '福岡県', 'フクオカケン', '筑紫郡那珂川町', 'チクシグンナカガワマチ', '不入道', 'フニュウドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑紫郡那珂川町埋金', '40', '40305', '8111232', '福岡県', 'フクオカケン', '筑紫郡那珂川町', 'チクシグンナカガワマチ', '埋金', 'ウメガネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑紫郡那珂川町市ノ瀬', '40', '40305', '8111233', '福岡県', 'フクオカケン', '筑紫郡那珂川町', 'チクシグンナカガワマチ', '市ノ瀬', 'イチノセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑紫郡那珂川町五ケ山', '40', '40305', '8111234', '福岡県', 'フクオカケン', '筑紫郡那珂川町', 'チクシグンナカガワマチ', '五ケ山', 'ゴカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑紫郡那珂川町成竹', '40', '40305', '8111235', '福岡県', 'フクオカケン', '筑紫郡那珂川町', 'チクシグンナカガワマチ', '成竹', 'ナルタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑紫郡那珂川町南面里', '40', '40305', '8111236', '福岡県', 'フクオカケン', '筑紫郡那珂川町', 'チクシグンナカガワマチ', '南面里', 'ナメリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑紫郡那珂川町後野', '40', '40305', '8111241', '福岡県', 'フクオカケン', '筑紫郡那珂川町', 'チクシグンナカガワマチ', '後野', 'ウシロノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑紫郡那珂川町西隈', '40', '40305', '8111242', '福岡県', 'フクオカケン', '筑紫郡那珂川町', 'チクシグンナカガワマチ', '西隈', 'ニシグマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑紫郡那珂川町東隈', '40', '40305', '8111243', '福岡県', 'フクオカケン', '筑紫郡那珂川町', 'チクシグンナカガワマチ', '東隈', 'ヒガシグマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑紫郡那珂川町山田', '40', '40305', '8111244', '福岡県', 'フクオカケン', '筑紫郡那珂川町', 'チクシグンナカガワマチ', '山田', 'ヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑紫郡那珂川町別所', '40', '40305', '8111245', '福岡県', 'フクオカケン', '筑紫郡那珂川町', 'チクシグンナカガワマチ', '別所', 'ベッショ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑紫郡那珂川町西畑', '40', '40305', '8111246', '福岡県', 'フクオカケン', '筑紫郡那珂川町', 'チクシグンナカガワマチ', '西畑', 'ニシハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑紫郡那珂川町松木', '40', '40305', '8111251', '福岡県', 'フクオカケン', '筑紫郡那珂川町', 'チクシグンナカガワマチ', '松木', 'マツノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑紫郡那珂川町五郎丸', '40', '40305', '8111252', '福岡県', 'フクオカケン', '筑紫郡那珂川町', 'チクシグンナカガワマチ', '五郎丸', 'ゴロウマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑紫郡那珂川町仲', '40', '40305', '8111253', '福岡県', 'フクオカケン', '筑紫郡那珂川町', 'チクシグンナカガワマチ', '仲', 'チュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑紫郡那珂川町道善', '40', '40305', '8111254', '福岡県', 'フクオカケン', '筑紫郡那珂川町', 'チクシグンナカガワマチ', '道善', 'ドウゼン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑紫郡那珂川町恵子', '40', '40305', '8111255', '福岡県', 'フクオカケン', '筑紫郡那珂川町', 'チクシグンナカガワマチ', '恵子', 'エコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市南区井尻', '40', '40134', '8111302', '福岡県', 'フクオカケン', '福岡市南区', 'フクオカシミナミク', '井尻', 'イジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市南区折立町', '40', '40134', '8111303', '福岡県', 'フクオカケン', '福岡市南区', 'フクオカシミナミク', '折立町', 'オリタテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市南区横手', '40', '40134', '8111311', '福岡県', 'フクオカケン', '福岡市南区', 'フクオカシミナミク', '横手', 'ヨコテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市南区横手南町', '40', '40134', '8111312', '福岡県', 'フクオカケン', '福岡市南区', 'フクオカシミナミク', '横手南町', 'ヨコテミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市南区曰佐', '40', '40134', '8111313', '福岡県', 'フクオカケン', '福岡市南区', 'フクオカシミナミク', '曰佐', 'オサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市南区的場', '40', '40134', '8111314', '福岡県', 'フクオカケン', '福岡市南区', 'フクオカシミナミク', '的場', 'マトバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市南区柳瀬', '40', '40134', '8111321', '福岡県', 'フクオカケン', '福岡市南区', 'フクオカシミナミク', '柳瀬', 'ヤナセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市南区弥永団地', '40', '40134', '8111322', '福岡県', 'フクオカケン', '福岡市南区', 'フクオカシミナミク', '弥永団地', 'ヤナガダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市南区弥永', '40', '40134', '8111323', '福岡県', 'フクオカケン', '福岡市南区', 'フクオカシミナミク', '弥永', 'ヤナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市南区警弥郷', '40', '40134', '8111324', '福岡県', 'フクオカケン', '福岡市南区', 'フクオカシミナミク', '警弥郷', 'ケヤゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市南区和田', '40', '40134', '8111343', '福岡県', 'フクオカケン', '福岡市南区', 'フクオカシミナミク', '和田', 'ワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市南区三宅', '40', '40134', '8111344', '福岡県', 'フクオカケン', '福岡市南区', 'フクオカシミナミク', '三宅', 'ミヤケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市南区向新町', '40', '40134', '8111345', '福岡県', 'フクオカケン', '福岡市南区', 'フクオカシミナミク', '向新町', 'ムカイシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市南区老司', '40', '40134', '8111346', '福岡県', 'フクオカケン', '福岡市南区', 'フクオカシミナミク', '老司', 'ロウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市南区野多目', '40', '40134', '8111347', '福岡県', 'フクオカケン', '福岡市南区', 'フクオカシミナミク', '野多目', 'ノタメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市南区屋形原', '40', '40134', '8111351', '福岡県', 'フクオカケン', '福岡市南区', 'フクオカシミナミク', '屋形原', 'ヤカタバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市南区鶴田', '40', '40134', '8111352', '福岡県', 'フクオカケン', '福岡市南区', 'フクオカシミナミク', '鶴田', 'ツルタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市南区柏原', '40', '40134', '8111353', '福岡県', 'フクオカケン', '福岡市南区', 'フクオカシミナミク', '柏原', 'カシワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市南区大平寺', '40', '40134', '8111354', '福岡県', 'フクオカケン', '福岡市南区', 'フクオカシミナミク', '大平寺', 'タイヘイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市南区桧原', '40', '40134', '8111355', '福岡県', 'フクオカケン', '福岡市南区', 'フクオカシミナミク', '桧原', 'ヒバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市南区花畑', '40', '40134', '8111356', '福岡県', 'フクオカケン', '福岡市南区', 'フクオカシミナミク', '花畑', 'ハナハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市南区西長住', '40', '40134', '8111361', '福岡県', 'フクオカケン', '福岡市南区', 'フクオカシミナミク', '西長住', 'ニシナガズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市南区長住', '40', '40134', '8111362', '福岡県', 'フクオカケン', '福岡市南区', 'フクオカシミナミク', '長住', 'ナガズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市南区中尾', '40', '40134', '8111364', '福岡県', 'フクオカケン', '福岡市南区', 'フクオカシミナミク', '中尾', 'ナカオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市南区皿山', '40', '40134', '8111365', '福岡県', 'フクオカケン', '福岡市南区', 'フクオカシミナミク', '皿山', 'サラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糟屋郡宇美町', '40', '40341', '8112100', '福岡県', 'フクオカケン', '糟屋郡宇美町', 'カスヤグンウミマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('104340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糟屋郡須惠町', '40', '40344', '8112100', '福岡県', 'フクオカケン', '糟屋郡須惠町', 'カスヤグンスエマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('104341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糟屋郡宇美町宇美', '40', '40341', '8112101', '福岡県', 'フクオカケン', '糟屋郡宇美町', 'カスヤグンウミマチ', '宇美', 'ウミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糟屋郡宇美町炭焼', '40', '40341', '8112102', '福岡県', 'フクオカケン', '糟屋郡宇美町', 'カスヤグンウミマチ', '炭焼', 'スミヤキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糟屋郡宇美町四王寺坂', '40', '40341', '8112103', '福岡県', 'フクオカケン', '糟屋郡宇美町', 'カスヤグンウミマチ', '四王寺坂', 'シオウジザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糟屋郡宇美町井野', '40', '40341', '8112104', '福岡県', 'フクオカケン', '糟屋郡宇美町', 'カスヤグンウミマチ', '井野', 'イノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糟屋郡宇美町四王寺', '40', '40341', '8112105', '福岡県', 'フクオカケン', '糟屋郡宇美町', 'カスヤグンウミマチ', '四王寺', 'シオウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糟屋郡宇美町ひばりが丘', '40', '40341', '8112106', '福岡県', 'フクオカケン', '糟屋郡宇美町', 'カスヤグンウミマチ', 'ひばりが丘', 'ヒバリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糟屋郡宇美町とびたけ', '40', '40341', '8112107', '福岡県', 'フクオカケン', '糟屋郡宇美町', 'カスヤグンウミマチ', 'とびたけ', 'トビタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糟屋郡宇美町ゆりが丘', '40', '40341', '8112108', '福岡県', 'フクオカケン', '糟屋郡宇美町', 'カスヤグンウミマチ', 'ゆりが丘', 'ユリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糟屋郡宇美町桜原', '40', '40341', '8112109', '福岡県', 'フクオカケン', '糟屋郡宇美町', 'カスヤグンウミマチ', '桜原', 'サクラバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糟屋郡須惠町新原', '40', '40344', '8112111', '福岡県', 'フクオカケン', '糟屋郡須惠町', 'カスヤグンスエマチ', '新原', 'シンバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糟屋郡須惠町植木', '40', '40344', '8112112', '福岡県', 'フクオカケン', '糟屋郡須惠町', 'カスヤグンスエマチ', '植木', 'ウエキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糟屋郡須惠町須惠', '40', '40344', '8112113', '福岡県', 'フクオカケン', '糟屋郡須惠町', 'カスヤグンスエマチ', '須惠', 'スエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糟屋郡須惠町上須惠', '40', '40344', '8112114', '福岡県', 'フクオカケン', '糟屋郡須惠町', 'カスヤグンスエマチ', '上須惠', 'カミスエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糟屋郡須惠町佐谷', '40', '40344', '8112115', '福岡県', 'フクオカケン', '糟屋郡須惠町', 'カスヤグンスエマチ', '佐谷', 'サタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糟屋郡宇美町平和', '40', '40341', '8112121', '福岡県', 'フクオカケン', '糟屋郡宇美町', 'カスヤグンウミマチ', '平和', 'ヘイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糟屋郡宇美町明神坂', '40', '40341', '8112122', '福岡県', 'フクオカケン', '糟屋郡宇美町', 'カスヤグンウミマチ', '明神坂', 'ミョウジンザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糟屋郡宇美町光正寺', '40', '40341', '8112123', '福岡県', 'フクオカケン', '糟屋郡宇美町', 'カスヤグンウミマチ', '光正寺', 'コウショウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糟屋郡宇美町若草', '40', '40341', '8112124', '福岡県', 'フクオカケン', '糟屋郡宇美町', 'カスヤグンウミマチ', '若草', 'ワカクサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糟屋郡宇美町宇美東', '40', '40341', '8112125', '福岡県', 'フクオカケン', '糟屋郡宇美町', 'カスヤグンウミマチ', '宇美東', 'ウミヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糟屋郡宇美町障子岳南', '40', '40341', '8112126', '福岡県', 'フクオカケン', '糟屋郡宇美町', 'カスヤグンウミマチ', '障子岳南', 'ショウジダケミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糟屋郡宇美町障子岳', '40', '40341', '8112127', '福岡県', 'フクオカケン', '糟屋郡宇美町', 'カスヤグンウミマチ', '障子岳', 'ショウジダケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糟屋郡宇美町貴船', '40', '40341', '8112131', '福岡県', 'フクオカケン', '糟屋郡宇美町', 'カスヤグンウミマチ', '貴船', 'キフネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糟屋郡宇美町原田', '40', '40341', '8112132', '福岡県', 'フクオカケン', '糟屋郡宇美町', 'カスヤグンウミマチ', '原田', 'ハルダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糟屋郡志免町', '40', '40343', '8112200', '福岡県', 'フクオカケン', '糟屋郡志免町', 'カスヤグンシメマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('104367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糟屋郡志免町桜丘', '40', '40343', '8112201', '福岡県', 'フクオカケン', '糟屋郡志免町', 'カスヤグンシメマチ', '桜丘', 'サクラガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糟屋郡志免町志免', '40', '40343', '8112202', '福岡県', 'フクオカケン', '糟屋郡志免町', 'カスヤグンシメマチ', '志免', 'シメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糟屋郡志免町石橋台', '40', '40343', '8112203', '福岡県', 'フクオカケン', '糟屋郡志免町', 'カスヤグンシメマチ', '石橋台', 'イシバシダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糟屋郡志免町田富', '40', '40343', '8112204', '福岡県', 'フクオカケン', '糟屋郡志免町', 'カスヤグンシメマチ', '田富', 'タドミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糟屋郡志免町別府', '40', '40343', '8112205', '福岡県', 'フクオカケン', '糟屋郡志免町', 'カスヤグンシメマチ', '別府', 'ベフ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糟屋郡志免町御手洗', '40', '40343', '8112206', '福岡県', 'フクオカケン', '糟屋郡志免町', 'カスヤグンシメマチ', '御手洗', 'ミタライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糟屋郡志免町南里', '40', '40343', '8112207', '福岡県', 'フクオカケン', '糟屋郡志免町', 'カスヤグンシメマチ', '南里', 'ミナミザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糟屋郡志免町吉原', '40', '40343', '8112208', '福岡県', 'フクオカケン', '糟屋郡志免町', 'カスヤグンシメマチ', '吉原', 'ヨシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糟屋郡志免町王子', '40', '40343', '8112209', '福岡県', 'フクオカケン', '糟屋郡志免町', 'カスヤグンシメマチ', '王子', 'オウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糟屋郡須惠町旅石', '40', '40344', '8112221', '福岡県', 'フクオカケン', '糟屋郡須惠町', 'カスヤグンスエマチ', '旅石', 'タビイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糟屋郡志免町別府東', '40', '40343', '8112231', '福岡県', 'フクオカケン', '糟屋郡志免町', 'カスヤグンシメマチ', '別府東', 'ベフヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糟屋郡志免町別府西', '40', '40343', '8112232', '福岡県', 'フクオカケン', '糟屋郡志免町', 'カスヤグンシメマチ', '別府西', 'ベフニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糟屋郡志免町東公園台', '40', '40343', '8112241', '福岡県', 'フクオカケン', '糟屋郡志免町', 'カスヤグンシメマチ', '東公園台', 'ヒガシコウエンダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糟屋郡志免町松ケ丘', '40', '40343', '8112242', '福岡県', 'フクオカケン', '糟屋郡志免町', 'カスヤグンシメマチ', '松ケ丘', 'マツガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糟屋郡志免町志免東', '40', '40343', '8112243', '福岡県', 'フクオカケン', '糟屋郡志免町', 'カスヤグンシメマチ', '志免東', 'シメヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糟屋郡志免町志免中央', '40', '40343', '8112244', '福岡県', 'フクオカケン', '糟屋郡志免町', 'カスヤグンシメマチ', '志免中央', 'シメチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糟屋郡志免町片峰', '40', '40343', '8112245', '福岡県', 'フクオカケン', '糟屋郡志免町', 'カスヤグンシメマチ', '片峰', 'カタミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糟屋郡志免町片峰中央', '40', '40343', '8112246', '福岡県', 'フクオカケン', '糟屋郡志免町', 'カスヤグンシメマチ', '片峰中央', 'カタミネチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糟屋郡志免町向ケ丘', '40', '40343', '8112247', '福岡県', 'フクオカケン', '糟屋郡志免町', 'カスヤグンシメマチ', '向ケ丘', 'ムカイガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糟屋郡志免町坂瀬', '40', '40343', '8112248', '福岡県', 'フクオカケン', '糟屋郡志免町', 'カスヤグンシメマチ', '坂瀬', 'サカセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糟屋郡粕屋町', '40', '40349', '8112300', '福岡県', 'フクオカケン', '糟屋郡粕屋町', 'カスヤグンカスヤマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('104394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糟屋郡粕屋町上大隈', '40', '40349', '8112301', '福岡県', 'フクオカケン', '糟屋郡粕屋町', 'カスヤグンカスヤマチ', '上大隈', 'カミオオクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糟屋郡粕屋町大隈', '40', '40349', '8112302', '福岡県', 'フクオカケン', '糟屋郡粕屋町', 'カスヤグンカスヤマチ', '大隈', 'オオクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糟屋郡粕屋町酒殿', '40', '40349', '8112303', '福岡県', 'フクオカケン', '糟屋郡粕屋町', 'カスヤグンカスヤマチ', '酒殿', 'サカド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糟屋郡粕屋町仲原', '40', '40349', '8112304', '福岡県', 'フクオカケン', '糟屋郡粕屋町', 'カスヤグンカスヤマチ', '仲原', 'ナカバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糟屋郡粕屋町柚須', '40', '40349', '8112305', '福岡県', 'フクオカケン', '糟屋郡粕屋町', 'カスヤグンカスヤマチ', '柚須', 'ユス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糟屋郡粕屋町阿恵', '40', '40349', '8112306', '福岡県', 'フクオカケン', '糟屋郡粕屋町', 'カスヤグンカスヤマチ', '阿恵', 'アエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糟屋郡粕屋町原町', '40', '40349', '8112307', '福岡県', 'フクオカケン', '糟屋郡粕屋町', 'カスヤグンカスヤマチ', '原町', 'ハルマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糟屋郡粕屋町内橋', '40', '40349', '8112308', '福岡県', 'フクオカケン', '糟屋郡粕屋町', 'カスヤグンカスヤマチ', '内橋', 'ウチハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糟屋郡粕屋町駕与丁', '40', '40349', '8112309', '福岡県', 'フクオカケン', '糟屋郡粕屋町', 'カスヤグンカスヤマチ', '駕与丁', 'カヨイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糟屋郡粕屋町花ヶ浦', '40', '40349', '8112310', '福岡県', 'フクオカケン', '糟屋郡粕屋町', 'カスヤグンカスヤマチ', '花ヶ浦', 'ハナガウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糟屋郡粕屋町長者原', '40', '40349', '8112311', '福岡県', 'フクオカケン', '糟屋郡粕屋町', 'カスヤグンカスヤマチ', '長者原', 'チョウジャバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糟屋郡粕屋町戸原', '40', '40349', '8112312', '福岡県', 'フクオカケン', '糟屋郡粕屋町', 'カスヤグンカスヤマチ', '戸原', 'トバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糟屋郡粕屋町江辻', '40', '40349', '8112313', '福岡県', 'フクオカケン', '糟屋郡粕屋町', 'カスヤグンカスヤマチ', '江辻', 'エツジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糟屋郡粕屋町若宮', '40', '40349', '8112314', '福岡県', 'フクオカケン', '糟屋郡粕屋町', 'カスヤグンカスヤマチ', '若宮', 'ワカミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糟屋郡篠栗町', '40', '40342', '8112400', '福岡県', 'フクオカケン', '糟屋郡篠栗町', 'カスヤグンササグリマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('104411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糟屋郡篠栗町高田', '40', '40342', '8112401', '福岡県', 'フクオカケン', '糟屋郡篠栗町', 'カスヤグンササグリマチ', '高田', 'タカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糟屋郡篠栗町金出', '40', '40342', '8112402', '福岡県', 'フクオカケン', '糟屋郡篠栗町', 'カスヤグンササグリマチ', '金出', 'カナイデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糟屋郡篠栗町萩尾', '40', '40342', '8112403', '福岡県', 'フクオカケン', '糟屋郡篠栗町', 'カスヤグンササグリマチ', '萩尾', 'ハギノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糟屋郡篠栗町内住', '40', '40342', '8112404', '福岡県', 'フクオカケン', '糟屋郡篠栗町', 'カスヤグンササグリマチ', '内住', 'ナイジュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糟屋郡篠栗町篠栗', '40', '40342', '8112405', '福岡県', 'フクオカケン', '糟屋郡篠栗町', 'カスヤグンササグリマチ', '篠栗', 'ササグリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糟屋郡篠栗町若杉', '40', '40342', '8112411', '福岡県', 'フクオカケン', '糟屋郡篠栗町', 'カスヤグンササグリマチ', '若杉', 'ワカスギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糟屋郡篠栗町乙犬', '40', '40342', '8112412', '福岡県', 'フクオカケン', '糟屋郡篠栗町', 'カスヤグンササグリマチ', '乙犬', 'オトイヌ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糟屋郡篠栗町尾仲', '40', '40342', '8112413', '福岡県', 'フクオカケン', '糟屋郡篠栗町', 'カスヤグンササグリマチ', '尾仲', 'オナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糟屋郡篠栗町和田', '40', '40342', '8112414', '福岡県', 'フクオカケン', '糟屋郡篠栗町', 'カスヤグンササグリマチ', '和田', 'ワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糟屋郡篠栗町津波黒', '40', '40342', '8112415', '福岡県', 'フクオカケン', '糟屋郡篠栗町', 'カスヤグンササグリマチ', '津波黒', 'ツバクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糟屋郡篠栗町田中', '40', '40342', '8112416', '福岡県', 'フクオカケン', '糟屋郡篠栗町', 'カスヤグンササグリマチ', '田中', 'タナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糟屋郡久山町', '40', '40348', '8112500', '福岡県', 'フクオカケン', '糟屋郡久山町', 'カスヤグンヒサヤママチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('104426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糟屋郡久山町久原', '40', '40348', '8112501', '福岡県', 'フクオカケン', '糟屋郡久山町', 'カスヤグンヒサヤママチ', '久原', 'クバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糟屋郡久山町山田', '40', '40348', '8112502', '福岡県', 'フクオカケン', '糟屋郡久山町', 'カスヤグンヒサヤママチ', '山田', 'ヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糟屋郡久山町猪野', '40', '40348', '8112503', '福岡県', 'フクオカケン', '糟屋郡久山町', 'カスヤグンヒサヤママチ', '猪野', 'イノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県古賀市', '40', '40223', '8113100', '福岡県', 'フクオカケン', '古賀市', 'コガシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('104431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県古賀市天神', '40', '40223', '8113101', '福岡県', 'フクオカケン', '古賀市', 'コガシ', '天神', 'テンジン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県古賀市駅東', '40', '40223', '8113102', '福岡県', 'フクオカケン', '古賀市', 'コガシ', '駅東', 'エキヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県古賀市中央', '40', '40223', '8113103', '福岡県', 'フクオカケン', '古賀市', 'コガシ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県古賀市花鶴丘', '40', '40223', '8113104', '福岡県', 'フクオカケン', '古賀市', 'コガシ', '花鶴丘', 'カヅルガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県古賀市鹿部', '40', '40223', '8113105', '福岡県', 'フクオカケン', '古賀市', 'コガシ', '鹿部', 'シシブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県古賀市日吉', '40', '40223', '8113106', '福岡県', 'フクオカケン', '古賀市', 'コガシ', '日吉', 'ヒヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県古賀市美明', '40', '40223', '8113107', '福岡県', 'フクオカケン', '古賀市', 'コガシ', '美明', 'ミアケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県古賀市花見南', '40', '40223', '8113111', '福岡県', 'フクオカケン', '古賀市', 'コガシ', '花見南', 'ハナミミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県古賀市花見東', '40', '40223', '8113112', '福岡県', 'フクオカケン', '古賀市', 'コガシ', '花見東', 'ハナミヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県古賀市千鳥', '40', '40223', '8113113', '福岡県', 'フクオカケン', '古賀市', 'コガシ', '千鳥', 'チドリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県古賀市舞の里', '40', '40223', '8113114', '福岡県', 'フクオカケン', '古賀市', 'コガシ', '舞の里', 'マイノサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県古賀市久保', '40', '40223', '8113115', '福岡県', 'フクオカケン', '古賀市', 'コガシ', '久保', 'クボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県古賀市庄', '40', '40223', '8113116', '福岡県', 'フクオカケン', '古賀市', 'コガシ', '庄', 'ショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県古賀市今の庄', '40', '40223', '8113117', '福岡県', 'フクオカケン', '古賀市', 'コガシ', '今の庄', 'イマノショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県古賀市新久保', '40', '40223', '8113118', '福岡県', 'フクオカケン', '古賀市', 'コガシ', '新久保', 'シンクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県古賀市筵内', '40', '40223', '8113121', '福岡県', 'フクオカケン', '古賀市', 'コガシ', '筵内', 'ムシロウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県古賀市薦野', '40', '40223', '8113122', '福岡県', 'フクオカケン', '古賀市', 'コガシ', '薦野', 'コモノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県古賀市米多比', '40', '40223', '8113123', '福岡県', 'フクオカケン', '古賀市', 'コガシ', '米多比', 'ネタビ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県古賀市薬王寺', '40', '40223', '8113124', '福岡県', 'フクオカケン', '古賀市', 'コガシ', '薬王寺', 'ヤクオウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県古賀市谷山', '40', '40223', '8113125', '福岡県', 'フクオカケン', '古賀市', 'コガシ', '谷山', 'タニヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県古賀市小山田', '40', '40223', '8113126', '福岡県', 'フクオカケン', '古賀市', 'コガシ', '小山田', 'オヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県古賀市新原', '40', '40223', '8113127', '福岡県', 'フクオカケン', '古賀市', 'コガシ', '新原', 'シンバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県古賀市今在家', '40', '40223', '8113131', '福岡県', 'フクオカケン', '古賀市', 'コガシ', '今在家', 'イマザイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県古賀市川原', '40', '40223', '8113132', '福岡県', 'フクオカケン', '古賀市', 'コガシ', '川原', 'カワバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県古賀市青柳町', '40', '40223', '8113133', '福岡県', 'フクオカケン', '古賀市', 'コガシ', '青柳町', 'アオヤギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県古賀市青柳', '40', '40223', '8113134', '福岡県', 'フクオカケン', '古賀市', 'コガシ', '青柳', 'アオヤギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県古賀市小竹', '40', '40223', '8113135', '福岡県', 'フクオカケン', '古賀市', 'コガシ', '小竹', 'オダケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県古賀市糸ケ浦', '40', '40223', '8113136', '福岡県', 'フクオカケン', '古賀市', 'コガシ', '糸ケ浦', 'イトガウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県古賀市古賀', '40', '40223', '8113137', '福岡県', 'フクオカケン', '古賀市', 'コガシ', '古賀', 'コガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福津市', '40', '40224', '8113200', '福岡県', 'フクオカケン', '福津市', 'フクツシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('104466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福津市八並', '40', '40224', '8113201', '福岡県', 'フクオカケン', '福津市', 'フクツシ', '八並', 'ヤツナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福津市畦町', '40', '40224', '8113202', '福岡県', 'フクオカケン', '福津市', 'フクツシ', '畦町', 'アゼマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福津市本木', '40', '40224', '8113203', '福岡県', 'フクオカケン', '福津市', 'フクツシ', '本木', 'モトギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福津市舎利蔵', '40', '40224', '8113204', '福岡県', 'フクオカケン', '福津市', 'フクツシ', '舎利蔵', 'シャリクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福津市内殿', '40', '40224', '8113205', '福岡県', 'フクオカケン', '福津市', 'フクツシ', '内殿', 'ウチドノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福津市久末', '40', '40224', '8113206', '福岡県', 'フクオカケン', '福津市', 'フクツシ', '久末', 'ヒサスエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福津市上西郷', '40', '40224', '8113207', '福岡県', 'フクオカケン', '福津市', 'フクツシ', '上西郷', 'カミサイゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福津市福間駅東', '40', '40224', '8113208', '福岡県', 'フクオカケン', '福津市', 'フクツシ', '福間駅東', 'フクマエキヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福津市有弥の里', '40', '40224', '8113211', '福岡県', 'フクオカケン', '福津市', 'フクツシ', '有弥の里', 'ユミノサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福津市福間南', '40', '40224', '8113212', '福岡県', 'フクオカケン', '福津市', 'フクツシ', '福間南', 'フクマミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福津市', '40', '40224', '8113213', '福岡県', 'フクオカケン', '福津市', 'フクツシ', null, '　', '（直番地）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('104477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福津市花見が丘', '40', '40224', '8113214', '福岡県', 'フクオカケン', '福津市', 'フクツシ', '花見が丘', 'ハナミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福津市花見の里', '40', '40224', '8113215', '福岡県', 'フクオカケン', '福津市', 'フクツシ', '花見の里', 'ハナミノサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福津市花見が浜', '40', '40224', '8113216', '福岡県', 'フクオカケン', '福津市', 'フクツシ', '花見が浜', 'ハナミガハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福津市中央', '40', '40224', '8113217', '福岡県', 'フクオカケン', '福津市', 'フクツシ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福津市手光南', '40', '40224', '8113218', '福岡県', 'フクオカケン', '福津市', 'フクツシ', '手光南', 'テビカミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福津市西福間', '40', '40224', '8113219', '福岡県', 'フクオカケン', '福津市', 'フクツシ', '西福間', 'ニシフクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福津市あけぼの', '40', '40224', '8113220', '福岡県', 'フクオカケン', '福津市', 'フクツシ', 'あけぼの', 'アケボノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福津市若木台', '40', '40224', '8113221', '福岡県', 'フクオカケン', '福津市', 'フクツシ', '若木台', 'ワカギダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福津市津丸', '40', '40224', '8113222', '福岡県', 'フクオカケン', '福津市', 'フクツシ', '津丸', 'ツマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福津市光陽台', '40', '40224', '8113223', '福岡県', 'フクオカケン', '福津市', 'フクツシ', '光陽台', 'コウヨウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福津市手光', '40', '40224', '8113224', '福岡県', 'フクオカケン', '福津市', 'フクツシ', '手光', 'テビカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福津市東福間', '40', '40224', '8113225', '福岡県', 'フクオカケン', '福津市', 'フクツシ', '東福間', 'ヒガシフクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福津市小竹', '40', '40224', '8113226', '福岡県', 'フクオカケン', '福津市', 'フクツシ', '小竹', 'オダケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福津市高平', '40', '40224', '8113227', '福岡県', 'フクオカケン', '福津市', 'フクツシ', '高平', 'タカヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福津市光陽台南', '40', '40224', '8113228', '福岡県', 'フクオカケン', '福津市', 'フクツシ', '光陽台南', 'コウヨウダイミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福津市桜川', '40', '40224', '8113229', '福岡県', 'フクオカケン', '福津市', 'フクツシ', '桜川', 'サクラガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福津市在自', '40', '40224', '8113301', '福岡県', 'フクオカケン', '福津市', 'フクツシ', '在自', 'アラジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福津市大石', '40', '40224', '8113302', '福岡県', 'フクオカケン', '福津市', 'フクツシ', '大石', 'オオイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福津市須多田', '40', '40224', '8113303', '福岡県', 'フクオカケン', '福津市', 'フクツシ', '須多田', 'スダタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福津市津屋崎', '40', '40224', '8113304', '福岡県', 'フクオカケン', '福津市', 'フクツシ', '津屋崎', 'ツヤザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福津市宮司', '40', '40224', '8113305', '福岡県', 'フクオカケン', '福津市', 'フクツシ', '宮司', 'ミヤジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福津市生家', '40', '40224', '8113306', '福岡県', 'フクオカケン', '福津市', 'フクツシ', '生家', 'ユクエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福津市渡', '40', '40224', '8113307', '福岡県', 'フクオカケン', '福津市', 'フクツシ', '渡', 'ワタリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福津市星ケ丘', '40', '40224', '8113308', '福岡県', 'フクオカケン', '福津市', 'フクツシ', '星ケ丘', 'ホシガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福津市宮司元町', '40', '40224', '8113309', '福岡県', 'フクオカケン', '福津市', 'フクツシ', '宮司元町', 'ミヤジモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福津市宮司浜', '40', '40224', '8113311', '福岡県', 'フクオカケン', '福津市', 'フクツシ', '宮司浜', 'ミヤジハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福津市宮司ヶ丘', '40', '40224', '8113312', '福岡県', 'フクオカケン', '福津市', 'フクツシ', '宮司ヶ丘', 'ミヤジガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宗像市', '40', '40220', '8113400', '福岡県', 'フクオカケン', '宗像市', 'ムナカタシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('104509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宗像市池浦', '40', '40220', '8113401', '福岡県', 'フクオカケン', '宗像市', 'ムナカタシ', '池浦', 'イケウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宗像市河東', '40', '40220', '8113402', '福岡県', 'フクオカケン', '宗像市', 'ムナカタシ', '河東', 'カトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宗像市ひかりケ丘', '40', '40220', '8113403', '福岡県', 'フクオカケン', '宗像市', 'ムナカタシ', 'ひかりケ丘', 'ヒカリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宗像市城西ケ丘', '40', '40220', '8113404', '福岡県', 'フクオカケン', '宗像市', 'ムナカタシ', '城西ケ丘', 'ジョウセイガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宗像市須恵', '40', '40220', '8113405', '福岡県', 'フクオカケン', '宗像市', 'ムナカタシ', '須恵', 'スエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宗像市稲元', '40', '40220', '8113406', '福岡県', 'フクオカケン', '宗像市', 'ムナカタシ', '稲元', 'イナモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宗像市天平台', '40', '40220', '8113407', '福岡県', 'フクオカケン', '宗像市', 'ムナカタシ', '天平台', 'テンピョウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宗像市樟陽台', '40', '40220', '8113408', '福岡県', 'フクオカケン', '宗像市', 'ムナカタシ', '樟陽台', 'ショウヨウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宗像市山田', '40', '40220', '8113411', '福岡県', 'フクオカケン', '宗像市', 'ムナカタシ', '山田', 'ヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宗像市平等寺', '40', '40220', '8113412', '福岡県', 'フクオカケン', '宗像市', 'ムナカタシ', '平等寺', 'ビョウドウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宗像市曲', '40', '40220', '8113413', '福岡県', 'フクオカケン', '宗像市', 'ムナカタシ', '曲', 'マガリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宗像市光岡', '40', '40220', '8113414', '福岡県', 'フクオカケン', '宗像市', 'ムナカタシ', '光岡', 'ミツオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宗像市朝野', '40', '40220', '8113415', '福岡県', 'フクオカケン', '宗像市', 'ムナカタシ', '朝野', 'アサノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宗像市宮田', '40', '40220', '8113416', '福岡県', 'フクオカケン', '宗像市', 'ムナカタシ', '宮田', 'ミヤタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宗像市大穂', '40', '40220', '8113421', '福岡県', 'フクオカケン', '宗像市', 'ムナカタシ', '大穂', 'オオブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宗像市王丸', '40', '40220', '8113422', '福岡県', 'フクオカケン', '宗像市', 'ムナカタシ', '王丸', 'オウマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宗像市野坂', '40', '40220', '8113423', '福岡県', 'フクオカケン', '宗像市', 'ムナカタシ', '野坂', 'ノサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宗像市原町', '40', '40220', '8113424', '福岡県', 'フクオカケン', '宗像市', 'ムナカタシ', '原町', 'ハルマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宗像市日の里', '40', '40220', '8113425', '福岡県', 'フクオカケン', '宗像市', 'ムナカタシ', '日の里', 'ヒノサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宗像市平井', '40', '40220', '8113430', '福岡県', 'フクオカケン', '宗像市', 'ムナカタシ', '平井', 'ヒライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宗像市田熊', '40', '40220', '8113431', '福岡県', 'フクオカケン', '宗像市', 'ムナカタシ', '田熊', 'タグマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宗像市大井', '40', '40220', '8113432', '福岡県', 'フクオカケン', '宗像市', 'ムナカタシ', '大井', 'オオイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宗像市大井台', '40', '40220', '8113433', '福岡県', 'フクオカケン', '宗像市', 'ムナカタシ', '大井台', 'オオイダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宗像市村山田', '40', '40220', '8113434', '福岡県', 'フクオカケン', '宗像市', 'ムナカタシ', '村山田', 'ムラヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宗像市用山', '40', '40220', '8113435', '福岡県', 'フクオカケン', '宗像市', 'ムナカタシ', '用山', 'モチヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宗像市東郷', '40', '40220', '8113436', '福岡県', 'フクオカケン', '宗像市', 'ムナカタシ', '東郷', 'トウゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宗像市久原', '40', '40220', '8113437', '福岡県', 'フクオカケン', '宗像市', 'ムナカタシ', '久原', 'クバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宗像市和歌美台', '40', '40220', '8113438', '福岡県', 'フクオカケン', '宗像市', 'ムナカタシ', '和歌美台', 'ワカミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宗像市三倉', '40', '40220', '8113439', '福岡県', 'フクオカケン', '宗像市', 'ムナカタシ', '三倉', 'ミクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宗像市大井南', '40', '40220', '8113440', '福岡県', 'フクオカケン', '宗像市', 'ムナカタシ', '大井南', 'オオイミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宗像市神湊', '40', '40220', '8113501', '福岡県', 'フクオカケン', '宗像市', 'ムナカタシ', '神湊', 'コウノミナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宗像市江口', '40', '40220', '8113502', '福岡県', 'フクオカケン', '宗像市', 'ムナカタシ', '江口', 'エグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宗像市牟田尻', '40', '40220', '8113503', '福岡県', 'フクオカケン', '宗像市', 'ムナカタシ', '牟田尻', 'ムタジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宗像市深田', '40', '40220', '8113504', '福岡県', 'フクオカケン', '宗像市', 'ムナカタシ', '深田', 'フカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宗像市田島', '40', '40220', '8113505', '福岡県', 'フクオカケン', '宗像市', 'ムナカタシ', '田島', 'タシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宗像市吉田', '40', '40220', '8113506', '福岡県', 'フクオカケン', '宗像市', 'ムナカタシ', '吉田', 'ヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宗像市多禮', '40', '40220', '8113507', '福岡県', 'フクオカケン', '宗像市', 'ムナカタシ', '多禮', 'タレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宗像市地島', '40', '40220', '8113511', '福岡県', 'フクオカケン', '宗像市', 'ムナカタシ', '地島', 'ジノシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宗像市鐘崎', '40', '40220', '8113512', '福岡県', 'フクオカケン', '宗像市', 'ムナカタシ', '鐘崎', 'カネザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宗像市上八', '40', '40220', '8113513', '福岡県', 'フクオカケン', '宗像市', 'ムナカタシ', '上八', 'コウジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宗像市田野', '40', '40220', '8113514', '福岡県', 'フクオカケン', '宗像市', 'ムナカタシ', '田野', 'タノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宗像市池田', '40', '40220', '8113515', '福岡県', 'フクオカケン', '宗像市', 'ムナカタシ', '池田', 'イケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宗像市公園通り', '40', '40220', '8113516', '福岡県', 'フクオカケン', '宗像市', 'ムナカタシ', '公園通り', 'コウエンドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福津市勝浦', '40', '40224', '8113521', '福岡県', 'フクオカケン', '福津市', 'フクツシ', '勝浦', 'カツウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福津市奴山', '40', '40224', '8113522', '福岡県', 'フクオカケン', '福津市', 'フクツシ', '奴山', 'ヌヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宗像市大島', '40', '40220', '8113701', '福岡県', 'フクオカケン', '宗像市', 'ムナカタシ', '大島', 'オオシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宗像市曲', '40', '40220', '8114113', '福岡県', 'フクオカケン', '宗像市', 'ムナカタシ', '曲', 'マガリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宗像市大谷', '40', '40220', '8114141', '福岡県', 'フクオカケン', '宗像市', 'ムナカタシ', '大谷', 'オオタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宗像市泉ケ丘', '40', '40220', '8114142', '福岡県', 'フクオカケン', '宗像市', 'ムナカタシ', '泉ケ丘', 'イズミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宗像市三郎丸', '40', '40220', '8114143', '福岡県', 'フクオカケン', '宗像市', 'ムナカタシ', '三郎丸', 'サブロウマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宗像市陵厳寺', '40', '40220', '8114145', '福岡県', 'フクオカケン', '宗像市', 'ムナカタシ', '陵厳寺', 'リョウゲンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宗像市赤間', '40', '40220', '8114146', '福岡県', 'フクオカケン', '宗像市', 'ムナカタシ', '赤間', 'アカマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宗像市石丸', '40', '40220', '8114147', '福岡県', 'フクオカケン', '宗像市', 'ムナカタシ', '石丸', 'イシマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宗像市赤間文教町', '40', '40220', '8114148', '福岡県', 'フクオカケン', '宗像市', 'ムナカタシ', '赤間文教町', 'アカマブンキョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宗像市城南ケ丘', '40', '40220', '8114151', '福岡県', 'フクオカケン', '宗像市', 'ムナカタシ', '城南ケ丘', 'ジョウナンガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宗像市武丸', '40', '40220', '8114152', '福岡県', 'フクオカケン', '宗像市', 'ムナカタシ', '武丸', 'タケマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宗像市吉留', '40', '40220', '8114153', '福岡県', 'フクオカケン', '宗像市', 'ムナカタシ', '吉留', 'ヨシドメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宗像市冨地原', '40', '40220', '8114154', '福岡県', 'フクオカケン', '宗像市', 'ムナカタシ', '冨地原', 'フジワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宗像市名残', '40', '40220', '8114155', '福岡県', 'フクオカケン', '宗像市', 'ムナカタシ', '名残', 'ナゴリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宗像市自由ケ丘南', '40', '40220', '8114156', '福岡県', 'フクオカケン', '宗像市', 'ムナカタシ', '自由ケ丘南', 'ジユウガオカミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宗像市アスティ', '40', '40220', '8114157', '福岡県', 'フクオカケン', '宗像市', 'ムナカタシ', 'アスティ', 'アスティ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宗像市朝町', '40', '40220', '8114161', '福岡県', 'フクオカケン', '宗像市', 'ムナカタシ', '朝町', 'アサマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宗像市青葉台', '40', '40220', '8114162', '福岡県', 'フクオカケン', '宗像市', 'ムナカタシ', '青葉台', 'アオバダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宗像市自由ケ丘', '40', '40220', '8114163', '福岡県', 'フクオカケン', '宗像市', 'ムナカタシ', '自由ケ丘', 'ジユウガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宗像市徳重', '40', '40220', '8114164', '福岡県', 'フクオカケン', '宗像市', 'ムナカタシ', '徳重', 'トクシゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宗像市広陵台', '40', '40220', '8114165', '福岡県', 'フクオカケン', '宗像市', 'ムナカタシ', '広陵台', 'コウリョウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宗像市桜', '40', '40220', '8114166', '福岡県', 'フクオカケン', '宗像市', 'ムナカタシ', '桜', 'サクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宗像市葉山', '40', '40220', '8114171', '福岡県', 'フクオカケン', '宗像市', 'ムナカタシ', '葉山', 'ハヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宗像市緑町', '40', '40220', '8114172', '福岡県', 'フクオカケン', '宗像市', 'ムナカタシ', '緑町', 'ミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宗像市栄町', '40', '40220', '8114173', '福岡県', 'フクオカケン', '宗像市', 'ムナカタシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宗像市自由ケ丘西町', '40', '40220', '8114174', '福岡県', 'フクオカケン', '宗像市', 'ムナカタシ', '自由ケ丘西町', 'ジユウガオカニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宗像市田久', '40', '40220', '8114175', '福岡県', 'フクオカケン', '宗像市', 'ムナカタシ', '田久', 'タク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宗像市赤間ケ丘', '40', '40220', '8114176', '福岡県', 'フクオカケン', '宗像市', 'ムナカタシ', '赤間ケ丘', 'アカマガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宗像市桜美台', '40', '40220', '8114177', '福岡県', 'フクオカケン', '宗像市', 'ムナカタシ', '桜美台', 'オウビダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宗像市城山ニュータウン', '40', '40220', '8114181', '福岡県', 'フクオカケン', '宗像市', 'ムナカタシ', '城山ニュータウン', 'ジョウヤマニュータウン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宗像市城ケ谷', '40', '40220', '8114182', '福岡県', 'フクオカケン', '宗像市', 'ムナカタシ', '城ケ谷', 'ジョウガタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宗像市土穴', '40', '40220', '8114183', '福岡県', 'フクオカケン', '宗像市', 'ムナカタシ', '土穴', 'ツチアナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宗像市くりえいと', '40', '40220', '8114184', '福岡県', 'フクオカケン', '宗像市', 'ムナカタシ', 'くりえいと', 'クリエイト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宗像市赤間駅前', '40', '40220', '8114185', '福岡県', 'フクオカケン', '宗像市', 'ムナカタシ', '赤間駅前', 'アカマエキマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県遠賀郡岡垣町', '40', '40383', '8114200', '福岡県', 'フクオカケン', '遠賀郡岡垣町', 'オンガグンオカガキマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('104594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県遠賀郡岡垣町波津', '40', '40383', '8114201', '福岡県', 'フクオカケン', '遠賀郡岡垣町', 'オンガグンオカガキマチ', '波津', 'ハツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県遠賀郡岡垣町原', '40', '40383', '8114202', '福岡県', 'フクオカケン', '遠賀郡岡垣町', 'オンガグンオカガキマチ', '原', 'ハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県遠賀郡岡垣町内浦', '40', '40383', '8114203', '福岡県', 'フクオカケン', '遠賀郡岡垣町', 'オンガグンオカガキマチ', '内浦', 'ウツラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県遠賀郡岡垣町手野', '40', '40383', '8114204', '福岡県', 'フクオカケン', '遠賀郡岡垣町', 'オンガグンオカガキマチ', '手野', 'テノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県遠賀郡岡垣町三吉', '40', '40383', '8114205', '福岡県', 'フクオカケン', '遠賀郡岡垣町', 'オンガグンオカガキマチ', '三吉', 'ミヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県遠賀郡岡垣町吉木', '40', '40383', '8114211', '福岡県', 'フクオカケン', '遠賀郡岡垣町', 'オンガグンオカガキマチ', '吉木', 'ヨシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県遠賀郡岡垣町黒山', '40', '40383', '8114212', '福岡県', 'フクオカケン', '遠賀郡岡垣町', 'オンガグンオカガキマチ', '黒山', 'クロヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県遠賀郡岡垣町糠塚', '40', '40383', '8114213', '福岡県', 'フクオカケン', '遠賀郡岡垣町', 'オンガグンオカガキマチ', '糠塚', 'ヌカヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県遠賀郡岡垣町松ケ台', '40', '40383', '8114214', '福岡県', 'フクオカケン', '遠賀郡岡垣町', 'オンガグンオカガキマチ', '松ケ台', 'マツガダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県遠賀郡岡垣町旭台', '40', '40383', '8114215', '福岡県', 'フクオカケン', '遠賀郡岡垣町', 'オンガグンオカガキマチ', '旭台', 'アサヒダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県遠賀郡岡垣町旭南', '40', '40383', '8114216', '福岡県', 'フクオカケン', '遠賀郡岡垣町', 'オンガグンオカガキマチ', '旭南', 'アサヒミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県遠賀郡岡垣町桜台', '40', '40383', '8114217', '福岡県', 'フクオカケン', '遠賀郡岡垣町', 'オンガグンオカガキマチ', '桜台', 'サクラダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県遠賀郡岡垣町中央台', '40', '40383', '8114218', '福岡県', 'フクオカケン', '遠賀郡岡垣町', 'オンガグンオカガキマチ', '中央台', 'チュウオウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県遠賀郡岡垣町東山田', '40', '40383', '8114220', '福岡県', 'フクオカケン', '遠賀郡岡垣町', 'オンガグンオカガキマチ', '東山田', 'ヒガシヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県遠賀郡岡垣町山田', '40', '40383', '8114221', '福岡県', 'フクオカケン', '遠賀郡岡垣町', 'オンガグンオカガキマチ', '山田', 'ヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県遠賀郡岡垣町戸切', '40', '40383', '8114222', '福岡県', 'フクオカケン', '遠賀郡岡垣町', 'オンガグンオカガキマチ', '戸切', 'トギリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県遠賀郡岡垣町山田峠', '40', '40383', '8114223', '福岡県', 'フクオカケン', '遠賀郡岡垣町', 'オンガグンオカガキマチ', '山田峠', 'ヤマダトウゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県遠賀郡岡垣町鍋田', '40', '40383', '8114224', '福岡県', 'フクオカケン', '遠賀郡岡垣町', 'オンガグンオカガキマチ', '鍋田', 'ナベタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県遠賀郡岡垣町東高陽', '40', '40383', '8114225', '福岡県', 'フクオカケン', '遠賀郡岡垣町', 'オンガグンオカガキマチ', '東高陽', 'ヒガシコウヨウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県遠賀郡岡垣町南高陽', '40', '40383', '8114226', '福岡県', 'フクオカケン', '遠賀郡岡垣町', 'オンガグンオカガキマチ', '南高陽', 'ミナミコウヨウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県遠賀郡岡垣町高陽台', '40', '40383', '8114227', '福岡県', 'フクオカケン', '遠賀郡岡垣町', 'オンガグンオカガキマチ', '高陽台', 'コウヨウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県遠賀郡岡垣町東松原', '40', '40383', '8114228', '福岡県', 'フクオカケン', '遠賀郡岡垣町', 'オンガグンオカガキマチ', '東松原', 'ヒガシマツバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県遠賀郡岡垣町百合ケ丘', '40', '40383', '8114229', '福岡県', 'フクオカケン', '遠賀郡岡垣町', 'オンガグンオカガキマチ', '百合ケ丘', 'ユリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県遠賀郡岡垣町海老津', '40', '40383', '8114231', '福岡県', 'フクオカケン', '遠賀郡岡垣町', 'オンガグンオカガキマチ', '海老津', 'エビツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県遠賀郡岡垣町上畑', '40', '40383', '8114232', '福岡県', 'フクオカケン', '遠賀郡岡垣町', 'オンガグンオカガキマチ', '上畑', 'ジョウハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県遠賀郡岡垣町野間', '40', '40383', '8114233', '福岡県', 'フクオカケン', '遠賀郡岡垣町', 'オンガグンオカガキマチ', '野間', 'ノマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県遠賀郡岡垣町高倉', '40', '40383', '8114234', '福岡県', 'フクオカケン', '遠賀郡岡垣町', 'オンガグンオカガキマチ', '高倉', 'タカクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県遠賀郡岡垣町公園通り', '40', '40383', '8114235', '福岡県', 'フクオカケン', '遠賀郡岡垣町', 'オンガグンオカガキマチ', '公園通り', 'コウエンドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県遠賀郡岡垣町海老津駅前', '40', '40383', '8114236', '福岡県', 'フクオカケン', '遠賀郡岡垣町', 'オンガグンオカガキマチ', '海老津駅前', 'エビツエキマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県遠賀郡岡垣町東高倉', '40', '40383', '8114237', '福岡県', 'フクオカケン', '遠賀郡岡垣町', 'オンガグンオカガキマチ', '東高倉', 'ヒガシタカクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県遠賀郡岡垣町海老津駅南', '40', '40383', '8114238', '福岡県', 'フクオカケン', '遠賀郡岡垣町', 'オンガグンオカガキマチ', '海老津駅南', 'エビツエキミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県遠賀郡岡垣町野間南', '40', '40383', '8114239', '福岡県', 'フクオカケン', '遠賀郡岡垣町', 'オンガグンオカガキマチ', '野間南', 'ノマミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県遠賀郡岡垣町吉木東', '40', '40383', '8114241', '福岡県', 'フクオカケン', '遠賀郡岡垣町', 'オンガグンオカガキマチ', '吉木東', 'ヨシキヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県遠賀郡岡垣町吉木西', '40', '40383', '8114242', '福岡県', 'フクオカケン', '遠賀郡岡垣町', 'オンガグンオカガキマチ', '吉木西', 'ヨシキニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県遠賀郡遠賀町', '40', '40384', '8114300', '福岡県', 'フクオカケン', '遠賀郡遠賀町', 'オンガグンオンガチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('104630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県遠賀郡遠賀町島津', '40', '40384', '8114301', '福岡県', 'フクオカケン', '遠賀郡遠賀町', 'オンガグンオンガチョウ', '島津', 'シマヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県遠賀郡遠賀町広渡', '40', '40384', '8114302', '福岡県', 'フクオカケン', '遠賀郡遠賀町', 'オンガグンオンガチョウ', '広渡', 'ヒロワタリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県遠賀郡遠賀町今古賀', '40', '40384', '8114303', '福岡県', 'フクオカケン', '遠賀郡遠賀町', 'オンガグンオンガチョウ', '今古賀', 'イマコガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県遠賀郡遠賀町若松', '40', '40384', '8114304', '福岡県', 'フクオカケン', '遠賀郡遠賀町', 'オンガグンオンガチョウ', '若松', 'ワカマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県遠賀郡遠賀町松の本', '40', '40384', '8114305', '福岡県', 'フクオカケン', '遠賀郡遠賀町', 'オンガグンオンガチョウ', '松の本', 'マツノモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県遠賀郡遠賀町旧停', '40', '40384', '8114306', '福岡県', 'フクオカケン', '遠賀郡遠賀町', 'オンガグンオンガチョウ', '旧停', 'キュウテイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県遠賀郡遠賀町遠賀川', '40', '40384', '8114307', '福岡県', 'フクオカケン', '遠賀郡遠賀町', 'オンガグンオンガチョウ', '遠賀川', 'オンガガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県遠賀郡遠賀町老良', '40', '40384', '8114311', '福岡県', 'フクオカケン', '遠賀郡遠賀町', 'オンガグンオンガチョウ', '老良', 'オイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県遠賀郡遠賀町浅木', '40', '40384', '8114312', '福岡県', 'フクオカケン', '遠賀郡遠賀町', 'オンガグンオンガチョウ', '浅木', 'アサギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県遠賀郡遠賀町木守', '40', '40384', '8114313', '福岡県', 'フクオカケン', '遠賀郡遠賀町', 'オンガグンオンガチョウ', '木守', 'キモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県遠賀郡遠賀町虫生津', '40', '40384', '8114321', '福岡県', 'フクオカケン', '遠賀郡遠賀町', 'オンガグンオンガチョウ', '虫生津', 'ムショウヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県遠賀郡遠賀町芙蓉', '40', '40384', '8114322', '福岡県', 'フクオカケン', '遠賀郡遠賀町', 'オンガグンオンガチョウ', '芙蓉', 'フヨウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県遠賀郡遠賀町若葉台', '40', '40384', '8114323', '福岡県', 'フクオカケン', '遠賀郡遠賀町', 'オンガグンオンガチョウ', '若葉台', 'ワカバダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県遠賀郡遠賀町虫生津南', '40', '40384', '8114324', '福岡県', 'フクオカケン', '遠賀郡遠賀町', 'オンガグンオンガチョウ', '虫生津南', 'ムショウヅミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県遠賀郡遠賀町別府', '40', '40384', '8114331', '福岡県', 'フクオカケン', '遠賀郡遠賀町', 'オンガグンオンガチョウ', '別府', 'ベフ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県遠賀郡遠賀町上別府', '40', '40384', '8114332', '福岡県', 'フクオカケン', '遠賀郡遠賀町', 'オンガグンオンガチョウ', '上別府', 'カミベフ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県遠賀郡遠賀町島門', '40', '40384', '8114333', '福岡県', 'フクオカケン', '遠賀郡遠賀町', 'オンガグンオンガチョウ', '島門', 'シマド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県遠賀郡遠賀町蓮角', '40', '40384', '8114334', '福岡県', 'フクオカケン', '遠賀郡遠賀町', 'オンガグンオンガチョウ', '蓮角', 'レンガク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県遠賀郡遠賀町鬼津', '40', '40384', '8114341', '福岡県', 'フクオカケン', '遠賀郡遠賀町', 'オンガグンオンガチョウ', '鬼津', 'オニヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県遠賀郡遠賀町尾崎', '40', '40384', '8114342', '福岡県', 'フクオカケン', '遠賀郡遠賀町', 'オンガグンオンガチョウ', '尾崎', 'オザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県遠賀郡遠賀町田園', '40', '40384', '8114343', '福岡県', 'フクオカケン', '遠賀郡遠賀町', 'オンガグンオンガチョウ', '田園', 'デンエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市', '42', '42210', '8115100', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('104654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市郷ノ浦町長峰本村触', '42', '42210', '8115101', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '郷ノ浦町長峰本村触', 'ゴウノウラチョウナガミネホンムラフレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市郷ノ浦町長峰東触', '42', '42210', '8115102', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '郷ノ浦町長峰東触', 'ゴウノウラチョウナガミネヒガシフレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市郷ノ浦町新田触', '42', '42210', '8115103', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '郷ノ浦町新田触', 'ゴウノウラチョウシンデンフレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市郷ノ浦町里触', '42', '42210', '8115104', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '郷ノ浦町里触', 'ゴウノウラチョウサトフレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市郷ノ浦町小牧西触', '42', '42210', '8115105', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '郷ノ浦町小牧西触', 'ゴウノウラチョウコマキニシフレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市郷ノ浦町小牧東触', '42', '42210', '8115106', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '郷ノ浦町小牧東触', 'ゴウノウラチョウコマキヒガシフレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市郷ノ浦町有安触', '42', '42210', '8115107', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '郷ノ浦町有安触', 'ゴウノウラチョウアリヤスフレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市郷ノ浦町半城本村触', '42', '42210', '8115111', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '郷ノ浦町半城本村触', 'ゴウノウラチョウハンセイホンムラフレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市郷ノ浦町大浦触', '42', '42210', '8115112', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '郷ノ浦町大浦触', 'ゴウノウラチョウオオウラフレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市郷ノ浦町牛方触', '42', '42210', '8115113', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '郷ノ浦町牛方触', 'ゴウノウラチョウウシカタフレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市郷ノ浦町柳田触', '42', '42210', '8115114', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '郷ノ浦町柳田触', 'ゴウノウラチョウヤナギダフレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市郷ノ浦町木田触', '42', '42210', '8115115', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '郷ノ浦町木田触', 'ゴウノウラチョウキダフレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市郷ノ浦町物部本村触', '42', '42210', '8115116', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '郷ノ浦町物部本村触', 'ゴウノウラチョウモノベホンムラフレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市郷ノ浦町田中触', '42', '42210', '8115117', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '郷ノ浦町田中触', 'ゴウノウラチョウタナカフレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市郷ノ浦町平人触', '42', '42210', '8115121', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '郷ノ浦町平人触', 'ゴウノウラチョウヒロウトフレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市郷ノ浦町大原触', '42', '42210', '8115122', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '郷ノ浦町大原触', 'ゴウノウラチョウタイバルフレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市郷ノ浦町釘山触', '42', '42210', '8115123', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '郷ノ浦町釘山触', 'ゴウノウラチョウクギヤマフレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市郷ノ浦町志原南触', '42', '42210', '8115124', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '郷ノ浦町志原南触', 'ゴウノウラチョウシハラミナミフレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市郷ノ浦町志原西触', '42', '42210', '8115125', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '郷ノ浦町志原西触', 'ゴウノウラチョウシハラニシフレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市郷ノ浦町永田触', '42', '42210', '8115131', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '郷ノ浦町永田触', 'ゴウノウラチョウナガタフレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市郷ノ浦町東触', '42', '42210', '8115132', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '郷ノ浦町東触', 'ゴウノウラチョウヒガシフレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市郷ノ浦町本村触', '42', '42210', '8115133', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '郷ノ浦町本村触', 'ゴウノウラチョウホンムラフレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市郷ノ浦町庄触', '42', '42210', '8115134', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '郷ノ浦町庄触', 'ゴウノウラチョウショウフレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市郷ノ浦町郷ノ浦', '42', '42210', '8115135', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '郷ノ浦町郷ノ浦', 'ゴウノウラチョウゴウノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市郷ノ浦町片原触', '42', '42210', '8115136', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '郷ノ浦町片原触', 'ゴウノウラチョウカタバルフレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市郷ノ浦町若松触', '42', '42210', '8115141', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '郷ノ浦町若松触', 'ゴウノウラチョウワカマツフレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市郷ノ浦町坪触', '42', '42210', '8115142', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '郷ノ浦町坪触', 'ゴウノウラチョウツボフレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市郷ノ浦町初山西触', '42', '42210', '8115143', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '郷ノ浦町初山西触', 'ゴウノウラチョウハツヤマニシフレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市郷ノ浦町初山東触', '42', '42210', '8115144', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '郷ノ浦町初山東触', 'ゴウノウラチョウハツヤマヒガシフレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市郷ノ浦町渡良浦', '42', '42210', '8115151', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '郷ノ浦町渡良浦', 'ゴウノウラチョウワタラウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市郷ノ浦町渡良南触', '42', '42210', '8115152', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '郷ノ浦町渡良南触', 'ゴウノウラチョウワタラミナミフレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市郷ノ浦町渡良西触', '42', '42210', '8115153', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '郷ノ浦町渡良西触', 'ゴウノウラチョウワタラニシフレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市郷ノ浦町渡良東触', '42', '42210', '8115154', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '郷ノ浦町渡良東触', 'ゴウノウラチョウワタラヒガシフレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市郷ノ浦町麦谷触', '42', '42210', '8115155', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '郷ノ浦町麦谷触', 'ゴウノウラチョウムギヤフレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市郷ノ浦町大島', '42', '42210', '8115161', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '郷ノ浦町大島', 'ゴウノウラチョウオオシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市郷ノ浦町長島', '42', '42210', '8115162', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '郷ノ浦町長島', 'ゴウノウラチョウナガシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市郷ノ浦町原島', '42', '42210', '8115163', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '郷ノ浦町原島', 'ゴウノウラチョウハルシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市石田町山崎触', '42', '42210', '8115201', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '石田町山崎触', 'イシダチョウヤマサキフレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市石田町筒城仲触', '42', '42210', '8115202', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '石田町筒城仲触', 'イシダチョウツツキナカフレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市石田町筒城東触', '42', '42210', '8115203', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '石田町筒城東触', 'イシダチョウツツキヒガシフレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市石田町筒城西触', '42', '42210', '8115204', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '石田町筒城西触', 'イシダチョウツツキニシフレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市石田町石田東触', '42', '42210', '8115211', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '石田町石田東触', 'イシダチョウイシダヒガシフレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市石田町本村触', '42', '42210', '8115212', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '石田町本村触', 'イシダチョウホンムラフレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市石田町南触', '42', '42210', '8115213', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '石田町南触', 'イシダチョウミナミフレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市石田町印通寺浦', '42', '42210', '8115214', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '石田町印通寺浦', 'イシダチョウインドオジウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市石田町石田西触', '42', '42210', '8115215', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '石田町石田西触', 'イシダチョウイシダニシフレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市石田町池田東触', '42', '42210', '8115221', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '石田町池田東触', 'イシダチョウイケダヒガシフレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市石田町池田仲触', '42', '42210', '8115222', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '石田町池田仲触', 'イシダチョウイケダナカフレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市石田町久喜触', '42', '42210', '8115223', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '石田町久喜触', 'イシダチョウクキフレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市石田町池田西触', '42', '42210', '8115224', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '石田町池田西触', 'イシダチョウイケダニシフレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市石田町湯岳興触', '42', '42210', '8115225', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '石田町湯岳興触', 'イシダチョウユタケコウフレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市石田町湯岳射手吉触', '42', '42210', '8115226', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '石田町湯岳射手吉触', 'イシダチョウユタケイテヨシフレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市芦辺町芦辺浦', '42', '42210', '8115301', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '芦辺町芦辺浦', 'アシベチョウアシベウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市芦辺町諸吉本村触', '42', '42210', '8115311', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '芦辺町諸吉本村触', 'アシベチョウモロヨシホンムラフレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市芦辺町諸吉南触', '42', '42210', '8115312', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '芦辺町諸吉南触', 'アシベチョウモロヨシミナミフレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市芦辺町諸吉仲触', '42', '42210', '8115313', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '芦辺町諸吉仲触', 'アシベチョウモロヨシナカフレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市芦辺町諸吉東触', '42', '42210', '8115314', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '芦辺町諸吉東触', 'アシベチョウモロヨシヒガシフレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市芦辺町諸吉二亦触', '42', '42210', '8115315', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '芦辺町諸吉二亦触', 'アシベチョウモロヨシフタマタフレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市芦辺町諸吉大石触', '42', '42210', '8115316', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '芦辺町諸吉大石触', 'アシベチョウモロヨシオオイシフレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市芦辺町深江栄触', '42', '42210', '8115321', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '芦辺町深江栄触', 'アシベチョウフカエサカエフレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市芦辺町深江鶴亀触', '42', '42210', '8115322', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '芦辺町深江鶴亀触', 'アシベチョウフカエツルキフレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市芦辺町深江平触', '42', '42210', '8115323', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '芦辺町深江平触', 'アシベチョウフカエヒラフレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市芦辺町深江東触', '42', '42210', '8115324', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '芦辺町深江東触', 'アシベチョウフカエヒガシフレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市芦辺町深江南触', '42', '42210', '8115325', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '芦辺町深江南触', 'アシベチョウフカエミナミフレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市芦辺町深江本村触', '42', '42210', '8115326', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '芦辺町深江本村触', 'アシベチョウフカエホンムラフレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市芦辺町瀬戸浦', '42', '42210', '8115461', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '芦辺町瀬戸浦', 'アシベチョウセトウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市芦辺町箱崎大左右触', '42', '42210', '8115462', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '芦辺町箱崎大左右触', 'アシベチョウハコザキタイソウフレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市芦辺町箱崎中山触', '42', '42210', '8115463', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '芦辺町箱崎中山触', 'アシベチョウハコザキナカヤマフレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市芦辺町箱崎谷江触', '42', '42210', '8115464', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '芦辺町箱崎谷江触', 'アシベチョウハコザキタニエフレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市芦辺町箱崎釘ノ尾触', '42', '42210', '8115465', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '芦辺町箱崎釘ノ尾触', 'アシベチョウハコザキクギノオフレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市芦辺町箱崎本村触', '42', '42210', '8115466', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '芦辺町箱崎本村触', 'アシベチョウハコザキホンムラフレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市芦辺町箱崎江角触', '42', '42210', '8115467', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '芦辺町箱崎江角触', 'アシベチョウハコザキエスミフレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市芦辺町箱崎諸津触', '42', '42210', '8115468', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '芦辺町箱崎諸津触', 'アシベチョウハコザキモロツフレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市勝本町勝本浦', '42', '42210', '8115501', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '勝本町勝本浦', 'カツモトチョウカツモトウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市勝本町仲触', '42', '42210', '8115511', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '勝本町仲触', 'カツモトチョウナカフレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市勝本町東触', '42', '42210', '8115512', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '勝本町東触', 'カツモトチョウヒガシフレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市勝本町北触', '42', '42210', '8115513', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '勝本町北触', 'カツモトチョウキタフレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市勝本町西戸触', '42', '42210', '8115521', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '勝本町西戸触', 'カツモトチョウサイドフレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市勝本町新城東触', '42', '42210', '8115522', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '勝本町新城東触', 'カツモトチョウシンジョウヒガシフレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市勝本町片山触', '42', '42210', '8115523', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '勝本町片山触', 'カツモトチョウカタヤマフレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市勝本町坂本触', '42', '42210', '8115531', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '勝本町坂本触', 'カツモトチョウサカモトフレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市勝本町大久保触', '42', '42210', '8115532', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '勝本町大久保触', 'カツモトチョウオオクボフレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市勝本町新城西触', '42', '42210', '8115533', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '勝本町新城西触', 'カツモトチョウシンジョウニシフレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市勝本町本宮西触', '42', '42210', '8115541', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '勝本町本宮西触', 'カツモトチョウホングウニシフレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市勝本町本宮東触', '42', '42210', '8115542', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '勝本町本宮東触', 'カツモトチョウホングウヒガシフレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市勝本町上場触', '42', '42210', '8115543', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '勝本町上場触', 'カツモトチョウウワバフレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市勝本町布気触', '42', '42210', '8115544', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '勝本町布気触', 'カツモトチョウフケフレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市勝本町本宮南触', '42', '42210', '8115545', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '勝本町本宮南触', 'カツモトチョウホングウミナミフレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市勝本町本宮仲触', '42', '42210', '8115546', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '勝本町本宮仲触', 'カツモトチョウホングウナカフレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市勝本町湯本浦', '42', '42210', '8115551', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '勝本町湯本浦', 'カツモトチョウユノモトウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市勝本町百合畑触', '42', '42210', '8115552', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '勝本町百合畑触', 'カツモトチョウユリハタフレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市勝本町立石東触', '42', '42210', '8115553', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '勝本町立石東触', 'カツモトチョウタテイシヒガシフレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市勝本町立石仲触', '42', '42210', '8115554', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '勝本町立石仲触', 'カツモトチョウタテイシナカフレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市勝本町立石南触', '42', '42210', '8115555', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '勝本町立石南触', 'カツモトチョウタテイシミナミフレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市勝本町立石西触', '42', '42210', '8115556', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '勝本町立石西触', 'カツモトチョウタテイシニシフレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市芦辺町国分当田触', '42', '42210', '8115731', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '芦辺町国分当田触', 'アシベチョウコクブトウダフレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市芦辺町国分東触', '42', '42210', '8115732', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '芦辺町国分東触', 'アシベチョウコクブヒガシフレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市芦辺町国分川迎触', '42', '42210', '8115733', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '芦辺町国分川迎触', 'アシベチョウコクブカワムカエフレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市芦辺町国分本村触', '42', '42210', '8115734', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '芦辺町国分本村触', 'アシベチョウコクブホンムラフレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市芦辺町住吉山信触', '42', '42210', '8115741', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '芦辺町住吉山信触', 'アシベチョウスミヨシヤマノブフレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市芦辺町住吉東触', '42', '42210', '8115742', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '芦辺町住吉東触', 'アシベチョウスミヨシヒガシフレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市芦辺町住吉前触', '42', '42210', '8115743', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '芦辺町住吉前触', 'アシベチョウスミヨシマエフレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市芦辺町住吉後触', '42', '42210', '8115744', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '芦辺町住吉後触', 'アシベチョウスミヨシウシロフレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市芦辺町中野郷仲触', '42', '42210', '8115751', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '芦辺町中野郷仲触', 'アシベチョウナカノゴウナカフレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市芦辺町中野郷東触', '42', '42210', '8115752', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '芦辺町中野郷東触', 'アシベチョウナカノゴウヒガシフレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市芦辺町湯岳本村触', '42', '42210', '8115753', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '芦辺町湯岳本村触', 'アシベチョウユタケホンムラフレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市芦辺町湯岳今坂触', '42', '42210', '8115754', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '芦辺町湯岳今坂触', 'アシベチョウユタケコンザカフレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市芦辺町湯岳興触', '42', '42210', '8115755', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '芦辺町湯岳興触', 'アシベチョウユタケコウフレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市芦辺町中野郷本村触', '42', '42210', '8115756', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '芦辺町中野郷本村触', 'アシベチョウナカノゴウホンムラフレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県壱岐市芦辺町中野郷西触', '42', '42210', '8115757', '長崎県', 'ナガサキケン', '壱岐市', 'イキシ', '芦辺町中野郷西触', 'アシベチョウナカノゴウニシフレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市博多区', '40', '40132', '8120000', '福岡県', 'フクオカケン', '福岡市博多区', 'フクオカシハカタク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('104766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市博多区大井', '40', '40132', '8120001', '福岡県', 'フクオカケン', '福岡市博多区', 'フクオカシハカタク', '大井', 'オオイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市博多区空港前', '40', '40132', '8120002', '福岡県', 'フクオカケン', '福岡市博多区', 'フクオカシハカタク', '空港前', 'クウコウマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市博多区下臼井', '40', '40132', '8120003', '福岡県', 'フクオカケン', '福岡市博多区', 'フクオカシハカタク', '下臼井', 'シモウスイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市博多区榎田', '40', '40132', '8120004', '福岡県', 'フクオカケン', '福岡市博多区', 'フクオカシハカタク', '榎田', 'エノキダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市博多区上臼井', '40', '40132', '8120005', '福岡県', 'フクオカケン', '福岡市博多区', 'フクオカシハカタク', '上臼井', 'カミウスイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市博多区上牟田', '40', '40132', '8120006', '福岡県', 'フクオカケン', '福岡市博多区', 'フクオカシハカタク', '上牟田', 'カミムタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市博多区東比恵', '40', '40132', '8120007', '福岡県', 'フクオカケン', '福岡市博多区', 'フクオカシハカタク', '東比恵', 'ヒガシヒエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市博多区東光', '40', '40132', '8120008', '福岡県', 'フクオカケン', '福岡市博多区', 'フクオカシハカタク', '東光', 'トウコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市博多区博多駅前', '40', '40132', '8120011', '福岡県', 'フクオカケン', '福岡市博多区', 'フクオカシハカタク', '博多駅前', 'ハカタエキマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市博多区博多駅中央街', '40', '40132', '8120012', '福岡県', 'フクオカケン', '福岡市博多区', 'フクオカシハカタク', '博多駅中央街', 'ハカタエキチュウオウガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市博多区博多駅東', '40', '40132', '8120013', '福岡県', 'フクオカケン', '福岡市博多区', 'フクオカシハカタク', '博多駅東', 'ハカタエキヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市博多区比恵町', '40', '40132', '8120014', '福岡県', 'フクオカケン', '福岡市博多区', 'フクオカシハカタク', '比恵町', 'ヒエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市博多区山王', '40', '40132', '8120015', '福岡県', 'フクオカケン', '福岡市博多区', 'フクオカシハカタク', '山王', 'サンノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市博多区博多駅南', '40', '40132', '8120016', '福岡県', 'フクオカケン', '福岡市博多区', 'フクオカシハカタク', '博多駅南', 'ハカタエキミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市博多区美野島', '40', '40132', '8120017', '福岡県', 'フクオカケン', '福岡市博多区', 'フクオカシハカタク', '美野島', 'ミノシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市博多区住吉', '40', '40132', '8120018', '福岡県', 'フクオカケン', '福岡市博多区', 'フクオカシハカタク', '住吉', 'スミヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市博多区対馬小路', '40', '40132', '8120020', '福岡県', 'フクオカケン', '福岡市博多区', 'フクオカシハカタク', '対馬小路', 'ツマショウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市博多区築港本町', '40', '40132', '8120021', '福岡県', 'フクオカケン', '福岡市博多区', 'フクオカシハカタク', '築港本町', 'チッコウホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市博多区神屋町', '40', '40132', '8120022', '福岡県', 'フクオカケン', '福岡市博多区', 'フクオカシハカタク', '神屋町', 'カミヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市博多区奈良屋町', '40', '40132', '8120023', '福岡県', 'フクオカケン', '福岡市博多区', 'フクオカシハカタク', '奈良屋町', 'ナラヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市博多区綱場町', '40', '40132', '8120024', '福岡県', 'フクオカケン', '福岡市博多区', 'フクオカシハカタク', '綱場町', 'ツナバマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市博多区店屋町', '40', '40132', '8120025', '福岡県', 'フクオカケン', '福岡市博多区', 'フクオカシハカタク', '店屋町', 'テンヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市博多区上川端町', '40', '40132', '8120026', '福岡県', 'フクオカケン', '福岡市博多区', 'フクオカシハカタク', '上川端町', 'カミカワバタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市博多区下川端町', '40', '40132', '8120027', '福岡県', 'フクオカケン', '福岡市博多区', 'フクオカシハカタク', '下川端町', 'シモカワバタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市博多区須崎町', '40', '40132', '8120028', '福岡県', 'フクオカケン', '福岡市博多区', 'フクオカシハカタク', '須崎町', 'スサキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市博多区古門戸町', '40', '40132', '8120029', '福岡県', 'フクオカケン', '福岡市博多区', 'フクオカシハカタク', '古門戸町', 'コモンドマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市博多区沖浜町', '40', '40132', '8120031', '福岡県', 'フクオカケン', '福岡市博多区', 'フクオカシハカタク', '沖浜町', 'オキハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市博多区石城町', '40', '40132', '8120032', '福岡県', 'フクオカケン', '福岡市博多区', 'フクオカシハカタク', '石城町', 'セキジョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市博多区大博町', '40', '40132', '8120033', '福岡県', 'フクオカケン', '福岡市博多区', 'フクオカシハカタク', '大博町', 'タイハクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市博多区下呉服町', '40', '40132', '8120034', '福岡県', 'フクオカケン', '福岡市博多区', 'フクオカシハカタク', '下呉服町', 'シモゴフクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市博多区中呉服町', '40', '40132', '8120035', '福岡県', 'フクオカケン', '福岡市博多区', 'フクオカシハカタク', '中呉服町', 'ナカゴフクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市博多区上呉服町', '40', '40132', '8120036', '福岡県', 'フクオカケン', '福岡市博多区', 'フクオカシハカタク', '上呉服町', 'カミゴフクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市博多区御供所町', '40', '40132', '8120037', '福岡県', 'フクオカケン', '福岡市博多区', 'フクオカシハカタク', '御供所町', 'ゴクショマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市博多区祗園町', '40', '40132', '8120038', '福岡県', 'フクオカケン', '福岡市博多区', 'フクオカシハカタク', '祗園町', 'ギオンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市博多区冷泉町', '40', '40132', '8120039', '福岡県', 'フクオカケン', '福岡市博多区', 'フクオカシハカタク', '冷泉町', 'レイセンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市博多区吉塚', '40', '40132', '8120041', '福岡県', 'フクオカケン', '福岡市博多区', 'フクオカシハカタク', '吉塚', 'ヨシヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市博多区豊', '40', '40132', '8120042', '福岡県', 'フクオカケン', '福岡市博多区', 'フクオカシハカタク', '豊', 'ユタカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市博多区堅粕', '40', '40132', '8120043', '福岡県', 'フクオカケン', '福岡市博多区', 'フクオカシハカタク', '堅粕', 'カタカス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市博多区千代', '40', '40132', '8120044', '福岡県', 'フクオカケン', '福岡市博多区', 'フクオカシハカタク', '千代', 'チヨ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市博多区東公園', '40', '40132', '8120045', '福岡県', 'フクオカケン', '福岡市博多区', 'フクオカシハカタク', '東公園', 'ヒガシコウエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市博多区吉塚本町', '40', '40132', '8120046', '福岡県', 'フクオカケン', '福岡市博多区', 'フクオカシハカタク', '吉塚本町', 'ヨシヅカホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市東区箱崎ふ頭', '40', '40131', '8120051', '福岡県', 'フクオカケン', '福岡市東区', 'フクオカシヒガシク', '箱崎ふ頭', 'ハコザキフトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市東区貝塚団地', '40', '40131', '8120052', '福岡県', 'フクオカケン', '福岡市東区', 'フクオカシヒガシク', '貝塚団地', 'カイヅカダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市東区箱崎', '40', '40131', '8120053', '福岡県', 'フクオカケン', '福岡市東区', 'フクオカシヒガシク', '箱崎', 'ハコザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市東区馬出', '40', '40131', '8120054', '福岡県', 'フクオカケン', '福岡市東区', 'フクオカシヒガシク', '馬出', 'マイダシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市東区東浜', '40', '40131', '8120055', '福岡県', 'フクオカケン', '福岡市東区', 'フクオカシヒガシク', '東浜', 'ヒガシハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市東区筥松', '40', '40131', '8120061', '福岡県', 'フクオカケン', '福岡市東区', 'フクオカシヒガシク', '筥松', 'ハコマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市東区松島1丁目', '40', '40131', '8120062', '福岡県', 'フクオカケン', '福岡市東区', 'フクオカシヒガシク', '松島', 'マツシマ', null, null, '1丁目', '01チョウメ');
INSERT INTO `ms_addresses` VALUES ('104814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市東区松島2丁目', '40', '40131', '8120062', '福岡県', 'フクオカケン', '福岡市東区', 'フクオカシヒガシク', '松島', 'マツシマ', null, null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('104815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市東区原田', '40', '40131', '8120063', '福岡県', 'フクオカケン', '福岡市東区', 'フクオカシヒガシク', '原田', 'ハラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市東区松田', '40', '40131', '8120064', '福岡県', 'フクオカケン', '福岡市東区', 'フクオカシヒガシク', '松田', 'マツダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市東区二又瀬新町', '40', '40131', '8120065', '福岡県', 'フクオカケン', '福岡市東区', 'フクオカシヒガシク', '二又瀬新町', 'フタマタセシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市東区二又瀬', '40', '40131', '8120066', '福岡県', 'フクオカケン', '福岡市東区', 'フクオカシヒガシク', '二又瀬', 'フタマタセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市東区筥松新町', '40', '40131', '8120067', '福岡県', 'フクオカケン', '福岡市東区', 'フクオカシヒガシク', '筥松新町', 'ハコマツシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市東区社領', '40', '40131', '8120068', '福岡県', 'フクオカケン', '福岡市東区', 'フクオカシヒガシク', '社領', 'シャリョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市東区郷口町', '40', '40131', '8120069', '福岡県', 'フクオカケン', '福岡市東区', 'フクオカシヒガシク', '郷口町', 'ゴウグチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市博多区青木', '40', '40132', '8120851', '福岡県', 'フクオカケン', '福岡市博多区', 'フクオカシハカタク', '青木', 'アオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市博多区東平尾公園', '40', '40132', '8120852', '福岡県', 'フクオカケン', '福岡市博多区', 'フクオカシハカタク', '東平尾公園', 'ヒガシヒラオコウエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市博多区東平尾', '40', '40132', '8120853', '福岡県', 'フクオカケン', '福岡市博多区', 'フクオカシハカタク', '東平尾', 'ヒガシヒラオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市博多区東月隈', '40', '40132', '8120854', '福岡県', 'フクオカケン', '福岡市博多区', 'フクオカシハカタク', '東月隈', 'ヒガシツキグマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市博多区下月隈', '40', '40132', '8120855', '福岡県', 'フクオカケン', '福岡市博多区', 'フクオカシハカタク', '下月隈', 'シモツキグマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市博多区西月隈', '40', '40132', '8120857', '福岡県', 'フクオカケン', '福岡市博多区', 'フクオカシハカタク', '西月隈', 'ニシツキグマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市博多区月隈', '40', '40132', '8120858', '福岡県', 'フクオカケン', '福岡市博多区', 'フクオカシハカタク', '月隈', 'ツキグマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市博多区浦田', '40', '40132', '8120861', '福岡県', 'フクオカケン', '福岡市博多区', 'フクオカシハカタク', '浦田', 'ウラタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市博多区立花寺', '40', '40132', '8120862', '福岡県', 'フクオカケン', '福岡市博多区', 'フクオカシハカタク', '立花寺', 'リュウゲジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市博多区金の隈', '40', '40132', '8120863', '福岡県', 'フクオカケン', '福岡市博多区', 'フクオカシハカタク', '金の隈', 'カネノクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市博多区東雲町', '40', '40132', '8120871', '福岡県', 'フクオカケン', '福岡市博多区', 'フクオカシハカタク', '東雲町', 'シノノメマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市博多区春町', '40', '40132', '8120872', '福岡県', 'フクオカケン', '福岡市博多区', 'フクオカシハカタク', '春町', 'ハルマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市博多区西春町', '40', '40132', '8120873', '福岡県', 'フクオカケン', '福岡市博多区', 'フクオカシハカタク', '西春町', 'ニシハルマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市博多区光丘町', '40', '40132', '8120874', '福岡県', 'フクオカケン', '福岡市博多区', 'フクオカシハカタク', '光丘町', 'ヒカリガオカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市博多区新和町', '40', '40132', '8120875', '福岡県', 'フクオカケン', '福岡市博多区', 'フクオカシハカタク', '新和町', 'シンワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市博多区昭南町', '40', '40132', '8120876', '福岡県', 'フクオカケン', '福岡市博多区', 'フクオカシハカタク', '昭南町', 'ショウナンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市博多区元町', '40', '40132', '8120877', '福岡県', 'フクオカケン', '福岡市博多区', 'フクオカシハカタク', '元町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市博多区竹丘町', '40', '40132', '8120878', '福岡県', 'フクオカケン', '福岡市博多区', 'フクオカシハカタク', '竹丘町', 'タケオカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市博多区銀天町', '40', '40132', '8120879', '福岡県', 'フクオカケン', '福岡市博多区', 'フクオカシハカタク', '銀天町', 'ギンテンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市博多区井相田', '40', '40132', '8120881', '福岡県', 'フクオカケン', '福岡市博多区', 'フクオカシハカタク', '井相田', 'イソウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市博多区麦野', '40', '40132', '8120882', '福岡県', 'フクオカケン', '福岡市博多区', 'フクオカシハカタク', '麦野', 'ムギノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市博多区南本町', '40', '40132', '8120883', '福岡県', 'フクオカケン', '福岡市博多区', 'フクオカシハカタク', '南本町', 'ミナミホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市博多区寿町', '40', '40132', '8120884', '福岡県', 'フクオカケン', '福岡市博多区', 'フクオカシハカタク', '寿町', 'コトブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市博多区相生町', '40', '40132', '8120885', '福岡県', 'フクオカケン', '福岡市博多区', 'フクオカシハカタク', '相生町', 'アイオイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市博多区南八幡町', '40', '40132', '8120886', '福岡県', 'フクオカケン', '福岡市博多区', 'フクオカシハカタク', '南八幡町', 'ミナミハチマンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市博多区三筑', '40', '40132', '8120887', '福岡県', 'フクオカケン', '福岡市博多区', 'フクオカシハカタク', '三筑', 'サンチク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市博多区板付', '40', '40132', '8120888', '福岡県', 'フクオカケン', '福岡市博多区', 'フクオカシハカタク', '板付', 'イタヅケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市博多区雀居', '40', '40132', '8120891', '福岡県', 'フクオカケン', '福岡市博多区', 'フクオカシハカタク', '雀居', 'ササイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市博多区東那珂', '40', '40132', '8120892', '福岡県', 'フクオカケン', '福岡市博多区', 'フクオカシハカタク', '東那珂', 'ヒガシナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市博多区那珂', '40', '40132', '8120893', '福岡県', 'フクオカケン', '福岡市博多区', 'フクオカシハカタク', '那珂', 'ナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市博多区諸岡', '40', '40132', '8120894', '福岡県', 'フクオカケン', '福岡市博多区', 'フクオカシハカタク', '諸岡', 'モロオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市博多区竹下', '40', '40132', '8120895', '福岡県', 'フクオカケン', '福岡市博多区', 'フクオカシハカタク', '竹下', 'タケシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市博多区東光寺町', '40', '40132', '8120896', '福岡県', 'フクオカケン', '福岡市博多区', 'フクオカシハカタク', '東光寺町', 'トウコウジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('104855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市博多区半道橋', '40', '40132', '8120897', '福岡県', 'フクオカケン', '福岡市博多区', 'フクオカシハカタク', '半道橋', 'ハンミチバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市東区', '40', '40131', '8130000', '福岡県', 'フクオカケン', '福岡市東区', 'フクオカシヒガシク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('105026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市東区唐原', '40', '40131', '8130001', '福岡県', 'フクオカケン', '福岡市東区', 'フクオカシヒガシク', '唐原', 'トウノハル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市東区下原', '40', '40131', '8130002', '福岡県', 'フクオカケン', '福岡市東区', 'フクオカシヒガシク', '下原', 'シモバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市東区香住ケ丘', '40', '40131', '8130003', '福岡県', 'フクオカケン', '福岡市東区', 'フクオカシヒガシク', '香住ケ丘', 'カスミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市東区松香台', '40', '40131', '8130004', '福岡県', 'フクオカケン', '福岡市東区', 'フクオカシヒガシク', '松香台', 'マツカダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市東区御島崎', '40', '40131', '8130005', '福岡県', 'フクオカケン', '福岡市東区', 'フクオカシヒガシク', '御島崎', 'ミシマザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糟屋郡粕屋町内橋', '40', '40349', '8130008', '福岡県', 'フクオカケン', '糟屋郡粕屋町', 'カスヤグンカスヤマチ', '内橋', 'ウチハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市東区香椎', '40', '40131', '8130011', '福岡県', 'フクオカケン', '福岡市東区', 'フクオカシヒガシク', '香椎', 'カシイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市東区香椎駅東', '40', '40131', '8130012', '福岡県', 'フクオカケン', '福岡市東区', 'フクオカシヒガシク', '香椎駅東', 'カシイエキヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市東区香椎駅前', '40', '40131', '8130013', '福岡県', 'フクオカケン', '福岡市東区', 'フクオカシヒガシク', '香椎駅前', 'カシイエキマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市東区香椎台', '40', '40131', '8130014', '福岡県', 'フクオカケン', '福岡市東区', 'フクオカシヒガシク', '香椎台', 'カシイダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市東区香椎団地', '40', '40131', '8130015', '福岡県', 'フクオカケン', '福岡市東区', 'フクオカシヒガシク', '香椎団地', 'カシイダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市東区香椎浜', '40', '40131', '8130016', '福岡県', 'フクオカケン', '福岡市東区', 'フクオカシヒガシク', '香椎浜', 'カシイハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市東区香椎照葉', '40', '40131', '8130017', '福岡県', 'フクオカケン', '福岡市東区', 'フクオカシヒガシク', '香椎照葉', 'カシイテリハ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市東区みどりが丘', '40', '40131', '8130021', '福岡県', 'フクオカケン', '福岡市東区', 'フクオカシヒガシク', 'みどりが丘', 'ミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市東区蒲田', '40', '40131', '8130023', '福岡県', 'フクオカケン', '福岡市東区', 'フクオカシヒガシク', '蒲田', 'カマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市東区名子', '40', '40131', '8130024', '福岡県', 'フクオカケン', '福岡市東区', 'フクオカシヒガシク', '名子', 'ナゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市東区青葉', '40', '40131', '8130025', '福岡県', 'フクオカケン', '福岡市東区', 'フクオカシヒガシク', '青葉', 'アオバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市東区八田', '40', '40131', '8130031', '福岡県', 'フクオカケン', '福岡市東区', 'フクオカシヒガシク', '八田', 'ハッタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市東区土井', '40', '40131', '8130032', '福岡県', 'フクオカケン', '福岡市東区', 'フクオカシヒガシク', '土井', 'ドイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市東区多々良', '40', '40131', '8130033', '福岡県', 'フクオカケン', '福岡市東区', 'フクオカシヒガシク', '多々良', 'タタラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市東区多の津', '40', '40131', '8130034', '福岡県', 'フクオカケン', '福岡市東区', 'フクオカシヒガシク', '多の津', 'タノツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市東区松崎', '40', '40131', '8130035', '福岡県', 'フクオカケン', '福岡市東区', 'フクオカシヒガシク', '松崎', 'マツザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市東区若宮', '40', '40131', '8130036', '福岡県', 'フクオカケン', '福岡市東区', 'フクオカシヒガシク', '若宮', 'ワカミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市東区水谷', '40', '40131', '8130041', '福岡県', 'フクオカケン', '福岡市東区', 'フクオカシヒガシク', '水谷', 'ミズタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市東区舞松原', '40', '40131', '8130042', '福岡県', 'フクオカケン', '福岡市東区', 'フクオカシヒガシク', '舞松原', 'マイマツバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市東区名島', '40', '40131', '8130043', '福岡県', 'フクオカケン', '福岡市東区', 'フクオカシヒガシク', '名島', 'ナジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市東区千早', '40', '40131', '8130044', '福岡県', 'フクオカケン', '福岡市東区', 'フクオカシヒガシク', '千早', 'チハヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市東区城浜団地', '40', '40131', '8130045', '福岡県', 'フクオカケン', '福岡市東区', 'フクオカシヒガシク', '城浜団地', 'シロハマダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市東区松島3丁目', '40', '40131', '8130062', '福岡県', 'フクオカケン', '福岡市東区', 'フクオカシヒガシク', '松島', 'マツシマ', null, null, '3丁目', '03チョウメ');
INSERT INTO `ms_addresses` VALUES ('105055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市東区松島4丁目', '40', '40131', '8130062', '福岡県', 'フクオカケン', '福岡市東区', 'フクオカシヒガシク', '松島', 'マツシマ', null, null, '4丁目', '04チョウメ');
INSERT INTO `ms_addresses` VALUES ('105056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市東区松島5丁目', '40', '40131', '8130062', '福岡県', 'フクオカケン', '福岡市東区', 'フクオカシヒガシク', '松島', 'マツシマ', null, null, '5丁目', '05チョウメ');
INSERT INTO `ms_addresses` VALUES ('105057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市東区松島6丁目', '40', '40131', '8130062', '福岡県', 'フクオカケン', '福岡市東区', 'フクオカシヒガシク', '松島', 'マツシマ', null, null, '6丁目', '06チョウメ');
INSERT INTO `ms_addresses` VALUES ('105073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市早良区', '40', '40137', '8140000', '福岡県', 'フクオカケン', '福岡市早良区', 'フクオカシサワラク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('105074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市早良区百道浜', '40', '40137', '8140001', '福岡県', 'フクオカケン', '福岡市早良区', 'フクオカシサワラク', '百道浜', 'モモチハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市早良区西新', '40', '40137', '8140002', '福岡県', 'フクオカケン', '福岡市早良区', 'フクオカシサワラク', '西新', 'ニシジン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市早良区城西', '40', '40137', '8140003', '福岡県', 'フクオカケン', '福岡市早良区', 'フクオカシサワラク', '城西', 'ジョウセイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市早良区曙', '40', '40137', '8140004', '福岡県', 'フクオカケン', '福岡市早良区', 'フクオカシサワラク', '曙', 'アケボノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市早良区祖原', '40', '40137', '8140005', '福岡県', 'フクオカケン', '福岡市早良区', 'フクオカシサワラク', '祖原', 'ソハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市早良区百道', '40', '40137', '8140006', '福岡県', 'フクオカケン', '福岡市早良区', 'フクオカシサワラク', '百道', 'モモチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市早良区高取', '40', '40137', '8140011', '福岡県', 'フクオカケン', '福岡市早良区', 'フクオカシサワラク', '高取', 'タカトリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市早良区昭代', '40', '40137', '8140012', '福岡県', 'フクオカケン', '福岡市早良区', 'フクオカシサワラク', '昭代', 'ショウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市早良区藤崎', '40', '40137', '8140013', '福岡県', 'フクオカケン', '福岡市早良区', 'フクオカシサワラク', '藤崎', 'フジサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市早良区弥生', '40', '40137', '8140014', '福岡県', 'フクオカケン', '福岡市早良区', 'フクオカシサワラク', '弥生', 'ヤヨイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市早良区室見', '40', '40137', '8140015', '福岡県', 'フクオカケン', '福岡市早良区', 'フクオカシサワラク', '室見', 'ムロミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市早良区荒江', '40', '40137', '8140021', '福岡県', 'フクオカケン', '福岡市早良区', 'フクオカシサワラク', '荒江', 'アラエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市早良区原', '40', '40137', '8140022', '福岡県', 'フクオカケン', '福岡市早良区', 'フクオカシサワラク', '原', 'ハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市早良区原団地', '40', '40137', '8140023', '福岡県', 'フクオカケン', '福岡市早良区', 'フクオカシサワラク', '原団地', 'ハラダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市早良区南庄', '40', '40137', '8140031', '福岡県', 'フクオカケン', '福岡市早良区', 'フクオカシサワラク', '南庄', 'ミナミショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市早良区小田部', '40', '40137', '8140032', '福岡県', 'フクオカケン', '福岡市早良区', 'フクオカシサワラク', '小田部', 'コタベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市早良区有田', '40', '40137', '8140033', '福岡県', 'フクオカケン', '福岡市早良区', 'フクオカシサワラク', '有田', 'アリタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市早良区有田団地', '40', '40137', '8140034', '福岡県', 'フクオカケン', '福岡市早良区', 'フクオカシサワラク', '有田団地', 'アリタダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市早良区室住団地', '40', '40137', '8140035', '福岡県', 'フクオカケン', '福岡市早良区', 'フクオカシサワラク', '室住団地', 'ムロズミダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市城南区', '40', '40136', '8140100', '福岡県', 'フクオカケン', '福岡市城南区', 'フクオカシジョウナンク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('105094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市城南区荒江', '40', '40136', '8140101', '福岡県', 'フクオカケン', '福岡市城南区', 'フクオカシジョウナンク', '荒江', 'アラエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市城南区荒江団地', '40', '40136', '8140102', '福岡県', 'フクオカケン', '福岡市城南区', 'フクオカシジョウナンク', '荒江団地', 'アラエダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市城南区鳥飼', '40', '40136', '8140103', '福岡県', 'フクオカケン', '福岡市城南区', 'フクオカシジョウナンク', '鳥飼', 'トリカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市城南区別府', '40', '40136', '8140104', '福岡県', 'フクオカケン', '福岡市城南区', 'フクオカシジョウナンク', '別府', 'ベフ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市城南区城西団地', '40', '40136', '8140105', '福岡県', 'フクオカケン', '福岡市城南区', 'フクオカシジョウナンク', '城西団地', 'ジョウセイダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市城南区別府団地', '40', '40136', '8140106', '福岡県', 'フクオカケン', '福岡市城南区', 'フクオカシジョウナンク', '別府団地', 'ベフダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市城南区茶山', '40', '40136', '8140111', '福岡県', 'フクオカケン', '福岡市城南区', 'フクオカシジョウナンク', '茶山', 'チャヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市城南区友丘', '40', '40136', '8140112', '福岡県', 'フクオカケン', '福岡市城南区', 'フクオカシジョウナンク', '友丘', 'トモオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市城南区田島', '40', '40136', '8140113', '福岡県', 'フクオカケン', '福岡市城南区', 'フクオカシジョウナンク', '田島', 'タシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市城南区金山団地', '40', '40136', '8140114', '福岡県', 'フクオカケン', '福岡市城南区', 'フクオカシジョウナンク', '金山団地', 'カナヤマダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市城南区神松寺', '40', '40136', '8140121', '福岡県', 'フクオカケン', '福岡市城南区', 'フクオカシジョウナンク', '神松寺', 'シンショウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市城南区友泉亭', '40', '40136', '8140122', '福岡県', 'フクオカケン', '福岡市城南区', 'フクオカシジョウナンク', '友泉亭', 'ユウセンテイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市城南区長尾', '40', '40136', '8140123', '福岡県', 'フクオカケン', '福岡市城南区', 'フクオカシジョウナンク', '長尾', 'ナガオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市城南区松山', '40', '40136', '8140131', '福岡県', 'フクオカケン', '福岡市城南区', 'フクオカシジョウナンク', '松山', 'マツヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市城南区干隈', '40', '40136', '8140132', '福岡県', 'フクオカケン', '福岡市城南区', 'フクオカシジョウナンク', '干隈', 'ホシクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市城南区七隈', '40', '40136', '8140133', '福岡県', 'フクオカケン', '福岡市城南区', 'フクオカシジョウナンク', '七隈', 'ナナクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市城南区飯倉', '40', '40136', '8140134', '福岡県', 'フクオカケン', '福岡市城南区', 'フクオカシジョウナンク', '飯倉', 'イイクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市城南区西片江', '40', '40136', '8140141', '福岡県', 'フクオカケン', '福岡市城南区', 'フクオカシジョウナンク', '西片江', 'ニシカタエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市城南区片江', '40', '40136', '8140142', '福岡県', 'フクオカケン', '福岡市城南区', 'フクオカシジョウナンク', '片江', 'カタエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市城南区南片江', '40', '40136', '8140143', '福岡県', 'フクオカケン', '福岡市城南区', 'フクオカシジョウナンク', '南片江', 'ミナミカタエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市城南区梅林', '40', '40136', '8140144', '福岡県', 'フクオカケン', '福岡市城南区', 'フクオカシジョウナンク', '梅林', 'ウメバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市城南区堤', '40', '40136', '8140151', '福岡県', 'フクオカケン', '福岡市城南区', 'フクオカシジョウナンク', '堤', 'ツツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市城南区堤団地', '40', '40136', '8140152', '福岡県', 'フクオカケン', '福岡市城南区', 'フクオカシジョウナンク', '堤団地', 'ツツミダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市城南区樋井川', '40', '40136', '8140153', '福岡県', 'フクオカケン', '福岡市城南区', 'フクオカシジョウナンク', '樋井川', 'ヒイガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市城南区宝台団地', '40', '40136', '8140154', '福岡県', 'フクオカケン', '福岡市城南区', 'フクオカシジョウナンク', '宝台団地', 'タカラダイダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市城南区東油山', '40', '40136', '8140155', '福岡県', 'フクオカケン', '福岡市城南区', 'フクオカシジョウナンク', '東油山', 'ヒガシアブラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市早良区飯倉', '40', '40137', '8140161', '福岡県', 'フクオカケン', '福岡市早良区', 'フクオカシサワラク', '飯倉', 'イイクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市早良区星の原団地', '40', '40137', '8140162', '福岡県', 'フクオカケン', '福岡市早良区', 'フクオカシサワラク', '星の原団地', 'ホシノハラダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市早良区干隈', '40', '40137', '8140163', '福岡県', 'フクオカケン', '福岡市早良区', 'フクオカシサワラク', '干隈', 'ホシクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市早良区賀茂', '40', '40137', '8140164', '福岡県', 'フクオカケン', '福岡市早良区', 'フクオカシサワラク', '賀茂', 'カモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市早良区次郎丸', '40', '40137', '8140165', '福岡県', 'フクオカケン', '福岡市早良区', 'フクオカシサワラク', '次郎丸', 'ジロウマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市早良区野芥', '40', '40137', '8140171', '福岡県', 'フクオカケン', '福岡市早良区', 'フクオカシサワラク', '野芥', 'ノケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市早良区梅林', '40', '40137', '8140172', '福岡県', 'フクオカケン', '福岡市早良区', 'フクオカシサワラク', '梅林', 'ウメバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市早良区西油山', '40', '40137', '8140173', '福岡県', 'フクオカケン', '福岡市早良区', 'フクオカシサワラク', '西油山', 'ニシアブラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市早良区田隈', '40', '40137', '8140174', '福岡県', 'フクオカケン', '福岡市早良区', 'フクオカシサワラク', '田隈', 'タグマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市早良区田村', '40', '40137', '8140175', '福岡県', 'フクオカケン', '福岡市早良区', 'フクオカシサワラク', '田村', 'タムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市早良区四箇田団地', '40', '40137', '8140176', '福岡県', 'フクオカケン', '福岡市早良区', 'フクオカシサワラク', '四箇田団地', 'シカタダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市早良区田', '40', '40137', '8140177', '福岡県', 'フクオカケン', '福岡市早良区', 'フクオカシサワラク', '田', 'タ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市南区', '40', '40134', '8150000', '福岡県', 'フクオカケン', '福岡市南区', 'フクオカシミナミク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('105161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市南区五十川', '40', '40134', '8150001', '福岡県', 'フクオカケン', '福岡市南区', 'フクオカシミナミク', '五十川', 'ゴジッカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市南区高木', '40', '40134', '8150004', '福岡県', 'フクオカケン', '福岡市南区', 'フクオカシミナミク', '高木', 'タカキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市南区清水', '40', '40134', '8150031', '福岡県', 'フクオカケン', '福岡市南区', 'フクオカシミナミク', '清水', 'シミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市南区塩原', '40', '40134', '8150032', '福岡県', 'フクオカケン', '福岡市南区', 'フクオカシミナミク', '塩原', 'シオバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市南区大橋', '40', '40134', '8150033', '福岡県', 'フクオカケン', '福岡市南区', 'フクオカシミナミク', '大橋', 'オオハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市南区南大橋', '40', '40134', '8150034', '福岡県', 'フクオカケン', '福岡市南区', 'フクオカシミナミク', '南大橋', 'ミナミオオハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市南区向野', '40', '40134', '8150035', '福岡県', 'フクオカケン', '福岡市南区', 'フクオカシミナミク', '向野', 'ムカイノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市南区筑紫丘', '40', '40134', '8150036', '福岡県', 'フクオカケン', '福岡市南区', 'フクオカシミナミク', '筑紫丘', 'チクシガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市南区玉川町', '40', '40134', '8150037', '福岡県', 'フクオカケン', '福岡市南区', 'フクオカシミナミク', '玉川町', 'タマガワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市南区大橋団地', '40', '40134', '8150038', '福岡県', 'フクオカケン', '福岡市南区', 'フクオカシミナミク', '大橋団地', 'オオハシダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市南区野間', '40', '40134', '8150041', '福岡県', 'フクオカケン', '福岡市南区', 'フクオカシミナミク', '野間', 'ノマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市南区若久', '40', '40134', '8150042', '福岡県', 'フクオカケン', '福岡市南区', 'フクオカシミナミク', '若久', 'ワカヒサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市南区若久団地', '40', '40134', '8150048', '福岡県', 'フクオカケン', '福岡市南区', 'フクオカシミナミク', '若久団地', 'ワカヒサダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市南区柳河内', '40', '40134', '8150063', '福岡県', 'フクオカケン', '福岡市南区', 'フクオカシミナミク', '柳河内', 'ヤナゴウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市南区平和', '40', '40134', '8150071', '福岡県', 'フクオカケン', '福岡市南区', 'フクオカシミナミク', '平和', 'ヘイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市南区多賀', '40', '40134', '8150072', '福岡県', 'フクオカケン', '福岡市南区', 'フクオカシミナミク', '多賀', 'タガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市南区大池', '40', '40134', '8150073', '福岡県', 'フクオカケン', '福岡市南区', 'フクオカシミナミク', '大池', 'オオイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市南区寺塚', '40', '40134', '8150074', '福岡県', 'フクオカケン', '福岡市南区', 'フクオカシミナミク', '寺塚', 'テラヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市南区長丘', '40', '40134', '8150075', '福岡県', 'フクオカケン', '福岡市南区', 'フクオカシミナミク', '長丘', 'ナガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市南区那の川', '40', '40134', '8150081', '福岡県', 'フクオカケン', '福岡市南区', 'フクオカシミナミク', '那の川', 'ナノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市南区大楠', '40', '40134', '8150082', '福岡県', 'フクオカケン', '福岡市南区', 'フクオカシミナミク', '大楠', 'オオグス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市南区高宮', '40', '40134', '8150083', '福岡県', 'フクオカケン', '福岡市南区', 'フクオカシミナミク', '高宮', 'タカミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市南区市崎', '40', '40134', '8150084', '福岡県', 'フクオカケン', '福岡市南区', 'フクオカシミナミク', '市崎', 'イチザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県春日市', '40', '40218', '8160000', '福岡県', 'フクオカケン', '春日市', 'カスガシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('105200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大野城市', '40', '40219', '8160000', '福岡県', 'フクオカケン', '大野城市', 'オオノジョウシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('105201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県春日市春日原東町', '40', '40218', '8160801', '福岡県', 'フクオカケン', '春日市', 'カスガシ', '春日原東町', 'カスガバルヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県春日市春日原北町', '40', '40218', '8160802', '福岡県', 'フクオカケン', '春日市', 'カスガシ', '春日原北町', 'カスガバルキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県春日市春日原南町', '40', '40218', '8160803', '福岡県', 'フクオカケン', '春日市', 'カスガシ', '春日原南町', 'カスガバルミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県春日市原町', '40', '40218', '8160804', '福岡県', 'フクオカケン', '春日市', 'カスガシ', '原町', 'ハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県春日市千歳町', '40', '40218', '8160805', '福岡県', 'フクオカケン', '春日市', 'カスガシ', '千歳町', 'チトセマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県春日市光町', '40', '40218', '8160806', '福岡県', 'フクオカケン', '春日市', 'カスガシ', '光町', 'ヒカリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県春日市宝町', '40', '40218', '8160807', '福岡県', 'フクオカケン', '春日市', 'カスガシ', '宝町', 'タカラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県春日市春日公園', '40', '40218', '8160811', '福岡県', 'フクオカケン', '春日市', 'カスガシ', '春日公園', 'カスガコウエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県春日市平田台', '40', '40218', '8160812', '福岡県', 'フクオカケン', '春日市', 'カスガシ', '平田台', 'ヒラタダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大野城市平田台', '40', '40219', '8160812', '福岡県', 'フクオカケン', '大野城市', 'オオノジョウシ', '平田台', 'ヒラタダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県春日市惣利', '40', '40218', '8160813', '福岡県', 'フクオカケン', '春日市', 'カスガシ', '惣利', 'ソウリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県春日市春日', '40', '40218', '8160814', '福岡県', 'フクオカケン', '春日市', 'カスガシ', '春日', 'カスガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県春日市若葉台東', '40', '40218', '8160821', '福岡県', 'フクオカケン', '春日市', 'カスガシ', '若葉台東', 'ワカバダイヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県春日市ちくし台', '40', '40218', '8160822', '福岡県', 'フクオカケン', '春日市', 'カスガシ', 'ちくし台', 'チクシダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県春日市若葉台西', '40', '40218', '8160823', '福岡県', 'フクオカケン', '春日市', 'カスガシ', '若葉台西', 'ワカバダイニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県春日市小倉', '40', '40218', '8160824', '福岡県', 'フクオカケン', '春日市', 'カスガシ', '小倉', 'コクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県春日市伯玄町', '40', '40218', '8160825', '福岡県', 'フクオカケン', '春日市', 'カスガシ', '伯玄町', 'ハクゲンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県春日市小倉東', '40', '40218', '8160826', '福岡県', 'フクオカケン', '春日市', 'カスガシ', '小倉東', 'コクラヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県春日市大谷', '40', '40218', '8160831', '福岡県', 'フクオカケン', '春日市', 'カスガシ', '大谷', 'オオタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県春日市紅葉ケ丘西', '40', '40218', '8160832', '福岡県', 'フクオカケン', '春日市', 'カスガシ', '紅葉ケ丘西', 'モミジガオカニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県春日市紅葉ケ丘東', '40', '40218', '8160833', '福岡県', 'フクオカケン', '春日市', 'カスガシ', '紅葉ケ丘東', 'モミジガオカヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県春日市塚原台', '40', '40218', '8160841', '福岡県', 'フクオカケン', '春日市', 'カスガシ', '塚原台', 'ツカハラダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県春日市下白水', '40', '40218', '8160842', '福岡県', 'フクオカケン', '春日市', 'カスガシ', '下白水', 'シモシロウズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県春日市松ケ丘', '40', '40218', '8160843', '福岡県', 'フクオカケン', '春日市', 'カスガシ', '松ケ丘', 'マツガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県春日市上白水', '40', '40218', '8160844', '福岡県', 'フクオカケン', '春日市', 'カスガシ', '上白水', 'カミシロウズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県春日市白水ケ丘', '40', '40218', '8160845', '福岡県', 'フクオカケン', '春日市', 'カスガシ', '白水ケ丘', 'シロウズガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県春日市下白水南', '40', '40218', '8160846', '福岡県', 'フクオカケン', '春日市', 'カスガシ', '下白水南', 'シモシロウズミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県春日市大土居', '40', '40218', '8160847', '福岡県', 'フクオカケン', '春日市', 'カスガシ', '大土居', 'オオドイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県春日市白水池', '40', '40218', '8160848', '福岡県', 'フクオカケン', '春日市', 'カスガシ', '白水池', 'シロウズイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県春日市昇町', '40', '40218', '8160851', '福岡県', 'フクオカケン', '春日市', 'カスガシ', '昇町', 'ノボリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県春日市一の谷', '40', '40218', '8160852', '福岡県', 'フクオカケン', '春日市', 'カスガシ', '一の谷', 'イチノタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県春日市泉', '40', '40218', '8160853', '福岡県', 'フクオカケン', '春日市', 'カスガシ', '泉', 'イズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県春日市下白水北', '40', '40218', '8160854', '福岡県', 'フクオカケン', '春日市', 'カスガシ', '下白水北', 'シモシロウズキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県春日市天神山', '40', '40218', '8160855', '福岡県', 'フクオカケン', '春日市', 'カスガシ', '天神山', 'テンジンヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県春日市岡本', '40', '40218', '8160861', '福岡県', 'フクオカケン', '春日市', 'カスガシ', '岡本', 'オカモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県春日市弥生', '40', '40218', '8160862', '福岡県', 'フクオカケン', '春日市', 'カスガシ', '弥生', 'ヤヨイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県春日市須玖南', '40', '40218', '8160863', '福岡県', 'フクオカケン', '春日市', 'カスガシ', '須玖南', 'スグミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県春日市須玖北', '40', '40218', '8160864', '福岡県', 'フクオカケン', '春日市', 'カスガシ', '須玖北', 'スグキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県春日市須玖', '40', '40218', '8160871', '福岡県', 'フクオカケン', '春日市', 'カスガシ', '須玖', 'スグ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県春日市桜ケ丘', '40', '40218', '8160872', '福岡県', 'フクオカケン', '春日市', 'カスガシ', '桜ケ丘', 'サクラガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県春日市日の出町', '40', '40218', '8160873', '福岡県', 'フクオカケン', '春日市', 'カスガシ', '日の出町', 'ヒノデマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県春日市大和町', '40', '40218', '8160874', '福岡県', 'フクオカケン', '春日市', 'カスガシ', '大和町', 'ヤマトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大野城市乙金東', '40', '40219', '8160901', '福岡県', 'フクオカケン', '大野城市', 'オオノジョウシ', '乙金東', 'オトガナヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大野城市乙金', '40', '40219', '8160902', '福岡県', 'フクオカケン', '大野城市', 'オオノジョウシ', '乙金', 'オトガナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大野城市乙金台', '40', '40219', '8160903', '福岡県', 'フクオカケン', '大野城市', 'オオノジョウシ', '乙金台', 'オトガナダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大野城市大池', '40', '40219', '8160904', '福岡県', 'フクオカケン', '大野城市', 'オオノジョウシ', '大池', 'オオイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大野城市川久保', '40', '40219', '8160905', '福岡県', 'フクオカケン', '大野城市', 'オオノジョウシ', '川久保', 'カワクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大野城市中', '40', '40219', '8160906', '福岡県', 'フクオカケン', '大野城市', 'オオノジョウシ', '中', 'ナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大野城市大城', '40', '40219', '8160911', '福岡県', 'フクオカケン', '大野城市', 'オオノジョウシ', '大城', 'オオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大野城市御笠川', '40', '40219', '8160912', '福岡県', 'フクオカケン', '大野城市', 'オオノジョウシ', '御笠川', 'ミカサガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大野城市仲畑', '40', '40219', '8160921', '福岡県', 'フクオカケン', '大野城市', 'オオノジョウシ', '仲畑', 'ナカハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大野城市山田', '40', '40219', '8160922', '福岡県', 'フクオカケン', '大野城市', 'オオノジョウシ', '山田', 'ヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大野城市雑餉隈町', '40', '40219', '8160923', '福岡県', 'フクオカケン', '大野城市', 'オオノジョウシ', '雑餉隈町', 'ザツショノクママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大野城市栄町', '40', '40219', '8160924', '福岡県', 'フクオカケン', '大野城市', 'オオノジョウシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大野城市筒井', '40', '40219', '8160931', '福岡県', 'フクオカケン', '大野城市', 'オオノジョウシ', '筒井', 'ツツイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大野城市瓦田', '40', '40219', '8160932', '福岡県', 'フクオカケン', '大野城市', 'オオノジョウシ', '瓦田', 'カワラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大野城市瑞穂町', '40', '40219', '8160933', '福岡県', 'フクオカケン', '大野城市', 'オオノジョウシ', '瑞穂町', 'ミズホマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大野城市曙町', '40', '40219', '8160934', '福岡県', 'フクオカケン', '大野城市', 'オオノジョウシ', '曙町', 'アケボノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大野城市錦町', '40', '40219', '8160935', '福岡県', 'フクオカケン', '大野城市', 'オオノジョウシ', '錦町', 'ニシキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大野城市東大利', '40', '40219', '8160941', '福岡県', 'フクオカケン', '大野城市', 'オオノジョウシ', '東大利', 'ヒガシオオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大野城市中央', '40', '40219', '8160942', '福岡県', 'フクオカケン', '大野城市', 'オオノジョウシ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大野城市白木原', '40', '40219', '8160943', '福岡県', 'フクオカケン', '大野城市', 'オオノジョウシ', '白木原', 'シラキバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大野城市下大利団地', '40', '40219', '8160951', '福岡県', 'フクオカケン', '大野城市', 'オオノジョウシ', '下大利団地', 'シモオオリダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大野城市下大利', '40', '40219', '8160952', '福岡県', 'フクオカケン', '大野城市', 'オオノジョウシ', '下大利', 'シモオオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大野城市旭ケ丘', '40', '40219', '8160953', '福岡県', 'フクオカケン', '大野城市', 'オオノジョウシ', '旭ケ丘', 'アサヒガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大野城市紫台', '40', '40219', '8160954', '福岡県', 'フクオカケン', '大野城市', 'オオノジョウシ', '紫台', 'ムラサキダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大野城市上大利', '40', '40219', '8160955', '福岡県', 'フクオカケン', '大野城市', 'オオノジョウシ', '上大利', 'カミオオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大野城市南大利', '40', '40219', '8160956', '福岡県', 'フクオカケン', '大野城市', 'オオノジョウシ', '南大利', 'ミナミオオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大野城市緑ケ丘', '40', '40219', '8160961', '福岡県', 'フクオカケン', '大野城市', 'オオノジョウシ', '緑ケ丘', 'ミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大野城市つつじケ丘', '40', '40219', '8160962', '福岡県', 'フクオカケン', '大野城市', 'オオノジョウシ', 'つつじケ丘', 'ツツジガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大野城市宮野台', '40', '40219', '8160963', '福岡県', 'フクオカケン', '大野城市', 'オオノジョウシ', '宮野台', 'ミヤノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大野城市南ケ丘', '40', '40219', '8160964', '福岡県', 'フクオカケン', '大野城市', 'オオノジョウシ', '南ケ丘', 'ミナミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大野城市牛頸', '40', '40219', '8160971', '福岡県', 'フクオカケン', '大野城市', 'オオノジョウシ', '牛頸', 'ウシクビ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大野城市平野台', '40', '40219', '8160972', '福岡県', 'フクオカケン', '大野城市', 'オオノジョウシ', '平野台', 'ヒラノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大野城市横峰', '40', '40219', '8160973', '福岡県', 'フクオカケン', '大野城市', 'オオノジョウシ', '横峰', 'ヨコミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大野城市若草', '40', '40219', '8160981', '福岡県', 'フクオカケン', '大野城市', 'オオノジョウシ', '若草', 'ワカクサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大野城市畑ケ坂', '40', '40219', '8160982', '福岡県', 'フクオカケン', '大野城市', 'オオノジョウシ', '畑ケ坂', 'ハタガサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大野城市月の浦', '40', '40219', '8160983', '福岡県', 'フクオカケン', '大野城市', 'オオノジョウシ', '月の浦', 'ツキノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市', '42', '42209', '8170000', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('105290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市厳原町小浦', '42', '42209', '8170001', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '厳原町小浦', 'イヅハラマチコウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市厳原町曲', '42', '42209', '8170002', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '厳原町曲', 'イヅハラマチマガリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市厳原町南室', '42', '42209', '8170003', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '厳原町南室', 'イヅハラマチナムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市厳原町桟原', '42', '42209', '8170005', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '厳原町桟原', 'イヅハラマチサジキバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市厳原町北里', '42', '42209', '8170006', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '厳原町北里', 'イヅハラマチキタザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市厳原町宮谷', '42', '42209', '8170011', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '厳原町宮谷', 'イヅハラマチミヤダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市厳原町日吉', '42', '42209', '8170012', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '厳原町日吉', 'イヅハラマチヒヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市厳原町中村', '42', '42209', '8170013', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '厳原町中村', 'イヅハラマチナカムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市厳原町天道茂', '42', '42209', '8170014', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '厳原町天道茂', 'イヅハラマチテンドウシゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市厳原町西里', '42', '42209', '8170015', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '厳原町西里', 'イヅハラマチニシザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市厳原町東里', '42', '42209', '8170016', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '厳原町東里', 'イヅハラマチヒガシザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市厳原町今屋敷', '42', '42209', '8170021', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '厳原町今屋敷', 'イヅハラマチイマヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市厳原町国分', '42', '42209', '8170022', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '厳原町国分', 'イヅハラマチコクブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市厳原町田渕', '42', '42209', '8170023', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '厳原町田渕', 'イヅハラマチタブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市厳原町大手橋', '42', '42209', '8170024', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '厳原町大手橋', 'イヅハラマチオオテバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市厳原町久田道', '42', '42209', '8170031', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '厳原町久田道', 'イヅハラマチクタミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市厳原町久田', '42', '42209', '8170032', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '厳原町久田', 'イヅハラマチクタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市厳原町尾浦', '42', '42209', '8170033', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '厳原町尾浦', 'イヅハラマチオウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市厳原町安神', '42', '42209', '8170034', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '厳原町安神', 'イヅハラマチアガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市厳原町久和', '42', '42209', '8170035', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '厳原町久和', 'イヅハラマチクワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市厳原町与良内院', '42', '42209', '8170151', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '厳原町与良内院', 'イヅハラマチヨラナイイン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市厳原町豆酘内院', '42', '42209', '8170152', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '厳原町豆酘内院', 'イヅハラマチツツナイイン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市厳原町浅藻', '42', '42209', '8170153', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '厳原町浅藻', 'イヅハラマチアザモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市厳原町豆酘', '42', '42209', '8170154', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '厳原町豆酘', 'イヅハラマチツツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市厳原町豆酘瀬', '42', '42209', '8170155', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '厳原町豆酘瀬', 'イヅハラマチツツセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市厳原町佐須瀬', '42', '42209', '8170156', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '厳原町佐須瀬', 'イヅハラマチサスセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市厳原町内山', '42', '42209', '8170157', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '厳原町内山', 'イヅハラマチウチヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市厳原町阿連', '42', '42209', '8170241', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '厳原町阿連', 'イヅハラマチアレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市厳原町下原', '42', '42209', '8170242', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '厳原町下原', 'イヅハラマチシモバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市厳原町樫根', '42', '42209', '8170243', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '厳原町樫根', 'イヅハラマチカシネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市厳原町久根浜', '42', '42209', '8170244', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '厳原町久根浜', 'イヅハラマチクネハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市厳原町久根田舎', '42', '42209', '8170245', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '厳原町久根田舎', 'イヅハラマチクネイナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市厳原町上槻', '42', '42209', '8170246', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '厳原町上槻', 'イヅハラマチコウツキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市厳原町椎根', '42', '42209', '8170247', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '厳原町椎根', 'イヅハラマチシイネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市厳原町小茂田', '42', '42209', '8170248', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '厳原町小茂田', 'イヅハラマチコモダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市美津島町洲藻', '42', '42209', '8170321', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '美津島町洲藻', 'ミツシママチスモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市美津島町鶏知', '42', '42209', '8170322', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '美津島町鶏知', 'ミツシママチケチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市美津島町大船越', '42', '42209', '8170323', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '美津島町大船越', 'ミツシママチオオフナコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市美津島町久須保', '42', '42209', '8170324', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '美津島町久須保', 'ミツシママチクスボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市美津島町緒方', '42', '42209', '8170325', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '美津島町緒方', 'ミツシママチオカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市美津島町根緒', '42', '42209', '8170326', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '美津島町根緒', 'ミツシママチネオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市美津島町尾崎', '42', '42209', '8170431', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '美津島町尾崎', 'ミツシママチオサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市美津島町今里', '42', '42209', '8170432', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '美津島町今里', 'ミツシママチイマザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市美津島町加志', '42', '42209', '8170433', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '美津島町加志', 'ミツシママチカシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市美津島町吹崎', '42', '42209', '8170434', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '美津島町吹崎', 'ミツシママチフクザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市美津島町箕形', '42', '42209', '8170435', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '美津島町箕形', 'ミツシママチミカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市美津島町竹敷', '42', '42209', '8170511', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '美津島町竹敷', 'ミツシママチタケシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市美津島町黒瀬', '42', '42209', '8170512', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '美津島町黒瀬', 'ミツシママチクロセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市美津島町昼ケ浦', '42', '42209', '8170513', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '美津島町昼ケ浦', 'ミツシママチヒルガウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市美津島町島山', '42', '42209', '8170514', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '美津島町島山', 'ミツシママチシマヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市美津島町小船越', '42', '42209', '8171101', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '美津島町小船越', 'ミツシママチコフナコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市美津島町芦浦', '42', '42209', '8171102', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '美津島町芦浦', 'ミツシママチヨシガウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市美津島町賀谷', '42', '42209', '8171103', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '美津島町賀谷', 'ミツシママチガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市美津島町濃部', '42', '42209', '8171104', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '美津島町濃部', 'ミツシママチノブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市美津島町大山', '42', '42209', '8171105', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '美津島町大山', 'ミツシママチオヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市美津島町犬吠', '42', '42209', '8171106', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '美津島町犬吠', 'ミツシママチイヌボエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市美津島町鴨居瀬', '42', '42209', '8171107', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '美津島町鴨居瀬', 'ミツシママチカモイセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市豊玉町仁位', '42', '42209', '8171201', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '豊玉町仁位', 'トヨタママチニイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市豊玉町和板', '42', '42209', '8171202', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '豊玉町和板', 'トヨタママチワイタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市豊玉町曽', '42', '42209', '8171212', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '豊玉町曽', 'トヨタママチソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市豊玉町千尋藻', '42', '42209', '8171213', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '豊玉町千尋藻', 'トヨタママチチロモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市豊玉町鑓川', '42', '42209', '8171214', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '豊玉町鑓川', 'トヨタママチヤリカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市豊玉町横浦', '42', '42209', '8171223', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '豊玉町横浦', 'トヨタママチヨコウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市豊玉町糸瀬', '42', '42209', '8171231', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '豊玉町糸瀬', 'トヨタママチイトセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市豊玉町嵯峨', '42', '42209', '8171232', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '豊玉町嵯峨', 'トヨタママチサガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市豊玉町貝鮒', '42', '42209', '8171233', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '豊玉町貝鮒', 'トヨタママチカイフナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市豊玉町佐志賀', '42', '42209', '8171234', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '豊玉町佐志賀', 'トヨタママチサシカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市豊玉町貝口', '42', '42209', '8171241', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '豊玉町貝口', 'トヨタママチカイグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市豊玉町唐洲', '42', '42209', '8171245', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '豊玉町唐洲', 'トヨタママチカラス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市豊玉町廻', '42', '42209', '8171246', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '豊玉町廻', 'トヨタママチマワリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市豊玉町田', '42', '42209', '8171251', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '豊玉町田', 'トヨタママチタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市豊玉町大綱', '42', '42209', '8171252', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '豊玉町大綱', 'トヨタママチオオツナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市豊玉町卯麦', '42', '42209', '8171253', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '豊玉町卯麦', 'トヨタママチウムギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市豊玉町佐保', '42', '42209', '8171254', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '豊玉町佐保', 'トヨタママチサホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市豊玉町志多浦', '42', '42209', '8171255', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '豊玉町志多浦', 'トヨタママチシタノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市豊玉町小綱', '42', '42209', '8171256', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '豊玉町小綱', 'トヨタママチコヅナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市豊玉町銘', '42', '42209', '8171257', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '豊玉町銘', 'トヨタママチメイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市峰町三根', '42', '42209', '8171301', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '峰町三根', 'ミネマチミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市峰町狩尾', '42', '42209', '8171302', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '峰町狩尾', 'ミネマチカリオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市峰町木坂', '42', '42209', '8171303', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '峰町木坂', 'ミネマチキサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市峰町青海', '42', '42209', '8171304', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '峰町青海', 'ミネマチオウミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市峰町津柳', '42', '42209', '8171305', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '峰町津柳', 'ミネマチツヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市峰町吉田', '42', '42209', '8171306', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '峰町吉田', 'ミネマチヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市峰町賀佐', '42', '42209', '8171307', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '峰町賀佐', 'ミネマチカサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市峰町櫛', '42', '42209', '8171411', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '峰町櫛', 'ミネマチクシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市峰町佐賀', '42', '42209', '8171412', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '峰町佐賀', 'ミネマチサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市峰町志多賀', '42', '42209', '8171413', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '峰町志多賀', 'ミネマチシタカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市上県町鹿見', '42', '42209', '8171511', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '上県町鹿見', 'カミアガタマチシシミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市上県町久原', '42', '42209', '8171512', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '上県町久原', 'カミアガタマチクバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市上県町女連', '42', '42209', '8171513', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '上県町女連', 'カミアガタマチウナツラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市上県町飼所', '42', '42209', '8171521', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '上県町飼所', 'カミアガタマチカイドコロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市上県町樫滝', '42', '42209', '8171522', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '上県町樫滝', 'カミアガタマチカシタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市上県町瀬田', '42', '42209', '8171523', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '上県町瀬田', 'カミアガタマチセタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市上県町犬ケ浦', '42', '42209', '8171524', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '上県町犬ケ浦', 'カミアガタマチイヌガウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市上県町御園', '42', '42209', '8171525', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '上県町御園', 'カミアガタマチミソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市上県町越高', '42', '42209', '8171531', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '上県町越高', 'カミアガタマチコシタカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市上県町伊奈', '42', '42209', '8171532', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '上県町伊奈', 'カミアガタマチイナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市上県町志多留', '42', '42209', '8171533', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '上県町志多留', 'カミアガタマチシタル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市上県町西津屋', '42', '42209', '8171601', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '上県町西津屋', 'カミアガタマチニシツヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市上県町佐須奈', '42', '42209', '8171602', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '上県町佐須奈', 'カミアガタマチサスナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市上県町佐護', '42', '42209', '8171603', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '上県町佐護', 'カミアガタマチサゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市上対馬町比田勝', '42', '42209', '8171701', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '上対馬町比田勝', 'カミツシママチヒタカツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市上対馬町古里', '42', '42209', '8171702', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '上対馬町古里', 'カミツシママチフルサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市上対馬町西泊', '42', '42209', '8171703', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '上対馬町西泊', 'カミツシママチニシドマリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市上対馬町網代', '42', '42209', '8171704', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '上対馬町網代', 'カミツシママチアジロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市上対馬町冨浦', '42', '42209', '8171711', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '上対馬町冨浦', 'カミツシママチトミガウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市上対馬町唐舟志', '42', '42209', '8171712', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '上対馬町唐舟志', 'カミツシママチトウジュウシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市上対馬町浜久須', '42', '42209', '8171713', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '上対馬町浜久須', 'カミツシママチハマグス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市上対馬町玖須', '42', '42209', '8171714', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '上対馬町玖須', 'カミツシママチクス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市上対馬町大増', '42', '42209', '8171715', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '上対馬町大増', 'カミツシママチオオマス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市上対馬町河内', '42', '42209', '8171721', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '上対馬町河内', 'カミツシママチカワチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市上対馬町大浦', '42', '42209', '8171722', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '上対馬町大浦', 'カミツシママチオオウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市上対馬町鰐浦', '42', '42209', '8171723', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '上対馬町鰐浦', 'カミツシママチワニウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市上対馬町豊', '42', '42209', '8171724', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '上対馬町豊', 'カミツシママチトヨ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市上対馬町泉', '42', '42209', '8171725', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '上対馬町泉', 'カミツシママチイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市上対馬町小鹿', '42', '42209', '8172241', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '上対馬町小鹿', 'カミツシママチオシカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市上対馬町一重', '42', '42209', '8172242', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '上対馬町一重', 'カミツシママチヒトエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市上対馬町芦見', '42', '42209', '8172243', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '上対馬町芦見', 'カミツシママチアシミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市上対馬町琴', '42', '42209', '8172331', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '上対馬町琴', 'カミツシママチキン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市上対馬町五根緒', '42', '42209', '8172332', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '上対馬町五根緒', 'カミツシママチゴネオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県対馬市上対馬町舟志', '42', '42209', '8172333', '長崎県', 'ナガサキケン', '対馬市', 'ツシマシ', '上対馬町舟志', 'カミツシママチシュウシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑紫野市', '40', '40217', '8180000', '福岡県', 'フクオカケン', '筑紫野市', 'チクシノシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('105418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑紫野市柚須原', '40', '40217', '8180001', '福岡県', 'フクオカケン', '筑紫野市', 'チクシノシ', '柚須原', 'ユスバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑紫野市香園', '40', '40217', '8180002', '福岡県', 'フクオカケン', '筑紫野市', 'チクシノシ', '香園', 'コウゾノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑紫野市山家', '40', '40217', '8180003', '福岡県', 'フクオカケン', '筑紫野市', 'チクシノシ', '山家', 'ヤマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑紫野市吉木', '40', '40217', '8180004', '福岡県', 'フクオカケン', '筑紫野市', 'チクシノシ', '吉木', 'ヨシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑紫野市原', '40', '40217', '8180005', '福岡県', 'フクオカケン', '筑紫野市', 'チクシノシ', '原', 'ハル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑紫野市大石', '40', '40217', '8180006', '福岡県', 'フクオカケン', '筑紫野市', 'チクシノシ', '大石', 'オオイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑紫野市本道寺', '40', '40217', '8180007', '福岡県', 'フクオカケン', '筑紫野市', 'チクシノシ', '本道寺', 'ホンドウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑紫野市阿志岐', '40', '40217', '8180011', '福岡県', 'フクオカケン', '筑紫野市', 'チクシノシ', '阿志岐', 'アシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑紫野市天山', '40', '40217', '8180012', '福岡県', 'フクオカケン', '筑紫野市', 'チクシノシ', '天山', 'アマヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑紫野市岡田', '40', '40217', '8180013', '福岡県', 'フクオカケン', '筑紫野市', 'チクシノシ', '岡田', 'オカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑紫野市牛島', '40', '40217', '8180014', '福岡県', 'フクオカケン', '筑紫野市', 'チクシノシ', '牛島', 'ウシジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑紫野市下見', '40', '40217', '8180021', '福岡県', 'フクオカケン', '筑紫野市', 'チクシノシ', '下見', 'シタミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑紫野市筑紫駅前通', '40', '40217', '8180022', '福岡県', 'フクオカケン', '筑紫野市', 'チクシノシ', '筑紫駅前通', 'チクシエキマエドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑紫野市若江', '40', '40217', '8180023', '福岡県', 'フクオカケン', '筑紫野市', 'チクシノシ', '若江', 'ワカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑紫野市原田', '40', '40217', '8180024', '福岡県', 'フクオカケン', '筑紫野市', 'チクシノシ', '原田', 'ハルダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑紫野市筑紫', '40', '40217', '8180025', '福岡県', 'フクオカケン', '筑紫野市', 'チクシノシ', '筑紫', 'チクシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑紫野市美咲', '40', '40217', '8180026', '福岡県', 'フクオカケン', '筑紫野市', 'チクシノシ', '美咲', 'ミサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑紫野市隈', '40', '40217', '8180031', '福岡県', 'フクオカケン', '筑紫野市', 'チクシノシ', '隈', 'クマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑紫野市西小田', '40', '40217', '8180032', '福岡県', 'フクオカケン', '筑紫野市', 'チクシノシ', '西小田', 'ニシオダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑紫野市馬市', '40', '40217', '8180033', '福岡県', 'フクオカケン', '筑紫野市', 'チクシノシ', '馬市', 'ウマイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑紫野市美しが丘南', '40', '40217', '8180034', '福岡県', 'フクオカケン', '筑紫野市', 'チクシノシ', '美しが丘南', 'ウツクシガオカミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑紫野市美しが丘北', '40', '40217', '8180035', '福岡県', 'フクオカケン', '筑紫野市', 'チクシノシ', '美しが丘北', 'ウツクシガオカキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑紫野市光が丘', '40', '40217', '8180036', '福岡県', 'フクオカケン', '筑紫野市', 'チクシノシ', '光が丘', 'ヒカリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑紫野市上古賀', '40', '40217', '8180041', '福岡県', 'フクオカケン', '筑紫野市', 'チクシノシ', '上古賀', 'カミコガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑紫野市立明寺', '40', '40217', '8180042', '福岡県', 'フクオカケン', '筑紫野市', 'チクシノシ', '立明寺', 'リュウミョウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑紫野市むさしケ丘', '40', '40217', '8180043', '福岡県', 'フクオカケン', '筑紫野市', 'チクシノシ', 'むさしケ丘', 'ムサシガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑紫野市萩原', '40', '40217', '8180044', '福岡県', 'フクオカケン', '筑紫野市', 'チクシノシ', '萩原', 'ハギワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑紫野市平等寺', '40', '40217', '8180045', '福岡県', 'フクオカケン', '筑紫野市', 'チクシノシ', '平等寺', 'ビョウドウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑紫野市山口', '40', '40217', '8180046', '福岡県', 'フクオカケン', '筑紫野市', 'チクシノシ', '山口', 'ヤマグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑紫野市古賀', '40', '40217', '8180047', '福岡県', 'フクオカケン', '筑紫野市', 'チクシノシ', '古賀', 'コガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑紫野市二日市', '40', '40217', '8180051', '福岡県', 'フクオカケン', '筑紫野市', 'チクシノシ', '二日市', 'フツカイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑紫野市武藏', '40', '40217', '8180052', '福岡県', 'フクオカケン', '筑紫野市', 'チクシノシ', '武藏', 'ムサシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑紫野市天拝坂', '40', '40217', '8180053', '福岡県', 'フクオカケン', '筑紫野市', 'チクシノシ', '天拝坂', 'テンパイザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑紫野市杉塚', '40', '40217', '8180054', '福岡県', 'フクオカケン', '筑紫野市', 'チクシノシ', '杉塚', 'スギヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑紫野市塔原', '40', '40217', '8180055', '福岡県', 'フクオカケン', '筑紫野市', 'チクシノシ', '塔原', 'トウノハル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑紫野市二日市北', '40', '40217', '8180056', '福岡県', 'フクオカケン', '筑紫野市', 'チクシノシ', '二日市北', 'フツカイチキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑紫野市二日市南', '40', '40217', '8180057', '福岡県', 'フクオカケン', '筑紫野市', 'チクシノシ', '二日市南', 'フツカイチミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑紫野市湯町', '40', '40217', '8180058', '福岡県', 'フクオカケン', '筑紫野市', 'チクシノシ', '湯町', 'ユマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑紫野市塔原東', '40', '40217', '8180059', '福岡県', 'フクオカケン', '筑紫野市', 'チクシノシ', '塔原東', 'トウノハルヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑紫野市紫', '40', '40217', '8180061', '福岡県', 'フクオカケン', '筑紫野市', 'チクシノシ', '紫', 'ムラサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑紫野市針摺', '40', '40217', '8180062', '福岡県', 'フクオカケン', '筑紫野市', 'チクシノシ', '針摺', 'ハリスリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑紫野市桜台', '40', '40217', '8180063', '福岡県', 'フクオカケン', '筑紫野市', 'チクシノシ', '桜台', 'サクラダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑紫野市常松', '40', '40217', '8180064', '福岡県', 'フクオカケン', '筑紫野市', 'チクシノシ', '常松', 'ツネマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑紫野市諸田', '40', '40217', '8180065', '福岡県', 'フクオカケン', '筑紫野市', 'チクシノシ', '諸田', 'モロタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑紫野市永岡', '40', '40217', '8180066', '福岡県', 'フクオカケン', '筑紫野市', 'チクシノシ', '永岡', 'ナガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑紫野市俗明院', '40', '40217', '8180067', '福岡県', 'フクオカケン', '筑紫野市', 'チクシノシ', '俗明院', 'ゾクミョウイン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑紫野市石崎', '40', '40217', '8180068', '福岡県', 'フクオカケン', '筑紫野市', 'チクシノシ', '石崎', 'イシザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑紫野市二日市西', '40', '40217', '8180071', '福岡県', 'フクオカケン', '筑紫野市', 'チクシノシ', '二日市西', 'フツカイチニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑紫野市二日市中央', '40', '40217', '8180072', '福岡県', 'フクオカケン', '筑紫野市', 'チクシノシ', '二日市中央', 'フツカイチチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑紫野市塔原西', '40', '40217', '8180073', '福岡県', 'フクオカケン', '筑紫野市', 'チクシノシ', '塔原西', 'トウノハルニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑紫野市塔原南', '40', '40217', '8180074', '福岡県', 'フクオカケン', '筑紫野市', 'チクシノシ', '塔原南', 'トウノハルミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑紫野市針摺東', '40', '40217', '8180081', '福岡県', 'フクオカケン', '筑紫野市', 'チクシノシ', '針摺東', 'ハリスリヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑紫野市針摺南', '40', '40217', '8180082', '福岡県', 'フクオカケン', '筑紫野市', 'チクシノシ', '針摺南', 'ハリスリミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑紫野市針摺中央', '40', '40217', '8180083', '福岡県', 'フクオカケン', '筑紫野市', 'チクシノシ', '針摺中央', 'ハリスリチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑紫野市針摺西', '40', '40217', '8180084', '福岡県', 'フクオカケン', '筑紫野市', 'チクシノシ', '針摺西', 'ハリスリニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑紫野市針摺北', '40', '40217', '8180085', '福岡県', 'フクオカケン', '筑紫野市', 'チクシノシ', '針摺北', 'ハリスリキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県太宰府市', '40', '40221', '8180100', '福岡県', 'フクオカケン', '太宰府市', 'ダザイフシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('105475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県太宰府市観世音寺', '40', '40221', '8180101', '福岡県', 'フクオカケン', '太宰府市', 'ダザイフシ', '観世音寺', 'カンゼオンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県太宰府市白川', '40', '40221', '8180102', '福岡県', 'フクオカケン', '太宰府市', 'ダザイフシ', '白川', 'シラカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県太宰府市朱雀', '40', '40221', '8180103', '福岡県', 'フクオカケン', '太宰府市', 'ダザイフシ', '朱雀', 'スザク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県太宰府市通古賀', '40', '40221', '8180104', '福岡県', 'フクオカケン', '太宰府市', 'ダザイフシ', '通古賀', 'トオノコガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県太宰府市都府楼南', '40', '40221', '8180105', '福岡県', 'フクオカケン', '太宰府市', 'ダザイフシ', '都府楼南', 'トフロウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県太宰府市御笠', '40', '40221', '8180110', '福岡県', 'フクオカケン', '太宰府市', 'ダザイフシ', '御笠', 'ミカサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県太宰府市三条', '40', '40221', '8180111', '福岡県', 'フクオカケン', '太宰府市', 'ダザイフシ', '三条', 'サンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県太宰府市北谷', '40', '40221', '8180114', '福岡県', 'フクオカケン', '太宰府市', 'ダザイフシ', '北谷', 'キタダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県太宰府市内山', '40', '40221', '8180115', '福岡県', 'フクオカケン', '太宰府市', 'ダザイフシ', '内山', 'ウチヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県太宰府市宰府', '40', '40221', '8180117', '福岡県', 'フクオカケン', '太宰府市', 'ダザイフシ', '宰府', 'サイフ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県太宰府市石坂', '40', '40221', '8180118', '福岡県', 'フクオカケン', '太宰府市', 'ダザイフシ', '石坂', 'イシザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県太宰府市連歌屋', '40', '40221', '8180119', '福岡県', 'フクオカケン', '太宰府市', 'ダザイフシ', '連歌屋', 'レンガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県太宰府市青山', '40', '40221', '8180121', '福岡県', 'フクオカケン', '太宰府市', 'ダザイフシ', '青山', 'アオヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県太宰府市高雄', '40', '40221', '8180122', '福岡県', 'フクオカケン', '太宰府市', 'ダザイフシ', '高雄', 'タカオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県太宰府市梅ケ丘', '40', '40221', '8180123', '福岡県', 'フクオカケン', '太宰府市', 'ダザイフシ', '梅ケ丘', 'ウメガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県太宰府市梅香苑', '40', '40221', '8180124', '福岡県', 'フクオカケン', '太宰府市', 'ダザイフシ', '梅香苑', 'バイコウエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県太宰府市五条', '40', '40221', '8180125', '福岡県', 'フクオカケン', '太宰府市', 'ダザイフシ', '五条', 'ゴジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県太宰府市水城', '40', '40221', '8180131', '福岡県', 'フクオカケン', '太宰府市', 'ダザイフシ', '水城', 'ミズキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県太宰府市国分', '40', '40221', '8180132', '福岡県', 'フクオカケン', '太宰府市', 'ダザイフシ', '国分', 'コクブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県太宰府市坂本', '40', '40221', '8180133', '福岡県', 'フクオカケン', '太宰府市', 'ダザイフシ', '坂本', 'サカモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県太宰府市大佐野', '40', '40221', '8180134', '福岡県', 'フクオカケン', '太宰府市', 'ダザイフシ', '大佐野', 'オオザノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県太宰府市向佐野', '40', '40221', '8180135', '福岡県', 'フクオカケン', '太宰府市', 'ダザイフシ', '向佐野', 'ムカイザノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県太宰府市長浦台', '40', '40221', '8180136', '福岡県', 'フクオカケン', '太宰府市', 'ダザイフシ', '長浦台', 'ナガウラダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県太宰府市青葉台', '40', '40221', '8180137', '福岡県', 'フクオカケン', '太宰府市', 'ダザイフシ', '青葉台', 'アオバダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県太宰府市吉松', '40', '40221', '8180138', '福岡県', 'フクオカケン', '太宰府市', 'ダザイフシ', '吉松', 'ヨシマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市西区', '40', '40135', '8190000', '福岡県', 'フクオカケン', '福岡市西区', 'フクオカシニシク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('105527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市西区小戸', '40', '40135', '8190001', '福岡県', 'フクオカケン', '福岡市西区', 'フクオカシニシク', '小戸', 'オド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市西区姪の浜', '40', '40135', '8190002', '福岡県', 'フクオカケン', '福岡市西区', 'フクオカシニシク', '姪の浜', 'メイノハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市西区内浜', '40', '40135', '8190005', '福岡県', 'フクオカケン', '福岡市西区', 'フクオカシニシク', '内浜', 'ウチハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市西区姪浜駅南', '40', '40135', '8190006', '福岡県', 'フクオカケン', '福岡市西区', 'フクオカシニシク', '姪浜駅南', 'メイノハマエキミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市西区愛宕南', '40', '40135', '8190007', '福岡県', 'フクオカケン', '福岡市西区', 'フクオカシニシク', '愛宕南', 'アタゴミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市西区小呂島', '40', '40135', '8190011', '福岡県', 'フクオカケン', '福岡市西区', 'フクオカシニシク', '小呂島', 'オロノシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市西区能古', '40', '40135', '8190012', '福岡県', 'フクオカケン', '福岡市西区', 'フクオカシニシク', '能古', 'ノコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市西区愛宕浜', '40', '40135', '8190013', '福岡県', 'フクオカケン', '福岡市西区', 'フクオカシニシク', '愛宕浜', 'アタゴハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市西区豊浜', '40', '40135', '8190014', '福岡県', 'フクオカケン', '福岡市西区', 'フクオカシニシク', '豊浜', 'トヨハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市西区愛宕', '40', '40135', '8190015', '福岡県', 'フクオカケン', '福岡市西区', 'フクオカシニシク', '愛宕', 'アタゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市西区大町団地', '40', '40135', '8190021', '福岡県', 'フクオカケン', '福岡市西区', 'フクオカシニシク', '大町団地', 'オオマチダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市西区福重', '40', '40135', '8190022', '福岡県', 'フクオカケン', '福岡市西区', 'フクオカシニシク', '福重', 'フクシゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市西区福重団地', '40', '40135', '8190023', '福岡県', 'フクオカケン', '福岡市西区', 'フクオカシニシク', '福重団地', 'フクシゲダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市西区十郎川団地', '40', '40135', '8190024', '福岡県', 'フクオカケン', '福岡市西区', 'フクオカシニシク', '十郎川団地', 'ジュウロウガワダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市西区石丸', '40', '40135', '8190025', '福岡県', 'フクオカケン', '福岡市西区', 'フクオカシニシク', '石丸', 'イシマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市西区室見が丘', '40', '40135', '8190030', '福岡県', 'フクオカケン', '福岡市西区', 'フクオカシニシク', '室見が丘', 'ムロミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市西区橋本', '40', '40135', '8190031', '福岡県', 'フクオカケン', '福岡市西区', 'フクオカシニシク', '橋本', 'ハシモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市西区戸切', '40', '40135', '8190032', '福岡県', 'フクオカケン', '福岡市西区', 'フクオカシニシク', '戸切', 'トギレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市西区橋本', '40', '40135', '8190033', '福岡県', 'フクオカケン', '福岡市西区', 'フクオカシニシク', '橋本', 'ハシモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市西区田', '40', '40135', '8190034', '福岡県', 'フクオカケン', '福岡市西区', 'フクオカシニシク', '田', 'タ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市西区金武', '40', '40135', '8190035', '福岡県', 'フクオカケン', '福岡市西区', 'フクオカシニシク', '金武', 'カナタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市西区吉武', '40', '40135', '8190036', '福岡県', 'フクオカケン', '福岡市西区', 'フクオカシニシク', '吉武', 'ヨシタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市西区飯盛', '40', '40135', '8190037', '福岡県', 'フクオカケン', '福岡市西区', 'フクオカシニシク', '飯盛', 'イイモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市西区羽根戸', '40', '40135', '8190038', '福岡県', 'フクオカケン', '福岡市西区', 'フクオカシニシク', '羽根戸', 'ハネド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市西区西入部', '40', '40135', '8190039', '福岡県', 'フクオカケン', '福岡市西区', 'フクオカシニシク', '西入部', 'ニシイリベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市西区拾六町', '40', '40135', '8190041', '福岡県', 'フクオカケン', '福岡市西区', 'フクオカシニシク', '拾六町', 'ジュウロクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市西区壱岐団地', '40', '40135', '8190042', '福岡県', 'フクオカケン', '福岡市西区', 'フクオカシニシク', '壱岐団地', 'イキダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市西区野方', '40', '40135', '8190043', '福岡県', 'フクオカケン', '福岡市西区', 'フクオカシニシク', '野方', 'ノカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市西区生松台', '40', '40135', '8190044', '福岡県', 'フクオカケン', '福岡市西区', 'フクオカシニシク', '生松台', 'イキマツダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市西区拾六町団地', '40', '40135', '8190045', '福岡県', 'フクオカケン', '福岡市西区', 'フクオカシニシク', '拾六町団地', 'ジュウロクチョウダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市西区西の丘', '40', '40135', '8190046', '福岡県', 'フクオカケン', '福岡市西区', 'フクオカシニシク', '西の丘', 'ニシノオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市西区下山門団地', '40', '40135', '8190051', '福岡県', 'フクオカケン', '福岡市西区', 'フクオカシニシク', '下山門団地', 'シモヤマトダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市西区下山門', '40', '40135', '8190052', '福岡県', 'フクオカケン', '福岡市西区', 'フクオカシニシク', '下山門', 'シモヤマト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市西区城の原団地', '40', '40135', '8190053', '福岡県', 'フクオカケン', '福岡市西区', 'フクオカシニシク', '城の原団地', 'ジョウノハルダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市西区上山門', '40', '40135', '8190054', '福岡県', 'フクオカケン', '福岡市西区', 'フクオカシニシク', '上山門', 'カミヤマト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市西区生の松原', '40', '40135', '8190055', '福岡県', 'フクオカケン', '福岡市西区', 'フクオカシニシク', '生の松原', 'イキノマツバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市西区今宿東', '40', '40135', '8190161', '福岡県', 'フクオカケン', '福岡市西区', 'フクオカシニシク', '今宿東', 'イマジュクヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市西区今宿青木', '40', '40135', '8190162', '福岡県', 'フクオカケン', '福岡市西区', 'フクオカシニシク', '今宿青木', 'イマジュクアオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市西区今宿上ノ原', '40', '40135', '8190163', '福岡県', 'フクオカケン', '福岡市西区', 'フクオカシニシク', '今宿上ノ原', 'イマジュクカミノハル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市西区今宿町', '40', '40135', '8190164', '福岡県', 'フクオカケン', '福岡市西区', 'フクオカシニシク', '今宿町', 'イマジュクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市西区今津', '40', '40135', '8190165', '福岡県', 'フクオカケン', '福岡市西区', 'フクオカシニシク', '今津', 'イマヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市西区横浜1丁目', '40', '40135', '8190166', '福岡県', 'フクオカケン', '福岡市西区', 'フクオカシニシク', '横浜', 'ヨコハマ', null, null, '1丁目', '01チョウメ');
INSERT INTO `ms_addresses` VALUES ('105569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市西区横浜2丁目', '40', '40135', '8190166', '福岡県', 'フクオカケン', '福岡市西区', 'フクオカシニシク', '横浜', 'ヨコハマ', null, null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('105570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市西区今宿', '40', '40135', '8190167', '福岡県', 'フクオカケン', '福岡市西区', 'フクオカシニシク', '今宿', 'イマジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市西区今宿駅前', '40', '40135', '8190168', '福岡県', 'フクオカケン', '福岡市西区', 'フクオカシニシク', '今宿駅前', 'イマジュクエキマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市西区宮浦', '40', '40135', '8190201', '福岡県', 'フクオカケン', '福岡市西区', 'フクオカシニシク', '宮浦', 'ミヤノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市西区西浦', '40', '40135', '8190202', '福岡県', 'フクオカケン', '福岡市西区', 'フクオカシニシク', '西浦', 'ニシノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市西区小田', '40', '40135', '8190203', '福岡県', 'フクオカケン', '福岡市西区', 'フクオカシニシク', '小田', 'コタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市西区草場', '40', '40135', '8190204', '福岡県', 'フクオカケン', '福岡市西区', 'フクオカシニシク', '草場', 'クサバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市西区玄界島', '40', '40135', '8190205', '福岡県', 'フクオカケン', '福岡市西区', 'フクオカシニシク', '玄界島', 'ゲンカイシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市西区横浜3丁目', '40', '40135', '8190366', '福岡県', 'フクオカケン', '福岡市西区', 'フクオカシニシク', '横浜', 'ヨコハマ', null, null, '3丁目', '03チョウメ');
INSERT INTO `ms_addresses` VALUES ('105579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市西区飯氏', '40', '40135', '8190371', '福岡県', 'フクオカケン', '福岡市西区', 'フクオカシニシク', '飯氏', 'イイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市西区宇田川原', '40', '40135', '8190372', '福岡県', 'フクオカケン', '福岡市西区', 'フクオカシニシク', '宇田川原', 'ウダガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市西区周船寺', '40', '40135', '8190373', '福岡県', 'フクオカケン', '福岡市西区', 'フクオカシニシク', '周船寺', 'スセンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市西区千里', '40', '40135', '8190374', '福岡県', 'フクオカケン', '福岡市西区', 'フクオカシニシク', '千里', 'センリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市西区徳永', '40', '40135', '8190375', '福岡県', 'フクオカケン', '福岡市西区', 'フクオカシニシク', '徳永', 'トクナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市西区女原', '40', '40135', '8190376', '福岡県', 'フクオカケン', '福岡市西区', 'フクオカシニシク', '女原', 'ミョウバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市西区泉', '40', '40135', '8190381', '福岡県', 'フクオカケン', '福岡市西区', 'フクオカシニシク', '泉', 'イズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市西区桑原', '40', '40135', '8190382', '福岡県', 'フクオカケン', '福岡市西区', 'フクオカシニシク', '桑原', 'クワバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市西区田尻', '40', '40135', '8190383', '福岡県', 'フクオカケン', '福岡市西区', 'フクオカシニシク', '田尻', 'タジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市西区太郎丸', '40', '40135', '8190384', '福岡県', 'フクオカケン', '福岡市西区', 'フクオカシニシク', '太郎丸', 'タロウマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市西区元岡', '40', '40135', '8190385', '福岡県', 'フクオカケン', '福岡市西区', 'フクオカシニシク', '元岡', 'モトオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市西区元浜', '40', '40135', '8190386', '福岡県', 'フクオカケン', '福岡市西区', 'フクオカシニシク', '元浜', 'モトハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県福岡市西区富士見', '40', '40135', '8190387', '福岡県', 'フクオカケン', '福岡市西区', 'フクオカシニシク', '富士見', 'フジミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県前原市', '40', '40222', '8191100', '福岡県', 'フクオカケン', '前原市', 'マエバルシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('105595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県前原市板持', '40', '40222', '8191101', '福岡県', 'フクオカケン', '前原市', 'マエバルシ', '板持', 'イタモチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県前原市高田', '40', '40222', '8191102', '福岡県', 'フクオカケン', '前原市', 'マエバルシ', '高田', 'タカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県前原市池田', '40', '40222', '8191103', '福岡県', 'フクオカケン', '前原市', 'マエバルシ', '池田', 'イケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県前原市波多江', '40', '40222', '8191104', '福岡県', 'フクオカケン', '前原市', 'マエバルシ', '波多江', 'ハタエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県前原市潤', '40', '40222', '8191105', '福岡県', 'フクオカケン', '前原市', 'マエバルシ', '潤', 'ウルウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県前原市志登', '40', '40222', '8191106', '福岡県', 'フクオカケン', '前原市', 'マエバルシ', '志登', 'シト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県前原市波多江駅北', '40', '40222', '8191107', '福岡県', 'フクオカケン', '前原市', 'マエバルシ', '波多江駅北', 'ハタエエキキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県前原市波多江駅南', '40', '40222', '8191108', '福岡県', 'フクオカケン', '前原市', 'マエバルシ', '波多江駅南', 'ハタエエキミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県前原市泊', '40', '40222', '8191111', '福岡県', 'フクオカケン', '前原市', 'マエバルシ', '泊', 'トマリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県前原市浦志', '40', '40222', '8191112', '福岡県', 'フクオカケン', '前原市', 'マエバルシ', '浦志', 'ウラシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県前原市前原', '40', '40222', '8191113', '福岡県', 'フクオカケン', '前原市', 'マエバルシ', '前原', 'マエバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県前原市新田', '40', '40222', '8191114', '福岡県', 'フクオカケン', '前原市', 'マエバルシ', '新田', 'シンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県前原市油比', '40', '40222', '8191115', '福岡県', 'フクオカケン', '前原市', 'マエバルシ', '油比', 'ユビ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県前原市前原中央', '40', '40222', '8191116', '福岡県', 'フクオカケン', '前原市', 'マエバルシ', '前原中央', 'マエバルチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県前原市前原西', '40', '40222', '8191117', '福岡県', 'フクオカケン', '前原市', 'マエバルシ', '前原西', 'マエバルニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県前原市前原北', '40', '40222', '8191118', '福岡県', 'フクオカケン', '前原市', 'マエバルシ', '前原北', 'マエバルキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県前原市前原東', '40', '40222', '8191119', '福岡県', 'フクオカケン', '前原市', 'マエバルシ', '前原東', 'マエバルヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県前原市荻浦', '40', '40222', '8191121', '福岡県', 'フクオカケン', '前原市', 'マエバルシ', '荻浦', 'オギノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県前原市東', '40', '40222', '8191122', '福岡県', 'フクオカケン', '前原市', 'マエバルシ', '東', 'ヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県前原市神在', '40', '40222', '8191123', '福岡県', 'フクオカケン', '前原市', 'マエバルシ', '神在', 'カミアリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県前原市加布里', '40', '40222', '8191124', '福岡県', 'フクオカケン', '前原市', 'マエバルシ', '加布里', 'カフリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県前原市千早新田', '40', '40222', '8191125', '福岡県', 'フクオカケン', '前原市', 'マエバルシ', '千早新田', 'チハヤシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県前原市岩本', '40', '40222', '8191126', '福岡県', 'フクオカケン', '前原市', 'マエバルシ', '岩本', 'イワモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県前原市有田中央', '40', '40222', '8191127', '福岡県', 'フクオカケン', '前原市', 'マエバルシ', '有田中央', 'アリタチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県前原市篠原東', '40', '40222', '8191128', '福岡県', 'フクオカケン', '前原市', 'マエバルシ', '篠原東', 'シノワラヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県前原市篠原西', '40', '40222', '8191129', '福岡県', 'フクオカケン', '前原市', 'マエバルシ', '篠原西', 'シノワラニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県前原市篠原', '40', '40222', '8191131', '福岡県', 'フクオカケン', '前原市', 'マエバルシ', '篠原', 'シノワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県前原市有田', '40', '40222', '8191132', '福岡県', 'フクオカケン', '前原市', 'マエバルシ', '有田', 'アリタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県前原市富', '40', '40222', '8191133', '福岡県', 'フクオカケン', '前原市', 'マエバルシ', '富', 'トミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県前原市多久', '40', '40222', '8191134', '福岡県', 'フクオカケン', '前原市', 'マエバルシ', '多久', 'タク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県前原市大浦', '40', '40222', '8191135', '福岡県', 'フクオカケン', '前原市', 'マエバルシ', '大浦', 'オオウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県前原市美咲が丘', '40', '40222', '8191136', '福岡県', 'フクオカケン', '前原市', 'マエバルシ', '美咲が丘', 'ミサキガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県前原市南風台', '40', '40222', '8191137', '福岡県', 'フクオカケン', '前原市', 'マエバルシ', '南風台', 'ミナカゼダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県前原市前原駅南', '40', '40222', '8191138', '福岡県', 'フクオカケン', '前原市', 'マエバルシ', '前原駅南', 'マエバルエキミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県前原市前原南', '40', '40222', '8191139', '福岡県', 'フクオカケン', '前原市', 'マエバルシ', '前原南', 'マエバルミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県前原市蔵持', '40', '40222', '8191141', '福岡県', 'フクオカケン', '前原市', 'マエバルシ', '蔵持', 'クラモチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県前原市八島', '40', '40222', '8191142', '福岡県', 'フクオカケン', '前原市', 'マエバルシ', '八島', 'ヤシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県前原市高上', '40', '40222', '8191143', '福岡県', 'フクオカケン', '前原市', 'マエバルシ', '高上', 'タカウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県前原市山北', '40', '40222', '8191144', '福岡県', 'フクオカケン', '前原市', 'マエバルシ', '山北', 'ヤマギタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県前原市雷山', '40', '40222', '8191145', '福岡県', 'フクオカケン', '前原市', 'マエバルシ', '雷山', 'ライザン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県前原市三坂', '40', '40222', '8191146', '福岡県', 'フクオカケン', '前原市', 'マエバルシ', '三坂', 'ミサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県前原市香力', '40', '40222', '8191147', '福岡県', 'フクオカケン', '前原市', 'マエバルシ', '香力', 'コウリキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県前原市本', '40', '40222', '8191151', '福岡県', 'フクオカケン', '前原市', 'マエバルシ', '本', 'ホン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県前原市飯原', '40', '40222', '8191152', '福岡県', 'フクオカケン', '前原市', 'マエバルシ', '飯原', 'イイバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県前原市長野', '40', '40222', '8191153', '福岡県', 'フクオカケン', '前原市', 'マエバルシ', '長野', 'ナガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県前原市白糸', '40', '40222', '8191154', '福岡県', 'フクオカケン', '前原市', 'マエバルシ', '白糸', 'シライト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県前原市川付', '40', '40222', '8191155', '福岡県', 'フクオカケン', '前原市', 'マエバルシ', '川付', 'カワツキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県前原市瀬戸', '40', '40222', '8191156', '福岡県', 'フクオカケン', '前原市', 'マエバルシ', '瀬戸', 'セト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糸島郡志摩町', '40', '40463', '8191300', '福岡県', 'フクオカケン', '糸島郡志摩町', 'イトシマグンシママチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('105647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糸島郡志摩町井田原', '40', '40463', '8191301', '福岡県', 'フクオカケン', '糸島郡志摩町', 'イトシマグンシママチ', '井田原', 'イダハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糸島郡志摩町吉田', '40', '40463', '8191302', '福岡県', 'フクオカケン', '糸島郡志摩町', 'イトシマグンシママチ', '吉田', 'ヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糸島郡志摩町野北', '40', '40463', '8191303', '福岡県', 'フクオカケン', '糸島郡志摩町', 'イトシマグンシママチ', '野北', 'ノギタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糸島郡志摩町桜井', '40', '40463', '8191304', '福岡県', 'フクオカケン', '糸島郡志摩町', 'イトシマグンシママチ', '桜井', 'サクライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糸島郡志摩町馬場', '40', '40463', '8191305', '福岡県', 'フクオカケン', '糸島郡志摩町', 'イトシマグンシママチ', '馬場', 'ババ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糸島郡志摩町松隈', '40', '40463', '8191306', '福岡県', 'フクオカケン', '糸島郡志摩町', 'イトシマグンシママチ', '松隈', 'マツグマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糸島郡志摩町津和崎', '40', '40463', '8191311', '福岡県', 'フクオカケン', '糸島郡志摩町', 'イトシマグンシママチ', '津和崎', 'ツワザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糸島郡志摩町初', '40', '40463', '8191312', '福岡県', 'フクオカケン', '糸島郡志摩町', 'イトシマグンシママチ', '初', 'ハツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糸島郡志摩町稲留', '40', '40463', '8191313', '福岡県', 'フクオカケン', '糸島郡志摩町', 'イトシマグンシママチ', '稲留', 'イナドメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糸島郡志摩町師吉', '40', '40463', '8191314', '福岡県', 'フクオカケン', '糸島郡志摩町', 'イトシマグンシママチ', '師吉', 'モロヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糸島郡志摩町稲葉', '40', '40463', '8191315', '福岡県', 'フクオカケン', '糸島郡志摩町', 'イトシマグンシママチ', '稲葉', 'イナバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糸島郡志摩町小富士', '40', '40463', '8191321', '福岡県', 'フクオカケン', '糸島郡志摩町', 'イトシマグンシママチ', '小富士', 'コフジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糸島郡志摩町御床', '40', '40463', '8191322', '福岡県', 'フクオカケン', '糸島郡志摩町', 'イトシマグンシママチ', '御床', 'ミトコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糸島郡志摩町小金丸', '40', '40463', '8191323', '福岡県', 'フクオカケン', '糸島郡志摩町', 'イトシマグンシママチ', '小金丸', 'コガネマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糸島郡志摩町東貝塚', '40', '40463', '8191324', '福岡県', 'フクオカケン', '糸島郡志摩町', 'イトシマグンシママチ', '東貝塚', 'ヒガシカイヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糸島郡志摩町西貝塚', '40', '40463', '8191325', '福岡県', 'フクオカケン', '糸島郡志摩町', 'イトシマグンシママチ', '西貝塚', 'ニシカイヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糸島郡志摩町久家', '40', '40463', '8191331', '福岡県', 'フクオカケン', '糸島郡志摩町', 'イトシマグンシママチ', '久家', 'クガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糸島郡志摩町船越', '40', '40463', '8191332', '福岡県', 'フクオカケン', '糸島郡志摩町', 'イトシマグンシママチ', '船越', 'フナコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糸島郡志摩町新町', '40', '40463', '8191333', '福岡県', 'フクオカケン', '糸島郡志摩町', 'イトシマグンシママチ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糸島郡志摩町岐志', '40', '40463', '8191334', '福岡県', 'フクオカケン', '糸島郡志摩町', 'イトシマグンシママチ', '岐志', 'キシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糸島郡志摩町芥屋', '40', '40463', '8191335', '福岡県', 'フクオカケン', '糸島郡志摩町', 'イトシマグンシママチ', '芥屋', 'ケヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糸島郡志摩町姫島', '40', '40463', '8191336', '福岡県', 'フクオカケン', '糸島郡志摩町', 'イトシマグンシママチ', '姫島', 'ヒメシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県前原市曽根', '40', '40222', '8191561', '福岡県', 'フクオカケン', '前原市', 'マエバルシ', '曽根', 'ソネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県前原市井田', '40', '40222', '8191562', '福岡県', 'フクオカケン', '前原市', 'マエバルシ', '井田', 'イタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県前原市高来寺', '40', '40222', '8191563', '福岡県', 'フクオカケン', '前原市', 'マエバルシ', '高来寺', 'コウライジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県前原市大門', '40', '40222', '8191564', '福岡県', 'フクオカケン', '前原市', 'マエバルシ', '大門', 'ダイモン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県前原市高祖', '40', '40222', '8191571', '福岡県', 'フクオカケン', '前原市', 'マエバルシ', '高祖', 'タカス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県前原市末永', '40', '40222', '8191572', '福岡県', 'フクオカケン', '前原市', 'マエバルシ', '末永', 'スエナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県前原市王丸', '40', '40222', '8191573', '福岡県', 'フクオカケン', '前原市', 'マエバルシ', '王丸', 'オウマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県前原市川原', '40', '40222', '8191574', '福岡県', 'フクオカケン', '前原市', 'マエバルシ', '川原', 'カワバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県前原市西堂', '40', '40222', '8191575', '福岡県', 'フクオカケン', '前原市', 'マエバルシ', '西堂', 'ニシノドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県前原市瑞梅寺', '40', '40222', '8191581', '福岡県', 'フクオカケン', '前原市', 'マエバルシ', '瑞梅寺', 'ズイバイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県前原市井原', '40', '40222', '8191582', '福岡県', 'フクオカケン', '前原市', 'マエバルシ', '井原', 'イワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県前原市三雲', '40', '40222', '8191583', '福岡県', 'フクオカケン', '前原市', 'マエバルシ', '三雲', 'ミクモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糸島郡二丈町', '40', '40462', '8191600', '福岡県', 'フクオカケン', '糸島郡二丈町', 'イトシマグンニジョウマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('105683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糸島郡二丈町深江', '40', '40462', '8191601', '福岡県', 'フクオカケン', '糸島郡二丈町', 'イトシマグンニジョウマチ', '深江', 'フカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糸島郡二丈町片山', '40', '40462', '8191611', '福岡県', 'フクオカケン', '糸島郡二丈町', 'イトシマグンニジョウマチ', '片山', 'カタヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糸島郡二丈町下松末', '40', '40462', '8191612', '福岡県', 'フクオカケン', '糸島郡二丈町', 'イトシマグンニジョウマチ', '下松末', 'シモマスエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糸島郡二丈町松末', '40', '40462', '8191613', '福岡県', 'フクオカケン', '糸島郡二丈町', 'イトシマグンニジョウマチ', '松末', 'マスエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糸島郡二丈町浜窪', '40', '40462', '8191614', '福岡県', 'フクオカケン', '糸島郡二丈町', 'イトシマグンニジョウマチ', '浜窪', 'ハマクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糸島郡二丈町田中', '40', '40462', '8191615', '福岡県', 'フクオカケン', '糸島郡二丈町', 'イトシマグンニジョウマチ', '田中', 'タナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糸島郡二丈町武', '40', '40462', '8191616', '福岡県', 'フクオカケン', '糸島郡二丈町', 'イトシマグンニジョウマチ', '武', 'タケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糸島郡二丈町上深江', '40', '40462', '8191621', '福岡県', 'フクオカケン', '糸島郡二丈町', 'イトシマグンニジョウマチ', '上深江', 'カミフカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糸島郡二丈町一貴山', '40', '40462', '8191622', '福岡県', 'フクオカケン', '糸島郡二丈町', 'イトシマグンニジョウマチ', '一貴山', 'イキサン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糸島郡二丈町石崎', '40', '40462', '8191623', '福岡県', 'フクオカケン', '糸島郡二丈町', 'イトシマグンニジョウマチ', '石崎', 'イシザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糸島郡二丈町満吉', '40', '40462', '8191624', '福岡県', 'フクオカケン', '糸島郡二丈町', 'イトシマグンニジョウマチ', '満吉', 'ミツヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糸島郡二丈町長石', '40', '40462', '8191625', '福岡県', 'フクオカケン', '糸島郡二丈町', 'イトシマグンニジョウマチ', '長石', 'ナガイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糸島郡二丈町波呂', '40', '40462', '8191626', '福岡県', 'フクオカケン', '糸島郡二丈町', 'イトシマグンニジョウマチ', '波呂', 'ハロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糸島郡二丈町松国', '40', '40462', '8191627', '福岡県', 'フクオカケン', '糸島郡二丈町', 'イトシマグンニジョウマチ', '松国', 'マツクニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糸島郡二丈町福井', '40', '40462', '8191631', '福岡県', 'フクオカケン', '糸島郡二丈町', 'イトシマグンニジョウマチ', '福井', 'フクイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糸島郡二丈町吉井', '40', '40462', '8191641', '福岡県', 'フクオカケン', '糸島郡二丈町', 'イトシマグンニジョウマチ', '吉井', 'ヨシイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県糸島郡二丈町鹿家', '40', '40462', '8191642', '福岡県', 'フクオカケン', '糸島郡二丈町', 'イトシマグンニジョウマチ', '鹿家', 'シカカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡芽室町', '01', '01637', '0820000', '北海道', 'ホッカイドウ', '河西郡芽室町', 'カサイグンメムロチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('105713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県飯塚市', '40', '40205', '8200000', '福岡県', 'フクオカケン', '飯塚市', 'イイヅカシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('105714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県飯塚市鯰田', '40', '40205', '8200001', '福岡県', 'フクオカケン', '飯塚市', 'イイヅカシ', '鯰田', 'ナマズタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県飯塚市川島', '40', '40205', '8200002', '福岡県', 'フクオカケン', '飯塚市', 'イイヅカシ', '川島', 'カワシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県飯塚市立岩', '40', '40205', '8200003', '福岡県', 'フクオカケン', '飯塚市', 'イイヅカシ', '立岩', 'タテイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県飯塚市新立岩', '40', '40205', '8200004', '福岡県', 'フクオカケン', '飯塚市', 'イイヅカシ', '新立岩', 'シンタテイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県飯塚市新飯塚', '40', '40205', '8200005', '福岡県', 'フクオカケン', '飯塚市', 'イイヅカシ', '新飯塚', 'シンイイヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡芽室町平和', '01', '01637', '0820001', '北海道', 'ホッカイドウ', '河西郡芽室町', 'カサイグンメムロチョウ', '平和', 'ヘイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県飯塚市柏の森', '40', '40205', '8200011', '福岡県', 'フクオカケン', '飯塚市', 'イイヅカシ', '柏の森', 'カヤノモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県飯塚市下三緒', '40', '40205', '8200012', '福岡県', 'フクオカケン', '飯塚市', 'イイヅカシ', '下三緒', 'シモミオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県飯塚市上三緒', '40', '40205', '8200013', '福岡県', 'フクオカケン', '飯塚市', 'イイヅカシ', '上三緒', 'カミミオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県飯塚市鶴三緒', '40', '40205', '8200014', '福岡県', 'フクオカケン', '飯塚市', 'イイヅカシ', '鶴三緒', 'ツルミオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県飯塚市菰田', '40', '40205', '8200015', '福岡県', 'フクオカケン', '飯塚市', 'イイヅカシ', '菰田', 'コモダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県飯塚市菰田東', '40', '40205', '8200016', '福岡県', 'フクオカケン', '飯塚市', 'イイヅカシ', '菰田東', 'コモダヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県飯塚市菰田西', '40', '40205', '8200017', '福岡県', 'フクオカケン', '飯塚市', 'イイヅカシ', '菰田西', 'コモダニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県飯塚市芳雄町', '40', '40205', '8200018', '福岡県', 'フクオカケン', '飯塚市', 'イイヅカシ', '芳雄町', 'ヨシオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡芽室町北明光勇', '01', '01637', '0820002', '北海道', 'ホッカイドウ', '河西郡芽室町', 'カサイグンメムロチョウ', '北明', 'ホクメイ', null, null, '光勇', 'コウユウ');
INSERT INTO `ms_addresses` VALUES ('105729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県飯塚市潤野', '40', '40205', '8200021', '福岡県', 'フクオカケン', '飯塚市', 'イイヅカシ', '潤野', 'ウルノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県飯塚市明星寺', '40', '40205', '8200022', '福岡県', 'フクオカケン', '飯塚市', 'イイヅカシ', '明星寺', 'ミョウジョウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡芽室町西士狩国見', '01', '01637', '0820003', '北海道', 'ホッカイドウ', '河西郡芽室町', 'カサイグンメムロチョウ', '西士狩', 'ニシシカリ', null, null, '国見', 'クニミ');
INSERT INTO `ms_addresses` VALUES ('105732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県飯塚市西徳前', '40', '40205', '8200031', '福岡県', 'フクオカケン', '飯塚市', 'イイヅカシ', '西徳前', 'ニシトクゼン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県飯塚市東徳前', '40', '40205', '8200032', '福岡県', 'フクオカケン', '飯塚市', 'イイヅカシ', '東徳前', 'ヒガシトクゼン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県飯塚市徳前', '40', '40205', '8200033', '福岡県', 'フクオカケン', '飯塚市', 'イイヅカシ', '徳前', 'トクゼン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡芽室町東芽室北下美生', '01', '01637', '0820004', '北海道', 'ホッカイドウ', '河西郡芽室町', 'カサイグンメムロチョウ', '東芽室北', 'ヒガシメムロキタ', null, null, '下美生', 'シモビセイ');
INSERT INTO `ms_addresses` VALUES ('105736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県飯塚市吉原町', '40', '40205', '8200040', '福岡県', 'フクオカケン', '飯塚市', 'イイヅカシ', '吉原町', 'ヨシハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県飯塚市飯塚', '40', '40205', '8200041', '福岡県', 'フクオカケン', '飯塚市', 'イイヅカシ', '飯塚', 'イイヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県飯塚市本町', '40', '40205', '8200042', '福岡県', 'フクオカケン', '飯塚市', 'イイヅカシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県飯塚市西町', '40', '40205', '8200043', '福岡県', 'フクオカケン', '飯塚市', 'イイヅカシ', '西町', 'ニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県飯塚市横田', '40', '40205', '8200044', '福岡県', 'フクオカケン', '飯塚市', 'イイヅカシ', '横田', 'ヨコタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県飯塚市花瀬', '40', '40205', '8200045', '福岡県', 'フクオカケン', '飯塚市', 'イイヅカシ', '花瀬', 'ハナセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県飯塚市大日寺', '40', '40205', '8200046', '福岡県', 'フクオカケン', '飯塚市', 'イイヅカシ', '大日寺', 'ダイニチジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県飯塚市八木山', '40', '40205', '8200047', '福岡県', 'フクオカケン', '飯塚市', 'イイヅカシ', '八木山', 'ヤキヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県飯塚市蓮台寺', '40', '40205', '8200048', '福岡県', 'フクオカケン', '飯塚市', 'イイヅカシ', '蓮台寺', 'レンダイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県飯塚市建花寺', '40', '40205', '8200049', '福岡県', 'フクオカケン', '飯塚市', 'イイヅカシ', '建花寺', 'ケンゲイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡芽室町東芽室基線日甜', '01', '01637', '0820005', '北海道', 'ホッカイドウ', '河西郡芽室町', 'カサイグンメムロチョウ', '東芽室基線', 'ヒガシメムロキセン', null, null, '日甜', 'ニッテン');
INSERT INTO `ms_addresses` VALUES ('105747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県飯塚市庄司', '40', '40205', '8200051', '福岡県', 'フクオカケン', '飯塚市', 'イイヅカシ', '庄司', 'ショウシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県飯塚市相田', '40', '40205', '8200052', '福岡県', 'フクオカケン', '飯塚市', 'イイヅカシ', '相田', 'アイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県飯塚市伊岐須', '40', '40205', '8200053', '福岡県', 'フクオカケン', '飯塚市', 'イイヅカシ', '伊岐須', 'イギス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県飯塚市伊川', '40', '40205', '8200054', '福岡県', 'フクオカケン', '飯塚市', 'イイヅカシ', '伊川', 'イカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡芽室町東芽室南大成', '01', '01637', '0820006', '北海道', 'ホッカイドウ', '河西郡芽室町', 'カサイグンメムロチョウ', '東芽室南', 'ヒガシメムロミナミ', null, null, '大成', 'タイセイ');
INSERT INTO `ms_addresses` VALUES ('105752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県飯塚市吉北', '40', '40205', '8200061', '福岡県', 'フクオカケン', '飯塚市', 'イイヅカシ', '吉北', 'ヨシキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県飯塚市目尾', '40', '40205', '8200062', '福岡県', 'フクオカケン', '飯塚市', 'イイヅカシ', '目尾', 'シャカノオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県飯塚市柳橋', '40', '40205', '8200063', '福岡県', 'フクオカケン', '飯塚市', 'イイヅカシ', '柳橋', 'ヤナギバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県飯塚市津島', '40', '40205', '8200064', '福岡県', 'フクオカケン', '飯塚市', 'イイヅカシ', '津島', 'ツシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県飯塚市中', '40', '40205', '8200065', '福岡県', 'フクオカケン', '飯塚市', 'イイヅカシ', '中', 'ナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県飯塚市幸袋', '40', '40205', '8200066', '福岡県', 'フクオカケン', '飯塚市', 'イイヅカシ', '幸袋', 'コウブクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県飯塚市川津', '40', '40205', '8200067', '福岡県', 'フクオカケン', '飯塚市', 'イイヅカシ', '川津', 'カワヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県飯塚市片島', '40', '40205', '8200068', '福岡県', 'フクオカケン', '飯塚市', 'イイヅカシ', '片島', 'カタシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県飯塚市宮町', '40', '40205', '8200069', '福岡県', 'フクオカケン', '飯塚市', 'イイヅカシ', '宮町', 'ミヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡芽室町北芽室美藁', '01', '01637', '0820007', '北海道', 'ホッカイドウ', '河西郡芽室町', 'カサイグンメムロチョウ', '北芽室', 'キタメムロ', null, null, '美藁', 'ビマン');
INSERT INTO `ms_addresses` VALUES ('105762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県飯塚市堀池', '40', '40205', '8200070', '福岡県', 'フクオカケン', '飯塚市', 'イイヅカシ', '堀池', 'ホリイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡芽室町北芽室芽室太', '01', '01637', '0820007', '北海道', 'ホッカイドウ', '河西郡芽室町', 'カサイグンメムロチョウ', '北芽室', 'キタメムロ', null, null, '芽室太', 'メムロブト');
INSERT INTO `ms_addresses` VALUES ('105764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県飯塚市忠隈', '40', '40205', '8200071', '福岡県', 'フクオカケン', '飯塚市', 'イイヅカシ', '忠隈', 'タダクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県飯塚市南尾', '40', '40205', '8200072', '福岡県', 'フクオカケン', '飯塚市', 'イイヅカシ', '南尾', 'ミナミオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県飯塚市平恒', '40', '40205', '8200073', '福岡県', 'フクオカケン', '飯塚市', 'イイヅカシ', '平恒', 'ヒラツネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県飯塚市楽市', '40', '40205', '8200074', '福岡県', 'フクオカケン', '飯塚市', 'イイヅカシ', '楽市', 'ラクイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県飯塚市天道', '40', '40205', '8200075', '福岡県', 'フクオカケン', '飯塚市', 'イイヅカシ', '天道', 'テントウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県飯塚市太郎丸', '40', '40205', '8200076', '福岡県', 'フクオカケン', '飯塚市', 'イイヅカシ', '太郎丸', 'タロウマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県飯塚市椋本', '40', '40205', '8200077', '福岡県', 'フクオカケン', '飯塚市', 'イイヅカシ', '椋本', 'ムクモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県飯塚市久保白', '40', '40205', '8200078', '福岡県', 'フクオカケン', '飯塚市', 'イイヅカシ', '久保白', 'クボシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県飯塚市高田', '40', '40205', '8200079', '福岡県', 'フクオカケン', '飯塚市', 'イイヅカシ', '高田', 'タカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡芽室町毛根', '01', '01637', '0820008', '北海道', 'ホッカイドウ', '河西郡芽室町', 'カサイグンメムロチョウ', '毛根', 'ケネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県飯塚市枝国', '40', '40205', '8200081', '福岡県', 'フクオカケン', '飯塚市', 'イイヅカシ', '枝国', 'エダクニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県飯塚市若菜', '40', '40205', '8200082', '福岡県', 'フクオカケン', '飯塚市', 'イイヅカシ', '若菜', 'ワカナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県飯塚市秋松', '40', '40205', '8200083', '福岡県', 'フクオカケン', '飯塚市', 'イイヅカシ', '秋松', 'アキマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県飯塚市椿', '40', '40205', '8200084', '福岡県', 'フクオカケン', '飯塚市', 'イイヅカシ', '椿', 'ツバキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県飯塚市安恒', '40', '40205', '8200085', '福岡県', 'フクオカケン', '飯塚市', 'イイヅカシ', '安恒', 'ヤスツネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県飯塚市津原', '40', '40205', '8200086', '福岡県', 'フクオカケン', '飯塚市', 'イイヅカシ', '津原', 'ツワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県飯塚市舎利蔵', '40', '40205', '8200087', '福岡県', 'フクオカケン', '飯塚市', 'イイヅカシ', '舎利蔵', 'シャリクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県飯塚市弁分', '40', '40205', '8200088', '福岡県', 'フクオカケン', '飯塚市', 'イイヅカシ', '弁分', 'ベンブン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県飯塚市小正', '40', '40205', '8200089', '福岡県', 'フクオカケン', '飯塚市', 'イイヅカシ', '小正', 'オバサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡芽室町祥栄西', '01', '01637', '0820009', '北海道', 'ホッカイドウ', '河西郡芽室町', 'カサイグンメムロチョウ', '祥栄西', 'ショウエイニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡芽室町祥栄北', '01', '01637', '0820010', '北海道', 'ホッカイドウ', '河西郡芽室町', 'カサイグンメムロチョウ', '祥栄北', 'ショウエイキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県飯塚市綱分', '40', '40205', '8200101', '福岡県', 'フクオカケン', '飯塚市', 'イイヅカシ', '綱分', 'ツナワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県飯塚市山倉', '40', '40205', '8200102', '福岡県', 'フクオカケン', '飯塚市', 'イイヅカシ', '山倉', 'ヤマクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県飯塚市入水', '40', '40205', '8200103', '福岡県', 'フクオカケン', '飯塚市', 'イイヅカシ', '入水', 'イリミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県飯塚市高倉', '40', '40205', '8200104', '福岡県', 'フクオカケン', '飯塚市', 'イイヅカシ', '高倉', 'タカクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県飯塚市筒野', '40', '40205', '8200105', '福岡県', 'フクオカケン', '飯塚市', 'イイヅカシ', '筒野', 'ツツノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県飯塚市赤坂', '40', '40205', '8200106', '福岡県', 'フクオカケン', '飯塚市', 'イイヅカシ', '赤坂', 'アカサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡芽室町東1条', '01', '01637', '0820011', '北海道', 'ホッカイドウ', '河西郡芽室町', 'カサイグンメムロチョウ', '東1条', 'ヒガシ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県飯塚市有安', '40', '40205', '8200111', '福岡県', 'フクオカケン', '飯塚市', 'イイヅカシ', '有安', 'アリヤス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県飯塚市有井', '40', '40205', '8200112', '福岡県', 'フクオカケン', '飯塚市', 'イイヅカシ', '有井', 'アリイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県飯塚市庄内元吉', '40', '40205', '8200113', '福岡県', 'フクオカケン', '飯塚市', 'イイヅカシ', '庄内元吉', 'ショウナイモトヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県飯塚市大門', '40', '40205', '8200114', '福岡県', 'フクオカケン', '飯塚市', 'イイヅカシ', '大門', 'オオカド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県飯塚市仁保', '40', '40205', '8200115', '福岡県', 'フクオカケン', '飯塚市', 'イイヅカシ', '仁保', 'ニホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県飯塚市多田', '40', '40205', '8200116', '福岡県', 'フクオカケン', '飯塚市', 'イイヅカシ', '多田', 'タダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡芽室町東2条', '01', '01637', '0820012', '北海道', 'ホッカイドウ', '河西郡芽室町', 'カサイグンメムロチョウ', '東2条', 'ヒガシ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡芽室町東3条', '01', '01637', '0820013', '北海道', 'ホッカイドウ', '河西郡芽室町', 'カサイグンメムロチョウ', '東3条', 'ヒガシ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡芽室町東4条', '01', '01637', '0820014', '北海道', 'ホッカイドウ', '河西郡芽室町', 'カサイグンメムロチョウ', '東4条', 'ヒガシ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡芽室町東5条', '01', '01637', '0820015', '北海道', 'ホッカイドウ', '河西郡芽室町', 'カサイグンメムロチョウ', '東5条', 'ヒガシ05ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡芽室町東6条', '01', '01637', '0820016', '北海道', 'ホッカイドウ', '河西郡芽室町', 'カサイグンメムロチョウ', '東6条', 'ヒガシ06ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡芽室町東7条', '01', '01637', '0820017', '北海道', 'ホッカイドウ', '河西郡芽室町', 'カサイグンメムロチョウ', '東7条', 'ヒガシ07ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡芽室町東8条', '01', '01637', '0820018', '北海道', 'ホッカイドウ', '河西郡芽室町', 'カサイグンメムロチョウ', '東8条', 'ヒガシ08ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡芽室町東9条', '01', '01637', '0820019', '北海道', 'ホッカイドウ', '河西郡芽室町', 'カサイグンメムロチョウ', '東9条', 'ヒガシ09ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡芽室町東10条', '01', '01637', '0820020', '北海道', 'ホッカイドウ', '河西郡芽室町', 'カサイグンメムロチョウ', '東10条', 'ヒガシ10ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県嘉麻市', '40', '40227', '8200200', '福岡県', 'フクオカケン', '嘉麻市', 'カマシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('105809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県嘉麻市漆生', '40', '40227', '8200201', '福岡県', 'フクオカケン', '嘉麻市', 'カマシ', '漆生', 'ウルシオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県嘉麻市山野', '40', '40227', '8200202', '福岡県', 'フクオカケン', '嘉麻市', 'カマシ', '山野', 'ヤマノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県嘉麻市平', '40', '40227', '8200203', '福岡県', 'フクオカケン', '嘉麻市', 'カマシ', '平', 'ヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県嘉麻市稲築才田', '40', '40227', '8200204', '福岡県', 'フクオカケン', '嘉麻市', 'カマシ', '稲築才田', 'イナツキサイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県嘉麻市岩崎', '40', '40227', '8200205', '福岡県', 'フクオカケン', '嘉麻市', 'カマシ', '岩崎', 'イワサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県嘉麻市鴨生', '40', '40227', '8200206', '福岡県', 'フクオカケン', '嘉麻市', 'カマシ', '鴨生', 'カモオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県嘉麻市口春', '40', '40227', '8200207', '福岡県', 'フクオカケン', '嘉麻市', 'カマシ', '口春', 'クチノハル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡芽室町東11条', '01', '01637', '0820021', '北海道', 'ホッカイドウ', '河西郡芽室町', 'カサイグンメムロチョウ', '東11条', 'ヒガシ11ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡芽室町東12条', '01', '01637', '0820022', '北海道', 'ホッカイドウ', '河西郡芽室町', 'カサイグンメムロチョウ', '東12条', 'ヒガシ12ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡芽室町本通', '01', '01637', '0820030', '北海道', 'ホッカイドウ', '河西郡芽室町', 'カサイグンメムロチョウ', '本通', 'ホンドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県嘉麻市牛隈', '40', '40227', '8200301', '福岡県', 'フクオカケン', '嘉麻市', 'カマシ', '牛隈', 'ウシクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県嘉麻市大隈町', '40', '40227', '8200302', '福岡県', 'フクオカケン', '嘉麻市', 'カマシ', '大隈町', 'オオクママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県嘉麻市中益', '40', '40227', '8200303', '福岡県', 'フクオカケン', '嘉麻市', 'カマシ', '中益', 'ナカマス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県嘉麻市大隈', '40', '40227', '8200304', '福岡県', 'フクオカケン', '嘉麻市', 'カマシ', '大隈', 'オオクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県嘉麻市貞月', '40', '40227', '8200305', '福岡県', 'フクオカケン', '嘉麻市', 'カマシ', '貞月', 'サダツキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県嘉麻市上西郷', '40', '40227', '8200306', '福岡県', 'フクオカケン', '嘉麻市', 'カマシ', '上西郷', 'カミサイゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡芽室町西1条', '01', '01637', '0820031', '北海道', 'ホッカイドウ', '河西郡芽室町', 'カサイグンメムロチョウ', '西1条', 'ニシ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県嘉麻市上', '40', '40227', '8200311', '福岡県', 'フクオカケン', '嘉麻市', 'カマシ', '上', 'カミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県嘉麻市宮吉', '40', '40227', '8200312', '福岡県', 'フクオカケン', '嘉麻市', 'カマシ', '宮吉', 'ミヤヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県嘉麻市桑野', '40', '40227', '8200313', '福岡県', 'フクオカケン', '嘉麻市', 'カマシ', '桑野', 'クワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県嘉麻市小野谷', '40', '40227', '8200314', '福岡県', 'フクオカケン', '嘉麻市', 'カマシ', '小野谷', 'オノダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡芽室町西2条', '01', '01637', '0820032', '北海道', 'ホッカイドウ', '河西郡芽室町', 'カサイグンメムロチョウ', '西2条', 'ニシ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県嘉麻市馬見', '40', '40227', '8200321', '福岡県', 'フクオカケン', '嘉麻市', 'カマシ', '馬見', 'ウマミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県嘉麻市屏', '40', '40227', '8200322', '福岡県', 'フクオカケン', '嘉麻市', 'カマシ', '屏', 'ヘイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県嘉麻市椎木', '40', '40227', '8200323', '福岡県', 'フクオカケン', '嘉麻市', 'カマシ', '椎木', 'シイノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡芽室町西3条', '01', '01637', '0820033', '北海道', 'ホッカイドウ', '河西郡芽室町', 'カサイグンメムロチョウ', '西3条', 'ニシ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県嘉麻市芥田', '40', '40227', '8200331', '福岡県', 'フクオカケン', '嘉麻市', 'カマシ', '芥田', 'アクタダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県嘉麻市千手', '40', '40227', '8200332', '福岡県', 'フクオカケン', '嘉麻市', 'カマシ', '千手', 'センズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県嘉麻市大力', '40', '40227', '8200333', '福岡県', 'フクオカケン', '嘉麻市', 'カマシ', '大力', 'ダイリキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県嘉麻市泉河内', '40', '40227', '8200334', '福岡県', 'フクオカケン', '嘉麻市', 'カマシ', '泉河内', 'イズミコウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県嘉麻市東畑', '40', '40227', '8200335', '福岡県', 'フクオカケン', '嘉麻市', 'カマシ', '東畑', 'ヒガシハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県嘉麻市嘉穂才田', '40', '40227', '8200336', '福岡県', 'フクオカケン', '嘉麻市', 'カマシ', '嘉穂才田', 'カホサイタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県嘉麻市九郎原', '40', '40227', '8200337', '福岡県', 'フクオカケン', '嘉麻市', 'カマシ', '九郎原', 'クロウバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡芽室町西4条', '01', '01637', '0820034', '北海道', 'ホッカイドウ', '河西郡芽室町', 'カサイグンメムロチョウ', '西4条', 'ニシ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡芽室町西5条', '01', '01637', '0820035', '北海道', 'ホッカイドウ', '河西郡芽室町', 'カサイグンメムロチョウ', '西5条', 'ニシ05ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡芽室町西6条', '01', '01637', '0820036', '北海道', 'ホッカイドウ', '河西郡芽室町', 'カサイグンメムロチョウ', '西6条', 'ニシ06ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡芽室町西7条', '01', '01637', '0820037', '北海道', 'ホッカイドウ', '河西郡芽室町', 'カサイグンメムロチョウ', '西7条', 'ニシ07ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡芽室町西8条', '01', '01637', '0820038', '北海道', 'ホッカイドウ', '河西郡芽室町', 'カサイグンメムロチョウ', '西8条', 'ニシ08ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡芽室町西9条', '01', '01637', '0820039', '北海道', 'ホッカイドウ', '河西郡芽室町', 'カサイグンメムロチョウ', '西9条', 'ニシ09ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡芽室町西10条', '01', '01637', '0820040', '北海道', 'ホッカイドウ', '河西郡芽室町', 'カサイグンメムロチョウ', '西10条', 'ニシ10ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡芽室町西11条', '01', '01637', '0820041', '北海道', 'ホッカイドウ', '河西郡芽室町', 'カサイグンメムロチョウ', '西11条', 'ニシ11ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡芽室町芽室北中島', '01', '01637', '0820042', '北海道', 'ホッカイドウ', '河西郡芽室町', 'カサイグンメムロチョウ', '芽室北', 'メムロキタ', null, null, '中島', 'ナカジマ');
INSERT INTO `ms_addresses` VALUES ('105853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡芽室町芽室北西芽室', '01', '01637', '0820042', '北海道', 'ホッカイドウ', '河西郡芽室町', 'カサイグンメムロチョウ', '芽室北', 'メムロキタ', null, null, '西芽室', 'ニシメムロ');
INSERT INTO `ms_addresses` VALUES ('105854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡芽室町芽室基線元町', '01', '01637', '0820043', '北海道', 'ホッカイドウ', '河西郡芽室町', 'カサイグンメムロチョウ', '芽室基線', 'メムロキセン', null, null, '元町', 'モトマチ');
INSERT INTO `ms_addresses` VALUES ('105855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡芽室町芽室南高岩', '01', '01637', '0820044', '北海道', 'ホッカイドウ', '河西郡芽室町', 'カサイグンメムロチョウ', '芽室南', 'メムロミナミ', null, null, '高岩', 'タカイワ');
INSERT INTO `ms_addresses` VALUES ('105856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡芽室町芽室南南弥生', '01', '01637', '0820044', '北海道', 'ホッカイドウ', '河西郡芽室町', 'カサイグンメムロチョウ', '芽室南', 'メムロミナミ', null, null, '南弥生', 'ミナミヤヨイ');
INSERT INTO `ms_addresses` VALUES ('105857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県嘉麻市飯田', '40', '40227', '8200501', '福岡県', 'フクオカケン', '嘉麻市', 'カマシ', '飯田', 'イイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県嘉麻市上臼井', '40', '40227', '8200502', '福岡県', 'フクオカケン', '嘉麻市', 'カマシ', '上臼井', 'カミウスイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県嘉麻市光代', '40', '40227', '8200503', '福岡県', 'フクオカケン', '嘉麻市', 'カマシ', '光代', 'コウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県嘉麻市下臼井', '40', '40227', '8200504', '福岡県', 'フクオカケン', '嘉麻市', 'カマシ', '下臼井', 'シモウスイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県嘉麻市西郷', '40', '40227', '8200505', '福岡県', 'フクオカケン', '嘉麻市', 'カマシ', '西郷', 'ニシノゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県嘉麻市平山', '40', '40227', '8200506', '福岡県', 'フクオカケン', '嘉麻市', 'カマシ', '平山', 'ヒラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡芽室町東1条南', '01', '01637', '0820051', '北海道', 'ホッカイドウ', '河西郡芽室町', 'カサイグンメムロチョウ', '東1条南', 'ヒガシ01ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡芽室町東2条南', '01', '01637', '0820052', '北海道', 'ホッカイドウ', '河西郡芽室町', 'カサイグンメムロチョウ', '東2条南', 'ヒガシ02ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡芽室町東3条南', '01', '01637', '0820053', '北海道', 'ホッカイドウ', '河西郡芽室町', 'カサイグンメムロチョウ', '東3条南', 'ヒガシ03ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡芽室町東4条南', '01', '01637', '0820054', '北海道', 'ホッカイドウ', '河西郡芽室町', 'カサイグンメムロチョウ', '東4条南', 'ヒガシ04ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡芽室町東6条南', '01', '01637', '0820056', '北海道', 'ホッカイドウ', '河西郡芽室町', 'カサイグンメムロチョウ', '東6条南', 'ヒガシ06ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡芽室町東7条南', '01', '01637', '0820057', '北海道', 'ホッカイドウ', '河西郡芽室町', 'カサイグンメムロチョウ', '東7条南', 'ヒガシ07ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡芽室町本通南', '01', '01637', '0820060', '北海道', 'ホッカイドウ', '河西郡芽室町', 'カサイグンメムロチョウ', '本通南', 'ホンドオリミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県嘉穂郡桂川町', '40', '40421', '8200600', '福岡県', 'フクオカケン', '嘉穂郡桂川町', 'カホグンケイセンマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('105871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県嘉穂郡桂川町内山田', '40', '40421', '8200601', '福岡県', 'フクオカケン', '嘉穂郡桂川町', 'カホグンケイセンマチ', '内山田', 'ウチヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県嘉穂郡桂川町九郎丸', '40', '40421', '8200602', '福岡県', 'フクオカケン', '嘉穂郡桂川町', 'カホグンケイセンマチ', '九郎丸', 'クロウマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県嘉穂郡桂川町寿命', '40', '40421', '8200603', '福岡県', 'フクオカケン', '嘉穂郡桂川町', 'カホグンケイセンマチ', '寿命', 'ジュメイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県嘉穂郡桂川町瀬戸', '40', '40421', '8200604', '福岡県', 'フクオカケン', '嘉穂郡桂川町', 'カホグンケイセンマチ', '瀬戸', 'セト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県嘉穂郡桂川町中屋', '40', '40421', '8200605', '福岡県', 'フクオカケン', '嘉穂郡桂川町', 'カホグンケイセンマチ', '中屋', 'チュウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県嘉穂郡桂川町土居', '40', '40421', '8200606', '福岡県', 'フクオカケン', '嘉穂郡桂川町', 'カホグンケイセンマチ', '土居', 'トイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県嘉穂郡桂川町土師', '40', '40421', '8200607', '福岡県', 'フクオカケン', '嘉穂郡桂川町', 'カホグンケイセンマチ', '土師', 'ハジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県嘉穂郡桂川町豆田', '40', '40421', '8200608', '福岡県', 'フクオカケン', '嘉穂郡桂川町', 'カホグンケイセンマチ', '豆田', 'マメダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県嘉穂郡桂川町吉隈', '40', '40421', '8200609', '福岡県', 'フクオカケン', '嘉穂郡桂川町', 'カホグンケイセンマチ', '吉隈', 'ヨシクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡芽室町西1条南', '01', '01637', '0820061', '北海道', 'ホッカイドウ', '河西郡芽室町', 'カサイグンメムロチョウ', '西1条南', 'ニシ01ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡芽室町西2条南', '01', '01637', '0820062', '北海道', 'ホッカイドウ', '河西郡芽室町', 'カサイグンメムロチョウ', '西2条南', 'ニシ02ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡芽室町西3条南', '01', '01637', '0820063', '北海道', 'ホッカイドウ', '河西郡芽室町', 'カサイグンメムロチョウ', '西3条南', 'ニシ03ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡芽室町西4条南', '01', '01637', '0820064', '北海道', 'ホッカイドウ', '河西郡芽室町', 'カサイグンメムロチョウ', '西4条南', 'ニシ04ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県飯塚市長尾', '40', '40205', '8200701', '福岡県', 'フクオカケン', '飯塚市', 'イイヅカシ', '長尾', 'ナガオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県飯塚市平塚', '40', '40205', '8200702', '福岡県', 'フクオカケン', '飯塚市', 'イイヅカシ', '平塚', 'ヒラツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県飯塚市北古賀', '40', '40205', '8200703', '福岡県', 'フクオカケン', '飯塚市', 'イイヅカシ', '北古賀', 'キタコガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県飯塚市阿恵', '40', '40205', '8200704', '福岡県', 'フクオカケン', '飯塚市', 'イイヅカシ', '阿恵', 'アエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県飯塚市筑穂元吉', '40', '40205', '8200705', '福岡県', 'フクオカケン', '飯塚市', 'イイヅカシ', '筑穂元吉', 'チクホモトヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県飯塚市内野', '40', '40205', '8200706', '福岡県', 'フクオカケン', '飯塚市', 'イイヅカシ', '内野', 'ウチノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県飯塚市桑曲', '40', '40205', '8200707', '福岡県', 'フクオカケン', '飯塚市', 'イイヅカシ', '桑曲', 'クワマガリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県飯塚市弥山', '40', '40205', '8200708', '福岡県', 'フクオカケン', '飯塚市', 'イイヅカシ', '弥山', 'ヤヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県飯塚市馬敷', '40', '40205', '8200709', '福岡県', 'フクオカケン', '飯塚市', 'イイヅカシ', '馬敷', 'マシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡芽室町新生', '01', '01637', '0820071', '北海道', 'ホッカイドウ', '河西郡芽室町', 'カサイグンメムロチョウ', '新生', 'シンセイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県飯塚市山口', '40', '40205', '8200711', '福岡県', 'フクオカケン', '飯塚市', 'イイヅカシ', '山口', 'ヤマグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県飯塚市大分', '40', '40205', '8200712', '福岡県', 'フクオカケン', '飯塚市', 'イイヅカシ', '大分', 'ダイブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県飯塚市内住', '40', '40205', '8200713', '福岡県', 'フクオカケン', '飯塚市', 'イイヅカシ', '内住', 'ナイジュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡芽室町北伏古南', '01', '01637', '0820072', '北海道', 'ホッカイドウ', '河西郡芽室町', 'カサイグンメムロチョウ', '北伏古南', 'キタフシコミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡芽室町中伏古', '01', '01637', '0820073', '北海道', 'ホッカイドウ', '河西郡芽室町', 'カサイグンメムロチョウ', '中伏古', 'ナカフシコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡芽室町栄光栄', '01', '01637', '0820074', '北海道', 'ホッカイドウ', '河西郡芽室町', 'カサイグンメムロチョウ', '栄', 'サカエ', null, null, '光栄', 'コウエイ');
INSERT INTO `ms_addresses` VALUES ('105902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡芽室町栄常盤', '01', '01637', '0820074', '北海道', 'ホッカイドウ', '河西郡芽室町', 'カサイグンメムロチョウ', '栄', 'サカエ', null, null, '常盤', 'トキワ');
INSERT INTO `ms_addresses` VALUES ('105903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡芽室町栄柏友', '01', '01637', '0820074', '北海道', 'ホッカイドウ', '河西郡芽室町', 'カサイグンメムロチョウ', '栄', 'サカエ', null, null, '柏友', 'ハクユウ');
INSERT INTO `ms_addresses` VALUES ('105904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡芽室町栄豊来', '01', '01637', '0820074', '北海道', 'ホッカイドウ', '河西郡芽室町', 'カサイグンメムロチョウ', '栄', 'サカエ', null, null, '豊来', 'ホウライ');
INSERT INTO `ms_addresses` VALUES ('105905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡芽室町栄丸山', '01', '01637', '0820074', '北海道', 'ホッカイドウ', '河西郡芽室町', 'カサイグンメムロチョウ', '栄', 'サカエ', null, null, '丸山', 'マルヤマ');
INSERT INTO `ms_addresses` VALUES ('105906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡芽室町坂の上博進', '01', '01637', '0820075', '北海道', 'ホッカイドウ', '河西郡芽室町', 'カサイグンメムロチョウ', '坂の上', 'サカノウエ', null, null, '博進', 'ハクシン');
INSERT INTO `ms_addresses` VALUES ('105907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡芽室町美生', '01', '01637', '0820076', '北海道', 'ホッカイドウ', '河西郡芽室町', 'カサイグンメムロチョウ', '美生', 'ビセイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡芽室町上芽室南', '01', '01637', '0820077', '北海道', 'ホッカイドウ', '河西郡芽室町', 'カサイグンメムロチョウ', '上芽室南', 'カミメムロミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡芽室町渋山', '01', '01637', '0820078', '北海道', 'ホッカイドウ', '河西郡芽室町', 'カサイグンメムロチョウ', '渋山', 'シブサン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡芽室町新朝日', '01', '01637', '0820079', '北海道', 'ホッカイドウ', '河西郡芽室町', 'カサイグンメムロチョウ', '新朝日', 'シンアサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡芽室町新生南', '01', '01637', '0820081', '北海道', 'ホッカイドウ', '河西郡芽室町', 'カサイグンメムロチョウ', '新生南', 'シンセイミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡芽室町北伏古東', '01', '01637', '0820082', '北海道', 'ホッカイドウ', '河西郡芽室町', 'カサイグンメムロチョウ', '北伏古東', 'キタフシコヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡芽室町中伏古東', '01', '01637', '0820083', '北海道', 'ホッカイドウ', '河西郡芽室町', 'カサイグンメムロチョウ', '中伏古東', 'ナカフシコヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡芽室町上芽室北', '01', '01637', '0820084', '北海道', 'ホッカイドウ', '河西郡芽室町', 'カサイグンメムロチョウ', '上芽室北', 'カミメムロキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡芽室町上芽室基線', '01', '01637', '0820085', '北海道', 'ホッカイドウ', '河西郡芽室町', 'カサイグンメムロチョウ', '上芽室基線', 'カミメムロキセン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡芽室町中美生', '01', '01637', '0820086', '北海道', 'ホッカイドウ', '河西郡芽室町', 'カサイグンメムロチョウ', '中美生', 'チュウビセイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡芽室町上芽室東', '01', '01637', '0820087', '北海道', 'ホッカイドウ', '河西郡芽室町', 'カサイグンメムロチョウ', '上芽室東', 'カミメムロヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県鞍手郡小竹町', '40', '40401', '8201100', '福岡県', 'フクオカケン', '鞍手郡小竹町', 'クラテグンコタケマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('105919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県鞍手郡小竹町御徳', '40', '40401', '8201101', '福岡県', 'フクオカケン', '鞍手郡小竹町', 'クラテグンコタケマチ', '御徳', 'ゴトク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県鞍手郡小竹町赤地', '40', '40401', '8201102', '福岡県', 'フクオカケン', '鞍手郡小竹町', 'クラテグンコタケマチ', '赤地', 'アカジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県鞍手郡小竹町勝野', '40', '40401', '8201103', '福岡県', 'フクオカケン', '鞍手郡小竹町', 'クラテグンコタケマチ', '勝野', 'カツノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県鞍手郡小竹町新多', '40', '40401', '8201104', '福岡県', 'フクオカケン', '鞍手郡小竹町', 'クラテグンコタケマチ', '新多', 'ニイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県鞍手郡小竹町新山崎', '40', '40401', '8201105', '福岡県', 'フクオカケン', '鞍手郡小竹町', 'クラテグンコタケマチ', '新山崎', 'シンヤマザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県鞍手郡小竹町南良津', '40', '40401', '8201106', '福岡県', 'フクオカケン', '鞍手郡小竹町', 'クラテグンコタケマチ', '南良津', 'ナラヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県飯塚市勢田', '40', '40205', '8201111', '福岡県', 'フクオカケン', '飯塚市', 'イイヅカシ', '勢田', 'セイタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県飯塚市鹿毛馬', '40', '40205', '8201112', '福岡県', 'フクオカケン', '飯塚市', 'イイヅカシ', '鹿毛馬', 'カケノウマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県飯塚市佐與', '40', '40205', '8201113', '福岡県', 'フクオカケン', '飯塚市', 'イイヅカシ', '佐與', 'サヨ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県飯塚市口原', '40', '40205', '8201114', '福岡県', 'フクオカケン', '飯塚市', 'イイヅカシ', '口原', 'クチノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡芽室町上伏古', '01', '01637', '0820381', '北海道', 'ホッカイドウ', '河西郡芽室町', 'カサイグンメムロチョウ', '上伏古', 'カミフシコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡芽室町雄馬別', '01', '01637', '0820382', '北海道', 'ホッカイドウ', '河西郡芽室町', 'カサイグンメムロチョウ', '雄馬別', 'オマベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡芽室町伏美', '01', '01637', '0820383', '北海道', 'ホッカイドウ', '河西郡芽室町', 'カサイグンメムロチョウ', '伏美', 'フシミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡芽室町上美生', '01', '01637', '0820384', '北海道', 'ホッカイドウ', '河西郡芽室町', 'カサイグンメムロチョウ', '上美生', 'カミビセイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡芽室町渋山上渋山', '01', '01637', '0820385', '北海道', 'ホッカイドウ', '河西郡芽室町', 'カサイグンメムロチョウ', '渋山', 'シブサン', null, null, '上渋山', 'カミシブサン');
INSERT INTO `ms_addresses` VALUES ('105936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡芽室町東めむろ1条北', '01', '01637', '0820801', '北海道', 'ホッカイドウ', '河西郡芽室町', 'カサイグンメムロチョウ', '東めむろ1条北', 'ヒガシメムロ01ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡芽室町東めむろ2条北', '01', '01637', '0820802', '北海道', 'ホッカイドウ', '河西郡芽室町', 'カサイグンメムロチョウ', '東めむろ2条北', 'ヒガシメムロ02ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡芽室町東めむろ3条北', '01', '01637', '0820803', '北海道', 'ホッカイドウ', '河西郡芽室町', 'カサイグンメムロチョウ', '東めむろ3条北', 'ヒガシメムロ03ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡芽室町東めむろ1条南', '01', '01637', '0820811', '北海道', 'ホッカイドウ', '河西郡芽室町', 'カサイグンメムロチョウ', '東めむろ1条南', 'ヒガシメムロ01ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡芽室町東めむろ2条南', '01', '01637', '0820812', '北海道', 'ホッカイドウ', '河西郡芽室町', 'カサイグンメムロチョウ', '東めむろ2条南', 'ヒガシメムロ02ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡芽室町東めむろ3条南', '01', '01637', '0820813', '北海道', 'ホッカイドウ', '河西郡芽室町', 'カサイグンメムロチョウ', '東めむろ3条南', 'ヒガシメムロ03ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県嘉麻市大隈町猪之鼻', '40', '40227', '8210002', '福岡県', 'フクオカケン', '嘉麻市', 'カマシ', '大隈町', 'オオクママチ', null, null, '猪之鼻', 'イノハナ');
INSERT INTO `ms_addresses` VALUES ('105963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県嘉麻市大隈', '40', '40227', '8210004', '福岡県', 'フクオカケン', '嘉麻市', 'カマシ', '大隈', 'オオクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県嘉麻市下山田', '40', '40227', '8210011', '福岡県', 'フクオカケン', '嘉麻市', 'カマシ', '下山田', 'シモヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県嘉麻市上山田', '40', '40227', '8210012', '福岡県', 'フクオカケン', '嘉麻市', 'カマシ', '上山田', 'カミヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県嘉麻市熊ケ畑', '40', '40227', '8210013', '福岡県', 'フクオカケン', '嘉麻市', 'カマシ', '熊ケ畑', 'クマガハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県嘉麻市猪国', '40', '40227', '8210014', '福岡県', 'フクオカケン', '嘉麻市', 'カマシ', '猪国', 'イノクニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県直方市', '40', '40204', '8220000', '福岡県', 'フクオカケン', '直方市', 'ノオガタシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('105970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県直方市感田', '40', '40204', '8220001', '福岡県', 'フクオカケン', '直方市', 'ノオガタシ', '感田', 'ガンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県直方市頓野', '40', '40204', '8220002', '福岡県', 'フクオカケン', '直方市', 'ノオガタシ', '頓野', 'トンノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県直方市上頓野', '40', '40204', '8220003', '福岡県', 'フクオカケン', '直方市', 'ノオガタシ', '上頓野', 'カミトンノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県直方市畑', '40', '40204', '8220004', '福岡県', 'フクオカケン', '直方市', 'ノオガタシ', '畑', 'ハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県直方市永満寺', '40', '40204', '8220005', '福岡県', 'フクオカケン', '直方市', 'ノオガタシ', '永満寺', 'エイマンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県直方市上境', '40', '40204', '8220006', '福岡県', 'フクオカケン', '直方市', 'ノオガタシ', '上境', 'カミザカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県直方市下境', '40', '40204', '8220007', '福岡県', 'フクオカケン', '直方市', 'ノオガタシ', '下境', 'シモザカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県直方市湯野原', '40', '40204', '8220008', '福岡県', 'フクオカケン', '直方市', 'ノオガタシ', '湯野原', 'ユノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県直方市中泉', '40', '40204', '8220011', '福岡県', 'フクオカケン', '直方市', 'ノオガタシ', '中泉', 'ナカイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県直方市赤地', '40', '40204', '8220012', '福岡県', 'フクオカケン', '直方市', 'ノオガタシ', '赤地', 'アカジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県直方市溝堀', '40', '40204', '8220013', '福岡県', 'フクオカケン', '直方市', 'ノオガタシ', '溝堀', 'ミゾホリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県直方市丸山町', '40', '40204', '8220014', '福岡県', 'フクオカケン', '直方市', 'ノオガタシ', '丸山町', 'マルヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県直方市新町', '40', '40204', '8220015', '福岡県', 'フクオカケン', '直方市', 'ノオガタシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県直方市直方', '40', '40204', '8220016', '福岡県', 'フクオカケン', '直方市', 'ノオガタシ', '直方', 'ノオガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県直方市殿町', '40', '40204', '8220017', '福岡県', 'フクオカケン', '直方市', 'ノオガタシ', '殿町', 'トノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県直方市新知町', '40', '40204', '8220021', '福岡県', 'フクオカケン', '直方市', 'ノオガタシ', '新知町', 'シンチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県直方市知古', '40', '40204', '8220022', '福岡県', 'フクオカケン', '直方市', 'ノオガタシ', '知古', 'チコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県直方市神正町', '40', '40204', '8220023', '福岡県', 'フクオカケン', '直方市', 'ノオガタシ', '神正町', 'シンセイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県直方市須崎町', '40', '40204', '8220024', '福岡県', 'フクオカケン', '直方市', 'ノオガタシ', '須崎町', 'スサキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県直方市日吉町', '40', '40204', '8220025', '福岡県', 'フクオカケン', '直方市', 'ノオガタシ', '日吉町', 'ヒヨシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県直方市津田町', '40', '40204', '8220026', '福岡県', 'フクオカケン', '直方市', 'ノオガタシ', '津田町', 'ツダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県直方市古町', '40', '40204', '8220027', '福岡県', 'フクオカケン', '直方市', 'ノオガタシ', '古町', 'フルマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県直方市植木', '40', '40204', '8220031', '福岡県', 'フクオカケン', '直方市', 'ノオガタシ', '植木', 'ウエキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県直方市下新入', '40', '40204', '8220032', '福岡県', 'フクオカケン', '直方市', 'ノオガタシ', '下新入', 'シモシンニュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県直方市上新入', '40', '40204', '8220033', '福岡県', 'フクオカケン', '直方市', 'ノオガタシ', '上新入', 'カミシンニュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県直方市山部', '40', '40204', '8220034', '福岡県', 'フクオカケン', '直方市', 'ノオガタシ', '山部', 'ヤマベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宮若市福丸', '40', '40226', '8220101', '福岡県', 'フクオカケン', '宮若市', 'ミヤワカシ', '福丸', 'フクマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宮若市金丸', '40', '40226', '8220111', '福岡県', 'フクオカケン', '宮若市', 'ミヤワカシ', '金丸', 'カナマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宮若市原田', '40', '40226', '8220112', '福岡県', 'フクオカケン', '宮若市', 'ミヤワカシ', '原田', 'ハラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('105999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宮若市金生', '40', '40226', '8220113', '福岡県', 'フクオカケン', '宮若市', 'ミヤワカシ', '金生', 'カノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宮若市湯原', '40', '40226', '8220121', '福岡県', 'フクオカケン', '宮若市', 'ミヤワカシ', '湯原', 'ユバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宮若市下', '40', '40226', '8220122', '福岡県', 'フクオカケン', '宮若市', 'ミヤワカシ', '下', 'シモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宮若市三ケ畑', '40', '40226', '8220123', '福岡県', 'フクオカケン', '宮若市', 'ミヤワカシ', '三ケ畑', 'サンガハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宮若市縁山畑', '40', '40226', '8220124', '福岡県', 'フクオカケン', '宮若市', 'ミヤワカシ', '縁山畑', 'ヘリヤマハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宮若市乙野', '40', '40226', '8220131', '福岡県', 'フクオカケン', '宮若市', 'ミヤワカシ', '乙野', 'オトノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宮若市小伏', '40', '40226', '8220132', '福岡県', 'フクオカケン', '宮若市', 'ミヤワカシ', '小伏', 'コブシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宮若市脇田', '40', '40226', '8220133', '福岡県', 'フクオカケン', '宮若市', 'ミヤワカシ', '脇田', 'ワキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宮若市犬鳴', '40', '40226', '8220134', '福岡県', 'フクオカケン', '宮若市', 'ミヤワカシ', '犬鳴', 'イヌナキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宮若市平', '40', '40226', '8220141', '福岡県', 'フクオカケン', '宮若市', 'ミヤワカシ', '平', 'タイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宮若市竹原', '40', '40226', '8220142', '福岡県', 'フクオカケン', '宮若市', 'ミヤワカシ', '竹原', 'タケハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宮若市高野', '40', '40226', '8220143', '福岡県', 'フクオカケン', '宮若市', 'ミヤワカシ', '高野', 'タカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宮若市稲光', '40', '40226', '8220144', '福岡県', 'フクオカケン', '宮若市', 'ミヤワカシ', '稲光', 'イナミツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宮若市宮永', '40', '40226', '8220145', '福岡県', 'フクオカケン', '宮若市', 'ミヤワカシ', '宮永', 'ミヤナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宮若市黒丸', '40', '40226', '8220146', '福岡県', 'フクオカケン', '宮若市', 'ミヤワカシ', '黒丸', 'クロマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宮若市水原', '40', '40226', '8220151', '福岡県', 'フクオカケン', '宮若市', 'ミヤワカシ', '水原', 'ミズハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宮若市沼口', '40', '40226', '8220152', '福岡県', 'フクオカケン', '宮若市', 'ミヤワカシ', '沼口', 'ヌマグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宮若市山口', '40', '40226', '8220153', '福岡県', 'フクオカケン', '宮若市', 'ミヤワカシ', '山口', 'ヤマグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県田川郡福智町赤池', '40', '40610', '8221101', '福岡県', 'フクオカケン', '田川郡福智町', 'タガワグンフクチマチ', '赤池', 'アカイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県田川郡福智町上野', '40', '40610', '8221102', '福岡県', 'フクオカケン', '田川郡福智町', 'タガワグンフクチマチ', '上野', 'アガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県田川郡福智町市場', '40', '40610', '8221103', '福岡県', 'フクオカケン', '田川郡福智町', 'タガワグンフクチマチ', '市場', 'イチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県田川郡福智町', '40', '40610', '8221200', '福岡県', 'フクオカケン', '田川郡福智町', 'タガワグンフクチマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('106023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県田川郡福智町金田', '40', '40610', '8221201', '福岡県', 'フクオカケン', '田川郡福智町', 'タガワグンフクチマチ', '金田', 'カナダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県田川郡福智町神崎', '40', '40610', '8221202', '福岡県', 'フクオカケン', '田川郡福智町', 'タガワグンフクチマチ', '神崎', 'コウザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県田川郡福智町伊方', '40', '40610', '8221211', '福岡県', 'フクオカケン', '田川郡福智町', 'タガワグンフクチマチ', '伊方', 'イカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県田川郡福智町弁城', '40', '40610', '8221212', '福岡県', 'フクオカケン', '田川郡福智町', 'タガワグンフクチマチ', '弁城', 'ベンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県田川郡糸田町', '40', '40604', '8221300', '福岡県', 'フクオカケン', '田川郡糸田町', 'タガワグンイトダマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('106031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県田川郡糸田町堀川', '40', '40604', '8221301', '福岡県', 'フクオカケン', '田川郡糸田町', 'タガワグンイトダマチ', '堀川', 'ホリカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県田川郡糸田町大熊', '40', '40604', '8221302', '福岡県', 'フクオカケン', '田川郡糸田町', 'タガワグンイトダマチ', '大熊', 'オオクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県田川郡糸田町桃山', '40', '40604', '8221303', '福岡県', 'フクオカケン', '田川郡糸田町', 'タガワグンイトダマチ', '桃山', 'モモヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県田川郡糸田町自由ケ丘', '40', '40604', '8221304', '福岡県', 'フクオカケン', '田川郡糸田町', 'タガワグンイトダマチ', '自由ケ丘', 'ジユウガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県田川郡糸田町宮床団地', '40', '40604', '8221305', '福岡県', 'フクオカケン', '田川郡糸田町', 'タガワグンイトダマチ', '宮床団地', 'ミヤトコダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県田川郡糸田町貴船', '40', '40604', '8221306', '福岡県', 'フクオカケン', '田川郡糸田町', 'タガワグンイトダマチ', '貴船', 'キフネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県田川郡糸田町宮床', '40', '40604', '8221307', '福岡県', 'フクオカケン', '田川郡糸田町', 'タガワグンイトダマチ', '宮床', 'ミヤトコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県田川郡糸田町北区', '40', '40604', '8221311', '福岡県', 'フクオカケン', '田川郡糸田町', 'タガワグンイトダマチ', '北区', 'キタク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県田川郡糸田町下糸田', '40', '40604', '8221312', '福岡県', 'フクオカケン', '田川郡糸田町', 'タガワグンイトダマチ', '下糸田', 'シモイトダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県田川郡糸田町打越', '40', '40604', '8221313', '福岡県', 'フクオカケン', '田川郡糸田町', 'タガワグンイトダマチ', '打越', 'ウチコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県田川郡糸田町中糸田', '40', '40604', '8221314', '福岡県', 'フクオカケン', '田川郡糸田町', 'タガワグンイトダマチ', '中糸田', 'ナカイトダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県田川郡糸田町宮川二', '40', '40604', '8221315', '福岡県', 'フクオカケン', '田川郡糸田町', 'タガワグンイトダマチ', '宮川二', 'ミヤガワ02', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県田川郡糸田町上糸田', '40', '40604', '8221316', '福岡県', 'フクオカケン', '田川郡糸田町', 'タガワグンイトダマチ', '上糸田', 'カミイトダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県田川郡糸田町宮川一', '40', '40604', '8221317', '福岡県', 'フクオカケン', '田川郡糸田町', 'タガワグンイトダマチ', '宮川一', 'ミヤガワ01', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県田川郡糸田町原', '40', '40604', '8221318', '福岡県', 'フクオカケン', '田川郡糸田町', 'タガワグンイトダマチ', '原', 'ハル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県田川郡糸田町宮谷', '40', '40604', '8221321', '福岡県', 'フクオカケン', '田川郡糸田町', 'タガワグンイトダマチ', '宮谷', 'ミヤタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県田川郡糸田町西部', '40', '40604', '8221322', '福岡県', 'フクオカケン', '田川郡糸田町', 'タガワグンイトダマチ', '西部', 'サイブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県田川郡糸田町真岡', '40', '40604', '8221323', '福岡県', 'フクオカケン', '田川郡糸田町', 'タガワグンイトダマチ', '真岡', 'シンオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県田川郡糸田町旭ケ丘', '40', '40604', '8221324', '福岡県', 'フクオカケン', '田川郡糸田町', 'タガワグンイトダマチ', '旭ケ丘', 'アサヒガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県田川郡糸田町南糸田', '40', '40604', '8221325', '福岡県', 'フクオカケン', '田川郡糸田町', 'タガワグンイトダマチ', '南糸田', 'ミナミイトダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県田川郡糸田町鼡ケ池', '40', '40604', '8221326', '福岡県', 'フクオカケン', '田川郡糸田町', 'タガワグンイトダマチ', '鼡ケ池', 'ネズガイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県田川郡香春町', '40', '40601', '8221400', '福岡県', 'フクオカケン', '田川郡香春町', 'タガワグンカワラマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('106053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県田川郡香春町採銅所', '40', '40601', '8221401', '福岡県', 'フクオカケン', '田川郡香春町', 'タガワグンカワラマチ', '採銅所', 'サイドウショ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県田川郡香春町鏡山', '40', '40601', '8221402', '福岡県', 'フクオカケン', '田川郡香春町', 'タガワグンカワラマチ', '鏡山', 'カガミヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県田川郡香春町高野', '40', '40601', '8221403', '福岡県', 'フクオカケン', '田川郡香春町', 'タガワグンカワラマチ', '高野', 'タカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県田川郡香春町柿下', '40', '40601', '8221404', '福岡県', 'フクオカケン', '田川郡香春町', 'タガワグンカワラマチ', '柿下', 'カキシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県田川郡香春町中津原', '40', '40601', '8221405', '福岡県', 'フクオカケン', '田川郡香春町', 'タガワグンカワラマチ', '中津原', 'ナカツバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県田川郡香春町香春', '40', '40601', '8221406', '福岡県', 'フクオカケン', '田川郡香春町', 'タガワグンカワラマチ', '香春', 'カワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宮若市', '40', '40226', '8230000', '福岡県', 'フクオカケン', '宮若市', 'ミヤワカシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('106065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宮若市龍徳', '40', '40226', '8230001', '福岡県', 'フクオカケン', '宮若市', 'ミヤワカシ', '龍徳', 'リュウトク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宮若市鶴田', '40', '40226', '8230002', '福岡県', 'フクオカケン', '宮若市', 'ミヤワカシ', '鶴田', 'ツルダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宮若市本城', '40', '40226', '8230003', '福岡県', 'フクオカケン', '宮若市', 'ミヤワカシ', '本城', 'ホンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宮若市磯光', '40', '40226', '8230004', '福岡県', 'フクオカケン', '宮若市', 'ミヤワカシ', '磯光', 'イソミツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宮若市上大隈', '40', '40226', '8230005', '福岡県', 'フクオカケン', '宮若市', 'ミヤワカシ', '上大隈', 'カミオオクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宮若市宮田', '40', '40226', '8230011', '福岡県', 'フクオカケン', '宮若市', 'ミヤワカシ', '宮田', 'ミヤタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宮若市長井鶴', '40', '40226', '8230012', '福岡県', 'フクオカケン', '宮若市', 'ミヤワカシ', '長井鶴', 'ナガイヅル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宮若市芹田', '40', '40226', '8230013', '福岡県', 'フクオカケン', '宮若市', 'ミヤワカシ', '芹田', 'セリダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宮若市下有木', '40', '40226', '8230014', '福岡県', 'フクオカケン', '宮若市', 'ミヤワカシ', '下有木', 'シモアルキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宮若市上有木', '40', '40226', '8230015', '福岡県', 'フクオカケン', '宮若市', 'ミヤワカシ', '上有木', 'カミアルキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宮若市四郎丸', '40', '40226', '8230016', '福岡県', 'フクオカケン', '宮若市', 'ミヤワカシ', '四郎丸', 'シロウマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県宮若市倉久', '40', '40226', '8230017', '福岡県', 'フクオカケン', '宮若市', 'ミヤワカシ', '倉久', 'クラヒサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県行橋市', '40', '40213', '8240000', '福岡県', 'フクオカケン', '行橋市', 'ユクハシシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('106079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県行橋市行事', '40', '40213', '8240001', '福岡県', 'フクオカケン', '行橋市', 'ユクハシシ', '行事', 'ギョウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県行橋市東大橋', '40', '40213', '8240002', '福岡県', 'フクオカケン', '行橋市', 'ユクハシシ', '東大橋', 'ヒガシオオハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県行橋市大橋', '40', '40213', '8240003', '福岡県', 'フクオカケン', '行橋市', 'ユクハシシ', '大橋', 'オオハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県行橋市金屋', '40', '40213', '8240004', '福岡県', 'フクオカケン', '行橋市', 'ユクハシシ', '金屋', 'カナヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県行橋市中央', '40', '40213', '8240005', '福岡県', 'フクオカケン', '行橋市', 'ユクハシシ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県行橋市門樋町', '40', '40213', '8240006', '福岡県', 'フクオカケン', '行橋市', 'ユクハシシ', '門樋町', 'モンピマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県行橋市神田町', '40', '40213', '8240007', '福岡県', 'フクオカケン', '行橋市', 'ユクハシシ', '神田町', 'ジンデンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県行橋市宮市町', '40', '40213', '8240008', '福岡県', 'フクオカケン', '行橋市', 'ユクハシシ', '宮市町', 'ミヤイチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県行橋市蓑島', '40', '40213', '8240011', '福岡県', 'フクオカケン', '行橋市', 'ユクハシシ', '蓑島', 'ミノシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県行橋市文久', '40', '40213', '8240012', '福岡県', 'フクオカケン', '行橋市', 'ユクハシシ', '文久', 'ブンキュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県行橋市沓尾', '40', '40213', '8240013', '福岡県', 'フクオカケン', '行橋市', 'ユクハシシ', '沓尾', 'クツオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県行橋市長井', '40', '40213', '8240014', '福岡県', 'フクオカケン', '行橋市', 'ユクハシシ', '長井', 'ナガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県行橋市元永', '40', '40213', '8240015', '福岡県', 'フクオカケン', '行橋市', 'ユクハシシ', '元永', 'モトナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県行橋市津留', '40', '40213', '8240016', '福岡県', 'フクオカケン', '行橋市', 'ユクハシシ', '津留', 'ツル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県行橋市真菰', '40', '40213', '8240017', '福岡県', 'フクオカケン', '行橋市', 'ユクハシシ', '真菰', 'マコモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県行橋市今井', '40', '40213', '8240018', '福岡県', 'フクオカケン', '行橋市', 'ユクハシシ', '今井', 'イマイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県行橋市馬場', '40', '40213', '8240021', '福岡県', 'フクオカケン', '行橋市', 'ユクハシシ', '馬場', 'ババ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県行橋市稲童', '40', '40213', '8240022', '福岡県', 'フクオカケン', '行橋市', 'ユクハシシ', '稲童', 'イナドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県行橋市松原', '40', '40213', '8240023', '福岡県', 'フクオカケン', '行橋市', 'ユクハシシ', '松原', 'マツバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県行橋市袋迫', '40', '40213', '8240024', '福岡県', 'フクオカケン', '行橋市', 'ユクハシシ', '袋迫', 'フクロサコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県行橋市東徳永', '40', '40213', '8240025', '福岡県', 'フクオカケン', '行橋市', 'ユクハシシ', '東徳永', 'ヒガシトクナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県行橋市道場寺', '40', '40213', '8240026', '福岡県', 'フクオカケン', '行橋市', 'ユクハシシ', '道場寺', 'ドウジョウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県行橋市高瀬', '40', '40213', '8240027', '福岡県', 'フクオカケン', '行橋市', 'ユクハシシ', '高瀬', 'タカセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県行橋市辻垣', '40', '40213', '8240028', '福岡県', 'フクオカケン', '行橋市', 'ユクハシシ', '辻垣', 'ツジカキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県行橋市西宮市', '40', '40213', '8240031', '福岡県', 'フクオカケン', '行橋市', 'ユクハシシ', '西宮市', 'ニシミヤイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県行橋市南大橋', '40', '40213', '8240032', '福岡県', 'フクオカケン', '行橋市', 'ユクハシシ', '南大橋', 'ミナミオオハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県行橋市北泉', '40', '40213', '8240033', '福岡県', 'フクオカケン', '行橋市', 'ユクハシシ', '北泉', 'キタイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県行橋市泉中央', '40', '40213', '8240034', '福岡県', 'フクオカケン', '行橋市', 'ユクハシシ', '泉中央', 'イズミチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県行橋市東泉', '40', '40213', '8240035', '福岡県', 'フクオカケン', '行橋市', 'ユクハシシ', '東泉', 'ヒガシイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県行橋市南泉', '40', '40213', '8240036', '福岡県', 'フクオカケン', '行橋市', 'ユクハシシ', '南泉', 'ミナミイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県行橋市矢留', '40', '40213', '8240037', '福岡県', 'フクオカケン', '行橋市', 'ユクハシシ', '矢留', 'ヤドミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県行橋市西泉', '40', '40213', '8240038', '福岡県', 'フクオカケン', '行橋市', 'ユクハシシ', '西泉', 'ニシイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県行橋市大野井', '40', '40213', '8240041', '福岡県', 'フクオカケン', '行橋市', 'ユクハシシ', '大野井', 'オオノイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県行橋市寺畔', '40', '40213', '8240042', '福岡県', 'フクオカケン', '行橋市', 'ユクハシシ', '寺畔', 'テラナワテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県行橋市流末', '40', '40213', '8240043', '福岡県', 'フクオカケン', '行橋市', 'ユクハシシ', '流末', 'リュウマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県行橋市天生田', '40', '40213', '8240044', '福岡県', 'フクオカケン', '行橋市', 'ユクハシシ', '天生田', 'アモウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県行橋市大谷', '40', '40213', '8240045', '福岡県', 'フクオカケン', '行橋市', 'ユクハシシ', '大谷', 'オオタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県行橋市西谷', '40', '40213', '8240046', '福岡県', 'フクオカケン', '行橋市', 'ユクハシシ', '西谷', 'ニシタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県行橋市津積', '40', '40213', '8240047', '福岡県', 'フクオカケン', '行橋市', 'ユクハシシ', '津積', 'ツツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県行橋市宝山', '40', '40213', '8240048', '福岡県', 'フクオカケン', '行橋市', 'ユクハシシ', '宝山', 'タカラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県行橋市福原', '40', '40213', '8240049', '福岡県', 'フクオカケン', '行橋市', 'ユクハシシ', '福原', 'フクバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県行橋市下検地', '40', '40213', '8240051', '福岡県', 'フクオカケン', '行橋市', 'ユクハシシ', '下検地', 'シモケンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県行橋市上検地', '40', '40213', '8240052', '福岡県', 'フクオカケン', '行橋市', 'ユクハシシ', '上検地', 'カミケンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県行橋市中川', '40', '40213', '8240053', '福岡県', 'フクオカケン', '行橋市', 'ユクハシシ', '中川', 'ナカガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県行橋市下稗田', '40', '40213', '8240054', '福岡県', 'フクオカケン', '行橋市', 'ユクハシシ', '下稗田', 'シモヒエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県行橋市上稗田', '40', '40213', '8240055', '福岡県', 'フクオカケン', '行橋市', 'ユクハシシ', '上稗田', 'カミヒエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県行橋市前田', '40', '40213', '8240056', '福岡県', 'フクオカケン', '行橋市', 'ユクハシシ', '前田', 'マエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県行橋市宮の杜', '40', '40213', '8240057', '福岡県', 'フクオカケン', '行橋市', 'ユクハシシ', '宮の杜', 'ミヤノモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県行橋市長木', '40', '40213', '8240058', '福岡県', 'フクオカケン', '行橋市', 'ユクハシシ', '長木', 'オサギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県行橋市草野', '40', '40213', '8240061', '福岡県', 'フクオカケン', '行橋市', 'ユクハシシ', '草野', 'クサノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県行橋市下津熊', '40', '40213', '8240062', '福岡県', 'フクオカケン', '行橋市', 'ユクハシシ', '下津熊', 'シモヅクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県行橋市中津熊', '40', '40213', '8240063', '福岡県', 'フクオカケン', '行橋市', 'ユクハシシ', '中津熊', 'ナカヅクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県行橋市上津熊', '40', '40213', '8240064', '福岡県', 'フクオカケン', '行橋市', 'ユクハシシ', '上津熊', 'カミヅクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県行橋市長音寺', '40', '40213', '8240065', '福岡県', 'フクオカケン', '行橋市', 'ユクハシシ', '長音寺', 'チョウオンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県行橋市吉国', '40', '40213', '8240066', '福岡県', 'フクオカケン', '行橋市', 'ユクハシシ', '吉国', 'ヨシクニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県行橋市二塚', '40', '40213', '8240067', '福岡県', 'フクオカケン', '行橋市', 'ユクハシシ', '二塚', 'フタヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県行橋市延永', '40', '40213', '8240068', '福岡県', 'フクオカケン', '行橋市', 'ユクハシシ', '延永', 'ノブナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県行橋市徳永', '40', '40213', '8240071', '福岡県', 'フクオカケン', '行橋市', 'ユクハシシ', '徳永', 'トクナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県行橋市須磨園', '40', '40213', '8240072', '福岡県', 'フクオカケン', '行橋市', 'ユクハシシ', '須磨園', 'スマゾノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県行橋市福丸', '40', '40213', '8240073', '福岡県', 'フクオカケン', '行橋市', 'ユクハシシ', '福丸', 'フクマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県行橋市常松', '40', '40213', '8240074', '福岡県', 'フクオカケン', '行橋市', 'ユクハシシ', '常松', 'ツネマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県行橋市長尾', '40', '40213', '8240075', '福岡県', 'フクオカケン', '行橋市', 'ユクハシシ', '長尾', 'ナガオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県行橋市下崎', '40', '40213', '8240076', '福岡県', 'フクオカケン', '行橋市', 'ユクハシシ', '下崎', 'シモサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県行橋市入覚', '40', '40213', '8240077', '福岡県', 'フクオカケン', '行橋市', 'ユクハシシ', '入覚', 'ニュウガク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県行橋市高来', '40', '40213', '8240078', '福岡県', 'フクオカケン', '行橋市', 'ユクハシシ', '高来', 'タカク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県行橋市矢山', '40', '40213', '8240079', '福岡県', 'フクオカケン', '行橋市', 'ユクハシシ', '矢山', 'ヤヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県京都郡みやこ町徳永', '40', '40625', '8240101', '福岡県', 'フクオカケン', '京都郡みやこ町', 'ミヤコグンミヤコマチ', '徳永', 'トクナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県京都郡みやこ町呰見', '40', '40625', '8240102', '福岡県', 'フクオカケン', '京都郡みやこ町', 'ミヤコグンミヤコマチ', '呰見', 'アザミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県京都郡みやこ町下原', '40', '40625', '8240103', '福岡県', 'フクオカケン', '京都郡みやこ町', 'ミヤコグンミヤコマチ', '下原', 'シモバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県京都郡みやこ町綾野', '40', '40625', '8240104', '福岡県', 'フクオカケン', '京都郡みやこ町', 'ミヤコグンミヤコマチ', '綾野', 'アヤノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県京都郡みやこ町徳政', '40', '40625', '8240105', '福岡県', 'フクオカケン', '京都郡みやこ町', 'ミヤコグンミヤコマチ', '徳政', 'トクセイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県京都郡みやこ町有久', '40', '40625', '8240106', '福岡県', 'フクオカケン', '京都郡みやこ町', 'ミヤコグンミヤコマチ', '有久', 'アリヒサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県京都郡みやこ町田中', '40', '40625', '8240107', '福岡県', 'フクオカケン', '京都郡みやこ町', 'ミヤコグンミヤコマチ', '田中', 'タナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県京都郡みやこ町上坂', '40', '40625', '8240111', '福岡県', 'フクオカケン', '京都郡みやこ町', 'ミヤコグンミヤコマチ', '上坂', 'カミサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県京都郡みやこ町上原', '40', '40625', '8240112', '福岡県', 'フクオカケン', '京都郡みやこ町', 'ミヤコグンミヤコマチ', '上原', 'カンバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県京都郡みやこ町吉岡', '40', '40625', '8240113', '福岡県', 'フクオカケン', '京都郡みやこ町', 'ミヤコグンミヤコマチ', '吉岡', 'ヨシオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県京都郡みやこ町節丸', '40', '40625', '8240114', '福岡県', 'フクオカケン', '京都郡みやこ町', 'ミヤコグンミヤコマチ', '節丸', 'セツマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県京都郡みやこ町光冨', '40', '40625', '8240115', '福岡県', 'フクオカケン', '京都郡みやこ町', 'ミヤコグンミヤコマチ', '光冨', 'ミツドミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県京都郡みやこ町豊津', '40', '40625', '8240121', '福岡県', 'フクオカケン', '京都郡みやこ町', 'ミヤコグンミヤコマチ', '豊津', 'トヨツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県京都郡みやこ町彦徳', '40', '40625', '8240122', '福岡県', 'フクオカケン', '京都郡みやこ町', 'ミヤコグンミヤコマチ', '彦徳', 'ケンドク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県京都郡みやこ町国分', '40', '40625', '8240123', '福岡県', 'フクオカケン', '京都郡みやこ町', 'ミヤコグンミヤコマチ', '国分', 'コクブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県京都郡みやこ町惣社', '40', '40625', '8240124', '福岡県', 'フクオカケン', '京都郡みやこ町', 'ミヤコグンミヤコマチ', '惣社', 'ソウシャ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県京都郡みやこ町国作', '40', '40625', '8240125', '福岡県', 'フクオカケン', '京都郡みやこ町', 'ミヤコグンミヤコマチ', '国作', 'コクサク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県京都郡みやこ町犀川下高屋', '40', '40625', '8240201', '福岡県', 'フクオカケン', '京都郡みやこ町', 'ミヤコグンミヤコマチ', '犀川下高屋', 'サイガワシモタカヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県京都郡みやこ町犀川上高屋', '40', '40625', '8240202', '福岡県', 'フクオカケン', '京都郡みやこ町', 'ミヤコグンミヤコマチ', '犀川上高屋', 'サイガワカミタカヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県京都郡みやこ町犀川続命院', '40', '40625', '8240203', '福岡県', 'フクオカケン', '京都郡みやこ町', 'ミヤコグンミヤコマチ', '犀川続命院', 'サイガワゾクミョウイン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県京都郡みやこ町犀川末江', '40', '40625', '8240204', '福岡県', 'フクオカケン', '京都郡みやこ町', 'ミヤコグンミヤコマチ', '犀川末江', 'サイガワスエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県京都郡みやこ町犀川久冨', '40', '40625', '8240205', '福岡県', 'フクオカケン', '京都郡みやこ町', 'ミヤコグンミヤコマチ', '犀川久冨', 'サイガワヒサドミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県京都郡みやこ町犀川八ツ溝', '40', '40625', '8240206', '福岡県', 'フクオカケン', '京都郡みやこ町', 'ミヤコグンミヤコマチ', '犀川八ツ溝', 'サイガワヤツミゾ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県京都郡みやこ町蔵持', '40', '40625', '8240207', '福岡県', 'フクオカケン', '京都郡みやこ町', 'ミヤコグンミヤコマチ', '蔵持', 'クラモチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県京都郡みやこ町今里', '40', '40625', '8240211', '福岡県', 'フクオカケン', '京都郡みやこ町', 'ミヤコグンミヤコマチ', '今里', 'イマサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県京都郡みやこ町犀川大熊', '40', '40625', '8240212', '福岡県', 'フクオカケン', '京都郡みやこ町', 'ミヤコグンミヤコマチ', '犀川大熊', 'サイガワオオクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県京都郡みやこ町犀川喜多良', '40', '40625', '8240213', '福岡県', 'フクオカケン', '京都郡みやこ町', 'ミヤコグンミヤコマチ', '犀川喜多良', 'サイガワキタラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県京都郡みやこ町犀川鐙畑', '40', '40625', '8240214', '福岡県', 'フクオカケン', '京都郡みやこ町', 'ミヤコグンミヤコマチ', '犀川鐙畑', 'サイガワアブミハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県京都郡みやこ町犀川生立', '40', '40625', '8240215', '福岡県', 'フクオカケン', '京都郡みやこ町', 'ミヤコグンミヤコマチ', '犀川生立', 'サイガワオイタツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県京都郡みやこ町犀川谷口', '40', '40625', '8240216', '福岡県', 'フクオカケン', '京都郡みやこ町', 'ミヤコグンミヤコマチ', '犀川谷口', 'サイガワタニグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県京都郡みやこ町犀川古川', '40', '40625', '8240217', '福岡県', 'フクオカケン', '京都郡みやこ町', 'ミヤコグンミヤコマチ', '犀川古川', 'サイガワフルカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県京都郡みやこ町犀川山鹿', '40', '40625', '8240221', '福岡県', 'フクオカケン', '京都郡みやこ町', 'ミヤコグンミヤコマチ', '犀川山鹿', 'サイガワヤマガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県京都郡みやこ町犀川大村', '40', '40625', '8240222', '福岡県', 'フクオカケン', '京都郡みやこ町', 'ミヤコグンミヤコマチ', '犀川大村', 'サイガワオオムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県京都郡みやこ町犀川柳瀬', '40', '40625', '8240223', '福岡県', 'フクオカケン', '京都郡みやこ町', 'ミヤコグンミヤコマチ', '犀川柳瀬', 'サイガワヤナセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県京都郡みやこ町犀川崎山', '40', '40625', '8240224', '福岡県', 'フクオカケン', '京都郡みやこ町', 'ミヤコグンミヤコマチ', '犀川崎山', 'サイガワサキヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県京都郡みやこ町犀川大坂', '40', '40625', '8240225', '福岡県', 'フクオカケン', '京都郡みやこ町', 'ミヤコグンミヤコマチ', '犀川大坂', 'サイガワオオサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県京都郡みやこ町松坂', '40', '40625', '8240226', '福岡県', 'フクオカケン', '京都郡みやこ町', 'ミヤコグンミヤコマチ', '松坂', 'マツサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県京都郡みやこ町犀川本庄', '40', '40625', '8240231', '福岡県', 'フクオカケン', '京都郡みやこ町', 'ミヤコグンミヤコマチ', '犀川本庄', 'サイガワホンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県京都郡みやこ町桜台', '40', '40625', '8240232', '福岡県', 'フクオカケン', '京都郡みやこ町', 'ミヤコグンミヤコマチ', '桜台', 'サクラダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県京都郡みやこ町犀川花熊', '40', '40625', '8240233', '福岡県', 'フクオカケン', '京都郡みやこ町', 'ミヤコグンミヤコマチ', '犀川花熊', 'サイガワハナグマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県京都郡みやこ町下高屋団地', '40', '40625', '8240234', '福岡県', 'フクオカケン', '京都郡みやこ町', 'ミヤコグンミヤコマチ', '下高屋団地', 'シモタカヤダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県京都郡みやこ町犀川木山', '40', '40625', '8240235', '福岡県', 'フクオカケン', '京都郡みやこ町', 'ミヤコグンミヤコマチ', '犀川木山', 'サイガワキヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県京都郡みやこ町犀川内垣', '40', '40625', '8240241', '福岡県', 'フクオカケン', '京都郡みやこ町', 'ミヤコグンミヤコマチ', '犀川内垣', 'サイガワウチガキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県京都郡みやこ町犀川犬丸', '40', '40625', '8240242', '福岡県', 'フクオカケン', '京都郡みやこ町', 'ミヤコグンミヤコマチ', '犀川犬丸', 'サイガワイヌマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県京都郡みやこ町犀川木井馬場', '40', '40625', '8240243', '福岡県', 'フクオカケン', '京都郡みやこ町', 'ミヤコグンミヤコマチ', '犀川木井馬場', 'サイガワキイババ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県京都郡みやこ町犀川横瀬', '40', '40625', '8240244', '福岡県', 'フクオカケン', '京都郡みやこ町', 'ミヤコグンミヤコマチ', '犀川横瀬', 'サイガワヨコセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県京都郡みやこ町犀川下伊良原', '40', '40625', '8240251', '福岡県', 'フクオカケン', '京都郡みやこ町', 'ミヤコグンミヤコマチ', '犀川下伊良原', 'サイガワシモイラハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県京都郡みやこ町犀川上伊良原', '40', '40625', '8240252', '福岡県', 'フクオカケン', '京都郡みやこ町', 'ミヤコグンミヤコマチ', '犀川上伊良原', 'サイガワカミイラハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県京都郡みやこ町犀川帆柱', '40', '40625', '8240253', '福岡県', 'フクオカケン', '京都郡みやこ町', 'ミヤコグンミヤコマチ', '犀川帆柱', 'サイガワホバシラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県京都郡みやこ町犀川扇谷', '40', '40625', '8240254', '福岡県', 'フクオカケン', '京都郡みやこ町', 'ミヤコグンミヤコマチ', '犀川扇谷', 'サイガワオウギダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県田川郡赤村', '40', '40609', '8240400', '福岡県', 'フクオカケン', '田川郡赤村', 'タガワグンアカムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('106198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県田川郡添田町津野', '40', '40602', '8240411', '福岡県', 'フクオカケン', '田川郡添田町', 'タガワグンソエダマチ', '津野', 'ツノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県田川郡赤村赤', '40', '40609', '8240431', '福岡県', 'フクオカケン', '田川郡赤村', 'タガワグンアカムラ', '赤', 'アカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県田川郡赤村内田', '40', '40609', '8240432', '福岡県', 'フクオカケン', '田川郡赤村', 'タガワグンアカムラ', '内田', 'ウチダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県田川郡大任町', '40', '40608', '8240500', '福岡県', 'フクオカケン', '田川郡大任町', 'タガワグンオオトウマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('106202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県田川郡大任町今任原', '40', '40608', '8240511', '福岡県', 'フクオカケン', '田川郡大任町', 'タガワグンオオトウマチ', '今任原', 'イマトウバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県田川郡大任町大行事', '40', '40608', '8240512', '福岡県', 'フクオカケン', '田川郡大任町', 'タガワグンオオトウマチ', '大行事', 'ダイギョウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県田川郡添田町', '40', '40602', '8240600', '福岡県', 'フクオカケン', '田川郡添田町', 'タガワグンソエダマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('106205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県田川郡添田町庄', '40', '40602', '8240601', '福岡県', 'フクオカケン', '田川郡添田町', 'タガワグンソエダマチ', '庄', 'ショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県田川郡添田町添田', '40', '40602', '8240602', '福岡県', 'フクオカケン', '田川郡添田町', 'タガワグンソエダマチ', '添田', 'ソエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県田川郡添田町中元寺', '40', '40602', '8240603', '福岡県', 'フクオカケン', '田川郡添田町', 'タガワグンソエダマチ', '中元寺', 'チュウガンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県田川郡添田町野田', '40', '40602', '8240604', '福岡県', 'フクオカケン', '田川郡添田町', 'タガワグンソエダマチ', '野田', 'ノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県田川郡添田町英彦山', '40', '40602', '8240721', '福岡県', 'フクオカケン', '田川郡添田町', 'タガワグンソエダマチ', '英彦山', 'ヒコサン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県田川郡添田町落合', '40', '40602', '8240722', '福岡県', 'フクオカケン', '田川郡添田町', 'タガワグンソエダマチ', '落合', 'オチアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県田川郡添田町桝田', '40', '40602', '8240723', '福岡県', 'フクオカケン', '田川郡添田町', 'タガワグンソエダマチ', '桝田', 'マスダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県京都郡みやこ町', '40', '40625', '8240800', '福岡県', 'フクオカケン', '京都郡みやこ町', 'ミヤコグンミヤコマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('106214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県京都郡みやこ町勝山大久保', '40', '40625', '8240801', '福岡県', 'フクオカケン', '京都郡みやこ町', 'ミヤコグンミヤコマチ', '勝山大久保', 'カツヤマオオクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県京都郡みやこ町勝山松田', '40', '40625', '8240802', '福岡県', 'フクオカケン', '京都郡みやこ町', 'ミヤコグンミヤコマチ', '勝山松田', 'カツヤママツダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県京都郡みやこ町勝山箕田', '40', '40625', '8240811', '福岡県', 'フクオカケン', '京都郡みやこ町', 'ミヤコグンミヤコマチ', '勝山箕田', 'カツヤマミダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県京都郡みやこ町勝山長川', '40', '40625', '8240812', '福岡県', 'フクオカケン', '京都郡みやこ町', 'ミヤコグンミヤコマチ', '勝山長川', 'カツヤマナガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県京都郡みやこ町勝山宮原', '40', '40625', '8240813', '福岡県', 'フクオカケン', '京都郡みやこ町', 'ミヤコグンミヤコマチ', '勝山宮原', 'カツヤマミヤバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県京都郡みやこ町勝山浦河内', '40', '40625', '8240814', '福岡県', 'フクオカケン', '京都郡みやこ町', 'ミヤコグンミヤコマチ', '勝山浦河内', 'カツヤマウラガワチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県京都郡みやこ町勝山上矢山', '40', '40625', '8240815', '福岡県', 'フクオカケン', '京都郡みやこ町', 'ミヤコグンミヤコマチ', '勝山上矢山', 'カツヤマカミヤヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県京都郡みやこ町勝山矢山', '40', '40625', '8240816', '福岡県', 'フクオカケン', '京都郡みやこ町', 'ミヤコグンミヤコマチ', '勝山矢山', 'カツヤマヤヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県京都郡みやこ町勝山岩熊', '40', '40625', '8240817', '福岡県', 'フクオカケン', '京都郡みやこ町', 'ミヤコグンミヤコマチ', '勝山岩熊', 'カツヤマイワグマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県京都郡みやこ町勝山池田', '40', '40625', '8240818', '福岡県', 'フクオカケン', '京都郡みやこ町', 'ミヤコグンミヤコマチ', '勝山池田', 'カツヤマイケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県京都郡みやこ町勝山上田', '40', '40625', '8240821', '福岡県', 'フクオカケン', '京都郡みやこ町', 'ミヤコグンミヤコマチ', '勝山上田', 'カツヤマウエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県京都郡みやこ町勝山黒田', '40', '40625', '8240822', '福岡県', 'フクオカケン', '京都郡みやこ町', 'ミヤコグンミヤコマチ', '勝山黒田', 'カツヤマクロダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県田川市', '40', '40206', '8250000', '福岡県', 'フクオカケン', '田川市', 'タガワシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('106233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県田川市伊加利', '40', '40206', '8250001', '福岡県', 'フクオカケン', '田川市', 'タガワシ', '伊加利', 'イカリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県田川市伊田', '40', '40206', '8250002', '福岡県', 'フクオカケン', '田川市', 'タガワシ', '伊田', 'イタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県田川市白鳥町', '40', '40206', '8250003', '福岡県', 'フクオカケン', '田川市', 'タガワシ', '白鳥町', 'シラトリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県田川市夏吉', '40', '40206', '8250004', '福岡県', 'フクオカケン', '田川市', 'タガワシ', '夏吉', 'ナツヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県田川市糒', '40', '40206', '8250005', '福岡県', 'フクオカケン', '田川市', 'タガワシ', '糒', 'ホシイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県田川市栄町', '40', '40206', '8250011', '福岡県', 'フクオカケン', '田川市', 'タガワシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県田川市日の出町', '40', '40206', '8250012', '福岡県', 'フクオカケン', '田川市', 'タガワシ', '日の出町', 'ヒノデマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県田川市中央町', '40', '40206', '8250013', '福岡県', 'フクオカケン', '田川市', 'タガワシ', '中央町', 'チュウオウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県田川市魚町', '40', '40206', '8250014', '福岡県', 'フクオカケン', '田川市', 'タガワシ', '魚町', 'ウオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県田川市伊田町', '40', '40206', '8250015', '福岡県', 'フクオカケン', '田川市', 'タガワシ', '伊田町', 'イタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県田川市新町', '40', '40206', '8250016', '福岡県', 'フクオカケン', '田川市', 'タガワシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県田川市寿町', '40', '40206', '8250017', '福岡県', 'フクオカケン', '田川市', 'タガワシ', '寿町', 'コトブキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県田川市番田町', '40', '40206', '8250018', '福岡県', 'フクオカケン', '田川市', 'タガワシ', '番田町', 'バンダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県田川郡川崎町池尻上原', '40', '40605', '8260002', '福岡県', 'フクオカケン', '田川郡川崎町', 'タガワグンカワサキマチ', '池尻', 'イケジリ', null, null, '上原', 'カンバル');
INSERT INTO `ms_addresses` VALUES ('106253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県田川郡川崎町池尻小倉畔', '40', '40605', '8260002', '福岡県', 'フクオカケン', '田川郡川崎町', 'タガワグンカワサキマチ', '池尻', 'イケジリ', null, null, '小倉畔', 'コクラノテ');
INSERT INTO `ms_addresses` VALUES ('106254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県田川市桜町', '40', '40206', '8260021', '福岡県', 'フクオカケン', '田川市', 'タガワシ', '桜町', 'サクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県田川市本町', '40', '40206', '8260022', '福岡県', 'フクオカケン', '田川市', 'タガワシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県田川市上本町', '40', '40206', '8260023', '福岡県', 'フクオカケン', '田川市', 'タガワシ', '上本町', 'カミホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県田川市西本町', '40', '40206', '8260024', '福岡県', 'フクオカケン', '田川市', 'タガワシ', '西本町', 'ニシホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県田川市大黒町', '40', '40206', '8260025', '福岡県', 'フクオカケン', '田川市', 'タガワシ', '大黒町', 'ダイコクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県田川市春日町', '40', '40206', '8260026', '福岡県', 'フクオカケン', '田川市', 'タガワシ', '春日町', 'カスガマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県田川市宮尾町', '40', '40206', '8260027', '福岡県', 'フクオカケン', '田川市', 'タガワシ', '宮尾町', 'ミヤオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県田川市千代町', '40', '40206', '8260031', '福岡県', 'フクオカケン', '田川市', 'タガワシ', '千代町', 'チヨマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県田川市平松町', '40', '40206', '8260032', '福岡県', 'フクオカケン', '田川市', 'タガワシ', '平松町', 'ヒラマツマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県田川市丸山町', '40', '40206', '8260033', '福岡県', 'フクオカケン', '田川市', 'タガワシ', '丸山町', 'マルヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県田川市弓削田', '40', '40206', '8260041', '福岡県', 'フクオカケン', '田川市', 'タガワシ', '弓削田', 'ユゲタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県田川市川宮', '40', '40206', '8260042', '福岡県', 'フクオカケン', '田川市', 'タガワシ', '川宮', 'カワミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県田川市奈良', '40', '40206', '8260043', '福岡県', 'フクオカケン', '田川市', 'タガワシ', '奈良', 'ナラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県田川市位登', '40', '40206', '8260044', '福岡県', 'フクオカケン', '田川市', 'タガワシ', '位登', 'イトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県田川市猪国', '40', '40206', '8260045', '福岡県', 'フクオカケン', '田川市', 'タガワシ', '猪国', 'イノクニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県田川郡川崎町', '40', '40605', '8270000', '福岡県', 'フクオカケン', '田川郡川崎町', 'タガワグンカワサキマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('106275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県田川郡川崎町安眞木', '40', '40605', '8270001', '福岡県', 'フクオカケン', '田川郡川崎町', 'タガワグンカワサキマチ', '安眞木', 'アマギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県田川郡川崎町池尻', '40', '40605', '8270002', '福岡県', 'フクオカケン', '田川郡川崎町', 'タガワグンカワサキマチ', '池尻', 'イケジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県田川郡川崎町川崎', '40', '40605', '8270003', '福岡県', 'フクオカケン', '田川郡川崎町', 'タガワグンカワサキマチ', '川崎', 'カワサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県田川郡川崎町田原', '40', '40605', '8270004', '福岡県', 'フクオカケン', '田川郡川崎町', 'タガワグンカワサキマチ', '田原', 'タバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県豊前市', '40', '40214', '8280000', '福岡県', 'フクオカケン', '豊前市', 'ブゼンシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('106281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県豊前市畠中', '40', '40214', '8280001', '福岡県', 'フクオカケン', '豊前市', 'ブゼンシ', '畠中', 'ハタケナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県豊前市松江', '40', '40214', '8280002', '福岡県', 'フクオカケン', '豊前市', 'ブゼンシ', '松江', 'ショウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県豊前市中村', '40', '40214', '8280003', '福岡県', 'フクオカケン', '豊前市', 'ブゼンシ', '中村', 'ナカムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県豊前市馬場', '40', '40214', '8280004', '福岡県', 'フクオカケン', '豊前市', 'ブゼンシ', '馬場', 'ババ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県豊前市畑', '40', '40214', '8280005', '福岡県', 'フクオカケン', '豊前市', 'ブゼンシ', '畑', 'ハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県豊前市四郎丸', '40', '40214', '8280011', '福岡県', 'フクオカケン', '豊前市', 'ブゼンシ', '四郎丸', 'シロウマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県豊前市鳥越', '40', '40214', '8280012', '福岡県', 'フクオカケン', '豊前市', 'ブゼンシ', '鳥越', 'トリゴエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県豊前市川内', '40', '40214', '8280013', '福岡県', 'フクオカケン', '豊前市', 'ブゼンシ', '川内', 'カワチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県豊前市八屋', '40', '40214', '8280021', '福岡県', 'フクオカケン', '豊前市', 'ブゼンシ', '八屋', 'ハチヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県豊前市宇島', '40', '40214', '8280022', '福岡県', 'フクオカケン', '豊前市', 'ブゼンシ', '宇島', 'ウノシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県豊前市沓川', '40', '40214', '8280023', '福岡県', 'フクオカケン', '豊前市', 'ブゼンシ', '沓川', 'クツガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県豊前市久松', '40', '40214', '8280024', '福岡県', 'フクオカケン', '豊前市', 'ブゼンシ', '久松', 'ヒサマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県豊前市恒富', '40', '40214', '8280025', '福岡県', 'フクオカケン', '豊前市', 'ブゼンシ', '恒富', 'ツネドミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県豊前市清水町', '40', '40214', '8280026', '福岡県', 'フクオカケン', '豊前市', 'ブゼンシ', '清水町', 'ショウズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県豊前市赤熊', '40', '40214', '8280027', '福岡県', 'フクオカケン', '豊前市', 'ブゼンシ', '赤熊', 'アカグマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県豊前市三毛門', '40', '40214', '8280031', '福岡県', 'フクオカケン', '豊前市', 'ブゼンシ', '三毛門', 'ミケカド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県豊前市三楽', '40', '40214', '8280032', '福岡県', 'フクオカケン', '豊前市', 'ブゼンシ', '三楽', 'サンラク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県豊前市六郎', '40', '40214', '8280033', '福岡県', 'フクオカケン', '豊前市', 'ブゼンシ', '六郎', 'ロクロウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県豊前市森久', '40', '40214', '8280034', '福岡県', 'フクオカケン', '豊前市', 'ブゼンシ', '森久', 'モリヒサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県豊前市市丸', '40', '40214', '8280035', '福岡県', 'フクオカケン', '豊前市', 'ブゼンシ', '市丸', 'イチマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県豊前市小犬丸', '40', '40214', '8280036', '福岡県', 'フクオカケン', '豊前市', 'ブゼンシ', '小犬丸', 'コイヌマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県豊前市梶屋', '40', '40214', '8280041', '福岡県', 'フクオカケン', '豊前市', 'ブゼンシ', '梶屋', 'カジヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県豊前市堀立', '40', '40214', '8280042', '福岡県', 'フクオカケン', '豊前市', 'ブゼンシ', '堀立', 'ホリタテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県豊前市岸井', '40', '40214', '8280043', '福岡県', 'フクオカケン', '豊前市', 'ブゼンシ', '岸井', 'キシイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県豊前市小石原', '40', '40214', '8280044', '福岡県', 'フクオカケン', '豊前市', 'ブゼンシ', '小石原', 'コイシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県豊前市皆毛', '40', '40214', '8280045', '福岡県', 'フクオカケン', '豊前市', 'ブゼンシ', '皆毛', 'カイモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県豊前市高田', '40', '40214', '8280046', '福岡県', 'フクオカケン', '豊前市', 'ブゼンシ', '高田', 'タカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県豊前市広瀬', '40', '40214', '8280047', '福岡県', 'フクオカケン', '豊前市', 'ブゼンシ', '広瀬', 'ヒロセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県豊前市久路土', '40', '40214', '8280048', '福岡県', 'フクオカケン', '豊前市', 'ブゼンシ', '久路土', 'キュウロツチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県豊前市鬼木', '40', '40214', '8280049', '福岡県', 'フクオカケン', '豊前市', 'ブゼンシ', '鬼木', 'オニノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県豊前市吉木', '40', '40214', '8280051', '福岡県', 'フクオカケン', '豊前市', 'ブゼンシ', '吉木', 'ヨシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県豊前市塔田', '40', '40214', '8280052', '福岡県', 'フクオカケン', '豊前市', 'ブゼンシ', '塔田', 'トウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県豊前市千束', '40', '40214', '8280053', '福岡県', 'フクオカケン', '豊前市', 'ブゼンシ', '千束', 'チヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県豊前市永久', '40', '40214', '8280054', '福岡県', 'フクオカケン', '豊前市', 'ブゼンシ', '永久', 'ナガヒサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県豊前市河原田', '40', '40214', '8280055', '福岡県', 'フクオカケン', '豊前市', 'ブゼンシ', '河原田', 'カワハラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県豊前市薬師寺', '40', '40214', '8280056', '福岡県', 'フクオカケン', '豊前市', 'ブゼンシ', '薬師寺', 'ヤクシジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県豊前市荒堀', '40', '40214', '8280061', '福岡県', 'フクオカケン', '豊前市', 'ブゼンシ', '荒堀', 'アラホリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県豊前市今市', '40', '40214', '8280062', '福岡県', 'フクオカケン', '豊前市', 'ブゼンシ', '今市', 'イマイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県豊前市野田', '40', '40214', '8280063', '福岡県', 'フクオカケン', '豊前市', 'ブゼンシ', '野田', 'ノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県豊前市大西', '40', '40214', '8280064', '福岡県', 'フクオカケン', '豊前市', 'ブゼンシ', '大西', 'オオニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県豊前市青畑', '40', '40214', '8280065', '福岡県', 'フクオカケン', '豊前市', 'ブゼンシ', '青畑', 'アオハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県豊前市大村', '40', '40214', '8280066', '福岡県', 'フクオカケン', '豊前市', 'ブゼンシ', '大村', 'オオムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県豊前市山内', '40', '40214', '8280071', '福岡県', 'フクオカケン', '豊前市', 'ブゼンシ', '山内', 'ヤマウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県豊前市才尾', '40', '40214', '8280072', '福岡県', 'フクオカケン', '豊前市', 'ブゼンシ', '才尾', 'サイオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県豊前市挾間', '40', '40214', '8280073', '福岡県', 'フクオカケン', '豊前市', 'ブゼンシ', '挾間', 'ハサマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県豊前市下河内', '40', '40214', '8280074', '福岡県', 'フクオカケン', '豊前市', 'ブゼンシ', '下河内', 'シモカワチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県豊前市下川底', '40', '40214', '8280075', '福岡県', 'フクオカケン', '豊前市', 'ブゼンシ', '下川底', 'シモカワソコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県豊前市中川底', '40', '40214', '8280076', '福岡県', 'フクオカケン', '豊前市', 'ブゼンシ', '中川底', 'ナカガワソコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県豊前市上川底', '40', '40214', '8280077', '福岡県', 'フクオカケン', '豊前市', 'ブゼンシ', '上川底', 'カミカワソコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県豊前市天和', '40', '40214', '8280081', '福岡県', 'フクオカケン', '豊前市', 'ブゼンシ', '天和', 'テンワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県豊前市大河内', '40', '40214', '8280082', '福岡県', 'フクオカケン', '豊前市', 'ブゼンシ', '大河内', 'オオカワチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県豊前市岩屋', '40', '40214', '8280083', '福岡県', 'フクオカケン', '豊前市', 'ブゼンシ', '岩屋', 'イワヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県豊前市篠瀬', '40', '40214', '8280084', '福岡県', 'フクオカケン', '豊前市', 'ブゼンシ', '篠瀬', 'シノセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県豊前市鳥井畑', '40', '40214', '8280085', '福岡県', 'フクオカケン', '豊前市', 'ブゼンシ', '鳥井畑', 'トリイハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県豊前市求菩提', '40', '40214', '8280086', '福岡県', 'フクオカケン', '豊前市', 'ブゼンシ', '求菩提', 'クボテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県築上郡築上町', '40', '40647', '8290100', '福岡県', 'フクオカケン', '築上郡築上町', 'チクジョウグンチクジョウマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('106340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県築上郡築上町東築城', '40', '40647', '8290101', '福岡県', 'フクオカケン', '築上郡築上町', 'チクジョウグンチクジョウマチ', '東築城', 'ヒガシツイキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県築上郡築上町築城', '40', '40647', '8290102', '福岡県', 'フクオカケン', '築上郡築上町', 'チクジョウグンチクジョウマチ', '築城', 'ツイキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県築上郡築上町広末', '40', '40647', '8290103', '福岡県', 'フクオカケン', '築上郡築上町', 'チクジョウグンチクジョウマチ', '広末', 'ヒロスエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県築上郡築上町小山田', '40', '40647', '8290104', '福岡県', 'フクオカケン', '築上郡築上町', 'チクジョウグンチクジョウマチ', '小山田', 'オヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県築上郡築上町上別府', '40', '40647', '8290105', '福岡県', 'フクオカケン', '築上郡築上町', 'チクジョウグンチクジョウマチ', '上別府', 'カミベフ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県築上郡築上町船迫', '40', '40647', '8290106', '福岡県', 'フクオカケン', '築上郡築上町', 'チクジョウグンチクジョウマチ', '船迫', 'フナサコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県築上郡築上町弓の師', '40', '40647', '8290107', '福岡県', 'フクオカケン', '築上郡築上町', 'チクジョウグンチクジョウマチ', '弓の師', 'ユミノシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県築上郡築上町下別府', '40', '40647', '8290108', '福岡県', 'フクオカケン', '築上郡築上町', 'チクジョウグンチクジョウマチ', '下別府', 'シモベフ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県築上郡築上町安武', '40', '40647', '8290111', '福岡県', 'フクオカケン', '築上郡築上町', 'チクジョウグンチクジョウマチ', '安武', 'ヤスタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県築上郡築上町赤幡', '40', '40647', '8290112', '福岡県', 'フクオカケン', '築上郡築上町', 'チクジョウグンチクジョウマチ', '赤幡', 'アカハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県築上郡築上町下香楽', '40', '40647', '8290113', '福岡県', 'フクオカケン', '築上郡築上町', 'チクジョウグンチクジョウマチ', '下香楽', 'シモコウラク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県築上郡築上町上香楽', '40', '40647', '8290114', '福岡県', 'フクオカケン', '築上郡築上町', 'チクジョウグンチクジョウマチ', '上香楽', 'カミコウラク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県築上郡築上町上深野', '40', '40647', '8290115', '福岡県', 'フクオカケン', '築上郡築上町', 'チクジョウグンチクジョウマチ', '上深野', 'カミフカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県築上郡築上町下深野', '40', '40647', '8290116', '福岡県', 'フクオカケン', '築上郡築上町', 'チクジョウグンチクジョウマチ', '下深野', 'シモフカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県築上郡築上町袈裟丸', '40', '40647', '8290117', '福岡県', 'フクオカケン', '築上郡築上町', 'チクジョウグンチクジョウマチ', '袈裟丸', 'ケサマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県築上郡築上町松丸', '40', '40647', '8290121', '福岡県', 'フクオカケン', '築上郡築上町', 'チクジョウグンチクジョウマチ', '松丸', 'マツマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県築上郡築上町伝法寺', '40', '40647', '8290122', '福岡県', 'フクオカケン', '築上郡築上町', 'チクジョウグンチクジョウマチ', '伝法寺', 'デンボウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県築上郡築上町本庄', '40', '40647', '8290123', '福岡県', 'フクオカケン', '築上郡築上町', 'チクジョウグンチクジョウマチ', '本庄', 'ホンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県築上郡築上町櫟原', '40', '40647', '8290124', '福岡県', 'フクオカケン', '築上郡築上町', 'チクジョウグンチクジョウマチ', '櫟原', 'イチギバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県築上郡築上町寒田', '40', '40647', '8290125', '福岡県', 'フクオカケン', '築上郡築上町', 'チクジョウグンチクジョウマチ', '寒田', 'サワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県築上郡築上町西八田航空自衛隊築城基地', '40', '40647', '8290151', '福岡県', 'フクオカケン', '築上郡築上町', 'チクジョウグンチクジョウマチ', '西八田', 'ニシハッタ', null, null, '航空自衛隊築城基地', 'コウクウジエイタイツイキキチ');
INSERT INTO `ms_addresses` VALUES ('106361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県築上郡築上町椎田', '40', '40647', '8290301', '福岡県', 'フクオカケン', '築上郡築上町', 'チクジョウグンチクジョウマチ', '椎田', 'シイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県築上郡築上町臼田', '40', '40647', '8290302', '福岡県', 'フクオカケン', '築上郡築上町', 'チクジョウグンチクジョウマチ', '臼田', 'ウスダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県築上郡築上町山本', '40', '40647', '8290303', '福岡県', 'フクオカケン', '築上郡築上町', 'チクジョウグンチクジョウマチ', '山本', 'ヤマモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県築上郡築上町小原', '40', '40647', '8290304', '福岡県', 'フクオカケン', '築上郡築上町', 'チクジョウグンチクジョウマチ', '小原', 'オバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県築上郡築上町真如寺', '40', '40647', '8290305', '福岡県', 'フクオカケン', '築上郡築上町', 'チクジョウグンチクジョウマチ', '真如寺', 'シンニョウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県築上郡築上町湊', '40', '40647', '8290311', '福岡県', 'フクオカケン', '築上郡築上町', 'チクジョウグンチクジョウマチ', '湊', 'ミナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県築上郡築上町石堂', '40', '40647', '8290312', '福岡県', 'フクオカケン', '築上郡築上町', 'チクジョウグンチクジョウマチ', '石堂', 'イシドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県築上郡築上町有安', '40', '40647', '8290313', '福岡県', 'フクオカケン', '築上郡築上町', 'チクジョウグンチクジョウマチ', '有安', 'アリヤス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県築上郡築上町上ノ河内', '40', '40647', '8290314', '福岡県', 'フクオカケン', '築上郡築上町', 'チクジョウグンチクジョウマチ', '上ノ河内', 'ウエノカワチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県築上郡築上町上り松', '40', '40647', '8290315', '福岡県', 'フクオカケン', '築上郡築上町', 'チクジョウグンチクジョウマチ', '上り松', 'アガリマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県築上郡築上町坂本', '40', '40647', '8290321', '福岡県', 'フクオカケン', '築上郡築上町', 'チクジョウグンチクジョウマチ', '坂本', 'サカモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県築上郡築上町日奈古', '40', '40647', '8290322', '福岡県', 'フクオカケン', '築上郡築上町', 'チクジョウグンチクジョウマチ', '日奈古', 'ヒナゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県築上郡築上町極楽寺', '40', '40647', '8290323', '福岡県', 'フクオカケン', '築上郡築上町', 'チクジョウグンチクジョウマチ', '極楽寺', 'ゴクラクジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県築上郡築上町高塚', '40', '40647', '8290331', '福岡県', 'フクオカケン', '築上郡築上町', 'チクジョウグンチクジョウマチ', '高塚', 'タカツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県築上郡築上町越路', '40', '40647', '8290332', '福岡県', 'フクオカケン', '築上郡築上町', 'チクジョウグンチクジョウマチ', '越路', 'コイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県築上郡築上町水原', '40', '40647', '8290333', '福岡県', 'フクオカケン', '築上郡築上町', 'チクジョウグンチクジョウマチ', '水原', 'ミズハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県築上郡築上町奈古', '40', '40647', '8290334', '福岡県', 'フクオカケン', '築上郡築上町', 'チクジョウグンチクジョウマチ', '奈古', 'ナゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県築上郡築上町岩丸', '40', '40647', '8290335', '福岡県', 'フクオカケン', '築上郡築上町', 'チクジョウグンチクジョウマチ', '岩丸', 'イワマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県築上郡築上町宇留津', '40', '40647', '8290341', '福岡県', 'フクオカケン', '築上郡築上町', 'チクジョウグンチクジョウマチ', '宇留津', 'ウルヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県築上郡築上町東八田', '40', '40647', '8290342', '福岡県', 'フクオカケン', '築上郡築上町', 'チクジョウグンチクジョウマチ', '東八田', 'ヒガシハッタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県築上郡築上町西八田', '40', '40647', '8290343', '福岡県', 'フクオカケン', '築上郡築上町', 'チクジョウグンチクジョウマチ', '西八田', 'ニシハッタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡池田町', '01', '01644', '0830000', '北海道', 'ホッカイドウ', '中川郡池田町', 'ナカガワグンイケダチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('106385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市小森野', '40', '40203', '8300001', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '小森野', 'コモリノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市高野', '40', '40203', '8300002', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '高野', 'タカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市東櫛原町', '40', '40203', '8300003', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '東櫛原町', 'ヒガシクシハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市南薫町', '40', '40203', '8300004', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '南薫町', 'ナンクンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市通外町', '40', '40203', '8300005', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '通外町', 'トオリホカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市南薫西町', '40', '40203', '8300006', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '南薫西町', 'ナンクンニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡池田町旭町', '01', '01644', '0830001', '北海道', 'ホッカイドウ', '中川郡池田町', 'ナカガワグンイケダチョウ', '旭町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市旭町', '40', '40203', '8300011', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '旭町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市日ノ出町', '40', '40203', '8300012', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '日ノ出町', 'ヒノデマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市櫛原町', '40', '40203', '8300013', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '櫛原町', 'クシハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市寺町', '40', '40203', '8300014', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '寺町', 'テラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市螢川町', '40', '40203', '8300015', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '螢川町', 'ホタルガワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市通東町', '40', '40203', '8300016', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '通東町', 'トオリヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市日吉町', '40', '40203', '8300017', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '日吉町', 'ヒヨシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市通町', '40', '40203', '8300018', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '通町', 'トオリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡池田町清見', '01', '01644', '0830002', '北海道', 'ホッカイドウ', '中川郡池田町', 'ナカガワグンイケダチョウ', '清見', 'キヨミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市篠山町', '40', '40203', '8300021', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '篠山町', 'ササヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市城南町', '40', '40203', '8300022', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '城南町', 'ジョウナンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市中央町', '40', '40203', '8300023', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '中央町', 'チュウオウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市縄手町', '40', '40203', '8300024', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '縄手町', 'ナワテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市瀬下町', '40', '40203', '8300025', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '瀬下町', 'セノシタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市長門石町', '40', '40203', '8300026', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '長門石町', 'ナガトイシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市長門石', '40', '40203', '8300027', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '長門石', 'ナガトイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市京町', '40', '40203', '8300028', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '京町', 'キョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市洗町', '40', '40203', '8300029', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '洗町', 'アライマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡池田町清見ケ丘', '01', '01644', '0830003', '北海道', 'ホッカイドウ', '中川郡池田町', 'ナカガワグンイケダチョウ', '清見ケ丘', 'キヨミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市六ツ門町', '40', '40203', '8300031', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '六ツ門町', 'ムツモンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市東町', '40', '40203', '8300032', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '東町', 'ヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市天神町', '40', '40203', '8300033', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '天神町', 'テンジンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市大手町', '40', '40203', '8300034', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '大手町', 'オオテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市東和町', '40', '40203', '8300035', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '東和町', 'トウワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市篠原町', '40', '40203', '8300036', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '篠原町', 'シノハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市諏訪野町', '40', '40203', '8300037', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '諏訪野町', 'スワノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市西町', '40', '40203', '8300038', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '西町', 'ニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡池田町様舞', '01', '01644', '0830004', '北海道', 'ホッカイドウ', '中川郡池田町', 'ナカガワグンイケダチョウ', '様舞', 'サママイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市白山町', '40', '40203', '8300041', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '白山町', 'シラヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市荘島町', '40', '40203', '8300042', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '荘島町', 'ショウジママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市松ケ枝町', '40', '40203', '8300043', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '松ケ枝町', 'マツガエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市本町', '40', '40203', '8300044', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市小頭町', '40', '40203', '8300045', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '小頭町', 'コガシラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市原古賀町', '40', '40203', '8300046', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '原古賀町', 'ハランコガマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市津福本町', '40', '40203', '8300047', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '津福本町', 'ツブクホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市梅満町', '40', '40203', '8300048', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '梅満町', 'ウメミツマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市大石町', '40', '40203', '8300049', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '大石町', 'オオイシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市南', '40', '40203', '8300051', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '南', 'ミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市上津町', '40', '40203', '8300052', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '上津町', 'カミツマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市藤山町', '40', '40203', '8300053', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '藤山町', 'フジヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市藤光町', '40', '40203', '8300054', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '藤光町', 'フジミツマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市上津', '40', '40203', '8300055', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '上津', 'カミツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市本山', '40', '40203', '8300056', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '本山', 'モトヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市藤光', '40', '40203', '8300057', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '藤光', 'フジミツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市野伏間', '40', '40203', '8300058', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '野伏間', 'ノブスマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市江戸屋敷', '40', '40203', '8300059', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '江戸屋敷', 'エドヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市津福今町', '40', '40203', '8300061', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '津福今町', 'ツブクイママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市荒木町白口', '40', '40203', '8300062', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '荒木町白口', 'アラキマチシラクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市荒木町荒木', '40', '40203', '8300063', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '荒木町荒木', 'アラキマチアラキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市荒木町藤田', '40', '40203', '8300064', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '荒木町藤田', 'アラキマチフジタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市荒木町今', '40', '40203', '8300065', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '荒木町今', 'アラキマチイマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市荒木町下荒木', '40', '40203', '8300066', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '荒木町下荒木', 'アラキマチシモアラキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市大善寺南', '40', '40203', '8300070', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '大善寺南', 'ダイゼンジミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市安武町武島', '40', '40203', '8300071', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '安武町武島', 'ヤスタケマチタケシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市安武町安武本', '40', '40203', '8300072', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '安武町安武本', 'ヤスタケマチヤスタケホン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市大善寺町宮本', '40', '40203', '8300073', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '大善寺町宮本', 'ダイゼンジマチミヤモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市大善寺町夜明', '40', '40203', '8300074', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '大善寺町夜明', 'ダイゼンジマチヨアケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市大善寺町黒田', '40', '40203', '8300075', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '大善寺町黒田', 'ダイゼンジマチクロダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市大善寺町藤吉', '40', '40203', '8300076', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '大善寺町藤吉', 'ダイゼンジマチフジヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市大善寺町中津', '40', '40203', '8300077', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '大善寺町中津', 'ダイゼンジマチナカツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市安武町住吉', '40', '40203', '8300078', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '安武町住吉', 'ヤスタケマチスミヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市大善寺大橋', '40', '40203', '8300079', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '大善寺大橋', 'ダイゼンジオオハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市三潴町早津崎', '40', '40203', '8300101', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '三潴町早津崎', 'ミヅママチハヤツザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市三潴町田川', '40', '40203', '8300102', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '三潴町田川', 'ミヅママチタガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市三潴町高三潴', '40', '40203', '8300103', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '三潴町高三潴', 'ミヅママチタカミズマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市三潴町原田', '40', '40203', '8300104', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '三潴町原田', 'ミヅママチハルダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市三潴町草場', '40', '40203', '8300105', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '三潴町草場', 'ミヅママチクサバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市三潴町西牟田', '40', '40203', '8300111', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '三潴町西牟田', 'ミヅママチニシムタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市三潴町玉満', '40', '40203', '8300112', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '三潴町玉満', 'ミヅママチタマミツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市三潴町生岩', '40', '40203', '8300113', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '三潴町生岩', 'ミヅママチイキイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市三潴町福光', '40', '40203', '8300114', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '三潴町福光', 'ミヅママチフクミツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市三潴町壱町原', '40', '40203', '8300115', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '三潴町壱町原', 'ミヅママチイッチョウバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市三潴町清松', '40', '40203', '8300116', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '三潴町清松', 'ミヅママチキヨマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡池田町大通南', '01', '01644', '0830020', '北海道', 'ホッカイドウ', '中川郡池田町', 'ナカガワグンイケダチョウ', '大通南', 'オオドオリミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市城島町芦塚', '40', '40203', '8300201', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '城島町芦塚', 'ジョウジママチアシヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市城島町下田', '40', '40203', '8300202', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '城島町下田', 'ジョウジママチシモダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市城島町浜', '40', '40203', '8300203', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '城島町浜', 'ジョウジママチハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市城島町内野', '40', '40203', '8300204', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '城島町内野', 'ジョウジママチウチノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市城島町大依', '40', '40203', '8300205', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '城島町大依', 'ジョウジママチオオヨリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市城島町六町原', '40', '40203', '8300206', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '城島町六町原', 'ジョウジママチロクチョウバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市城島町城島', '40', '40203', '8300207', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '城島町城島', 'ジョウジママチジョウジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡池田町西1条', '01', '01644', '0830021', '北海道', 'ホッカイドウ', '中川郡池田町', 'ナカガワグンイケダチョウ', '西1条', 'ニシ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市城島町楢津', '40', '40203', '8300211', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '城島町楢津', 'ジョウジママチナラツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市城島町江上上', '40', '40203', '8300212', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '城島町江上上', 'ジョウジママチエガミカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市城島町江上', '40', '40203', '8300213', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '城島町江上', 'ジョウジママチエガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市城島町江上本', '40', '40203', '8300214', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '城島町江上本', 'ジョウジママチエガミホン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市城島町原中牟田', '40', '40203', '8300215', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '城島町原中牟田', 'ジョウジママチハラナカムタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市城島町江島', '40', '40203', '8300216', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '城島町江島', 'ジョウジママチエシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡池田町西2条', '01', '01644', '0830022', '北海道', 'ホッカイドウ', '中川郡池田町', 'ナカガワグンイケダチョウ', '西2条', 'ニシ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市城島町浮島', '40', '40203', '8300221', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '城島町浮島', 'ジョウジママチウキシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市城島町青木島', '40', '40203', '8300222', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '城島町青木島', 'ジョウジママチアオキシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市城島町四郎丸', '40', '40203', '8300223', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '城島町四郎丸', 'ジョウジママチシロウマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市城島町上青木', '40', '40203', '8300224', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '城島町上青木', 'ジョウジママチカミアオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市城島町下青木', '40', '40203', '8300225', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '城島町下青木', 'ジョウジママチシモアオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市城島町西青木', '40', '40203', '8300226', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '城島町西青木', 'ジョウジママチニシアオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡池田町西3条', '01', '01644', '0830023', '北海道', 'ホッカイドウ', '中川郡池田町', 'ナカガワグンイケダチョウ', '西3条', 'ニシ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡池田町利別西町', '01', '01644', '0830031', '北海道', 'ホッカイドウ', '中川郡池田町', 'ナカガワグンイケダチョウ', '利別西町', 'トシベツニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡池田町利別東町', '01', '01644', '0830032', '北海道', 'ホッカイドウ', '中川郡池田町', 'ナカガワグンイケダチョウ', '利別東町', 'トシベツヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡池田町利別南町', '01', '01644', '0830033', '北海道', 'ホッカイドウ', '中川郡池田町', 'ナカガワグンイケダチョウ', '利別南町', 'トシベツミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡池田町利別本町', '01', '01644', '0830034', '北海道', 'ホッカイドウ', '中川郡池田町', 'ナカガワグンイケダチョウ', '利別本町', 'トシベツモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県三潴郡大木町', '40', '40522', '8300400', '福岡県', 'フクオカケン', '三潴郡大木町', 'ミズマグンオオキマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('106495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県三潴郡大木町笹渕', '40', '40522', '8300401', '福岡県', 'フクオカケン', '三潴郡大木町', 'ミズマグンオオキマチ', '笹渕', 'ササブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県三潴郡大木町福土', '40', '40522', '8300402', '福岡県', 'フクオカケン', '三潴郡大木町', 'ミズマグンオオキマチ', '福土', 'フクド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県三潴郡大木町大角', '40', '40522', '8300403', '福岡県', 'フクオカケン', '三潴郡大木町', 'ミズマグンオオキマチ', '大角', 'オオズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県三潴郡大木町上白垣', '40', '40522', '8300404', '福岡県', 'フクオカケン', '三潴郡大木町', 'ミズマグンオオキマチ', '上白垣', 'カミシラカキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県三潴郡大木町横溝', '40', '40522', '8300405', '福岡県', 'フクオカケン', '三潴郡大木町', 'ミズマグンオオキマチ', '横溝', 'ヨコミゾ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県三潴郡大木町前牟田', '40', '40522', '8300406', '福岡県', 'フクオカケン', '三潴郡大木町', 'ミズマグンオオキマチ', '前牟田', 'マエムタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡池田町川合', '01', '01644', '0830041', '北海道', 'ホッカイドウ', '中川郡池田町', 'ナカガワグンイケダチョウ', '川合', 'カワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県三潴郡大木町蛭池', '40', '40522', '8300411', '福岡県', 'フクオカケン', '三潴郡大木町', 'ミズマグンオオキマチ', '蛭池', 'ヒルイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県三潴郡大木町侍島', '40', '40522', '8300412', '福岡県', 'フクオカケン', '三潴郡大木町', 'ミズマグンオオキマチ', '侍島', 'サムライジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県三潴郡大木町上牟田口', '40', '40522', '8300413', '福岡県', 'フクオカケン', '三潴郡大木町', 'ミズマグンオオキマチ', '上牟田口', 'カミムタグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県三潴郡大木町上木佐木', '40', '40522', '8300414', '福岡県', 'フクオカケン', '三潴郡大木町', 'ミズマグンオオキマチ', '上木佐木', 'カミキサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県三潴郡大木町絵下古賀', '40', '40522', '8300415', '福岡県', 'フクオカケン', '三潴郡大木町', 'ミズマグンオオキマチ', '絵下古賀', 'エゲコガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県三潴郡大木町八町牟田', '40', '40522', '8300416', '福岡県', 'フクオカケン', '三潴郡大木町', 'ミズマグンオオキマチ', '八町牟田', 'ハッチョウムタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県三潴郡大木町上八院', '40', '40522', '8300417', '福岡県', 'フクオカケン', '三潴郡大木町', 'ミズマグンオオキマチ', '上八院', 'カミハチイン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡池田町千代田', '01', '01644', '0830042', '北海道', 'ホッカイドウ', '中川郡池田町', 'ナカガワグンイケダチョウ', '千代田', 'チヨダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県三潴郡大木町奥牟田', '40', '40522', '8300421', '福岡県', 'フクオカケン', '三潴郡大木町', 'ミズマグンオオキマチ', '奥牟田', 'オクムタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県三潴郡大木町高橋', '40', '40522', '8300422', '福岡県', 'フクオカケン', '三潴郡大木町', 'ミズマグンオオキマチ', '高橋', 'タカハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県三潴郡大木町大藪', '40', '40522', '8300423', '福岡県', 'フクオカケン', '三潴郡大木町', 'ミズマグンオオキマチ', '大藪', 'オオヤブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県三潴郡大木町三八松', '40', '40522', '8300424', '福岡県', 'フクオカケン', '三潴郡大木町', 'ミズマグンオオキマチ', '三八松', 'ミヤマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県三潴郡大木町筏溝', '40', '40522', '8300425', '福岡県', 'フクオカケン', '三潴郡大木町', 'ミズマグンオオキマチ', '筏溝', 'イカダミゾ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡池田町豊田', '01', '01644', '0830043', '北海道', 'ホッカイドウ', '中川郡池田町', 'ナカガワグンイケダチョウ', '豊田', 'トヨタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡池田町青山', '01', '01644', '0830044', '北海道', 'ホッカイドウ', '中川郡池田町', 'ナカガワグンイケダチョウ', '青山', 'アオヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡池田町富岡', '01', '01644', '0830045', '北海道', 'ホッカイドウ', '中川郡池田町', 'ナカガワグンイケダチョウ', '富岡', 'トミオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡池田町東台', '01', '01644', '0830046', '北海道', 'ホッカイドウ', '中川郡池田町', 'ナカガワグンイケダチョウ', '東台', 'トウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡池田町昭栄', '01', '01644', '0830047', '北海道', 'ホッカイドウ', '中川郡池田町', 'ナカガワグンイケダチョウ', '昭栄', 'ショウエイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡池田町大通', '01', '01644', '0830090', '北海道', 'ホッカイドウ', '中川郡池田町', 'ナカガワグンイケダチョウ', '大通', 'オオドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡池田町東1条', '01', '01644', '0830091', '北海道', 'ホッカイドウ', '中川郡池田町', 'ナカガワグンイケダチョウ', '東1条', 'ヒガシ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡池田町東2条', '01', '01644', '0830092', '北海道', 'ホッカイドウ', '中川郡池田町', 'ナカガワグンイケダチョウ', '東2条', 'ヒガシ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市北野町中川', '40', '40203', '8301101', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '北野町中川', 'キタノマチナカガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市北野町八重亀', '40', '40203', '8301102', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '北野町八重亀', 'キタノマチヤエガメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市北野町金島', '40', '40203', '8301103', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '北野町金島', 'キタノマチカネシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市北野町大城', '40', '40203', '8301104', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '北野町大城', 'キタノマチオオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市北野町中島', '40', '40203', '8301105', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '北野町中島', 'キタノマチナカシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市北野町仁王丸', '40', '40203', '8301106', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '北野町仁王丸', 'キタノマチニオウマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市北野町塚島', '40', '40203', '8301107', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '北野町塚島', 'キタノマチツカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市北野町千代島', '40', '40203', '8301111', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '北野町千代島', 'キタノマチチヨジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市北野町陣屋', '40', '40203', '8301112', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '北野町陣屋', 'キタノマチジンヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市北野町中', '40', '40203', '8301113', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '北野町中', 'キタノマチナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市北野町高良', '40', '40203', '8301114', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '北野町高良', 'キタノマチコウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市北野町鳥巣', '40', '40203', '8301115', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '北野町鳥巣', 'キタノマチトリス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市北野町石崎', '40', '40203', '8301116', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '北野町石崎', 'キタノマチイシザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市北野町上弓削', '40', '40203', '8301117', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '北野町上弓削', 'キタノマチカミユゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市北野町十郎丸', '40', '40203', '8301121', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '北野町十郎丸', 'キタノマチジュウロウマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市北野町今山', '40', '40203', '8301122', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '北野町今山', 'キタノマチイマヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市北野町冨多', '40', '40203', '8301123', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '北野町冨多', 'キタノマチトミタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市北野町乙吉', '40', '40203', '8301124', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '北野町乙吉', 'キタノマチオトヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市北野町乙丸', '40', '40203', '8301125', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '北野町乙丸', 'キタノマチオトマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市北野町稲数', '40', '40203', '8301126', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '北野町稲数', 'キタノマチイナカズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市北野町赤司', '40', '40203', '8301127', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '北野町赤司', 'キタノマチアカシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県三井郡大刀洗町', '40', '40503', '8301200', '福岡県', 'フクオカケン', '三井郡大刀洗町', 'ミイグンタチアライマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('106549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県三井郡大刀洗町冨多', '40', '40503', '8301201', '福岡県', 'フクオカケン', '三井郡大刀洗町', 'ミイグンタチアライマチ', '冨多', 'トミタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県三井郡大刀洗町菅野', '40', '40503', '8301202', '福岡県', 'フクオカケン', '三井郡大刀洗町', 'ミイグンタチアライマチ', '菅野', 'スガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県三井郡大刀洗町三川', '40', '40503', '8301203', '福岡県', 'フクオカケン', '三井郡大刀洗町', 'ミイグンタチアライマチ', '三川', 'ミカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県三井郡大刀洗町西原', '40', '40503', '8301204', '福岡県', 'フクオカケン', '三井郡大刀洗町', 'ミイグンタチアライマチ', '西原', 'ニシバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県三井郡大刀洗町守部', '40', '40503', '8301205', '福岡県', 'フクオカケン', '三井郡大刀洗町', 'ミイグンタチアライマチ', '守部', 'モルベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県三井郡大刀洗町中川', '40', '40503', '8301206', '福岡県', 'フクオカケン', '三井郡大刀洗町', 'ミイグンタチアライマチ', '中川', 'ナカガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県三井郡大刀洗町本郷', '40', '40503', '8301211', '福岡県', 'フクオカケン', '三井郡大刀洗町', 'ミイグンタチアライマチ', '本郷', 'ホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県三井郡大刀洗町甲条', '40', '40503', '8301212', '福岡県', 'フクオカケン', '三井郡大刀洗町', 'ミイグンタチアライマチ', '甲条', 'コウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県三井郡大刀洗町春日', '40', '40503', '8301213', '福岡県', 'フクオカケン', '三井郡大刀洗町', 'ミイグンタチアライマチ', '春日', 'カスガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県三井郡大刀洗町栄田', '40', '40503', '8301214', '福岡県', 'フクオカケン', '三井郡大刀洗町', 'ミイグンタチアライマチ', '栄田', 'サカエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県三井郡大刀洗町高樋', '40', '40503', '8301221', '福岡県', 'フクオカケン', '三井郡大刀洗町', 'ミイグンタチアライマチ', '高樋', 'タカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県三井郡大刀洗町上高橋', '40', '40503', '8301222', '福岡県', 'フクオカケン', '三井郡大刀洗町', 'ミイグンタチアライマチ', '上高橋', 'カミタカハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県三井郡大刀洗町今', '40', '40503', '8301223', '福岡県', 'フクオカケン', '三井郡大刀洗町', 'ミイグンタチアライマチ', '今', 'イマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県三井郡大刀洗町鵜木', '40', '40503', '8301224', '福岡県', 'フクオカケン', '三井郡大刀洗町', 'ミイグンタチアライマチ', '鵜木', 'ウノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県三井郡大刀洗町下高橋', '40', '40503', '8301225', '福岡県', 'フクオカケン', '三井郡大刀洗町', 'ミイグンタチアライマチ', '下高橋', 'シモタカハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県三井郡大刀洗町山隈', '40', '40503', '8301226', '福岡県', 'フクオカケン', '三井郡大刀洗町', 'ミイグンタチアライマチ', '山隈', 'ヤマグマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大川市', '40', '40212', '8310000', '福岡県', 'フクオカケン', '大川市', 'オオカワシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('106610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大川市下青木', '40', '40212', '8310001', '福岡県', 'フクオカケン', '大川市', 'オオカワシ', '下青木', 'シモアオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大川市下林', '40', '40212', '8310002', '福岡県', 'フクオカケン', '大川市', 'オオカワシ', '下林', 'ゲバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大川市諸富', '40', '40212', '8310003', '福岡県', 'フクオカケン', '大川市', 'オオカワシ', '諸富', 'モロドミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大川市榎津', '40', '40212', '8310004', '福岡県', 'フクオカケン', '大川市', 'オオカワシ', '榎津', 'エノキヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大川市向島', '40', '40212', '8310005', '福岡県', 'フクオカケン', '大川市', 'オオカワシ', '向島', 'ムカイジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大川市中古賀', '40', '40212', '8310006', '福岡県', 'フクオカケン', '大川市', 'オオカワシ', '中古賀', 'ナカコガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大川市道海島', '40', '40212', '8310007', '福岡県', 'フクオカケン', '大川市', 'オオカワシ', '道海島', 'ドウカイジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大川市鐘ケ江', '40', '40212', '8310008', '福岡県', 'フクオカケン', '大川市', 'オオカワシ', '鐘ケ江', 'カネガエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大川市下白垣', '40', '40212', '8310011', '福岡県', 'フクオカケン', '大川市', 'オオカワシ', '下白垣', 'シモシラカキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大川市上白垣', '40', '40212', '8310012', '福岡県', 'フクオカケン', '大川市', 'オオカワシ', '上白垣', 'カミシラカキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大川市中八院', '40', '40212', '8310013', '福岡県', 'フクオカケン', '大川市', 'オオカワシ', '中八院', 'ナカハチイン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大川市中木室', '40', '40212', '8310014', '福岡県', 'フクオカケン', '大川市', 'オオカワシ', '中木室', 'ナカキムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大川市本木室', '40', '40212', '8310015', '福岡県', 'フクオカケン', '大川市', 'オオカワシ', '本木室', 'ホンギムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大川市酒見', '40', '40212', '8310016', '福岡県', 'フクオカケン', '大川市', 'オオカワシ', '酒見', 'サケミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大川市下八院', '40', '40212', '8310017', '福岡県', 'フクオカケン', '大川市', 'オオカワシ', '下八院', 'シモハチイン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大川市大橋', '40', '40212', '8310021', '福岡県', 'フクオカケン', '大川市', 'オオカワシ', '大橋', 'オオハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大川市下木佐木', '40', '40212', '8310022', '福岡県', 'フクオカケン', '大川市', 'オオカワシ', '下木佐木', 'シモキサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大川市下牟田口', '40', '40212', '8310023', '福岡県', 'フクオカケン', '大川市', 'オオカワシ', '下牟田口', 'シモムタグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大川市鬼古賀', '40', '40212', '8310024', '福岡県', 'フクオカケン', '大川市', 'オオカワシ', '鬼古賀', 'オニコガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大川市坂井', '40', '40212', '8310025', '福岡県', 'フクオカケン', '大川市', 'オオカワシ', '坂井', 'サカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大川市三丸', '40', '40212', '8310026', '福岡県', 'フクオカケン', '大川市', 'オオカワシ', '三丸', 'ミツマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大川市荻島', '40', '40212', '8310027', '福岡県', 'フクオカケン', '大川市', 'オオカワシ', '荻島', 'オギシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大川市郷原', '40', '40212', '8310028', '福岡県', 'フクオカケン', '大川市', 'オオカワシ', '郷原', 'ゴウバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大川市上巻', '40', '40212', '8310031', '福岡県', 'フクオカケン', '大川市', 'オオカワシ', '上巻', 'アゲマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大川市北古賀', '40', '40212', '8310032', '福岡県', 'フクオカケン', '大川市', 'オオカワシ', '北古賀', 'キタコガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大川市幡保', '40', '40212', '8310033', '福岡県', 'フクオカケン', '大川市', 'オオカワシ', '幡保', 'ハタホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大川市一木', '40', '40212', '8310034', '福岡県', 'フクオカケン', '大川市', 'オオカワシ', '一木', 'ヒトツキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大川市津', '40', '40212', '8310035', '福岡県', 'フクオカケン', '大川市', 'オオカワシ', '津', 'ツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大川市小保', '40', '40212', '8310041', '福岡県', 'フクオカケン', '大川市', 'オオカワシ', '小保', 'コボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大川市九網', '40', '40212', '8310042', '福岡県', 'フクオカケン', '大川市', 'オオカワシ', '九網', 'クアミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大川市新田', '40', '40212', '8310043', '福岡県', 'フクオカケン', '大川市', 'オオカワシ', '新田', 'シンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大川市紅粉屋', '40', '40212', '8310044', '福岡県', 'フクオカケン', '大川市', 'オオカワシ', '紅粉屋', 'ベニヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大川市大野島', '40', '40212', '8310045', '福岡県', 'フクオカケン', '大川市', 'オオカワシ', '大野島', 'オオノシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市', '40', '40207', '8320000', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('106647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市蒲生', '40', '40207', '8320001', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '蒲生', 'ガモウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市高島', '40', '40207', '8320002', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '高島', 'タカシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市立石', '40', '40207', '8320003', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '立石', 'タテイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市矢加部', '40', '40207', '8320004', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '矢加部', 'ヤカベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市西蒲池', '40', '40207', '8320005', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '西蒲池', 'ニシカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市東蒲池', '40', '40207', '8320006', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '東蒲池', 'ヒガシカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市金納', '40', '40207', '8320007', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '金納', 'カンノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市保加町', '40', '40207', '8320011', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '保加町', 'ホカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市中町', '40', '40207', '8320012', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '中町', 'ナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市上町', '40', '40207', '8320013', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '上町', 'カミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市八百屋町', '40', '40207', '8320014', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '八百屋町', 'ヤオヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市西魚屋町', '40', '40207', '8320015', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '西魚屋町', 'ニシウオヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市蟹町', '40', '40207', '8320016', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '蟹町', 'カニマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市材木町', '40', '40207', '8320017', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '材木町', 'ザイモクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市本船津町', '40', '40207', '8320018', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '本船津町', 'モトフナツマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市隅町', '40', '40207', '8320021', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '隅町', 'スミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市旭町', '40', '40207', '8320022', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '旭町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市京町', '40', '40207', '8320023', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '京町', 'キョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市辻町', '40', '40207', '8320024', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '辻町', 'ツジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市恵美須町', '40', '40207', '8320025', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '恵美須町', 'エビスマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市曙町', '40', '40207', '8320026', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '曙町', 'アケボノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市横山町', '40', '40207', '8320027', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '横山町', 'ヨコヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市常盤町', '40', '40207', '8320028', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '常盤町', 'トキワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市八軒町', '40', '40207', '8320029', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '八軒町', 'ハチケンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市椿原町', '40', '40207', '8320031', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '椿原町', 'ツバハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市新町', '40', '40207', '8320032', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市南長柄町', '40', '40207', '8320033', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '南長柄町', 'ミナミナガエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市北長柄町', '40', '40207', '8320034', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '北長柄町', 'キタナガエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市東魚屋町', '40', '40207', '8320035', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '東魚屋町', 'ヒガシウオヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市小道具町', '40', '40207', '8320036', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '小道具町', 'コドウグマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市細工町', '40', '40207', '8320037', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '細工町', 'サイクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市片原町', '40', '40207', '8320041', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '片原町', 'カタハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市一新町', '40', '40207', '8320042', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '一新町', 'イッシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市出来町', '40', '40207', '8320043', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '出来町', 'デキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市袋町', '40', '40207', '8320044', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '袋町', 'フクロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市本町', '40', '40207', '8320045', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市奥州町', '40', '40207', '8320046', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '奥州町', 'オウシュウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市矢留町', '40', '40207', '8320050', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '矢留町', 'ヤドミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市佃町', '40', '40207', '8320051', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '佃町', 'ツクダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市橋本町', '40', '40207', '8320052', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '橋本町', 'ハシモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市大浜町', '40', '40207', '8320053', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '大浜町', 'オオハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市有明町', '40', '40207', '8320054', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '有明町', 'アリアケマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市吉富町', '40', '40207', '8320055', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '吉富町', 'ヨシトミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市矢留本町', '40', '40207', '8320056', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '矢留本町', 'ヤドミホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市弥四郎町', '40', '40207', '8320057', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '弥四郎町', 'ヤシロウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市上宮永町', '40', '40207', '8320058', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '上宮永町', 'カミミヤナガマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市下宮永町', '40', '40207', '8320059', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '下宮永町', 'シモミヤナガマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市本城町', '40', '40207', '8320061', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '本城町', 'ホンジョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市城南町', '40', '40207', '8320062', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '城南町', 'ジョウナンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市茂庵町', '40', '40207', '8320063', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '茂庵町', 'モアンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市宮永町', '40', '40207', '8320064', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '宮永町', 'ミヤナガマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市沖端町', '40', '40207', '8320065', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '沖端町', 'オキノハタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市稲荷町', '40', '40207', '8320066', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '稲荷町', 'イナリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市鬼童町', '40', '40207', '8320067', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '鬼童町', 'オンドウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市城隅町', '40', '40207', '8320068', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '城隅町', 'ジョウグウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市新外町', '40', '40207', '8320069', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '新外町', 'シンホカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市新船津町', '40', '40207', '8320071', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '新船津町', 'シンフナツマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市糀屋町', '40', '40207', '8320072', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '糀屋町', 'コウジヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市鍛冶屋町', '40', '40207', '8320073', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '鍛冶屋町', 'カジヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市元町', '40', '40207', '8320074', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '元町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市柳町', '40', '40207', '8320075', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '柳町', 'ヤナギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市坂本町', '40', '40207', '8320076', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '坂本町', 'サカモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市筑紫町', '40', '40207', '8320077', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '筑紫町', 'チクシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市西浜武', '40', '40207', '8320081', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '西浜武', 'ニシハマタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市古賀', '40', '40207', '8320082', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '古賀', 'コガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市南浜武', '40', '40207', '8320083', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '南浜武', 'ミナミハマタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市昭南町', '40', '40207', '8320084', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '昭南町', 'ショウナンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市吉原', '40', '40207', '8320085', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '吉原', 'ヨシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市久々原', '40', '40207', '8320086', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '久々原', 'ククハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市七ツ家', '40', '40207', '8320087', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '七ツ家', 'ナナツエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市間', '40', '40207', '8320088', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '間', 'ハサマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市田脇', '40', '40207', '8320089', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '田脇', 'タワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市三橋町起田', '40', '40207', '8320801', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '三橋町起田', 'ミツハシマチオキダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市三橋町吉開', '40', '40207', '8320802', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '三橋町吉開', 'ミツハシマチヨシガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市三橋町新村', '40', '40207', '8320803', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '三橋町新村', 'ミツハシマチミムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市三橋町木元', '40', '40207', '8320804', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '三橋町木元', 'ミツハシマチキノモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市三橋町磯鳥', '40', '40207', '8320805', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '三橋町磯鳥', 'ミツハシマチイソドリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市三橋町柳河', '40', '40207', '8320806', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '三橋町柳河', 'ミツハシマチヤナガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市三橋町枝光', '40', '40207', '8320807', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '三橋町枝光', 'ミツハシマチエダミツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市三橋町中山', '40', '40207', '8320811', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '三橋町中山', 'ミツハシマチナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市三橋町五拾町', '40', '40207', '8320812', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '三橋町五拾町', 'ミツハシマチゴジッチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市三橋町棚町', '40', '40207', '8320813', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '三橋町棚町', 'ミツハシマチタノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市三橋町垂見', '40', '40207', '8320814', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '三橋町垂見', 'ミツハシマチタルミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市三橋町白鳥', '40', '40207', '8320815', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '三橋町白鳥', 'ミツハシマチシラトリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市三橋町久末', '40', '40207', '8320816', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '三橋町久末', 'ミツハシマチヒサスエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市三橋町百町', '40', '40207', '8320821', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '三橋町百町', 'ミツハシマチヒャクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市三橋町下百町', '40', '40207', '8320822', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '三橋町下百町', 'ミツハシマチシモヒャクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市三橋町今古賀', '40', '40207', '8320823', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '三橋町今古賀', 'ミツハシマチイマコガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市三橋町藤吉', '40', '40207', '8320824', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '三橋町藤吉', 'ミツハシマチフジヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市三橋町江曲', '40', '40207', '8320825', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '三橋町江曲', 'ミツハシマチエマガリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市三橋町高畑', '40', '40207', '8320826', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '三橋町高畑', 'ミツハシマチタカハタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市三橋町蒲船津', '40', '40207', '8320827', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '三橋町蒲船津', 'ミツハシマチカマフナツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市三橋町正行', '40', '40207', '8320828', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '三橋町正行', 'ミツハシマチマサユキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑後市', '40', '40211', '8330000', '福岡県', 'フクオカケン', '筑後市', 'チクゴシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('106743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑後市一条', '40', '40211', '8330001', '福岡県', 'フクオカケン', '筑後市', 'チクゴシ', '一条', 'イチジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑後市前津', '40', '40211', '8330002', '福岡県', 'フクオカケン', '筑後市', 'チクゴシ', '前津', 'マエヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑後市羽犬塚', '40', '40211', '8330003', '福岡県', 'フクオカケン', '筑後市', 'チクゴシ', '羽犬塚', 'ハイヌヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑後市徳久', '40', '40211', '8330004', '福岡県', 'フクオカケン', '筑後市', 'チクゴシ', '徳久', 'トクヒサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑後市長浜', '40', '40211', '8330005', '福岡県', 'フクオカケン', '筑後市', 'チクゴシ', '長浜', 'ナガハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑後市新溝', '40', '40211', '8330006', '福岡県', 'フクオカケン', '筑後市', 'チクゴシ', '新溝', 'シンミゾ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑後市鶴田', '40', '40211', '8330007', '福岡県', 'フクオカケン', '筑後市', 'チクゴシ', '鶴田', 'ツルダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑後市久恵', '40', '40211', '8330011', '福岡県', 'フクオカケン', '筑後市', 'チクゴシ', '久恵', 'クエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑後市溝口', '40', '40211', '8330012', '福岡県', 'フクオカケン', '筑後市', 'チクゴシ', '溝口', 'ミゾクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑後市北長田', '40', '40211', '8330013', '福岡県', 'フクオカケン', '筑後市', 'チクゴシ', '北長田', 'キタナガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑後市尾島', '40', '40211', '8330014', '福岡県', 'フクオカケン', '筑後市', 'チクゴシ', '尾島', 'オシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑後市津島', '40', '40211', '8330015', '福岡県', 'フクオカケン', '筑後市', 'チクゴシ', '津島', 'ツシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑後市常用', '40', '40211', '8330016', '福岡県', 'フクオカケン', '筑後市', 'チクゴシ', '常用', 'ツネモチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑後市志', '40', '40211', '8330017', '福岡県', 'フクオカケン', '筑後市', 'チクゴシ', '志', 'シムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑後市下妻', '40', '40211', '8330021', '福岡県', 'フクオカケン', '筑後市', 'チクゴシ', '下妻', 'シモツマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑後市富安', '40', '40211', '8330022', '福岡県', 'フクオカケン', '筑後市', 'チクゴシ', '富安', 'トミヤス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑後市馬間田', '40', '40211', '8330023', '福岡県', 'フクオカケン', '筑後市', 'チクゴシ', '馬間田', 'ママダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑後市中牟田', '40', '40211', '8330024', '福岡県', 'フクオカケン', '筑後市', 'チクゴシ', '中牟田', 'ナカムタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑後市中折地', '40', '40211', '8330025', '福岡県', 'フクオカケン', '筑後市', 'チクゴシ', '中折地', 'ナカオリジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑後市折地', '40', '40211', '8330026', '福岡県', 'フクオカケン', '筑後市', 'チクゴシ', '折地', 'オリジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑後市水田', '40', '40211', '8330027', '福岡県', 'フクオカケン', '筑後市', 'チクゴシ', '水田', 'ミズタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑後市山ノ井', '40', '40211', '8330031', '福岡県', 'フクオカケン', '筑後市', 'チクゴシ', '山ノ井', 'ヤマノイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑後市野町', '40', '40211', '8330032', '福岡県', 'フクオカケン', '筑後市', 'チクゴシ', '野町', 'ノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑後市上北島', '40', '40211', '8330033', '福岡県', 'フクオカケン', '筑後市', 'チクゴシ', '上北島', 'カミキタジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑後市下北島', '40', '40211', '8330034', '福岡県', 'フクオカケン', '筑後市', 'チクゴシ', '下北島', 'シモキタジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑後市古島', '40', '40211', '8330035', '福岡県', 'フクオカケン', '筑後市', 'チクゴシ', '古島', 'コジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑後市井田', '40', '40211', '8330036', '福岡県', 'フクオカケン', '筑後市', 'チクゴシ', '井田', 'セイデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑後市島田', '40', '40211', '8330037', '福岡県', 'フクオカケン', '筑後市', 'チクゴシ', '島田', 'シマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑後市和泉', '40', '40211', '8330041', '福岡県', 'フクオカケン', '筑後市', 'チクゴシ', '和泉', 'イズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑後市長崎', '40', '40211', '8330042', '福岡県', 'フクオカケン', '筑後市', 'チクゴシ', '長崎', 'ナガサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑後市庄島', '40', '40211', '8330043', '福岡県', 'フクオカケン', '筑後市', 'チクゴシ', '庄島', 'ショウジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑後市富久', '40', '40211', '8330044', '福岡県', 'フクオカケン', '筑後市', 'チクゴシ', '富久', 'トミヒサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑後市四ケ所', '40', '40211', '8330045', '福岡県', 'フクオカケン', '筑後市', 'チクゴシ', '四ケ所', 'シカショ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑後市江口', '40', '40211', '8330046', '福岡県', 'フクオカケン', '筑後市', 'チクゴシ', '江口', 'エグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑後市若菜', '40', '40211', '8330047', '福岡県', 'フクオカケン', '筑後市', 'チクゴシ', '若菜', 'ワカナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑後市富重', '40', '40211', '8330051', '福岡県', 'フクオカケン', '筑後市', 'チクゴシ', '富重', 'トミシゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑後市高江', '40', '40211', '8330052', '福岡県', 'フクオカケン', '筑後市', 'チクゴシ', '高江', 'タカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑後市西牟田', '40', '40211', '8330053', '福岡県', 'フクオカケン', '筑後市', 'チクゴシ', '西牟田', 'ニシムタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑後市蔵数', '40', '40211', '8330054', '福岡県', 'フクオカケン', '筑後市', 'チクゴシ', '蔵数', 'クラカズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑後市熊野', '40', '40211', '8330055', '福岡県', 'フクオカケン', '筑後市', 'チクゴシ', '熊野', 'クマノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県筑後市久富', '40', '40211', '8330056', '福岡県', 'フクオカケン', '筑後市', 'チクゴシ', '久富', 'ヒサドミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県八女市', '40', '40210', '8340000', '福岡県', 'フクオカケン', '八女市', 'ヤメシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('106786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県八女郡立花町', '40', '40543', '8340000', '福岡県', 'フクオカケン', '八女郡立花町', 'ヤメグンタチバナマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('106787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県八女市宅間田', '40', '40210', '8340001', '福岡県', 'フクオカケン', '八女市', 'ヤメシ', '宅間田', 'タクマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県八女市黒土', '40', '40210', '8340002', '福岡県', 'フクオカケン', '八女市', 'ヤメシ', '黒土', 'クロツチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県八女市平田', '40', '40210', '8340003', '福岡県', 'フクオカケン', '八女市', 'ヤメシ', '平田', 'ヒラタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県八女市納楚', '40', '40210', '8340004', '福岡県', 'フクオカケン', '八女市', 'ヤメシ', '納楚', 'ノウソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県八女市大島', '40', '40210', '8340005', '福岡県', 'フクオカケン', '八女市', 'ヤメシ', '大島', 'オオジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県八女市吉田', '40', '40210', '8340006', '福岡県', 'フクオカケン', '八女市', 'ヤメシ', '吉田', 'ヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県八女市長野', '40', '40210', '8340011', '福岡県', 'フクオカケン', '八女市', 'ヤメシ', '長野', 'ナガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県八女市山内', '40', '40210', '8340012', '福岡県', 'フクオカケン', '八女市', 'ヤメシ', '山内', 'ヤマウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県八女市大籠', '40', '40210', '8340013', '福岡県', 'フクオカケン', '八女市', 'ヤメシ', '大籠', 'オオゴモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県八女市忠見', '40', '40210', '8340014', '福岡県', 'フクオカケン', '八女市', 'ヤメシ', '忠見', 'タダミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県八女市本', '40', '40210', '8340015', '福岡県', 'フクオカケン', '八女市', 'ヤメシ', '本', 'ホン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県八女市豊福', '40', '40210', '8340016', '福岡県', 'フクオカケン', '八女市', 'ヤメシ', '豊福', 'トヨブク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県八女市北田形', '40', '40210', '8340021', '福岡県', 'フクオカケン', '八女市', 'ヤメシ', '北田形', 'キタタガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県八女市柳島', '40', '40210', '8340022', '福岡県', 'フクオカケン', '八女市', 'ヤメシ', '柳島', 'ヤナジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県八女市馬場', '40', '40210', '8340023', '福岡県', 'フクオカケン', '八女市', 'ヤメシ', '馬場', 'ババ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県八女市津江', '40', '40210', '8340024', '福岡県', 'フクオカケン', '八女市', 'ヤメシ', '津江', 'ツノエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県八女市祈祷院', '40', '40210', '8340025', '福岡県', 'フクオカケン', '八女市', 'ヤメシ', '祈祷院', 'キトウイン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県八女市井延', '40', '40210', '8340026', '福岡県', 'フクオカケン', '八女市', 'ヤメシ', '井延', 'イノブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県八女市本町', '40', '40210', '8340031', '福岡県', 'フクオカケン', '八女市', 'ヤメシ', '本町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県八女市宮野', '40', '40210', '8340032', '福岡県', 'フクオカケン', '八女市', 'ヤメシ', '宮野', 'ミヤノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県八女市柳瀬', '40', '40210', '8340033', '福岡県', 'フクオカケン', '八女市', 'ヤメシ', '柳瀬', 'ヤナゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県八女市高塚', '40', '40210', '8340034', '福岡県', 'フクオカケン', '八女市', 'ヤメシ', '高塚', 'タカツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県八女市緒玉', '40', '40210', '8340041', '福岡県', 'フクオカケン', '八女市', 'ヤメシ', '緒玉', 'オダマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県八女市酒井田', '40', '40210', '8340042', '福岡県', 'フクオカケン', '八女市', 'ヤメシ', '酒井田', 'サカイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県八女市光', '40', '40210', '8340043', '福岡県', 'フクオカケン', '八女市', 'ヤメシ', '光', 'ヒカリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県八女市矢原', '40', '40210', '8340044', '福岡県', 'フクオカケン', '八女市', 'ヤメシ', '矢原', 'ヤバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県八女市平', '40', '40210', '8340045', '福岡県', 'フクオカケン', '八女市', 'ヤメシ', '平', 'タイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県八女市国武', '40', '40210', '8340046', '福岡県', 'フクオカケン', '八女市', 'ヤメシ', '国武', 'クニタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県八女市稲富', '40', '40210', '8340047', '福岡県', 'フクオカケン', '八女市', 'ヤメシ', '稲富', 'イナドミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県八女市立野', '40', '40210', '8340051', '福岡県', 'フクオカケン', '八女市', 'ヤメシ', '立野', 'タテノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県八女市新庄', '40', '40210', '8340052', '福岡県', 'フクオカケン', '八女市', 'ヤメシ', '新庄', 'シンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県八女市川犬', '40', '40210', '8340053', '福岡県', 'フクオカケン', '八女市', 'ヤメシ', '川犬', 'カワイヌ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県八女市前古賀', '40', '40210', '8340054', '福岡県', 'フクオカケン', '八女市', 'ヤメシ', '前古賀', 'マエコガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県八女市鵜池', '40', '40210', '8340055', '福岡県', 'フクオカケン', '八女市', 'ヤメシ', '鵜池', 'ウノイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県八女市今福', '40', '40210', '8340061', '福岡県', 'フクオカケン', '八女市', 'ヤメシ', '今福', 'イマブク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県八女市岩崎', '40', '40210', '8340062', '福岡県', 'フクオカケン', '八女市', 'ヤメシ', '岩崎', 'イワサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県八女市本村', '40', '40210', '8340063', '福岡県', 'フクオカケン', '八女市', 'ヤメシ', '本村', 'モトムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県八女市蒲原', '40', '40210', '8340064', '福岡県', 'フクオカケン', '八女市', 'ヤメシ', '蒲原', 'カマハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県八女市亀甲', '40', '40210', '8340065', '福岡県', 'フクオカケン', '八女市', 'ヤメシ', '亀甲', 'カメノコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県八女市室岡', '40', '40210', '8340066', '福岡県', 'フクオカケン', '八女市', 'ヤメシ', '室岡', 'ムロオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県八女市龍ケ原', '40', '40210', '8340067', '福岡県', 'フクオカケン', '八女市', 'ヤメシ', '龍ケ原', 'タツガハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県八女郡立花町田形', '40', '40543', '8340071', '福岡県', 'フクオカケン', '八女郡立花町', 'ヤメグンタチバナマチ', '田形', 'タガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県八女郡立花町遠久谷', '40', '40543', '8340072', '福岡県', 'フクオカケン', '八女郡立花町', 'ヤメグンタチバナマチ', '遠久谷', 'トオクダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県八女郡立花町下辺春', '40', '40543', '8340073', '福岡県', 'フクオカケン', '八女郡立花町', 'ヤメグンタチバナマチ', '下辺春', 'シモヘバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県八女郡立花町谷川', '40', '40543', '8340074', '福岡県', 'フクオカケン', '八女郡立花町', 'ヤメグンタチバナマチ', '谷川', 'タニガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県八女郡立花町原島', '40', '40543', '8340075', '福岡県', 'フクオカケン', '八女郡立花町', 'ヤメグンタチバナマチ', '原島', 'ハラジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県八女郡立花町山崎', '40', '40543', '8340081', '福岡県', 'フクオカケン', '八女郡立花町', 'ヤメグンタチバナマチ', '山崎', 'ヤマサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県八女郡立花町兼松', '40', '40543', '8340082', '福岡県', 'フクオカケン', '八女郡立花町', 'ヤメグンタチバナマチ', '兼松', 'カネマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県八女郡立花町上辺春', '40', '40543', '8340083', '福岡県', 'フクオカケン', '八女郡立花町', 'ヤメグンタチバナマチ', '上辺春', 'カミヘバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県八女郡立花町白木', '40', '40543', '8340084', '福岡県', 'フクオカケン', '八女郡立花町', 'ヤメグンタチバナマチ', '白木', 'シラキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県八女郡立花町北山', '40', '40543', '8340085', '福岡県', 'フクオカケン', '八女郡立花町', 'ヤメグンタチバナマチ', '北山', 'キタヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県八女郡広川町', '40', '40544', '8340100', '福岡県', 'フクオカケン', '八女郡広川町', 'ヤメグンヒロカワマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('106839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県八女郡広川町小椎尾', '40', '40544', '8340101', '福岡県', 'フクオカケン', '八女郡広川町', 'ヤメグンヒロカワマチ', '小椎尾', 'コジオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県八女郡広川町水原', '40', '40544', '8340102', '福岡県', 'フクオカケン', '八女郡広川町', 'ヤメグンヒロカワマチ', '水原', 'ミズハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県八女郡広川町六田', '40', '40544', '8340103', '福岡県', 'フクオカケン', '八女郡広川町', 'ヤメグンヒロカワマチ', '六田', 'ロクタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県八女郡広川町吉常', '40', '40544', '8340104', '福岡県', 'フクオカケン', '八女郡広川町', 'ヤメグンヒロカワマチ', '吉常', 'ヨシツネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県八女郡広川町長延', '40', '40544', '8340105', '福岡県', 'フクオカケン', '八女郡広川町', 'ヤメグンヒロカワマチ', '長延', 'ナガノブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県八女郡広川町日吉', '40', '40544', '8340111', '福岡県', 'フクオカケン', '八女郡広川町', 'ヤメグンヒロカワマチ', '日吉', 'ヒヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県八女郡広川町久泉', '40', '40544', '8340112', '福岡県', 'フクオカケン', '八女郡広川町', 'ヤメグンヒロカワマチ', '久泉', 'ヒサイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県八女郡広川町川上', '40', '40544', '8340113', '福岡県', 'フクオカケン', '八女郡広川町', 'ヤメグンヒロカワマチ', '川上', 'カワカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県八女郡広川町太田', '40', '40544', '8340114', '福岡県', 'フクオカケン', '八女郡広川町', 'ヤメグンヒロカワマチ', '太田', 'オオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県八女郡広川町新代', '40', '40544', '8340115', '福岡県', 'フクオカケン', '八女郡広川町', 'ヤメグンヒロカワマチ', '新代', 'ニイシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県八女郡広川町広川', '40', '40544', '8340121', '福岡県', 'フクオカケン', '八女郡広川町', 'ヤメグンヒロカワマチ', '広川', 'ヒロカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県八女郡広川町一條', '40', '40544', '8340122', '福岡県', 'フクオカケン', '八女郡広川町', 'ヤメグンヒロカワマチ', '一條', 'イチジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県八女郡広川町藤田', '40', '40544', '8340123', '福岡県', 'フクオカケン', '八女郡広川町', 'ヤメグンヒロカワマチ', '藤田', 'フジタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県八女郡星野村', '40', '40546', '8340201', '福岡県', 'フクオカケン', '八女郡星野村', 'ヤメグンホシノムラ', null, '　', '（全域）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('106860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県八女市上陽町上横山', '40', '40210', '8341101', '福岡県', 'フクオカケン', '八女市', 'ヤメシ', '上陽町上横山', 'ジョウヨウマチカミヨコヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県八女市上陽町北川内', '40', '40210', '8341102', '福岡県', 'フクオカケン', '八女市', 'ヤメシ', '上陽町北川内', 'ジョウヨウマチキタカワウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県八女市上陽町久木原', '40', '40210', '8341103', '福岡県', 'フクオカケン', '八女市', 'ヤメシ', '上陽町久木原', 'ジョウヨウマチクキハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県八女市上陽町下横山', '40', '40210', '8341104', '福岡県', 'フクオカケン', '八女市', 'ヤメシ', '上陽町下横山', 'ジョウヨウマチシモヨコヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県八女郡黒木町', '40', '40541', '8341200', '福岡県', 'フクオカケン', '八女郡黒木町', 'ヤメグンクロギマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('106865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県八女郡黒木町北大淵', '40', '40541', '8341201', '福岡県', 'フクオカケン', '八女郡黒木町', 'ヤメグンクロギマチ', '北大淵', 'キタオオブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県八女郡黒木町大淵', '40', '40541', '8341202', '福岡県', 'フクオカケン', '八女郡黒木町', 'ヤメグンクロギマチ', '大淵', 'オオブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県八女郡黒木町北木屋', '40', '40541', '8341203', '福岡県', 'フクオカケン', '八女郡黒木町', 'ヤメグンクロギマチ', '北木屋', 'キタゴヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県八女郡黒木町木屋', '40', '40541', '8341204', '福岡県', 'フクオカケン', '八女郡黒木町', 'ヤメグンクロギマチ', '木屋', 'コヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県八女郡黒木町田代', '40', '40541', '8341205', '福岡県', 'フクオカケン', '八女郡黒木町', 'ヤメグンクロギマチ', '田代', 'タシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県八女郡黒木町土窪', '40', '40541', '8341211', '福岡県', 'フクオカケン', '八女郡黒木町', 'ヤメグンクロギマチ', '土窪', 'ツチクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県八女郡黒木町鹿子生', '40', '40541', '8341212', '福岡県', 'フクオカケン', '八女郡黒木町', 'ヤメグンクロギマチ', '鹿子生', 'カコオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県八女郡黒木町本分', '40', '40541', '8341213', '福岡県', 'フクオカケン', '八女郡黒木町', 'ヤメグンクロギマチ', '本分', 'ホンブン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県八女郡黒木町田本', '40', '40541', '8341214', '福岡県', 'フクオカケン', '八女郡黒木町', 'ヤメグンクロギマチ', '田本', 'タモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県八女郡黒木町湯辺田', '40', '40541', '8341215', '福岡県', 'フクオカケン', '八女郡黒木町', 'ヤメグンクロギマチ', '湯辺田', 'ユベタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県八女郡黒木町桑原', '40', '40541', '8341216', '福岡県', 'フクオカケン', '八女郡黒木町', 'ヤメグンクロギマチ', '桑原', 'クワハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県八女郡黒木町黒木', '40', '40541', '8341217', '福岡県', 'フクオカケン', '八女郡黒木町', 'ヤメグンクロギマチ', '黒木', 'クロギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県八女郡黒木町今', '40', '40541', '8341221', '福岡県', 'フクオカケン', '八女郡黒木町', 'ヤメグンクロギマチ', '今', 'イマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県八女郡黒木町笠原', '40', '40541', '8341222', '福岡県', 'フクオカケン', '八女郡黒木町', 'ヤメグンクロギマチ', '笠原', 'カサハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県八女郡矢部村', '40', '40545', '8341400', '福岡県', 'フクオカケン', '八女郡矢部村', 'ヤメグンヤベムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('106881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県八女郡矢部村北矢部', '40', '40545', '8341401', '福岡県', 'フクオカケン', '八女郡矢部村', 'ヤメグンヤベムラ', '北矢部', 'キタヤベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県八女郡矢部村矢部', '40', '40545', '8341402', '福岡県', 'フクオカケン', '八女郡矢部村', 'ヤメグンヤベムラ', '矢部', 'ヤベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県みやま市', '40', '40229', '8350000', '福岡県', 'フクオカケン', 'みやま市', 'ミヤマシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('106887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県みやま市瀬高町廣瀬', '40', '40229', '8350001', '福岡県', 'フクオカケン', 'みやま市', 'ミヤマシ', '瀬高町廣瀬', 'セタカマチヒロセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県みやま市瀬高町小田', '40', '40229', '8350002', '福岡県', 'フクオカケン', 'みやま市', 'ミヤマシ', '瀬高町小田', 'セタカマチオダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県みやま市瀬高町本吉', '40', '40229', '8350003', '福岡県', 'フクオカケン', 'みやま市', 'ミヤマシ', '瀬高町本吉', 'セタカマチモトヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県みやま市瀬高町山門', '40', '40229', '8350004', '福岡県', 'フクオカケン', 'みやま市', 'ミヤマシ', '瀬高町山門', 'セタカマチヤマト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県みやま市瀬高町大草', '40', '40229', '8350005', '福岡県', 'フクオカケン', 'みやま市', 'ミヤマシ', '瀬高町大草', 'セタカマチオオクサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県みやま市瀬高町坂田', '40', '40229', '8350006', '福岡県', 'フクオカケン', 'みやま市', 'ミヤマシ', '瀬高町坂田', 'セタカマチサカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県みやま市瀬高町長田', '40', '40229', '8350007', '福岡県', 'フクオカケン', 'みやま市', 'ミヤマシ', '瀬高町長田', 'セタカマチナガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県みやま市瀬高町松田', '40', '40229', '8350011', '福岡県', 'フクオカケン', 'みやま市', 'ミヤマシ', '瀬高町松田', 'セタカマチマツダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県みやま市瀬高町大廣園', '40', '40229', '8350012', '福岡県', 'フクオカケン', 'みやま市', 'ミヤマシ', '瀬高町大廣園', 'セタカマチオオヒロゾノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県みやま市瀬高町太神', '40', '40229', '8350013', '福岡県', 'フクオカケン', 'みやま市', 'ミヤマシ', '瀬高町太神', 'セタカマチオオガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県みやま市瀬高町河内', '40', '40229', '8350014', '福岡県', 'フクオカケン', 'みやま市', 'ミヤマシ', '瀬高町河内', 'セタカマチカワチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県みやま市瀬高町泰仙寺', '40', '40229', '8350015', '福岡県', 'フクオカケン', 'みやま市', 'ミヤマシ', '瀬高町泰仙寺', 'セタカマチタイセンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県みやま市瀬高町濱田', '40', '40229', '8350016', '福岡県', 'フクオカケン', 'みやま市', 'ミヤマシ', '瀬高町濱田', 'セタカマチハマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県みやま市瀬高町東津留', '40', '40229', '8350017', '福岡県', 'フクオカケン', 'みやま市', 'ミヤマシ', '瀬高町東津留', 'セタカマチヒガシツル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県みやま市瀬高町高柳', '40', '40229', '8350018', '福岡県', 'フクオカケン', 'みやま市', 'ミヤマシ', '瀬高町高柳', 'セタカマチタカヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県みやま市瀬高町大江', '40', '40229', '8350019', '福岡県', 'フクオカケン', 'みやま市', 'ミヤマシ', '瀬高町大江', 'セタカマチオオエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県みやま市瀬高町本郷', '40', '40229', '8350021', '福岡県', 'フクオカケン', 'みやま市', 'ミヤマシ', '瀬高町本郷', 'セタカマチホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県みやま市瀬高町文廣', '40', '40229', '8350022', '福岡県', 'フクオカケン', 'みやま市', 'ミヤマシ', '瀬高町文廣', 'セタカマチアヤヒロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県みやま市瀬高町小川', '40', '40229', '8350023', '福岡県', 'フクオカケン', 'みやま市', 'ミヤマシ', '瀬高町小川', 'セタカマチオガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県みやま市瀬高町下庄', '40', '40229', '8350024', '福岡県', 'フクオカケン', 'みやま市', 'ミヤマシ', '瀬高町下庄', 'セタカマチシモノショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県みやま市瀬高町上庄', '40', '40229', '8350025', '福岡県', 'フクオカケン', 'みやま市', 'ミヤマシ', '瀬高町上庄', 'セタカマチカミノショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県みやま市山川町立山', '40', '40229', '8350101', '福岡県', 'フクオカケン', 'みやま市', 'ミヤマシ', '山川町立山', 'ヤマカワマチタチヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県みやま市山川町尾野', '40', '40229', '8350102', '福岡県', 'フクオカケン', 'みやま市', 'ミヤマシ', '山川町尾野', 'ヤマカワマチオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県みやま市山川町清水', '40', '40229', '8350103', '福岡県', 'フクオカケン', 'みやま市', 'ミヤマシ', '山川町清水', 'ヤマカワマチシミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県みやま市山川町河原内', '40', '40229', '8350104', '福岡県', 'フクオカケン', 'みやま市', 'ミヤマシ', '山川町河原内', 'ヤマカワマチカワハラウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県みやま市山川町真弓', '40', '40229', '8350111', '福岡県', 'フクオカケン', 'みやま市', 'ミヤマシ', '山川町真弓', 'ヤマカワマチマユミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県みやま市山川町北関', '40', '40229', '8350112', '福岡県', 'フクオカケン', 'みやま市', 'ミヤマシ', '山川町北関', 'ヤマカワマチキタノセキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県みやま市山川町重冨', '40', '40229', '8350113', '福岡県', 'フクオカケン', 'みやま市', 'ミヤマシ', '山川町重冨', 'ヤマカワマチシゲトミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県みやま市山川町甲田', '40', '40229', '8350114', '福岡県', 'フクオカケン', 'みやま市', 'ミヤマシ', '山川町甲田', 'ヤマカワマチコウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県みやま市山川町原町', '40', '40229', '8350115', '福岡県', 'フクオカケン', 'みやま市', 'ミヤマシ', '山川町原町', 'ヤマカワマチハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県みやま市高田町舞鶴', '40', '40229', '8350131', '福岡県', 'フクオカケン', 'みやま市', 'ミヤマシ', '高田町舞鶴', 'タカタマチマイヅル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県みやま市高田町亀谷', '40', '40229', '8350132', '福岡県', 'フクオカケン', 'みやま市', 'ミヤマシ', '高田町亀谷', 'タカタマチカメタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県みやま市高田町田浦', '40', '40229', '8350133', '福岡県', 'フクオカケン', 'みやま市', 'ミヤマシ', '高田町田浦', 'タカタマチタノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県みやま市高田町飯江', '40', '40229', '8350134', '福岡県', 'フクオカケン', 'みやま市', 'ミヤマシ', '高田町飯江', 'タカタマチハエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県みやま市高田町竹飯', '40', '40229', '8350135', '福岡県', 'フクオカケン', 'みやま市', 'ミヤマシ', '高田町竹飯', 'タカタマチタケイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県みやま市高田町海津', '40', '40229', '8350136', '福岡県', 'フクオカケン', 'みやま市', 'ミヤマシ', '高田町海津', 'タカタマチカイヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市', '40', '40202', '8360000', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('106927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市昭和開', '40', '40202', '8360001', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '昭和開', 'ショウワビラキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市岬', '40', '40202', '8360002', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '岬', 'ミサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市唐船', '40', '40202', '8360003', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '唐船', 'トウセン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市手鎌', '40', '40202', '8360004', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '手鎌', 'テガマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市椿黒町', '40', '40202', '8360005', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '椿黒町', 'ツバクロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市大黒町', '40', '40202', '8360006', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '大黒町', 'ダイコクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市城町', '40', '40202', '8360007', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '城町', 'シロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市健老町', '40', '40202', '8360011', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '健老町', 'ケンロウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市明治町', '40', '40202', '8360012', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '明治町', 'メイジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市中町', '40', '40202', '8360013', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '中町', 'ナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市恵比須町', '40', '40202', '8360014', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '恵比須町', 'エビスマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市天神町', '40', '40202', '8360015', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '天神町', 'テンジンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市北磯町', '40', '40202', '8360016', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '北磯町', 'キタイソマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市新開町', '40', '40202', '8360017', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '新開町', 'シンカイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市浜町', '40', '40202', '8360021', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '浜町', 'ハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市港町', '40', '40202', '8360022', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '港町', 'ミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市中島町', '40', '40202', '8360023', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '中島町', 'ナカシママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市住吉町', '40', '40202', '8360024', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '住吉町', 'スミヨシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市中友町', '40', '40202', '8360025', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '中友町', 'ナカトモマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市浜田町', '40', '40202', '8360026', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '浜田町', 'ハマダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市西浜田町', '40', '40202', '8360027', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '西浜田町', 'ニシハマダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市西新町', '40', '40202', '8360031', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '西新町', 'ニシシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市新地町', '40', '40202', '8360032', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '新地町', 'シンチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市松原町', '40', '40202', '8360033', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '松原町', 'マツバラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市小浜町', '40', '40202', '8360034', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '小浜町', 'コハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市千代町', '40', '40202', '8360035', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '千代町', 'チヨマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市小川町', '40', '40202', '8360036', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '小川町', 'オガワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市岬町', '40', '40202', '8360037', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '岬町', 'ミサキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市新栄町', '40', '40202', '8360041', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '新栄町', 'シンサカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市栄町', '40', '40202', '8360042', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市橋口町', '40', '40202', '8360043', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '橋口町', 'ハシグチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市古町', '40', '40202', '8360044', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '古町', 'フルマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市久保田町', '40', '40202', '8360045', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '久保田町', 'クボタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市本町', '40', '40202', '8360046', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市大正町', '40', '40202', '8360047', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '大正町', 'タイショウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市諏訪町', '40', '40202', '8360051', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '諏訪町', 'スワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市白金町', '40', '40202', '8360052', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '白金町', 'シラガネマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市山下町', '40', '40202', '8360053', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '山下町', 'ヤマシタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市天領町', '40', '40202', '8360054', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '天領町', 'テンリョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市樋口町', '40', '40202', '8360055', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '樋口町', 'ヒグチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市姫島町', '40', '40202', '8360056', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '姫島町', 'ヒメシママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市汐屋町', '40', '40202', '8360057', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '汐屋町', 'シオヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市新港町', '40', '40202', '8360061', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '新港町', 'シンコウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市西港町', '40', '40202', '8360062', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '西港町', 'ニシミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市入船町', '40', '40202', '8360063', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '入船町', 'イリフネマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市高砂町', '40', '40202', '8360064', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '高砂町', 'タカサゴマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市三川町', '40', '40202', '8360065', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '三川町', 'ミカワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市浪花町', '40', '40202', '8360066', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '浪花町', 'ナニワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市四山町', '40', '40202', '8360067', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '四山町', 'ヨツヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市加納町', '40', '40202', '8360071', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '加納町', 'カノウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市上屋敷町', '40', '40202', '8360072', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '上屋敷町', 'カミヤシキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市船津町', '40', '40202', '8360073', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '船津町', 'フナツマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市藤田町', '40', '40202', '8360074', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '藤田町', 'フジタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市南船津町', '40', '40202', '8360075', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '南船津町', 'ミナミフナツマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市三里町', '40', '40202', '8360076', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '三里町', 'ミサトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市早米来町', '40', '40202', '8360077', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '早米来町', 'ゾウメキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市田端町', '40', '40202', '8360081', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '田端町', 'タバタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市片平町', '40', '40202', '8360082', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '片平町', 'カタヒラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市長田町', '40', '40202', '8360083', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '長田町', 'ナガタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市馬場町', '40', '40202', '8360084', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '馬場町', 'ババマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市一部町', '40', '40202', '8360085', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '一部町', 'イチブマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市馬込町', '40', '40202', '8360086', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '馬込町', 'マゴメマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市飯田町', '40', '40202', '8360087', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '飯田町', 'イイダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市沖田町', '40', '40202', '8360091', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '沖田町', 'オキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市桜町', '40', '40202', '8360092', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '桜町', 'サクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市神田町', '40', '40202', '8360093', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '神田町', 'カンダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市臼井町', '40', '40202', '8360094', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '臼井町', 'ウスイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市野添町', '40', '40202', '8360095', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '野添町', 'ノゾエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市萩尾町', '40', '40202', '8360096', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '萩尾町', 'ハギオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市東萩尾町', '40', '40202', '8360097', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '東萩尾町', 'ヒガシハギオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市柿園町', '40', '40202', '8360801', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '柿園町', 'カキゾノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市日出町', '40', '40202', '8360802', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '日出町', 'ヒノデマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('106999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市鳥塚町', '40', '40202', '8360803', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '鳥塚町', 'トリツカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市長溝町', '40', '40202', '8360804', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '長溝町', 'ナガミゾマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市通町', '40', '40202', '8360805', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '通町', 'トオリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市東新町', '40', '40202', '8360806', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '東新町', 'ヒガシシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市旭町', '40', '40202', '8360807', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '旭町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市八尻町', '40', '40202', '8360811', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '八尻町', 'ハチジリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市亀甲町', '40', '40202', '8360812', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '亀甲町', 'カメノコマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市平原町', '40', '40202', '8360813', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '平原町', 'ヒラバルマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市龍湖瀬町', '40', '40202', '8360814', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '龍湖瀬町', 'リュウゴゼマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市瓦町', '40', '40202', '8360815', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '瓦町', 'カワラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市八本町', '40', '40202', '8360816', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '八本町', 'ハチホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市浅牟田町', '40', '40202', '8360817', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '浅牟田町', 'アサムタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市東泉町', '40', '40202', '8360821', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '東泉町', 'ヒガシイズミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市稲荷町', '40', '40202', '8360822', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '稲荷町', 'トウカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市亀谷町', '40', '40202', '8360823', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '亀谷町', 'カメタニマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市大浦町', '40', '40202', '8360824', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '大浦町', 'オオウラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市三坑町', '40', '40202', '8360825', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '三坑町', 'サンコウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市焼石町', '40', '40202', '8360826', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '焼石町', 'ヤケイシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市東宮浦町', '40', '40202', '8360827', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '東宮浦町', 'ヒガシミヤウラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市泉町', '40', '40202', '8360831', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '泉町', 'イズミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市常盤町', '40', '40202', '8360832', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '常盤町', 'トキワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市山上町', '40', '40202', '8360833', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '山上町', 'ヤマノウエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市一本町', '40', '40202', '8360834', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '一本町', 'イッポンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市西宮浦町', '40', '40202', '8360835', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '西宮浦町', 'ニシミヤウラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市左古町', '40', '40202', '8360836', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '左古町', 'サコマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市谷町', '40', '40202', '8360837', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '谷町', 'タニマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市築町', '40', '40202', '8360841', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '築町', 'チクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市有明町', '40', '40202', '8360842', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '有明町', 'ユウメイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市不知火町', '40', '40202', '8360843', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '不知火町', 'シラヌヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市浄真町', '40', '40202', '8360844', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '浄真町', 'ジョウシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市正山町', '40', '40202', '8360845', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '正山町', 'ショウザンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市右京町', '40', '40202', '8360846', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '右京町', 'ウキョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市八江町', '40', '40202', '8360847', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '八江町', 'ヤツエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市笹林町', '40', '40202', '8360851', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '笹林町', 'ササバヤシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市曙町', '40', '40202', '8360852', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '曙町', 'アケボノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市上町', '40', '40202', '8360853', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '上町', 'カミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市出雲町', '40', '40202', '8360854', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '出雲町', 'イズモマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市松浦町', '40', '40202', '8360855', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '松浦町', 'マツウラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市宮坂町', '40', '40202', '8360856', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '宮坂町', 'ミヤサカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市宮山町', '40', '40202', '8360857', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '宮山町', 'ミヤヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市宝坂町', '40', '40202', '8360861', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '宝坂町', 'タカラザカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市原山町', '40', '40202', '8360862', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '原山町', 'ハラヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市一浦町', '40', '40202', '8360863', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '一浦町', 'イチノウラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市真道寺町', '40', '40202', '8360864', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '真道寺町', 'シンドウジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市七浦町', '40', '40202', '8360865', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '七浦町', 'ナナウラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市上官町', '40', '40202', '8360866', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '上官町', 'ジョウカンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市花園町', '40', '40202', '8360867', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '花園町', 'ハナゾノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市昭和町', '40', '40202', '8360871', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '昭和町', 'ショウワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市黄金町', '40', '40202', '8360872', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '黄金町', 'コガネマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市駛馬町', '40', '40202', '8360873', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '駛馬町', 'ハヤメマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市末広町', '40', '40202', '8360874', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '末広町', 'スエヒロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市宮原町', '40', '40202', '8360875', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '宮原町', 'ミヤハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市若宮町', '40', '40202', '8360876', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '若宮町', 'ワカミヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市延命寺町', '40', '40202', '8360877', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '延命寺町', 'エンメイジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市米生町', '40', '40202', '8360881', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '米生町', 'ヨネオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市臼井新町', '40', '40202', '8360882', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '臼井新町', 'ウスイシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市馬渡町', '40', '40202', '8360883', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '馬渡町', 'マワタリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市笹原町', '40', '40202', '8360884', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '笹原町', 'ササハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市下池町', '40', '40202', '8360885', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '下池町', 'シモイケマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市勝立', '40', '40202', '8360886', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '勝立', 'カツダチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市合成町', '40', '40202', '8360891', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '合成町', 'ゴウセイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市早鐘町', '40', '40202', '8360892', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '早鐘町', 'ハヤガネマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市櫟野', '40', '40202', '8360893', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '櫟野', 'イチノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市教楽来', '40', '40202', '8360894', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '教楽来', 'キョウラギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市新勝立町', '40', '40202', '8360895', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '新勝立町', 'シンカツダチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市天道町', '40', '40202', '8360896', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '天道町', 'テンドウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市青葉町', '40', '40202', '8360897', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '青葉町', 'アオバマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市四ケ', '40', '40202', '8370901', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '四ケ', 'シカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市上内', '40', '40202', '8370902', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '上内', 'カミウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市宮崎', '40', '40202', '8370903', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '宮崎', 'ミヤザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市吉野', '40', '40202', '8370904', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '吉野', 'ヨシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市甘木', '40', '40202', '8370905', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '甘木', 'アマギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市倉永', '40', '40202', '8370906', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '倉永', 'クラナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市四箇新町', '40', '40202', '8370907', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '四箇新町', 'シカシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市橘', '40', '40202', '8370911', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '橘', 'タチバナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市白銀', '40', '40202', '8370912', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '白銀', 'シラガネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市岩本', '40', '40202', '8370913', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '岩本', 'イワモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市宮部', '40', '40202', '8370914', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '宮部', 'ミヤベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市久福木', '40', '40202', '8370915', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '久福木', 'クブキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市田隈', '40', '40202', '8370916', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '田隈', 'タクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市草木', '40', '40202', '8370917', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '草木', 'クサギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市三池', '40', '40202', '8370921', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '三池', 'ミイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市今山', '40', '40202', '8370922', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '今山', 'イマヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市新町', '40', '40202', '8370923', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市歴木', '40', '40202', '8370924', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '歴木', 'クヌギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市白川', '40', '40202', '8370925', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '白川', 'シラカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市上白川町', '40', '40202', '8370926', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '上白川町', 'カミシラカワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市中白川町', '40', '40202', '8370927', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '中白川町', 'ナカシラカワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県大牟田市下白川町', '40', '40202', '8370928', '福岡県', 'フクオカケン', '大牟田市', 'オオムタシ', '下白川町', 'シモシラカワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉市', '40', '40228', '8380000', '福岡県', 'フクオカケン', '朝倉市', 'アサクラシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('107109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉郡筑前町', '40', '40447', '8380000', '福岡県', 'フクオカケン', '朝倉郡筑前町', 'アサクラグンチクゼンマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('107110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉市秋月', '40', '40228', '8380001', '福岡県', 'フクオカケン', '朝倉市', 'アサクラシ', '秋月', 'アキヅキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉市長谷山', '40', '40228', '8380002', '福岡県', 'フクオカケン', '朝倉市', 'アサクラシ', '長谷山', 'ハセヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉市楢原', '40', '40228', '8380003', '福岡県', 'フクオカケン', '朝倉市', 'アサクラシ', '楢原', 'ナラハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉市隈江', '40', '40228', '8380004', '福岡県', 'フクオカケン', '朝倉市', 'アサクラシ', '隈江', 'クマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉市甘水', '40', '40228', '8380005', '福岡県', 'フクオカケン', '朝倉市', 'アサクラシ', '甘水', 'アモズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉市秋月野鳥', '40', '40228', '8380011', '福岡県', 'フクオカケン', '朝倉市', 'アサクラシ', '秋月野鳥', 'アキヅキノトリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉市江川', '40', '40228', '8380012', '福岡県', 'フクオカケン', '朝倉市', 'アサクラシ', '江川', 'エガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉市田代', '40', '40228', '8380013', '福岡県', 'フクオカケン', '朝倉市', 'アサクラシ', '田代', 'タシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉市山見', '40', '40228', '8380014', '福岡県', 'フクオカケン', '朝倉市', 'アサクラシ', '山見', 'ヤマミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉市持丸', '40', '40228', '8380015', '福岡県', 'フクオカケン', '朝倉市', 'アサクラシ', '持丸', 'モチマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉市下渕', '40', '40228', '8380016', '福岡県', 'フクオカケン', '朝倉市', 'アサクラシ', '下渕', 'シタフチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉市千手', '40', '40228', '8380017', '福岡県', 'フクオカケン', '朝倉市', 'アサクラシ', '千手', 'センズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉市日向石', '40', '40228', '8380018', '福岡県', 'フクオカケン', '朝倉市', 'アサクラシ', '日向石', 'ヒュウガイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉市上秋月', '40', '40228', '8380019', '福岡県', 'フクオカケン', '朝倉市', 'アサクラシ', '上秋月', 'カミアキヅキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉市美奈宜の杜', '40', '40228', '8380020', '福岡県', 'フクオカケン', '朝倉市', 'アサクラシ', '美奈宜の杜', 'ミナギノモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉市矢野竹', '40', '40228', '8380021', '福岡県', 'フクオカケン', '朝倉市', 'アサクラシ', '矢野竹', 'ヤノタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉市城', '40', '40228', '8380022', '福岡県', 'フクオカケン', '朝倉市', 'アサクラシ', '城', 'シロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉市三奈木', '40', '40228', '8380023', '福岡県', 'フクオカケン', '朝倉市', 'アサクラシ', '三奈木', 'ミナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉市牛鶴', '40', '40228', '8380024', '福岡県', 'フクオカケン', '朝倉市', 'アサクラシ', '牛鶴', 'ウシヅル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉市相窪', '40', '40228', '8380025', '福岡県', 'フクオカケン', '朝倉市', 'アサクラシ', '相窪', 'アイノクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉市柿原', '40', '40228', '8380026', '福岡県', 'フクオカケン', '朝倉市', 'アサクラシ', '柿原', 'カキバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉市板屋', '40', '40228', '8380027', '福岡県', 'フクオカケン', '朝倉市', 'アサクラシ', '板屋', 'イタヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉市屋形原', '40', '40228', '8380028', '福岡県', 'フクオカケン', '朝倉市', 'アサクラシ', '屋形原', 'ヤカタバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉市荷原', '40', '40228', '8380029', '福岡県', 'フクオカケン', '朝倉市', 'アサクラシ', '荷原', 'イナイバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉市屋永', '40', '40228', '8380031', '福岡県', 'フクオカケン', '朝倉市', 'アサクラシ', '屋永', 'ヤナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉市中島田', '40', '40228', '8380032', '福岡県', 'フクオカケン', '朝倉市', 'アサクラシ', '中島田', 'ナカシマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉市田島', '40', '40228', '8380033', '福岡県', 'フクオカケン', '朝倉市', 'アサクラシ', '田島', 'タシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉市福光', '40', '40228', '8380034', '福岡県', 'フクオカケン', '朝倉市', 'アサクラシ', '福光', 'フクミツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉市中', '40', '40228', '8380035', '福岡県', 'フクオカケン', '朝倉市', 'アサクラシ', '中', 'ナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉市片延', '40', '40228', '8380036', '福岡県', 'フクオカケン', '朝倉市', 'アサクラシ', '片延', 'カタノブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉市林田', '40', '40228', '8380037', '福岡県', 'フクオカケン', '朝倉市', 'アサクラシ', '林田', 'ハヤシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉市鵜木', '40', '40228', '8380038', '福岡県', 'フクオカケン', '朝倉市', 'アサクラシ', '鵜木', 'ウノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉市桑原', '40', '40228', '8380039', '福岡県', 'フクオカケン', '朝倉市', 'アサクラシ', '桑原', 'クワバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉市鎌崎', '40', '40228', '8380041', '福岡県', 'フクオカケン', '朝倉市', 'アサクラシ', '鎌崎', 'カマサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉市上畑', '40', '40228', '8380042', '福岡県', 'フクオカケン', '朝倉市', 'アサクラシ', '上畑', 'ウエハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉市長田', '40', '40228', '8380043', '福岡県', 'フクオカケン', '朝倉市', 'アサクラシ', '長田', 'ナガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉市八重津', '40', '40228', '8380044', '福岡県', 'フクオカケン', '朝倉市', 'アサクラシ', '八重津', 'ヤエヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉市白鳥', '40', '40228', '8380045', '福岡県', 'フクオカケン', '朝倉市', 'アサクラシ', '白鳥', 'シラトリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉市倉吉', '40', '40228', '8380046', '福岡県', 'フクオカケン', '朝倉市', 'アサクラシ', '倉吉', 'クラヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉市徳渕', '40', '40228', '8380047', '福岡県', 'フクオカケン', '朝倉市', 'アサクラシ', '徳渕', 'トクノフチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉市金丸', '40', '40228', '8380048', '福岡県', 'フクオカケン', '朝倉市', 'アサクラシ', '金丸', 'カナマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉市小田', '40', '40228', '8380051', '福岡県', 'フクオカケン', '朝倉市', 'アサクラシ', '小田', 'オタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉市小隈', '40', '40228', '8380052', '福岡県', 'フクオカケン', '朝倉市', 'アサクラシ', '小隈', 'オグマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉市中寒水', '40', '40228', '8380053', '福岡県', 'フクオカケン', '朝倉市', 'アサクラシ', '中寒水', 'ナカソウズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉市草水', '40', '40228', '8380054', '福岡県', 'フクオカケン', '朝倉市', 'アサクラシ', '草水', 'ソウズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉市下浦', '40', '40228', '8380055', '福岡県', 'フクオカケン', '朝倉市', 'アサクラシ', '下浦', 'シモウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉市中原', '40', '40228', '8380056', '福岡県', 'フクオカケン', '朝倉市', 'アサクラシ', '中原', 'ナカバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉市上浦', '40', '40228', '8380057', '福岡県', 'フクオカケン', '朝倉市', 'アサクラシ', '上浦', 'カミウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉市馬田', '40', '40228', '8380058', '福岡県', 'フクオカケン', '朝倉市', 'アサクラシ', '馬田', 'マダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉市平塚', '40', '40228', '8380059', '福岡県', 'フクオカケン', '朝倉市', 'アサクラシ', '平塚', 'ヒラツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉市菩提寺', '40', '40228', '8380061', '福岡県', 'フクオカケン', '朝倉市', 'アサクラシ', '菩提寺', 'ボダイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉市堤', '40', '40228', '8380062', '福岡県', 'フクオカケン', '朝倉市', 'アサクラシ', '堤', 'ツツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉市古賀', '40', '40228', '8380063', '福岡県', 'フクオカケン', '朝倉市', 'アサクラシ', '古賀', 'コガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉市頓田', '40', '40228', '8380064', '福岡県', 'フクオカケン', '朝倉市', 'アサクラシ', '頓田', 'トンタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉市一木', '40', '40228', '8380065', '福岡県', 'フクオカケン', '朝倉市', 'アサクラシ', '一木', 'ヒトツギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉市千代丸', '40', '40228', '8380066', '福岡県', 'フクオカケン', '朝倉市', 'アサクラシ', '千代丸', 'チヨマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉市牛木', '40', '40228', '8380067', '福岡県', 'フクオカケン', '朝倉市', 'アサクラシ', '牛木', 'ウシギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉市甘木', '40', '40228', '8380068', '福岡県', 'フクオカケン', '朝倉市', 'アサクラシ', '甘木', 'アマギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉市来春', '40', '40228', '8380069', '福岡県', 'フクオカケン', '朝倉市', 'アサクラシ', '来春', 'ライハ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉市佐田', '40', '40228', '8380071', '福岡県', 'フクオカケン', '朝倉市', 'アサクラシ', '佐田', 'サダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉市黒川', '40', '40228', '8380072', '福岡県', 'フクオカケン', '朝倉市', 'アサクラシ', '黒川', 'クロガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県小郡市', '40', '40216', '8380100', '福岡県', 'フクオカケン', '小郡市', 'オゴオリシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('107172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県小郡市美鈴が丘', '40', '40216', '8380101', '福岡県', 'フクオカケン', '小郡市', 'オゴオリシ', '美鈴が丘', 'ミスズガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県小郡市津古', '40', '40216', '8380102', '福岡県', 'フクオカケン', '小郡市', 'オゴオリシ', '津古', 'ツコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県小郡市三国が丘', '40', '40216', '8380103', '福岡県', 'フクオカケン', '小郡市', 'オゴオリシ', '三国が丘', 'ミクニガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県小郡市乙隈', '40', '40216', '8380104', '福岡県', 'フクオカケン', '小郡市', 'オゴオリシ', '乙隈', 'オトグマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県小郡市横隈', '40', '40216', '8380105', '福岡県', 'フクオカケン', '小郡市', 'オゴオリシ', '横隈', 'ヨコグマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県小郡市三沢', '40', '40216', '8380106', '福岡県', 'フクオカケン', '小郡市', 'オゴオリシ', '三沢', 'ミツサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県小郡市希みが丘', '40', '40216', '8380107', '福岡県', 'フクオカケン', '小郡市', 'オゴオリシ', '希みが丘', 'ノゾミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県小郡市美鈴の杜', '40', '40216', '8380108', '福岡県', 'フクオカケン', '小郡市', 'オゴオリシ', '美鈴の杜', 'ミスズノモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県小郡市吹上', '40', '40216', '8380111', '福岡県', 'フクオカケン', '小郡市', 'オゴオリシ', '吹上', 'フキアゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県小郡市干潟', '40', '40216', '8380112', '福岡県', 'フクオカケン', '小郡市', 'オゴオリシ', '干潟', 'ヒカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県小郡市山隈', '40', '40216', '8380113', '福岡県', 'フクオカケン', '小郡市', 'オゴオリシ', '山隈', 'ヤマグマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県小郡市井上', '40', '40216', '8380114', '福岡県', 'フクオカケン', '小郡市', 'オゴオリシ', '井上', 'イノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県小郡市大保', '40', '40216', '8380115', '福岡県', 'フクオカケン', '小郡市', 'オゴオリシ', '大保', 'オオホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県小郡市力武', '40', '40216', '8380116', '福岡県', 'フクオカケン', '小郡市', 'オゴオリシ', '力武', 'リキタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県小郡市上岩田', '40', '40216', '8380121', '福岡県', 'フクオカケン', '小郡市', 'オゴオリシ', '上岩田', 'カミイワタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県小郡市松崎', '40', '40216', '8380122', '福岡県', 'フクオカケン', '小郡市', 'オゴオリシ', '松崎', 'マツザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県小郡市下岩田', '40', '40216', '8380123', '福岡県', 'フクオカケン', '小郡市', 'オゴオリシ', '下岩田', 'シモイワタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県小郡市古飯', '40', '40216', '8380124', '福岡県', 'フクオカケン', '小郡市', 'オゴオリシ', '古飯', 'フルエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県小郡市二タ', '40', '40216', '8380125', '福岡県', 'フクオカケン', '小郡市', 'オゴオリシ', '二タ', 'フタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県小郡市二森', '40', '40216', '8380126', '福岡県', 'フクオカケン', '小郡市', 'オゴオリシ', '二森', 'フタモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県小郡市大崎', '40', '40216', '8380127', '福岡県', 'フクオカケン', '小郡市', 'オゴオリシ', '大崎', 'オオザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県小郡市稲吉', '40', '40216', '8380128', '福岡県', 'フクオカケン', '小郡市', 'オゴオリシ', '稲吉', 'イナヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県小郡市平方', '40', '40216', '8380131', '福岡県', 'フクオカケン', '小郡市', 'オゴオリシ', '平方', 'ヒラカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県小郡市光行', '40', '40216', '8380132', '福岡県', 'フクオカケン', '小郡市', 'オゴオリシ', '光行', 'ミツユキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県小郡市八坂', '40', '40216', '8380133', '福岡県', 'フクオカケン', '小郡市', 'オゴオリシ', '八坂', 'ヤサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県小郡市下西鰺坂', '40', '40216', '8380134', '福岡県', 'フクオカケン', '小郡市', 'オゴオリシ', '下西鰺坂', 'シモニシアジサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県小郡市赤川', '40', '40216', '8380135', '福岡県', 'フクオカケン', '小郡市', 'オゴオリシ', '赤川', 'アカガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県小郡市上西鰺坂', '40', '40216', '8380136', '福岡県', 'フクオカケン', '小郡市', 'オゴオリシ', '上西鰺坂', 'カミニシアジサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県小郡市福童', '40', '40216', '8380137', '福岡県', 'フクオカケン', '小郡市', 'オゴオリシ', '福童', 'フクドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県小郡市寺福童', '40', '40216', '8380138', '福岡県', 'フクオカケン', '小郡市', 'オゴオリシ', '寺福童', 'テラフクドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県小郡市小郡', '40', '40216', '8380141', '福岡県', 'フクオカケン', '小郡市', 'オゴオリシ', '小郡', 'オゴオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県小郡市大板井', '40', '40216', '8380142', '福岡県', 'フクオカケン', '小郡市', 'オゴオリシ', '大板井', 'オオイタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県小郡市小板井', '40', '40216', '8380143', '福岡県', 'フクオカケン', '小郡市', 'オゴオリシ', '小板井', 'コイタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県小郡市祇園', '40', '40216', '8380144', '福岡県', 'フクオカケン', '小郡市', 'オゴオリシ', '祇園', 'ギオン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉郡筑前町櫛木', '40', '40447', '8380201', '福岡県', 'フクオカケン', '朝倉郡筑前町', 'アサクラグンチクゼンマチ', '櫛木', 'クシギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉郡筑前町三箇山', '40', '40447', '8380202', '福岡県', 'フクオカケン', '朝倉郡筑前町', 'アサクラグンチクゼンマチ', '三箇山', 'サンガヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉郡筑前町畑島', '40', '40447', '8380203', '福岡県', 'フクオカケン', '朝倉郡筑前町', 'アサクラグンチクゼンマチ', '畑島', 'ハタジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉郡筑前町長者町', '40', '40447', '8380204', '福岡県', 'フクオカケン', '朝倉郡筑前町', 'アサクラグンチクゼンマチ', '長者町', 'チョウジャマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉郡筑前町三並', '40', '40447', '8380205', '福岡県', 'フクオカケン', '朝倉郡筑前町', 'アサクラグンチクゼンマチ', '三並', 'ミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉郡筑前町曽根田', '40', '40447', '8380206', '福岡県', 'フクオカケン', '朝倉郡筑前町', 'アサクラグンチクゼンマチ', '曽根田', 'ソネダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉郡筑前町三牟田', '40', '40447', '8380207', '福岡県', 'フクオカケン', '朝倉郡筑前町', 'アサクラグンチクゼンマチ', '三牟田', 'ミムタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉郡筑前町下高場', '40', '40447', '8380211', '福岡県', 'フクオカケン', '朝倉郡筑前町', 'アサクラグンチクゼンマチ', '下高場', 'シモタカバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉郡筑前町四三嶋', '40', '40447', '8380212', '福岡県', 'フクオカケン', '朝倉郡筑前町', 'アサクラグンチクゼンマチ', '四三嶋', 'シソジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉郡筑前町安野', '40', '40447', '8380213', '福岡県', 'フクオカケン', '朝倉郡筑前町', 'アサクラグンチクゼンマチ', '安野', 'ヤスノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉郡筑前町東小田', '40', '40447', '8380214', '福岡県', 'フクオカケン', '朝倉郡筑前町', 'アサクラグンチクゼンマチ', '東小田', 'ヒガシオダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉郡筑前町篠隈', '40', '40447', '8380215', '福岡県', 'フクオカケン', '朝倉郡筑前町', 'アサクラグンチクゼンマチ', '篠隈', 'シノクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉郡筑前町吹田', '40', '40447', '8380221', '福岡県', 'フクオカケン', '朝倉郡筑前町', 'アサクラグンチクゼンマチ', '吹田', 'フキダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉郡筑前町赤坂', '40', '40447', '8380222', '福岡県', 'フクオカケン', '朝倉郡筑前町', 'アサクラグンチクゼンマチ', '赤坂', 'アカサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉郡筑前町砥上', '40', '40447', '8380223', '福岡県', 'フクオカケン', '朝倉郡筑前町', 'アサクラグンチクゼンマチ', '砥上', 'トカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉郡筑前町松延', '40', '40447', '8380224', '福岡県', 'フクオカケン', '朝倉郡筑前町', 'アサクラグンチクゼンマチ', '松延', 'マツノブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉郡筑前町石櫃', '40', '40447', '8380225', '福岡県', 'フクオカケン', '朝倉郡筑前町', 'アサクラグンチクゼンマチ', '石櫃', 'イシビツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉郡筑前町中牟田', '40', '40447', '8380226', '福岡県', 'フクオカケン', '朝倉郡筑前町', 'アサクラグンチクゼンマチ', '中牟田', 'ナカムタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉郡筑前町朝日', '40', '40447', '8380227', '福岡県', 'フクオカケン', '朝倉郡筑前町', 'アサクラグンチクゼンマチ', '朝日', 'アサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉郡筑前町二', '40', '40447', '8380228', '福岡県', 'フクオカケン', '朝倉郡筑前町', 'アサクラグンチクゼンマチ', '二', 'フタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉郡筑前町栗田', '40', '40447', '8380801', '福岡県', 'フクオカケン', '朝倉郡筑前町', 'アサクラグンチクゼンマチ', '栗田', 'クリダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉郡筑前町久光', '40', '40447', '8380802', '福岡県', 'フクオカケン', '朝倉郡筑前町', 'アサクラグンチクゼンマチ', '久光', 'ヒサミツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉郡筑前町当所', '40', '40447', '8380803', '福岡県', 'フクオカケン', '朝倉郡筑前町', 'アサクラグンチクゼンマチ', '当所', 'トウショ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉郡筑前町森山', '40', '40447', '8380804', '福岡県', 'フクオカケン', '朝倉郡筑前町', 'アサクラグンチクゼンマチ', '森山', 'モリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉郡筑前町弥永', '40', '40447', '8380811', '福岡県', 'フクオカケン', '朝倉郡筑前町', 'アサクラグンチクゼンマチ', '弥永', 'イヤナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉郡筑前町大塚', '40', '40447', '8380812', '福岡県', 'フクオカケン', '朝倉郡筑前町', 'アサクラグンチクゼンマチ', '大塚', 'オオヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉郡筑前町依井', '40', '40447', '8380813', '福岡県', 'フクオカケン', '朝倉郡筑前町', 'アサクラグンチクゼンマチ', '依井', 'ヨリイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉郡筑前町高田', '40', '40447', '8380814', '福岡県', 'フクオカケン', '朝倉郡筑前町', 'アサクラグンチクゼンマチ', '高田', 'タカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉郡筑前町野町', '40', '40447', '8380815', '福岡県', 'フクオカケン', '朝倉郡筑前町', 'アサクラグンチクゼンマチ', '野町', 'ノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉郡筑前町新町', '40', '40447', '8380816', '福岡県', 'フクオカケン', '朝倉郡筑前町', 'アサクラグンチクゼンマチ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉郡筑前町朝園', '40', '40447', '8380817', '福岡県', 'フクオカケン', '朝倉郡筑前町', 'アサクラグンチクゼンマチ', '朝園', 'アサゾノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉郡筑前町上高場', '40', '40447', '8380821', '福岡県', 'フクオカケン', '朝倉郡筑前町', 'アサクラグンチクゼンマチ', '上高場', 'カミタカバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉郡筑前町高上', '40', '40447', '8380822', '福岡県', 'フクオカケン', '朝倉郡筑前町', 'アサクラグンチクゼンマチ', '高上', 'タコエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉郡筑前町山隈', '40', '40447', '8380823', '福岡県', 'フクオカケン', '朝倉郡筑前町', 'アサクラグンチクゼンマチ', '山隈', 'ヤマグマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉郡筑前町原地蔵', '40', '40447', '8380824', '福岡県', 'フクオカケン', '朝倉郡筑前町', 'アサクラグンチクゼンマチ', '原地蔵', 'ハラジゾウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉郡筑前町大久保', '40', '40447', '8380825', '福岡県', 'フクオカケン', '朝倉郡筑前町', 'アサクラグンチクゼンマチ', '大久保', 'オオクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉市烏集院', '40', '40228', '8381301', '福岡県', 'フクオカケン', '朝倉市', 'アサクラシ', '烏集院', 'ウスノイン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉市宮野', '40', '40228', '8381302', '福岡県', 'フクオカケン', '朝倉市', 'アサクラシ', '宮野', 'ミヤノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉市比良松', '40', '40228', '8381303', '福岡県', 'フクオカケン', '朝倉市', 'アサクラシ', '比良松', 'ヒラマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉市須川', '40', '40228', '8381304', '福岡県', 'フクオカケン', '朝倉市', 'アサクラシ', '須川', 'スガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉市菱野', '40', '40228', '8381305', '福岡県', 'フクオカケン', '朝倉市', 'アサクラシ', '菱野', 'ヒシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉市山田', '40', '40228', '8381306', '福岡県', 'フクオカケン', '朝倉市', 'アサクラシ', '山田', 'ヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉市古毛', '40', '40228', '8381307', '福岡県', 'フクオカケン', '朝倉市', 'アサクラシ', '古毛', 'コモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉市多々連', '40', '40228', '8381311', '福岡県', 'フクオカケン', '朝倉市', 'アサクラシ', '多々連', 'タダレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉市田中', '40', '40228', '8381312', '福岡県', 'フクオカケン', '朝倉市', 'アサクラシ', '田中', 'タナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉市上寺', '40', '40228', '8381313', '福岡県', 'フクオカケン', '朝倉市', 'アサクラシ', '上寺', 'カミデラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉市長渕', '40', '40228', '8381314', '福岡県', 'フクオカケン', '朝倉市', 'アサクラシ', '長渕', 'ナガフチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉市入地', '40', '40228', '8381315', '福岡県', 'フクオカケン', '朝倉市', 'アサクラシ', '入地', 'イリジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉市大庭', '40', '40228', '8381316', '福岡県', 'フクオカケン', '朝倉市', 'アサクラシ', '大庭', 'オオバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉市石成', '40', '40228', '8381317', '福岡県', 'フクオカケン', '朝倉市', 'アサクラシ', '石成', 'イシナリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉市杷木赤谷', '40', '40228', '8381501', '福岡県', 'フクオカケン', '朝倉市', 'アサクラシ', '杷木赤谷', 'ハキアカダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉市杷木松末', '40', '40228', '8381502', '福岡県', 'フクオカケン', '朝倉市', 'アサクラシ', '杷木松末', 'ハキマスエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉市杷木大山', '40', '40228', '8381503', '福岡県', 'フクオカケン', '朝倉市', 'アサクラシ', '杷木大山', 'ハキオオヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉市杷木星丸', '40', '40228', '8381504', '福岡県', 'フクオカケン', '朝倉市', 'アサクラシ', '杷木星丸', 'ハキホシマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉市杷木穂坂', '40', '40228', '8381505', '福岡県', 'フクオカケン', '朝倉市', 'アサクラシ', '杷木穂坂', 'ハキホサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉市杷木林田', '40', '40228', '8381506', '福岡県', 'フクオカケン', '朝倉市', 'アサクラシ', '杷木林田', 'ハキハヤシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉市杷木白木', '40', '40228', '8381507', '福岡県', 'フクオカケン', '朝倉市', 'アサクラシ', '杷木白木', 'ハキシラキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉市杷木池田', '40', '40228', '8381511', '福岡県', 'フクオカケン', '朝倉市', 'アサクラシ', '杷木池田', 'ハキイケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉市杷木寒水', '40', '40228', '8381512', '福岡県', 'フクオカケン', '朝倉市', 'アサクラシ', '杷木寒水', 'ハキソウズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉市杷木古賀', '40', '40228', '8381513', '福岡県', 'フクオカケン', '朝倉市', 'アサクラシ', '杷木古賀', 'ハキコガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉市杷木久喜宮', '40', '40228', '8381514', '福岡県', 'フクオカケン', '朝倉市', 'アサクラシ', '杷木久喜宮', 'ハキクグミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉市杷木若市', '40', '40228', '8381515', '福岡県', 'フクオカケン', '朝倉市', 'アサクラシ', '杷木若市', 'ハキワカイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉市杷木志波', '40', '40228', '8381521', '福岡県', 'フクオカケン', '朝倉市', 'アサクラシ', '杷木志波', 'ハキシワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉郡東峰村小石原', '40', '40448', '8381601', '福岡県', 'フクオカケン', '朝倉郡東峰村', 'アサクラグントウホウムラ', '小石原', 'コイシワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉郡東峰村小石原鼓', '40', '40448', '8381602', '福岡県', 'フクオカケン', '朝倉郡東峰村', 'アサクラグントウホウムラ', '小石原鼓', 'コイシワラツヅミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉郡東峰村', '40', '40448', '8381700', '福岡県', 'フクオカケン', '朝倉郡東峰村', 'アサクラグントウホウムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('107280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉郡東峰村宝珠山', '40', '40448', '8381701', '福岡県', 'フクオカケン', '朝倉郡東峰村', 'アサクラグントウホウムラ', '宝珠山', 'ホウシュヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県朝倉郡東峰村福井', '40', '40448', '8381702', '福岡県', 'フクオカケン', '朝倉郡東峰村', 'アサクラグントウホウムラ', '福井', 'フクイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市', '40', '40203', '8390000', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('107295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県みやま市高田町昭和開', '40', '40229', '8390201', '福岡県', 'フクオカケン', 'みやま市', 'ミヤマシ', '高田町昭和開', 'タカタマチショウワビラキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県みやま市高田町永治', '40', '40229', '8390202', '福岡県', 'フクオカケン', 'みやま市', 'ミヤマシ', '高田町永治', 'タカタマチエイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県みやま市高田町黒崎開', '40', '40229', '8390203', '福岡県', 'フクオカケン', 'みやま市', 'ミヤマシ', '高田町黒崎開', 'タカタマチクロサキビラキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県みやま市高田町北新開', '40', '40229', '8390204', '福岡県', 'フクオカケン', 'みやま市', 'ミヤマシ', '高田町北新開', 'タカタマチキタシンガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県みやま市高田町南新開', '40', '40229', '8390205', '福岡県', 'フクオカケン', 'みやま市', 'ミヤマシ', '高田町南新開', 'タカタマチミナミシンガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県みやま市高田町徳島', '40', '40229', '8390211', '福岡県', 'フクオカケン', 'みやま市', 'ミヤマシ', '高田町徳島', 'タカタマチトクシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県みやま市高田町江浦町', '40', '40229', '8390212', '福岡県', 'フクオカケン', 'みやま市', 'ミヤマシ', '高田町江浦町', 'タカタマチエノウラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県みやま市高田町江浦', '40', '40229', '8390213', '福岡県', 'フクオカケン', 'みやま市', 'ミヤマシ', '高田町江浦', 'タカタマチエノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県みやま市高田町今福', '40', '40229', '8390214', '福岡県', 'フクオカケン', 'みやま市', 'ミヤマシ', '高田町今福', 'タカタマチイマブク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県みやま市高田町濃施', '40', '40229', '8390215', '福岡県', 'フクオカケン', 'みやま市', 'ミヤマシ', '高田町濃施', 'タカタマチノセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県みやま市高田町下楠田', '40', '40229', '8390221', '福岡県', 'フクオカケン', 'みやま市', 'ミヤマシ', '高田町下楠田', 'タカタマチシモクスダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県みやま市高田町原', '40', '40229', '8390222', '福岡県', 'フクオカケン', 'みやま市', 'ミヤマシ', '高田町原', 'タカタマチハル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県みやま市高田町岩津', '40', '40229', '8390223', '福岡県', 'フクオカケン', 'みやま市', 'ミヤマシ', '高田町岩津', 'タカタマチイワツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県みやま市高田町田尻', '40', '40229', '8390224', '福岡県', 'フクオカケン', 'みやま市', 'ミヤマシ', '高田町田尻', 'タカタマチタジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県みやま市高田町上楠田', '40', '40229', '8390225', '福岡県', 'フクオカケン', 'みやま市', 'ミヤマシ', '高田町上楠田', 'タカタマチカミクスダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市大和町徳益', '40', '40207', '8390241', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '大和町徳益', 'ヤマトマチトクマス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市大和町豊原', '40', '40207', '8390242', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '大和町豊原', 'ヤマトマチトヨハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市大和町塩塚', '40', '40207', '8390243', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '大和町塩塚', 'ヤマトマチシオツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市大和町六合', '40', '40207', '8390244', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '大和町六合', 'ヤマトマチロクゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市大和町明野', '40', '40207', '8390251', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '大和町明野', 'ヤマトマチアケノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市大和町栄', '40', '40207', '8390252', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '大和町栄', 'ヤマトマチサカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市大和町鷹ノ尾', '40', '40207', '8390253', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '大和町鷹ノ尾', 'ヤマトマチタカノオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市大和町中島', '40', '40207', '8390254', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '大和町中島', 'ヤマトマチナカシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市大和町皿垣開', '40', '40207', '8390261', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '大和町皿垣開', 'ヤマトマチサラカキビラキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市大和町永田開', '40', '40207', '8390262', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '大和町永田開', 'ヤマトマチナガタビラキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市大和町大坪', '40', '40207', '8390263', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '大和町大坪', 'ヤマトマチオオツボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県柳川市大和町谷垣', '40', '40207', '8390264', '福岡県', 'フクオカケン', '柳川市', 'ヤナガワシ', '大和町谷垣', 'ヤマトマチタニガキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市宮ノ陣', '40', '40203', '8390801', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '宮ノ陣', 'ミヤノジン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市宮ノ陣町五郎丸', '40', '40203', '8390802', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '宮ノ陣町五郎丸', 'ミヤノジンマチゴロウマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市宮ノ陣町大杜', '40', '40203', '8390803', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '宮ノ陣町大杜', 'ミヤノジンマチオオト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市宮ノ陣町若松', '40', '40203', '8390804', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '宮ノ陣町若松', 'ミヤノジンマチワカマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市宮ノ陣町八丁島', '40', '40203', '8390805', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '宮ノ陣町八丁島', 'ミヤノジンマチハッチョウジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市東合川干出町', '40', '40203', '8390806', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '東合川干出町', 'ヒガシアイカワヒイデマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市東合川町', '40', '40203', '8390807', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '東合川町', 'ヒガシアイカワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市東合川新町', '40', '40203', '8390808', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '東合川新町', 'ヒガシアイカワシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市東合川', '40', '40203', '8390809', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '東合川', 'ヒガシアイカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市山川神代', '40', '40203', '8390811', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '山川神代', 'ヤマカワクマシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市山川安居野', '40', '40203', '8390812', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '山川安居野', 'ヤマカワアイノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市山川市ノ上町', '40', '40203', '8390813', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '山川市ノ上町', 'ヤマカワイチノウエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市山川追分', '40', '40203', '8390814', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '山川追分', 'ヤマカワオイワケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市山川沓形町', '40', '40203', '8390815', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '山川沓形町', 'ヤマカワクツガタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市山川野口町', '40', '40203', '8390816', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '山川野口町', 'ヤマカワノグチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市山川町', '40', '40203', '8390817', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '山川町', 'ヤマカワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市太郎原町', '40', '40203', '8390821', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '太郎原町', 'ダイロバルマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市善導寺町木塚', '40', '40203', '8390822', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '善導寺町木塚', 'ゼンドウジマチキヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市善導寺町与田', '40', '40203', '8390823', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '善導寺町与田', 'ゼンドウジマチヨダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市善導寺町飯田', '40', '40203', '8390824', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '善導寺町飯田', 'ゼンドウジマチイイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市善導寺町島', '40', '40203', '8390825', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '善導寺町島', 'ゼンドウジマチシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市山本町耳納', '40', '40203', '8390826', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '山本町耳納', 'ヤマモトマチミノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市山本町豊田', '40', '40203', '8390827', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '山本町豊田', 'ヤマモトマチトヨダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市大橋町蜷川', '40', '40203', '8390831', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '大橋町蜷川', 'オオハシマチニナガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市大橋町合楽', '40', '40203', '8390832', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '大橋町合楽', 'オオハシマチアイラク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市大橋町常持', '40', '40203', '8390833', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '大橋町常持', 'オオハシマチツネモチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市草野町紅桃林', '40', '40203', '8390834', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '草野町紅桃林', 'クサノマチコトバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市草野町草野', '40', '40203', '8390835', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '草野町草野', 'クサノマチクサノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市草野町吉木', '40', '40203', '8390836', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '草野町吉木', 'クサノマチヨシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市草野町矢作', '40', '40203', '8390837', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '草野町矢作', 'クサノマチヤハギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市御井旗崎', '40', '40203', '8390841', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '御井旗崎', 'ミイハタザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市御井朝妻', '40', '40203', '8390842', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '御井朝妻', 'ミイアサヅマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市朝妻町', '40', '40203', '8390843', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '朝妻町', 'アサヅママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市御井町', '40', '40203', '8390851', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '御井町', 'ミイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市高良内町', '40', '40203', '8390852', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '高良内町', 'コウラウチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市青峰', '40', '40203', '8390853', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '青峰', 'セイホウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市合川町', '40', '40203', '8390861', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '合川町', 'アイカワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市野中町', '40', '40203', '8390862', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '野中町', 'ノナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市国分町', '40', '40203', '8390863', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '国分町', 'コクブマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市百年公園', '40', '40203', '8390864', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '百年公園', 'ヒャクネンコウエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市新合川', '40', '40203', '8390865', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '新合川', 'シンアイカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市田主丸町長栖', '40', '40203', '8391201', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '田主丸町長栖', 'タヌシマルマチナガス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市田主丸町鷹取', '40', '40203', '8391202', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '田主丸町鷹取', 'タヌシマルマチタカトリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市田主丸町秋成', '40', '40203', '8391203', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '田主丸町秋成', 'タヌシマルマチアキナリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市田主丸町殖木', '40', '40203', '8391204', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '田主丸町殖木', 'タヌシマルマチフエキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市田主丸町船越', '40', '40203', '8391205', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '田主丸町船越', 'タヌシマルマチフナゴシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市田主丸町吉本', '40', '40203', '8391206', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '田主丸町吉本', 'タヌシマルマチヨシモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市田主丸町森部', '40', '40203', '8391211', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '田主丸町森部', 'タヌシマルマチモリベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市田主丸町石垣', '40', '40203', '8391212', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '田主丸町石垣', 'タヌシマルマチイシカキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市田主丸町益生田', '40', '40203', '8391213', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '田主丸町益生田', 'タヌシマルマチマスオダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市田主丸町地徳', '40', '40203', '8391214', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '田主丸町地徳', 'タヌシマルマチチトク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市田主丸町竹野', '40', '40203', '8391215', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '田主丸町竹野', 'タヌシマルマチタケノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市田主丸町中尾', '40', '40203', '8391216', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '田主丸町中尾', 'タヌシマルマチナカオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市田主丸町上原', '40', '40203', '8391221', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '田主丸町上原', 'タヌシマルマチカミハル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市田主丸町志塚島', '40', '40203', '8391222', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '田主丸町志塚島', 'タヌシマルマチシツカシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市田主丸町以真恵', '40', '40203', '8391223', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '田主丸町以真恵', 'タヌシマルマチイマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市田主丸町牧', '40', '40203', '8391224', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '田主丸町牧', 'タヌシマルマチマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市田主丸町菅原', '40', '40203', '8391225', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '田主丸町菅原', 'タヌシマルマチスガハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市田主丸町八幡', '40', '40203', '8391226', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '田主丸町八幡', 'タヌシマルマチヤハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市田主丸町朝森', '40', '40203', '8391227', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '田主丸町朝森', 'タヌシマルマチアサモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市田主丸町恵利', '40', '40203', '8391228', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '田主丸町恵利', 'タヌシマルマチエリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市田主丸町野田', '40', '40203', '8391231', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '田主丸町野田', 'タヌシマルマチノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市田主丸町常盤', '40', '40203', '8391232', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '田主丸町常盤', 'タヌシマルマチトキワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市田主丸町田主丸', '40', '40203', '8391233', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '田主丸町田主丸', 'タヌシマルマチタヌシマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県久留米市田主丸町豊城', '40', '40203', '8391234', '福岡県', 'フクオカケン', '久留米市', 'クルメシ', '田主丸町豊城', 'タヌシマルマチトヨキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県うきは市吉井町桜井', '40', '40225', '8391301', '福岡県', 'フクオカケン', 'うきは市', 'ウキハシ', '吉井町桜井', 'ヨシイマチサクライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県うきは市吉井町徳丸', '40', '40225', '8391302', '福岡県', 'フクオカケン', 'うきは市', 'ウキハシ', '吉井町徳丸', 'ヨシイマチトクマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県うきは市吉井町宮田', '40', '40225', '8391303', '福岡県', 'フクオカケン', 'うきは市', 'ウキハシ', '吉井町宮田', 'ヨシイマチミヤダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県うきは市吉井町千年', '40', '40225', '8391304', '福岡県', 'フクオカケン', 'うきは市', 'ウキハシ', '吉井町千年', 'ヨシイマチチトセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県うきは市吉井町福永', '40', '40225', '8391305', '福岡県', 'フクオカケン', 'うきは市', 'ウキハシ', '吉井町福永', 'ヨシイマチフクナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県うきは市吉井町新治', '40', '40225', '8391306', '福岡県', 'フクオカケン', 'うきは市', 'ウキハシ', '吉井町新治', 'ヨシイマチニイハル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県うきは市吉井町橘田', '40', '40225', '8391307', '福岡県', 'フクオカケン', 'うきは市', 'ウキハシ', '吉井町橘田', 'ヨシイマチタチバナダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県うきは市吉井町八和田', '40', '40225', '8391308', '福岡県', 'フクオカケン', 'うきは市', 'ウキハシ', '吉井町八和田', 'ヨシイマチヤワタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県うきは市吉井町若宮', '40', '40225', '8391311', '福岡県', 'フクオカケン', 'うきは市', 'ウキハシ', '吉井町若宮', 'ヨシイマチワカミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県うきは市吉井町清瀬', '40', '40225', '8391312', '福岡県', 'フクオカケン', 'うきは市', 'ウキハシ', '吉井町清瀬', 'ヨシイマチキヨセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県うきは市吉井町', '40', '40225', '8391321', '福岡県', 'フクオカケン', 'うきは市', 'ウキハシ', '吉井町', 'ヨシイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県うきは市吉井町屋部', '40', '40225', '8391331', '福岡県', 'フクオカケン', 'うきは市', 'ウキハシ', '吉井町屋部', 'ヨシイマチヤベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県うきは市吉井町福益', '40', '40225', '8391332', '福岡県', 'フクオカケン', 'うきは市', 'ウキハシ', '吉井町福益', 'ヨシイマチフクマス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県うきは市吉井町富永', '40', '40225', '8391333', '福岡県', 'フクオカケン', 'うきは市', 'ウキハシ', '吉井町富永', 'ヨシイマチトミナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県うきは市吉井町江南', '40', '40225', '8391341', '福岡県', 'フクオカケン', 'うきは市', 'ウキハシ', '吉井町江南', 'ヨシイマチエナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県うきは市吉井町生葉', '40', '40225', '8391342', '福岡県', 'フクオカケン', 'うきは市', 'ウキハシ', '吉井町生葉', 'ヨシイマチイクハ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県うきは市吉井町鷹取', '40', '40225', '8391343', '福岡県', 'フクオカケン', 'うきは市', 'ウキハシ', '吉井町鷹取', 'ヨシイマチタカトリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県うきは市吉井町長栖', '40', '40225', '8391344', '福岡県', 'フクオカケン', 'うきは市', 'ウキハシ', '吉井町長栖', 'ヨシイマチナガス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県うきは市', '40', '40225', '8391400', '福岡県', 'フクオカケン', 'うきは市', 'ウキハシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('107414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県うきは市浮羽町朝田', '40', '40225', '8391401', '福岡県', 'フクオカケン', 'うきは市', 'ウキハシ', '浮羽町朝田', 'ウキハマチアサダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県うきは市浮羽町浮羽', '40', '40225', '8391402', '福岡県', 'フクオカケン', 'うきは市', 'ウキハシ', '浮羽町浮羽', 'ウキハマチウキハ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県うきは市浮羽町東隈上', '40', '40225', '8391403', '福岡県', 'フクオカケン', 'うきは市', 'ウキハシ', '浮羽町東隈上', 'ウキハマチヒガシクマノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県うきは市浮羽町西隈上', '40', '40225', '8391404', '福岡県', 'フクオカケン', 'うきは市', 'ウキハシ', '浮羽町西隈上', 'ウキハマチニシクマノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県うきは市浮羽町古川', '40', '40225', '8391405', '福岡県', 'フクオカケン', 'うきは市', 'ウキハシ', '浮羽町古川', 'ウキハマチフルカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県うきは市浮羽町高見', '40', '40225', '8391406', '福岡県', 'フクオカケン', 'うきは市', 'ウキハシ', '浮羽町高見', 'ウキハマチタカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県うきは市浮羽町三春', '40', '40225', '8391407', '福岡県', 'フクオカケン', 'うきは市', 'ウキハシ', '浮羽町三春', 'ウキハマチミハル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県うきは市浮羽町山北', '40', '40225', '8391408', '福岡県', 'フクオカケン', 'うきは市', 'ウキハシ', '浮羽町山北', 'ウキハマチヤマキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県うきは市浮羽町流川', '40', '40225', '8391411', '福岡県', 'フクオカケン', 'うきは市', 'ウキハシ', '浮羽町流川', 'ウキハマチナガレカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県うきは市浮羽町小塩', '40', '40225', '8391412', '福岡県', 'フクオカケン', 'うきは市', 'ウキハシ', '浮羽町小塩', 'ウキハマチコジオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県うきは市浮羽町新川', '40', '40225', '8391413', '福岡県', 'フクオカケン', 'うきは市', 'ウキハシ', '浮羽町新川', 'ウキハマチニイカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県うきは市浮羽町田篭', '40', '40225', '8391414', '福岡県', 'フクオカケン', 'うきは市', 'ウキハシ', '浮羽町田篭', 'ウキハマチタゴモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県うきは市浮羽町妹川', '40', '40225', '8391415', '福岡県', 'フクオカケン', 'うきは市', 'ウキハシ', '浮羽町妹川', 'ウキハマチイモガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市前津江町柚木', '44', '44204', '8391421', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '前津江町柚木', 'マエツエマチユウギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市前津江町柚木千歳木', '44', '44204', '8391421', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '前津江町柚木', 'マエツエマチユウギ', null, null, '千歳木', 'チトセギ');
INSERT INTO `ms_addresses` VALUES ('107429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市前津江町柚木塔ノ本', '44', '44204', '8391421', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '前津江町柚木', 'マエツエマチユウギ', null, null, '塔ノ本', 'トウノモト');
INSERT INTO `ms_addresses` VALUES ('107430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市前津江町柚木仁田原', '44', '44204', '8391421', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '前津江町柚木', 'マエツエマチユウギ', null, null, '仁田原', 'ニタバル');
INSERT INTO `ms_addresses` VALUES ('107431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市前津江町柚木本村', '44', '44204', '8391421', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '前津江町柚木', 'マエツエマチユウギ', null, null, '本村', 'ホンムラ');
INSERT INTO `ms_addresses` VALUES ('107440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市巨勢町修理田', '41', '41201', '8400001', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '巨勢町修理田', 'コセマチシュリタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市蓮池町見島', '41', '41201', '8400002', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '蓮池町見島', 'ハスイケマチミシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市蓮池町古賀', '41', '41201', '8400003', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '蓮池町古賀', 'ハスイケマチコガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市蓮池町小松', '41', '41201', '8400004', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '蓮池町小松', 'ハスイケマチコマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市蓮池町蓮池', '41', '41201', '8400005', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '蓮池町蓮池', 'ハスイケマチハスイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市巨勢町東西', '41', '41201', '8400006', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '巨勢町東西', 'コセマチトウザイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市巨勢町高尾', '41', '41201', '8400007', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '巨勢町高尾', 'コセマチタカオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市巨勢町牛島', '41', '41201', '8400008', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '巨勢町牛島', 'コセマチウシジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市北川副町江上', '41', '41201', '8400011', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '北川副町江上', 'キタカワソエマチエガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市北川副町光法', '41', '41201', '8400012', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '北川副町光法', 'キタカワソエマチミツノリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市北川副町新郷', '41', '41201', '8400013', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '北川副町新郷', 'キタカワソエマチシンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市木原', '41', '41201', '8400015', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '木原', 'キハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市南佐賀', '41', '41201', '8400016', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '南佐賀', 'ミナミサガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市新郷本町', '41', '41201', '8400017', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '新郷本町', 'シンゴウホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市鬼丸町', '41', '41201', '8400021', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '鬼丸町', 'オニマルチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市中の館町', '41', '41201', '8400022', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '中の館町', 'ナカノタテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市本庄町袋', '41', '41201', '8400023', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '本庄町袋', 'ホンジョウマチフクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市本庄町末次', '41', '41201', '8400024', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '本庄町末次', 'ホンジョウマチスエツグ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市本庄町鹿子', '41', '41201', '8400025', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '本庄町鹿子', 'ホンジョウマチカノコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市本庄町正里', '41', '41201', '8400026', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '本庄町正里', 'ホンジョウマチショウリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市本庄町本庄', '41', '41201', '8400027', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '本庄町本庄', 'ホンジョウマチホンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市下田町', '41', '41201', '8400031', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '下田町', 'シモダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市末広', '41', '41201', '8400032', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '末広', 'スエヒロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市光', '41', '41201', '8400033', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '光', 'ヒカリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市西与賀町厘外', '41', '41201', '8400034', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '西与賀町厘外', 'ニシヨカマチリンゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市西与賀町今津', '41', '41201', '8400035', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '西与賀町今津', 'ニシヨカマチイマヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市西与賀町高太郎', '41', '41201', '8400036', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '西与賀町高太郎', 'ニシヨカマチタカタロウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市西与賀町相応津', '41', '41201', '8400037', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '西与賀町相応津', 'ニシヨカマチソウオウツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市城内', '41', '41201', '8400041', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '城内', 'ジョウナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市赤松町', '41', '41201', '8400042', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '赤松町', 'アカマツマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市精町', '41', '41201', '8400043', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '精町', 'シラゲマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市道祖元町', '41', '41201', '8400044', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '道祖元町', 'サヤノモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市西田代', '41', '41201', '8400045', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '西田代', 'ニシタシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市西魚町', '41', '41201', '8400046', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '西魚町', 'ニシウオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市与賀町', '41', '41201', '8400047', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '与賀町', 'ヨカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市田代', '41', '41201', '8400051', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '田代', 'タシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市今宿町', '41', '41201', '8400052', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '今宿町', 'イマシュクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市朝日町', '41', '41201', '8400053', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '朝日町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市水ケ江', '41', '41201', '8400054', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '水ケ江', 'ミズガエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市材木', '41', '41201', '8400055', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '材木', 'ザイモク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市紺屋町', '41', '41201', '8400056', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '紺屋町', 'コンヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市大和町尼寺', '41', '41201', '8400201', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '大和町尼寺', 'ヤマトチョウニイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市大和町久池井', '41', '41201', '8400202', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '大和町久池井', 'ヤマトチョウクチイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市大和町梅野', '41', '41201', '8400203', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '大和町梅野', 'ヤマトチョウウメノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市大和町松瀬', '41', '41201', '8400204', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '大和町松瀬', 'ヤマトチョウマツセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市大和町名尾', '41', '41201', '8400205', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '大和町名尾', 'ヤマトチョウナオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市大和町東山田', '41', '41201', '8400211', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '大和町東山田', 'ヤマトチョウヒガシヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市大和町池上', '41', '41201', '8400212', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '大和町池上', 'ヤマトチョウイケノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市大和町久留間', '41', '41201', '8400213', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '大和町久留間', 'ヤマトチョウクルマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市大和町川上', '41', '41201', '8400214', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '大和町川上', 'ヤマトチョウカワカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市大和町八反原', '41', '41201', '8400215', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '大和町八反原', 'ヤマトチョウハッタバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市富士町古湯', '41', '41201', '8400501', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '富士町古湯', 'フジチョウフルユ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市富士町杉山', '41', '41201', '8400502', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '富士町杉山', 'フジチョウスギヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市富士町市川', '41', '41201', '8400503', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '富士町市川', 'フジチョウイチカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市富士町苣木', '41', '41201', '8400504', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '富士町苣木', 'フジチョウチャノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市富士町鎌原', '41', '41201', '8400511', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '富士町鎌原', 'フジチョウカマバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市富士町上熊川', '41', '41201', '8400512', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '富士町上熊川', 'フジチョウカミクマカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市富士町下熊川', '41', '41201', '8400513', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '富士町下熊川', 'フジチョウシモクマカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市富士町内野', '41', '41201', '8400514', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '富士町内野', 'フジチョウウチノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市富士町松瀬', '41', '41201', '8400515', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '富士町松瀬', 'フジチョウマツセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市富士町梅野', '41', '41201', '8400516', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '富士町梅野', 'フジチョウウメノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市富士町小副川', '41', '41201', '8400521', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '富士町小副川', 'フジチョウオソエガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市富士町畑瀬', '41', '41201', '8400522', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '富士町畑瀬', 'フジチョウハタセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市富士町栗並', '41', '41201', '8400531', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '富士町栗並', 'フジチョウクリナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市富士町大野', '41', '41201', '8400532', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '富士町大野', 'フジチョウオオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市富士町大串', '41', '41201', '8400533', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '富士町大串', 'フジチョウオオクシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市富士町中原', '41', '41201', '8400534', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '富士町中原', 'フジチョウナカバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市富士町下無津呂', '41', '41201', '8400535', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '富士町下無津呂', 'フジチョウシモムツロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市富士町上無津呂', '41', '41201', '8400536', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '富士町上無津呂', 'フジチョウカミムツロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市富士町麻那古', '41', '41201', '8400537', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '富士町麻那古', 'フジチョウマナゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市富士町関屋', '41', '41201', '8400541', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '富士町関屋', 'フジチョウセキヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市富士町藤瀬', '41', '41201', '8400542', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '富士町藤瀬', 'フジチョウフジセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市富士町古場', '41', '41201', '8400543', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '富士町古場', 'フジチョウコバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市富士町下合瀬', '41', '41201', '8400544', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '富士町下合瀬', 'フジチョウシモオオセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市富士町上合瀬', '41', '41201', '8400545', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '富士町上合瀬', 'フジチョウカミオオセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市駅前中央', '41', '41201', '8400801', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '駅前中央', 'エキマエチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市大財北町', '41', '41201', '8400802', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '大財北町', 'オオタカラキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市栄町', '41', '41201', '8400803', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市神野東', '41', '41201', '8400804', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '神野東', 'コウノヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市神野西', '41', '41201', '8400805', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '神野西', 'コウノニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市神園', '41', '41201', '8400806', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '神園', 'カミゾノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市大財', '41', '41201', '8400811', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '大財', 'オオタカラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市愛敬町', '41', '41201', '8400812', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '愛敬町', 'アイケイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市唐人', '41', '41201', '8400813', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '唐人', 'トウジン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市成章町', '41', '41201', '8400814', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '成章町', 'セイショウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市天神', '41', '41201', '8400815', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '天神', 'テンジン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市駅南本町', '41', '41201', '8400816', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '駅南本町', 'エキミナミホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市東佐賀町', '41', '41201', '8400821', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '東佐賀町', 'ヒガシサガマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市高木町', '41', '41201', '8400822', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '高木町', 'タカギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市柳町', '41', '41201', '8400823', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '柳町', 'ヤナギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市呉服元町', '41', '41201', '8400824', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '呉服元町', 'ゴフクモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市中央本町', '41', '41201', '8400825', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '中央本町', 'チュウオウホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市白山', '41', '41201', '8400826', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '白山', 'シラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市松原', '41', '41201', '8400831', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '松原', 'マツバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市堀川町', '41', '41201', '8400832', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '堀川町', 'ホリカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市中の小路', '41', '41201', '8400833', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '中の小路', 'ナカノコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市八幡小路', '41', '41201', '8400834', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '八幡小路', 'ハチマンコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市緑小路', '41', '41201', '8400841', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '緑小路', 'ミドリコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市多布施', '41', '41201', '8400842', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '多布施', 'タフセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市川原町', '41', '41201', '8400843', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '川原町', 'カワハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市伊勢町', '41', '41201', '8400844', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '伊勢町', 'イセマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市六座町', '41', '41201', '8400845', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '六座町', 'ロクザマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市新栄東', '41', '41201', '8400850', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '新栄東', 'シンエイヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市天祐', '41', '41201', '8400851', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '天祐', 'テンユウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市中折町', '41', '41201', '8400852', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '中折町', 'ナカオレマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市長瀬町', '41', '41201', '8400853', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '長瀬町', 'ナガセマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市八戸', '41', '41201', '8400854', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '八戸', 'ヤエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市昭栄町', '41', '41201', '8400855', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '昭栄町', 'ショウエイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市新生町', '41', '41201', '8400856', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '新生町', 'シンセイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市鍋島町八戸', '41', '41201', '8400857', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '鍋島町八戸', 'ナベシママチヤエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市天祐団地', '41', '41201', '8400858', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '天祐団地', 'テンユウダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市新栄西', '41', '41201', '8400859', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '新栄西', 'シンエイニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市嘉瀬町中原', '41', '41201', '8400861', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '嘉瀬町中原', 'カセマチナカバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市嘉瀬町扇町', '41', '41201', '8400862', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '嘉瀬町扇町', 'カセマチオウギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市嘉瀬町十五', '41', '41201', '8400863', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '嘉瀬町十五', 'カセマチジュウゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市嘉瀬町荻野', '41', '41201', '8400864', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '嘉瀬町荻野', 'カセマチオギノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県三養基郡みやき町西島', '41', '41346', '8401101', '佐賀県', 'サガケン', '三養基郡みやき町', 'ミヤキグンミヤキチョウ', '西島', 'ニシジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県三養基郡みやき町天建寺', '41', '41346', '8401102', '佐賀県', 'サガケン', '三養基郡みやき町', 'ミヤキグンミヤキチョウ', '天建寺', 'テンケンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県三養基郡みやき町坂口', '41', '41346', '8401103', '佐賀県', 'サガケン', '三養基郡みやき町', 'ミヤキグンミヤキチョウ', '坂口', 'サカグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県三養基郡みやき町東津', '41', '41346', '8401104', '佐賀県', 'サガケン', '三養基郡みやき町', 'ミヤキグンミヤキチョウ', '東津', 'ヒガシツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県三養基郡みやき町寄人', '41', '41346', '8401105', '佐賀県', 'サガケン', '三養基郡みやき町', 'ミヤキグンミヤキチョウ', '寄人', 'ヨリウト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県三養基郡みやき町市武', '41', '41346', '8401106', '佐賀県', 'サガケン', '三養基郡みやき町', 'ミヤキグンミヤキチョウ', '市武', 'イチタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市諸富町大堂', '41', '41201', '8402101', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '諸富町大堂', 'モロドミチョウオオドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市諸富町為重', '41', '41201', '8402102', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '諸富町為重', 'モロドミチョウタメシゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市諸富町寺井津', '41', '41201', '8402103', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '諸富町寺井津', 'モロドミチョウテライツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市諸富町徳富', '41', '41201', '8402104', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '諸富町徳富', 'モロドミチョウトクドミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市諸富町諸富津', '41', '41201', '8402105', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '諸富町諸富津', 'モロドミチョウモロドミツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市諸富町山領', '41', '41201', '8402106', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '諸富町山領', 'モロドミチョウヤマリョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市川副町福富', '41', '41201', '8402201', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '川副町福富', 'カワソエマチフクドミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市川副町早津江津', '41', '41201', '8402202', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '川副町早津江津', 'カワソエマチハヤツエツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市川副町早津江', '41', '41201', '8402203', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '川副町早津江', 'カワソエマチハヤツエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市川副町西古賀', '41', '41201', '8402204', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '川副町西古賀', 'カワソエマチニシコガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市川副町南里', '41', '41201', '8402205', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '川副町南里', 'カワソエマチナンリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市川副町大詫間', '41', '41201', '8402211', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '川副町大詫間', 'カワソエマチオオダクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市川副町犬井道', '41', '41201', '8402212', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '川副町犬井道', 'カワソエマチイヌイドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市川副町鹿江', '41', '41201', '8402213', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '川副町鹿江', 'カワソエマチカノエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市川副町小々森', '41', '41201', '8402214', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '川副町小々森', 'カワソエマチコゴモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市東与賀町下古賀', '41', '41201', '8402221', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '東与賀町下古賀', 'ヒガシヨカチョウシモコガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市東与賀町田中', '41', '41201', '8402222', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '東与賀町田中', 'ヒガシヨカチョウタナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市東与賀町飯盛', '41', '41201', '8402223', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '東与賀町飯盛', 'ヒガシヨカチョウイサガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市昭和北', '01', '01206', '0840901', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '昭和北', 'ショウワキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市昭和', '01', '01206', '0840902', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '昭和', 'ショウワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市昭和町', '01', '01206', '0840903', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '昭和町', 'ショウワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市新富士町', '01', '01206', '0840904', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '新富士町', 'シンフジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市鳥取南', '01', '01206', '0840905', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '鳥取南', 'トットリミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市鳥取大通', '01', '01206', '0840906', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '鳥取大通', 'トットリオオドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市鳥取北', '01', '01206', '0840907', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '鳥取北', 'トットリキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市北園', '01', '01206', '0840908', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '北園', 'キタゾノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市昭和南', '01', '01206', '0840909', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '昭和南', 'ショウワミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市昭和中央', '01', '01206', '0840910', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '昭和中央', 'ショウワチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市星が浦北', '01', '01206', '0840911', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '星が浦北', 'ホシガウラキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市星が浦大通', '01', '01206', '0840912', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '星が浦大通', 'ホシガウラオオドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市星が浦南', '01', '01206', '0840913', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '星が浦南', 'ホシガウラミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市西港', '01', '01206', '0840914', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '西港', 'ニシコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市大楽毛南', '01', '01206', '0840915', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '大楽毛南', 'オタノシケミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市大楽毛西', '01', '01206', '0840916', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '大楽毛西', 'オタノシケニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市大楽毛', '01', '01206', '0840917', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '大楽毛', 'オタノシケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市大楽毛北', '01', '01206', '0840918', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '大楽毛北', 'オタノシケキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市美濃', '01', '01206', '0840921', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '美濃', 'ミノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市北斗', '01', '01206', '0840922', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '北斗', 'ホクト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市鶴野東', '01', '01206', '0840923', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '鶴野東', 'ツルノヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市鶴野', '01', '01206', '0840924', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '鶴野', 'ツルノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市新野', '01', '01206', '0840925', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '新野', 'ニイノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市鶴丘', '01', '01206', '0840926', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '鶴丘', 'ツルオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市駒牧', '01', '01206', '0840927', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '駒牧', 'コママキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市山花', '01', '01206', '0840928', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '山花', 'ヤマハナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市中鶴野', '01', '01206', '0840929', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '中鶴野', 'ナカツルノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県鳥栖市', '41', '41203', '8410000', '佐賀県', 'サガケン', '鳥栖市', 'トスシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('107639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県鳥栖市今町', '41', '41203', '8410001', '佐賀県', 'サガケン', '鳥栖市', 'トスシ', '今町', 'イママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県鳥栖市柚比町', '41', '41203', '8410002', '佐賀県', 'サガケン', '鳥栖市', 'トスシ', '柚比町', 'ユビマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県鳥栖市加藤田町', '41', '41203', '8410003', '佐賀県', 'サガケン', '鳥栖市', 'トスシ', '加藤田町', 'カトウダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県鳥栖市神辺町', '41', '41203', '8410004', '佐賀県', 'サガケン', '鳥栖市', 'トスシ', '神辺町', 'コウノエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県鳥栖市弥生が丘', '41', '41203', '8410005', '佐賀県', 'サガケン', '鳥栖市', 'トスシ', '弥生が丘', 'ヤヨイガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県鳥栖市永吉町', '41', '41203', '8410011', '佐賀県', 'サガケン', '鳥栖市', 'トスシ', '永吉町', 'ナガヨシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県鳥栖市田代昌町', '41', '41203', '8410012', '佐賀県', 'サガケン', '鳥栖市', 'トスシ', '田代昌町', 'タシロショウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県鳥栖市田代新町', '41', '41203', '8410013', '佐賀県', 'サガケン', '鳥栖市', 'トスシ', '田代新町', 'タシロシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県鳥栖市桜町', '41', '41203', '8410014', '佐賀県', 'サガケン', '鳥栖市', 'トスシ', '桜町', 'サクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県鳥栖市田代上町', '41', '41203', '8410015', '佐賀県', 'サガケン', '鳥栖市', 'トスシ', '田代上町', 'タシロカンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県鳥栖市田代外町', '41', '41203', '8410016', '佐賀県', 'サガケン', '鳥栖市', 'トスシ', '田代外町', 'タシロホカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県鳥栖市田代大官町', '41', '41203', '8410017', '佐賀県', 'サガケン', '鳥栖市', 'トスシ', '田代大官町', 'タシロダイカンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県鳥栖市田代本町', '41', '41203', '8410018', '佐賀県', 'サガケン', '鳥栖市', 'トスシ', '田代本町', 'タシロホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県鳥栖市幡崎町', '41', '41203', '8410021', '佐賀県', 'サガケン', '鳥栖市', 'トスシ', '幡崎町', 'ハタザキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県鳥栖市飯田町', '41', '41203', '8410022', '佐賀県', 'サガケン', '鳥栖市', 'トスシ', '飯田町', 'イイダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県鳥栖市姫方町', '41', '41203', '8410023', '佐賀県', 'サガケン', '鳥栖市', 'トスシ', '姫方町', 'ヒメカタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県鳥栖市原町', '41', '41203', '8410024', '佐賀県', 'サガケン', '鳥栖市', 'トスシ', '原町', 'ハルマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県鳥栖市曽根崎町', '41', '41203', '8410025', '佐賀県', 'サガケン', '鳥栖市', 'トスシ', '曽根崎町', 'ソネザキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県鳥栖市本鳥栖町', '41', '41203', '8410026', '佐賀県', 'サガケン', '鳥栖市', 'トスシ', '本鳥栖町', 'ホンドスマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県鳥栖市松原町', '41', '41203', '8410027', '佐賀県', 'サガケン', '鳥栖市', 'トスシ', '松原町', 'マツバラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県鳥栖市鎗田町', '41', '41203', '8410031', '佐賀県', 'サガケン', '鳥栖市', 'トスシ', '鎗田町', 'ヤリタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県鳥栖市大正町', '41', '41203', '8410032', '佐賀県', 'サガケン', '鳥栖市', 'トスシ', '大正町', 'タイショウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県鳥栖市本通町', '41', '41203', '8410033', '佐賀県', 'サガケン', '鳥栖市', 'トスシ', '本通町', 'ホンドオリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県鳥栖市京町', '41', '41203', '8410034', '佐賀県', 'サガケン', '鳥栖市', 'トスシ', '京町', 'キョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県鳥栖市東町', '41', '41203', '8410035', '佐賀県', 'サガケン', '鳥栖市', 'トスシ', '東町', 'ヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県鳥栖市秋葉町', '41', '41203', '8410036', '佐賀県', 'サガケン', '鳥栖市', 'トスシ', '秋葉町', 'アキバマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県鳥栖市本町', '41', '41203', '8410037', '佐賀県', 'サガケン', '鳥栖市', 'トスシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県鳥栖市古野町', '41', '41203', '8410038', '佐賀県', 'サガケン', '鳥栖市', 'トスシ', '古野町', 'フルノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県鳥栖市土井町', '41', '41203', '8410039', '佐賀県', 'サガケン', '鳥栖市', 'トスシ', '土井町', 'ドイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県鳥栖市酒井東町', '41', '41203', '8410041', '佐賀県', 'サガケン', '鳥栖市', 'トスシ', '酒井東町', 'サカイヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県鳥栖市酒井西町', '41', '41203', '8410042', '佐賀県', 'サガケン', '鳥栖市', 'トスシ', '酒井西町', 'サカイニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県鳥栖市水屋町', '41', '41203', '8410043', '佐賀県', 'サガケン', '鳥栖市', 'トスシ', '水屋町', 'ミズヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県鳥栖市高田町', '41', '41203', '8410044', '佐賀県', 'サガケン', '鳥栖市', 'トスシ', '高田町', 'タカタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県鳥栖市安楽寺町', '41', '41203', '8410045', '佐賀県', 'サガケン', '鳥栖市', 'トスシ', '安楽寺町', 'アンラクジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県鳥栖市真木町', '41', '41203', '8410046', '佐賀県', 'サガケン', '鳥栖市', 'トスシ', '真木町', 'マキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県鳥栖市今泉町', '41', '41203', '8410047', '佐賀県', 'サガケン', '鳥栖市', 'トスシ', '今泉町', 'イマイズミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県鳥栖市藤木町', '41', '41203', '8410048', '佐賀県', 'サガケン', '鳥栖市', 'トスシ', '藤木町', 'フジノキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県鳥栖市元町', '41', '41203', '8410051', '佐賀県', 'サガケン', '鳥栖市', 'トスシ', '元町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県鳥栖市宿町', '41', '41203', '8410052', '佐賀県', 'サガケン', '鳥栖市', 'トスシ', '宿町', 'シュクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県鳥栖市布津原町', '41', '41203', '8410053', '佐賀県', 'サガケン', '鳥栖市', 'トスシ', '布津原町', 'フツハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県鳥栖市蔵上町', '41', '41203', '8410054', '佐賀県', 'サガケン', '鳥栖市', 'トスシ', '蔵上町', 'クラノウエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県鳥栖市養父町', '41', '41203', '8410055', '佐賀県', 'サガケン', '鳥栖市', 'トスシ', '養父町', 'ヤブマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県鳥栖市蔵上', '41', '41203', '8410056', '佐賀県', 'サガケン', '鳥栖市', 'トスシ', '蔵上', 'クラノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県鳥栖市轟木町', '41', '41203', '8410061', '佐賀県', 'サガケン', '鳥栖市', 'トスシ', '轟木町', 'トドロキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県鳥栖市幸津町', '41', '41203', '8410062', '佐賀県', 'サガケン', '鳥栖市', 'トスシ', '幸津町', 'サイツマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県鳥栖市下野町', '41', '41203', '8410063', '佐賀県', 'サガケン', '鳥栖市', 'トスシ', '下野町', 'シモノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県鳥栖市三島町', '41', '41203', '8410064', '佐賀県', 'サガケン', '鳥栖市', 'トスシ', '三島町', 'ミシママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県鳥栖市前田町', '41', '41203', '8410065', '佐賀県', 'サガケン', '鳥栖市', 'トスシ', '前田町', 'マエダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県鳥栖市儀徳町', '41', '41203', '8410066', '佐賀県', 'サガケン', '鳥栖市', 'トスシ', '儀徳町', 'ギトクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県鳥栖市西田町', '41', '41203', '8410067', '佐賀県', 'サガケン', '鳥栖市', 'トスシ', '西田町', 'ニシダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県鳥栖市あさひ新町', '41', '41203', '8410068', '佐賀県', 'サガケン', '鳥栖市', 'トスシ', 'あさひ新町', 'アサヒシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県鳥栖市原古賀町', '41', '41203', '8410071', '佐賀県', 'サガケン', '鳥栖市', 'トスシ', '原古賀町', 'ハラコガマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県鳥栖市村田町', '41', '41203', '8410072', '佐賀県', 'サガケン', '鳥栖市', 'トスシ', '村田町', 'ムラタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県鳥栖市江島町', '41', '41203', '8410073', '佐賀県', 'サガケン', '鳥栖市', 'トスシ', '江島町', 'エジママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県鳥栖市西新町', '41', '41203', '8410074', '佐賀県', 'サガケン', '鳥栖市', 'トスシ', '西新町', 'ニシシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県鳥栖市立石町', '41', '41203', '8410075', '佐賀県', 'サガケン', '鳥栖市', 'トスシ', '立石町', 'タテイシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県鳥栖市平田町', '41', '41203', '8410076', '佐賀県', 'サガケン', '鳥栖市', 'トスシ', '平田町', 'ヒラタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県鳥栖市萱方町', '41', '41203', '8410081', '佐賀県', 'サガケン', '鳥栖市', 'トスシ', '萱方町', 'カヤカタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県鳥栖市浅井町', '41', '41203', '8410082', '佐賀県', 'サガケン', '鳥栖市', 'トスシ', '浅井町', 'アサイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県鳥栖市古賀町', '41', '41203', '8410083', '佐賀県', 'サガケン', '鳥栖市', 'トスシ', '古賀町', 'コガマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県鳥栖市山浦町', '41', '41203', '8410084', '佐賀県', 'サガケン', '鳥栖市', 'トスシ', '山浦町', 'ヤマウラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県鳥栖市山都町', '41', '41203', '8410085', '佐賀県', 'サガケン', '鳥栖市', 'トスシ', '山都町', 'ヤマトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県鳥栖市牛原町', '41', '41203', '8410086', '佐賀県', 'サガケン', '鳥栖市', 'トスシ', '牛原町', 'ウシワラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県鳥栖市河内町', '41', '41203', '8410087', '佐賀県', 'サガケン', '鳥栖市', 'トスシ', '河内町', 'カワチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県鳥栖市桜ケ丘町', '41', '41203', '8410088', '佐賀県', 'サガケン', '鳥栖市', 'トスシ', '桜ケ丘町', 'サクラガオカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県鳥栖市虹ケ丘町', '41', '41203', '8410089', '佐賀県', 'サガケン', '鳥栖市', 'トスシ', '虹ケ丘町', 'ニジガオカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県三養基郡基山町', '41', '41341', '8410200', '佐賀県', 'サガケン', '三養基郡基山町', 'ミヤキグンキヤマチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('107706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県三養基郡基山町小倉', '41', '41341', '8410201', '佐賀県', 'サガケン', '三養基郡基山町', 'ミヤキグンキヤマチョウ', '小倉', 'コクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県三養基郡基山町長野', '41', '41341', '8410202', '佐賀県', 'サガケン', '三養基郡基山町', 'ミヤキグンキヤマチョウ', '長野', 'ナガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県三養基郡基山町園部', '41', '41341', '8410203', '佐賀県', 'サガケン', '三養基郡基山町', 'ミヤキグンキヤマチョウ', '園部', 'ソノベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県三養基郡基山町宮浦', '41', '41341', '8410204', '佐賀県', 'サガケン', '三養基郡基山町', 'ミヤキグンキヤマチョウ', '宮浦', 'ミヤウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県三養基郡基山町けやき台', '41', '41341', '8410205', '佐賀県', 'サガケン', '三養基郡基山町', 'ミヤキグンキヤマチョウ', 'けやき台', 'ケヤキダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県神埼市', '41', '41210', '8420000', '佐賀県', 'サガケン', '神埼市', 'カンザキシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('107719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県神埼郡吉野ヶ里町', '41', '41327', '8420000', '佐賀県', 'サガケン', '神埼郡吉野ヶ里町', 'カンザキグンヨシノガリチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('107720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県神埼市神埼町神埼', '41', '41210', '8420001', '佐賀県', 'サガケン', '神埼市', 'カンザキシ', '神埼町神埼', 'カンザキマチカンザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県神埼市神埼町田道ケ里', '41', '41210', '8420002', '佐賀県', 'サガケン', '神埼市', 'カンザキシ', '神埼町田道ケ里', 'カンザキマチタミチガリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県神埼市神埼町本堀', '41', '41210', '8420003', '佐賀県', 'サガケン', '神埼市', 'カンザキシ', '神埼町本堀', 'カンザキマチモトホリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県神埼市神埼町永歌', '41', '41210', '8420004', '佐賀県', 'サガケン', '神埼市', 'カンザキシ', '神埼町永歌', 'カンザキマチナガウタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県神埼市神埼町西小津ケ里', '41', '41210', '8420005', '佐賀県', 'サガケン', '神埼市', 'カンザキシ', '神埼町西小津ケ里', 'カンザキマチニシオヅガリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県神埼市神埼町枝ケ里', '41', '41210', '8420006', '佐賀県', 'サガケン', '神埼市', 'カンザキシ', '神埼町枝ケ里', 'カンザキマチエダガリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県神埼市神埼町鶴', '41', '41210', '8420007', '佐賀県', 'サガケン', '神埼市', 'カンザキシ', '神埼町鶴', 'カンザキマチツル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県神埼市神埼町竹', '41', '41210', '8420011', '佐賀県', 'サガケン', '神埼市', 'カンザキシ', '神埼町竹', 'カンザキマチタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県神埼市神埼町横武', '41', '41210', '8420012', '佐賀県', 'サガケン', '神埼市', 'カンザキシ', '神埼町横武', 'カンザキマチヨコタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県神埼市神埼町本告牟田', '41', '41210', '8420013', '佐賀県', 'サガケン', '神埼市', 'カンザキシ', '神埼町本告牟田', 'カンザキマチモトオリムタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県神埼市神埼町姉川', '41', '41210', '8420014', '佐賀県', 'サガケン', '神埼市', 'カンザキシ', '神埼町姉川', 'カンザキマチアネガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県神埼市神埼町尾崎', '41', '41210', '8420015', '佐賀県', 'サガケン', '神埼市', 'カンザキシ', '神埼町尾崎', 'カンザキマチオサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県神埼郡吉野ヶ里町吉田', '41', '41327', '8420031', '佐賀県', 'サガケン', '神埼郡吉野ヶ里町', 'カンザキグンヨシノガリチョウ', '吉田', 'ヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県神埼郡吉野ヶ里町立野', '41', '41327', '8420032', '佐賀県', 'サガケン', '神埼郡吉野ヶ里町', 'カンザキグンヨシノガリチョウ', '立野', 'タテノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県神埼郡吉野ヶ里町豆田', '41', '41327', '8420033', '佐賀県', 'サガケン', '神埼郡吉野ヶ里町', 'カンザキグンヨシノガリチョウ', '豆田', 'マメダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県神埼郡吉野ヶ里町箱川', '41', '41327', '8420034', '佐賀県', 'サガケン', '神埼郡吉野ヶ里町', 'カンザキグンヨシノガリチョウ', '箱川', 'ハコガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県神埼郡吉野ヶ里町田手', '41', '41327', '8420035', '佐賀県', 'サガケン', '神埼郡吉野ヶ里町', 'カンザキグンヨシノガリチョウ', '田手', 'タデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県神埼市千代田町黒井', '41', '41210', '8420051', '佐賀県', 'サガケン', '神埼市', 'カンザキシ', '千代田町黒井', 'チヨダチョウクロイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県神埼市千代田町姉', '41', '41210', '8420052', '佐賀県', 'サガケン', '神埼市', 'カンザキシ', '千代田町姉', 'チヨダチョウアネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県神埼市千代田町直鳥', '41', '41210', '8420053', '佐賀県', 'サガケン', '神埼市', 'カンザキシ', '千代田町直鳥', 'チヨダチョウナオトリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県神埼市千代田町餘江', '41', '41210', '8420054', '佐賀県', 'サガケン', '神埼市', 'カンザキシ', '千代田町餘江', 'チヨダチョウアマリエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県神埼市千代田町下西', '41', '41210', '8420055', '佐賀県', 'サガケン', '神埼市', 'カンザキシ', '千代田町下西', 'チヨダチョウシモサイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県神埼市千代田町境原', '41', '41210', '8420056', '佐賀県', 'サガケン', '神埼市', 'カンザキシ', '千代田町境原', 'チヨダチョウサカイバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県神埼市千代田町詫田', '41', '41210', '8420061', '佐賀県', 'サガケン', '神埼市', 'カンザキシ', '千代田町詫田', 'チヨダチョウタクタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県神埼市千代田町柳島', '41', '41210', '8420062', '佐賀県', 'サガケン', '神埼市', 'カンザキシ', '千代田町柳島', 'チヨダチョウヤナギシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県神埼市千代田町迎島', '41', '41210', '8420063', '佐賀県', 'サガケン', '神埼市', 'カンザキシ', '千代田町迎島', 'チヨダチョウムカイシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県神埼市千代田町渡瀬', '41', '41210', '8420064', '佐賀県', 'サガケン', '神埼市', 'カンザキシ', '千代田町渡瀬', 'チヨダチョウワタゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県神埼市千代田町崎村', '41', '41210', '8420065', '佐賀県', 'サガケン', '神埼市', 'カンザキシ', '千代田町崎村', 'チヨダチョウサキムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県神埼市千代田町用作', '41', '41210', '8420066', '佐賀県', 'サガケン', '神埼市', 'カンザキシ', '千代田町用作', 'チヨダチョウヨウサク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県神埼市千代田町嘉納', '41', '41210', '8420067', '佐賀県', 'サガケン', '神埼市', 'カンザキシ', '千代田町嘉納', 'チヨダチョウカノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県神埼市千代田町下板', '41', '41210', '8420068', '佐賀県', 'サガケン', '神埼市', 'カンザキシ', '千代田町下板', 'チヨダチョウシモイタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県神埼郡吉野ヶ里町松隈', '41', '41327', '8420101', '佐賀県', 'サガケン', '神埼郡吉野ヶ里町', 'カンザキグンヨシノガリチョウ', '松隈', 'マツグマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県神埼郡吉野ヶ里町石動', '41', '41327', '8420102', '佐賀県', 'サガケン', '神埼郡吉野ヶ里町', 'カンザキグンヨシノガリチョウ', '石動', 'イシナリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県神埼郡吉野ヶ里町大曲', '41', '41327', '8420103', '佐賀県', 'サガケン', '神埼郡吉野ヶ里町', 'カンザキグンヨシノガリチョウ', '大曲', 'オオマガリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県神埼郡吉野ヶ里町三津', '41', '41327', '8420104', '佐賀県', 'サガケン', '神埼郡吉野ヶ里町', 'カンザキグンヨシノガリチョウ', '三津', 'ミツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県神埼市神埼町鶴', '41', '41210', '8420107', '佐賀県', 'サガケン', '神埼市', 'カンザキシ', '神埼町鶴', 'カンザキマチツル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県神埼市神埼町志波屋', '41', '41210', '8420121', '佐賀県', 'サガケン', '神埼市', 'カンザキシ', '神埼町志波屋', 'カンザキマチシワヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県神埼市神埼町城原', '41', '41210', '8420122', '佐賀県', 'サガケン', '神埼市', 'カンザキシ', '神埼町城原', 'カンザキマチジョウバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県神埼市神埼町的', '41', '41210', '8420123', '佐賀県', 'サガケン', '神埼市', 'カンザキシ', '神埼町的', 'カンザキマチイクワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県神埼市脊振町広滝', '41', '41210', '8420201', '佐賀県', 'サガケン', '神埼市', 'カンザキシ', '脊振町広滝', 'セフリマチヒロタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県神埼市脊振町鹿路', '41', '41210', '8420202', '佐賀県', 'サガケン', '神埼市', 'カンザキシ', '脊振町鹿路', 'セフリマチロクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県神埼市脊振町服巻', '41', '41210', '8420203', '佐賀県', 'サガケン', '神埼市', 'カンザキシ', '脊振町服巻', 'セフリマチハラマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市三瀬村三瀬', '41', '41201', '8420301', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '三瀬村三瀬', 'ミツセムラミツセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市三瀬村藤原', '41', '41201', '8420302', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '三瀬村藤原', 'ミツセムラフジバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市三瀬村杠', '41', '41201', '8420303', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '三瀬村杠', 'ミツセムラユズリハ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県武雄市', '41', '41206', '8430000', '佐賀県', 'サガケン', '武雄市', 'タケオシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('107776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県武雄市朝日町甘久', '41', '41206', '8430001', '佐賀県', 'サガケン', '武雄市', 'タケオシ', '朝日町甘久', 'アサヒチョウアマグ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県武雄市朝日町中野', '41', '41206', '8430002', '佐賀県', 'サガケン', '武雄市', 'タケオシ', '朝日町中野', 'アサヒチョウナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県武雄市朝日町芦原', '41', '41206', '8430003', '佐賀県', 'サガケン', '武雄市', 'タケオシ', '朝日町芦原', 'アサヒチョウアシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県武雄市橘町芦原', '41', '41206', '8430011', '佐賀県', 'サガケン', '武雄市', 'タケオシ', '橘町芦原', 'タチバナチョウアシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県武雄市橘町片白', '41', '41206', '8430012', '佐賀県', 'サガケン', '武雄市', 'タケオシ', '橘町片白', 'タチバナチョウカタジロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県武雄市橘町大日', '41', '41206', '8430013', '佐賀県', 'サガケン', '武雄市', 'タケオシ', '橘町大日', 'タチバナチョウダイニチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県武雄市橘町永島', '41', '41206', '8430014', '佐賀県', 'サガケン', '武雄市', 'タケオシ', '橘町永島', 'タチバナチョウナガシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県武雄市武雄町永島', '41', '41206', '8430021', '佐賀県', 'サガケン', '武雄市', 'タケオシ', '武雄町永島', 'タケオチョウナガシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県武雄市武雄町武雄', '41', '41206', '8430022', '佐賀県', 'サガケン', '武雄市', 'タケオシ', '武雄町武雄', 'タケオチョウタケオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県武雄市武雄町昭和', '41', '41206', '8430023', '佐賀県', 'サガケン', '武雄市', 'タケオシ', '武雄町昭和', 'タケオチョウショウワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県武雄市武雄町富岡', '41', '41206', '8430024', '佐賀県', 'サガケン', '武雄市', 'タケオシ', '武雄町富岡', 'タケオチョウトミオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県武雄市若木町川古', '41', '41206', '8430151', '佐賀県', 'サガケン', '武雄市', 'タケオシ', '若木町川古', 'ワカキチョウカワゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県武雄市若木町本部', '41', '41206', '8430152', '佐賀県', 'サガケン', '武雄市', 'タケオシ', '若木町本部', 'ワカキチョウモトベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県武雄市若木町桃川', '41', '41206', '8430153', '佐賀県', 'サガケン', '武雄市', 'タケオシ', '若木町桃川', 'ワカキチョウモモノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県武雄市西川登町小田志', '41', '41206', '8430231', '佐賀県', 'サガケン', '武雄市', 'タケオシ', '西川登町小田志', 'ニシカワノボリチョウコタジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県武雄市西川登町神六', '41', '41206', '8430232', '佐賀県', 'サガケン', '武雄市', 'タケオシ', '西川登町神六', 'ニシカワノボリチョウジンロク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県武雄市東川登町永野', '41', '41206', '8430233', '佐賀県', 'サガケン', '武雄市', 'タケオシ', '東川登町永野', 'ヒガシカワノボリチョウナガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県武雄市東川登町袴野', '41', '41206', '8430234', '佐賀県', 'サガケン', '武雄市', 'タケオシ', '東川登町袴野', 'ヒガシカワノボリチョウハカマノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県嬉野市', '41', '41209', '8430300', '佐賀県', 'サガケン', '嬉野市', 'ウレシノシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('107795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県嬉野市嬉野町下宿', '41', '41209', '8430301', '佐賀県', 'サガケン', '嬉野市', 'ウレシノシ', '嬉野町下宿', 'ウレシノマチシモジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県嬉野市嬉野町下野', '41', '41209', '8430302', '佐賀県', 'サガケン', '嬉野市', 'ウレシノシ', '嬉野町下野', 'ウレシノマチシモノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県嬉野市嬉野町吉田', '41', '41209', '8430303', '佐賀県', 'サガケン', '嬉野市', 'ウレシノシ', '嬉野町吉田', 'ウレシノマチヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県嬉野市嬉野町岩屋川内', '41', '41209', '8430304', '佐賀県', 'サガケン', '嬉野市', 'ウレシノシ', '嬉野町岩屋川内', 'ウレシノマチイワヤガワチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県嬉野市嬉野町不動山', '41', '41209', '8430305', '佐賀県', 'サガケン', '嬉野市', 'ウレシノシ', '嬉野町不動山', 'ウレシノマチフドウヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県西松浦郡有田町', '41', '41401', '8440000', '佐賀県', 'サガケン', '西松浦郡有田町', 'ニシマツウラグンアリタチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('107811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県西松浦郡有田町泉山', '41', '41401', '8440001', '佐賀県', 'サガケン', '西松浦郡有田町', 'ニシマツウラグンアリタチョウ', '泉山', 'イズミヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県西松浦郡有田町中樽', '41', '41401', '8440002', '佐賀県', 'サガケン', '西松浦郡有田町', 'ニシマツウラグンアリタチョウ', '中樽', 'ナカダル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県西松浦郡有田町上幸平', '41', '41401', '8440003', '佐賀県', 'サガケン', '西松浦郡有田町', 'ニシマツウラグンアリタチョウ', '上幸平', 'カミコウヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県西松浦郡有田町大樽', '41', '41401', '8440004', '佐賀県', 'サガケン', '西松浦郡有田町', 'ニシマツウラグンアリタチョウ', '大樽', 'オオダル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県西松浦郡有田町幸平', '41', '41401', '8440005', '佐賀県', 'サガケン', '西松浦郡有田町', 'ニシマツウラグンアリタチョウ', '幸平', 'コウビラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県西松浦郡有田町赤絵町', '41', '41401', '8440006', '佐賀県', 'サガケン', '西松浦郡有田町', 'ニシマツウラグンアリタチョウ', '赤絵町', 'アカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県西松浦郡有田町白川', '41', '41401', '8440007', '佐賀県', 'サガケン', '西松浦郡有田町', 'ニシマツウラグンアリタチョウ', '白川', 'シラカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県西松浦郡有田町稗古場', '41', '41401', '8440008', '佐賀県', 'サガケン', '西松浦郡有田町', 'ニシマツウラグンアリタチョウ', '稗古場', 'ヒエコバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県西松浦郡有田町中の原', '41', '41401', '8440009', '佐賀県', 'サガケン', '西松浦郡有田町', 'ニシマツウラグンアリタチョウ', '中の原', 'ナカノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県西松浦郡有田町岩谷川内', '41', '41401', '8440011', '佐賀県', 'サガケン', '西松浦郡有田町', 'ニシマツウラグンアリタチョウ', '岩谷川内', 'イワタニガワチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県西松浦郡有田町桑古場', '41', '41401', '8440012', '佐賀県', 'サガケン', '西松浦郡有田町', 'ニシマツウラグンアリタチョウ', '桑古場', 'クワコバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県西松浦郡有田町大野', '41', '41401', '8440013', '佐賀県', 'サガケン', '西松浦郡有田町', 'ニシマツウラグンアリタチョウ', '大野', 'オオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県西松浦郡有田町戸矢', '41', '41401', '8440014', '佐賀県', 'サガケン', '西松浦郡有田町', 'ニシマツウラグンアリタチョウ', '戸矢', 'トヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県西松浦郡有田町古木場', '41', '41401', '8440015', '佐賀県', 'サガケン', '西松浦郡有田町', 'ニシマツウラグンアリタチョウ', '古木場', 'フルコバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県西松浦郡有田町境野', '41', '41401', '8440016', '佐賀県', 'サガケン', '西松浦郡有田町', 'ニシマツウラグンアリタチョウ', '境野', 'サカイノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県西松浦郡有田町戸杓', '41', '41401', '8440017', '佐賀県', 'サガケン', '西松浦郡有田町', 'ニシマツウラグンアリタチョウ', '戸杓', 'トシャク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県西松浦郡有田町本町', '41', '41401', '8440018', '佐賀県', 'サガケン', '西松浦郡有田町', 'ニシマツウラグンアリタチョウ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県西松浦郡有田町応法', '41', '41401', '8440021', '佐賀県', 'サガケン', '西松浦郡有田町', 'ニシマツウラグンアリタチョウ', '応法', 'オウボウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県西松浦郡有田町黒牟田', '41', '41401', '8440022', '佐賀県', 'サガケン', '西松浦郡有田町', 'ニシマツウラグンアリタチョウ', '黒牟田', 'クロムタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県西松浦郡有田町丸尾', '41', '41401', '8440023', '佐賀県', 'サガケン', '西松浦郡有田町', 'ニシマツウラグンアリタチョウ', '丸尾', 'マルオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県西松浦郡有田町赤坂', '41', '41401', '8440024', '佐賀県', 'サガケン', '西松浦郡有田町', 'ニシマツウラグンアリタチョウ', '赤坂', 'アカサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県西松浦郡有田町外尾山', '41', '41401', '8440025', '佐賀県', 'サガケン', '西松浦郡有田町', 'ニシマツウラグンアリタチョウ', '外尾山', 'ホカオヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県西松浦郡有田町外尾町', '41', '41401', '8440026', '佐賀県', 'サガケン', '西松浦郡有田町', 'ニシマツウラグンアリタチョウ', '外尾町', 'ホカオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県西松浦郡有田町南原', '41', '41401', '8440027', '佐賀県', 'サガケン', '西松浦郡有田町', 'ニシマツウラグンアリタチョウ', '南原', 'ナンバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県西松浦郡有田町南山', '41', '41401', '8440028', '佐賀県', 'サガケン', '西松浦郡有田町', 'ニシマツウラグンアリタチョウ', '南山', 'ナンザン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県小城市', '41', '41208', '8450000', '佐賀県', 'サガケン', '小城市', 'オギシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('107845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県小城市小城町', '41', '41208', '8450001', '佐賀県', 'サガケン', '小城市', 'オギシ', '小城町', 'オギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県小城市小城町畑田', '41', '41208', '8450002', '佐賀県', 'サガケン', '小城市', 'オギシ', '小城町畑田', 'オギマチハタケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県小城市小城町岩蔵', '41', '41208', '8450003', '佐賀県', 'サガケン', '小城市', 'オギシ', '小城町岩蔵', 'オギマチイワクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県小城市小城町松尾', '41', '41208', '8450004', '佐賀県', 'サガケン', '小城市', 'オギシ', '小城町松尾', 'オギマチマツオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県小城市小城町東新町', '41', '41208', '8450005', '佐賀県', 'サガケン', '小城市', 'オギシ', '小城町東新町', 'オギマチヒガシシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県小城市小城町船田', '41', '41208', '8450011', '佐賀県', 'サガケン', '小城市', 'オギシ', '小城町船田', 'オギマチフナダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県小城市小城町池上', '41', '41208', '8450012', '佐賀県', 'サガケン', '小城市', 'オギシ', '小城町池上', 'オギマチイケノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県小城市小城町栗原', '41', '41208', '8450013', '佐賀県', 'サガケン', '小城市', 'オギシ', '小城町栗原', 'オギマチクリハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県小城市小城町晴気', '41', '41208', '8450014', '佐賀県', 'サガケン', '小城市', 'オギシ', '小城町晴気', 'オギマチハルケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県小城市三日月町長神田', '41', '41208', '8450021', '佐賀県', 'サガケン', '小城市', 'オギシ', '三日月町長神田', 'ミカツキチョウチョウカンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県小城市三日月町久米', '41', '41208', '8450022', '佐賀県', 'サガケン', '小城市', 'オギシ', '三日月町久米', 'ミカツキチョウクメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県小城市三日月町織島', '41', '41208', '8450023', '佐賀県', 'サガケン', '小城市', 'オギシ', '三日月町織島', 'ミカツキチョウオリシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県小城市三日月町道辺', '41', '41208', '8450024', '佐賀県', 'サガケン', '小城市', 'オギシ', '三日月町道辺', 'ミカツキチョウミチベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県小城市三日月町三ケ島', '41', '41208', '8450025', '佐賀県', 'サガケン', '小城市', 'オギシ', '三日月町三ケ島', 'ミカツキチョウミカシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県小城市三日月町堀江', '41', '41208', '8450031', '佐賀県', 'サガケン', '小城市', 'オギシ', '三日月町堀江', 'ミカツキチョウホリエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県小城市三日月町金田', '41', '41208', '8450032', '佐賀県', 'サガケン', '小城市', 'オギシ', '三日月町金田', 'ミカツキチョウカナダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県小城市三日月町樋口', '41', '41208', '8450033', '佐賀県', 'サガケン', '小城市', 'オギシ', '三日月町樋口', 'ミカツキチョウヒグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県小城市三日月町甲柳原', '41', '41208', '8450034', '佐賀県', 'サガケン', '小城市', 'オギシ', '三日月町甲柳原', 'ミカツキチョウコウヤナギハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県小城市三日月町石木', '41', '41208', '8450035', '佐賀県', 'サガケン', '小城市', 'オギシ', '三日月町石木', 'ミカツキチョウイシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県多久市', '41', '41204', '8460000', '佐賀県', 'サガケン', '多久市', 'タクシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('107868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県多久市北多久町', '41', '41204', '8460001', '佐賀県', 'サガケン', '多久市', 'タクシ', '北多久町', 'キタタクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県多久市北多久町小侍', '41', '41204', '8460002', '佐賀県', 'サガケン', '多久市', 'タクシ', '北多久町小侍', 'キタタクマチコサムライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県多久市北多久町多久原', '41', '41204', '8460003', '佐賀県', 'サガケン', '多久市', 'タクシ', '北多久町多久原', 'キタタクマチタクバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県多久市北多久町中多久', '41', '41204', '8460004', '佐賀県', 'サガケン', '多久市', 'タクシ', '北多久町中多久', 'キタタクマチナカタク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県多久市北多久町砂原', '41', '41204', '8460005', '佐賀県', 'サガケン', '多久市', 'タクシ', '北多久町砂原', 'キタタクマチスナハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県多久市北多久町莇原', '41', '41204', '8460006', '佐賀県', 'サガケン', '多久市', 'タクシ', '北多久町莇原', 'キタタクマチアザミバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県多久市北多久町メイプルタウン', '41', '41204', '8460007', '佐賀県', 'サガケン', '多久市', 'タクシ', '北多久町メイプルタウン', 'キタタクマチメイプルタウン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県多久市東多久町', '41', '41204', '8460011', '佐賀県', 'サガケン', '多久市', 'タクシ', '東多久町', 'ヒガシタクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県多久市東多久町別府', '41', '41204', '8460012', '佐賀県', 'サガケン', '多久市', 'タクシ', '東多久町別府', 'ヒガシタクマチベフ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県多久市東多久町古賀', '41', '41204', '8460013', '佐賀県', 'サガケン', '多久市', 'タクシ', '東多久町古賀', 'ヒガシタクマチコガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県多久市東多久町納所', '41', '41204', '8460014', '佐賀県', 'サガケン', '多久市', 'タクシ', '東多久町納所', 'ヒガシタクマチノウソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県多久市南多久町', '41', '41204', '8460021', '佐賀県', 'サガケン', '多久市', 'タクシ', '南多久町', 'ミナミタクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県多久市南多久町泉町', '41', '41204', '8460022', '佐賀県', 'サガケン', '多久市', 'タクシ', '南多久町泉町', 'ミナミタクマチイズミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県多久市南多久町長尾', '41', '41204', '8460023', '佐賀県', 'サガケン', '多久市', 'タクシ', '南多久町長尾', 'ミナミタクマチナガオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県多久市南多久町下多久', '41', '41204', '8460024', '佐賀県', 'サガケン', '多久市', 'タクシ', '南多久町下多久', 'ミナミタクマチシモタク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県多久市南多久町花祭', '41', '41204', '8460025', '佐賀県', 'サガケン', '多久市', 'タクシ', '南多久町花祭', 'ミナミタクマチハナマツリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県多久市多久町', '41', '41204', '8460031', '佐賀県', 'サガケン', '多久市', 'タクシ', '多久町', 'タクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県多久市西多久町', '41', '41204', '8460041', '佐賀県', 'サガケン', '多久市', 'タクシ', '西多久町', 'ニシタクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市', '41', '41202', '8470000', '佐賀県', 'サガケン', '唐津市', 'カラツシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('107888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市双水', '41', '41202', '8470001', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '双水', 'ソウズイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市山本', '41', '41202', '8470002', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '山本', 'ヤマモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市橋本', '41', '41202', '8470003', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '橋本', 'ハシモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市養母田', '41', '41202', '8470004', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '養母田', 'ヤブタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市養母田鬼塚', '41', '41202', '8470005', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '養母田鬼塚', 'ヤブタオニヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市栄町', '41', '41202', '8470011', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市大名小路', '41', '41202', '8470012', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '大名小路', 'ダイミョウコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市南城内', '41', '41202', '8470013', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '南城内', 'ミナミジョウナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市西城内', '41', '41202', '8470014', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '西城内', 'ニシジョウナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市北城内', '41', '41202', '8470015', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '北城内', 'キタジョウナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市東城内', '41', '41202', '8470016', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '東城内', 'ヒガシジョウナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市東唐津', '41', '41202', '8470017', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '東唐津', 'ヒガシカラツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市松南町', '41', '41202', '8470021', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '松南町', 'ショウナンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市鏡', '41', '41202', '8470022', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '鏡', 'カガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市半田', '41', '41202', '8470023', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '半田', 'ハダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市東宇木', '41', '41202', '8470024', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '東宇木', 'ヒガシウキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市宇木', '41', '41202', '8470025', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '宇木', 'ウキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市柏崎', '41', '41202', '8470026', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '柏崎', 'カシワザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市高島', '41', '41202', '8470027', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '高島', 'タカシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市原', '41', '41202', '8470031', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '原', 'ハル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市夕日', '41', '41202', '8470032', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '夕日', 'ユウヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市久里', '41', '41202', '8470033', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '久里', 'クリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市中原', '41', '41202', '8470034', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '中原', 'ナカバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市千代田町', '41', '41202', '8470041', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '千代田町', 'チヨダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市魚屋町', '41', '41202', '8470042', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '魚屋町', 'ウオヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市新興町東新興町', '41', '41202', '8470043', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '新興町', 'シンコウマチ', null, null, '東新興町', 'ヒガシシンコウマチ');
INSERT INTO `ms_addresses` VALUES ('107914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市木綿町', '41', '41202', '8470044', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '木綿町', 'キワタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市京町', '41', '41202', '8470045', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '京町', 'キョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市高砂町', '41', '41202', '8470046', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '高砂町', 'タカサゴマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市本町', '41', '41202', '8470047', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市中町', '41', '41202', '8470051', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '中町', 'ナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市呉服町', '41', '41202', '8470052', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '呉服町', 'ゴフクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市紺屋町', '41', '41202', '8470053', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '紺屋町', 'コンヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市米屋町', '41', '41202', '8470054', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '米屋町', 'コメヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市刀町', '41', '41202', '8470055', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '刀町', 'カタナマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市坊主町', '41', '41202', '8470056', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '坊主町', 'ボウズマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市材木町', '41', '41202', '8470061', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '材木町', 'ザイモクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市船宮町', '41', '41202', '8470062', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '船宮町', 'フナミヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市東町', '41', '41202', '8470063', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '東町', 'ヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市元石町', '41', '41202', '8470064', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '元石町', 'モトイシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市水主町', '41', '41202', '8470065', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '水主町', 'カコマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市大石町', '41', '41202', '8470066', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '大石町', 'オオイシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市十人町', '41', '41202', '8470067', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '十人町', 'ジュウニンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市和多田海士町', '41', '41202', '8470071', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '和多田海士町', 'ワタダアママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市和多田百人町', '41', '41202', '8470072', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '和多田百人町', 'ワタダヒャクニンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市和多田東百人町', '41', '41202', '8470073', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '和多田東百人町', 'ワタダヒガシヒャクニンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市和多田先石', '41', '41202', '8470074', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '和多田先石', 'ワタダサキイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市和多田用尺', '41', '41202', '8470075', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '和多田用尺', 'ワタダヨウジャク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市和多田南先石', '41', '41202', '8470081', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '和多田南先石', 'ワタダミナミサキイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市和多田天満町', '41', '41202', '8470082', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '和多田天満町', 'ワタダテンマンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市和多田大土井', '41', '41202', '8470083', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '和多田大土井', 'ワタダオオドイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市和多田西山', '41', '41202', '8470084', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '和多田西山', 'ワタダニシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市和多田本村', '41', '41202', '8470085', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '和多田本村', 'ワタダホンムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市中瀬通', '41', '41202', '8470101', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '中瀬通', 'ナカノセドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市八幡町', '41', '41202', '8470102', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '八幡町', 'ヤハタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市橋本町', '41', '41202', '8470103', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '橋本町', 'ハシモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市桜町', '41', '41202', '8470104', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '桜町', 'サクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市佐志', '41', '41202', '8470111', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '佐志', 'サシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市佐志南', '41', '41202', '8470112', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '佐志南', 'サシミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市佐志中里', '41', '41202', '8470113', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '佐志中里', 'サシナカザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市佐志中通', '41', '41202', '8470114', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '佐志中通', 'サシナカドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市佐志浜町', '41', '41202', '8470115', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '佐志浜町', 'サシハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市鳩川', '41', '41202', '8470121', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '鳩川', 'ハトガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市唐房', '41', '41202', '8470122', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '唐房', 'トウボウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市枝去木', '41', '41202', '8470123', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '枝去木', 'エザルギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市浦', '41', '41202', '8470124', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '浦', 'ウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市神集島', '41', '41202', '8470131', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '神集島', 'カシワジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市相賀', '41', '41202', '8470132', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '相賀', 'オウカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市湊町', '41', '41202', '8470133', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '湊町', 'ミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市中里', '41', '41202', '8470134', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '中里', 'ナカザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市屋形石', '41', '41202', '8470135', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '屋形石', 'ヤカタイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市横野', '41', '41202', '8470136', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '横野', 'ヨコノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市呼子町大友', '41', '41202', '8470301', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '呼子町大友', 'ヨブコチョウオオドモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市呼子町小友', '41', '41202', '8470302', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '呼子町小友', 'ヨブコチョウコドモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市呼子町呼子', '41', '41202', '8470303', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '呼子町呼子', 'ヨブコチョウヨブコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市呼子町殿ノ浦', '41', '41202', '8470304', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '呼子町殿ノ浦', 'ヨブコチョウトノノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市呼子町加部島', '41', '41202', '8470305', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '呼子町加部島', 'ヨブコチョウカベシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市呼子町小川島', '41', '41202', '8470306', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '呼子町小川島', 'ヨブコチョウオガワシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市鎮西町丸田', '41', '41202', '8470311', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '鎮西町丸田', 'チンゼイマチマルダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市鎮西町赤木', '41', '41202', '8470312', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '鎮西町赤木', 'チンゼイマチアカギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市鎮西町塩鶴', '41', '41202', '8470313', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '鎮西町塩鶴', 'チンゼイマチシオヅル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市鎮西町菖蒲', '41', '41202', '8470314', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '鎮西町菖蒲', 'チンゼイマチショウブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市鎮西町八床', '41', '41202', '8470315', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '鎮西町八床', 'チンゼイマチヤトコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市鎮西町中野', '41', '41202', '8470316', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '鎮西町中野', 'チンゼイマチナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市鎮西町加唐島', '41', '41202', '8470317', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '鎮西町加唐島', 'チンゼイマチカカラシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市鎮西町横竹', '41', '41202', '8470321', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '鎮西町横竹', 'チンゼイマチヨコタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市鎮西町打上', '41', '41202', '8470322', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '鎮西町打上', 'チンゼイマチウチアゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市鎮西町岩野', '41', '41202', '8470323', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '鎮西町岩野', 'チンゼイマチイワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市鎮西町高野', '41', '41202', '8470324', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '鎮西町高野', 'チンゼイマチコウノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市鎮西町加倉', '41', '41202', '8470325', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '鎮西町加倉', 'チンゼイマチカクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市鎮西町早田', '41', '41202', '8470326', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '鎮西町早田', 'チンゼイマチハヤタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市鎮西町石室', '41', '41202', '8470327', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '鎮西町石室', 'チンゼイマチイシムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市鎮西町名護屋', '41', '41202', '8470401', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '鎮西町名護屋', 'チンゼイマチナゴヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市鎮西町野元', '41', '41202', '8470402', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '鎮西町野元', 'チンゼイマチノモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市鎮西町串', '41', '41202', '8470403', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '鎮西町串', 'チンゼイマチクシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市鎮西町波戸', '41', '41202', '8470404', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '鎮西町波戸', 'チンゼイマチハド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市鎮西町馬渡島', '41', '41202', '8470405', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '鎮西町馬渡島', 'チンゼイマチマダラシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市鎮西町松島', '41', '41202', '8470406', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '鎮西町松島', 'チンゼイマチマツシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市東山', '41', '41202', '8470801', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '東山', 'ヒガシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市梨川内', '41', '41202', '8470802', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '梨川内', 'ナシガワチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市大良', '41', '41202', '8470803', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '大良', 'ダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市後川内', '41', '41202', '8470804', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '後川内', 'ウシロガワチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市八百屋町', '41', '41202', '8470811', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '八百屋町', 'ヤオヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市平野町', '41', '41202', '8470812', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '平野町', 'ヒラノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市新町', '41', '41202', '8470813', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市弓鷹町', '41', '41202', '8470814', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '弓鷹町', 'ユミタカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市西寺町', '41', '41202', '8470815', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '西寺町', 'ニシデラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('107999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市新興町西新興町', '41', '41202', '8470816', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '新興町', 'シンコウマチ', null, null, '西新興町', 'ニシシンコウマチ');
INSERT INTO `ms_addresses` VALUES ('108000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市熊原町', '41', '41202', '8470817', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '熊原町', 'クマノハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市町田', '41', '41202', '8470821', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '町田', 'チョウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市長谷', '41', '41202', '8470822', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '長谷', 'ナガタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市旭が丘', '41', '41202', '8470823', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '旭が丘', 'アサヒガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市神田', '41', '41202', '8470824', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '神田', 'コウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市見借', '41', '41202', '8470825', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '見借', 'ミルカシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市千々賀', '41', '41202', '8470831', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '千々賀', 'チチカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市石志', '41', '41202', '8470832', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '石志', 'イシシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市畑島', '41', '41202', '8470833', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '畑島', 'ハタシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市山田', '41', '41202', '8470834', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '山田', 'ヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市朝日町', '41', '41202', '8470841', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '朝日町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市山下町', '41', '41202', '8470842', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '山下町', 'ヤマシタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市桜馬場', '41', '41202', '8470843', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '桜馬場', 'サクラノババ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市菜畑', '41', '41202', '8470844', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '菜畑', 'ナバタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市富士見町', '41', '41202', '8470851', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '富士見町', 'フジミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市元旗町', '41', '41202', '8470852', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '元旗町', 'モトハタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市江川町', '41', '41202', '8470853', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '江川町', 'エガワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市西旗町', '41', '41202', '8470854', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '西旗町', 'ニシハタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市西浜町', '41', '41202', '8470855', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '西浜町', 'ニシノハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市二タ子', '41', '41202', '8470861', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '二タ子', 'フタゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市中山町', '41', '41202', '8470862', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '中山町', 'ナカヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市妙見町', '41', '41202', '8470863', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '妙見町', 'ミョウケンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市東大島町', '41', '41202', '8470871', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '東大島町', 'ヒガシオオシママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市西大島町', '41', '41202', '8470872', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '西大島町', 'ニシオオシママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市海岸通', '41', '41202', '8470873', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '海岸通', 'カイガンドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市藤崎通', '41', '41202', '8470874', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '藤崎通', 'フジサキドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市西唐津', '41', '41202', '8470875', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '西唐津', 'ニシカラツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市南富士見町', '41', '41202', '8470876', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '南富士見町', 'ミナミフジミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市竹木場', '41', '41202', '8470881', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '竹木場', 'タケコバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市菅牟田', '41', '41202', '8470882', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '菅牟田', 'スガムタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市重河内', '41', '41202', '8470883', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '重河内', 'シゲカワチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市熊ノ峰', '41', '41202', '8470884', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '熊ノ峰', 'クマノミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市唐川', '41', '41202', '8470885', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '唐川', 'トウノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市七山荒川', '41', '41202', '8471101', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '七山荒川', 'ナナヤマアラカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市七山馬川', '41', '41202', '8471102', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '七山馬川', 'ナナヤママノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市七山池原', '41', '41202', '8471103', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '七山池原', 'ナナヤマイケバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市七山木浦', '41', '41202', '8471104', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '七山木浦', 'ナナヤマキウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市七山仁部', '41', '41202', '8471105', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '七山仁部', 'ナナヤマニブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市七山滝川', '41', '41202', '8471106', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '七山滝川', 'ナナヤマタキガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市七山藤川', '41', '41202', '8471107', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '七山藤川', 'ナナヤマフジカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市七山白木', '41', '41202', '8471108', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '七山白木', 'ナナヤマシラキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市北波多徳須恵', '41', '41202', '8471201', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '北波多徳須恵', 'キタハタトクスエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市北波多田中', '41', '41202', '8471202', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '北波多田中', 'キタハタタナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市北波多山彦', '41', '41202', '8471203', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '北波多山彦', 'キタハタヤマヒコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市北波多岸山', '41', '41202', '8471211', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '北波多岸山', 'キタハタキシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市北波多大杉', '41', '41202', '8471212', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '北波多大杉', 'キタハタオオスギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市北波多竹有', '41', '41202', '8471213', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '北波多竹有', 'キタハタタケアリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市北波多稗田', '41', '41202', '8471214', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '北波多稗田', 'キタハタヒエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市北波多上平野', '41', '41202', '8471221', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '北波多上平野', 'キタハタカミヒラノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市北波多成渕', '41', '41202', '8471222', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '北波多成渕', 'キタハタナルフチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市北波多下平野', '41', '41202', '8471223', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '北波多下平野', 'キタハタシモヒラノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市北波多行合野', '41', '41202', '8471224', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '北波多行合野', 'キタハタユキアイノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市北波多志気', '41', '41202', '8471225', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '北波多志気', 'キタハタシゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県東松浦郡玄海町', '41', '41387', '8471400', '佐賀県', 'サガケン', '東松浦郡玄海町', 'ヒガシマツウラグンゲンカイチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('108055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県東松浦郡玄海町小加倉', '41', '41387', '8471401', '佐賀県', 'サガケン', '東松浦郡玄海町', 'ヒガシマツウラグンゲンカイチョウ', '小加倉', 'コガクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県東松浦郡玄海町有浦下', '41', '41387', '8471402', '佐賀県', 'サガケン', '東松浦郡玄海町', 'ヒガシマツウラグンゲンカイチョウ', '有浦下', 'アリウラシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県東松浦郡玄海町有浦上', '41', '41387', '8471403', '佐賀県', 'サガケン', '東松浦郡玄海町', 'ヒガシマツウラグンゲンカイチョウ', '有浦上', 'アリウラカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県東松浦郡玄海町長倉', '41', '41387', '8471404', '佐賀県', 'サガケン', '東松浦郡玄海町', 'ヒガシマツウラグンゲンカイチョウ', '長倉', 'ナガクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県東松浦郡玄海町藤平', '41', '41387', '8471405', '佐賀県', 'サガケン', '東松浦郡玄海町', 'ヒガシマツウラグンゲンカイチョウ', '藤平', 'フジヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県東松浦郡玄海町轟木', '41', '41387', '8471411', '佐賀県', 'サガケン', '東松浦郡玄海町', 'ヒガシマツウラグンゲンカイチョウ', '轟木', 'トドロキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県東松浦郡玄海町田代', '41', '41387', '8471412', '佐賀県', 'サガケン', '東松浦郡玄海町', 'ヒガシマツウラグンゲンカイチョウ', '田代', 'タシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県東松浦郡玄海町大鳥', '41', '41387', '8471413', '佐賀県', 'サガケン', '東松浦郡玄海町', 'ヒガシマツウラグンゲンカイチョウ', '大鳥', 'オオトリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県東松浦郡玄海町湯野尾', '41', '41387', '8471414', '佐賀県', 'サガケン', '東松浦郡玄海町', 'ヒガシマツウラグンゲンカイチョウ', '湯野尾', 'ユノオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県東松浦郡玄海町座川内', '41', '41387', '8471415', '佐賀県', 'サガケン', '東松浦郡玄海町', 'ヒガシマツウラグンゲンカイチョウ', '座川内', 'ソソロガワチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県東松浦郡玄海町牟形', '41', '41387', '8471416', '佐賀県', 'サガケン', '東松浦郡玄海町', 'ヒガシマツウラグンゲンカイチョウ', '牟形', 'ムカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県東松浦郡玄海町諸浦', '41', '41387', '8471421', '佐賀県', 'サガケン', '東松浦郡玄海町', 'ヒガシマツウラグンゲンカイチョウ', '諸浦', 'モロウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県東松浦郡玄海町新田', '41', '41387', '8471422', '佐賀県', 'サガケン', '東松浦郡玄海町', 'ヒガシマツウラグンゲンカイチョウ', '新田', 'シンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県東松浦郡玄海町石田', '41', '41387', '8471423', '佐賀県', 'サガケン', '東松浦郡玄海町', 'ヒガシマツウラグンゲンカイチョウ', '石田', 'イシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県東松浦郡玄海町栄', '41', '41387', '8471424', '佐賀県', 'サガケン', '東松浦郡玄海町', 'ヒガシマツウラグンゲンカイチョウ', '栄', 'サカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県東松浦郡玄海町花の木', '41', '41387', '8471425', '佐賀県', 'サガケン', '東松浦郡玄海町', 'ヒガシマツウラグンゲンカイチョウ', '花の木', 'ハナノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県東松浦郡玄海町普恩寺', '41', '41387', '8471431', '佐賀県', 'サガケン', '東松浦郡玄海町', 'ヒガシマツウラグンゲンカイチョウ', '普恩寺', 'フオンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県東松浦郡玄海町平尾', '41', '41387', '8471432', '佐賀県', 'サガケン', '東松浦郡玄海町', 'ヒガシマツウラグンゲンカイチョウ', '平尾', 'ヒラオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県東松浦郡玄海町浜野浦', '41', '41387', '8471433', '佐賀県', 'サガケン', '東松浦郡玄海町', 'ヒガシマツウラグンゲンカイチョウ', '浜野浦', 'ハマノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県東松浦郡玄海町大薗', '41', '41387', '8471434', '佐賀県', 'サガケン', '東松浦郡玄海町', 'ヒガシマツウラグンゲンカイチョウ', '大薗', 'オオゾノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県東松浦郡玄海町仮屋', '41', '41387', '8471435', '佐賀県', 'サガケン', '東松浦郡玄海町', 'ヒガシマツウラグンゲンカイチョウ', '仮屋', 'カリヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県東松浦郡玄海町今村', '41', '41387', '8471441', '佐賀県', 'サガケン', '東松浦郡玄海町', 'ヒガシマツウラグンゲンカイチョウ', '今村', 'イマムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県東松浦郡玄海町値賀川内', '41', '41387', '8471442', '佐賀県', 'サガケン', '東松浦郡玄海町', 'ヒガシマツウラグンゲンカイチョウ', '値賀川内', 'チカガワチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県東松浦郡玄海町仮立', '41', '41387', '8471443', '佐賀県', 'サガケン', '東松浦郡玄海町', 'ヒガシマツウラグンゲンカイチョウ', '仮立', 'カリダチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県東松浦郡玄海町中通', '41', '41387', '8471444', '佐賀県', 'サガケン', '東松浦郡玄海町', 'ヒガシマツウラグンゲンカイチョウ', '中通', 'ナカドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県東松浦郡玄海町下宮', '41', '41387', '8471445', '佐賀県', 'サガケン', '東松浦郡玄海町', 'ヒガシマツウラグンゲンカイチョウ', '下宮', 'シモミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県東松浦郡玄海町外津', '41', '41387', '8471446', '佐賀県', 'サガケン', '東松浦郡玄海町', 'ヒガシマツウラグンゲンカイチョウ', '外津', 'ホカワヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市肥前町切木', '41', '41202', '8471501', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '肥前町切木', 'ヒゼンマチキリゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市肥前町赤坂', '41', '41202', '8471502', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '肥前町赤坂', 'ヒゼンマチアカサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市肥前町湯野浦', '41', '41202', '8471503', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '肥前町湯野浦', 'ヒゼンマチユノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市肥前町中浦', '41', '41202', '8471504', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '肥前町中浦', 'ヒゼンマチナカウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市肥前町杉野浦', '41', '41202', '8471505', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '肥前町杉野浦', 'ヒゼンマチスギノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市肥前町大浦', '41', '41202', '8471506', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '肥前町大浦', 'ヒゼンマチオオウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市肥前町満越', '41', '41202', '8471507', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '肥前町満越', 'ヒゼンマチミツコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市肥前町新木場', '41', '41202', '8471511', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '肥前町新木場', 'ヒゼンマチニイコバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市肥前町梅崎', '41', '41202', '8471512', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '肥前町梅崎', 'ヒゼンマチウメザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市肥前町寺浦', '41', '41202', '8471513', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '肥前町寺浦', 'ヒゼンマチテラウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市肥前町仁田野尾', '41', '41202', '8471514', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '肥前町仁田野尾', 'ヒゼンマチニタノオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市肥前町万賀里川', '41', '41202', '8471515', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '肥前町万賀里川', 'ヒゼンマチマガリカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市肥前町瓜ケ坂', '41', '41202', '8471516', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '肥前町瓜ケ坂', 'ヒゼンマチウリガサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市肥前町上ケ倉', '41', '41202', '8471517', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '肥前町上ケ倉', 'ヒゼンマチアゲクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市肥前町田野', '41', '41202', '8471521', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '肥前町田野', 'ヒゼンマチタノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市肥前町犬頭', '41', '41202', '8471522', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '肥前町犬頭', 'ヒゼンマチイヌガシラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市肥前町星賀', '41', '41202', '8471523', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '肥前町星賀', 'ヒゼンマチホシカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市肥前町向島', '41', '41202', '8471524', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '肥前町向島', 'ヒゼンマチムクシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市肥前町納所', '41', '41202', '8471525', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '肥前町納所', 'ヒゼンマチノウサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市肥前町入野', '41', '41202', '8471526', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '肥前町入野', 'ヒゼンマチイリノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市肥前町鶴牧', '41', '41202', '8471527', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '肥前町鶴牧', 'ヒゼンマチツルマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県伊万里市', '41', '41205', '8480000', '佐賀県', 'サガケン', '伊万里市', 'イマリシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('108108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県伊万里市南波多町重橋', '41', '41205', '8480001', '佐賀県', 'サガケン', '伊万里市', 'イマリシ', '南波多町重橋', 'ミナミハタチョウジュウバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県伊万里市南波多町谷口', '41', '41205', '8480002', '佐賀県', 'サガケン', '伊万里市', 'イマリシ', '南波多町谷口', 'ミナミハタチョウタニグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県伊万里市南波多町古里', '41', '41205', '8480003', '佐賀県', 'サガケン', '伊万里市', 'イマリシ', '南波多町古里', 'ミナミハタチョウフルサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県伊万里市南波多町水留', '41', '41205', '8480004', '佐賀県', 'サガケン', '伊万里市', 'イマリシ', '南波多町水留', 'ミナミハタチョウツヅミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県伊万里市南波多町大曲', '41', '41205', '8480005', '佐賀県', 'サガケン', '伊万里市', 'イマリシ', '南波多町大曲', 'ミナミハタチョウオオマガリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県伊万里市南波多町高瀬', '41', '41205', '8480006', '佐賀県', 'サガケン', '伊万里市', 'イマリシ', '南波多町高瀬', 'ミナミハタチョウタカゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県伊万里市南波多町井手野', '41', '41205', '8480007', '佐賀県', 'サガケン', '伊万里市', 'イマリシ', '南波多町井手野', 'ミナミハタチョウイデノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県伊万里市南波多町大川原', '41', '41205', '8480011', '佐賀県', 'サガケン', '伊万里市', 'イマリシ', '南波多町大川原', 'ミナミハタチョウオオカワバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県伊万里市南波多町古川', '41', '41205', '8480012', '佐賀県', 'サガケン', '伊万里市', 'イマリシ', '南波多町古川', 'ミナミハタチョウフルコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県伊万里市南波多町笠椎', '41', '41205', '8480013', '佐賀県', 'サガケン', '伊万里市', 'イマリシ', '南波多町笠椎', 'ミナミハタチョウカサジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県伊万里市南波多町小麦原', '41', '41205', '8480014', '佐賀県', 'サガケン', '伊万里市', 'イマリシ', '南波多町小麦原', 'ミナミハタチョウコムギハル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県伊万里市南波多町府招', '41', '41205', '8480015', '佐賀県', 'サガケン', '伊万里市', 'イマリシ', '南波多町府招', 'ミナミハタチョウフマネキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県伊万里市南波多町原屋敷', '41', '41205', '8480016', '佐賀県', 'サガケン', '伊万里市', 'イマリシ', '南波多町原屋敷', 'ミナミハタチョウハラヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県伊万里市大坪町甲', '41', '41205', '8480021', '佐賀県', 'サガケン', '伊万里市', 'イマリシ', '大坪町甲', 'オオツボチョウコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県伊万里市大坪町乙', '41', '41205', '8480022', '佐賀県', 'サガケン', '伊万里市', 'イマリシ', '大坪町乙', 'オオツボチョウオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県伊万里市大坪町丙', '41', '41205', '8480023', '佐賀県', 'サガケン', '伊万里市', 'イマリシ', '大坪町丙', 'オオツボチョウヘイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県伊万里市大川内町甲', '41', '41205', '8480024', '佐賀県', 'サガケン', '伊万里市', 'イマリシ', '大川内町甲', 'オオカワチチョウコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県伊万里市大川内町乙', '41', '41205', '8480025', '佐賀県', 'サガケン', '伊万里市', 'イマリシ', '大川内町乙', 'オオカワチチョウオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県伊万里市大川内町丙', '41', '41205', '8480026', '佐賀県', 'サガケン', '伊万里市', 'イマリシ', '大川内町丙', 'オオカワチチョウヘイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県伊万里市立花町', '41', '41205', '8480027', '佐賀県', 'サガケン', '伊万里市', 'イマリシ', '立花町', 'タチバナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県伊万里市脇田町', '41', '41205', '8480028', '佐賀県', 'サガケン', '伊万里市', 'イマリシ', '脇田町', 'ワキダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県伊万里市二里町八谷搦', '41', '41205', '8480031', '佐賀県', 'サガケン', '伊万里市', 'イマリシ', '二里町八谷搦', 'ニリチョウハチヤガラミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県伊万里市二里町大里甲', '41', '41205', '8480032', '佐賀県', 'サガケン', '伊万里市', 'イマリシ', '二里町大里甲', 'ニリチョウオオザトコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県伊万里市二里町中里乙', '41', '41205', '8480033', '佐賀県', 'サガケン', '伊万里市', 'イマリシ', '二里町中里乙', 'ニリチョウナカザトオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県伊万里市二里町中里甲', '41', '41205', '8480034', '佐賀県', 'サガケン', '伊万里市', 'イマリシ', '二里町中里甲', 'ニリチョウナカザトコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県伊万里市二里町大里乙', '41', '41205', '8480035', '佐賀県', 'サガケン', '伊万里市', 'イマリシ', '二里町大里乙', 'ニリチョウオオザトオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県伊万里市新天町', '41', '41205', '8480041', '佐賀県', 'サガケン', '伊万里市', 'イマリシ', '新天町', 'シンテンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県伊万里市蓮池町', '41', '41205', '8480042', '佐賀県', 'サガケン', '伊万里市', 'イマリシ', '蓮池町', 'ハスイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県伊万里市瀬戸町', '41', '41205', '8480043', '佐賀県', 'サガケン', '伊万里市', 'イマリシ', '瀬戸町', 'セトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県伊万里市木須町', '41', '41205', '8480044', '佐賀県', 'サガケン', '伊万里市', 'イマリシ', '木須町', 'キスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県伊万里市松島町', '41', '41205', '8480045', '佐賀県', 'サガケン', '伊万里市', 'イマリシ', '松島町', 'マツシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県伊万里市伊万里町乙', '41', '41205', '8480046', '佐賀県', 'サガケン', '伊万里市', 'イマリシ', '伊万里町乙', 'イマリチョウオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県伊万里市伊万里町甲', '41', '41205', '8480047', '佐賀県', 'サガケン', '伊万里市', 'イマリシ', '伊万里町甲', 'イマリチョウコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県伊万里市波多津町辻', '41', '41205', '8480101', '佐賀県', 'サガケン', '伊万里市', 'イマリシ', '波多津町辻', 'ハタツチョウツジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県伊万里市波多津町畑津', '41', '41205', '8480102', '佐賀県', 'サガケン', '伊万里市', 'イマリシ', '波多津町畑津', 'ハタツチョウハタツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県伊万里市波多津町内野', '41', '41205', '8480103', '佐賀県', 'サガケン', '伊万里市', 'イマリシ', '波多津町内野', 'ハタツチョウウチノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県伊万里市波多津町煤屋', '41', '41205', '8480104', '佐賀県', 'サガケン', '伊万里市', 'イマリシ', '波多津町煤屋', 'ハタツチョウススヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県伊万里市波多津町馬蛤潟', '41', '41205', '8480105', '佐賀県', 'サガケン', '伊万里市', 'イマリシ', '波多津町馬蛤潟', 'ハタツチョウマテガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県伊万里市波多津町木場', '41', '41205', '8480111', '佐賀県', 'サガケン', '伊万里市', 'イマリシ', '波多津町木場', 'ハタツチョウコバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県伊万里市波多津町田代', '41', '41205', '8480112', '佐賀県', 'サガケン', '伊万里市', 'イマリシ', '波多津町田代', 'ハタツチョウタシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県伊万里市波多津町板木', '41', '41205', '8480113', '佐賀県', 'サガケン', '伊万里市', 'イマリシ', '波多津町板木', 'ハタツチョウイタギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県伊万里市波多津町津留主屋', '41', '41205', '8480114', '佐賀県', 'サガケン', '伊万里市', 'イマリシ', '波多津町津留主屋', 'ハタツチョウツルヌシヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県伊万里市波多津町中山', '41', '41205', '8480115', '佐賀県', 'サガケン', '伊万里市', 'イマリシ', '波多津町中山', 'ハタツチョウナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県伊万里市波多津町井野尾', '41', '41205', '8480116', '佐賀県', 'サガケン', '伊万里市', 'イマリシ', '波多津町井野尾', 'ハタツチョウイノオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県伊万里市波多津町筒井', '41', '41205', '8480117', '佐賀県', 'サガケン', '伊万里市', 'イマリシ', '波多津町筒井', 'ハタツチョウツツイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県伊万里市黒川町塩屋', '41', '41205', '8480121', '佐賀県', 'サガケン', '伊万里市', 'イマリシ', '黒川町塩屋', 'クロガワチョウシオヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県伊万里市黒川町福田', '41', '41205', '8480122', '佐賀県', 'サガケン', '伊万里市', 'イマリシ', '黒川町福田', 'クロガワチョウフクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県伊万里市黒川町大黒川', '41', '41205', '8480123', '佐賀県', 'サガケン', '伊万里市', 'イマリシ', '黒川町大黒川', 'クロガワチョウオオクロガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県伊万里市黒川町名村団地', '41', '41205', '8480124', '佐賀県', 'サガケン', '伊万里市', 'イマリシ', '黒川町', 'クロガワチョウ', null, null, '名村団地', 'ナムラダンチ');
INSERT INTO `ms_addresses` VALUES ('108157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県伊万里市黒川町小黒川', '41', '41205', '8480125', '佐賀県', 'サガケン', '伊万里市', 'イマリシ', '黒川町小黒川', 'クロガワチョウコクロガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県伊万里市黒川町畑川内', '41', '41205', '8480131', '佐賀県', 'サガケン', '伊万里市', 'イマリシ', '黒川町畑川内', 'クロガワチョウハタガワチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県伊万里市黒川町長尾', '41', '41205', '8480132', '佐賀県', 'サガケン', '伊万里市', 'イマリシ', '黒川町長尾', 'クロガワチョウナガオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県伊万里市黒川町真手野', '41', '41205', '8480133', '佐賀県', 'サガケン', '伊万里市', 'イマリシ', '黒川町真手野', 'クロガワチョウマテノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県伊万里市黒川町花房', '41', '41205', '8480134', '佐賀県', 'サガケン', '伊万里市', 'イマリシ', '黒川町花房', 'クロガワチョウハナブサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県伊万里市黒川町清水', '41', '41205', '8480141', '佐賀県', 'サガケン', '伊万里市', 'イマリシ', '黒川町清水', 'クロガワチョウシミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県伊万里市黒川町立目', '41', '41205', '8480142', '佐賀県', 'サガケン', '伊万里市', 'イマリシ', '黒川町立目', 'クロガワチョウタチメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県伊万里市黒川町牟田', '41', '41205', '8480143', '佐賀県', 'サガケン', '伊万里市', 'イマリシ', '黒川町牟田', 'クロガワチョウムタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県伊万里市黒川町横野', '41', '41205', '8480144', '佐賀県', 'サガケン', '伊万里市', 'イマリシ', '黒川町横野', 'クロガワチョウヨコノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県伊万里市黒川町椿原', '41', '41205', '8480145', '佐賀県', 'サガケン', '伊万里市', 'イマリシ', '黒川町椿原', 'クロガワチョウツバキハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県伊万里市黒川町黒塩', '41', '41205', '8480146', '佐賀県', 'サガケン', '伊万里市', 'イマリシ', '黒川町黒塩', 'クロガワチョウクロシオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県松浦市福島町喜内瀬免', '42', '42208', '8480401', '長崎県', 'ナガサキケン', '松浦市', 'マツウラシ', '福島町喜内瀬免', 'フクシマチョウキナイセメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県松浦市福島町端免', '42', '42208', '8480402', '長崎県', 'ナガサキケン', '松浦市', 'マツウラシ', '福島町端免', 'フクシマチョウハシメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県松浦市福島町塩浜免', '42', '42208', '8480403', '長崎県', 'ナガサキケン', '松浦市', 'マツウラシ', '福島町塩浜免', 'フクシマチョウシオハマメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県松浦市福島町浅谷免', '42', '42208', '8480404', '長崎県', 'ナガサキケン', '松浦市', 'マツウラシ', '福島町浅谷免', 'フクシマチョウアサガイメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県松浦市福島町土谷免', '42', '42208', '8480405', '長崎県', 'ナガサキケン', '松浦市', 'マツウラシ', '福島町土谷免', 'フクシマチョウドヤメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県松浦市福島町原免', '42', '42208', '8480406', '長崎県', 'ナガサキケン', '松浦市', 'マツウラシ', '福島町原免', 'フクシマチョウハルメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県松浦市福島町鍋串免', '42', '42208', '8480407', '長崎県', 'ナガサキケン', '松浦市', 'マツウラシ', '福島町鍋串免', 'フクシマチョウナベグシメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県松浦市福島町里免', '42', '42208', '8480408', '長崎県', 'ナガサキケン', '松浦市', 'マツウラシ', '福島町里免', 'フクシマチョウサトメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市', '41', '41201', '8490000', '佐賀県', 'サガケン', '佐賀市', 'サガシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('108186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県三養基郡上峰町', '41', '41345', '8490100', '佐賀県', 'サガケン', '三養基郡上峰町', 'ミヤキグンカミミネチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('108187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県三養基郡みやき町', '41', '41346', '8490100', '佐賀県', 'サガケン', '三養基郡みやき町', 'ミヤキグンミヤキチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('108188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県三養基郡みやき町原古賀', '41', '41346', '8490101', '佐賀県', 'サガケン', '三養基郡みやき町', 'ミヤキグンミヤキチョウ', '原古賀', 'ハルコガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県三養基郡みやき町簑原', '41', '41346', '8490102', '佐賀県', 'サガケン', '三養基郡みやき町', 'ミヤキグンミヤキチョウ', '簑原', 'ミノバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県三養基郡みやき町白壁', '41', '41346', '8490111', '佐賀県', 'サガケン', '三養基郡みやき町', 'ミヤキグンミヤキチョウ', '白壁', 'シラカベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県三養基郡みやき町江口', '41', '41346', '8490112', '佐賀県', 'サガケン', '三養基郡みやき町', 'ミヤキグンミヤキチョウ', '江口', 'エグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県三養基郡みやき町東尾', '41', '41346', '8490113', '佐賀県', 'サガケン', '三養基郡みやき町', 'ミヤキグンミヤキチョウ', '東尾', 'ヒガシオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県三養基郡みやき町中津隈', '41', '41346', '8490114', '佐賀県', 'サガケン', '三養基郡みやき町', 'ミヤキグンミヤキチョウ', '中津隈', 'ナカツクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県三養基郡上峰町江迎', '41', '41345', '8490121', '佐賀県', 'サガケン', '三養基郡上峰町', 'ミヤキグンカミミネチョウ', '江迎', 'エムカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県三養基郡上峰町前牟田', '41', '41345', '8490122', '佐賀県', 'サガケン', '三養基郡上峰町', 'ミヤキグンカミミネチョウ', '前牟田', 'マエムタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県三養基郡上峰町坊所', '41', '41345', '8490123', '佐賀県', 'サガケン', '三養基郡上峰町', 'ミヤキグンカミミネチョウ', '坊所', 'ボウジョ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県三養基郡上峰町堤', '41', '41345', '8490124', '佐賀県', 'サガケン', '三養基郡上峰町', 'ミヤキグンカミミネチョウ', '堤', 'ツツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市久保田町徳万', '41', '41201', '8490201', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '久保田町徳万', 'クボタチョウトクマン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市久保田町久富', '41', '41201', '8490202', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '久保田町久富', 'クボタチョウヒサドミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市久保田町新田', '41', '41201', '8490203', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '久保田町新田', 'クボタチョウシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市久保田町久保田', '41', '41201', '8490204', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '久保田町久保田', 'クボタチョウクボタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市久保田町江戸', '41', '41201', '8490205', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '久保田町江戸', 'クボタチョウエド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県小城市牛津町乙柳', '41', '41208', '8490301', '佐賀県', 'サガケン', '小城市', 'オギシ', '牛津町乙柳', 'ウシヅチョウオトヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県小城市牛津町柿樋瀬', '41', '41208', '8490302', '佐賀県', 'サガケン', '小城市', 'オギシ', '牛津町柿樋瀬', 'ウシヅチョウカキヒセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県小城市牛津町牛津', '41', '41208', '8490303', '佐賀県', 'サガケン', '小城市', 'オギシ', '牛津町牛津', 'ウシヅチョウウシヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県小城市牛津町下砥川', '41', '41208', '8490304', '佐賀県', 'サガケン', '小城市', 'オギシ', '牛津町下砥川', 'ウシヅチョウシモトガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県小城市牛津町上砥川', '41', '41208', '8490305', '佐賀県', 'サガケン', '小城市', 'オギシ', '牛津町上砥川', 'ウシヅチョウカミトガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県小城市牛津町勝', '41', '41208', '8490306', '佐賀県', 'サガケン', '小城市', 'オギシ', '牛津町勝', 'ウシヅチョウカツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県小城市芦刈町芦溝', '41', '41208', '8490311', '佐賀県', 'サガケン', '小城市', 'オギシ', '芦刈町芦溝', 'アシカリチョウアシミゾ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県小城市芦刈町下古賀', '41', '41208', '8490312', '佐賀県', 'サガケン', '小城市', 'オギシ', '芦刈町下古賀', 'アシカリチョウシモコガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県小城市芦刈町永田', '41', '41208', '8490313', '佐賀県', 'サガケン', '小城市', 'オギシ', '芦刈町永田', 'アシカリチョウナガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県小城市芦刈町三王崎', '41', '41208', '8490314', '佐賀県', 'サガケン', '小城市', 'オギシ', '芦刈町三王崎', 'アシカリチョウミオウザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県小城市芦刈町浜枝川', '41', '41208', '8490315', '佐賀県', 'サガケン', '小城市', 'オギシ', '芦刈町浜枝川', 'アシカリチョウハマエダガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県小城市芦刈町道免', '41', '41208', '8490316', '佐賀県', 'サガケン', '小城市', 'オギシ', '芦刈町道免', 'アシカリチョウドウメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県杵島郡白石町福富', '41', '41425', '8490401', '佐賀県', 'サガケン', '杵島郡白石町', 'キシマグンシロイシチョウ', '福富', 'フクドミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県杵島郡白石町福富下分', '41', '41425', '8490402', '佐賀県', 'サガケン', '杵島郡白石町', 'キシマグンシロイシチョウ', '福富下分', 'フクドミシモブン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県杵島郡白石町八平', '41', '41425', '8490403', '佐賀県', 'サガケン', '杵島郡白石町', 'キシマグンシロイシチョウ', '八平', 'ハチヘイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県杵島郡江北町', '41', '41424', '8490500', '佐賀県', 'サガケン', '杵島郡江北町', 'キシマグンコウホクマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('108219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県杵島郡江北町山口', '41', '41424', '8490501', '佐賀県', 'サガケン', '杵島郡江北町', 'キシマグンコウホクマチ', '山口', 'ヤマグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県杵島郡江北町佐留志', '41', '41424', '8490502', '佐賀県', 'サガケン', '杵島郡江北町', 'キシマグンコウホクマチ', '佐留志', 'サルシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県杵島郡江北町惣領分', '41', '41424', '8490503', '佐賀県', 'サガケン', '杵島郡江北町', 'キシマグンコウホクマチ', '惣領分', 'ソウリョウブン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県杵島郡江北町八町', '41', '41424', '8490504', '佐賀県', 'サガケン', '杵島郡江北町', 'キシマグンコウホクマチ', '八町', 'ハッチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県杵島郡江北町下小田', '41', '41424', '8490505', '佐賀県', 'サガケン', '杵島郡江北町', 'キシマグンコウホクマチ', '下小田', 'シモオダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県杵島郡江北町上小田', '41', '41424', '8490506', '佐賀県', 'サガケン', '杵島郡江北町', 'キシマグンコウホクマチ', '上小田', 'カミオダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市久保泉町川久保', '41', '41201', '8490901', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '久保泉町川久保', 'クボイズミマチカワクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市久保泉町上和泉', '41', '41201', '8490902', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '久保泉町上和泉', 'クボイズミマチカミイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市久保泉町下和泉', '41', '41201', '8490903', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '久保泉町下和泉', 'クボイズミマチシモイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市金立町薬師丸', '41', '41201', '8490904', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '金立町薬師丸', 'キンリュウマチヤクシマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市金立町千布', '41', '41201', '8490905', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '金立町千布', 'キンリュウマチチフ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市金立町金立', '41', '41201', '8490906', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '金立町金立', 'キンリュウマチキンリュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市兵庫町若宮', '41', '41201', '8490911', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '兵庫町若宮', 'ヒョウゴマチワカミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市兵庫町瓦町', '41', '41201', '8490912', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '兵庫町瓦町', 'ヒョウゴマチカワラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市兵庫町渕', '41', '41201', '8490913', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '兵庫町渕', 'ヒョウゴマチフチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市兵庫町西渕', '41', '41201', '8490914', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '兵庫町西渕', 'ヒョウゴマチニシブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市兵庫町藤木', '41', '41201', '8490915', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '兵庫町藤木', 'ヒョウゴマチフジノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市高木瀬町東高木', '41', '41201', '8490916', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '高木瀬町東高木', 'タカギセマチヒガシタカギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市高木瀬町長瀬', '41', '41201', '8490917', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '高木瀬町長瀬', 'タカギセマチナガセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市兵庫南', '41', '41201', '8490918', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '兵庫南', 'ヒョウゴミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市高木瀬西', '41', '41201', '8490921', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '高木瀬西', 'タカギセニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市高木瀬東', '41', '41201', '8490922', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '高木瀬東', 'タカギセヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市日の出', '41', '41201', '8490923', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '日の出', 'ヒノデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市新中町', '41', '41201', '8490924', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '新中町', 'シンナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市八丁畷町', '41', '41201', '8490925', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '八丁畷町', 'ハッチョウナワテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市若宮', '41', '41201', '8490926', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '若宮', 'ワカミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市高木瀬団地', '41', '41201', '8490927', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '高木瀬団地', 'タカギセダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市若楠', '41', '41201', '8490928', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '若楠', 'ワカクス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市鍋島町蛎久', '41', '41201', '8490931', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '鍋島町蛎久', 'ナベシママチカキヒサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市鍋島町八戸溝', '41', '41201', '8490932', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '鍋島町八戸溝', 'ナベシママチヤエミゾ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市卸本町', '41', '41201', '8490933', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '卸本町', 'オロシホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市開成', '41', '41201', '8490934', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '開成', 'カイセイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市八戸溝', '41', '41201', '8490935', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '八戸溝', 'ヤエミゾ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市鍋島町森田', '41', '41201', '8490936', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '鍋島町森田', 'ナベシママチモリタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市鍋島', '41', '41201', '8490937', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '鍋島', 'ナベシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県佐賀市鍋島町鍋島', '41', '41201', '8490938', '佐賀県', 'サガケン', '佐賀市', 'サガシ', '鍋島町鍋島', 'ナベシママチナベシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県杵島郡白石町', '41', '41425', '8491100', '佐賀県', 'サガケン', '杵島郡白石町', 'キシマグンシロイシチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('108258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県杵島郡白石町今泉', '41', '41425', '8491101', '佐賀県', 'サガケン', '杵島郡白石町', 'キシマグンシロイシチョウ', '今泉', 'イマイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県杵島郡白石町大渡', '41', '41425', '8491102', '佐賀県', 'サガケン', '杵島郡白石町', 'キシマグンシロイシチョウ', '大渡', 'オオワタリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県杵島郡白石町築切', '41', '41425', '8491103', '佐賀県', 'サガケン', '杵島郡白石町', 'キシマグンシロイシチョウ', '築切', 'ツイキリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県杵島郡白石町堤', '41', '41425', '8491104', '佐賀県', 'サガケン', '杵島郡白石町', 'キシマグンシロイシチョウ', '堤', 'ツツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県杵島郡白石町遠江', '41', '41425', '8491105', '佐賀県', 'サガケン', '杵島郡白石町', 'キシマグンシロイシチョウ', '遠江', 'トオノエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県杵島郡白石町廿治', '41', '41425', '8491106', '佐賀県', 'サガケン', '杵島郡白石町', 'キシマグンシロイシチョウ', '廿治', 'ハタチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県杵島郡白石町東郷', '41', '41425', '8491111', '佐賀県', 'サガケン', '杵島郡白石町', 'キシマグンシロイシチョウ', '東郷', 'ヒガシゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県杵島郡白石町福田', '41', '41425', '8491112', '佐賀県', 'サガケン', '杵島郡白石町', 'キシマグンシロイシチョウ', '福田', 'フクタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県杵島郡白石町福吉', '41', '41425', '8491113', '佐賀県', 'サガケン', '杵島郡白石町', 'キシマグンシロイシチョウ', '福吉', 'フクヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県杵島郡白石町馬洗', '41', '41425', '8491114', '佐賀県', 'サガケン', '杵島郡白石町', 'キシマグンシロイシチョウ', '馬洗', 'モウライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県杵島郡白石町湯崎', '41', '41425', '8491115', '佐賀県', 'サガケン', '杵島郡白石町', 'キシマグンシロイシチョウ', '湯崎', 'ユザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県杵島郡白石町横手', '41', '41425', '8491116', '佐賀県', 'サガケン', '杵島郡白石町', 'キシマグンシロイシチョウ', '横手', 'ヨコテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県杵島郡白石町牛屋', '41', '41425', '8491201', '佐賀県', 'サガケン', '杵島郡白石町', 'キシマグンシロイシチョウ', '牛屋', 'ウシヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県杵島郡白石町新明', '41', '41425', '8491202', '佐賀県', 'サガケン', '杵島郡白石町', 'キシマグンシロイシチョウ', '新明', 'シンメイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県杵島郡白石町戸ケ里', '41', '41425', '8491203', '佐賀県', 'サガケン', '杵島郡白石町', 'キシマグンシロイシチョウ', '戸ケ里', 'トガリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県杵島郡白石町坂田', '41', '41425', '8491204', '佐賀県', 'サガケン', '杵島郡白石町', 'キシマグンシロイシチョウ', '坂田', 'サカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県杵島郡白石町田野上', '41', '41425', '8491205', '佐賀県', 'サガケン', '杵島郡白石町', 'キシマグンシロイシチョウ', '田野上', 'タノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県杵島郡白石町辺田', '41', '41425', '8491206', '佐賀県', 'サガケン', '杵島郡白石町', 'キシマグンシロイシチョウ', '辺田', 'ヘタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県杵島郡白石町深浦', '41', '41425', '8491207', '佐賀県', 'サガケン', '杵島郡白石町', 'キシマグンシロイシチョウ', '深浦', 'フカウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県杵島郡白石町新開', '41', '41425', '8491208', '佐賀県', 'サガケン', '杵島郡白石町', 'キシマグンシロイシチョウ', '新開', 'シンカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県杵島郡白石町新拓', '41', '41425', '8491221', '佐賀県', 'サガケン', '杵島郡白石町', 'キシマグンシロイシチョウ', '新拓', 'シンタク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県鹿島市', '41', '41207', '8491300', '佐賀県', 'サガケン', '鹿島市', 'カシマシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('108282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県鹿島市常広', '41', '41207', '8491301', '佐賀県', 'サガケン', '鹿島市', 'カシマシ', '常広', 'ツネヒロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県鹿島市井手', '41', '41207', '8491302', '佐賀県', 'サガケン', '鹿島市', 'カシマシ', '井手', 'イデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県鹿島市森', '41', '41207', '8491303', '佐賀県', 'サガケン', '鹿島市', 'カシマシ', '森', 'モリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県鹿島市中村', '41', '41207', '8491304', '佐賀県', 'サガケン', '鹿島市', 'カシマシ', '中村', 'ナカムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県鹿島市高津原', '41', '41207', '8491311', '佐賀県', 'サガケン', '鹿島市', 'カシマシ', '高津原', 'タカツハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県鹿島市納富分', '41', '41207', '8491312', '佐賀県', 'サガケン', '鹿島市', 'カシマシ', '納富分', 'ノウドミブン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県鹿島市重ノ木', '41', '41207', '8491313', '佐賀県', 'サガケン', '鹿島市', 'カシマシ', '重ノ木', 'ジュウノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県鹿島市山浦', '41', '41207', '8491314', '佐賀県', 'サガケン', '鹿島市', 'カシマシ', '山浦', 'ヤマウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県鹿島市三河内', '41', '41207', '8491315', '佐賀県', 'サガケン', '鹿島市', 'カシマシ', '三河内', 'ミカワチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県鹿島市古枝', '41', '41207', '8491321', '佐賀県', 'サガケン', '鹿島市', 'カシマシ', '古枝', 'フルエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県鹿島市浜町', '41', '41207', '8491322', '佐賀県', 'サガケン', '鹿島市', 'カシマシ', '浜町', 'ハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県鹿島市音成', '41', '41207', '8491323', '佐賀県', 'サガケン', '鹿島市', 'カシマシ', '音成', 'オトナリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県鹿島市飯田', '41', '41207', '8491324', '佐賀県', 'サガケン', '鹿島市', 'カシマシ', '飯田', 'イイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県嬉野市塩田町久間甲', '41', '41209', '8491401', '佐賀県', 'サガケン', '嬉野市', 'ウレシノシ', '塩田町久間甲', 'シオタチョウクマコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県嬉野市塩田町久間乙', '41', '41209', '8491402', '佐賀県', 'サガケン', '嬉野市', 'ウレシノシ', '塩田町久間乙', 'シオタチョウクマオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県嬉野市塩田町久間丙', '41', '41209', '8491403', '佐賀県', 'サガケン', '嬉野市', 'ウレシノシ', '塩田町久間丙', 'シオタチョウクマヘイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県嬉野市塩田町久間丁', '41', '41209', '8491404', '佐賀県', 'サガケン', '嬉野市', 'ウレシノシ', '塩田町久間丁', 'シオタチョウクマテイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県嬉野市塩田町馬場下甲', '41', '41209', '8491411', '佐賀県', 'サガケン', '嬉野市', 'ウレシノシ', '塩田町馬場下甲', 'シオタチョウババシタコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県嬉野市塩田町馬場下乙', '41', '41209', '8491412', '佐賀県', 'サガケン', '嬉野市', 'ウレシノシ', '塩田町馬場下乙', 'シオタチョウババシタオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県嬉野市塩田町馬場下丙', '41', '41209', '8491413', '佐賀県', 'サガケン', '嬉野市', 'ウレシノシ', '塩田町馬場下丙', 'シオタチョウババシタヘイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県嬉野市塩田町大草野甲', '41', '41209', '8491414', '佐賀県', 'サガケン', '嬉野市', 'ウレシノシ', '塩田町大草野甲', 'シオタチョウオオクサノコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県嬉野市塩田町大草野丙', '41', '41209', '8491415', '佐賀県', 'サガケン', '嬉野市', 'ウレシノシ', '塩田町大草野丙', 'シオタチョウオオクサノヘイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県嬉野市塩田町大草野乙', '41', '41209', '8491416', '佐賀県', 'サガケン', '嬉野市', 'ウレシノシ', '塩田町大草野乙', 'シオタチョウオオクサノオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県嬉野市塩田町真崎', '41', '41209', '8491421', '佐賀県', 'サガケン', '嬉野市', 'ウレシノシ', '塩田町真崎', 'シオタチョウマツサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県嬉野市塩田町谷所甲', '41', '41209', '8491422', '佐賀県', 'サガケン', '嬉野市', 'ウレシノシ', '塩田町谷所甲', 'シオタチョウタニドコロコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県嬉野市塩田町谷所乙', '41', '41209', '8491423', '佐賀県', 'サガケン', '嬉野市', 'ウレシノシ', '塩田町谷所乙', 'シオタチョウタニドコロオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県嬉野市塩田町谷所丙', '41', '41209', '8491424', '佐賀県', 'サガケン', '嬉野市', 'ウレシノシ', '塩田町谷所丙', 'シオタチョウタニドコロヘイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県嬉野市塩田町五町田甲', '41', '41209', '8491425', '佐賀県', 'サガケン', '嬉野市', 'ウレシノシ', '塩田町五町田甲', 'シオタチョウゴチョウダコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県嬉野市塩田町五町田乙', '41', '41209', '8491426', '佐賀県', 'サガケン', '嬉野市', 'ウレシノシ', '塩田町五町田乙', 'シオタチョウゴチョウダオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県藤津郡太良町', '41', '41441', '8491600', '佐賀県', 'サガケン', '藤津郡太良町', 'フジツグンタラチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('108315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県藤津郡太良町伊福甲', '41', '41441', '8491601', '佐賀県', 'サガケン', '藤津郡太良町', 'フジツグンタラチョウ', '伊福甲', 'イフクコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県藤津郡太良町多良', '41', '41441', '8491602', '佐賀県', 'サガケン', '藤津郡太良町', 'フジツグンタラチョウ', '多良', 'タラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県藤津郡太良町糸岐', '41', '41441', '8491603', '佐賀県', 'サガケン', '藤津郡太良町', 'フジツグンタラチョウ', '糸岐', 'イトキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県藤津郡太良町大浦戊', '41', '41441', '8491611', '佐賀県', 'サガケン', '藤津郡太良町', 'フジツグンタラチョウ', '大浦戊', 'オオウラボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県藤津郡太良町大浦丁', '41', '41441', '8491612', '佐賀県', 'サガケン', '藤津郡太良町', 'フジツグンタラチョウ', '大浦丁', 'オオウラテイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県藤津郡太良町大浦丙', '41', '41441', '8491613', '佐賀県', 'サガケン', '藤津郡太良町', 'フジツグンタラチョウ', '大浦丙', 'オオウラヘイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県藤津郡太良町大浦甲', '41', '41441', '8491614', '佐賀県', 'サガケン', '藤津郡太良町', 'フジツグンタラチョウ', '大浦甲', 'オオウラコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県藤津郡太良町大浦乙', '41', '41441', '8491615', '佐賀県', 'サガケン', '藤津郡太良町', 'フジツグンタラチョウ', '大浦乙', 'オオウラオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県藤津郡太良町大浦己', '41', '41441', '8491616', '佐賀県', 'サガケン', '藤津郡太良町', 'フジツグンタラチョウ', '大浦己', 'オオウラキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県杵島郡大町町', '41', '41423', '8492100', '佐賀県', 'サガケン', '杵島郡大町町', 'キシマグンオオマチチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('108326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県杵島郡大町町大町', '41', '41423', '8492101', '佐賀県', 'サガケン', '杵島郡大町町', 'キシマグンオオマチチョウ', '大町', 'オオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県杵島郡大町町福母', '41', '41423', '8492102', '佐賀県', 'サガケン', '杵島郡大町町', 'キシマグンオオマチチョウ', '福母', 'フクモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県武雄市北方町志久', '41', '41206', '8492201', '佐賀県', 'サガケン', '武雄市', 'タケオシ', '北方町志久', 'キタガタチョウシク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県武雄市北方町大渡', '41', '41206', '8492202', '佐賀県', 'サガケン', '武雄市', 'タケオシ', '北方町大渡', 'キタガタチョウオオワタリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県武雄市北方町芦原', '41', '41206', '8492203', '佐賀県', 'サガケン', '武雄市', 'タケオシ', '北方町芦原', 'キタガタチョウアシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県武雄市北方町大崎', '41', '41206', '8492204', '佐賀県', 'サガケン', '武雄市', 'タケオシ', '北方町大崎', 'キタガタチョウオオサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県武雄市山内町犬走', '41', '41206', '8492301', '佐賀県', 'サガケン', '武雄市', 'タケオシ', '山内町犬走', 'ヤマウチチョウイヌバシリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県武雄市山内町鳥海', '41', '41206', '8492302', '佐賀県', 'サガケン', '武雄市', 'タケオシ', '山内町鳥海', 'ヤマウチチョウトノミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県武雄市山内町三間坂', '41', '41206', '8492303', '佐賀県', 'サガケン', '武雄市', 'タケオシ', '山内町三間坂', 'ヤマウチチョウミマサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県武雄市山内町大野', '41', '41206', '8492304', '佐賀県', 'サガケン', '武雄市', 'タケオシ', '山内町大野', 'ヤマウチチョウオオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県武雄市山内町宮野', '41', '41206', '8492305', '佐賀県', 'サガケン', '武雄市', 'タケオシ', '山内町宮野', 'ヤマウチチョウミヤノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県武雄市武内町梅野', '41', '41206', '8492341', '佐賀県', 'サガケン', '武雄市', 'タケオシ', '武内町梅野', 'タケウチチョウウメノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県武雄市武内町真手野', '41', '41206', '8492342', '佐賀県', 'サガケン', '武雄市', 'タケオシ', '武内町真手野', 'タケウチチョウマテノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市厳木町天川', '41', '41202', '8493101', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '厳木町天川', 'キュウラギマチアマガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市厳木町鳥越', '41', '41202', '8493102', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '厳木町鳥越', 'キュウラギマチトリゴエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市厳木町広川', '41', '41202', '8493103', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '厳木町広川', 'キュウラギマチヒロカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市厳木町星領', '41', '41202', '8493104', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '厳木町星領', 'キュウラギマチホシリョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市厳木町広瀬', '41', '41202', '8493111', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '厳木町広瀬', 'キュウラギマチヒロセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市厳木町中島', '41', '41202', '8493112', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '厳木町中島', 'キュウラギマチナカシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市厳木町牧瀬', '41', '41202', '8493113', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '厳木町牧瀬', 'キュウラギマチマキセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市厳木町浦川内', '41', '41202', '8493114', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '厳木町浦川内', 'キュウラギマチウラガワチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市厳木町平之', '41', '41202', '8493115', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '厳木町平之', 'キュウラギマチヒラノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市厳木町瀬戸木場', '41', '41202', '8493121', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '厳木町瀬戸木場', 'キュウラギマチセトコバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市厳木町浪瀬', '41', '41202', '8493122', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '厳木町浪瀬', 'キュウラギマチナミセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市厳木町岩屋', '41', '41202', '8493123', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '厳木町岩屋', 'キュウラギマチイワヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市厳木町厳木', '41', '41202', '8493131', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '厳木町厳木', 'キュウラギマチキュウラギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市厳木町うつぼ木', '41', '41202', '8493132', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '厳木町うつぼ木', 'キュウラギマチウツボキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市厳木町本山', '41', '41202', '8493133', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '厳木町本山', 'キュウラギマチモトヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市相知町相知', '41', '41202', '8493201', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '相知町相知', 'オウチチョウオウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市相知町平山下', '41', '41202', '8493202', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '相知町平山下', 'オウチチョウヒラヤマシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市相知町平山上', '41', '41202', '8493203', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '相知町平山上', 'オウチチョウヒラヤマカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市相知町千束', '41', '41202', '8493211', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '相知町千束', 'オウチチョウセンゾク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市相知町横枕', '41', '41202', '8493212', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '相知町横枕', 'オウチチョウヨコマクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市相知町湯屋', '41', '41202', '8493213', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '相知町湯屋', 'オウチチョウユヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市相知町田頭', '41', '41202', '8493214', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '相知町田頭', 'オウチチョウタガシラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市相知町楠', '41', '41202', '8493215', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '相知町楠', 'オウチチョウクス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市相知町町切', '41', '41202', '8493216', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '相知町町切', 'オウチチョウチョウギリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市相知町長部田', '41', '41202', '8493217', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '相知町長部田', 'オウチチョウナガヘタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市相知町中山', '41', '41202', '8493218', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '相知町中山', 'オウチチョウナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市相知町鷹取', '41', '41202', '8493219', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '相知町鷹取', 'オウチチョウタカトリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市相知町大野', '41', '41202', '8493221', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '相知町大野', 'オウチチョウオオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市相知町黒岩', '41', '41202', '8493222', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '相知町黒岩', 'オウチチョウクロイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市相知町伊岐佐', '41', '41202', '8493223', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '相知町伊岐佐', 'オウチチョウイキサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市相知町山崎', '41', '41202', '8493224', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '相知町山崎', 'オウチチョウヤマサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市相知町牟田部', '41', '41202', '8493231', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '相知町牟田部', 'オウチチョウムタベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市相知町久保', '41', '41202', '8493232', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '相知町久保', 'オウチチョウクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市相知町佐里', '41', '41202', '8493233', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '相知町佐里', 'オウチチョウサリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県西松浦郡有田町二ノ瀬', '41', '41401', '8494141', '佐賀県', 'サガケン', '西松浦郡有田町', 'ニシマツウラグンアリタチョウ', '二ノ瀬', 'ニノセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県西松浦郡有田町山谷牧', '41', '41401', '8494142', '佐賀県', 'サガケン', '西松浦郡有田町', 'ニシマツウラグンアリタチョウ', '山谷牧', 'ヤマダニマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県西松浦郡有田町下山谷', '41', '41401', '8494143', '佐賀県', 'サガケン', '西松浦郡有田町', 'ニシマツウラグンアリタチョウ', '下山谷', 'シモヤマダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県西松浦郡有田町上山谷', '41', '41401', '8494144', '佐賀県', 'サガケン', '西松浦郡有田町', 'ニシマツウラグンアリタチョウ', '上山谷', 'カミヤマダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県西松浦郡有田町山谷切口', '41', '41401', '8494145', '佐賀県', 'サガケン', '西松浦郡有田町', 'ニシマツウラグンアリタチョウ', '山谷切口', 'ヤマダニキリグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県西松浦郡有田町岳', '41', '41401', '8494146', '佐賀県', 'サガケン', '西松浦郡有田町', 'ニシマツウラグンアリタチョウ', '岳', 'タケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県西松浦郡有田町広瀬山', '41', '41401', '8494151', '佐賀県', 'サガケン', '西松浦郡有田町', 'ニシマツウラグンアリタチョウ', '広瀬山', 'ヒロセヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県西松浦郡有田町広瀬', '41', '41401', '8494152', '佐賀県', 'サガケン', '西松浦郡有田町', 'ニシマツウラグンアリタチョウ', '広瀬', 'ヒロセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県西松浦郡有田町立部', '41', '41401', '8494153', '佐賀県', 'サガケン', '西松浦郡有田町', 'ニシマツウラグンアリタチョウ', '立部', 'タチベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県西松浦郡有田町大木宿', '41', '41401', '8494154', '佐賀県', 'サガケン', '西松浦郡有田町', 'ニシマツウラグンアリタチョウ', '大木宿', 'オオギシュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県西松浦郡有田町山本', '41', '41401', '8494155', '佐賀県', 'サガケン', '西松浦郡有田町', 'ニシマツウラグンアリタチョウ', '山本', 'ヤマモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県西松浦郡有田町桑木原', '41', '41401', '8494156', '佐賀県', 'サガケン', '西松浦郡有田町', 'ニシマツウラグンアリタチョウ', '桑木原', 'クワノキバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県西松浦郡有田町蔵宿', '41', '41401', '8494161', '佐賀県', 'サガケン', '西松浦郡有田町', 'ニシマツウラグンアリタチョウ', '蔵宿', 'ゾウシュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県西松浦郡有田町上内野', '41', '41401', '8494162', '佐賀県', 'サガケン', '西松浦郡有田町', 'ニシマツウラグンアリタチョウ', '上内野', 'カミウチノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県西松浦郡有田町下内野', '41', '41401', '8494163', '佐賀県', 'サガケン', '西松浦郡有田町', 'ニシマツウラグンアリタチョウ', '下内野', 'シモウチノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県西松浦郡有田町仏ノ原', '41', '41401', '8494164', '佐賀県', 'サガケン', '西松浦郡有田町', 'ニシマツウラグンアリタチョウ', '仏ノ原', 'ホトケノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県西松浦郡有田町黒川', '41', '41401', '8494165', '佐賀県', 'サガケン', '西松浦郡有田町', 'ニシマツウラグンアリタチョウ', '黒川', 'クロゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県西松浦郡有田町北ノ川内', '41', '41401', '8494166', '佐賀県', 'サガケン', '西松浦郡有田町', 'ニシマツウラグンアリタチョウ', '北ノ川内', 'キタノカワチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県西松浦郡有田町代々木', '41', '41401', '8494171', '佐賀県', 'サガケン', '西松浦郡有田町', 'ニシマツウラグンアリタチョウ', '代々木', 'ヨヨギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県西松浦郡有田町下本', '41', '41401', '8494172', '佐賀県', 'サガケン', '西松浦郡有田町', 'ニシマツウラグンアリタチョウ', '下本', 'シモホン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県西松浦郡有田町舞原', '41', '41401', '8494173', '佐賀県', 'サガケン', '西松浦郡有田町', 'ニシマツウラグンアリタチョウ', '舞原', 'マイバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県西松浦郡有田町上本', '41', '41401', '8494174', '佐賀県', 'サガケン', '西松浦郡有田町', 'ニシマツウラグンアリタチョウ', '上本', 'カミホン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県西松浦郡有田町楠木原', '41', '41401', '8494175', '佐賀県', 'サガケン', '西松浦郡有田町', 'ニシマツウラグンアリタチョウ', '楠木原', 'クスノキバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県西松浦郡有田町原明', '41', '41401', '8494176', '佐賀県', 'サガケン', '西松浦郡有田町', 'ニシマツウラグンアリタチョウ', '原明', 'ハラアケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県伊万里市山代町楠久', '41', '41205', '8494251', '佐賀県', 'サガケン', '伊万里市', 'イマリシ', '山代町楠久', 'ヤマシロチョウクスク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県伊万里市山代町楠久津', '41', '41205', '8494252', '佐賀県', 'サガケン', '伊万里市', 'イマリシ', '山代町楠久津', 'ヤマシロチョウクスクツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県伊万里市山代町峰', '41', '41205', '8494253', '佐賀県', 'サガケン', '伊万里市', 'イマリシ', '山代町峰', 'ヤマシロチョウミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県伊万里市山代町城', '41', '41205', '8494254', '佐賀県', 'サガケン', '伊万里市', 'イマリシ', '山代町城', 'ヤマシロチョウジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県伊万里市山代町福川内', '41', '41205', '8494255', '佐賀県', 'サガケン', '伊万里市', 'イマリシ', '山代町福川内', 'ヤマシロチョウフクガワチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県伊万里市山代町久原', '41', '41205', '8494256', '佐賀県', 'サガケン', '伊万里市', 'イマリシ', '山代町久原', 'ヤマシロチョウクバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県伊万里市山代町立岩', '41', '41205', '8494261', '佐賀県', 'サガケン', '伊万里市', 'イマリシ', '山代町立岩', 'ヤマシロチョウタチイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県伊万里市山代町西分', '41', '41205', '8494262', '佐賀県', 'サガケン', '伊万里市', 'イマリシ', '山代町西分', 'ヤマシロチョウニシブン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県伊万里市山代町西大久保', '41', '41205', '8494263', '佐賀県', 'サガケン', '伊万里市', 'イマリシ', '山代町西大久保', 'ヤマシロチョウニシオオクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県伊万里市山代町東分', '41', '41205', '8494264', '佐賀県', 'サガケン', '伊万里市', 'イマリシ', '山代町東分', 'ヤマシロチョウヒガシブン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県伊万里市東山代町長浜', '41', '41205', '8494271', '佐賀県', 'サガケン', '伊万里市', 'イマリシ', '東山代町長浜', 'ヒガシヤマシロチョウナガハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県伊万里市東山代町日尾', '41', '41205', '8494272', '佐賀県', 'サガケン', '伊万里市', 'イマリシ', '東山代町日尾', 'ヒガシヤマシロチョウヒオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県伊万里市東山代町天神', '41', '41205', '8494273', '佐賀県', 'サガケン', '伊万里市', 'イマリシ', '東山代町天神', 'ヒガシヤマシロチョウテンジン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県伊万里市東山代町脇野', '41', '41205', '8494274', '佐賀県', 'サガケン', '伊万里市', 'イマリシ', '東山代町脇野', 'ヒガシヤマシロチョウワキノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県伊万里市東山代町大久保', '41', '41205', '8494281', '佐賀県', 'サガケン', '伊万里市', 'イマリシ', '東山代町大久保', 'ヒガシヤマシロチョウオオクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県伊万里市東山代町里', '41', '41205', '8494282', '佐賀県', 'サガケン', '伊万里市', 'イマリシ', '東山代町里', 'ヒガシヤマシロチョウサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県伊万里市東山代町東大久保', '41', '41205', '8494283', '佐賀県', 'サガケン', '伊万里市', 'イマリシ', '東山代町東大久保', 'ヒガシヤマシロチョウヒガシオオクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県伊万里市東山代町浦川内', '41', '41205', '8494284', '佐賀県', 'サガケン', '伊万里市', 'イマリシ', '東山代町浦川内', 'ヒガシヤマシロチョウウラガワチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県伊万里市東山代町滝川内', '41', '41205', '8494285', '佐賀県', 'サガケン', '伊万里市', 'イマリシ', '東山代町滝川内', 'ヒガシヤマシロチョウタキガワチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県伊万里市東山代町川内野', '41', '41205', '8494286', '佐賀県', 'サガケン', '伊万里市', 'イマリシ', '東山代町川内野', 'ヒガシヤマシロチョウカワチノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市浜玉町岡口', '41', '41202', '8495101', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '浜玉町岡口', 'ハマタママチオカグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市浜玉町五反田', '41', '41202', '8495102', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '浜玉町五反田', 'ハマタママチゴタンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市浜玉町大江', '41', '41202', '8495103', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '浜玉町大江', 'ハマタママチオオエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市浜玉町渕上', '41', '41202', '8495104', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '浜玉町渕上', 'ハマタママチフチノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市浜玉町谷口', '41', '41202', '8495105', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '浜玉町谷口', 'ハマタママチタニグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市浜玉町南山', '41', '41202', '8495111', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '浜玉町南山', 'ハマタママチミナミヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市浜玉町平原', '41', '41202', '8495112', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '浜玉町平原', 'ハマタママチヒラバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市浜玉町鳥巣', '41', '41202', '8495113', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '浜玉町鳥巣', 'ハマタママチトリス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市浜玉町横田上', '41', '41202', '8495121', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '浜玉町横田上', 'ハマタママチヨコタカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市浜玉町横田下', '41', '41202', '8495122', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '浜玉町横田下', 'ハマタママチヨコタシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市浜玉町東山田', '41', '41202', '8495123', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '浜玉町東山田', 'ハマタママチヒガシヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市浜玉町山瀬', '41', '41202', '8495124', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '浜玉町山瀬', 'ハマタママチヤマセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県唐津市浜玉町浜崎', '41', '41202', '8495131', '佐賀県', 'サガケン', '唐津市', 'カラツシ', '浜玉町浜崎', 'ハマタママチハマサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県伊万里市大川町大川野', '41', '41205', '8495251', '佐賀県', 'サガケン', '伊万里市', 'イマリシ', '大川町大川野', 'オオカワチョウオオカワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県伊万里市大川町川西', '41', '41205', '8495252', '佐賀県', 'サガケン', '伊万里市', 'イマリシ', '大川町川西', 'オオカワチョウカワニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県伊万里市大川町駒鳴', '41', '41205', '8495253', '佐賀県', 'サガケン', '伊万里市', 'イマリシ', '大川町駒鳴', 'オオカワチョウコマナキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県伊万里市大川町立川', '41', '41205', '8495254', '佐賀県', 'サガケン', '伊万里市', 'イマリシ', '大川町立川', 'オオカワチョウタツガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県伊万里市大川町山口', '41', '41205', '8495255', '佐賀県', 'サガケン', '伊万里市', 'イマリシ', '大川町山口', 'オオカワチョウヤマグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県伊万里市大川町東田代', '41', '41205', '8495256', '佐賀県', 'サガケン', '伊万里市', 'イマリシ', '大川町東田代', 'オオカワチョウヒガシタシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県伊万里市大川町川原', '41', '41205', '8495257', '佐賀県', 'サガケン', '伊万里市', 'イマリシ', '大川町川原', 'オオカワチョウカワバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県伊万里市松浦町桃川', '41', '41205', '8495261', '佐賀県', 'サガケン', '伊万里市', 'イマリシ', '松浦町桃川', 'マツウラチョウモモノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県伊万里市松浦町中野原', '41', '41205', '8495262', '佐賀県', 'サガケン', '伊万里市', 'イマリシ', '松浦町中野原', 'マツウラチョウナカノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県伊万里市松浦町山形', '41', '41205', '8495263', '佐賀県', 'サガケン', '伊万里市', 'イマリシ', '松浦町山形', 'マツウラチョウヤマガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '佐賀県伊万里市松浦町提川', '41', '41205', '8495264', '佐賀県', 'サガケン', '伊万里市', 'イマリシ', '松浦町提川', 'マツウラチョウサゲノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市', '01', '01206', '0850000', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('108466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市', '42', '42201', '8500000', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('108467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市西山', '42', '42201', '8500001', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '西山', 'ニシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市木場町', '42', '42201', '8500002', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '木場町', 'コバマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市片淵', '42', '42201', '8500003', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '片淵', 'カタフチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市下西山町', '42', '42201', '8500004', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '下西山町', 'シモニシヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市西山本町', '42', '42201', '8500005', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '西山本町', 'ニシヤマホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市上西山町', '42', '42201', '8500006', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '上西山町', 'カミニシヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市立山', '42', '42201', '8500007', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '立山', 'タテヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市古川町', '01', '01206', '0850001', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '古川町', 'フルカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市鳴滝', '42', '42201', '8500011', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '鳴滝', 'ナルタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市本河内', '42', '42201', '8500012', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '本河内', 'ホンゴウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市中川', '42', '42201', '8500013', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '中川', 'ナカガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市新中川町', '42', '42201', '8500014', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '新中川町', 'シンナカガワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市桜馬場', '42', '42201', '8500015', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '桜馬場', 'サクラババ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市夫婦川町', '42', '42201', '8500016', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '夫婦川町', 'フウフガワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市新大工町', '42', '42201', '8500017', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '新大工町', 'シンダイクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市伊勢町', '42', '42201', '8500018', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '伊勢町', 'イセマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市新釧路町', '01', '01206', '0850002', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '新釧路町', 'シンクシロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市炉粕町', '42', '42201', '8500021', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '炉粕町', 'ロカスマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市馬町', '42', '42201', '8500022', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '馬町', 'ウママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市出来大工町', '42', '42201', '8500023', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '出来大工町', 'デキダイクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市大井手町', '42', '42201', '8500024', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '大井手町', 'オオイデマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市今博多町', '42', '42201', '8500025', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '今博多町', 'イマハカタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市古町', '42', '42201', '8500026', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '古町', 'フルマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市桶屋町', '42', '42201', '8500027', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '桶屋町', 'オケヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市勝山町', '42', '42201', '8500028', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '勝山町', 'カツヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市八百屋町', '42', '42201', '8500029', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '八百屋町', 'ヤオヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市川北町', '01', '01206', '0850003', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '川北町', 'カワキタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市桜町', '42', '42201', '8500031', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '桜町', 'サクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市興善町', '42', '42201', '8500032', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '興善町', 'コウゼンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市万才町', '42', '42201', '8500033', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '万才町', 'マンザイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市樺島町', '42', '42201', '8500034', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '樺島町', 'カバシママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市元船町', '42', '42201', '8500035', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '元船町', 'モトフナマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市五島町', '42', '42201', '8500036', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '五島町', 'ゴトウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市金屋町', '42', '42201', '8500037', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '金屋町', 'カナヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市新富町', '01', '01206', '0850004', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '新富町', 'シントミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市浜平', '42', '42201', '8500041', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '浜平', 'ハマヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市御船蔵町', '42', '42201', '8500042', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '御船蔵町', 'オフナグラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市八千代町', '42', '42201', '8500043', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '八千代町', 'ヤチヨマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市天神町', '42', '42201', '8500044', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '天神町', 'テンジンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市宝町', '42', '42201', '8500045', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '宝町', 'タカラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市幸町', '42', '42201', '8500046', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '幸町', 'サイワイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市銭座町', '42', '42201', '8500047', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '銭座町', 'ゼンザマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市上銭座町', '42', '42201', '8500048', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '上銭座町', 'カミゼンザマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市松浦町', '01', '01206', '0850005', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '松浦町', 'マツウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市西坂町', '42', '42201', '8500051', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '西坂町', 'ニシザカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市筑後町', '42', '42201', '8500052', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '筑後町', 'チクゴマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市玉園町', '42', '42201', '8500053', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '玉園町', 'タマゾノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市上町', '42', '42201', '8500054', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '上町', 'ウワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市中町', '42', '42201', '8500055', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '中町', 'ナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市恵美須町', '42', '42201', '8500056', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '恵美須町', 'エビスマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市大黒町', '42', '42201', '8500057', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '大黒町', 'ダイコクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市尾上町', '42', '42201', '8500058', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '尾上町', 'オノウエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市双葉町', '01', '01206', '0850006', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '双葉町', 'フタバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市水の浦町', '42', '42201', '8500061', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '水の浦町', 'ミズノウラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市大谷町', '42', '42201', '8500062', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '大谷町', 'オオタニマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市飽の浦町', '42', '42201', '8500063', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '飽の浦町', 'アクノウラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市秋月町', '42', '42201', '8500064', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '秋月町', 'アキヅキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市入船町', '42', '42201', '8500065', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '入船町', 'イリフネマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市大浜町', '42', '42201', '8500066', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '大浜町', 'オオハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市小浦町', '42', '42201', '8500067', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '小浦町', 'コウラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市福田本町', '42', '42201', '8500068', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '福田本町', 'フクダホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市堀川町', '01', '01206', '0850007', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '堀川町', 'ホリカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市塩浜町', '42', '42201', '8500071', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '塩浜町', 'シオハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市岩瀬道町', '42', '42201', '8500072', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '岩瀬道町', 'イワセドウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市東立神町', '42', '42201', '8500073', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '東立神町', 'ヒガシタテガミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市西立神町', '42', '42201', '8500074', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '西立神町', 'ニシタテガミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市西泊町', '42', '42201', '8500075', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '西泊町', 'ニシドマリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市木鉢町', '42', '42201', '8500076', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '木鉢町', 'キバチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市小瀬戸町', '42', '42201', '8500077', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '小瀬戸町', 'コセドマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市神ノ島町', '42', '42201', '8500078', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '神ノ島町', 'カミノシママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市みなと坂', '42', '42201', '8500079', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', 'みなと坂', 'ミナトザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市入江町', '01', '01206', '0850008', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '入江町', 'イリエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市旭町', '01', '01206', '0850011', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '旭町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市川上町', '01', '01206', '0850012', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '川上町', 'カワカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市栄町', '01', '01206', '0850013', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市末広町', '01', '01206', '0850014', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '末広町', 'スエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市北大通', '01', '01206', '0850015', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '北大通', 'キタオオドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市錦町', '01', '01206', '0850016', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '錦町', 'ニシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市幸町', '01', '01206', '0850017', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市黒金町', '01', '01206', '0850018', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '黒金町', 'クロガネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市浪花町', '01', '01206', '0850021', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '浪花町', 'ナニワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市南浜町', '01', '01206', '0850022', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '南浜町', 'ミナミハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市海運', '01', '01206', '0850023', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '海運', 'カイウン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市浜町', '01', '01206', '0850024', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '浜町', 'ハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市宝町', '01', '01206', '0850025', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '宝町', 'タカラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市寿', '01', '01206', '0850026', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '寿', 'コトブキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市仲浜町', '01', '01206', '0850027', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '仲浜町', 'ナカハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市中島町', '01', '01206', '0850031', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '中島町', 'ナカジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市新栄町', '01', '01206', '0850032', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '新栄町', 'シンエイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市若松町', '01', '01206', '0850033', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '若松町', 'ワカマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市白金町', '01', '01206', '0850034', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '白金町', 'シロガネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市共栄大通', '01', '01206', '0850035', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '共栄大通', 'キョウエイオオドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市若竹町', '01', '01206', '0850036', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '若竹町', 'ワカタケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市柳町', '01', '01206', '0850037', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '柳町', 'ヤナギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市花園町', '01', '01206', '0850038', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '花園町', 'ハナゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市春日町', '01', '01206', '0850041', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '春日町', 'カスガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市若草町', '01', '01206', '0850042', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '若草町', 'ワカクサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市喜多町', '01', '01206', '0850043', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '喜多町', 'キタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市川端町', '01', '01206', '0850044', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '川端町', 'カワバタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市住之江町', '01', '01206', '0850045', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '住之江町', 'スミノエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市新橋大通', '01', '01206', '0850046', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '新橋大通', 'シンバシオオドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市新川町', '01', '01206', '0850047', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '新川町', 'シンカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市駒場町', '01', '01206', '0850048', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '駒場町', 'コマバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市光陽町', '01', '01206', '0850051', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '光陽町', 'コウヨウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市中園町', '01', '01206', '0850052', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '中園町', 'ナカゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市豊川町', '01', '01206', '0850053', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '豊川町', 'トヨカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市暁町', '01', '01206', '0850054', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '暁町', 'アカツキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市治水町', '01', '01206', '0850055', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '治水町', 'ジスイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市東川町', '01', '01206', '0850056', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '東川町', 'ヒガシカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市愛国西', '01', '01206', '0850057', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '愛国西', 'アイコクニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市愛国東', '01', '01206', '0850058', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '愛国東', 'アイコクヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市芦野', '01', '01206', '0850061', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '芦野', 'アシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市愛国', '01', '01206', '0850062', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '愛国', 'アイコク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市文苑', '01', '01206', '0850063', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '文苑', 'フミゾノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市広里', '01', '01206', '0850064', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '広里', 'ヒロサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市美原', '01', '01206', '0850065', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '美原', 'ミハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市八幡町', '42', '42201', '8500801', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '八幡町', 'ヤハタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市伊良林', '42', '42201', '8500802', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '伊良林', 'イラバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市風頭町', '42', '42201', '8500803', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '風頭町', 'カザガシラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市彦見町', '42', '42201', '8500804', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '彦見町', 'ヒコミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市矢の平', '42', '42201', '8500811', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '矢の平', 'ヤノヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市白木町', '42', '42201', '8500812', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '白木町', 'シロキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市八つ尾町', '42', '42201', '8500813', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '八つ尾町', 'ヤツオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市高平町', '42', '42201', '8500821', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '高平町', 'タカヒラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市愛宕', '42', '42201', '8500822', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '愛宕', 'アタゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市弥生町', '42', '42201', '8500823', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '弥生町', 'ヤヨイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市三景台町', '42', '42201', '8500824', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '三景台町', 'サンケイダイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市鍛冶屋町', '42', '42201', '8500831', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '鍛冶屋町', 'カジヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市油屋町', '42', '42201', '8500832', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '油屋町', 'アブラヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市東小島町', '42', '42201', '8500833', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '東小島町', 'ヒガシコシママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市上小島', '42', '42201', '8500834', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '上小島', 'カミコシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市桜木町', '42', '42201', '8500835', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '桜木町', 'サクラギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市中小島', '42', '42201', '8500836', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '中小島', 'ナカコシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市西小島', '42', '42201', '8500837', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '西小島', 'ニシコシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市銅座町', '42', '42201', '8500841', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '銅座町', 'ドウザマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市新地町', '42', '42201', '8500842', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '新地町', 'シンチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市常盤町', '42', '42201', '8500843', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '常盤町', 'トキワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市古川町', '42', '42201', '8500851', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '古川町', 'フルカワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市万屋町', '42', '42201', '8500852', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '万屋町', 'ヨロズヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市浜町', '42', '42201', '8500853', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '浜町', 'ハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市銀屋町', '42', '42201', '8500854', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '銀屋町', 'ギンヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市東古川町', '42', '42201', '8500855', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '東古川町', 'ヒガシフルカワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市江戸町', '42', '42201', '8500861', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '江戸町', 'エドマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市出島町', '42', '42201', '8500862', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '出島町', 'デジママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市麹屋町', '42', '42201', '8500871', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '麹屋町', 'コウジヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市寺町', '42', '42201', '8500872', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '寺町', 'テラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市諏訪町', '42', '42201', '8500873', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '諏訪町', 'スワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市魚の町', '42', '42201', '8500874', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '魚の町', 'ウオノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市栄町', '42', '42201', '8500875', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市賑町', '42', '42201', '8500876', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '賑町', 'ニギワイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市築町', '42', '42201', '8500877', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '築町', 'ツキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市本石灰町', '42', '42201', '8500901', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '本石灰町', 'モトシックイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市丸山町', '42', '42201', '8500902', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '丸山町', 'マルヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市寄合町', '42', '42201', '8500903', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '寄合町', 'ヨリアイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市船大工町', '42', '42201', '8500904', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '船大工町', 'フナダイクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市籠町', '42', '42201', '8500905', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '籠町', 'カゴマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市館内町', '42', '42201', '8500906', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '館内町', 'カンナイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市稲田町', '42', '42201', '8500907', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '稲田町', 'イナダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市十人町', '42', '42201', '8500908', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '十人町', 'ジュウニンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市梅香崎町', '42', '42201', '8500909', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '梅香崎町', 'ウメガサキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市東山手町', '42', '42201', '8500911', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '東山手町', 'ヒガシヤマテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市中新町', '42', '42201', '8500912', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '中新町', 'ナカシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市元町', '42', '42201', '8500913', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '元町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市日の出町', '42', '42201', '8500914', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '日の出町', 'ヒノデマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市東山町', '42', '42201', '8500915', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '東山町', 'ヒガシヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市大浦東町', '42', '42201', '8500916', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '大浦東町', 'オオウラヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市下町', '42', '42201', '8500917', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '下町', 'シタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市大浦町', '42', '42201', '8500918', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '大浦町', 'オオウラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市松が枝町', '42', '42201', '8500921', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '松が枝町', 'マツガエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市相生町', '42', '42201', '8500922', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '相生町', 'アイオイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市上田町', '42', '42201', '8500923', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '上田町', 'ウエダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市出雲', '42', '42201', '8500924', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '出雲', 'イズモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市南山手町', '42', '42201', '8500931', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '南山手町', 'ミナミヤマテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市東琴平', '42', '42201', '8500932', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '東琴平', 'ヒガシコトヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市西琴平町', '42', '42201', '8500933', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '西琴平町', 'ニシコトヒラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市小菅町', '42', '42201', '8500934', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '小菅町', 'コスゲマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市古河町', '42', '42201', '8500935', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '古河町', 'フルコマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市浪の平町', '42', '42201', '8500936', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '浪の平町', 'ナミノヒラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市小曽根町', '42', '42201', '8500937', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '小曽根町', 'コゾネマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市高丘', '42', '42201', '8500941', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '高丘', 'タカオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市南町', '42', '42201', '8500942', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '南町', 'ミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市南が丘町', '42', '42201', '8500943', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '南が丘町', 'ミナミガオカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市八景町', '42', '42201', '8500944', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '八景町', 'ハッケイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市星取', '42', '42201', '8500945', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '星取', 'ホシトリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市川上町', '42', '42201', '8500946', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '川上町', 'カワカミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市椎の木町', '42', '42201', '8500947', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '椎の木町', 'シイノギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市国分町', '42', '42201', '8500951', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '国分町', 'コクブマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市戸町', '42', '42201', '8500952', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '戸町', 'トマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市上戸町', '42', '42201', '8500953', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '上戸町', 'カミトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市新戸町', '42', '42201', '8500954', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '新戸町', 'シントマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市小ケ倉町', '42', '42201', '8500961', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '小ケ倉町', 'コガクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市新小が倉', '42', '42201', '8500962', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '新小が倉', 'シンコガクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市ダイヤランド', '42', '42201', '8500963', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', 'ダイヤランド', 'ダイヤランド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市大山町', '42', '42201', '8500964', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '大山町', 'オオヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市磯道町', '42', '42201', '8500971', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '磯道町', 'イソミチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市古道町', '42', '42201', '8500972', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '古道町', 'フルミチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市鹿尾町', '42', '42201', '8500973', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '鹿尾町', 'カノオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市京太郎町', '42', '42201', '8500974', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '京太郎町', 'キョウタロウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市三和町', '42', '42201', '8500975', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '三和町', 'サンワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市毛井首町', '42', '42201', '8500976', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '毛井首町', 'ケイクビマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市土井首町', '42', '42201', '8500977', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '土井首町', 'ドイノクビマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市草住町', '42', '42201', '8500981', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '草住町', 'クサズミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市柳田町', '42', '42201', '8500982', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '柳田町', 'ヤナギダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市米山町', '42', '42201', '8500983', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '米山町', 'コメノヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市鶴見台', '42', '42201', '8500984', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '鶴見台', 'ツルミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市平瀬町', '42', '42201', '8500985', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '平瀬町', 'ヒラセマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市末石町', '42', '42201', '8500991', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '末石町', 'スエイシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市江川町', '42', '42201', '8500992', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '江川町', 'エガワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市八郎岳町', '42', '42201', '8500993', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '八郎岳町', 'ハチロウダケマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市竿浦町', '42', '42201', '8500994', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '竿浦町', 'サオノウラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市平山町', '42', '42201', '8500995', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '平山町', 'ヒラヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市平山台', '42', '42201', '8500996', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '平山台', 'ヒラヤマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市阿寒町仁々志別', '01', '01206', '0850201', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '阿寒町仁々志別', 'アカンチョウニニシベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市阿寒町下舌辛', '01', '01206', '0850211', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '阿寒町下舌辛', 'アカンチョウシモシタカラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市阿寒町旭町', '01', '01206', '0850212', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '阿寒町旭町', 'アカンチョウアサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市阿寒町仲町', '01', '01206', '0850213', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '阿寒町仲町', 'アカンチョウナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市阿寒町富士見', '01', '01206', '0850214', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '阿寒町富士見', 'アカンチョウフジミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市阿寒町中央', '01', '01206', '0850215', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '阿寒町中央', 'アカンチョウチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市阿寒町北新町', '01', '01206', '0850216', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '阿寒町北新町', 'アカンチョウキタシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市阿寒町北町', '01', '01206', '0850217', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '阿寒町北町', 'アカンチョウキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市阿寒町新町', '01', '01206', '0850218', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '阿寒町新町', 'アカンチョウシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市阿寒町舌辛', '01', '01206', '0850220', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '阿寒町舌辛', 'アカンチョウシタカラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市阿寒町上舌辛', '01', '01206', '0850221', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '阿寒町上舌辛', 'アカンチョウカミシタカラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市阿寒町布伏内', '01', '01206', '0850222', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '阿寒町布伏内', 'アカンチョウフブシナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市阿寒町下布伏内', '01', '01206', '0850223', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '阿寒町下布伏内', 'アカンチョウシモフブシナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市阿寒町雄別横山', '01', '01206', '0850224', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '阿寒町雄別横山', 'アカンチョウユウベツヨコヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市阿寒町知茶布', '01', '01206', '0850225', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '阿寒町知茶布', 'アカンチョウチチャップ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市阿寒町下徹別', '01', '01206', '0850231', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '阿寒町下徹別', 'アカンチョウシモテシベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市阿寒町大正', '01', '01206', '0850232', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '阿寒町大正', 'アカンチョウタイショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市阿寒町西徹別', '01', '01206', '0850233', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '阿寒町西徹別', 'アカンチョウニシテシベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市阿寒町蘇牛', '01', '01206', '0850234', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '阿寒町蘇牛', 'アカンチョウソウシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市阿寒町上徹別', '01', '01206', '0850235', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '阿寒町上徹別', 'アカンチョウカミテシベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市阿寒町中徹別', '01', '01206', '0850236', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '阿寒町中徹別', 'アカンチョウナカテシベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市阿寒町徹別中央', '01', '01206', '0850237', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '阿寒町徹別中央', 'アカンチョウテシベツチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市阿寒町飽別', '01', '01206', '0850238', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '阿寒町飽別', 'アカンチョウアクベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市阿寒町中阿寒', '01', '01206', '0850241', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '阿寒町中阿寒', 'アカンチョウナカアカン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市阿寒町東舌辛', '01', '01206', '0850242', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '阿寒町東舌辛', 'アカンチョウヒガシシタカラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市阿寒町西阿寒', '01', '01206', '0850243', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '阿寒町西阿寒', 'アカンチョウニシアカン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市阿寒町紀ノ丘', '01', '01206', '0850244', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '阿寒町紀ノ丘', 'アカンチョウキノオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市阿寒町上阿寒', '01', '01206', '0850245', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '阿寒町上阿寒', 'アカンチョウカミアカン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市桜田', '01', '01206', '0850251', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '桜田', 'サクラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市青山', '01', '01206', '0850252', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '青山', 'アオヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市阿寒町阿寒湖温泉1丁目', '01', '01206', '0850467', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '阿寒町阿寒湖温泉', 'アカンチョウアカンコオンセン', null, null, '1丁目', '01チョウメ');
INSERT INTO `ms_addresses` VALUES ('108712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市阿寒町阿寒湖温泉2丁目', '01', '01206', '0850467', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '阿寒町阿寒湖温泉', 'アカンチョウアカンコオンセン', null, null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('108713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市阿寒町阿寒湖温泉3丁目', '01', '01206', '0850467', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '阿寒町阿寒湖温泉', 'アカンチョウアカンコオンセン', null, null, '3丁目', '03チョウメ');
INSERT INTO `ms_addresses` VALUES ('108714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市阿寒町阿寒湖温泉4丁目', '01', '01206', '0850467', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '阿寒町阿寒湖温泉', 'アカンチョウアカンコオンセン', null, null, '4丁目', '04チョウメ');
INSERT INTO `ms_addresses` VALUES ('108715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市阿寒町阿寒湖温泉5丁目', '01', '01206', '0850467', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '阿寒町阿寒湖温泉', 'アカンチョウアカンコオンセン', null, null, '5丁目', '05チョウメ');
INSERT INTO `ms_addresses` VALUES ('108716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市阿寒町阿寒湖温泉6丁目', '01', '01206', '0850467', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '阿寒町阿寒湖温泉', 'アカンチョウアカンコオンセン', null, null, '6丁目', '06チョウメ');
INSERT INTO `ms_addresses` VALUES ('108717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市三津浦', '01', '01206', '0850801', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '三津浦', 'ミツウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市桂恋', '01', '01206', '0850802', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '桂恋', 'カツラコイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市益浦', '01', '01206', '0850803', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '益浦', 'マスウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市白樺台', '01', '01206', '0850804', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '白樺台', 'シラカバダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市桜ケ岡', '01', '01206', '0850805', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '桜ケ岡', 'サクラガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市武佐', '01', '01206', '0850806', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '武佐', 'ムサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市高山', '01', '01206', '0850807', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '高山', 'タカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市興津', '01', '01206', '0850811', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '興津', 'オコツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市紫雲台', '01', '01206', '0850812', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '紫雲台', 'シウンダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市春採', '01', '01206', '0850813', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '春採', 'ハルトリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市緑ケ岡', '01', '01206', '0850814', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '緑ケ岡', 'ミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市材木町', '01', '01206', '0850815', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '材木町', 'ザイモクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市貝塚', '01', '01206', '0850816', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '貝塚', 'カイヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市鶴ケ岱', '01', '01206', '0850821', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '鶴ケ岱', 'ツルガダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市春湖台', '01', '01206', '0850822', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '春湖台', 'シュンコダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市千代ノ浦', '01', '01206', '0850823', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '千代ノ浦', 'チヨノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市柏木町', '01', '01206', '0850824', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '柏木町', 'カシワギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市千歳町', '01', '01206', '0850825', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '千歳町', 'チトセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市城山', '01', '01206', '0850826', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '城山', 'シロヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市住吉', '01', '01206', '0850831', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '住吉', 'スミヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市富士見', '01', '01206', '0850832', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '富士見', 'フジミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市宮本', '01', '01206', '0850833', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '宮本', 'ミヤモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市弥生', '01', '01206', '0850834', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '弥生', 'ヤヨイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市浦見', '01', '01206', '0850835', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '浦見', 'ウラミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市幣舞町', '01', '01206', '0850836', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '幣舞町', 'ヌサマイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市大川町', '01', '01206', '0850837', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '大川町', 'オオカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市南大通', '01', '01206', '0850841', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '南大通', 'ミナミオオドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市米町', '01', '01206', '0850842', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '米町', 'ヨネマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市弁天ケ浜', '01', '01206', '0850843', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '弁天ケ浜', 'ベンテンガハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市知人町', '01', '01206', '0850844', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '知人町', 'シリトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市港町', '01', '01206', '0850845', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '港町', 'ミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市入舟', '01', '01206', '0850846', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '入舟', 'イリフネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市大町', '01', '01206', '0850847', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '大町', 'オオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市古賀町', '42', '42201', '8510101', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '古賀町', 'コガマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市つつじが丘', '42', '42201', '8510102', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', 'つつじが丘', 'ツツジガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市中里町', '42', '42201', '8510103', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '中里町', 'ナカザトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市船石町', '42', '42201', '8510104', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '船石町', 'フナイシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市上戸石町', '42', '42201', '8510111', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '上戸石町', 'カミトイシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市川内町', '42', '42201', '8510112', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '川内町', 'カワウチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市戸石町', '42', '42201', '8510113', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '戸石町', 'トイシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市牧島町', '42', '42201', '8510114', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '牧島町', 'マキシママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市かき道', '42', '42201', '8510115', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', 'かき道', 'カキドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市東町', '42', '42201', '8510116', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '東町', 'ヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市宿町', '42', '42201', '8510121', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '宿町', 'シュクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市界', '42', '42201', '8510122', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '界', 'サカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市網場町', '42', '42201', '8510123', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '網場町', 'アバマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市春日町', '42', '42201', '8510124', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '春日町', 'カスガマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市潮見町', '42', '42201', '8510125', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '潮見町', 'シオミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市芒塚町', '42', '42201', '8510126', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '芒塚町', 'ススキヅカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市松原町', '42', '42201', '8510131', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '松原町', 'マツバラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市鶴の尾町', '42', '42201', '8510132', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '鶴の尾町', 'ツルノオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市矢上町', '42', '42201', '8510133', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '矢上町', 'ヤガミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市田中町', '42', '42201', '8510134', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '田中町', 'タナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市現川町', '42', '42201', '8510135', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '現川町', 'ウツツガワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市平間町', '42', '42201', '8510136', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '平間町', 'ヒラママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市高城台', '42', '42201', '8510137', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '高城台', 'タカシロダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市茂木町', '42', '42201', '8510241', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '茂木町', 'モギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市北浦町', '42', '42201', '8510242', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '北浦町', 'キタウラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市宮摺町', '42', '42201', '8510243', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '宮摺町', 'ミヤズリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市大崎町', '42', '42201', '8510244', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '大崎町', 'オオサキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市千々町', '42', '42201', '8510245', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '千々町', 'チヂマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市田上', '42', '42201', '8510251', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '田上', 'タガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市田手原町', '42', '42201', '8510252', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '田手原町', 'タデワラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市早坂町', '42', '42201', '8510253', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '早坂町', 'ハヤサカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市飯香浦町', '42', '42201', '8510254', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '飯香浦町', 'イカノウラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市太田尾町', '42', '42201', '8510255', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '太田尾町', 'オオタオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市深堀町', '42', '42201', '8510301', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '深堀町', 'フカホリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市大籠町', '42', '42201', '8510302', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '大籠町', 'オオゴモリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市香焼町', '42', '42201', '8510310', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '香焼町', 'コウヤギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市蚊焼町', '42', '42201', '8510401', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '蚊焼町', 'カヤキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市晴海台町', '42', '42201', '8510402', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '晴海台町', 'ハルミダイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市布巻町', '42', '42201', '8510403', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '布巻町', 'ヌノマキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市藤田尾町', '42', '42201', '8510404', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '藤田尾町', 'トウダオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市為石町', '42', '42201', '8510405', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '為石町', 'タメシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市椿が丘町', '42', '42201', '8510406', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '椿が丘町', 'ツバキガオカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市川原町', '42', '42201', '8510407', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '川原町', 'カワラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市宮崎町', '42', '42201', '8510408', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '宮崎町', 'ミヤザキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市黒浜町', '42', '42201', '8510501', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '黒浜町', 'クロハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市以下宿町', '42', '42201', '8510502', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '以下宿町', 'イガヤドマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市高浜町', '42', '42201', '8510503', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '高浜町', 'タカハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市南越町', '42', '42201', '8510504', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '南越町', 'ナンゴシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市野母町', '42', '42201', '8510505', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '野母町', 'ノモマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市脇岬町', '42', '42201', '8510506', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '脇岬町', 'ワキミサキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市野母崎樺島町', '42', '42201', '8510507', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '野母崎樺島町', 'ノモザキカバシママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市見崎町', '42', '42201', '8511121', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '見崎町', 'ミサキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市相川町', '42', '42201', '8511122', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '相川町', 'アイガワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市四杖町', '42', '42201', '8511123', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '四杖町', 'ヨツエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市牧野町', '42', '42201', '8511124', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '牧野町', 'マキノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市園田町', '42', '42201', '8511125', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '園田町', 'ソノダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市上浦町', '42', '42201', '8511131', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '上浦町', 'カミウラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市小江原', '42', '42201', '8511132', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '小江原', 'コエバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市小江町', '42', '42201', '8511133', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '小江町', 'コエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市柿泊町', '42', '42201', '8511134', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '柿泊町', 'カキドマリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市手熊町', '42', '42201', '8511135', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '手熊町', 'テグママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市向町', '42', '42201', '8511136', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '向町', 'ムカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市式見町', '42', '42201', '8511137', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '式見町', 'シキミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市伊王島町', '42', '42201', '8511201', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '伊王島町', 'イオウジママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道阿寒郡鶴居村新幌呂', '01', '01667', '0851131', '北海道', 'ホッカイドウ', '阿寒郡鶴居村', 'アカングンツルイムラ', '新幌呂', 'シンホロロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市高島町', '42', '42201', '8511315', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '高島町', 'タカシママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道阿寒郡鶴居村上幌呂', '01', '01667', '0851132', '北海道', 'ホッカイドウ', '阿寒郡鶴居村', 'アカングンツルイムラ', '上幌呂', 'カミホロロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道阿寒郡鶴居村支幌呂', '01', '01667', '0851133', '北海道', 'ホッカイドウ', '阿寒郡鶴居村', 'アカングンツルイムラ', '支幌呂', 'シホロロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道阿寒郡鶴居村茂幌呂', '01', '01667', '0851134', '北海道', 'ホッカイドウ', '阿寒郡鶴居村', 'アカングンツルイムラ', '茂幌呂', 'モホロロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道阿寒郡鶴居村幌呂西', '01', '01667', '0851141', '北海道', 'ホッカイドウ', '阿寒郡鶴居村', 'アカングンツルイムラ', '幌呂西', 'ホロロニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道阿寒郡鶴居村幌呂東', '01', '01667', '0851142', '北海道', 'ホッカイドウ', '阿寒郡鶴居村', 'アカングンツルイムラ', '幌呂東', 'ホロロヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道阿寒郡鶴居村中幌呂', '01', '01667', '0851143', '北海道', 'ホッカイドウ', '阿寒郡鶴居村', 'アカングンツルイムラ', '中幌呂', 'ナカホロロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道阿寒郡鶴居村下幌呂', '01', '01667', '0851144', '北海道', 'ホッカイドウ', '阿寒郡鶴居村', 'アカングンツルイムラ', '下幌呂', 'シモホロロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道阿寒郡鶴居村温根内', '01', '01667', '0851145', '北海道', 'ホッカイドウ', '阿寒郡鶴居村', 'アカングンツルイムラ', '温根内', 'オンネナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道阿寒郡鶴居村アトコシヤラカ', '01', '01667', '0851146', '北海道', 'ホッカイドウ', '阿寒郡鶴居村', 'アカングンツルイムラ', 'アトコシヤラカ', 'アトコシャラカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道阿寒郡鶴居村幌呂', '01', '01667', '0851147', '北海道', 'ホッカイドウ', '阿寒郡鶴居村', 'アカングンツルイムラ', '幌呂', 'ホロロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道阿寒郡鶴居村', '01', '01667', '0851200', '北海道', 'ホッカイドウ', '阿寒郡鶴居村', 'アカングンツルイムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('108899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道阿寒郡鶴居村鶴居北', '01', '01667', '0851201', '北海道', 'ホッカイドウ', '阿寒郡鶴居村', 'アカングンツルイムラ', '鶴居北', 'ツルイキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道阿寒郡鶴居村中雪裡西', '01', '01667', '0851202', '北海道', 'ホッカイドウ', '阿寒郡鶴居村', 'アカングンツルイムラ', '中雪裡', 'ナカセツリ', null, null, '西', 'ニシ');
INSERT INTO `ms_addresses` VALUES ('108901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道阿寒郡鶴居村鶴居西', '01', '01667', '0851203', '北海道', 'ホッカイドウ', '阿寒郡鶴居村', 'アカングンツルイムラ', '鶴居西', 'ツルイニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道阿寒郡鶴居村鶴居南', '01', '01667', '0851204', '北海道', 'ホッカイドウ', '阿寒郡鶴居村', 'アカングンツルイムラ', '鶴居南', 'ツルイミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道阿寒郡鶴居村中雪裡南', '01', '01667', '0851205', '北海道', 'ホッカイドウ', '阿寒郡鶴居村', 'アカングンツルイムラ', '中雪裡', 'ナカセツリ', null, null, '南', 'ミナミ');
INSERT INTO `ms_addresses` VALUES ('108904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道阿寒郡鶴居村鶴居東', '01', '01667', '0851206', '北海道', 'ホッカイドウ', '阿寒郡鶴居村', 'アカングンツルイムラ', '鶴居東', 'ツルイヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道阿寒郡鶴居村中雪裡東', '01', '01667', '0851207', '北海道', 'ホッカイドウ', '阿寒郡鶴居村', 'アカングンツルイムラ', '中雪裡', 'ナカセツリ', null, null, '東', 'ヒガシ');
INSERT INTO `ms_addresses` VALUES ('108906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県西彼杵郡長与町', '42', '42307', '8512100', '長崎県', 'ナガサキケン', '西彼杵郡長与町', 'ニシソノギグンナガヨチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('108907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県西彼杵郡時津町', '42', '42308', '8512100', '長崎県', 'ナガサキケン', '西彼杵郡時津町', 'ニシソノギグントギツチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('108908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県西彼杵郡時津町西時津郷', '42', '42308', '8512101', '長崎県', 'ナガサキケン', '西彼杵郡時津町', 'ニシソノギグントギツチョウ', '西時津郷', 'ニシトギツゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県西彼杵郡時津町浜田郷', '42', '42308', '8512102', '長崎県', 'ナガサキケン', '西彼杵郡時津町', 'ニシソノギグントギツチョウ', '浜田郷', 'ハマダゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県西彼杵郡時津町元村郷', '42', '42308', '8512103', '長崎県', 'ナガサキケン', '西彼杵郡時津町', 'ニシソノギグントギツチョウ', '元村郷', 'モトムラゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県西彼杵郡時津町野田郷', '42', '42308', '8512104', '長崎県', 'ナガサキケン', '西彼杵郡時津町', 'ニシソノギグントギツチョウ', '野田郷', 'ノダゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県西彼杵郡時津町浦郷', '42', '42308', '8512105', '長崎県', 'ナガサキケン', '西彼杵郡時津町', 'ニシソノギグントギツチョウ', '浦郷', 'ウラゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県西彼杵郡時津町左底郷', '42', '42308', '8512106', '長崎県', 'ナガサキケン', '西彼杵郡時津町', 'ニシソノギグントギツチョウ', '左底郷', 'サソコゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県西彼杵郡時津町久留里郷', '42', '42308', '8512107', '長崎県', 'ナガサキケン', '西彼杵郡時津町', 'ニシソノギグントギツチョウ', '久留里郷', 'クルリゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県西彼杵郡時津町日並郷', '42', '42308', '8512108', '長崎県', 'ナガサキケン', '西彼杵郡時津町', 'ニシソノギグントギツチョウ', '日並郷', 'ヒナミゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道阿寒郡鶴居村下雪裡', '01', '01667', '0851211', '北海道', 'ホッカイドウ', '阿寒郡鶴居村', 'アカングンツルイムラ', '下雪裡', 'シモセツリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県西彼杵郡時津町子々川郷', '42', '42308', '8512111', '長崎県', 'ナガサキケン', '西彼杵郡時津町', 'ニシソノギグントギツチョウ', '子々川郷', 'シシガワゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道阿寒郡鶴居村支雪裡', '01', '01667', '0851212', '北海道', 'ホッカイドウ', '阿寒郡鶴居村', 'アカングンツルイムラ', '支雪裡', 'シセツリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県西彼杵郡長与町岡郷', '42', '42307', '8512121', '長崎県', 'ナガサキケン', '西彼杵郡長与町', 'ニシソノギグンナガヨチョウ', '岡郷', 'オカゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県西彼杵郡長与町本川内郷', '42', '42307', '8512122', '長崎県', 'ナガサキケン', '西彼杵郡長与町', 'ニシソノギグンナガヨチョウ', '本川内郷', 'ホンガワチゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県西彼杵郡長与町平木場郷', '42', '42307', '8512123', '長崎県', 'ナガサキケン', '西彼杵郡長与町', 'ニシソノギグンナガヨチョウ', '平木場郷', 'ヒラコバゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県西彼杵郡長与町丸田郷', '42', '42307', '8512124', '長崎県', 'ナガサキケン', '西彼杵郡長与町', 'ニシソノギグンナガヨチョウ', '丸田郷', 'マルタゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県西彼杵郡長与町三根郷', '42', '42307', '8512125', '長崎県', 'ナガサキケン', '西彼杵郡長与町', 'ニシソノギグンナガヨチョウ', '三根郷', 'ミネゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県西彼杵郡長与町吉無田郷', '42', '42307', '8512126', '長崎県', 'ナガサキケン', '西彼杵郡長与町', 'ニシソノギグンナガヨチョウ', '吉無田郷', 'ヨシムタゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県西彼杵郡長与町高田郷', '42', '42307', '8512127', '長崎県', 'ナガサキケン', '西彼杵郡長与町', 'ニシソノギグンナガヨチョウ', '高田郷', 'コウダゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県西彼杵郡長与町嬉里郷', '42', '42307', '8512128', '長崎県', 'ナガサキケン', '西彼杵郡長与町', 'ニシソノギグンナガヨチョウ', '嬉里郷', 'ウレリゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県西彼杵郡長与町斉藤郷', '42', '42307', '8512129', '長崎県', 'ナガサキケン', '西彼杵郡長与町', 'ニシソノギグンナガヨチョウ', '斉藤郷', 'サイトウゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道阿寒郡鶴居村茂雪裡', '01', '01667', '0851213', '北海道', 'ホッカイドウ', '阿寒郡鶴居村', 'アカングンツルイムラ', '茂雪裡', 'モセツリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県西彼杵郡長与町まなび野', '42', '42307', '8512130', '長崎県', 'ナガサキケン', '西彼杵郡長与町', 'ニシソノギグンナガヨチョウ', 'まなび野', 'マナビノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市畦町', '42', '42201', '8512201', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '畦町', 'アゼマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市樫山町', '42', '42201', '8512202', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '樫山町', 'カシヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市三重田町', '42', '42201', '8512203', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '三重田町', 'ミエダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市三重町', '42', '42201', '8512204', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '三重町', 'ミエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市松崎町', '42', '42201', '8512205', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '松崎町', 'マツザキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市三京町', '42', '42201', '8512206', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '三京町', 'サンキョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市さくらの里', '42', '42201', '8512207', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', 'さくらの里', 'サクラノサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市京泊', '42', '42201', '8512211', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '京泊', 'キョウドマリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市畝刈町', '42', '42201', '8512212', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '畝刈町', 'アゼカリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市多以良町', '42', '42201', '8512213', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '多以良町', 'タイラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市鳴見町', '42', '42201', '8512214', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '鳴見町', 'ナルミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市鳴見台', '42', '42201', '8512215', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '鳴見台', 'ナルミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市豊洋台', '42', '42201', '8512216', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '豊洋台', 'ホウヨウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市赤首町', '42', '42201', '8512321', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '赤首町', 'アカクビマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市西出津町', '42', '42201', '8512322', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '西出津町', 'ニシシツマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市新牧野町', '42', '42201', '8512323', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '新牧野町', 'シンマキノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市上黒崎町', '42', '42201', '8512324', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '上黒崎町', 'カミクロサキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市永田町', '42', '42201', '8512325', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '永田町', 'ナガタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市下黒崎町', '42', '42201', '8512326', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '下黒崎町', 'シモクロサキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市東出津町', '42', '42201', '8512327', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '東出津町', 'ヒガシシツマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市神浦口福町', '42', '42201', '8512401', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '神浦口福町', 'コウノウラクチブクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市神浦江川町', '42', '42201', '8512403', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '神浦江川町', 'コウノウラエガワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市神浦丸尾町', '42', '42201', '8512404', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '神浦丸尾町', 'コウノウラマルオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市神浦向町', '42', '42201', '8512405', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '神浦向町', 'コウノウラムカイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市神浦扇山町', '42', '42201', '8512411', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '神浦扇山町', 'コウノウラオオギヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市神浦夏井町', '42', '42201', '8512413', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '神浦夏井町', 'コウノウラナツイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市神浦北大中尾町', '42', '42201', '8512421', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '神浦北大中尾町', 'コウノウラキタオオナカオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市神浦上大中尾町', '42', '42201', '8512422', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '神浦上大中尾町', 'コウノウラカミオオナカオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市神浦下大中尾町', '42', '42201', '8512423', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '神浦下大中尾町', 'コウノウラシモオオナカオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市神浦上道徳町', '42', '42201', '8512424', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '神浦上道徳町', 'コウノウラカミドウトクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市神浦下道徳町', '42', '42201', '8512425', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '神浦下道徳町', 'コウノウラシモドウトクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市上大野町', '42', '42201', '8512426', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '上大野町', 'カミオオノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市下大野町', '42', '42201', '8512427', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '下大野町', 'シモオオノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市西海町', '42', '42201', '8513101', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '西海町', 'ニシウミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市琴海村松町', '42', '42201', '8513102', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '琴海村松町', 'キンカイムラマツマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市琴海戸根町', '42', '42201', '8513103', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '琴海戸根町', 'キンカイトネマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市琴海戸根原町', '42', '42201', '8513211', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '琴海戸根原町', 'キンカイトネハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市長浦町', '42', '42201', '8513212', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '長浦町', 'ナガウラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市琴海形上町', '42', '42201', '8513213', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '琴海形上町', 'キンカイカタガミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市琴海大平町', '42', '42201', '8513214', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '琴海大平町', 'キンカイオオヒラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市琴海尾戸町', '42', '42201', '8513215', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '琴海尾戸町', 'キンカイオドマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県西海市西彼町宮浦郷', '42', '42212', '8513301', '長崎県', 'ナガサキケン', '西海市', 'サイカイシ', '西彼町宮浦郷', 'セイヒチョウミヤウラゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県西海市西彼町中山郷', '42', '42212', '8513302', '長崎県', 'ナガサキケン', '西海市', 'サイカイシ', '西彼町中山郷', 'セイヒチョウナカヤマゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県西海市西彼町亀浦郷', '42', '42212', '8513303', '長崎県', 'ナガサキケン', '西海市', 'サイカイシ', '西彼町亀浦郷', 'セイヒチョウカメウラゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県西海市西彼町上岳郷', '42', '42212', '8513304', '長崎県', 'ナガサキケン', '西海市', 'サイカイシ', '西彼町上岳郷', 'セイヒチョウカミダケゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県西海市西彼町喰場郷', '42', '42212', '8513305', '長崎県', 'ナガサキケン', '西海市', 'サイカイシ', '西彼町喰場郷', 'セイヒチョウジキバゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県西海市西彼町鳥加郷川山', '42', '42212', '8513306', '長崎県', 'ナガサキケン', '西海市', 'サイカイシ', '西彼町鳥加郷', 'セイヒチョウトリカゴウ', null, null, '川山', 'カワヤマ');
INSERT INTO `ms_addresses` VALUES ('108986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県西海市西彼町下岳郷', '42', '42212', '8513311', '長崎県', 'ナガサキケン', '西海市', 'サイカイシ', '西彼町下岳郷', 'セイヒチョウシモタケゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県西海市西彼町白崎郷', '42', '42212', '8513312', '長崎県', 'ナガサキケン', '西海市', 'サイカイシ', '西彼町白崎郷', 'セイヒチョウシロサキゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県西海市西彼町風早郷', '42', '42212', '8513313', '長崎県', 'ナガサキケン', '西海市', 'サイカイシ', '西彼町風早郷', 'セイヒチョウカザハヤゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県西海市西彼町白似田郷', '42', '42212', '8513314', '長崎県', 'ナガサキケン', '西海市', 'サイカイシ', '西彼町白似田郷', 'セイヒチョウシラニタゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県西海市西彼町平原郷', '42', '42212', '8513315', '長崎県', 'ナガサキケン', '西海市', 'サイカイシ', '西彼町平原郷', 'セイヒチョウヒラバルゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県西海市西彼町鳥加郷', '42', '42212', '8513406', '長崎県', 'ナガサキケン', '西海市', 'サイカイシ', '西彼町鳥加郷', 'セイヒチョウトリカゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県西海市西彼町伊ノ浦郷', '42', '42212', '8513421', '長崎県', 'ナガサキケン', '西海市', 'サイカイシ', '西彼町伊ノ浦郷', 'セイヒチョウイノウラゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県西海市西彼町小迎郷', '42', '42212', '8513422', '長崎県', 'ナガサキケン', '西海市', 'サイカイシ', '西彼町小迎郷', 'セイヒチョウコムカエゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県西海市西彼町八木原郷', '42', '42212', '8513423', '長崎県', 'ナガサキケン', '西海市', 'サイカイシ', '西彼町八木原郷', 'セイヒチョウヤキハラゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県西海市西彼町大串郷', '42', '42212', '8513424', '長崎県', 'ナガサキケン', '西海市', 'サイカイシ', '西彼町大串郷', 'セイヒチョウオオクシゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県西海市西彼町平山郷', '42', '42212', '8513425', '長崎県', 'ナガサキケン', '西海市', 'サイカイシ', '西彼町平山郷', 'セイヒチョウヒラヤマゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('108999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県西海市', '42', '42212', '8513500', '長崎県', 'ナガサキケン', '西海市', 'サイカイシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('109000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県西海市西海町丹納郷', '42', '42212', '8513501', '長崎県', 'ナガサキケン', '西海市', 'サイカイシ', '西海町丹納郷', 'サイカイチョウタンノウゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県西海市西海町川内郷', '42', '42212', '8513502', '長崎県', 'ナガサキケン', '西海市', 'サイカイシ', '西海町川内郷', 'サイカイチョウカワチゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県西海市西海町太田原郷', '42', '42212', '8513503', '長崎県', 'ナガサキケン', '西海市', 'サイカイシ', '西海町太田原郷', 'サイカイチョウオオタハラゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県西海市西海町木場郷', '42', '42212', '8513504', '長崎県', 'ナガサキケン', '西海市', 'サイカイシ', '西海町木場郷', 'サイカイチョウコバゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県西海市西海町太田和郷', '42', '42212', '8513505', '長崎県', 'ナガサキケン', '西海市', 'サイカイシ', '西海町太田和郷', 'サイカイチョウオオタワゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県西海市西海町黒口郷', '42', '42212', '8513506', '長崎県', 'ナガサキケン', '西海市', 'サイカイシ', '西海町黒口郷', 'サイカイチョウクロクチゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県西海市西海町天久保郷', '42', '42212', '8513507', '長崎県', 'ナガサキケン', '西海市', 'サイカイシ', '西海町天久保郷', 'サイカイチョウアマクボゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県西海市西海町面高郷', '42', '42212', '8513508', '長崎県', 'ナガサキケン', '西海市', 'サイカイシ', '西海町面高郷', 'サイカイチョウオモダカゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県西海市西海町横瀬郷', '42', '42212', '8513509', '長崎県', 'ナガサキケン', '西海市', 'サイカイシ', '西海町横瀬郷', 'サイカイチョウヨコセゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県西海市西海町水浦郷', '42', '42212', '8513511', '長崎県', 'ナガサキケン', '西海市', 'サイカイシ', '西海町水浦郷', 'サイカイチョウミズノウラゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道阿寒郡鶴居村中久著呂', '01', '01667', '0851361', '北海道', 'ホッカイドウ', '阿寒郡鶴居村', 'アカングンツルイムラ', '中久著呂', 'ナカクチョロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道阿寒郡鶴居村下久著呂', '01', '01667', '0851362', '北海道', 'ホッカイドウ', '阿寒郡鶴居村', 'アカングンツルイムラ', '下久著呂', 'シモクチョロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道川上郡標茶町中久著呂市街', '01', '01664', '0851381', '北海道', 'ホッカイドウ', '川上郡標茶町', 'カワカミグンシベチャチョウ', '中久著呂市街', 'ナカクチョロシガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道川上郡標茶町中久著呂', '01', '01664', '0851382', '北海道', 'ホッカイドウ', '川上郡標茶町', 'カワカミグンシベチャチョウ', '中久著呂', 'ナカクチョロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道川上郡標茶町上久著呂', '01', '01664', '0851383', '北海道', 'ホッカイドウ', '川上郡標茶町', 'カワカミグンシベチャチョウ', '上久著呂', 'カミクチョロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道川上郡標茶町上沼幌', '01', '01664', '0851384', '北海道', 'ホッカイドウ', '川上郡標茶町', 'カワカミグンシベチャチョウ', '上沼幌', 'カミヌマホロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道川上郡標茶町下沼幌', '01', '01664', '0851385', '北海道', 'ホッカイドウ', '川上郡標茶町', 'カワカミグンシベチャチョウ', '下沼幌', 'シモヌマホロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道川上郡標茶町新久著呂', '01', '01664', '0851386', '北海道', 'ホッカイドウ', '川上郡標茶町', 'カワカミグンシベチャチョウ', '新久著呂', 'シンクチョロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道川上郡標茶町下久著呂', '01', '01664', '0851387', '北海道', 'ホッカイドウ', '川上郡標茶町', 'カワカミグンシベチャチョウ', '下久著呂', 'シモクチョロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道川上郡標茶町コッタロ', '01', '01664', '0851388', '北海道', 'ホッカイドウ', '川上郡標茶町', 'カワカミグンシベチャチョウ', 'コッタロ', 'コッタロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路郡釧路町跡永賀村', '01', '01661', '0852271', '北海道', 'ホッカイドウ', '釧路郡釧路町', 'クシログンクシロチョウ', '跡永賀村', 'アトエカムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路郡釧路町昆布森', '01', '01661', '0852272', '北海道', 'ホッカイドウ', '釧路郡釧路町', 'クシログンクシロチョウ', '昆布森', 'コンブモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路郡釧路町昆布森村', '01', '01661', '0852273', '北海道', 'ホッカイドウ', '釧路郡釧路町', 'クシログンクシロチョウ', '昆布森村', 'コンブモリムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市光町', '42', '42201', '8528001', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '光町', 'ヒカリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市弁天町', '42', '42201', '8528002', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '弁天町', 'ベンテンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市旭町', '42', '42201', '8528003', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '旭町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市丸尾町', '42', '42201', '8528004', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '丸尾町', 'マルオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市大鳥町', '42', '42201', '8528005', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '大鳥町', 'オオトリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市平戸小屋町', '42', '42201', '8528006', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '平戸小屋町', 'ヒラドゴヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市江の浦町', '42', '42201', '8528007', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '江の浦町', 'エノウラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市曙町', '42', '42201', '8528008', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '曙町', 'アケボノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市稲佐町', '42', '42201', '8528011', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '稲佐町', 'イナサマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市淵町', '42', '42201', '8528012', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '淵町', 'フチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市梁川町', '42', '42201', '8528013', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '梁川町', 'ヤナガワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市竹の久保町', '42', '42201', '8528014', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '竹の久保町', 'タケノクボマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市春木町', '42', '42201', '8528015', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '春木町', 'ハルキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市宝栄町', '42', '42201', '8528016', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '宝栄町', 'ホウエイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市岩見町', '42', '42201', '8528017', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '岩見町', 'イワミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市城山町', '42', '42201', '8528021', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '城山町', 'シロヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市富士見町', '42', '42201', '8528022', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '富士見町', 'フジミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市若草町', '42', '42201', '8528023', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '若草町', 'ワカクサマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市花園町', '42', '42201', '8528024', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '花園町', 'ハナゾノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市立岩町', '42', '42201', '8528025', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '立岩町', 'タテイワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市金堀町', '42', '42201', '8528026', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '金堀町', 'カナホリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市城山台', '42', '42201', '8528027', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '城山台', 'シロヤマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市三芳町', '42', '42201', '8528031', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '三芳町', 'ミヨシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市江里町', '42', '42201', '8528032', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '江里町', 'エリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市緑が丘町', '42', '42201', '8528033', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '緑が丘町', 'ミドリガオカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市城栄町', '42', '42201', '8528034', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '城栄町', 'ジョウエイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市油木町', '42', '42201', '8528035', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '油木町', 'アブラギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市青山町', '42', '42201', '8528036', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '青山町', 'アオヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市清水町', '42', '42201', '8528041', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '清水町', 'シミズマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市白鳥町', '42', '42201', '8528042', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '白鳥町', 'シラトリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市西町', '42', '42201', '8528043', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '西町', 'ニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市音無町', '42', '42201', '8528044', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '音無町', 'オトナシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市錦', '42', '42201', '8528045', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '錦', 'ニシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市柳谷町', '42', '42201', '8528046', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '柳谷町', 'ヤナギダニマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市若竹町', '42', '42201', '8528047', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '若竹町', 'ワカタケマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市西北町', '42', '42201', '8528051', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '西北町', 'ニシキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市岩屋町', '42', '42201', '8528052', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '岩屋町', 'イワヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市葉山', '42', '42201', '8528053', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '葉山', 'ハヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市エミネント葉山町', '42', '42201', '8528054', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', 'エミネント葉山町', 'エミネントハヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市虹が丘町', '42', '42201', '8528055', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '虹が丘町', 'ニジガオカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市大宮町', '42', '42201', '8528056', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '大宮町', 'オオミヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市滑石', '42', '42201', '8528061', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '滑石', 'ナメシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市大園町', '42', '42201', '8528062', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '大園町', 'オオゾノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市北栄町', '42', '42201', '8528063', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '北栄町', 'ホクエイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市北陽町', '42', '42201', '8528064', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '北陽町', 'ホクヨウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市横尾', '42', '42201', '8528065', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '横尾', 'ヨコオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市江平', '42', '42201', '8528101', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '江平', 'エビラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市坂本', '42', '42201', '8528102', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '坂本', 'サカモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市緑町', '42', '42201', '8528103', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '緑町', 'ミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市茂里町', '42', '42201', '8528104', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '茂里町', 'モリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市目覚町', '42', '42201', '8528105', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '目覚町', 'メザメマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市岩川町', '42', '42201', '8528106', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '岩川町', 'イワカワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市浜口町', '42', '42201', '8528107', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '浜口町', 'ハマグチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市川口町', '42', '42201', '8528108', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '川口町', 'カワグチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市高尾町', '42', '42201', '8528111', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '高尾町', 'タカオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市本尾町', '42', '42201', '8528112', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '本尾町', 'モトオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市上野町', '42', '42201', '8528113', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '上野町', 'ウエノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市橋口町', '42', '42201', '8528114', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '橋口町', 'ハシグチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市岡町', '42', '42201', '8528115', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '岡町', 'オカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市平和町', '42', '42201', '8528116', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '平和町', 'ヘイワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市平野町', '42', '42201', '8528117', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '平野町', 'ヒラノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市松山町', '42', '42201', '8528118', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '松山町', 'マツヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市三川町', '42', '42201', '8528121', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '三川町', 'ミカワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市西山台', '42', '42201', '8528122', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '西山台', 'ニシヤマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市三原', '42', '42201', '8528123', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '三原', 'ミハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市辻町', '42', '42201', '8528124', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '辻町', 'ツジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市小峰町', '42', '42201', '8528125', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '小峰町', 'コミネマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市石神町', '42', '42201', '8528126', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '石神町', 'イシガミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市大手', '42', '42201', '8528127', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '大手', 'オオテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市文教町', '42', '42201', '8528131', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '文教町', 'ブンキョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市扇町', '42', '42201', '8528132', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '扇町', 'オウギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市本原町', '42', '42201', '8528133', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '本原町', 'モトハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市大橋町', '42', '42201', '8528134', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '大橋町', 'オオハシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市千歳町', '42', '42201', '8528135', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '千歳町', 'チトセマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市家野町', '42', '42201', '8528136', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '家野町', 'イエノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市若葉町', '42', '42201', '8528137', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '若葉町', 'ワカバマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市畦別当町', '42', '42201', '8528141', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '畦別当町', 'アゼベツトウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市三ツ山町', '42', '42201', '8528142', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '三ツ山町', 'ミツヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市川平町', '42', '42201', '8528143', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '川平町', 'カワヒラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市女の都', '42', '42201', '8528144', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '女の都', 'メノト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市昭和', '42', '42201', '8528145', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '昭和', 'ショウワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市けやき台町', '42', '42201', '8528146', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', 'けやき台町', 'ケヤキダイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市泉', '42', '42201', '8528151', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '泉', 'イズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市住吉台町', '42', '42201', '8528152', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '住吉台町', 'スミヨシダイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市花丘町', '42', '42201', '8528153', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '花丘町', 'ハナオカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市住吉町', '42', '42201', '8528154', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '住吉町', 'スミヨシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市中園町', '42', '42201', '8528155', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '中園町', 'ナカゾノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市赤迫', '42', '42201', '8528156', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '赤迫', 'アカサコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市泉町', '42', '42201', '8528157', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '泉町', 'イズミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県五島市', '42', '42211', '8530000', '長崎県', 'ナガサキケン', '五島市', 'ゴトウシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('109138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県五島市栄町', '42', '42211', '8530001', '長崎県', 'ナガサキケン', '五島市', 'ゴトウシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県五島市中央町', '42', '42211', '8530002', '長崎県', 'ナガサキケン', '五島市', 'ゴトウシ', '中央町', 'チュウオウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県五島市錦町', '42', '42211', '8530003', '長崎県', 'ナガサキケン', '五島市', 'ゴトウシ', '錦町', 'ニシキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県五島市幸町', '42', '42211', '8530004', '長崎県', 'ナガサキケン', '五島市', 'ゴトウシ', '幸町', 'サイワイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県五島市末広町', '42', '42211', '8530005', '長崎県', 'ナガサキケン', '五島市', 'ゴトウシ', '末広町', 'スエヒロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県五島市江川町', '42', '42211', '8530006', '長崎県', 'ナガサキケン', '五島市', 'ゴトウシ', '江川町', 'エガワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県五島市福江町', '42', '42211', '8530007', '長崎県', 'ナガサキケン', '五島市', 'ゴトウシ', '福江町', 'フクエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県五島市下大津町', '42', '42211', '8530011', '長崎県', 'ナガサキケン', '五島市', 'ゴトウシ', '下大津町', 'シモオオヅチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県五島市長手町', '42', '42211', '8530012', '長崎県', 'ナガサキケン', '五島市', 'ゴトウシ', '長手町', 'ナガテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県五島市上大津町', '42', '42211', '8530013', '長崎県', 'ナガサキケン', '五島市', 'ゴトウシ', '上大津町', 'カミオオヅチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県五島市三尾野町', '42', '42211', '8530014', '長崎県', 'ナガサキケン', '五島市', 'ゴトウシ', '三尾野町', 'ミオノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県五島市東浜町', '42', '42211', '8530015', '長崎県', 'ナガサキケン', '五島市', 'ゴトウシ', '東浜町', 'ヒガシハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県五島市紺屋町', '42', '42211', '8530016', '長崎県', 'ナガサキケン', '五島市', 'ゴトウシ', '紺屋町', 'コンヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県五島市武家屋敷', '42', '42211', '8530017', '長崎県', 'ナガサキケン', '五島市', 'ゴトウシ', '武家屋敷', 'ブケヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県五島市池田町', '42', '42211', '8530018', '長崎県', 'ナガサキケン', '五島市', 'ゴトウシ', '池田町', 'イケダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県五島市下崎山町', '42', '42211', '8530021', '長崎県', 'ナガサキケン', '五島市', 'ゴトウシ', '下崎山町', 'シモサキヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県五島市向町', '42', '42211', '8530022', '長崎県', 'ナガサキケン', '五島市', 'ゴトウシ', '向町', 'ムカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県五島市上崎山町', '42', '42211', '8530023', '長崎県', 'ナガサキケン', '五島市', 'ゴトウシ', '上崎山町', 'カミサキヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県五島市野々切町', '42', '42211', '8530024', '長崎県', 'ナガサキケン', '五島市', 'ゴトウシ', '野々切町', 'ノノキレチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県五島市小泊町', '42', '42211', '8530025', '長崎県', 'ナガサキケン', '五島市', 'ゴトウシ', '小泊町', 'オドマリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県五島市浜町', '42', '42211', '8530026', '長崎県', 'ナガサキケン', '五島市', 'ゴトウシ', '浜町', 'ハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県五島市増田町', '42', '42211', '8530027', '長崎県', 'ナガサキケン', '五島市', 'ゴトウシ', '増田町', 'マスダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県五島市吉久木町', '42', '42211', '8530031', '長崎県', 'ナガサキケン', '五島市', 'ゴトウシ', '吉久木町', 'ヨシクギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県五島市大荒町', '42', '42211', '8530032', '長崎県', 'ナガサキケン', '五島市', 'ゴトウシ', '大荒町', 'オオアレチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県五島市木場町', '42', '42211', '8530033', '長崎県', 'ナガサキケン', '五島市', 'ゴトウシ', '木場町', 'コバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県五島市籠淵町', '42', '42211', '8530041', '長崎県', 'ナガサキケン', '五島市', 'ゴトウシ', '籠淵町', 'コモリブチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県五島市吉田町', '42', '42211', '8530042', '長崎県', 'ナガサキケン', '五島市', 'ゴトウシ', '吉田町', 'ヨシダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県五島市高田町', '42', '42211', '8530043', '長崎県', 'ナガサキケン', '五島市', 'ゴトウシ', '高田町', 'コウダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県五島市堤町', '42', '42211', '8530044', '長崎県', 'ナガサキケン', '五島市', 'ゴトウシ', '堤町', 'ツツミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県五島市平蔵町', '42', '42211', '8530051', '長崎県', 'ナガサキケン', '五島市', 'ゴトウシ', '平蔵町', 'ヒラゾウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県五島市松山町', '42', '42211', '8530052', '長崎県', 'ナガサキケン', '五島市', 'ゴトウシ', '松山町', 'マツヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県五島市奥浦町', '42', '42211', '8530053', '長崎県', 'ナガサキケン', '五島市', 'ゴトウシ', '奥浦町', 'オクウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県五島市戸岐町', '42', '42211', '8530054', '長崎県', 'ナガサキケン', '五島市', 'ゴトウシ', '戸岐町', 'トギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県五島市黄島町', '42', '42211', '8530061', '長崎県', 'ナガサキケン', '五島市', 'ゴトウシ', '黄島町', 'オウシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県五島市赤島町', '42', '42211', '8530062', '長崎県', 'ナガサキケン', '五島市', 'ゴトウシ', '赤島町', 'アカシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県五島市新港町', '42', '42211', '8530063', '長崎県', 'ナガサキケン', '五島市', 'ゴトウシ', '新港町', 'シンミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県五島市三尾野', '42', '42211', '8530064', '長崎県', 'ナガサキケン', '五島市', 'ゴトウシ', '三尾野', 'ミオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県五島市坂の上', '42', '42211', '8530065', '長崎県', 'ナガサキケン', '五島市', 'ゴトウシ', '坂の上', 'サカノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県五島市大円寺町', '42', '42211', '8530066', '長崎県', 'ナガサキケン', '五島市', 'ゴトウシ', '大円寺町', 'ダイエンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県五島市富江町富江', '42', '42211', '8530201', '長崎県', 'ナガサキケン', '五島市', 'ゴトウシ', '富江町富江', 'トミエマチトミエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県五島市富江町松尾', '42', '42211', '8530202', '長崎県', 'ナガサキケン', '五島市', 'ゴトウシ', '富江町松尾', 'トミエマチマツオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県五島市富江町田尾', '42', '42211', '8530203', '長崎県', 'ナガサキケン', '五島市', 'ゴトウシ', '富江町田尾', 'トミエマチタオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県五島市富江町繁敷', '42', '42211', '8530204', '長崎県', 'ナガサキケン', '五島市', 'ゴトウシ', '富江町繁敷', 'トミエマチシゲジキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県五島市富江町狩立', '42', '42211', '8530205', '長崎県', 'ナガサキケン', '五島市', 'ゴトウシ', '富江町狩立', 'トミエマチカリタテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県五島市富江町山手', '42', '42211', '8530206', '長崎県', 'ナガサキケン', '五島市', 'ゴトウシ', '富江町山手', 'トミエマチヤマテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県五島市富江町長峰', '42', '42211', '8530207', '長崎県', 'ナガサキケン', '五島市', 'ゴトウシ', '富江町長峰', 'トミエマチナガミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県五島市富江町黒島', '42', '42211', '8530208', '長崎県', 'ナガサキケン', '五島市', 'ゴトウシ', '富江町黒島', 'トミエマチクロシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県五島市富江町黒瀬', '42', '42211', '8530211', '長崎県', 'ナガサキケン', '五島市', 'ゴトウシ', '富江町黒瀬', 'トミエマチクロセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県五島市富江町山下', '42', '42211', '8530212', '長崎県', 'ナガサキケン', '五島市', 'ゴトウシ', '富江町山下', 'トミエマチヤマシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県五島市富江町岳', '42', '42211', '8530213', '長崎県', 'ナガサキケン', '五島市', 'ゴトウシ', '富江町岳', 'トミエマチタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県五島市富江町土取', '42', '42211', '8530214', '長崎県', 'ナガサキケン', '五島市', 'ゴトウシ', '富江町土取', 'トミエマチツチトリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県五島市富江町職人', '42', '42211', '8530215', '長崎県', 'ナガサキケン', '五島市', 'ゴトウシ', '富江町職人', 'トミエマチショクニン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県五島市岐宿町二本楠', '42', '42211', '8530311', '長崎県', 'ナガサキケン', '五島市', 'ゴトウシ', '岐宿町二本楠', 'キシクマチニホングス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県五島市岐宿町中嶽', '42', '42211', '8530312', '長崎県', 'ナガサキケン', '五島市', 'ゴトウシ', '岐宿町中嶽', 'キシクマチナカダケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県五島市岐宿町松山', '42', '42211', '8530313', '長崎県', 'ナガサキケン', '五島市', 'ゴトウシ', '岐宿町松山', 'キシクマチマツヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県五島市玉之浦町玉之浦', '42', '42211', '8530411', '長崎県', 'ナガサキケン', '五島市', 'ゴトウシ', '玉之浦町玉之浦', 'タマノウラマチタマノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県五島市玉之浦町立谷', '42', '42211', '8530412', '長崎県', 'ナガサキケン', '五島市', 'ゴトウシ', '玉之浦町立谷', 'タマノウラマチタチヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県五島市玉之浦町大宝', '42', '42211', '8530413', '長崎県', 'ナガサキケン', '五島市', 'ゴトウシ', '玉之浦町大宝', 'タマノウラマチダイホウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県五島市玉之浦町荒川', '42', '42211', '8530501', '長崎県', 'ナガサキケン', '五島市', 'ゴトウシ', '玉之浦町荒川', 'タマノウラマチアラカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県五島市玉之浦町幾久山', '42', '42211', '8530502', '長崎県', 'ナガサキケン', '五島市', 'ゴトウシ', '玉之浦町幾久山', 'タマノウラマチイツクヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県五島市玉之浦町小川', '42', '42211', '8530503', '長崎県', 'ナガサキケン', '五島市', 'ゴトウシ', '玉之浦町小川', 'タマノウラマチオガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県五島市玉之浦町丹奈', '42', '42211', '8530504', '長崎県', 'ナガサキケン', '五島市', 'ゴトウシ', '玉之浦町丹奈', 'タマノウラマチタンナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県五島市玉之浦町中須', '42', '42211', '8530505', '長崎県', 'ナガサキケン', '五島市', 'ゴトウシ', '玉之浦町中須', 'タマノウラマチナカス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県五島市玉之浦町上の平', '42', '42211', '8530506', '長崎県', 'ナガサキケン', '五島市', 'ゴトウシ', '玉之浦町上の平', 'タマノウラマチカミノヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県五島市玉之浦町頓泊', '42', '42211', '8530507', '長崎県', 'ナガサキケン', '五島市', 'ゴトウシ', '玉之浦町頓泊', 'タマノウラマチトントマリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県五島市玉之浦町布浦', '42', '42211', '8530508', '長崎県', 'ナガサキケン', '五島市', 'ゴトウシ', '玉之浦町布浦', 'タマノウラマチヌノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県五島市三井楽町濱ノ畔', '42', '42211', '8530601', '長崎県', 'ナガサキケン', '五島市', 'ゴトウシ', '三井楽町濱ノ畔', 'ミイラクマチハマノクリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県五島市三井楽町大川', '42', '42211', '8530602', '長崎県', 'ナガサキケン', '五島市', 'ゴトウシ', '三井楽町大川', 'ミイラクマチオオカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県五島市三井楽町柏', '42', '42211', '8530603', '長崎県', 'ナガサキケン', '五島市', 'ゴトウシ', '三井楽町柏', 'ミイラクマチカシワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県五島市三井楽町貝津', '42', '42211', '8530604', '長崎県', 'ナガサキケン', '五島市', 'ゴトウシ', '三井楽町貝津', 'ミイラクマチカイツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県五島市三井楽町濱窄', '42', '42211', '8530605', '長崎県', 'ナガサキケン', '五島市', 'ゴトウシ', '三井楽町濱窄', 'ミイラクマチハマサコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県五島市三井楽町丑ノ浦', '42', '42211', '8530606', '長崎県', 'ナガサキケン', '五島市', 'ゴトウシ', '三井楽町丑ノ浦', 'ミイラクマチウシノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県五島市三井楽町嶽', '42', '42211', '8530607', '長崎県', 'ナガサキケン', '五島市', 'ゴトウシ', '三井楽町嶽', 'ミイラクマチタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県五島市三井楽町波砂間', '42', '42211', '8530608', '長崎県', 'ナガサキケン', '五島市', 'ゴトウシ', '三井楽町波砂間', 'ミイラクマチハサマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県五島市三井楽町渕ノ元', '42', '42211', '8530609', '長崎県', 'ナガサキケン', '五島市', 'ゴトウシ', '三井楽町渕ノ元', 'ミイラクマチフチノモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県五島市三井楽町嵯峨島', '42', '42211', '8530611', '長崎県', 'ナガサキケン', '五島市', 'ゴトウシ', '三井楽町嵯峨島', 'ミイラクマチサガノシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県五島市三井楽町高崎', '42', '42211', '8530612', '長崎県', 'ナガサキケン', '五島市', 'ゴトウシ', '三井楽町高崎', 'ミイラクマチタカサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県五島市三井楽町塩水', '42', '42211', '8530613', '長崎県', 'ナガサキケン', '五島市', 'ゴトウシ', '三井楽町塩水', 'ミイラクマチシオミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県五島市岐宿町岐宿', '42', '42211', '8530701', '長崎県', 'ナガサキケン', '五島市', 'ゴトウシ', '岐宿町岐宿', 'キシクマチキシク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県五島市岐宿町川原', '42', '42211', '8530702', '長崎県', 'ナガサキケン', '五島市', 'ゴトウシ', '岐宿町川原', 'キシクマチカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県五島市岐宿町楠原', '42', '42211', '8530703', '長崎県', 'ナガサキケン', '五島市', 'ゴトウシ', '岐宿町楠原', 'キシクマチクスハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県五島市岐宿町河務', '42', '42211', '8530704', '長崎県', 'ナガサキケン', '五島市', 'ゴトウシ', '岐宿町河務', 'キシクマチコウム', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県五島市岐宿町戸岐ノ首', '42', '42211', '8530705', '長崎県', 'ナガサキケン', '五島市', 'ゴトウシ', '岐宿町戸岐ノ首', 'キシクマチトギノクビ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県五島市岐宿町唐船ノ浦', '42', '42211', '8530706', '長崎県', 'ナガサキケン', '五島市', 'ゴトウシ', '岐宿町唐船ノ浦', 'キシクマチトウセンノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県五島市久賀町', '42', '42211', '8532171', '長崎県', 'ナガサキケン', '五島市', 'ゴトウシ', '久賀町', 'ヒサカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県五島市蕨町', '42', '42211', '8532172', '長崎県', 'ナガサキケン', '五島市', 'ゴトウシ', '蕨町', 'ワラビチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県五島市田ノ浦町', '42', '42211', '8532173', '長崎県', 'ナガサキケン', '五島市', 'ゴトウシ', '田ノ浦町', 'タノウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県五島市猪之木町', '42', '42211', '8532174', '長崎県', 'ナガサキケン', '五島市', 'ゴトウシ', '猪之木町', 'イノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県五島市奈留町浦', '42', '42211', '8532201', '長崎県', 'ナガサキケン', '五島市', 'ゴトウシ', '奈留町浦', 'ナルマチウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県五島市奈留町大串', '42', '42211', '8532202', '長崎県', 'ナガサキケン', '五島市', 'ゴトウシ', '奈留町大串', 'ナルマチオオクシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県五島市奈留町泊', '42', '42211', '8532203', '長崎県', 'ナガサキケン', '五島市', 'ゴトウシ', '奈留町泊', 'ナルマチトマリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県五島市奈留町船廻', '42', '42211', '8532204', '長崎県', 'ナガサキケン', '五島市', 'ゴトウシ', '奈留町船廻', 'ナルマチフナマワリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県南松浦郡新上五島町若松郷', '42', '42411', '8532301', '長崎県', 'ナガサキケン', '南松浦郡新上五島町', 'ミナミマツウラグンシンカミゴトウチョウ', '若松郷', 'ワカマツゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県南松浦郡新上五島町桐古里郷', '42', '42411', '8532302', '長崎県', 'ナガサキケン', '南松浦郡新上五島町', 'ミナミマツウラグンシンカミゴトウチョウ', '桐古里郷', 'キリフルサトゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県南松浦郡新上五島町宿ノ浦郷', '42', '42411', '8532303', '長崎県', 'ナガサキケン', '南松浦郡新上五島町', 'ミナミマツウラグンシンカミゴトウチョウ', '宿ノ浦郷', 'シュクノウラゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県南松浦郡新上五島町荒川郷', '42', '42411', '8532304', '長崎県', 'ナガサキケン', '南松浦郡新上五島町', 'ミナミマツウラグンシンカミゴトウチョウ', '荒川郷', 'アラカワゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県南松浦郡新上五島町西神ノ浦郷', '42', '42411', '8532305', '長崎県', 'ナガサキケン', '南松浦郡新上五島町', 'ミナミマツウラグンシンカミゴトウチョウ', '西神ノ浦郷', 'ニシコウノウラゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県南松浦郡新上五島町榊ノ浦郷', '42', '42411', '8532311', '長崎県', 'ナガサキケン', '南松浦郡新上五島町', 'ミナミマツウラグンシンカミゴトウチョウ', '榊ノ浦郷', 'サカキノウラゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県南松浦郡新上五島町日島郷', '42', '42411', '8532312', '長崎県', 'ナガサキケン', '南松浦郡新上五島町', 'ミナミマツウラグンシンカミゴトウチョウ', '日島郷', 'ヒノシマゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県南松浦郡新上五島町有福郷', '42', '42411', '8532313', '長崎県', 'ナガサキケン', '南松浦郡新上五島町', 'ミナミマツウラグンシンカミゴトウチョウ', '有福郷', 'アリフクゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県南松浦郡新上五島町漁生浦郷', '42', '42411', '8532314', '長崎県', 'ナガサキケン', '南松浦郡新上五島町', 'ミナミマツウラグンシンカミゴトウチョウ', '漁生浦郷', 'リョウセウラゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県南松浦郡新上五島町間伏郷', '42', '42411', '8532315', '長崎県', 'ナガサキケン', '南松浦郡新上五島町', 'ミナミマツウラグンシンカミゴトウチョウ', '間伏郷', 'マブシゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県五島市伊福貴町', '42', '42211', '8532481', '長崎県', 'ナガサキケン', '五島市', 'ゴトウシ', '伊福貴町', 'イフキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県五島市本窯町', '42', '42211', '8532482', '長崎県', 'ナガサキケン', '五島市', 'ゴトウシ', '本窯町', 'モトガマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県南松浦郡新上五島町奈良尾郷', '42', '42411', '8533101', '長崎県', 'ナガサキケン', '南松浦郡新上五島町', 'ミナミマツウラグンシンカミゴトウチョウ', '奈良尾郷', 'ナラオゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県南松浦郡新上五島町岩瀬浦郷', '42', '42411', '8533102', '長崎県', 'ナガサキケン', '南松浦郡新上五島町', 'ミナミマツウラグンシンカミゴトウチョウ', '岩瀬浦郷', 'イワセウラゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県南松浦郡新上五島町鯛ノ浦郷', '42', '42411', '8533321', '長崎県', 'ナガサキケン', '南松浦郡新上五島町', 'ミナミマツウラグンシンカミゴトウチョウ', '鯛ノ浦郷', 'タイノウラゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県南松浦郡新上五島町阿瀬津郷', '42', '42411', '8533322', '長崎県', 'ナガサキケン', '南松浦郡新上五島町', 'ミナミマツウラグンシンカミゴトウチョウ', '阿瀬津郷', 'アゼツゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県南松浦郡新上五島町東神ノ浦郷', '42', '42411', '8533323', '長崎県', 'ナガサキケン', '南松浦郡新上五島町', 'ミナミマツウラグンシンカミゴトウチョウ', '東神ノ浦郷', 'ヒガシコウノウラゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市', '42', '42204', '8540000', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('109254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市福田町', '42', '42204', '8540001', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '福田町', 'フクダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市日の出町', '42', '42204', '8540002', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '日の出町', 'ヒノデマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市泉町', '42', '42204', '8540003', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '泉町', 'イズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市金谷町', '42', '42204', '8540004', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '金谷町', 'カナヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市城見町', '42', '42204', '8540005', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '城見町', 'シロミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市天満町', '42', '42204', '8540006', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '天満町', 'テンマンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市目代町', '42', '42204', '8540007', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '目代町', 'メシロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市八天町', '42', '42204', '8540011', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '八天町', 'ハッテンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市本町', '42', '42204', '8540012', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市栄町', '42', '42204', '8540013', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市東小路町', '42', '42204', '8540014', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '東小路町', 'ヒガシコウジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市西小路町', '42', '42204', '8540015', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '西小路町', 'ニシコウジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市高城町', '42', '42204', '8540016', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '高城町', 'タカシロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市仲沖町', '42', '42204', '8540021', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '仲沖町', 'ナカオキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市幸町', '42', '42204', '8540022', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '幸町', 'サイワイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市厚生町', '42', '42204', '8540023', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '厚生町', 'コウセイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市上町', '42', '42204', '8540024', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '上町', 'カミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市八坂町', '42', '42204', '8540025', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '八坂町', 'ヤサカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市東本町', '42', '42204', '8540026', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '東本町', 'ヒガシホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市旭町', '42', '42204', '8540027', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '旭町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市小野島町', '42', '42204', '8540031', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '小野島町', 'オノジママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市赤崎町', '42', '42204', '8540032', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '赤崎町', 'アカサキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市黒崎町', '42', '42204', '8540033', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '黒崎町', 'クロサキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市小野町', '42', '42204', '8540034', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '小野町', 'オノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市宗方町', '42', '42204', '8540035', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '宗方町', 'ムナカタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市長野町', '42', '42204', '8540036', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '長野町', 'ナガノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市川内町', '42', '42204', '8540037', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '川内町', 'カワチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市中央干拓', '42', '42204', '8540038', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '中央干拓', 'チュウオウカンタク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市船越町', '42', '42204', '8540041', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '船越町', 'フナコシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市上野町', '42', '42204', '8540042', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '上野町', 'ウエノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市立石町', '42', '42204', '8540043', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '立石町', 'タテイシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市西郷町', '42', '42204', '8540044', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '西郷町', 'ニシゴウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市新道町', '42', '42204', '8540045', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '新道町', 'シンミチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市原口町', '42', '42204', '8540046', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '原口町', 'ハラグチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市野中町', '42', '42204', '8540047', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '野中町', 'ノナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市鷲崎町', '42', '42204', '8540051', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '鷲崎町', 'ワシザキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市川床町', '42', '42204', '8540052', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '川床町', 'カワトコマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市小川町', '42', '42204', '8540053', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '小川町', 'オガワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市小ケ倉町', '42', '42204', '8540054', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '小ケ倉町', 'コガクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市栗面町', '42', '42204', '8540055', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '栗面町', 'クレモマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市土師野尾町', '42', '42204', '8540056', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '土師野尾町', 'ハジノオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市平山町', '42', '42204', '8540057', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '平山町', 'ヒラヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市宇都町', '42', '42204', '8540061', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '宇都町', 'ウヅマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市小船越町', '42', '42204', '8540062', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '小船越町', 'オブナコシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市貝津町', '42', '42204', '8540063', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '貝津町', 'カイヅマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市若葉町', '42', '42204', '8540064', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '若葉町', 'ワカバマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市津久葉町', '42', '42204', '8540065', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '津久葉町', 'ツクバマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市久山町', '42', '42204', '8540066', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '久山町', 'クヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市久山台', '42', '42204', '8540067', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '久山台', 'クヤマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市青葉台', '42', '42204', '8540068', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '青葉台', 'アオバダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市永昌東町', '42', '42204', '8540071', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '永昌東町', 'エイショウヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市永昌町', '42', '42204', '8540072', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '永昌町', 'エイショウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市中尾町', '42', '42204', '8540073', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '中尾町', 'ナカオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市山川町', '42', '42204', '8540074', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '山川町', 'ヤマカワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市馬渡町', '42', '42204', '8540075', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '馬渡町', 'マワタリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市堂崎町', '42', '42204', '8540076', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '堂崎町', 'ドウザキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市白岩町', '42', '42204', '8540077', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '白岩町', 'シライワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市栄田町', '42', '42204', '8540081', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '栄田町', 'エイダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市西栄田町', '42', '42204', '8540082', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '西栄田町', 'ニシエイダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市津水町', '42', '42204', '8540083', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '津水町', 'ツミズマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市真崎町', '42', '42204', '8540084', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '真崎町', 'マサキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市破籠井町', '42', '42204', '8540085', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '破籠井町', 'ワリゴイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市堀の内町', '42', '42204', '8540086', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '堀の内町', 'ホリノウチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市富川町', '42', '42204', '8540091', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '富川町', 'トミガワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市湯野尾町', '42', '42204', '8540092', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '湯野尾町', 'ユノオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市本野町', '42', '42204', '8540093', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '本野町', 'モトノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市本明町', '42', '42204', '8540094', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '本明町', 'ホンミョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市上大渡野町', '42', '42204', '8540095', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '上大渡野町', 'カミオオワタノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市下大渡野町', '42', '42204', '8540096', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '下大渡野町', 'シモオオワタノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市有喜町', '42', '42204', '8540121', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '有喜町', 'ウキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市鶴田町', '42', '42204', '8540122', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '鶴田町', 'ツルタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市天神町', '42', '42204', '8540123', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '天神町', 'テンジンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市中通町', '42', '42204', '8540124', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '中通町', 'ナカドオリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市早見町', '42', '42204', '8540125', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '早見町', 'ハヤミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市松里町', '42', '42204', '8540126', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '松里町', 'マツザトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市森山町下井牟田', '42', '42204', '8540201', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '森山町下井牟田', 'モリヤマチョウシモイムタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市森山町慶師野', '42', '42204', '8540202', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '森山町慶師野', 'モリヤマチョウケイシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市森山町本村', '42', '42204', '8540203', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '森山町本村', 'モリヤマチョウホンムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市森山町田尻', '42', '42204', '8540204', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '森山町田尻', 'モリヤマチョウタシリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市森山町杉谷', '42', '42204', '8540205', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '森山町杉谷', 'モリヤマチョウスギタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市森山町唐比北', '42', '42204', '8540206', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '森山町唐比北', 'モリヤマチョウカラコキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市森山町唐比東', '42', '42204', '8540207', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '森山町唐比東', 'モリヤマチョウカラコヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市森山町唐比西', '42', '42204', '8540208', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '森山町唐比西', 'モリヤマチョウカラコニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市森山町上井牟田', '42', '42204', '8540209', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '森山町上井牟田', 'モリヤマチョウカミイムタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県雲仙市愛野町甲', '42', '42213', '8540301', '長崎県', 'ナガサキケン', '雲仙市', 'ウンゼンシ', '愛野町甲', 'アイノマチコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県雲仙市愛野町乙', '42', '42213', '8540302', '長崎県', 'ナガサキケン', '雲仙市', 'ウンゼンシ', '愛野町乙', 'アイノマチオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県雲仙市千々石町甲', '42', '42213', '8540401', '長崎県', 'ナガサキケン', '雲仙市', 'ウンゼンシ', '千々石町甲', 'チヂワチョウコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県雲仙市千々石町乙', '42', '42213', '8540402', '長崎県', 'ナガサキケン', '雲仙市', 'ウンゼンシ', '千々石町乙', 'チヂワチョウオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県雲仙市千々石町丙', '42', '42213', '8540403', '長崎県', 'ナガサキケン', '雲仙市', 'ウンゼンシ', '千々石町丙', 'チヂワチョウヘイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県雲仙市千々石町丁', '42', '42213', '8540404', '長崎県', 'ナガサキケン', '雲仙市', 'ウンゼンシ', '千々石町丁', 'チヂワチョウテイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県雲仙市千々石町戊', '42', '42213', '8540405', '長崎県', 'ナガサキケン', '雲仙市', 'ウンゼンシ', '千々石町戊', 'チヂワチョウボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県雲仙市千々石町己', '42', '42213', '8540406', '長崎県', 'ナガサキケン', '雲仙市', 'ウンゼンシ', '千々石町己', 'チヂワチョウキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県雲仙市千々石町庚', '42', '42213', '8540407', '長崎県', 'ナガサキケン', '雲仙市', 'ウンゼンシ', '千々石町庚', 'チヂワチョウコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県雲仙市', '42', '42213', '8540500', '長崎県', 'ナガサキケン', '雲仙市', 'ウンゼンシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('109350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県雲仙市小浜町大亀', '42', '42213', '8540501', '長崎県', 'ナガサキケン', '雲仙市', 'ウンゼンシ', '小浜町大亀', 'オバマチョウオオカメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県雲仙市小浜町山畑', '42', '42213', '8540502', '長崎県', 'ナガサキケン', '雲仙市', 'ウンゼンシ', '小浜町山畑', 'オバマチョウヤマハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県雲仙市小浜町飛子', '42', '42213', '8540503', '長崎県', 'ナガサキケン', '雲仙市', 'ウンゼンシ', '小浜町飛子', 'オバマチョウトビコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県雲仙市小浜町金浜', '42', '42213', '8540504', '長崎県', 'ナガサキケン', '雲仙市', 'ウンゼンシ', '小浜町金浜', 'オバマチョウカナハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県雲仙市小浜町木場', '42', '42213', '8540505', '長崎県', 'ナガサキケン', '雲仙市', 'ウンゼンシ', '小浜町木場', 'オバマチョウコバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県雲仙市小浜町南木指', '42', '42213', '8540511', '長崎県', 'ナガサキケン', '雲仙市', 'ウンゼンシ', '小浜町南木指', 'オバマチョウミナミキサシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県雲仙市小浜町北木指', '42', '42213', '8540512', '長崎県', 'ナガサキケン', '雲仙市', 'ウンゼンシ', '小浜町北木指', 'オバマチョウキタキサシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県雲仙市小浜町南本町', '42', '42213', '8540513', '長崎県', 'ナガサキケン', '雲仙市', 'ウンゼンシ', '小浜町南本町', 'オバマチョウミナミホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県雲仙市小浜町北本町', '42', '42213', '8540514', '長崎県', 'ナガサキケン', '雲仙市', 'ウンゼンシ', '小浜町北本町', 'オバマチョウキタホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県雲仙市小浜町北野', '42', '42213', '8540515', '長崎県', 'ナガサキケン', '雲仙市', 'ウンゼンシ', '小浜町北野', 'オバマチョウキタノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県雲仙市小浜町富津', '42', '42213', '8540516', '長崎県', 'ナガサキケン', '雲仙市', 'ウンゼンシ', '小浜町富津', 'オバマチョウトミツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県雲仙市小浜町マリーナ', '42', '42213', '8540517', '長崎県', 'ナガサキケン', '雲仙市', 'ウンゼンシ', '小浜町マリーナ', 'オバマチョウマリーナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県雲仙市小浜町雲仙', '42', '42213', '8540621', '長崎県', 'ナガサキケン', '雲仙市', 'ウンゼンシ', '小浜町雲仙', 'オバマチョウウンゼン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県雲仙市南串山町甲', '42', '42213', '8540701', '長崎県', 'ナガサキケン', '雲仙市', 'ウンゼンシ', '南串山町甲', 'ミナミクシヤマチョウコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県雲仙市南串山町乙', '42', '42213', '8540702', '長崎県', 'ナガサキケン', '雲仙市', 'ウンゼンシ', '南串山町乙', 'ミナミクシヤマチョウオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県雲仙市南串山町丙', '42', '42213', '8540703', '長崎県', 'ナガサキケン', '雲仙市', 'ウンゼンシ', '南串山町丙', 'ミナミクシヤマチョウヘイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市飯盛町野中', '42', '42204', '8541101', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '飯盛町野中', 'イイモリチョウノナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市飯盛町山口', '42', '42204', '8541102', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '飯盛町山口', 'イイモリチョウヤマグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市飯盛町中山', '42', '42204', '8541103', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '飯盛町中山', 'イイモリチョウナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市飯盛町上原', '42', '42204', '8541104', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '飯盛町上原', 'イイモリチョウウエハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市飯盛町後田', '42', '42204', '8541105', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '飯盛町後田', 'イイモリチョウウシロダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市飯盛町平古場', '42', '42204', '8541111', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '飯盛町平古場', 'イイモリチョウヒラコバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市飯盛町開', '42', '42204', '8541112', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '飯盛町開', 'イイモリチョウヒラキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市飯盛町下釜', '42', '42204', '8541113', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '飯盛町下釜', 'イイモリチョウシモガマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市飯盛町久保', '42', '42204', '8541114', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '飯盛町久保', 'イイモリチョウクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市飯盛町古場', '42', '42204', '8541121', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '飯盛町古場', 'イイモリチョウコバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市飯盛町佐田', '42', '42204', '8541122', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '飯盛町佐田', 'イイモリチョウサダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市飯盛町里', '42', '42204', '8541123', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '飯盛町里', 'イイモリチョウサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市飯盛町川下', '42', '42204', '8541124', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '飯盛町川下', 'イイモリチョウカワシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市飯盛町池下', '42', '42204', '8541125', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '飯盛町池下', 'イイモリチョウイケシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市', '42', '42203', '8550000', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('109395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市中野町', '42', '42203', '8550001', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '中野町', 'ナカノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市洗切町', '42', '42203', '8550002', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '洗切町', 'アライキリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市三会町', '42', '42203', '8550003', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '三会町', 'ミエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市亀の甲町', '42', '42203', '8550004', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '亀の甲町', 'カメノコウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市中原町', '42', '42203', '8550005', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '中原町', 'ナカバラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市寺中町', '42', '42203', '8550006', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '寺中町', 'ジチュウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市津吹町', '42', '42203', '8550007', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '津吹町', 'ツブキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市原口町', '42', '42203', '8550008', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '原口町', 'ハラグチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市御手水町', '42', '42203', '8550011', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '御手水町', 'オチョウズマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市大手原町', '42', '42203', '8550012', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '大手原町', 'オオテバラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市稗田町', '42', '42203', '8550013', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '稗田町', 'ヒエダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市下宮町', '42', '42203', '8550014', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '下宮町', 'シモミヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市出平町', '42', '42203', '8550015', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '出平町', 'イデヒラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市山寺町', '42', '42203', '8550016', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '山寺町', 'ヤマデラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市江里町', '42', '42203', '8550017', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '江里町', 'エリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市西町', '42', '42203', '8550018', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '西町', 'ニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市油堀町', '42', '42203', '8550021', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '油堀町', 'アブラボリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市長貫町', '42', '42203', '8550022', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '長貫町', 'ナガヌキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市出の川町', '42', '42203', '8550023', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '出の川町', 'イデノカワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市広高野町', '42', '42203', '8550024', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '広高野町', 'ヒロコウヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市立野町', '42', '42203', '8550025', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '立野町', 'タテノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市礫石原町', '42', '42203', '8550026', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '礫石原町', 'クレイシバルマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市前浜町', '42', '42203', '8550031', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '前浜町', 'マエハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市北門町', '42', '42203', '8550032', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '北門町', 'キタモンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市新馬場町', '42', '42203', '8550033', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '新馬場町', 'シンババマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市田町', '42', '42203', '8550034', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '田町', 'タマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市先魁町', '42', '42203', '8550035', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '先魁町', 'サキガケマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市城内', '42', '42203', '8550036', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '城内', 'ジョウナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市', '42', '42203', '8550038', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', null, '　', '（直番地）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('109424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市宮の町', '42', '42203', '8550041', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '宮の町', 'ミヤノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市片町', '42', '42203', '8550042', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '片町', 'カタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市新田町', '42', '42203', '8550043', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '新田町', 'シンデンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市中町', '42', '42203', '8550044', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '中町', 'ナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市上の町', '42', '42203', '8550045', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '上の町', 'ウエノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市今川町', '42', '42203', '8550046', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '今川町', 'イマガワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市桜門町', '42', '42203', '8550051', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '桜門町', 'サクラモンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市下の丁', '42', '42203', '8550052', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '下の丁', 'シタノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市城西中の丁', '42', '42203', '8550053', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '城西中の丁', 'ジョウセイナカノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市古丁', '42', '42203', '8550054', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '古丁', 'フルチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市下新丁', '42', '42203', '8550055', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '下新丁', 'シタジンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市浦の川', '42', '42203', '8550056', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '浦の川', 'ウラノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市新建', '42', '42203', '8550057', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '新建', 'シンダチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市北原町', '42', '42203', '8550058', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '北原町', 'キタバラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市江戸丁', '42', '42203', '8550059', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '江戸丁', 'エドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市中尾町', '42', '42203', '8550061', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '中尾町', 'ナカオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市本町', '42', '42203', '8550062', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市原町', '42', '42203', '8550063', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '原町', 'ハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市柏野町', '42', '42203', '8550064', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '柏野町', 'カシワノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市南柏野町', '42', '42203', '8550065', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '南柏野町', 'ミナミカシワノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市柿の木町', '42', '42203', '8550066', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '柿の木町', 'カキノキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市上新丁', '42', '42203', '8550067', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '上新丁', 'ウワジンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市杉山町', '42', '42203', '8550068', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '杉山町', 'スギヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市宇土町', '42', '42203', '8550071', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '宇土町', 'ウトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市六ツ木町', '42', '42203', '8550072', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '六ツ木町', 'ムツギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市本光寺町', '42', '42203', '8550073', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '本光寺町', 'ホンコウジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市城見町', '42', '42203', '8550074', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '城見町', 'シロミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市下折橋町', '42', '42203', '8550075', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '下折橋町', 'シモオリハシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市上折橋町', '42', '42203', '8550076', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '上折橋町', 'カミオリハシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市南千本木町', '42', '42203', '8550077', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '南千本木町', 'ミナミセンボンギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市北千本木町', '42', '42203', '8550078', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '北千本木町', 'キタセンボンギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市高島', '42', '42203', '8550801', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '高島', 'タカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市弁天町', '42', '42203', '8550802', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '弁天町', 'ベンテンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市新町', '42', '42203', '8550803', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市万町', '42', '42203', '8550804', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '万町', 'ヨロズマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市堀町', '42', '42203', '8550805', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '堀町', 'ホリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市中堀町', '42', '42203', '8550806', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '中堀町', 'ナカホリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市白土町', '42', '42203', '8550807', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '白土町', 'シラチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市加美町', '42', '42203', '8550808', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '加美町', 'カミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市桜町', '42', '42203', '8550809', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '桜町', 'サクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市白土桃山', '42', '42203', '8550811', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '白土桃山', 'シラチモモヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市霊南', '42', '42203', '8550812', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '霊南', 'レイナン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市有馬船津町', '42', '42203', '8550813', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '有馬船津町', 'アリマフナツマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市津町', '42', '42203', '8550814', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '津町', 'ツマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市元船津町', '42', '42203', '8550815', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '元船津町', 'モトフナツマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市蛭子町', '42', '42203', '8550816', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '蛭子町', 'エビスマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市浦田', '42', '42203', '8550817', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '浦田', 'ウラタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市湊新地町', '42', '42203', '8550821', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '湊新地町', 'ミナトシンチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市中組町', '42', '42203', '8550822', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '中組町', 'ナカグミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市湊町', '42', '42203', '8550823', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '湊町', 'ミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市白山町', '42', '42203', '8550824', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '白山町', 'ハクサンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市広馬場町', '42', '42203', '8550825', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '広馬場町', 'ヒロババマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市湊道', '42', '42203', '8550831', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '湊道', 'ミナトミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市坂上町', '42', '42203', '8550832', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '坂上町', 'サカウエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市坂下町', '42', '42203', '8550833', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '坂下町', 'サカシタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市八幡町', '42', '42203', '8550834', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '八幡町', 'ヤハタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市西八幡町', '42', '42203', '8550835', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '西八幡町', 'ニシヤハタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市湖南町', '42', '42203', '8550836', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '湖南町', 'コナンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市崩山町', '42', '42203', '8550841', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '崩山町', 'クエヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市栄町', '42', '42203', '8550842', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市新山', '42', '42203', '8550843', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '新山', 'シンヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市萩原', '42', '42203', '8550851', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '萩原', 'ハギハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市寺町', '42', '42203', '8550852', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '寺町', 'テラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市上の原', '42', '42203', '8550853', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '上の原', 'ウエノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市萩が丘', '42', '42203', '8550854', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '萩が丘', 'ハギガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市青葉町', '42', '42203', '8550855', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '青葉町', 'アオバマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市小山町', '42', '42203', '8550856', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '小山町', 'コヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市下川尻町', '42', '42203', '8550861', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '下川尻町', 'シモカワシリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市新湊', '42', '42203', '8550862', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '新湊', 'シンミナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市親和町', '42', '42203', '8550863', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '親和町', 'シンワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市秩父が浦町', '42', '42203', '8550864', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '秩父が浦町', 'チチブガウラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市船泊町', '42', '42203', '8550865', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '船泊町', 'フナドマリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市南下川尻町', '42', '42203', '8550866', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '南下川尻町', 'ミナミシモカワシリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市緑町', '42', '42203', '8550867', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '緑町', 'ミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市南崩山町', '42', '42203', '8550871', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '南崩山町', 'ミナミクエヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市梅園町', '42', '42203', '8550872', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '梅園町', 'ウメゾノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市北安徳町', '42', '42203', '8550873', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '北安徳町', 'キタアントクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市鎌田町', '42', '42203', '8550874', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '鎌田町', 'カマダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市中安徳町', '42', '42203', '8550875', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '中安徳町', 'ナカアントクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市南安徳町', '42', '42203', '8550876', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '南安徳町', 'ミナミアントクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市浜の町', '42', '42203', '8550877', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '浜の町', 'ハマノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市大下町', '42', '42203', '8550878', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '大下町', 'オオジモマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市平成町', '42', '42203', '8550879', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '平成町', 'ヘイセイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市門内町', '42', '42203', '8550881', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '門内町', 'カドウチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市札の元町', '42', '42203', '8550882', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '札の元町', 'フダノモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市天神元町', '42', '42203', '8550883', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '天神元町', 'テンジンモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市仁田町', '42', '42203', '8550884', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '仁田町', 'ニタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市白谷町', '42', '42203', '8550885', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '白谷町', 'シラタニマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市北上木場町', '42', '42203', '8550886', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '北上木場町', 'キタカミコバマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市南上木場町', '42', '42203', '8550887', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '南上木場町', 'ミナミカミコバマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県大村市', '42', '42205', '8560000', '長崎県', 'ナガサキケン', '大村市', 'オオムラシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('109519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県大村市武留路町', '42', '42205', '8560001', '長崎県', 'ナガサキケン', '大村市', 'オオムラシ', '武留路町', 'ムルロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県大村市東野岳町', '42', '42205', '8560002', '長崎県', 'ナガサキケン', '大村市', 'オオムラシ', '東野岳町', 'ヒガシノダケマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県大村市野岳町', '42', '42205', '8560003', '長崎県', 'ナガサキケン', '大村市', 'オオムラシ', '野岳町', 'ノダケマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県大村市立福寺町', '42', '42205', '8560004', '長崎県', 'ナガサキケン', '大村市', 'オオムラシ', '立福寺町', 'リフクジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県大村市弥勒寺町', '42', '42205', '8560005', '長崎県', 'ナガサキケン', '大村市', 'オオムラシ', '弥勒寺町', 'ミロクジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県大村市福重町', '42', '42205', '8560006', '長崎県', 'ナガサキケン', '大村市', 'オオムラシ', '福重町', 'フクシゲマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県大村市草場町', '42', '42205', '8560007', '長崎県', 'ナガサキケン', '大村市', 'オオムラシ', '草場町', 'クサバマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県大村市松原', '42', '42205', '8560008', '長崎県', 'ナガサキケン', '大村市', 'オオムラシ', '松原', 'マツバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県大村市松原本町', '42', '42205', '8560009', '長崎県', 'ナガサキケン', '大村市', 'オオムラシ', '松原本町', 'マツバラホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県大村市重井田町', '42', '42205', '8560011', '長崎県', 'ナガサキケン', '大村市', 'オオムラシ', '重井田町', 'シゲイダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県大村市黒木町', '42', '42205', '8560012', '長崎県', 'ナガサキケン', '大村市', 'オオムラシ', '黒木町', 'クロキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県大村市中岳町', '42', '42205', '8560013', '長崎県', 'ナガサキケン', '大村市', 'オオムラシ', '中岳町', 'ナカダケマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県大村市田下町', '42', '42205', '8560014', '長崎県', 'ナガサキケン', '大村市', 'オオムラシ', '田下町', 'タジモマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県大村市宮代町', '42', '42205', '8560015', '長崎県', 'ナガサキケン', '大村市', 'オオムラシ', '宮代町', 'ミヤダイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県大村市原町', '42', '42205', '8560016', '長崎県', 'ナガサキケン', '大村市', 'オオムラシ', '原町', 'ハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県大村市荒瀬町', '42', '42205', '8560017', '長崎県', 'ナガサキケン', '大村市', 'オオムラシ', '荒瀬町', 'アラセマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県大村市今富町', '42', '42205', '8560018', '長崎県', 'ナガサキケン', '大村市', 'オオムラシ', '今富町', 'イマトミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県大村市野田町', '42', '42205', '8560019', '長崎県', 'ナガサキケン', '大村市', 'オオムラシ', '野田町', 'ノダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県大村市小路口本町', '42', '42205', '8560020', '長崎県', 'ナガサキケン', '大村市', 'オオムラシ', '小路口本町', 'オログチホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県大村市鬼橋町', '42', '42205', '8560021', '長崎県', 'ナガサキケン', '大村市', 'オオムラシ', '鬼橋町', 'オニバシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県大村市雄ケ原町', '42', '42205', '8560022', '長崎県', 'ナガサキケン', '大村市', 'オオムラシ', '雄ケ原町', 'マスラガハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県大村市上諏訪町', '42', '42205', '8560023', '長崎県', 'ナガサキケン', '大村市', 'オオムラシ', '上諏訪町', 'カミスワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県大村市諏訪', '42', '42205', '8560024', '長崎県', 'ナガサキケン', '大村市', 'オオムラシ', '諏訪', 'スワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県大村市小路口町', '42', '42205', '8560025', '長崎県', 'ナガサキケン', '大村市', 'オオムラシ', '小路口町', 'オログチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県大村市池田', '42', '42205', '8560026', '長崎県', 'ナガサキケン', '大村市', 'オオムラシ', '池田', 'イケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県大村市植松', '42', '42205', '8560027', '長崎県', 'ナガサキケン', '大村市', 'オオムラシ', '植松', 'ウエマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県大村市坂口町', '42', '42205', '8560028', '長崎県', 'ナガサキケン', '大村市', 'オオムラシ', '坂口町', 'サカグチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県大村市池田新町', '42', '42205', '8560029', '長崎県', 'ナガサキケン', '大村市', 'オオムラシ', '池田新町', 'イケダシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県大村市三城町', '42', '42205', '8560031', '長崎県', 'ナガサキケン', '大村市', 'オオムラシ', '三城町', 'サンジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県大村市東大村', '42', '42205', '8560032', '長崎県', 'ナガサキケン', '大村市', 'オオムラシ', '東大村', 'ヒガシオオムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県大村市荒平町', '42', '42205', '8560033', '長崎県', 'ナガサキケン', '大村市', 'オオムラシ', '荒平町', 'アラヒラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県大村市水計町', '42', '42205', '8560034', '長崎県', 'ナガサキケン', '大村市', 'オオムラシ', '水計町', 'ミズハカリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県大村市武部町', '42', '42205', '8560035', '長崎県', 'ナガサキケン', '大村市', 'オオムラシ', '武部町', 'タケベマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県大村市徳泉川内町', '42', '42205', '8560041', '長崎県', 'ナガサキケン', '大村市', 'オオムラシ', '徳泉川内町', 'トクセンガワチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県大村市平町', '42', '42205', '8560042', '長崎県', 'ナガサキケン', '大村市', 'オオムラシ', '平町', 'ヒラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県大村市小川内町', '42', '42205', '8560043', '長崎県', 'ナガサキケン', '大村市', 'オオムラシ', '小川内町', 'オガワウチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県大村市岩松町', '42', '42205', '8560044', '長崎県', 'ナガサキケン', '大村市', 'オオムラシ', '岩松町', 'イワマツマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県大村市向木場町', '42', '42205', '8560045', '長崎県', 'ナガサキケン', '大村市', 'オオムラシ', '向木場町', 'ムカイコバマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県大村市木場', '42', '42205', '8560046', '長崎県', 'ナガサキケン', '大村市', 'オオムラシ', '木場', 'コバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県大村市須田ノ木町', '42', '42205', '8560047', '長崎県', 'ナガサキケン', '大村市', 'オオムラシ', '須田ノ木町', 'スダノキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県大村市赤佐古町', '42', '42205', '8560048', '長崎県', 'ナガサキケン', '大村市', 'オオムラシ', '赤佐古町', 'アカサコマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県大村市寿古町', '42', '42205', '8560801', '長崎県', 'ナガサキケン', '大村市', 'オオムラシ', '寿古町', 'スコマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県大村市皆同町', '42', '42205', '8560802', '長崎県', 'ナガサキケン', '大村市', 'オオムラシ', '皆同町', 'カイドウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県大村市竹松町', '42', '42205', '8560803', '長崎県', 'ナガサキケン', '大村市', 'オオムラシ', '竹松町', 'タケマツマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県大村市大川田町', '42', '42205', '8560804', '長崎県', 'ナガサキケン', '大村市', 'オオムラシ', '大川田町', 'オオカワダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県大村市竹松本町', '42', '42205', '8560805', '長崎県', 'ナガサキケン', '大村市', 'オオムラシ', '竹松本町', 'タケマツホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県大村市富の原', '42', '42205', '8560806', '長崎県', 'ナガサキケン', '大村市', 'オオムラシ', '富の原', 'トミノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県大村市宮小路', '42', '42205', '8560807', '長崎県', 'ナガサキケン', '大村市', 'オオムラシ', '宮小路', 'ミヤショウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県大村市黒丸町', '42', '42205', '8560808', '長崎県', 'ナガサキケン', '大村市', 'オオムラシ', '黒丸町', 'クロマルマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県大村市沖田町', '42', '42205', '8560809', '長崎県', 'ナガサキケン', '大村市', 'オオムラシ', '沖田町', 'オキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県大村市原口町', '42', '42205', '8560811', '長崎県', 'ナガサキケン', '大村市', 'オオムラシ', '原口町', 'ハラグチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県大村市桜馬場', '42', '42205', '8560812', '長崎県', 'ナガサキケン', '大村市', 'オオムラシ', '桜馬場', 'サクラババ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県大村市西大村本町', '42', '42205', '8560813', '長崎県', 'ナガサキケン', '大村市', 'オオムラシ', '西大村本町', 'ニシオオムラホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県大村市松並', '42', '42205', '8560814', '長崎県', 'ナガサキケン', '大村市', 'オオムラシ', '松並', 'マツナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県大村市森園町', '42', '42205', '8560815', '長崎県', 'ナガサキケン', '大村市', 'オオムラシ', '森園町', 'モリゾノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県大村市箕島町', '42', '42205', '8560816', '長崎県', 'ナガサキケン', '大村市', 'オオムラシ', '箕島町', 'ミシママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県大村市古賀島町', '42', '42205', '8560817', '長崎県', 'ナガサキケン', '大村市', 'オオムラシ', '古賀島町', 'コガシママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県大村市今津町', '42', '42205', '8560818', '長崎県', 'ナガサキケン', '大村市', 'オオムラシ', '今津町', 'イマヅマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県大村市協和町', '42', '42205', '8560820', '長崎県', 'ナガサキケン', '大村市', 'オオムラシ', '協和町', 'キョウワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県大村市西乾馬場町', '42', '42205', '8560821', '長崎県', 'ナガサキケン', '大村市', 'オオムラシ', '西乾馬場町', 'ニシイヌイババマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県大村市古町', '42', '42205', '8560822', '長崎県', 'ナガサキケン', '大村市', 'オオムラシ', '古町', 'フルマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県大村市乾馬場町', '42', '42205', '8560823', '長崎県', 'ナガサキケン', '大村市', 'オオムラシ', '乾馬場町', 'イヌイババマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県大村市水田町', '42', '42205', '8560824', '長崎県', 'ナガサキケン', '大村市', 'オオムラシ', '水田町', 'ミズタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県大村市西三城町', '42', '42205', '8560825', '長崎県', 'ナガサキケン', '大村市', 'オオムラシ', '西三城町', 'ニシサンジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県大村市東三城町', '42', '42205', '8560826', '長崎県', 'ナガサキケン', '大村市', 'オオムラシ', '東三城町', 'ヒガシサンジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県大村市水主町', '42', '42205', '8560827', '長崎県', 'ナガサキケン', '大村市', 'オオムラシ', '水主町', 'カコマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県大村市杭出津', '42', '42205', '8560828', '長崎県', 'ナガサキケン', '大村市', 'オオムラシ', '杭出津', 'クイデツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県大村市松山町', '42', '42205', '8560829', '長崎県', 'ナガサキケン', '大村市', 'オオムラシ', '松山町', 'マツヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県大村市東本町', '42', '42205', '8560831', '長崎県', 'ナガサキケン', '大村市', 'オオムラシ', '東本町', 'ヒガシホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県大村市本町', '42', '42205', '8560832', '長崎県', 'ナガサキケン', '大村市', 'オオムラシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県大村市片町', '42', '42205', '8560833', '長崎県', 'ナガサキケン', '大村市', 'オオムラシ', '片町', 'カタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県大村市玖島', '42', '42205', '8560834', '長崎県', 'ナガサキケン', '大村市', 'オオムラシ', '玖島', 'クシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県大村市久原', '42', '42205', '8560835', '長崎県', 'ナガサキケン', '大村市', 'オオムラシ', '久原', 'クバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県大村市幸町', '42', '42205', '8560836', '長崎県', 'ナガサキケン', '大村市', 'オオムラシ', '幸町', 'サイワイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県大村市西本町', '42', '42205', '8560837', '長崎県', 'ナガサキケン', '大村市', 'オオムラシ', '西本町', 'ニシホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県大村市陰平町', '42', '42205', '8560841', '長崎県', 'ナガサキケン', '大村市', 'オオムラシ', '陰平町', 'カゲヒラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県大村市中里町', '42', '42205', '8560842', '長崎県', 'ナガサキケン', '大村市', 'オオムラシ', '中里町', 'ナカザトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県大村市今村町', '42', '42205', '8560843', '長崎県', 'ナガサキケン', '大村市', 'オオムラシ', '今村町', 'イマムラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県大村市溝陸町', '42', '42205', '8560844', '長崎県', 'ナガサキケン', '大村市', 'オオムラシ', '溝陸町', 'ミゾロクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県大村市大里町', '42', '42205', '8560845', '長崎県', 'ナガサキケン', '大村市', 'オオムラシ', '大里町', 'オオザトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県大村市日泊町', '42', '42205', '8560846', '長崎県', 'ナガサキケン', '大村市', 'オオムラシ', '日泊町', 'ヒドマルマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県大村市西部町', '42', '42205', '8560847', '長崎県', 'ナガサキケン', '大村市', 'オオムラシ', '西部町', 'セイブマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市', '42', '42202', '8570000', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('109613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市烏帽子町', '42', '42202', '8570001', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '烏帽子町', 'エボシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市春日町', '42', '42202', '8570011', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '春日町', 'カスガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市桜木町', '42', '42202', '8570012', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '桜木町', 'サクラギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市赤木町', '42', '42202', '8570013', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '赤木町', 'アカギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市田代町', '42', '42202', '8570014', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '田代町', 'タシロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市松山町', '42', '42202', '8570015', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '松山町', 'マツヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市俵町', '42', '42202', '8570016', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '俵町', 'タワラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市梅田町', '42', '42202', '8570017', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '梅田町', 'ウメダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市横尾町', '42', '42202', '8570018', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '横尾町', 'ヨコオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市折橋町', '42', '42202', '8570021', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '折橋町', 'オリハシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市山手町', '42', '42202', '8570022', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '山手町', 'ヤマテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市名切町', '42', '42202', '8570023', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '名切町', 'ナキリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市花園町', '42', '42202', '8570024', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '花園町', 'ハナゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市熊野町', '42', '42202', '8570025', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '熊野町', 'クマノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市宮地町', '42', '42202', '8570026', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '宮地町', 'ミヤジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市谷郷町', '42', '42202', '8570027', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '谷郷町', 'タニゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市八幡町', '42', '42202', '8570028', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '八幡町', 'ハチマンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市保立町', '42', '42202', '8570031', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '保立町', 'ホタテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市宮田町', '42', '42202', '8570032', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '宮田町', 'ミヤダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市城山町', '42', '42202', '8570033', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '城山町', 'シロヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市万徳町', '42', '42202', '8570034', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '万徳町', 'マントクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市福田町', '42', '42202', '8570035', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '福田町', 'フクダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市清水町', '42', '42202', '8570036', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '清水町', 'シミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市石坂町', '42', '42202', '8570037', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '石坂町', 'イシザカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市中通町', '42', '42202', '8570038', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '中通町', 'ナカドオリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市比良町', '42', '42202', '8570040', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '比良町', 'ヒラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市木場田町', '42', '42202', '8570041', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '木場田町', 'コバタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市高砂町', '42', '42202', '8570042', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '高砂町', 'タカサゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市天満町', '42', '42202', '8570043', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '天満町', 'テンマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市相生町', '42', '42202', '8570044', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '相生町', 'アイオイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市園田町', '42', '42202', '8570045', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '園田町', 'ソノダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市長尾町', '42', '42202', '8570046', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '長尾町', 'ナガオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市矢岳町', '42', '42202', '8570047', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '矢岳町', 'ヤタケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市西大久保町', '42', '42202', '8570048', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '西大久保町', 'ニシオオクボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市東大久保町', '42', '42202', '8570049', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '東大久保町', 'ヒガシオオクボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市浜田町', '42', '42202', '8570051', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '浜田町', 'ハマダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市松浦町', '42', '42202', '8570052', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '松浦町', 'マツウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市常盤町', '42', '42202', '8570053', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '常盤町', 'トキワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市栄町', '42', '42202', '8570054', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市湊町', '42', '42202', '8570055', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '湊町', 'ミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市平瀬町', '42', '42202', '8570056', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '平瀬町', 'ヒラセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市泉町', '42', '42202', '8570057', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '泉町', 'イズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市上町', '42', '42202', '8570058', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '上町', 'ウワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市元町', '42', '42202', '8570059', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '元町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市今福町', '42', '42202', '8570061', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '今福町', 'イマブクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市金比良町', '42', '42202', '8570062', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '金比良町', 'コンピラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市立神町', '42', '42202', '8570063', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '立神町', 'タテガミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市赤崎町', '42', '42202', '8570064', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '赤崎町', 'アカサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市小野町', '42', '42202', '8570065', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '小野町', 'オノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市小島町', '42', '42202', '8570066', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '小島町', 'コジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市神島町', '42', '42202', '8570067', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '神島町', 'カミシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市御船町', '42', '42202', '8570068', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '御船町', 'ミフネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市鵜渡越町', '42', '42202', '8570069', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '鵜渡越町', 'ウドゴエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県長崎市池島町', '42', '42201', '8570071', '長崎県', 'ナガサキケン', '長崎市', 'ナガサキシ', '池島町', 'イケシママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市知見寺町', '42', '42202', '8570101', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '知見寺町', 'チケンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市松瀬町', '42', '42202', '8570102', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '松瀬町', 'マツセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市原分町', '42', '42202', '8570103', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '原分町', 'ハルブンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市楠木町', '42', '42202', '8570104', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '楠木町', 'クスノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市白仁田町', '42', '42202', '8570105', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '白仁田町', 'シラニタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市菰田町', '42', '42202', '8570106', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '菰田町', 'コモダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市筒井町', '42', '42202', '8570111', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '筒井町', 'ツツイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市柚木町', '42', '42202', '8570112', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '柚木町', 'ユノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市下宇戸町', '42', '42202', '8570113', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '下宇戸町', 'シモウドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市小舟町', '42', '42202', '8570114', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '小舟町', 'コフネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市柚木元町', '42', '42202', '8570115', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '柚木元町', 'ユノキモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市潜木町', '42', '42202', '8570121', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '潜木町', 'クグルギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市里美町', '42', '42202', '8570122', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '里美町', 'サトヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市川谷町', '42', '42202', '8570123', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '川谷町', 'カワタニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市戸ケ倉町', '42', '42202', '8570124', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '戸ケ倉町', 'トガクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市高花町', '42', '42202', '8570125', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '高花町', 'タカハナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市上柚木町', '42', '42202', '8570126', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '上柚木町', 'カミユノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市大野町', '42', '42202', '8570131', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '大野町', 'オオノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市松原町', '42', '42202', '8570132', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '松原町', 'マツバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市矢峰町', '42', '42202', '8570133', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '矢峰町', 'ヤミネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市瀬戸越', '42', '42202', '8570134', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '瀬戸越', 'セトゴエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市瀬戸越町', '42', '42202', '8570135', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '瀬戸越町', 'セトゴエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市田原町', '42', '42202', '8570136', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '田原町', 'タバルチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市十文野町', '42', '42202', '8570141', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '十文野町', 'トモンノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市野中町', '42', '42202', '8570142', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '野中町', 'ノナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市吉岡町', '42', '42202', '8570143', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '吉岡町', 'ヨシオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市皆瀬町', '42', '42202', '8570144', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '皆瀬町', 'カイゼチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市牧の地町', '42', '42202', '8570145', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '牧の地町', 'マキノジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市小川内町', '42', '42202', '8570146', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '小川内町', 'オガワチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県北松浦郡佐々町', '42', '42391', '8570300', '長崎県', 'ナガサキケン', '北松浦郡佐々町', 'キタマツウラグンサザチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('109698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県北松浦郡佐々町本田原免', '42', '42391', '8570311', '長崎県', 'ナガサキケン', '北松浦郡佐々町', 'キタマツウラグンサザチョウ', '本田原免', 'ホンタバルメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県北松浦郡佐々町市場免', '42', '42391', '8570312', '長崎県', 'ナガサキケン', '北松浦郡佐々町', 'キタマツウラグンサザチョウ', '市場免', 'イチバメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県北松浦郡佐々町鴨川免', '42', '42391', '8570313', '長崎県', 'ナガサキケン', '北松浦郡佐々町', 'キタマツウラグンサザチョウ', '鴨川免', 'カモガワメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県北松浦郡佐々町古川免', '42', '42391', '8570314', '長崎県', 'ナガサキケン', '北松浦郡佐々町', 'キタマツウラグンサザチョウ', '古川免', 'フルカワメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県北松浦郡佐々町志方免', '42', '42391', '8570315', '長崎県', 'ナガサキケン', '北松浦郡佐々町', 'キタマツウラグンサザチョウ', '志方免', 'シカタメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県北松浦郡佐々町市瀬免', '42', '42391', '8570321', '長崎県', 'ナガサキケン', '北松浦郡佐々町', 'キタマツウラグンサザチョウ', '市瀬免', 'イチノセメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県北松浦郡佐々町松瀬免', '42', '42391', '8570322', '長崎県', 'ナガサキケン', '北松浦郡佐々町', 'キタマツウラグンサザチョウ', '松瀬免', 'マツセメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県北松浦郡佐々町江里免', '42', '42391', '8570323', '長崎県', 'ナガサキケン', '北松浦郡佐々町', 'キタマツウラグンサザチョウ', '江里免', 'エリメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県北松浦郡佐々町大茂免', '42', '42391', '8570324', '長崎県', 'ナガサキケン', '北松浦郡佐々町', 'キタマツウラグンサザチョウ', '大茂免', 'オオシゲメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県北松浦郡佐々町野寄免', '42', '42391', '8570331', '長崎県', 'ナガサキケン', '北松浦郡佐々町', 'キタマツウラグンサザチョウ', '野寄免', 'ノヨリメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県北松浦郡佐々町栗林免', '42', '42391', '8570332', '長崎県', 'ナガサキケン', '北松浦郡佐々町', 'キタマツウラグンサザチョウ', '栗林免', 'クリバヤシメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県北松浦郡佐々町中川原免', '42', '42391', '8570333', '長崎県', 'ナガサキケン', '北松浦郡佐々町', 'キタマツウラグンサザチョウ', '中川原免', 'ナカガワラメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県北松浦郡佐々町石木場免', '42', '42391', '8570334', '長崎県', 'ナガサキケン', '北松浦郡佐々町', 'キタマツウラグンサザチョウ', '石木場免', 'イシコバメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県北松浦郡佐々町皆瀬免', '42', '42391', '8570335', '長崎県', 'ナガサキケン', '北松浦郡佐々町', 'キタマツウラグンサザチョウ', '皆瀬免', 'カイゼメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県北松浦郡佐々町神田免', '42', '42391', '8570336', '長崎県', 'ナガサキケン', '北松浦郡佐々町', 'キタマツウラグンサザチョウ', '神田免', 'コウダメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県北松浦郡佐々町八口免', '42', '42391', '8570337', '長崎県', 'ナガサキケン', '北松浦郡佐々町', 'キタマツウラグンサザチョウ', '八口免', 'ヤクチメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県北松浦郡佐々町角山免', '42', '42391', '8570338', '長崎県', 'ナガサキケン', '北松浦郡佐々町', 'キタマツウラグンサザチョウ', '角山免', 'ツノヤマメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県北松浦郡佐々町羽須和免', '42', '42391', '8570341', '長崎県', 'ナガサキケン', '北松浦郡佐々町', 'キタマツウラグンサザチョウ', '羽須和免', 'ハスワメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県北松浦郡佐々町平野免', '42', '42391', '8570342', '長崎県', 'ナガサキケン', '北松浦郡佐々町', 'キタマツウラグンサザチョウ', '平野免', 'ヒラノメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県北松浦郡佐々町木場免', '42', '42391', '8570343', '長崎県', 'ナガサキケン', '北松浦郡佐々町', 'キタマツウラグンサザチョウ', '木場免', 'コバメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県北松浦郡佐々町迎木場免', '42', '42391', '8570344', '長崎県', 'ナガサキケン', '北松浦郡佐々町', 'キタマツウラグンサザチョウ', '迎木場免', 'ムカエコバメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県北松浦郡佐々町須崎免', '42', '42391', '8570351', '長崎県', 'ナガサキケン', '北松浦郡佐々町', 'キタマツウラグンサザチョウ', '須崎免', 'スサキメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県北松浦郡佐々町口石免', '42', '42391', '8570352', '長崎県', 'ナガサキケン', '北松浦郡佐々町', 'キタマツウラグンサザチョウ', '口石免', 'クチイシメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県北松浦郡佐々町沖田免', '42', '42391', '8570353', '長崎県', 'ナガサキケン', '北松浦郡佐々町', 'キタマツウラグンサザチョウ', '沖田免', 'オキタメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県北松浦郡佐々町小浦免', '42', '42391', '8570361', '長崎県', 'ナガサキケン', '北松浦郡佐々町', 'キタマツウラグンサザチョウ', '小浦免', 'コウラメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市小佐々町黒石', '42', '42202', '8570401', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '小佐々町黒石', 'コサザチョウクロイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市小佐々町小坂', '42', '42202', '8570402', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '小佐々町小坂', 'コサザチョウコサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市小佐々町臼ノ浦', '42', '42202', '8570403', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '小佐々町臼ノ浦', 'コサザチョウウスノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市小佐々町田原', '42', '42202', '8570404', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '小佐々町田原', 'コサザチョウタバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市小佐々町葛籠', '42', '42202', '8570405', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '小佐々町葛籠', 'コサザチョウツヅラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市小佐々町平原', '42', '42202', '8570406', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '小佐々町平原', 'コサザチョウヒラバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市小佐々町岳ノ木場', '42', '42202', '8570411', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '小佐々町岳ノ木場', 'コサザチョウタケノコバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市小佐々町西川内', '42', '42202', '8570412', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '小佐々町西川内', 'コサザチョウニシカワウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市小佐々町楠泊', '42', '42202', '8570413', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '小佐々町楠泊', 'コサザチョウクスドマリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市小佐々町矢岳', '42', '42202', '8570414', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '小佐々町矢岳', 'コサザチョウヤダケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市浅子町', '42', '42202', '8570431', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '浅子町', 'アサゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市祗園町', '42', '42202', '8570801', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '祗園町', 'ギオンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市高天町', '42', '42202', '8570802', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '高天町', 'コウテンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市勝富町', '42', '42202', '8570803', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '勝富町', 'カツトミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市松川町', '42', '42202', '8570804', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '松川町', 'マツカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市光月町', '42', '42202', '8570805', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '光月町', 'コウゲツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市島瀬町', '42', '42202', '8570806', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '島瀬町', 'シマノセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市高梨町', '42', '42202', '8570811', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '高梨町', 'タカナシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市須佐町', '42', '42202', '8570812', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '須佐町', 'スサマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市小佐世保町', '42', '42202', '8570813', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '小佐世保町', 'コサセボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市白木町', '42', '42202', '8570821', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '白木町', 'シラキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市山祗町', '42', '42202', '8570822', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '山祗町', 'ヤマズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市須田尾町', '42', '42202', '8570831', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '須田尾町', 'スダオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市藤原町', '42', '42202', '8570832', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '藤原町', 'フジワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市若葉町', '42', '42202', '8570833', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '若葉町', 'ワカバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市潮見町', '42', '42202', '8570834', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '潮見町', 'シオミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市大宮町', '42', '42202', '8570841', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '大宮町', 'オオミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市東山町', '42', '42202', '8570842', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '東山町', 'ヒガシヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市大黒町', '42', '42202', '8570843', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '大黒町', 'ダイコクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市稲荷町', '42', '42202', '8570851', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '稲荷町', 'イナリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市干尽町', '42', '42202', '8570852', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '干尽町', 'ヒヅクシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市前畑町', '42', '42202', '8570853', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '前畑町', 'マエハタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市福石町', '42', '42202', '8570854', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '福石町', 'フクイシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市新港町', '42', '42202', '8570855', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '新港町', 'シンミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市峰坂町', '42', '42202', '8570861', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '峰坂町', 'ミネノサカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市白南風町', '42', '42202', '8570862', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '白南風町', 'シラハエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市三浦町', '42', '42202', '8570863', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '三浦町', 'ミウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市戸尾町', '42', '42202', '8570864', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '戸尾町', 'トノオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市本島町', '42', '42202', '8570871', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '本島町', 'モトシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市上京町', '42', '42202', '8570872', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '上京町', 'カミキョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市宮崎町', '42', '42202', '8570873', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '宮崎町', 'ミヤザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市京坪町', '42', '42202', '8570874', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '京坪町', 'キョウノツボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市下京町', '42', '42202', '8570875', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '下京町', 'シモキョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市塩浜町', '42', '42202', '8570876', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '塩浜町', 'シオハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市万津町', '42', '42202', '8570877', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '万津町', 'ヨロヅチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市山県町', '42', '42202', '8570878', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '山県町', 'ヤマガタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市島地町', '42', '42202', '8570879', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '島地町', 'シマンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市日宇町', '42', '42202', '8571151', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '日宇町', 'ヒウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市黒髪町', '42', '42202', '8571152', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '黒髪町', 'クロカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市もみじが丘町', '42', '42202', '8571153', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', 'もみじが丘町', 'モミジガオカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市大塔町', '42', '42202', '8571161', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '大塔町', 'ダイトウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市卸本町', '42', '42202', '8571162', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '卸本町', 'オロシホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市大岳台町', '42', '42202', '8571163', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '大岳台町', 'オオタケダイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市白岳町', '42', '42202', '8571164', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '白岳町', 'シラタケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市大和町', '42', '42202', '8571165', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '大和町', 'ヤマトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市木風町', '42', '42202', '8571166', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '木風町', 'キカゼチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市沖新町', '42', '42202', '8571171', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '沖新町', 'オキシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市東浜町', '42', '42202', '8571172', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '東浜町', 'ヒガシハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市十郎新町', '42', '42202', '8571173', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '十郎新町', 'ジュウロウシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市天神', '42', '42202', '8571174', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '天神', 'テンジン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市天神町', '42', '42202', '8571175', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '天神町', 'テンジンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市崎辺町', '42', '42202', '8571176', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '崎辺町', 'サキベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市船越町', '42', '42202', '8571231', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '船越町', 'フナコシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市下船越町', '42', '42202', '8571232', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '下船越町', 'シモフナコシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市庵浦町', '42', '42202', '8571233', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '庵浦町', 'イオノウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市野崎町', '42', '42202', '8571234', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '野崎町', 'ノザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市俵ケ浦町', '42', '42202', '8571235', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '俵ケ浦町', 'タワラガウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県西海市西海町中浦南郷', '42', '42212', '8572221', '長崎県', 'ナガサキケン', '西海市', 'サイカイシ', '西海町中浦南郷', 'サイカイチョウナカウラミナミゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県西海市西海町中浦北郷', '42', '42212', '8572222', '長崎県', 'ナガサキケン', '西海市', 'サイカイシ', '西海町中浦北郷', 'サイカイチョウナカウラキタゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県西海市西海町七釜郷', '42', '42212', '8572223', '長崎県', 'ナガサキケン', '西海市', 'サイカイシ', '西海町七釜郷', 'サイカイチョウナナツガマゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県西海市大瀬戸町瀬戸板浦郷', '42', '42212', '8572301', '長崎県', 'ナガサキケン', '西海市', 'サイカイシ', '大瀬戸町瀬戸板浦郷', 'オオセトチョウセトイタノウラゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県西海市大瀬戸町瀬戸樫浦郷', '42', '42212', '8572302', '長崎県', 'ナガサキケン', '西海市', 'サイカイシ', '大瀬戸町瀬戸樫浦郷', 'オオセトチョウセトカシノウラゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県西海市大瀬戸町瀬戸西濱郷', '42', '42212', '8572303', '長崎県', 'ナガサキケン', '西海市', 'サイカイシ', '大瀬戸町瀬戸西濱郷', 'オオセトチョウセトニシハマゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県西海市大瀬戸町瀬戸下山郷', '42', '42212', '8572304', '長崎県', 'ナガサキケン', '西海市', 'サイカイシ', '大瀬戸町瀬戸下山郷', 'オオセトチョウセトシタヤマゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県西海市大瀬戸町瀬戸羽出川郷', '42', '42212', '8572305', '長崎県', 'ナガサキケン', '西海市', 'サイカイシ', '大瀬戸町瀬戸羽出川郷', 'オオセトチョウセトハデガワゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県西海市大瀬戸町瀬戸東濱郷', '42', '42212', '8572306', '長崎県', 'ナガサキケン', '西海市', 'サイカイシ', '大瀬戸町瀬戸東濱郷', 'オオセトチョウセトヒガシハマゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県西海市大瀬戸町瀬戸福島郷', '42', '42212', '8572307', '長崎県', 'ナガサキケン', '西海市', 'サイカイシ', '大瀬戸町瀬戸福島郷', 'オオセトチョウセトフクシマゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県西海市大瀬戸町多以良外郷', '42', '42212', '8572311', '長崎県', 'ナガサキケン', '西海市', 'サイカイシ', '大瀬戸町多以良外郷', 'オオセトチョウタイラソトゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県西海市大瀬戸町多以良内郷', '42', '42212', '8572312', '長崎県', 'ナガサキケン', '西海市', 'サイカイシ', '大瀬戸町多以良内郷', 'オオセトチョウタイラウチゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県西海市大瀬戸町雪浦幸物郷', '42', '42212', '8572321', '長崎県', 'ナガサキケン', '西海市', 'サイカイシ', '大瀬戸町雪浦幸物郷', 'オオセトチョウユキノウラコウブツゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県西海市大瀬戸町雪浦久良木郷', '42', '42212', '8572322', '長崎県', 'ナガサキケン', '西海市', 'サイカイシ', '大瀬戸町雪浦久良木郷', 'オオセトチョウユキノウラキュウラギゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県西海市大瀬戸町雪浦河通郷', '42', '42212', '8572323', '長崎県', 'ナガサキケン', '西海市', 'サイカイシ', '大瀬戸町雪浦河通郷', 'オオセトチョウユキノウラゴウツウゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県西海市大瀬戸町雪浦奥浦郷', '42', '42212', '8572324', '長崎県', 'ナガサキケン', '西海市', 'サイカイシ', '大瀬戸町雪浦奥浦郷', 'オオセトチョウユキノウラオクウラゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県西海市大瀬戸町雪浦小松郷', '42', '42212', '8572325', '長崎県', 'ナガサキケン', '西海市', 'サイカイシ', '大瀬戸町雪浦小松郷', 'オオセトチョウユキノウラコマツゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県西海市大瀬戸町雪浦下郷', '42', '42212', '8572326', '長崎県', 'ナガサキケン', '西海市', 'サイカイシ', '大瀬戸町雪浦下郷', 'オオセトチョウユキノウラシモゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県西海市大瀬戸町雪浦上郷', '42', '42212', '8572327', '長崎県', 'ナガサキケン', '西海市', 'サイカイシ', '大瀬戸町雪浦上郷', 'オオセトチョウユキノウラカミゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県西海市大瀬戸町雪浦下釜郷', '42', '42212', '8572328', '長崎県', 'ナガサキケン', '西海市', 'サイカイシ', '大瀬戸町雪浦下釜郷', 'オオセトチョウユキノウラシモノカマゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県西海市大島町黒瀬', '42', '42212', '8572401', '長崎県', 'ナガサキケン', '西海市', 'サイカイシ', '大島町黒瀬', 'オオシマチョウクロセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県西海市大島町内浦地区', '42', '42212', '8572402', '長崎県', 'ナガサキケン', '西海市', 'サイカイシ', '大島町内浦地区', 'オオシマチョウウチウラチク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県西海市大島町馬込', '42', '42212', '8572403', '長崎県', 'ナガサキケン', '西海市', 'サイカイシ', '大島町馬込', 'オオシマチョウマゴメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県西海市大島町中央地区', '42', '42212', '8572405', '長崎県', 'ナガサキケン', '西海市', 'サイカイシ', '大島町中央地区', 'オオシマチョウチュウオウチク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県西海市大島町寺島', '42', '42212', '8572411', '長崎県', 'ナガサキケン', '西海市', 'サイカイシ', '大島町寺島', 'オオシマチョウテラシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県西海市大島町真砂', '42', '42212', '8572412', '長崎県', 'ナガサキケン', '西海市', 'サイカイシ', '大島町真砂', 'オオシマチョウマサゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県西海市大島町間瀬', '42', '42212', '8572413', '長崎県', 'ナガサキケン', '西海市', 'サイカイシ', '大島町間瀬', 'オオシマチョウマゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県西海市大島町百合が丘', '42', '42212', '8572417', '長崎県', 'ナガサキケン', '西海市', 'サイカイシ', '大島町百合が丘', 'オオシマチョウユリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県西海市大島町徳万', '42', '42212', '8572418', '長崎県', 'ナガサキケン', '西海市', 'サイカイシ', '大島町徳万', 'オオシマチョウトクマン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県西海市大島町蛤', '42', '42212', '8572419', '長崎県', 'ナガサキケン', '西海市', 'サイカイシ', '大島町蛤', 'オオシマチョウハマグリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県西海市大島町中戸', '42', '42212', '8572421', '長崎県', 'ナガサキケン', '西海市', 'サイカイシ', '大島町中戸', 'オオシマチョウナカト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県西海市大島町太田尾', '42', '42212', '8572422', '長崎県', 'ナガサキケン', '西海市', 'サイカイシ', '大島町太田尾', 'オオシマチョウオオダオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県西海市大島町塔尾', '42', '42212', '8572423', '長崎県', 'ナガサキケン', '西海市', 'サイカイシ', '大島町塔尾', 'オオシマチョウトオノオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県西海市大島町塩田', '42', '42212', '8572424', '長崎県', 'ナガサキケン', '西海市', 'サイカイシ', '大島町塩田', 'オオシマチョウシオダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県西海市大島町田浦', '42', '42212', '8572425', '長崎県', 'ナガサキケン', '西海市', 'サイカイシ', '大島町田浦', 'オオシマチョウタノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県西海市大島町大島', '42', '42212', '8572426', '長崎県', 'ナガサキケン', '西海市', 'サイカイシ', '大島町大島', 'オオシマチョウオオジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県西海市', '42', '42212', '8572427', '長崎県', 'ナガサキケン', '西海市', 'サイカイシ', null, '　', '（直番地）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('109837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県西海市大瀬戸町松島内郷', '42', '42212', '8572531', '長崎県', 'ナガサキケン', '西海市', 'サイカイシ', '大瀬戸町松島内郷', 'オオセトチョウマツシマウチゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県西海市大瀬戸町松島外郷', '42', '42212', '8572532', '長崎県', 'ナガサキケン', '西海市', 'サイカイシ', '大瀬戸町松島外郷', 'オオセトチョウマツシマソトゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県西海市崎戸町蠣浦郷', '42', '42212', '8573101', '長崎県', 'ナガサキケン', '西海市', 'サイカイシ', '崎戸町蠣浦郷', 'サキトチョウカキノウラゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県西海市崎戸町本郷', '42', '42212', '8573102', '長崎県', 'ナガサキケン', '西海市', 'サイカイシ', '崎戸町本郷', 'サキトチョウホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県西海市崎戸町江島', '42', '42212', '8573103', '長崎県', 'ナガサキケン', '西海市', 'サイカイシ', '崎戸町江島', 'サキトチョウエノシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市黒島町', '42', '42202', '8573271', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '黒島町', 'クロシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県西海市崎戸町平島', '42', '42212', '8573311', '長崎県', 'ナガサキケン', '西海市', 'サイカイシ', '崎戸町平島', 'サキトチョウヒラシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県南松浦郡新上五島町赤尾郷', '42', '42411', '8574101', '長崎県', 'ナガサキケン', '南松浦郡新上五島町', 'ミナミマツウラグンシンカミゴトウチョウ', '赤尾郷', 'アカオゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県南松浦郡新上五島町友住郷', '42', '42411', '8574102', '長崎県', 'ナガサキケン', '南松浦郡新上五島町', 'ミナミマツウラグンシンカミゴトウチョウ', '友住郷', 'トモスミゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県南松浦郡新上五島町江ノ浜郷', '42', '42411', '8574103', '長崎県', 'ナガサキケン', '南松浦郡新上五島町', 'ミナミマツウラグンシンカミゴトウチョウ', '江ノ浜郷', 'エノハマゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県南松浦郡新上五島町有川郷', '42', '42411', '8574211', '長崎県', 'ナガサキケン', '南松浦郡新上五島町', 'ミナミマツウラグンシンカミゴトウチョウ', '有川郷', 'アリカワゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県南松浦郡新上五島町小河原郷', '42', '42411', '8574212', '長崎県', 'ナガサキケン', '南松浦郡新上五島町', 'ミナミマツウラグンシンカミゴトウチョウ', '小河原郷', 'オガワラゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県南松浦郡新上五島町太田郷', '42', '42411', '8574213', '長崎県', 'ナガサキケン', '南松浦郡新上五島町', 'ミナミマツウラグンシンカミゴトウチョウ', '太田郷', 'オオタゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県南松浦郡新上五島町七目郷', '42', '42411', '8574214', '長崎県', 'ナガサキケン', '南松浦郡新上五島町', 'ミナミマツウラグンシンカミゴトウチョウ', '七目郷', 'ナナメゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県南松浦郡新上五島町', '42', '42411', '8574400', '長崎県', 'ナガサキケン', '南松浦郡新上五島町', 'ミナミマツウラグンシンカミゴトウチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('109852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県南松浦郡新上五島町網上郷', '42', '42411', '8574401', '長崎県', 'ナガサキケン', '南松浦郡新上五島町', 'ミナミマツウラグンシンカミゴトウチョウ', '網上郷', 'アミアゲゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県南松浦郡新上五島町奈摩郷', '42', '42411', '8574402', '長崎県', 'ナガサキケン', '南松浦郡新上五島町', 'ミナミマツウラグンシンカミゴトウチョウ', '奈摩郷', 'ナマゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県南松浦郡新上五島町青方郷', '42', '42411', '8574404', '長崎県', 'ナガサキケン', '南松浦郡新上五島町', 'ミナミマツウラグンシンカミゴトウチョウ', '青方郷', 'アオカタゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県南松浦郡新上五島町船崎郷', '42', '42411', '8574405', '長崎県', 'ナガサキケン', '南松浦郡新上五島町', 'ミナミマツウラグンシンカミゴトウチョウ', '船崎郷', 'フナサキゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県南松浦郡新上五島町相河郷', '42', '42411', '8574411', '長崎県', 'ナガサキケン', '南松浦郡新上五島町', 'ミナミマツウラグンシンカミゴトウチョウ', '相河郷', 'アイコゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県南松浦郡新上五島町三日ノ浦郷', '42', '42411', '8574412', '長崎県', 'ナガサキケン', '南松浦郡新上五島町', 'ミナミマツウラグンシンカミゴトウチョウ', '三日ノ浦郷', 'ミカノウラゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県南松浦郡新上五島町今里郷', '42', '42411', '8574413', '長崎県', 'ナガサキケン', '南松浦郡新上五島町', 'ミナミマツウラグンシンカミゴトウチョウ', '今里郷', 'イマザトゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県南松浦郡新上五島町飯ノ瀬戸郷', '42', '42411', '8574414', '長崎県', 'ナガサキケン', '南松浦郡新上五島町', 'ミナミマツウラグンシンカミゴトウチョウ', '飯ノ瀬戸郷', 'イノセドゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県南松浦郡新上五島町続浜ノ浦郷', '42', '42411', '8574415', '長崎県', 'ナガサキケン', '南松浦郡新上五島町', 'ミナミマツウラグンシンカミゴトウチョウ', '続浜ノ浦郷', 'ツヅキハマノウラゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県南松浦郡新上五島町道土井郷', '42', '42411', '8574416', '長崎県', 'ナガサキケン', '南松浦郡新上五島町', 'ミナミマツウラグンシンカミゴトウチョウ', '道土井郷', 'ミチドイゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県南松浦郡新上五島町浦桑郷', '42', '42411', '8574511', '長崎県', 'ナガサキケン', '南松浦郡新上五島町', 'ミナミマツウラグンシンカミゴトウチョウ', '浦桑郷', 'ウラクワゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県南松浦郡新上五島町榎津郷', '42', '42411', '8574512', '長崎県', 'ナガサキケン', '南松浦郡新上五島町', 'ミナミマツウラグンシンカミゴトウチョウ', '榎津郷', 'エノキヅゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県南松浦郡新上五島町丸尾郷', '42', '42411', '8574513', '長崎県', 'ナガサキケン', '南松浦郡新上五島町', 'ミナミマツウラグンシンカミゴトウチョウ', '丸尾郷', 'マルオゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県南松浦郡新上五島町似首郷', '42', '42411', '8574514', '長崎県', 'ナガサキケン', '南松浦郡新上五島町', 'ミナミマツウラグンシンカミゴトウチョウ', '似首郷', 'ニタクビゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県南松浦郡新上五島町小串郷', '42', '42411', '8574601', '長崎県', 'ナガサキケン', '南松浦郡新上五島町', 'ミナミマツウラグンシンカミゴトウチョウ', '小串郷', 'コグシゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県南松浦郡新上五島町曽根郷', '42', '42411', '8574602', '長崎県', 'ナガサキケン', '南松浦郡新上五島町', 'ミナミマツウラグンシンカミゴトウチョウ', '曽根郷', 'ソネゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県南松浦郡新上五島町立串郷', '42', '42411', '8574603', '長崎県', 'ナガサキケン', '南松浦郡新上五島町', 'ミナミマツウラグンシンカミゴトウチョウ', '立串郷', 'タテクシゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県南松浦郡新上五島町津和崎郷', '42', '42411', '8574604', '長崎県', 'ナガサキケン', '南松浦郡新上五島町', 'ミナミマツウラグンシンカミゴトウチョウ', '津和崎郷', 'ツワザキゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県北松浦郡小値賀町', '42', '42383', '8574700', '長崎県', 'ナガサキケン', '北松浦郡小値賀町', 'キタマツウラグンオヂカチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('109873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県北松浦郡小値賀町笛吹郷', '42', '42383', '8574701', '長崎県', 'ナガサキケン', '北松浦郡小値賀町', 'キタマツウラグンオヂカチョウ', '笛吹郷', 'フエフキゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県北松浦郡小値賀町前方郷', '42', '42383', '8574702', '長崎県', 'ナガサキケン', '北松浦郡小値賀町', 'キタマツウラグンオヂカチョウ', '前方郷', 'マエガタゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県北松浦郡小値賀町中村郷', '42', '42383', '8574703', '長崎県', 'ナガサキケン', '北松浦郡小値賀町', 'キタマツウラグンオヂカチョウ', '中村郷', 'ナカムラゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県北松浦郡小値賀町柳郷', '42', '42383', '8574704', '長崎県', 'ナガサキケン', '北松浦郡小値賀町', 'キタマツウラグンオヂカチョウ', '柳郷', 'ヤナギゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県北松浦郡小値賀町浜津郷', '42', '42383', '8574705', '長崎県', 'ナガサキケン', '北松浦郡小値賀町', 'キタマツウラグンオヂカチョウ', '浜津郷', 'ハマヅゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県北松浦郡小値賀町黒島郷', '42', '42383', '8574706', '長崎県', 'ナガサキケン', '北松浦郡小値賀町', 'キタマツウラグンオヂカチョウ', '黒島郷', 'クロシマゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県北松浦郡小値賀町班島郷', '42', '42383', '8574707', '長崎県', 'ナガサキケン', '北松浦郡小値賀町', 'キタマツウラグンオヂカチョウ', '班島郷', 'マダラシマゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県北松浦郡小値賀町大島郷', '42', '42383', '8574708', '長崎県', 'ナガサキケン', '北松浦郡小値賀町', 'キタマツウラグンオヂカチョウ', '大島郷', 'オオシマゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県北松浦郡小値賀町野崎郷', '42', '42383', '8574709', '長崎県', 'ナガサキケン', '北松浦郡小値賀町', 'キタマツウラグンオヂカチョウ', '野崎郷', 'ノザキゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県北松浦郡小値賀町納島郷', '42', '42383', '8574711', '長崎県', 'ナガサキケン', '北松浦郡小値賀町', 'キタマツウラグンオヂカチョウ', '納島郷', 'ノウシマゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県北松浦郡小値賀町六島郷', '42', '42383', '8574712', '長崎県', 'ナガサキケン', '北松浦郡小値賀町', 'キタマツウラグンオヂカチョウ', '六島郷', 'ムシマゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市宇久町神浦', '42', '42202', '8574811', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '宇久町神浦', 'ウクマチコウノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市宇久町小浜', '42', '42202', '8574812', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '宇久町小浜', 'ウクマチオバマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市宇久町飯良', '42', '42202', '8574813', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '宇久町飯良', 'ウクマチイイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市宇久町本飯良', '42', '42202', '8574814', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '宇久町本飯良', 'ウクマチモトイイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市宇久町大久保', '42', '42202', '8574815', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '宇久町大久保', 'ウクマチオオクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市宇久町寺島', '42', '42202', '8574816', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '宇久町寺島', 'ウクマチテラシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市宇久町平', '42', '42202', '8574901', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '宇久町平', 'ウクマチタイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市宇久町野方', '42', '42202', '8574902', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '宇久町野方', 'ウクマチノガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市宇久町太田江', '42', '42202', '8574903', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '宇久町太田江', 'ウクマチオオダエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市宇久町木場', '42', '42202', '8574904', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '宇久町木場', 'ウクマチコバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市岳野町', '42', '42202', '8580901', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '岳野町', 'タケノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市踊石町', '42', '42202', '8580902', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '踊石町', 'オドリイシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市上本山町', '42', '42202', '8580903', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '上本山町', 'カミモトヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市中里町', '42', '42202', '8580904', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '中里町', 'ナカザトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市下本山町', '42', '42202', '8580905', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '下本山町', 'シモモトヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市八の久保町', '42', '42202', '8580906', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '八の久保町', 'ハチノクボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市棚方町', '42', '42202', '8580907', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '棚方町', 'タナガタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市光町', '42', '42202', '8580908', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '光町', 'ヒカリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市竹辺町', '42', '42202', '8580911', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '竹辺町', 'タケベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市母ケ浦町', '42', '42202', '8580912', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '母ケ浦町', 'ホウガウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市新田町', '42', '42202', '8580913', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '新田町', 'シンデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市川下町', '42', '42202', '8580914', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '川下町', 'カワシモチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市上相浦町', '42', '42202', '8580915', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '上相浦町', 'カミアイノウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市木宮町', '42', '42202', '8580916', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '木宮町', 'キノミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市愛宕町', '42', '42202', '8580917', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '愛宕町', 'アタゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市相浦町', '42', '42202', '8580918', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '相浦町', 'アイノウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市長坂町', '42', '42202', '8580921', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '長坂町', 'ナガサカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市鹿子前町', '42', '42202', '8580922', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '鹿子前町', 'カシマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市日野町', '42', '42202', '8580923', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '日野町', 'ヒノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市星和台町', '42', '42202', '8580924', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '星和台町', 'セイワダイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市椎木町', '42', '42202', '8580925', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '椎木町', 'シイノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市大潟町', '42', '42202', '8580926', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '大潟町', 'オオガタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市高島町', '42', '42202', '8580931', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '高島町', 'タカシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市小野町', '42', '42202', '8580965', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '小野町', 'オノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市高来町大戸', '42', '42204', '8590101', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '高来町大戸', 'タカキチョウオオト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市高来町折山', '42', '42204', '8590102', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '高来町折山', 'タカキチョウオリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市高来町古場', '42', '42204', '8590103', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '高来町古場', 'タカキチョウコバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市高来町建山', '42', '42204', '8590104', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '高来町建山', 'タカキチョウタチヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市高来町船津', '42', '42204', '8590105', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '高来町船津', 'タカキチョウフナツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市高来町冨地戸', '42', '42204', '8590106', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '高来町冨地戸', 'タカキチョウフジト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市高来町上与', '42', '42204', '8590111', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '高来町上与', 'タカキチョウウワグミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市高来町小船津', '42', '42204', '8590112', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '高来町小船津', 'タカキチョウコブナツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市高来町下与', '42', '42204', '8590113', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '高来町下与', 'タカキチョウシタグミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市高来町西平原', '42', '42204', '8590114', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '高来町西平原', 'タカキチョウニシヒラバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市高来町西尾', '42', '42204', '8590115', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '高来町西尾', 'タカキチョウニシノオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市高来町平田', '42', '42204', '8590116', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '高来町平田', 'タカキチョウヒラタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市高来町峰', '42', '42204', '8590117', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '高来町峰', 'タカキチョウミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市高来町泉', '42', '42204', '8590121', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '高来町泉', 'タカキチョウイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市高来町黒崎', '42', '42204', '8590122', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '高来町黒崎', 'タカキチョウクロサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市高来町小峰', '42', '42204', '8590123', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '高来町小峰', 'タカキチョウコミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市高来町里', '42', '42204', '8590124', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '高来町里', 'タカキチョウサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市高来町善住寺', '42', '42204', '8590125', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '高来町善住寺', 'タカキチョウゼンジュウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市高来町法川', '42', '42204', '8590126', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '高来町法川', 'タカキチョウノリガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市高来町町名', '42', '42204', '8590127', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '高来町町名', 'タカキチョウマチミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市高来町神津倉', '42', '42204', '8590131', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '高来町神津倉', 'タカキチョウコウヅクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市高来町三部壱', '42', '42204', '8590132', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '高来町三部壱', 'タカキチョウサンブイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市高来町東平原', '42', '42204', '8590133', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '高来町東平原', 'タカキチョウヒガシヒラバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市高来町汲水', '42', '42204', '8590141', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '高来町汲水', 'タカキチョウクミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市高来町黒新田', '42', '42204', '8590142', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '高来町黒新田', 'タカキチョウクロニタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市高来町坂元', '42', '42204', '8590143', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '高来町坂元', 'タカキチョウサカモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市高来町溝口', '42', '42204', '8590144', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '高来町溝口', 'タカキチョウミゾグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市高来町山道', '42', '42204', '8590145', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '高来町山道', 'タカキチョウヤマミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市高来町金崎', '42', '42204', '8590146', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '高来町金崎', 'タカキチョウカナサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市高来町水ノ浦', '42', '42204', '8590147', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '高来町水ノ浦', 'タカキチョウミズノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市小長井町打越', '42', '42204', '8590151', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '小長井町打越', 'コナガイチョウウチコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市小長井町大搦', '42', '42204', '8590152', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '小長井町大搦', 'コナガイチョウオオガラミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('109999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市小長井町大峰', '42', '42204', '8590153', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '小長井町大峰', 'コナガイチョウオオミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市小長井町川内', '42', '42204', '8590154', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '小長井町川内', 'コナガイチョウコウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市小長井町古場', '42', '42204', '8590161', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '小長井町古場', 'コナガイチョウコバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市小長井町新田原', '42', '42204', '8590162', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '小長井町新田原', 'コナガイチョウシンタバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市小長井町田原', '42', '42204', '8590163', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '小長井町田原', 'コナガイチョウタバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市小長井町牧', '42', '42204', '8590164', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '小長井町牧', 'コナガイチョウマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市小長井町小川原浦', '42', '42204', '8590165', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '小長井町小川原浦', 'コナガイチョウオガワハラウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市小長井町井崎', '42', '42204', '8590166', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '小長井町井崎', 'コナガイチョウイザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市小長井町遠竹', '42', '42204', '8590167', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '小長井町遠竹', 'コナガイチョウトオダケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市高来町小江干拓', '42', '42204', '8590171', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '高来町小江干拓', 'タカキチョウオエカンタク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市長田町', '42', '42204', '8590301', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '長田町', 'ナガタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市正久寺町', '42', '42204', '8590302', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '正久寺町', 'ショウキュウジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市高天町', '42', '42204', '8590303', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '高天町', 'コウテンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市白浜町', '42', '42204', '8590304', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '白浜町', 'シラハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市猿崎町', '42', '42204', '8590305', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '猿崎町', 'サルザキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市白原町', '42', '42204', '8590306', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '白原町', 'シラハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市白木峰町', '42', '42204', '8590307', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '白木峰町', 'シラキミネマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市小豆崎町', '42', '42204', '8590311', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '小豆崎町', 'アズキサキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市西里町', '42', '42204', '8590312', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '西里町', 'ニシザトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市中田町', '42', '42204', '8590313', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '中田町', 'ナカダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市御手水町', '42', '42204', '8590314', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '御手水町', 'オチョウズマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市大場町', '42', '42204', '8590315', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '大場町', 'オオバマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市多良見町化屋', '42', '42204', '8590401', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '多良見町化屋', 'タラミチョウケヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市多良見町囲', '42', '42204', '8590402', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '多良見町囲', 'タラミチョウカコイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市多良見町市布', '42', '42204', '8590403', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '多良見町市布', 'タラミチョウイチヌノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市多良見町西川内', '42', '42204', '8590404', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '多良見町西川内', 'タラミチョウニシカワウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市多良見町中里', '42', '42204', '8590405', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '多良見町中里', 'タラミチョウナカザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市多良見町木床', '42', '42204', '8590406', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '多良見町木床', 'タラミチョウキドコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市多良見町シーサイド', '42', '42204', '8590407', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '多良見町シーサイド', 'タラミチョウシーサイド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市多良見町東園', '42', '42204', '8590411', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '多良見町東園', 'タラミチョウヒガシゾノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市多良見町西園', '42', '42204', '8590412', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '多良見町西園', 'タラミチョウニシゾノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市多良見町野副', '42', '42204', '8590413', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '多良見町野副', 'タラミチョウノゾエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市多良見町元釜', '42', '42204', '8590414', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '多良見町元釜', 'タラミチョウモトガマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市多良見町山川内', '42', '42204', '8590415', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '多良見町山川内', 'タラミチョウヤマガワウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市多良見町野川内', '42', '42204', '8590416', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '多良見町野川内', 'タラミチョウノガワウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市多良見町舟津', '42', '42204', '8590417', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '多良見町舟津', 'タラミチョウフナツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県諫早市多良見町佐瀬', '42', '42204', '8590418', '長崎県', 'ナガサキケン', '諫早市', 'イサハヤシ', '多良見町佐瀬', 'タラミチョウサセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県雲仙市吾妻町本村名', '42', '42213', '8591101', '長崎県', 'ナガサキケン', '雲仙市', 'ウンゼンシ', '吾妻町本村名', 'アヅマチョウモトムラミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県雲仙市吾妻町木場名', '42', '42213', '8591102', '長崎県', 'ナガサキケン', '雲仙市', 'ウンゼンシ', '吾妻町木場名', 'アヅマチョウコバミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県雲仙市吾妻町平江名', '42', '42213', '8591103', '長崎県', 'ナガサキケン', '雲仙市', 'ウンゼンシ', '吾妻町平江名', 'アヅマチョウヒラエミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県雲仙市吾妻町古城名', '42', '42213', '8591104', '長崎県', 'ナガサキケン', '雲仙市', 'ウンゼンシ', '吾妻町古城名', 'アヅマチョウフルシロミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県雲仙市吾妻町田之平名', '42', '42213', '8591105', '長崎県', 'ナガサキケン', '雲仙市', 'ウンゼンシ', '吾妻町田之平名', 'アヅマチョウタノヒラミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県雲仙市吾妻町大木場名', '42', '42213', '8591106', '長崎県', 'ナガサキケン', '雲仙市', 'ウンゼンシ', '吾妻町大木場名', 'アヅマチョウオオコバミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県雲仙市吾妻町牛口名', '42', '42213', '8591107', '長崎県', 'ナガサキケン', '雲仙市', 'ウンゼンシ', '吾妻町牛口名', 'アヅマチョウウシグチミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県雲仙市吾妻町馬場名', '42', '42213', '8591111', '長崎県', 'ナガサキケン', '雲仙市', 'ウンゼンシ', '吾妻町馬場名', 'アヅマチョウババミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県雲仙市吾妻町栗林名', '42', '42213', '8591112', '長崎県', 'ナガサキケン', '雲仙市', 'ウンゼンシ', '吾妻町栗林名', 'アヅマチョウクリバヤシミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県雲仙市吾妻町布江名', '42', '42213', '8591113', '長崎県', 'ナガサキケン', '雲仙市', 'ウンゼンシ', '吾妻町布江名', 'アヅマチョウヌノエミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県雲仙市吾妻町川床名', '42', '42213', '8591114', '長崎県', 'ナガサキケン', '雲仙市', 'ウンゼンシ', '吾妻町川床名', 'アヅマチョウカワトコミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県雲仙市吾妻町永中名', '42', '42213', '8591115', '長崎県', 'ナガサキケン', '雲仙市', 'ウンゼンシ', '吾妻町永中名', 'アヅマチョウエイチュウミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県雲仙市吾妻町阿母名', '42', '42213', '8591116', '長崎県', 'ナガサキケン', '雲仙市', 'ウンゼンシ', '吾妻町阿母名', 'アヅマチョウアボミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県雲仙市瑞穂町西郷庚', '42', '42213', '8591201', '長崎県', 'ナガサキケン', '雲仙市', 'ウンゼンシ', '瑞穂町西郷庚', 'ミズホチョウサイゴウコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県雲仙市瑞穂町西郷甲', '42', '42213', '8591202', '長崎県', 'ナガサキケン', '雲仙市', 'ウンゼンシ', '瑞穂町西郷甲', 'ミズホチョウサイゴウコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県雲仙市瑞穂町西郷乙', '42', '42213', '8591203', '長崎県', 'ナガサキケン', '雲仙市', 'ウンゼンシ', '瑞穂町西郷乙', 'ミズホチョウサイゴウオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県雲仙市瑞穂町西郷丙', '42', '42213', '8591204', '長崎県', 'ナガサキケン', '雲仙市', 'ウンゼンシ', '瑞穂町西郷丙', 'ミズホチョウサイゴウヘイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県雲仙市瑞穂町西郷丁', '42', '42213', '8591205', '長崎県', 'ナガサキケン', '雲仙市', 'ウンゼンシ', '瑞穂町西郷丁', 'ミズホチョウサイゴウテイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県雲仙市瑞穂町西郷辛', '42', '42213', '8591206', '長崎県', 'ナガサキケン', '雲仙市', 'ウンゼンシ', '瑞穂町西郷辛', 'ミズホチョウサイゴウシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県雲仙市瑞穂町西郷戊', '42', '42213', '8591211', '長崎県', 'ナガサキケン', '雲仙市', 'ウンゼンシ', '瑞穂町西郷戊', 'ミズホチョウサイゴウボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県雲仙市瑞穂町西郷己', '42', '42213', '8591212', '長崎県', 'ナガサキケン', '雲仙市', 'ウンゼンシ', '瑞穂町西郷己', 'ミズホチョウサイゴウキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県雲仙市瑞穂町伊福甲', '42', '42213', '8591213', '長崎県', 'ナガサキケン', '雲仙市', 'ウンゼンシ', '瑞穂町伊福甲', 'ミズホチョウイフクコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県雲仙市瑞穂町伊福乙', '42', '42213', '8591214', '長崎県', 'ナガサキケン', '雲仙市', 'ウンゼンシ', '瑞穂町伊福乙', 'ミズホチョウイフクオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県雲仙市瑞穂町古部甲', '42', '42213', '8591215', '長崎県', 'ナガサキケン', '雲仙市', 'ウンゼンシ', '瑞穂町古部甲', 'ミズホチョウコベコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県雲仙市瑞穂町古部乙', '42', '42213', '8591216', '長崎県', 'ナガサキケン', '雲仙市', 'ウンゼンシ', '瑞穂町古部乙', 'ミズホチョウコベオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県雲仙市国見町神代甲', '42', '42213', '8591301', '長崎県', 'ナガサキケン', '雲仙市', 'ウンゼンシ', '国見町神代甲', 'クニミチョウコウジロコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県雲仙市国見町神代乙', '42', '42213', '8591302', '長崎県', 'ナガサキケン', '雲仙市', 'ウンゼンシ', '国見町神代乙', 'クニミチョウコウジロオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県雲仙市国見町神代丙', '42', '42213', '8591303', '長崎県', 'ナガサキケン', '雲仙市', 'ウンゼンシ', '国見町神代丙', 'クニミチョウコウジロヘイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県雲仙市国見町神代丁', '42', '42213', '8591304', '長崎県', 'ナガサキケン', '雲仙市', 'ウンゼンシ', '国見町神代丁', 'クニミチョウコウジロテイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県雲仙市国見町神代戊', '42', '42213', '8591305', '長崎県', 'ナガサキケン', '雲仙市', 'ウンゼンシ', '国見町神代戊', 'クニミチョウコウジロボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県雲仙市国見町神代己', '42', '42213', '8591306', '長崎県', 'ナガサキケン', '雲仙市', 'ウンゼンシ', '国見町神代己', 'クニミチョウコウジロキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県雲仙市国見町神代庚', '42', '42213', '8591307', '長崎県', 'ナガサキケン', '雲仙市', 'ウンゼンシ', '国見町神代庚', 'クニミチョウコウジロコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県雲仙市国見町神代辛', '42', '42213', '8591308', '長崎県', 'ナガサキケン', '雲仙市', 'ウンゼンシ', '国見町神代辛', 'クニミチョウコウジロシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県雲仙市国見町土黒甲', '42', '42213', '8591311', '長崎県', 'ナガサキケン', '雲仙市', 'ウンゼンシ', '国見町土黒甲', 'クニミチョウヒジクロコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県雲仙市国見町土黒乙', '42', '42213', '8591312', '長崎県', 'ナガサキケン', '雲仙市', 'ウンゼンシ', '国見町土黒乙', 'クニミチョウヒジクロオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県雲仙市国見町土黒丙', '42', '42213', '8591313', '長崎県', 'ナガサキケン', '雲仙市', 'ウンゼンシ', '国見町土黒丙', 'クニミチョウヒジクロヘイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県雲仙市国見町土黒丁', '42', '42213', '8591314', '長崎県', 'ナガサキケン', '雲仙市', 'ウンゼンシ', '国見町土黒丁', 'クニミチョウヒジクロテイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県雲仙市国見町土黒戊', '42', '42213', '8591315', '長崎県', 'ナガサキケン', '雲仙市', 'ウンゼンシ', '国見町土黒戊', 'クニミチョウヒジクロボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県雲仙市国見町土黒己', '42', '42213', '8591316', '長崎県', 'ナガサキケン', '雲仙市', 'ウンゼンシ', '国見町土黒己', 'クニミチョウヒジクロキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県雲仙市国見町土黒庚', '42', '42213', '8591317', '長崎県', 'ナガサキケン', '雲仙市', 'ウンゼンシ', '国見町土黒庚', 'クニミチョウヒジクロコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県雲仙市国見町多比良甲', '42', '42213', '8591321', '長崎県', 'ナガサキケン', '雲仙市', 'ウンゼンシ', '国見町多比良甲', 'クニミチョウタイラコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県雲仙市国見町多比良乙', '42', '42213', '8591322', '長崎県', 'ナガサキケン', '雲仙市', 'ウンゼンシ', '国見町多比良乙', 'クニミチョウタイラオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県雲仙市国見町多比良丙', '42', '42213', '8591323', '長崎県', 'ナガサキケン', '雲仙市', 'ウンゼンシ', '国見町多比良丙', 'クニミチョウタイラヘイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県雲仙市国見町多比良丁', '42', '42213', '8591324', '長崎県', 'ナガサキケン', '雲仙市', 'ウンゼンシ', '国見町多比良丁', 'クニミチョウタイラテイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県雲仙市国見町多比良戊', '42', '42213', '8591325', '長崎県', 'ナガサキケン', '雲仙市', 'ウンゼンシ', '国見町多比良戊', 'クニミチョウタイラボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市有明町湯江甲', '42', '42203', '8591401', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '有明町湯江甲', 'アリアケチョウユエコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市有明町湯江乙', '42', '42203', '8591402', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '有明町湯江乙', 'アリアケチョウユエオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市有明町湯江丙', '42', '42203', '8591403', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '有明町湯江丙', 'アリアケチョウユエヘイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市有明町湯江丁', '42', '42203', '8591404', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '有明町湯江丁', 'アリアケチョウユエテイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市有明町大三東甲', '42', '42203', '8591411', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '有明町大三東甲', 'アリアケチョウオオミサキコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市有明町大三東乙', '42', '42203', '8591412', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '有明町大三東乙', 'アリアケチョウオオミサキオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市有明町大三東丙', '42', '42203', '8591413', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '有明町大三東丙', 'アリアケチョウオオミサキヘイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市有明町大三東丁', '42', '42203', '8591414', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '有明町大三東丁', 'アリアケチョウオオミサキテイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県島原市有明町大三東戊', '42', '42203', '8591415', '長崎県', 'ナガサキケン', '島原市', 'シマバラシ', '有明町大三東戊', 'アリアケチョウオオミサキボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県南島原市深江町甲', '42', '42214', '8591501', '長崎県', 'ナガサキケン', '南島原市', 'ミナミシマバラシ', '深江町甲', 'フカエチョウコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県南島原市深江町乙', '42', '42214', '8591502', '長崎県', 'ナガサキケン', '南島原市', 'ミナミシマバラシ', '深江町乙', 'フカエチョウオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県南島原市深江町丙', '42', '42214', '8591503', '長崎県', 'ナガサキケン', '南島原市', 'ミナミシマバラシ', '深江町丙', 'フカエチョウヘイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県南島原市深江町丁', '42', '42214', '8591504', '長崎県', 'ナガサキケン', '南島原市', 'ミナミシマバラシ', '深江町丁', 'フカエチョウテイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県南島原市深江町戊', '42', '42214', '8591505', '長崎県', 'ナガサキケン', '南島原市', 'ミナミシマバラシ', '深江町戊', 'フカエチョウボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県南島原市布津町甲', '42', '42214', '8592111', '長崎県', 'ナガサキケン', '南島原市', 'ミナミシマバラシ', '布津町甲', 'フツチョウコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県南島原市布津町乙', '42', '42214', '8592112', '長崎県', 'ナガサキケン', '南島原市', 'ミナミシマバラシ', '布津町乙', 'フツチョウオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県南島原市布津町丙', '42', '42214', '8592113', '長崎県', 'ナガサキケン', '南島原市', 'ミナミシマバラシ', '布津町丙', 'フツチョウヘイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県南島原市有家町石田', '42', '42214', '8592121', '長崎県', 'ナガサキケン', '南島原市', 'ミナミシマバラシ', '有家町石田', 'アリエチョウイシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県南島原市有家町大苑', '42', '42214', '8592122', '長崎県', 'ナガサキケン', '南島原市', 'ミナミシマバラシ', '有家町大苑', 'アリエチョウオオゾノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県南島原市有家町原尾', '42', '42214', '8592123', '長崎県', 'ナガサキケン', '南島原市', 'ミナミシマバラシ', '有家町原尾', 'アリエチョウハラオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県南島原市有家町久保', '42', '42214', '8592201', '長崎県', 'ナガサキケン', '南島原市', 'ミナミシマバラシ', '有家町久保', 'アリエチョウクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県南島原市有家町山川', '42', '42214', '8592202', '長崎県', 'ナガサキケン', '南島原市', 'ミナミシマバラシ', '有家町山川', 'アリエチョウヤマガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県南島原市有家町尾上', '42', '42214', '8592203', '長崎県', 'ナガサキケン', '南島原市', 'ミナミシマバラシ', '有家町尾上', 'アリエチョウオノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県南島原市有家町蒲河', '42', '42214', '8592204', '長崎県', 'ナガサキケン', '南島原市', 'ミナミシマバラシ', '有家町蒲河', 'アリエチョウカマガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県南島原市有家町小川', '42', '42214', '8592205', '長崎県', 'ナガサキケン', '南島原市', 'ミナミシマバラシ', '有家町小川', 'アリエチョウコガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県南島原市有家町中須川', '42', '42214', '8592206', '長崎県', 'ナガサキケン', '南島原市', 'ミナミシマバラシ', '有家町中須川', 'アリエチョウナカスカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県南島原市西有家町里坊', '42', '42214', '8592211', '長崎県', 'ナガサキケン', '南島原市', 'ミナミシマバラシ', '西有家町里坊', 'ニシアリエチョウサトボウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県南島原市西有家町須川', '42', '42214', '8592212', '長崎県', 'ナガサキケン', '南島原市', 'ミナミシマバラシ', '西有家町須川', 'ニシアリエチョウスカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県南島原市西有家町見岳', '42', '42214', '8592213', '長崎県', 'ナガサキケン', '南島原市', 'ミナミシマバラシ', '西有家町見岳', 'ニシアリエチョウミダケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県南島原市西有家町慈恩寺', '42', '42214', '8592214', '長崎県', 'ナガサキケン', '南島原市', 'ミナミシマバラシ', '西有家町慈恩寺', 'ニシアリエチョウジオンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県南島原市西有家町長野', '42', '42214', '8592215', '長崎県', 'ナガサキケン', '南島原市', 'ミナミシマバラシ', '西有家町長野', 'ニシアリエチョウナガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県南島原市西有家町龍石', '42', '42214', '8592216', '長崎県', 'ナガサキケン', '南島原市', 'ミナミシマバラシ', '西有家町龍石', 'ニシアリエチョウタツイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県南島原市北有馬町甲', '42', '42214', '8592301', '長崎県', 'ナガサキケン', '南島原市', 'ミナミシマバラシ', '北有馬町甲', 'キタアリマチョウコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県南島原市北有馬町乙', '42', '42214', '8592302', '長崎県', 'ナガサキケン', '南島原市', 'ミナミシマバラシ', '北有馬町乙', 'キタアリマチョウオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県南島原市北有馬町丙', '42', '42214', '8592303', '長崎県', 'ナガサキケン', '南島原市', 'ミナミシマバラシ', '北有馬町丙', 'キタアリマチョウヘイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県南島原市北有馬町丁', '42', '42214', '8592304', '長崎県', 'ナガサキケン', '南島原市', 'ミナミシマバラシ', '北有馬町丁', 'キタアリマチョウテイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県南島原市北有馬町戊', '42', '42214', '8592305', '長崎県', 'ナガサキケン', '南島原市', 'ミナミシマバラシ', '北有馬町戊', 'キタアリマチョウボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県南島原市北有馬町己', '42', '42214', '8592306', '長崎県', 'ナガサキケン', '南島原市', 'ミナミシマバラシ', '北有馬町己', 'キタアリマチョウキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県南島原市南有馬町己古園轟河', '42', '42214', '8592316', '長崎県', 'ナガサキケン', '南島原市', 'ミナミシマバラシ', '南有馬町己', 'ミナミアリマチョウキ', null, null, '古園轟河', 'フルゾノトロツゴ');
INSERT INTO `ms_addresses` VALUES ('110129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県南島原市南有馬町甲', '42', '42214', '8592411', '長崎県', 'ナガサキケン', '南島原市', 'ミナミシマバラシ', '南有馬町甲', 'ミナミアリマチョウコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県南島原市南有馬町乙', '42', '42214', '8592412', '長崎県', 'ナガサキケン', '南島原市', 'ミナミシマバラシ', '南有馬町乙', 'ミナミアリマチョウオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県南島原市南有馬町丙', '42', '42214', '8592413', '長崎県', 'ナガサキケン', '南島原市', 'ミナミシマバラシ', '南有馬町丙', 'ミナミアリマチョウヘイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県南島原市南有馬町丁', '42', '42214', '8592414', '長崎県', 'ナガサキケン', '南島原市', 'ミナミシマバラシ', '南有馬町丁', 'ミナミアリマチョウテイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県南島原市南有馬町戊', '42', '42214', '8592415', '長崎県', 'ナガサキケン', '南島原市', 'ミナミシマバラシ', '南有馬町戊', 'ミナミアリマチョウボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県南島原市南有馬町己', '42', '42214', '8592416', '長崎県', 'ナガサキケン', '南島原市', 'ミナミシマバラシ', '南有馬町己', 'ミナミアリマチョウキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県南島原市口之津町乙', '42', '42214', '8592501', '長崎県', 'ナガサキケン', '南島原市', 'ミナミシマバラシ', '口之津町乙', 'クチノツチョウオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県南島原市口之津町甲', '42', '42214', '8592502', '長崎県', 'ナガサキケン', '南島原市', 'ミナミシマバラシ', '口之津町甲', 'クチノツチョウコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県南島原市口之津町丁', '42', '42214', '8592503', '長崎県', 'ナガサキケン', '南島原市', 'ミナミシマバラシ', '口之津町丁', 'クチノツチョウテイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県南島原市口之津町丙', '42', '42214', '8592504', '長崎県', 'ナガサキケン', '南島原市', 'ミナミシマバラシ', '口之津町丙', 'クチノツチョウヘイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県南島原市', '42', '42214', '8592600', '長崎県', 'ナガサキケン', '南島原市', 'ミナミシマバラシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('110140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県南島原市加津佐町己', '42', '42214', '8592601', '長崎県', 'ナガサキケン', '南島原市', 'ミナミシマバラシ', '加津佐町己', 'カヅサチョウキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県南島原市加津佐町戊', '42', '42214', '8592602', '長崎県', 'ナガサキケン', '南島原市', 'ミナミシマバラシ', '加津佐町戊', 'カヅサチョウボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県南島原市加津佐町丁', '42', '42214', '8592603', '長崎県', 'ナガサキケン', '南島原市', 'ミナミシマバラシ', '加津佐町丁', 'カヅサチョウテイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県南島原市加津佐町丙', '42', '42214', '8592604', '長崎県', 'ナガサキケン', '南島原市', 'ミナミシマバラシ', '加津佐町丙', 'カヅサチョウヘイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県南島原市加津佐町乙', '42', '42214', '8592605', '長崎県', 'ナガサキケン', '南島原市', 'ミナミシマバラシ', '加津佐町乙', 'カヅサチョウオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県南島原市加津佐町甲', '42', '42214', '8592606', '長崎県', 'ナガサキケン', '南島原市', 'ミナミシマバラシ', '加津佐町甲', 'カヅサチョウコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市三川内本町', '42', '42202', '8593151', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '三川内本町', 'ミカワチホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市新行江町', '42', '42202', '8593152', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '新行江町', 'シンギョウエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市三川内新町', '42', '42202', '8593153', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '三川内新町', 'ミカワチシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市塩浸町', '42', '42202', '8593154', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '塩浸町', 'シオヒタシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市三川内町', '42', '42202', '8593155', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '三川内町', 'ミカワチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市下の原町', '42', '42202', '8593156', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '下の原町', 'シモノハルチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市桑木場町', '42', '42202', '8593157', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '桑木場町', 'クワコバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市新替町', '42', '42202', '8593158', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '新替町', 'シンガエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市口の尾町', '42', '42202', '8593161', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '口の尾町', 'クチノオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市吉福町', '42', '42202', '8593162', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '吉福町', 'ヨシフクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市横手町', '42', '42202', '8593163', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '横手町', 'ヨコテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市心野町', '42', '42202', '8593164', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '心野町', 'ココンノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市江永町', '42', '42202', '8593165', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '江永町', 'エナガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市木原町', '42', '42202', '8593166', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '木原町', 'キハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市平松町', '42', '42202', '8593201', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '平松町', 'ヒラマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市上原町', '42', '42202', '8593202', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '上原町', 'ウワバルチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市陣の内町', '42', '42202', '8593203', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '陣の内町', 'ジンノウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市若竹台町', '42', '42202', '8593204', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '若竹台町', 'ワカタケダイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市田の浦町', '42', '42202', '8593205', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '田の浦町', 'タノウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市早苗町', '42', '42202', '8593211', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '早苗町', 'サナエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市花高', '42', '42202', '8593212', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '花高', 'ハナタカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市権常寺町', '42', '42202', '8593213', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '権常寺町', 'ゴンジョウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市権常寺', '42', '42202', '8593214', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '権常寺', 'ゴンジョウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市早岐', '42', '42202', '8593215', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '早岐', 'ハイキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市勝海町', '42', '42202', '8593216', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '勝海町', 'カツウミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市中原町', '42', '42202', '8593221', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '中原町', 'ナカハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市広田町', '42', '42202', '8593222', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '広田町', 'ヒロダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市広田', '42', '42202', '8593223', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '広田', 'ヒロタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市重尾町', '42', '42202', '8593224', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '重尾町', 'シゲオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市浦川内町', '42', '42202', '8593225', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '浦川内町', 'ウラガワチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市崎岡町', '42', '42202', '8593226', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '崎岡町', 'サキオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市瀬道町', '42', '42202', '8593231', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '瀬道町', 'セドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市萩坂町', '42', '42202', '8593232', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '萩坂町', 'ハギサカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市奥山町', '42', '42202', '8593233', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '奥山町', 'オクヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市長畑町', '42', '42202', '8593234', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '長畑町', 'ナガハタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市宮津町', '42', '42202', '8593235', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '宮津町', 'ミヤヅチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市南風崎町', '42', '42202', '8593236', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '南風崎町', 'ハエノサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市城間町', '42', '42202', '8593237', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '城間町', 'ジョウマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市有福町', '42', '42202', '8593241', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '有福町', 'アリフクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市指方町', '42', '42202', '8593242', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '指方町', 'サシカタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市ハウステンボス町', '42', '42202', '8593243', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', 'ハウステンボス町', 'ハウステンボスマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市江上町', '42', '42202', '8593244', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '江上町', 'エガミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市針尾東町', '42', '42202', '8593451', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '針尾東町', 'ハリオヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市針尾中町', '42', '42202', '8593452', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '針尾中町', 'ハリオナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市針尾西町', '42', '42202', '8593453', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '針尾西町', 'ハリオニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市針尾北町', '42', '42202', '8593454', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '針尾北町', 'ハリオキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県東彼杵郡川棚町', '42', '42322', '8593600', '長崎県', 'ナガサキケン', '東彼杵郡川棚町', 'ヒガシソノギグンカワタナチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('110196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県東彼杵郡川棚町猪乗川内郷', '42', '42322', '8593601', '長崎県', 'ナガサキケン', '東彼杵郡川棚町', 'ヒガシソノギグンカワタナチョウ', '猪乗川内郷', 'イノリゴウチゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県東彼杵郡川棚町木場郷', '42', '42322', '8593602', '長崎県', 'ナガサキケン', '東彼杵郡川棚町', 'ヒガシソノギグンカワタナチョウ', '木場郷', 'コバゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県東彼杵郡川棚町岩屋郷', '42', '42322', '8593603', '長崎県', 'ナガサキケン', '東彼杵郡川棚町', 'ヒガシソノギグンカワタナチョウ', '岩屋郷', 'イワヤゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県東彼杵郡川棚町石木郷', '42', '42322', '8593604', '長崎県', 'ナガサキケン', '東彼杵郡川棚町', 'ヒガシソノギグンカワタナチョウ', '石木郷', 'イシキゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県東彼杵郡川棚町百津郷', '42', '42322', '8593605', '長崎県', 'ナガサキケン', '東彼杵郡川棚町', 'ヒガシソノギグンカワタナチョウ', '百津郷', 'モモヅゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県東彼杵郡川棚町小音琴郷', '42', '42322', '8593606', '長崎県', 'ナガサキケン', '東彼杵郡川棚町', 'ヒガシソノギグンカワタナチョウ', '小音琴郷', 'コネゴトゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県東彼杵郡川棚町城山町', '42', '42322', '8593607', '長崎県', 'ナガサキケン', '東彼杵郡川棚町', 'ヒガシソノギグンカワタナチョウ', '城山町', 'シロヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県東彼杵郡川棚町栄町', '42', '42322', '8593608', '長崎県', 'ナガサキケン', '東彼杵郡川棚町', 'ヒガシソノギグンカワタナチョウ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県東彼杵郡川棚町中山郷', '42', '42322', '8593611', '長崎県', 'ナガサキケン', '東彼杵郡川棚町', 'ヒガシソノギグンカワタナチョウ', '中山郷', 'ナカヤマゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県東彼杵郡川棚町五反田郷', '42', '42322', '8593612', '長崎県', 'ナガサキケン', '東彼杵郡川棚町', 'ヒガシソノギグンカワタナチョウ', '五反田郷', 'ゴタンダゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県東彼杵郡川棚町上組郷', '42', '42322', '8593613', '長崎県', 'ナガサキケン', '東彼杵郡川棚町', 'ヒガシソノギグンカワタナチョウ', '上組郷', 'カミグミゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県東彼杵郡川棚町中組郷', '42', '42322', '8593614', '長崎県', 'ナガサキケン', '東彼杵郡川棚町', 'ヒガシソノギグンカワタナチョウ', '中組郷', 'ナカグミゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県東彼杵郡川棚町下組郷', '42', '42322', '8593615', '長崎県', 'ナガサキケン', '東彼杵郡川棚町', 'ヒガシソノギグンカワタナチョウ', '下組郷', 'シモグミゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県東彼杵郡川棚町白石郷', '42', '42322', '8593616', '長崎県', 'ナガサキケン', '東彼杵郡川棚町', 'ヒガシソノギグンカワタナチョウ', '白石郷', 'シロイシゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県東彼杵郡川棚町三越郷', '42', '42322', '8593617', '長崎県', 'ナガサキケン', '東彼杵郡川棚町', 'ヒガシソノギグンカワタナチョウ', '三越郷', 'ミツゴエゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県東彼杵郡川棚町小串郷', '42', '42322', '8593618', '長崎県', 'ナガサキケン', '東彼杵郡川棚町', 'ヒガシソノギグンカワタナチョウ', '小串郷', 'オグシゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県東彼杵郡川棚町新谷郷', '42', '42322', '8593619', '長崎県', 'ナガサキケン', '東彼杵郡川棚町', 'ヒガシソノギグンカワタナチョウ', '新谷郷', 'シンガエゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県東彼杵郡波佐見町', '42', '42323', '8593700', '長崎県', 'ナガサキケン', '東彼杵郡波佐見町', 'ヒガシソノギグンハサミチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('110215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県東彼杵郡波佐見町折敷瀬郷', '42', '42323', '8593701', '長崎県', 'ナガサキケン', '東彼杵郡波佐見町', 'ヒガシソノギグンハサミチョウ', '折敷瀬郷', 'オリシキセゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県東彼杵郡波佐見町湯無田郷', '42', '42323', '8593702', '長崎県', 'ナガサキケン', '東彼杵郡波佐見町', 'ヒガシソノギグンハサミチョウ', '湯無田郷', 'ユムタゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県東彼杵郡波佐見町野々川郷', '42', '42323', '8593703', '長崎県', 'ナガサキケン', '東彼杵郡波佐見町', 'ヒガシソノギグンハサミチョウ', '野々川郷', 'ノノカワゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県東彼杵郡波佐見町小樽郷', '42', '42323', '8593704', '長崎県', 'ナガサキケン', '東彼杵郡波佐見町', 'ヒガシソノギグンハサミチョウ', '小樽郷', 'コダルゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県東彼杵郡波佐見町永尾郷', '42', '42323', '8593705', '長崎県', 'ナガサキケン', '東彼杵郡波佐見町', 'ヒガシソノギグンハサミチョウ', '永尾郷', 'ナガオゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県東彼杵郡波佐見町三股郷', '42', '42323', '8593706', '長崎県', 'ナガサキケン', '東彼杵郡波佐見町', 'ヒガシソノギグンハサミチョウ', '三股郷', 'ミツマタゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県東彼杵郡波佐見町井石郷', '42', '42323', '8593711', '長崎県', 'ナガサキケン', '東彼杵郡波佐見町', 'ヒガシソノギグンハサミチョウ', '井石郷', 'イセキゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県東彼杵郡波佐見町中尾郷', '42', '42323', '8593712', '長崎県', 'ナガサキケン', '東彼杵郡波佐見町', 'ヒガシソノギグンハサミチョウ', '中尾郷', 'ナカオゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県東彼杵郡波佐見町鬼木郷', '42', '42323', '8593713', '長崎県', 'ナガサキケン', '東彼杵郡波佐見町', 'ヒガシソノギグンハサミチョウ', '鬼木郷', 'オニギゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県東彼杵郡波佐見町金屋郷', '42', '42323', '8593714', '長崎県', 'ナガサキケン', '東彼杵郡波佐見町', 'ヒガシソノギグンハサミチョウ', '金屋郷', 'カナヤゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県東彼杵郡波佐見町宿郷', '42', '42323', '8593715', '長崎県', 'ナガサキケン', '東彼杵郡波佐見町', 'ヒガシソノギグンハサミチョウ', '宿郷', 'シュクゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県東彼杵郡波佐見町田ノ頭郷', '42', '42323', '8593716', '長崎県', 'ナガサキケン', '東彼杵郡波佐見町', 'ヒガシソノギグンハサミチョウ', '田ノ頭郷', 'タノカシラゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県東彼杵郡波佐見町川内郷', '42', '42323', '8593721', '長崎県', 'ナガサキケン', '東彼杵郡波佐見町', 'ヒガシソノギグンハサミチョウ', '川内郷', 'カワチゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県東彼杵郡波佐見町岳辺田郷', '42', '42323', '8593722', '長崎県', 'ナガサキケン', '東彼杵郡波佐見町', 'ヒガシソノギグンハサミチョウ', '岳辺田郷', 'タケベタゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県東彼杵郡波佐見町平野郷', '42', '42323', '8593723', '長崎県', 'ナガサキケン', '東彼杵郡波佐見町', 'ヒガシソノギグンハサミチョウ', '平野郷', 'ヒラノゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県東彼杵郡波佐見町志折郷', '42', '42323', '8593724', '長崎県', 'ナガサキケン', '東彼杵郡波佐見町', 'ヒガシソノギグンハサミチョウ', '志折郷', 'シオリゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県東彼杵郡波佐見町長野郷', '42', '42323', '8593725', '長崎県', 'ナガサキケン', '東彼杵郡波佐見町', 'ヒガシソノギグンハサミチョウ', '長野郷', 'ナガノゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県東彼杵郡波佐見町稗木場郷', '42', '42323', '8593726', '長崎県', 'ナガサキケン', '東彼杵郡波佐見町', 'ヒガシソノギグンハサミチョウ', '稗木場郷', 'ヒエコバゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県東彼杵郡波佐見町皿山郷', '42', '42323', '8593727', '長崎県', 'ナガサキケン', '東彼杵郡波佐見町', 'ヒガシソノギグンハサミチョウ', '皿山郷', 'サラヤマゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県東彼杵郡波佐見町村木郷', '42', '42323', '8593728', '長崎県', 'ナガサキケン', '東彼杵郡波佐見町', 'ヒガシソノギグンハサミチョウ', '村木郷', 'ムラギゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県東彼杵郡東彼杵町', '42', '42321', '8593800', '長崎県', 'ナガサキケン', '東彼杵郡東彼杵町', 'ヒガシソノギグンヒガシソノギチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('110239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県東彼杵郡東彼杵町中尾郷', '42', '42321', '8593801', '長崎県', 'ナガサキケン', '東彼杵郡東彼杵町', 'ヒガシソノギグンヒガシソノギチョウ', '中尾郷', 'ナカオゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県東彼杵郡東彼杵町坂本郷', '42', '42321', '8593802', '長崎県', 'ナガサキケン', '東彼杵郡東彼杵町', 'ヒガシソノギグンヒガシソノギチョウ', '坂本郷', 'サカモトゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県東彼杵郡東彼杵町菅無田郷', '42', '42321', '8593803', '長崎県', 'ナガサキケン', '東彼杵郡東彼杵町', 'ヒガシソノギグンヒガシソノギチョウ', '菅無田郷', 'スガムタゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県東彼杵郡東彼杵町法音寺郷', '42', '42321', '8593804', '長崎県', 'ナガサキケン', '東彼杵郡東彼杵町', 'ヒガシソノギグンヒガシソノギチョウ', '法音寺郷', 'ホウオンジゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県東彼杵郡東彼杵町川内郷', '42', '42321', '8593805', '長崎県', 'ナガサキケン', '東彼杵郡東彼杵町', 'ヒガシソノギグンヒガシソノギチョウ', '川内郷', 'カワチゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県東彼杵郡東彼杵町三根郷', '42', '42321', '8593806', '長崎県', 'ナガサキケン', '東彼杵郡東彼杵町', 'ヒガシソノギグンヒガシソノギチョウ', '三根郷', 'ミネゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県東彼杵郡東彼杵町彼杵宿郷', '42', '42321', '8593807', '長崎県', 'ナガサキケン', '東彼杵郡東彼杵町', 'ヒガシソノギグンヒガシソノギチョウ', '彼杵宿郷', 'ソノギシュクゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県東彼杵郡東彼杵町蔵本郷', '42', '42321', '8593808', '長崎県', 'ナガサキケン', '東彼杵郡東彼杵町', 'ヒガシソノギグンヒガシソノギチョウ', '蔵本郷', 'クラモトゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県東彼杵郡東彼杵町口木田郷', '42', '42321', '8593809', '長崎県', 'ナガサキケン', '東彼杵郡東彼杵町', 'ヒガシソノギグンヒガシソノギチョウ', '口木田郷', 'クチキダゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県東彼杵郡東彼杵町大音琴郷', '42', '42321', '8593811', '長崎県', 'ナガサキケン', '東彼杵郡東彼杵町', 'ヒガシソノギグンヒガシソノギチョウ', '大音琴郷', 'オオネゴトゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県東彼杵郡東彼杵町小音琴郷', '42', '42321', '8593812', '長崎県', 'ナガサキケン', '東彼杵郡東彼杵町', 'ヒガシソノギグンヒガシソノギチョウ', '小音琴郷', 'コネゴトゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県東彼杵郡東彼杵町千綿宿郷', '42', '42321', '8593921', '長崎県', 'ナガサキケン', '東彼杵郡東彼杵町', 'ヒガシソノギグンヒガシソノギチョウ', '千綿宿郷', 'チワタシュクゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県東彼杵郡東彼杵町八反田郷', '42', '42321', '8593922', '長崎県', 'ナガサキケン', '東彼杵郡東彼杵町', 'ヒガシソノギグンヒガシソノギチョウ', '八反田郷', 'ハチタンダゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県東彼杵郡東彼杵町瀬戸郷', '42', '42321', '8593923', '長崎県', 'ナガサキケン', '東彼杵郡東彼杵町', 'ヒガシソノギグンヒガシソノギチョウ', '瀬戸郷', 'セトゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県東彼杵郡東彼杵町太ノ浦郷', '42', '42321', '8593924', '長崎県', 'ナガサキケン', '東彼杵郡東彼杵町', 'ヒガシソノギグンヒガシソノギチョウ', '太ノ浦郷', 'タノウラゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県東彼杵郡東彼杵町中岳郷', '42', '42321', '8593925', '長崎県', 'ナガサキケン', '東彼杵郡東彼杵町', 'ヒガシソノギグンヒガシソノギチョウ', '中岳郷', 'ナカタケゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県東彼杵郡東彼杵町蕪郷', '42', '42321', '8593926', '長崎県', 'ナガサキケン', '東彼杵郡東彼杵町', 'ヒガシソノギグンヒガシソノギチョウ', '蕪郷', 'カブラゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県東彼杵郡東彼杵町駄地郷', '42', '42321', '8593927', '長崎県', 'ナガサキケン', '東彼杵郡東彼杵町', 'ヒガシソノギグンヒガシソノギチョウ', '駄地郷', 'ダジゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県東彼杵郡東彼杵町平似田郷', '42', '42321', '8593928', '長崎県', 'ナガサキケン', '東彼杵郡東彼杵町', 'ヒガシソノギグンヒガシソノギチョウ', '平似田郷', 'ヒラニタゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県東彼杵郡東彼杵町里郷', '42', '42321', '8593929', '長崎県', 'ナガサキケン', '東彼杵郡東彼杵町', 'ヒガシソノギグンヒガシソノギチョウ', '里郷', 'サトゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県東彼杵郡東彼杵町木場郷', '42', '42321', '8593931', '長崎県', 'ナガサキケン', '東彼杵郡東彼杵町', 'ヒガシソノギグンヒガシソノギチョウ', '木場郷', 'コバゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県東彼杵郡東彼杵町遠目郷', '42', '42321', '8593932', '長崎県', 'ナガサキケン', '東彼杵郡東彼杵町', 'ヒガシソノギグンヒガシソノギチョウ', '遠目郷', 'トオメゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県東彼杵郡東彼杵町一ッ石郷', '42', '42321', '8593933', '長崎県', 'ナガサキケン', '東彼杵郡東彼杵町', 'ヒガシソノギグンヒガシソノギチョウ', '一ッ石郷', 'ヒトツイシゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県松浦市鷹島町阿翁浦免', '42', '42208', '8594301', '長崎県', 'ナガサキケン', '松浦市', 'マツウラシ', '鷹島町阿翁浦免', 'タカシマチョウアオウウラメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県松浦市鷹島町阿翁免', '42', '42208', '8594302', '長崎県', 'ナガサキケン', '松浦市', 'マツウラシ', '鷹島町阿翁免', 'タカシマチョウアオウメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県松浦市鷹島町神崎免', '42', '42208', '8594303', '長崎県', 'ナガサキケン', '松浦市', 'マツウラシ', '鷹島町神崎免', 'タカシマチョウコウザキメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県松浦市鷹島町里免', '42', '42208', '8594304', '長崎県', 'ナガサキケン', '松浦市', 'マツウラシ', '鷹島町里免', 'タカシマチョウサトメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県松浦市鷹島町中通免', '42', '42208', '8594305', '長崎県', 'ナガサキケン', '松浦市', 'マツウラシ', '鷹島町中通免', 'タカシマチョウナカドオリメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県松浦市鷹島町原免', '42', '42208', '8594306', '長崎県', 'ナガサキケン', '松浦市', 'マツウラシ', '鷹島町原免', 'タカシマチョウハルメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県松浦市鷹島町三里免', '42', '42208', '8594307', '長崎県', 'ナガサキケン', '松浦市', 'マツウラシ', '鷹島町三里免', 'タカシマチョウサンリメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県松浦市鷹島町船唐津免', '42', '42208', '8594308', '長崎県', 'ナガサキケン', '松浦市', 'マツウラシ', '鷹島町船唐津免', 'タカシマチョウフナトウヅメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県松浦市鷹島町黒島免', '42', '42208', '8594309', '長崎県', 'ナガサキケン', '松浦市', 'マツウラシ', '鷹島町黒島免', 'タカシマチョウクロシマメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県松浦市', '42', '42208', '8594500', '長崎県', 'ナガサキケン', '松浦市', 'マツウラシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('110272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県松浦市志佐町浦免', '42', '42208', '8594501', '長崎県', 'ナガサキケン', '松浦市', 'マツウラシ', '志佐町浦免', 'シサチョウウラメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県松浦市志佐町里免', '42', '42208', '8594502', '長崎県', 'ナガサキケン', '松浦市', 'マツウラシ', '志佐町里免', 'シサチョウサトメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県松浦市志佐町高野免', '42', '42208', '8594503', '長崎県', 'ナガサキケン', '松浦市', 'マツウラシ', '志佐町高野免', 'シサチョウタカノメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県松浦市志佐町栢木免', '42', '42208', '8594504', '長崎県', 'ナガサキケン', '松浦市', 'マツウラシ', '志佐町栢木免', 'シサチョウカヤノキメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県松浦市志佐町西山免', '42', '42208', '8594505', '長崎県', 'ナガサキケン', '松浦市', 'マツウラシ', '志佐町西山免', 'シサチョウニシヤマメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県松浦市志佐町白浜免', '42', '42208', '8594506', '長崎県', 'ナガサキケン', '松浦市', 'マツウラシ', '志佐町白浜免', 'シサチョウシラハマメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県松浦市志佐町庄野免', '42', '42208', '8594507', '長崎県', 'ナガサキケン', '松浦市', 'マツウラシ', '志佐町庄野免', 'シサチョウショウノメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県松浦市志佐町赤木免', '42', '42208', '8594511', '長崎県', 'ナガサキケン', '松浦市', 'マツウラシ', '志佐町赤木免', 'シサチョウアカギメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県松浦市志佐町笛吹免', '42', '42208', '8594512', '長崎県', 'ナガサキケン', '松浦市', 'マツウラシ', '志佐町笛吹免', 'シサチョウフエフキメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県松浦市志佐町田ノ平免', '42', '42208', '8594513', '長崎県', 'ナガサキケン', '松浦市', 'マツウラシ', '志佐町田ノ平免', 'シサチョウタノヒラメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県松浦市志佐町柚木川内免', '42', '42208', '8594514', '長崎県', 'ナガサキケン', '松浦市', 'マツウラシ', '志佐町柚木川内免', 'シサチョウユノキガワチメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県松浦市志佐町稗木場免', '42', '42208', '8594515', '長崎県', 'ナガサキケン', '松浦市', 'マツウラシ', '志佐町稗木場免', 'シサチョウヒエコバメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県松浦市志佐町長野免', '42', '42208', '8594516', '長崎県', 'ナガサキケン', '松浦市', 'マツウラシ', '志佐町長野免', 'シサチョウナガノメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県松浦市志佐町横辺田免', '42', '42208', '8594517', '長崎県', 'ナガサキケン', '松浦市', 'マツウラシ', '志佐町横辺田免', 'シサチョウヨコベタメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県松浦市志佐町池成免', '42', '42208', '8594518', '長崎県', 'ナガサキケン', '松浦市', 'マツウラシ', '志佐町池成免', 'シサチョウイケナリメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県松浦市今福町北免', '42', '42208', '8594521', '長崎県', 'ナガサキケン', '松浦市', 'マツウラシ', '今福町北免', 'イマフクチョウキタメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県松浦市今福町東免', '42', '42208', '8594522', '長崎県', 'ナガサキケン', '松浦市', 'マツウラシ', '今福町東免', 'イマフクチョウヒガシメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県松浦市今福町滑栄免', '42', '42208', '8594523', '長崎県', 'ナガサキケン', '松浦市', 'マツウラシ', '今福町滑栄免', 'イマフクチョウナベルバエメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県松浦市今福町木場免', '42', '42208', '8594524', '長崎県', 'ナガサキケン', '松浦市', 'マツウラシ', '今福町木場免', 'イマフクチョウコバメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県松浦市今福町寺上免', '42', '42208', '8594525', '長崎県', 'ナガサキケン', '松浦市', 'マツウラシ', '今福町寺上免', 'イマフクチョウテラゲメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県松浦市今福町坂野免', '42', '42208', '8594526', '長崎県', 'ナガサキケン', '松浦市', 'マツウラシ', '今福町坂野免', 'イマフクチョウサカノメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県松浦市今福町仏坂免', '42', '42208', '8594527', '長崎県', 'ナガサキケン', '松浦市', 'マツウラシ', '今福町仏坂免', 'イマフクチョウホトケザカメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県松浦市今福町浦免', '42', '42208', '8594528', '長崎県', 'ナガサキケン', '松浦市', 'マツウラシ', '今福町浦免', 'イマフクチョウウラメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県松浦市今福町飛島免', '42', '42208', '8594529', '長崎県', 'ナガサキケン', '松浦市', 'マツウラシ', '今福町飛島免', 'イマフクチョウトビシマメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県松浦市調川町平尾免', '42', '42208', '8594531', '長崎県', 'ナガサキケン', '松浦市', 'マツウラシ', '調川町平尾免', 'ツキノカワチョウヒラオメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県松浦市調川町中免', '42', '42208', '8594532', '長崎県', 'ナガサキケン', '松浦市', 'マツウラシ', '調川町中免', 'ツキノカワチョウナカメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県松浦市調川町上免', '42', '42208', '8594533', '長崎県', 'ナガサキケン', '松浦市', 'マツウラシ', '調川町上免', 'ツキノカワチョウカミメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県松浦市調川町白井免', '42', '42208', '8594534', '長崎県', 'ナガサキケン', '松浦市', 'マツウラシ', '調川町白井免', 'ツキノカワチョウシライメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県松浦市調川町松山田免', '42', '42208', '8594535', '長崎県', 'ナガサキケン', '松浦市', 'マツウラシ', '調川町松山田免', 'ツキノカワチョウマツヤマダメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県松浦市調川町下免', '42', '42208', '8594536', '長崎県', 'ナガサキケン', '松浦市', 'マツウラシ', '調川町下免', 'ツキノカワチョウシモメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県松浦市星鹿町北久保免', '42', '42208', '8594741', '長崎県', 'ナガサキケン', '松浦市', 'マツウラシ', '星鹿町北久保免', 'ホシカチョウキタクボメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県松浦市星鹿町牟田免', '42', '42208', '8594742', '長崎県', 'ナガサキケン', '松浦市', 'マツウラシ', '星鹿町牟田免', 'ホシカチョウムタメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県松浦市星鹿町下田免', '42', '42208', '8594743', '長崎県', 'ナガサキケン', '松浦市', 'マツウラシ', '星鹿町下田免', 'ホシカチョウシモダメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県松浦市星鹿町岳崎免', '42', '42208', '8594744', '長崎県', 'ナガサキケン', '松浦市', 'マツウラシ', '星鹿町岳崎免', 'ホシカチョウタケザキメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県松浦市星鹿町青島免', '42', '42208', '8594745', '長崎県', 'ナガサキケン', '松浦市', 'マツウラシ', '星鹿町青島免', 'ホシカチョウアオシマメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県松浦市御厨町池田免', '42', '42208', '8594751', '長崎県', 'ナガサキケン', '松浦市', 'マツウラシ', '御厨町池田免', 'ミクリヤチョウイケダメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県松浦市御厨町里免', '42', '42208', '8594752', '長崎県', 'ナガサキケン', '松浦市', 'マツウラシ', '御厨町里免', 'ミクリヤチョウサトメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県松浦市御厨町中野免', '42', '42208', '8594753', '長崎県', 'ナガサキケン', '松浦市', 'マツウラシ', '御厨町中野免', 'ミクリヤチョウナカノメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県松浦市御厨町北平免', '42', '42208', '8594754', '長崎県', 'ナガサキケン', '松浦市', 'マツウラシ', '御厨町北平免', 'ミクリヤチョウキタビラメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県松浦市御厨町横久保免', '42', '42208', '8594755', '長崎県', 'ナガサキケン', '松浦市', 'マツウラシ', '御厨町横久保免', 'ミクリヤチョウヨコクボメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県松浦市御厨町前田免', '42', '42208', '8594756', '長崎県', 'ナガサキケン', '松浦市', 'マツウラシ', '御厨町前田免', 'ミクリヤチョウマエダメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県松浦市御厨町高野免', '42', '42208', '8594757', '長崎県', 'ナガサキケン', '松浦市', 'マツウラシ', '御厨町高野免', 'ミクリヤチョウタカノメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県松浦市御厨町大崎免', '42', '42208', '8594758', '長崎県', 'ナガサキケン', '松浦市', 'マツウラシ', '御厨町大崎免', 'ミクリヤチョウオオサキメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県松浦市御厨町相坂免', '42', '42208', '8594761', '長崎県', 'ナガサキケン', '松浦市', 'マツウラシ', '御厨町相坂免', 'ミクリヤチョウアイサカメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県松浦市御厨町田原免', '42', '42208', '8594761', '長崎県', 'ナガサキケン', '松浦市', 'マツウラシ', '御厨町田原免', 'ミクリヤチョウタバルメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県松浦市御厨町小船免', '42', '42208', '8594762', '長崎県', 'ナガサキケン', '松浦市', 'マツウラシ', '御厨町小船免', 'ミクリヤチョウコブネメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県松浦市御厨町山根免', '42', '42208', '8594763', '長崎県', 'ナガサキケン', '松浦市', 'マツウラシ', '御厨町山根免', 'ミクリヤチョウヤマネメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県松浦市御厨町狩原免', '42', '42208', '8594764', '長崎県', 'ナガサキケン', '松浦市', 'マツウラシ', '御厨町狩原免', 'ミクリヤチョウカリハラメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県松浦市御厨町米ノ山免', '42', '42208', '8594765', '長崎県', 'ナガサキケン', '松浦市', 'マツウラシ', '御厨町米ノ山免', 'ミクリヤチョウコメノヤマメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県松浦市御厨町普住免', '42', '42208', '8594766', '長崎県', 'ナガサキケン', '松浦市', 'マツウラシ', '御厨町普住免', 'ミクリヤチョウフジュウメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県松浦市御厨町川内免', '42', '42208', '8594767', '長崎県', 'ナガサキケン', '松浦市', 'マツウラシ', '御厨町川内免', 'ミクリヤチョウカワチメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県松浦市御厨町西田免', '42', '42208', '8594768', '長崎県', 'ナガサキケン', '松浦市', 'マツウラシ', '御厨町西田免', 'ミクリヤチョウニシダメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県松浦市御厨町西木場免', '42', '42208', '8594769', '長崎県', 'ナガサキケン', '松浦市', 'マツウラシ', '御厨町西木場免', 'ミクリヤチョウニシコバメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県松浦市御厨町下登木免', '42', '42208', '8594771', '長崎県', 'ナガサキケン', '松浦市', 'マツウラシ', '御厨町下登木免', 'ミクリヤチョウシモノボリキメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県松浦市御厨町寺ノ尾免', '42', '42208', '8594772', '長崎県', 'ナガサキケン', '松浦市', 'マツウラシ', '御厨町寺ノ尾免', 'ミクリヤチョウテラノオメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県松浦市御厨町上登木免', '42', '42208', '8594773', '長崎県', 'ナガサキケン', '松浦市', 'マツウラシ', '御厨町上登木免', 'ミクリヤチョウカミノボリキメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県松浦市御厨町立木免', '42', '42208', '8594774', '長崎県', 'ナガサキケン', '松浦市', 'マツウラシ', '御厨町立木免', 'ミクリヤチョウタチキメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県松浦市御厨町郭公尾免', '42', '42208', '8594775', '長崎県', 'ナガサキケン', '松浦市', 'マツウラシ', '御厨町郭公尾免', 'ミクリヤチョウコッコウノオメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県松浦市御厨町木場免', '42', '42208', '8594776', '長崎県', 'ナガサキケン', '松浦市', 'マツウラシ', '御厨町木場免', 'ミクリヤチョウコバメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県松浦市御厨町板橋免', '42', '42208', '8594777', '長崎県', 'ナガサキケン', '松浦市', 'マツウラシ', '御厨町板橋免', 'ミクリヤチョウイタバシメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県松浦市御厨町田代免', '42', '42208', '8594778', '長崎県', 'ナガサキケン', '松浦市', 'マツウラシ', '御厨町田代免', 'ミクリヤチョウタシロメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県平戸市田平町岳崎免', '42', '42207', '8594801', '長崎県', 'ナガサキケン', '平戸市', 'ヒラドシ', '田平町岳崎免', 'タビラチョウタケザキメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県平戸市田平町福崎免', '42', '42207', '8594802', '長崎県', 'ナガサキケン', '平戸市', 'ヒラドシ', '田平町福崎免', 'タビラチョウフクザキメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県平戸市田平町小崎免', '42', '42207', '8594803', '長崎県', 'ナガサキケン', '平戸市', 'ヒラドシ', '田平町小崎免', 'タビラチョウコザキメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県平戸市田平町上亀免', '42', '42207', '8594804', '長崎県', 'ナガサキケン', '平戸市', 'ヒラドシ', '田平町上亀免', 'タビラチョウカミガメメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県平戸市田平町本山免', '42', '42207', '8594805', '長崎県', 'ナガサキケン', '平戸市', 'ヒラドシ', '田平町本山免', 'タビラチョウモトヤマメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県平戸市田平町下亀免', '42', '42207', '8594806', '長崎県', 'ナガサキケン', '平戸市', 'ヒラドシ', '田平町下亀免', 'タビラチョウシモガメメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県平戸市田平町里免', '42', '42207', '8594807', '長崎県', 'ナガサキケン', '平戸市', 'ヒラドシ', '田平町里免', 'タビラチョウサトメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県平戸市田平町古梶免', '42', '42207', '8594811', '長崎県', 'ナガサキケン', '平戸市', 'ヒラドシ', '田平町古梶免', 'タビラチョウフルカジメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県平戸市田平町田代免', '42', '42207', '8594812', '長崎県', 'ナガサキケン', '平戸市', 'ヒラドシ', '田平町田代免', 'タビラチョウタシロメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県平戸市田平町深月免', '42', '42207', '8594813', '長崎県', 'ナガサキケン', '平戸市', 'ヒラドシ', '田平町深月免', 'タビラチョウフカツキメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県平戸市田平町以善免', '42', '42207', '8594814', '長崎県', 'ナガサキケン', '平戸市', 'ヒラドシ', '田平町以善免', 'タビラチョウイヨシメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県平戸市田平町下寺免', '42', '42207', '8594815', '長崎県', 'ナガサキケン', '平戸市', 'ヒラドシ', '田平町下寺免', 'タビラチョウシモデラメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県平戸市田平町大久保免', '42', '42207', '8594821', '長崎県', 'ナガサキケン', '平戸市', 'ヒラドシ', '田平町大久保免', 'タビラチョウオオクボメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県平戸市田平町一関免', '42', '42207', '8594822', '長崎県', 'ナガサキケン', '平戸市', 'ヒラドシ', '田平町一関免', 'タビラチョウイッセキメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県平戸市田平町荻田免', '42', '42207', '8594823', '長崎県', 'ナガサキケン', '平戸市', 'ヒラドシ', '田平町荻田免', 'タビラチョウオギタメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県平戸市田平町小手田免', '42', '42207', '8594824', '長崎県', 'ナガサキケン', '平戸市', 'ヒラドシ', '田平町小手田免', 'タビラチョウコテダメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県平戸市田平町山内免', '42', '42207', '8594825', '長崎県', 'ナガサキケン', '平戸市', 'ヒラドシ', '田平町山内免', 'タビラチョウヤマウチメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県平戸市田平町野田免', '42', '42207', '8594826', '長崎県', 'ナガサキケン', '平戸市', 'ヒラドシ', '田平町野田免', 'タビラチョウノダメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県平戸市田平町横島免', '42', '42207', '8594827', '長崎県', 'ナガサキケン', '平戸市', 'ヒラドシ', '田平町横島免', 'タビラチョウヨコシマメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県平戸市', '42', '42207', '8595100', '長崎県', 'ナガサキケン', '平戸市', 'ヒラドシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('110358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県平戸市度島町', '42', '42207', '8595101', '長崎県', 'ナガサキケン', '平戸市', 'ヒラドシ', '度島町', 'タクシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県平戸市大久保町', '42', '42207', '8595102', '長崎県', 'ナガサキケン', '平戸市', 'ヒラドシ', '大久保町', 'オオクボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県平戸市田助町', '42', '42207', '8595103', '長崎県', 'ナガサキケン', '平戸市', 'ヒラドシ', '田助町', 'タスケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県平戸市崎方町', '42', '42207', '8595104', '長崎県', 'ナガサキケン', '平戸市', 'ヒラドシ', '崎方町', 'サキガタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県平戸市浦の町', '42', '42207', '8595111', '長崎県', 'ナガサキケン', '平戸市', 'ヒラドシ', '浦の町', 'ウラノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県平戸市宮の町', '42', '42207', '8595112', '長崎県', 'ナガサキケン', '平戸市', 'ヒラドシ', '宮の町', 'ミヤノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県平戸市木引田町', '42', '42207', '8595113', '長崎県', 'ナガサキケン', '平戸市', 'ヒラドシ', '木引田町', 'キヒキダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県平戸市築地町', '42', '42207', '8595114', '長崎県', 'ナガサキケン', '平戸市', 'ヒラドシ', '築地町', 'ツキジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県平戸市新町', '42', '42207', '8595115', '長崎県', 'ナガサキケン', '平戸市', 'ヒラドシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県平戸市職人町', '42', '42207', '8595116', '長崎県', 'ナガサキケン', '平戸市', 'ヒラドシ', '職人町', 'ショクニンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県平戸市魚の棚町', '42', '42207', '8595117', '長崎県', 'ナガサキケン', '平戸市', 'ヒラドシ', '魚の棚町', 'ウオノタナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県平戸市紺屋町', '42', '42207', '8595118', '長崎県', 'ナガサキケン', '平戸市', 'ヒラドシ', '紺屋町', 'コウヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県平戸市岩の上町', '42', '42207', '8595121', '長崎県', 'ナガサキケン', '平戸市', 'ヒラドシ', '岩の上町', 'イワノウエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県平戸市明の川内町', '42', '42207', '8595122', '長崎県', 'ナガサキケン', '平戸市', 'ヒラドシ', '明の川内町', 'アケノカワチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県平戸市大野町', '42', '42207', '8595123', '長崎県', 'ナガサキケン', '平戸市', 'ヒラドシ', '大野町', 'オオノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県平戸市大山町', '42', '42207', '8595131', '長崎県', 'ナガサキケン', '平戸市', 'ヒラドシ', '大山町', 'オオヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県平戸市川内町', '42', '42207', '8595132', '長崎県', 'ナガサキケン', '平戸市', 'ヒラドシ', '川内町', 'カワチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県平戸市中野大久保町', '42', '42207', '8595133', '長崎県', 'ナガサキケン', '平戸市', 'ヒラドシ', '中野大久保町', 'ナカノオオクボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県平戸市水垂町', '42', '42207', '8595134', '長崎県', 'ナガサキケン', '平戸市', 'ヒラドシ', '水垂町', 'ミズタリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県平戸市山中町', '42', '42207', '8595141', '長崎県', 'ナガサキケン', '平戸市', 'ヒラドシ', '山中町', 'ヤマナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県平戸市主師町', '42', '42207', '8595142', '長崎県', 'ナガサキケン', '平戸市', 'ヒラドシ', '主師町', 'シュウシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県平戸市坊方町', '42', '42207', '8595143', '長崎県', 'ナガサキケン', '平戸市', 'ヒラドシ', '坊方町', 'ボウガタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県平戸市下中野町', '42', '42207', '8595144', '長崎県', 'ナガサキケン', '平戸市', 'ヒラドシ', '下中野町', 'シモナカノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県平戸市古江町', '42', '42207', '8595145', '長崎県', 'ナガサキケン', '平戸市', 'ヒラドシ', '古江町', 'フルエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県平戸市木引町', '42', '42207', '8595151', '長崎県', 'ナガサキケン', '平戸市', 'ヒラドシ', '木引町', 'コヒキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県平戸市鏡川町', '42', '42207', '8595152', '長崎県', 'ナガサキケン', '平戸市', 'ヒラドシ', '鏡川町', 'カガミガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県平戸市戸石川町', '42', '42207', '8595153', '長崎県', 'ナガサキケン', '平戸市', 'ヒラドシ', '戸石川町', 'トイシガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県平戸市紐差町', '42', '42207', '8595361', '長崎県', 'ナガサキケン', '平戸市', 'ヒラドシ', '紐差町', 'ヒモサシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県平戸市木ケ津町', '42', '42207', '8595362', '長崎県', 'ナガサキケン', '平戸市', 'ヒラドシ', '木ケ津町', 'キガツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県平戸市草積町', '42', '42207', '8595363', '長崎県', 'ナガサキケン', '平戸市', 'ヒラドシ', '草積町', 'クサヅミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県平戸市迎紐差町', '42', '42207', '8595364', '長崎県', 'ナガサキケン', '平戸市', 'ヒラドシ', '迎紐差町', 'ムカエヒモサシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県平戸市木場町', '42', '42207', '8595365', '長崎県', 'ナガサキケン', '平戸市', 'ヒラドシ', '木場町', 'コバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県平戸市宝亀町', '42', '42207', '8595366', '長崎県', 'ナガサキケン', '平戸市', 'ヒラドシ', '宝亀町', 'ホウキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県平戸市獅子町', '42', '42207', '8595371', '長崎県', 'ナガサキケン', '平戸市', 'ヒラドシ', '獅子町', 'シシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県平戸市高越町', '42', '42207', '8595372', '長崎県', 'ナガサキケン', '平戸市', 'ヒラドシ', '高越町', 'タカゴエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県平戸市春日町', '42', '42207', '8595373', '長崎県', 'ナガサキケン', '平戸市', 'ヒラドシ', '春日町', 'カスガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県平戸市深川町', '42', '42207', '8595374', '長崎県', 'ナガサキケン', '平戸市', 'ヒラドシ', '深川町', 'フカガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県平戸市朶の原町', '42', '42207', '8595375', '長崎県', 'ナガサキケン', '平戸市', 'ヒラドシ', '朶の原町', 'ヘゴノハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県平戸市大石脇町', '42', '42207', '8595376', '長崎県', 'ナガサキケン', '平戸市', 'ヒラドシ', '大石脇町', 'オオイシワキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県平戸市根獅子町', '42', '42207', '8595381', '長崎県', 'ナガサキケン', '平戸市', 'ヒラドシ', '根獅子町', 'ネシコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県平戸市飯良町', '42', '42207', '8595382', '長崎県', 'ナガサキケン', '平戸市', 'ヒラドシ', '飯良町', 'イイラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県平戸市大川原町', '42', '42207', '8595383', '長崎県', 'ナガサキケン', '平戸市', 'ヒラドシ', '大川原町', 'オオカワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県平戸市赤松町', '42', '42207', '8595384', '長崎県', 'ナガサキケン', '平戸市', 'ヒラドシ', '赤松町', 'アカマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県平戸市堤町', '42', '42207', '8595501', '長崎県', 'ナガサキケン', '平戸市', 'ヒラドシ', '堤町', 'ツツミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県平戸市猪渡谷町', '42', '42207', '8595502', '長崎県', 'ナガサキケン', '平戸市', 'ヒラドシ', '猪渡谷町', 'イトヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県平戸市上中津良町', '42', '42207', '8595503', '長崎県', 'ナガサキケン', '平戸市', 'ヒラドシ', '上中津良町', 'カミナカツラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県平戸市下中津良町', '42', '42207', '8595504', '長崎県', 'ナガサキケン', '平戸市', 'ヒラドシ', '下中津良町', 'シモナカツラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県平戸市敷佐町', '42', '42207', '8595505', '長崎県', 'ナガサキケン', '平戸市', 'ヒラドシ', '敷佐町', 'シキサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県平戸市神船町', '42', '42207', '8595511', '長崎県', 'ナガサキケン', '平戸市', 'ヒラドシ', '神船町', 'シブネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県平戸市津吉町', '42', '42207', '8595512', '長崎県', 'ナガサキケン', '平戸市', 'ヒラドシ', '津吉町', 'ツヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県平戸市辻町', '42', '42207', '8595513', '長崎県', 'ナガサキケン', '平戸市', 'ヒラドシ', '辻町', 'ツジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県平戸市無代寺町', '42', '42207', '8595514', '長崎県', 'ナガサキケン', '平戸市', 'ヒラドシ', '無代寺町', 'ブダイジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県平戸市鮎川町', '42', '42207', '8595515', '長崎県', 'ナガサキケン', '平戸市', 'ヒラドシ', '鮎川町', 'アユカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県平戸市大佐志町', '42', '42207', '8595516', '長崎県', 'ナガサキケン', '平戸市', 'ヒラドシ', '大佐志町', 'オオサシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県平戸市船木町', '42', '42207', '8595521', '長崎県', 'ナガサキケン', '平戸市', 'ヒラドシ', '船木町', 'フナギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県平戸市神ノ川町', '42', '42207', '8595522', '長崎県', 'ナガサキケン', '平戸市', 'ヒラドシ', '神ノ川町', 'コウノカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県平戸市前津吉町', '42', '42207', '8595523', '長崎県', 'ナガサキケン', '平戸市', 'ヒラドシ', '前津吉町', 'マエツヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県平戸市神上町', '42', '42207', '8595524', '長崎県', 'ナガサキケン', '平戸市', 'ヒラドシ', '神上町', 'カミアゲチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県平戸市東中山町', '42', '42207', '8595525', '長崎県', 'ナガサキケン', '平戸市', 'ヒラドシ', '東中山町', 'ヒガシナカヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県平戸市西中山町', '42', '42207', '8595526', '長崎県', 'ナガサキケン', '平戸市', 'ヒラドシ', '西中山町', 'ニシナカヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県平戸市田代町', '42', '42207', '8595527', '長崎県', 'ナガサキケン', '平戸市', 'ヒラドシ', '田代町', 'タシロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県平戸市早福町', '42', '42207', '8595531', '長崎県', 'ナガサキケン', '平戸市', 'ヒラドシ', '早福町', 'ハイフクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県平戸市大志々伎町', '42', '42207', '8595532', '長崎県', 'ナガサキケン', '平戸市', 'ヒラドシ', '大志々伎町', 'オオシジキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県平戸市志々伎町', '42', '42207', '8595533', '長崎県', 'ナガサキケン', '平戸市', 'ヒラドシ', '志々伎町', 'シジキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県平戸市小田町', '42', '42207', '8595534', '長崎県', 'ナガサキケン', '平戸市', 'ヒラドシ', '小田町', 'オダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県平戸市野子町', '42', '42207', '8595535', '長崎県', 'ナガサキケン', '平戸市', 'ヒラドシ', '野子町', 'ノコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県平戸市生月町壱部', '42', '42207', '8595701', '長崎県', 'ナガサキケン', '平戸市', 'ヒラドシ', '生月町壱部', 'イキツキチョウイチブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県平戸市生月町壱部浦', '42', '42207', '8595702', '長崎県', 'ナガサキケン', '平戸市', 'ヒラドシ', '生月町壱部浦', 'イキツキチョウイチブウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県平戸市生月町里免', '42', '42207', '8595703', '長崎県', 'ナガサキケン', '平戸市', 'ヒラドシ', '生月町里免', 'イキツキチョウサトメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県平戸市生月町山田免', '42', '42207', '8595704', '長崎県', 'ナガサキケン', '平戸市', 'ヒラドシ', '生月町山田免', 'イキツキチョウヤマダメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県平戸市生月町舘浦', '42', '42207', '8595705', '長崎県', 'ナガサキケン', '平戸市', 'ヒラドシ', '生月町舘浦', 'イキツキチョウタチウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県平戸市生月町南免', '42', '42207', '8595706', '長崎県', 'ナガサキケン', '平戸市', 'ヒラドシ', '生月町南免', 'イキツキチョウミナミメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県平戸市生月町御崎', '42', '42207', '8595707', '長崎県', 'ナガサキケン', '平戸市', 'ヒラドシ', '生月町御崎', 'イキツキチョウミサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県平戸市大島村神浦', '42', '42207', '8595801', '長崎県', 'ナガサキケン', '平戸市', 'ヒラドシ', '大島村神浦', 'オオシマムラコウノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県平戸市大島村前平', '42', '42207', '8595802', '長崎県', 'ナガサキケン', '平戸市', 'ヒラドシ', '大島村前平', 'オオシマムラマエビラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県平戸市大島村西宇戸', '42', '42207', '8595803', '長崎県', 'ナガサキケン', '平戸市', 'ヒラドシ', '大島村西宇戸', 'オオシマムラニシウド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県平戸市大島村大根坂', '42', '42207', '8595804', '長崎県', 'ナガサキケン', '平戸市', 'ヒラドシ', '大島村大根坂', 'オオシマムラオオネザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県平戸市大島村的山川内', '42', '42207', '8595805', '長崎県', 'ナガサキケン', '平戸市', 'ヒラドシ', '大島村的山川内', 'オオシマムラアヅチカワチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県平戸市大島村的山戸田', '42', '42207', '8595806', '長崎県', 'ナガサキケン', '平戸市', 'ヒラドシ', '大島村的山戸田', 'オオシマムラアヅチトダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県北松浦郡江迎町', '42', '42388', '8596100', '長崎県', 'ナガサキケン', '北松浦郡江迎町', 'キタマツウラグンエムカエチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('110441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県北松浦郡江迎町長坂免', '42', '42388', '8596101', '長崎県', 'ナガサキケン', '北松浦郡江迎町', 'キタマツウラグンエムカエチョウ', '長坂免', 'ナガサカメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県北松浦郡江迎町上川内免', '42', '42388', '8596102', '長崎県', 'ナガサキケン', '北松浦郡江迎町', 'キタマツウラグンエムカエチョウ', '上川内免', 'カミガワチメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県北松浦郡江迎町埋立免', '42', '42388', '8596103', '長崎県', 'ナガサキケン', '北松浦郡江迎町', 'キタマツウラグンエムカエチョウ', '埋立免', 'ウメタテメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県北松浦郡江迎町末橘免', '42', '42388', '8596104', '長崎県', 'ナガサキケン', '北松浦郡江迎町', 'キタマツウラグンエムカエチョウ', '末橘免', 'スエタチバナメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県北松浦郡江迎町梶ノ村免', '42', '42388', '8596105', '長崎県', 'ナガサキケン', '北松浦郡江迎町', 'キタマツウラグンエムカエチョウ', '梶ノ村免', 'カジノムラメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県北松浦郡江迎町北田免', '42', '42388', '8596106', '長崎県', 'ナガサキケン', '北松浦郡江迎町', 'キタマツウラグンエムカエチョウ', '北田免', 'キタダメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県北松浦郡江迎町飯良坂免', '42', '42388', '8596111', '長崎県', 'ナガサキケン', '北松浦郡江迎町', 'キタマツウラグンエムカエチョウ', '飯良坂免', 'イイラザカメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県北松浦郡江迎町根引免', '42', '42388', '8596112', '長崎県', 'ナガサキケン', '北松浦郡江迎町', 'キタマツウラグンエムカエチョウ', '根引免', 'ネビキメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県北松浦郡江迎町栗越免', '42', '42388', '8596113', '長崎県', 'ナガサキケン', '北松浦郡江迎町', 'キタマツウラグンエムカエチョウ', '栗越免', 'クリコシメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県北松浦郡江迎町箙尾免', '42', '42388', '8596114', '長崎県', 'ナガサキケン', '北松浦郡江迎町', 'キタマツウラグンエムカエチョウ', '箙尾免', 'エビラオメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県北松浦郡江迎町中尾免', '42', '42388', '8596115', '長崎県', 'ナガサキケン', '北松浦郡江迎町', 'キタマツウラグンエムカエチョウ', '中尾免', 'ナカオメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県北松浦郡江迎町奥川内免', '42', '42388', '8596121', '長崎県', 'ナガサキケン', '北松浦郡江迎町', 'キタマツウラグンエムカエチョウ', '奥川内免', 'オクガワチメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県北松浦郡江迎町七腕免', '42', '42388', '8596122', '長崎県', 'ナガサキケン', '北松浦郡江迎町', 'キタマツウラグンエムカエチョウ', '七腕免', 'ナナカイメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県北松浦郡江迎町小川内免', '42', '42388', '8596123', '長崎県', 'ナガサキケン', '北松浦郡江迎町', 'キタマツウラグンエムカエチョウ', '小川内免', 'コガワチメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県北松浦郡江迎町乱橋免', '42', '42388', '8596124', '長崎県', 'ナガサキケン', '北松浦郡江迎町', 'キタマツウラグンエムカエチョウ', '乱橋免', 'ミダレバシメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県北松浦郡江迎町三浦免', '42', '42388', '8596125', '長崎県', 'ナガサキケン', '北松浦郡江迎町', 'キタマツウラグンエムカエチョウ', '三浦免', 'ミウラメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県北松浦郡江迎町北平免', '42', '42388', '8596126', '長崎県', 'ナガサキケン', '北松浦郡江迎町', 'キタマツウラグンエムカエチョウ', '北平免', 'キタヒラメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県北松浦郡江迎町赤坂免', '42', '42388', '8596131', '長崎県', 'ナガサキケン', '北松浦郡江迎町', 'キタマツウラグンエムカエチョウ', '赤坂免', 'アカサカメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県北松浦郡江迎町志戸氏免', '42', '42388', '8596132', '長崎県', 'ナガサキケン', '北松浦郡江迎町', 'キタマツウラグンエムカエチョウ', '志戸氏免', 'シトノウジメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県北松浦郡江迎町猪調免', '42', '42388', '8596133', '長崎県', 'ナガサキケン', '北松浦郡江迎町', 'キタマツウラグンエムカエチョウ', '猪調免', 'イノツキメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県北松浦郡江迎町田ノ元免', '42', '42388', '8596134', '長崎県', 'ナガサキケン', '北松浦郡江迎町', 'キタマツウラグンエムカエチョウ', '田ノ元免', 'タノモトメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県北松浦郡鹿町町新深江免', '42', '42389', '8596141', '長崎県', 'ナガサキケン', '北松浦郡鹿町町', 'キタマツウラグンシカマチチョウ', '新深江免', 'シンフカエメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県北松浦郡鹿町町深江免', '42', '42389', '8596142', '長崎県', 'ナガサキケン', '北松浦郡鹿町町', 'キタマツウラグンシカマチチョウ', '深江免', 'フカエメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県北松浦郡鹿町町深江潟免', '42', '42389', '8596143', '長崎県', 'ナガサキケン', '北松浦郡鹿町町', 'キタマツウラグンシカマチチョウ', '深江潟免', 'フカエガタメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県北松浦郡鹿町町鹿町免', '42', '42389', '8596144', '長崎県', 'ナガサキケン', '北松浦郡鹿町町', 'キタマツウラグンシカマチチョウ', '鹿町免', 'シカマチメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県北松浦郡鹿町町土肥ノ浦免', '42', '42389', '8596145', '長崎県', 'ナガサキケン', '北松浦郡鹿町町', 'キタマツウラグンシカマチチョウ', '土肥ノ浦免', 'ドイノウラメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県北松浦郡鹿町町', '42', '42389', '8596200', '長崎県', 'ナガサキケン', '北松浦郡鹿町町', 'キタマツウラグンシカマチチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('110468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県北松浦郡鹿町町大屋免', '42', '42389', '8596201', '長崎県', 'ナガサキケン', '北松浦郡鹿町町', 'キタマツウラグンシカマチチョウ', '大屋免', 'オオヤメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県北松浦郡鹿町町上歌ケ浦免', '42', '42389', '8596202', '長崎県', 'ナガサキケン', '北松浦郡鹿町町', 'キタマツウラグンシカマチチョウ', '上歌ケ浦免', 'カミウタガウラメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県北松浦郡鹿町町口ノ里免', '42', '42389', '8596203', '長崎県', 'ナガサキケン', '北松浦郡鹿町町', 'キタマツウラグンシカマチチョウ', '口ノ里免', 'クチノサトメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県北松浦郡鹿町町下歌ケ浦免', '42', '42389', '8596204', '長崎県', 'ナガサキケン', '北松浦郡鹿町町', 'キタマツウラグンシカマチチョウ', '下歌ケ浦免', 'シモウタガウラメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県北松浦郡鹿町町中野免', '42', '42389', '8596205', '長崎県', 'ナガサキケン', '北松浦郡鹿町町', 'キタマツウラグンシカマチチョウ', '中野免', 'ナカノメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県北松浦郡鹿町町長串免', '42', '42389', '8596206', '長崎県', 'ナガサキケン', '北松浦郡鹿町町', 'キタマツウラグンシカマチチョウ', '長串免', 'ナグシメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県北松浦郡鹿町町船ノ村免', '42', '42389', '8596207', '長崎県', 'ナガサキケン', '北松浦郡鹿町町', 'キタマツウラグンシカマチチョウ', '船ノ村免', 'フネノムラメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市吉井町草ノ尾', '42', '42202', '8596301', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '吉井町草ノ尾', 'ヨシイチョウソウノオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市吉井町福井', '42', '42202', '8596302', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '吉井町福井', 'ヨシイチョウフクイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市吉井町板樋', '42', '42202', '8596303', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '吉井町板樋', 'ヨシイチョウイタビ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市吉井町梶木場', '42', '42202', '8596304', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '吉井町梶木場', 'ヨシイチョウカジコバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市吉井町直谷', '42', '42202', '8596305', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '吉井町直谷', 'ヨシイチョウナオヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市吉井町橋川内', '42', '42202', '8596311', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '吉井町橋川内', 'ヨシイチョウハシカワチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市吉井町橋口', '42', '42202', '8596312', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '吉井町橋口', 'ヨシイチョウハシグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市吉井町上吉田', '42', '42202', '8596313', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '吉井町上吉田', 'ヨシイチョウカミヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市吉井町田原', '42', '42202', '8596314', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '吉井町田原', 'ヨシイチョウタバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市吉井町下原', '42', '42202', '8596315', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '吉井町下原', 'ヨシイチョウシモバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市吉井町乙石尾', '42', '42202', '8596316', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '吉井町乙石尾', 'ヨシイチョウオツイシオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市吉井町高峰', '42', '42202', '8596317', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '吉井町高峰', 'ヨシイチョウタカミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市吉井町前岳', '42', '42202', '8596321', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '吉井町前岳', 'ヨシイチョウマエダケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市吉井町踊瀬', '42', '42202', '8596322', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '吉井町踊瀬', 'ヨシイチョウオドリゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市吉井町春明', '42', '42202', '8596323', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '吉井町春明', 'ヨシイチョウハルアケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市吉井町吉元', '42', '42202', '8596324', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '吉井町吉元', 'ヨシイチョウヨシモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市吉井町大渡', '42', '42202', '8596325', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '吉井町大渡', 'ヨシイチョウオオワタリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市吉井町立石', '42', '42202', '8596326', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '吉井町立石', 'ヨシイチョウタテイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市世知原町赤木場', '42', '42202', '8596401', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '世知原町赤木場', 'セチバルチョウアカコバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市世知原町岩谷口', '42', '42202', '8596402', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '世知原町岩谷口', 'セチバルチョウイワヤグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市世知原町上野原', '42', '42202', '8596403', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '世知原町上野原', 'セチバルチョウウエノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市世知原町太田', '42', '42202', '8596404', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '世知原町太田', 'セチバルチョウオオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市世知原町開作', '42', '42202', '8596405', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '世知原町開作', 'セチバルチョウカイサク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市世知原町木浦原', '42', '42202', '8596406', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '世知原町木浦原', 'セチバルチョウキウラバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市世知原町北川内', '42', '42202', '8596407', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '世知原町北川内', 'セチバルチョウキタガワチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市世知原町栗迎', '42', '42202', '8596408', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '世知原町栗迎', 'セチバルチョウクリムカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市世知原町中通', '42', '42202', '8596409', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '世知原町中通', 'セチバルチョウナカドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市世知原町長田代', '42', '42202', '8596411', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '世知原町長田代', 'セチバルチョウナガタシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市世知原町西ノ岳', '42', '42202', '8596412', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '世知原町西ノ岳', 'セチバルチョウニシノタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市世知原町笥瀬', '42', '42202', '8596413', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '世知原町笥瀬', 'セチバルチョウヤナゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市世知原町矢櫃', '42', '42202', '8596414', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '世知原町矢櫃', 'セチバルチョウヤビツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長崎県佐世保市世知原町槍巻', '42', '42202', '8596415', '長崎県', 'ナガサキケン', '佐世保市', 'サセボシ', '世知原町槍巻', 'セチバルチョウヤリマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市千葉城町', '43', '43201', '8600001', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '千葉城町', 'チバジョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市本丸', '43', '43201', '8600002', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '本丸', 'ホンマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市古城町', '43', '43201', '8600003', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '古城町', 'コジョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市新町', '43', '43201', '8600004', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市宮内', '43', '43201', '8600005', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '宮内', 'ミヤウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市段山本町', '43', '43201', '8600006', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '段山本町', 'ダニヤマホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市古京町', '43', '43201', '8600007', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '古京町', 'フルキョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市二の丸', '43', '43201', '8600008', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '二の丸', 'ニノマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市新鍛冶屋町', '43', '43201', '8600011', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '新鍛冶屋町', 'シンカジヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市紺屋今町', '43', '43201', '8600012', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '紺屋今町', 'コウヤイママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市通町', '43', '43201', '8600013', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '通町', 'トオリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市慶徳堀町', '43', '43201', '8600014', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '慶徳堀町', 'ケイトクボリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市古川町', '43', '43201', '8600015', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '古川町', 'フルカワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市山崎町', '43', '43201', '8600016', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '山崎町', 'ヤマサキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市練兵町', '43', '43201', '8600017', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '練兵町', 'レンペイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市船場町下', '43', '43201', '8600018', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '船場町下', 'センバマチシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市船場町', '43', '43201', '8600019', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '船場町', 'センバマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市上鍛冶屋町', '43', '43201', '8600021', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '上鍛冶屋町', 'カミカジヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市横紺屋町', '43', '43201', '8600022', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '横紺屋町', 'ヨココウヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市河原町', '43', '43201', '8600023', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '河原町', 'カワラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市松原町', '43', '43201', '8600024', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '松原町', 'マツバラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市紺屋町', '43', '43201', '8600025', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '紺屋町', 'コウヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市鍛冶屋町', '43', '43201', '8600026', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '鍛冶屋町', 'カジヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市西唐人町', '43', '43201', '8600027', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '西唐人町', 'ニシトウジンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市中唐人町', '43', '43201', '8600028', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '中唐人町', 'ナカトウジンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市米屋町', '43', '43201', '8600029', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '米屋町', 'コメヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市魚屋町', '43', '43201', '8600031', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '魚屋町', 'ウオヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市万町', '43', '43201', '8600032', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '万町', 'ヨロズマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市紺屋阿弥陀寺町', '43', '43201', '8600033', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '紺屋阿弥陀寺町', 'コウヤアミダジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市東阿弥陀寺町', '43', '43201', '8600034', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '東阿弥陀寺町', 'ヒガシアミダジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市呉服町', '43', '43201', '8600035', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '呉服町', 'ゴフクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市古大工町', '43', '43201', '8600036', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '古大工町', 'フルダイクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市西阿弥陀寺町', '43', '43201', '8600037', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '西阿弥陀寺町', 'ニシアミダジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市古桶屋町', '43', '43201', '8600038', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '古桶屋町', 'フルオケヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市川端町', '43', '43201', '8600039', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '川端町', 'カワバタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市細工町', '43', '43201', '8600041', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '細工町', 'サイクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市小沢町', '43', '43201', '8600042', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '小沢町', 'コザワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市板屋町', '43', '43201', '8600043', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '板屋町', 'イタヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市谷尾崎町', '43', '43201', '8600044', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '谷尾崎町', 'タニオザキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市戸坂町', '43', '43201', '8600045', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '戸坂町', 'トサカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市横手', '43', '43201', '8600046', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '横手', 'ヨコテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市春日', '43', '43201', '8600047', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '春日', 'カスガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市池上町', '43', '43201', '8600048', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '池上町', 'イケノウエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市二本木', '43', '43201', '8600051', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '二本木', 'ニホンギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市田崎本町', '43', '43201', '8600052', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '田崎本町', 'タサキホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市田崎', '43', '43201', '8600053', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '田崎', 'タサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市八島', '43', '43201', '8600054', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '八島', 'ヤシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市蓮台寺', '43', '43201', '8600055', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '蓮台寺', 'レンダイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市新土河原', '43', '43201', '8600056', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '新土河原', 'シントガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市八島町', '43', '43201', '8600057', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '八島町', 'ヤシママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市田崎町', '43', '43201', '8600058', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '田崎町', 'タサキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市野中', '43', '43201', '8600059', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '野中', 'ノナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市上高橋', '43', '43201', '8600061', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '上高橋', 'カミタカハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市高橋町', '43', '43201', '8600062', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '高橋町', 'タカハシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市城山上代町', '43', '43201', '8600063', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '城山上代町', 'ジョウザンカミダイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市城山半田', '43', '43201', '8600064', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '城山半田', 'ジョウザンハンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市城山薬師', '43', '43201', '8600065', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '城山薬師', 'ジョウザンヤクシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市城山下代', '43', '43201', '8600066', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '城山下代', 'ジョウザンシモダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市城山大塘', '43', '43201', '8600067', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '城山大塘', 'ジョウザンオオドモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市上代', '43', '43201', '8600068', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '上代', 'カミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市池亀町', '43', '43201', '8600071', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '池亀町', 'イケガメマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市花園', '43', '43201', '8600072', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '花園', 'ハナゾノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市島崎', '43', '43201', '8600073', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '島崎', 'シマサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市出町', '43', '43201', '8600074', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '出町', 'デマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市稗田町', '43', '43201', '8600075', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '稗田町', 'ヒエダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市壺川', '43', '43201', '8600076', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '壺川', 'コセン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市内坪井町', '43', '43201', '8600077', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '内坪井町', 'ウチツボイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市京町', '43', '43201', '8600078', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '京町', 'キョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市上熊本', '43', '43201', '8600079', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '上熊本', 'カミクマモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市京町本丁', '43', '43201', '8600081', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '京町本丁', 'キョウマチホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市池田', '43', '43201', '8600082', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '池田', 'イケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市大窪', '43', '43201', '8600083', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '大窪', 'オオクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市山室', '43', '43201', '8600084', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '山室', 'ヤマムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市高平', '43', '43201', '8600085', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '高平', 'タカヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市打越町', '43', '43201', '8600086', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '打越町', 'ウチゴシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市清水打越町', '43', '43201', '8600087', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '清水打越町', 'シミズウチゴシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市津浦町', '43', '43201', '8600088', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '津浦町', 'ツノウラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道根室市明郷', '01', '01223', '0860061', '北海道', 'ホッカイドウ', '根室市', 'ネムロシ', '明郷', 'アケサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道根室市湖南', '01', '01223', '0860062', '北海道', 'ホッカイドウ', '根室市', 'ネムロシ', '湖南', 'コナン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道根室市東厚床', '01', '01223', '0860063', '北海道', 'ホッカイドウ', '根室市', 'ネムロシ', '東厚床', 'ヒガシアットコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道根室市厚床', '01', '01223', '0860064', '北海道', 'ホッカイドウ', '根室市', 'ネムロシ', '厚床', 'アットコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道根室市西厚床', '01', '01223', '0860065', '北海道', 'ホッカイドウ', '根室市', 'ネムロシ', '西厚床', 'ニシアットコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道根室市槍昔', '01', '01223', '0860071', '北海道', 'ホッカイドウ', '根室市', 'ネムロシ', '槍昔', 'ヤリムカシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道根室市川口', '01', '01223', '0860072', '北海道', 'ホッカイドウ', '根室市', 'ネムロシ', '川口', 'カワグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道根室市酪陽', '01', '01223', '0860073', '北海道', 'ホッカイドウ', '根室市', 'ネムロシ', '酪陽', 'ラクヨウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道根室市東梅', '01', '01223', '0860074', '北海道', 'ホッカイドウ', '根室市', 'ネムロシ', '東梅', 'トウバイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道根室市別当賀', '01', '01223', '0860075', '北海道', 'ホッカイドウ', '根室市', 'ネムロシ', '別当賀', 'ベツトウガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道根室市初田牛', '01', '01223', '0860076', '北海道', 'ホッカイドウ', '根室市', 'ネムロシ', '初田牛', 'ハッタウシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市安政町', '43', '43201', '8600801', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '安政町', 'アンセイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市中央街', '43', '43201', '8600802', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '中央街', 'チュウオウガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市新市街', '43', '43201', '8600803', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '新市街', 'シンシガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市辛島町', '43', '43201', '8600804', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '辛島町', 'カラシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市桜町', '43', '43201', '8600805', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '桜町', 'サクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市花畑町', '43', '43201', '8600806', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '花畑町', 'ハナバタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市下通', '43', '43201', '8600807', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '下通', 'シモトオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市手取本町', '43', '43201', '8600808', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '手取本町', 'テトリホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡浜中町厚陽', '01', '01663', '0860081', '北海道', 'ホッカイドウ', '厚岸郡浜中町', 'アッケシグンハマナカチョウ', '厚陽', 'コウヨウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市本荘', '43', '43201', '8600811', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '本荘', 'ホンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市南熊本', '43', '43201', '8600812', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '南熊本', 'ミナミクマモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市琴平', '43', '43201', '8600813', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '琴平', 'コトヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市琴平本町', '43', '43201', '8600814', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '琴平本町', 'コトヒラホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市春竹町', '43', '43201', '8600815', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '春竹町', 'ハルタケマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市本荘町', '43', '43201', '8600816', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '本荘町', 'ホンジョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市迎町', '43', '43201', '8600817', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '迎町', 'ムカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市弥生町', '43', '43201', '8600818', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '弥生町', 'ヤヨイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市本山', '43', '43201', '8600821', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '本山', 'モトヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市本山町', '43', '43201', '8600822', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '本山町', 'モトヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市世安町', '43', '43201', '8600823', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '世安町', 'ヨヤスマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市十禅寺', '43', '43201', '8600824', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '十禅寺', 'ジュウゼンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市十禅寺町', '43', '43201', '8600825', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '十禅寺町', 'ジュウゼンジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市平田', '43', '43201', '8600826', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '平田', 'ヒラタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市平田町', '43', '43201', '8600827', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '平田町', 'ヒラタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市八王寺町', '43', '43201', '8600831', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '八王寺町', 'ハチオウジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市萩原町', '43', '43201', '8600832', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '萩原町', 'ハギワラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市平成', '43', '43201', '8600833', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '平成', 'ヘイセイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市江越', '43', '43201', '8600834', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '江越', 'エゴエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市井川淵町', '43', '43201', '8600841', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '井川淵町', 'イガワブチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市南千反畑町', '43', '43201', '8600842', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '南千反畑町', 'ミナミセンダンバタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市草葉町', '43', '43201', '8600843', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '草葉町', 'クサバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市水道町', '43', '43201', '8600844', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '水道町', 'スイドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市上通町', '43', '43201', '8600845', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '上通町', 'カミトオリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市城東町', '43', '43201', '8600846', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '城東町', 'ジョウトウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市上林町', '43', '43201', '8600847', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '上林町', 'カミバヤシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市南坪井町', '43', '43201', '8600848', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '南坪井町', 'ミナミツボイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市子飼本町', '43', '43201', '8600851', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '子飼本町', 'コカイホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市薬園町', '43', '43201', '8600852', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '薬園町', 'ヤクエンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市西子飼町', '43', '43201', '8600853', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '西子飼町', 'ニシコカイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市東子飼町', '43', '43201', '8600854', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '東子飼町', 'ヒガシコカイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市北千反畑町', '43', '43201', '8600855', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '北千反畑町', 'キタセンダンバタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市妙体寺町', '43', '43201', '8600856', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '妙体寺町', 'ミョウタイジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市黒髪町坪井', '43', '43201', '8600861', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '黒髪町坪井', 'クロカミマチツボイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市黒髪', '43', '43201', '8600862', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '黒髪', 'クロカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市坪井', '43', '43201', '8600863', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '坪井', 'ツボイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道野付郡別海町上風連', '01', '01691', '0860131', '北海道', 'ホッカイドウ', '野付郡別海町', 'ノツケグンベツカイチョウ', '上風連', 'カミフウレン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道野付郡別海町', '01', '01691', '0860200', '北海道', 'ホッカイドウ', '野付郡別海町', 'ノツケグンベツカイチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('110644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道野付郡別海町別海宮舞町', '01', '01691', '0860201', '北海道', 'ホッカイドウ', '野付郡別海町', 'ノツケグンベツカイチョウ', '別海宮舞町', 'ベツカイミヤマイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道野付郡別海町別海旭町', '01', '01691', '0860202', '北海道', 'ホッカイドウ', '野付郡別海町', 'ノツケグンベツカイチョウ', '別海旭町', 'ベツカイアサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道野付郡別海町別海西本町', '01', '01691', '0860203', '北海道', 'ホッカイドウ', '野付郡別海町', 'ノツケグンベツカイチョウ', '別海西本町', 'ベツカイニシホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道野付郡別海町別海新栄町', '01', '01691', '0860204', '北海道', 'ホッカイドウ', '野付郡別海町', 'ノツケグンベツカイチョウ', '別海新栄町', 'ベツカイシンエイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道野付郡別海町別海常盤町', '01', '01691', '0860205', '北海道', 'ホッカイドウ', '野付郡別海町', 'ノツケグンベツカイチョウ', '別海常盤町', 'ベツカイトキワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道野付郡別海町別海寿町', '01', '01691', '0860211', '北海道', 'ホッカイドウ', '野付郡別海町', 'ノツケグンベツカイチョウ', '別海寿町', 'ベツカイコトブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道野付郡別海町別海鶴舞町', '01', '01691', '0860212', '北海道', 'ホッカイドウ', '野付郡別海町', 'ノツケグンベツカイチョウ', '別海鶴舞町', 'ベツカイツルマイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道野付郡別海町奥行', '01', '01691', '0860213', '北海道', 'ホッカイドウ', '野付郡別海町', 'ノツケグンベツカイチョウ', '奥行', 'オクユキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道野付郡別海町別海緑町', '01', '01691', '0860214', '北海道', 'ホッカイドウ', '野付郡別海町', 'ノツケグンベツカイチョウ', '別海緑町', 'ベツカイミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道野付郡別海町別海川上町', '01', '01691', '0860215', '北海道', 'ホッカイドウ', '野付郡別海町', 'ノツケグンベツカイチョウ', '別海川上町', 'ベツカイカワカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道野付郡別海町別海', '01', '01691', '0860216', '北海道', 'ホッカイドウ', '野付郡別海町', 'ノツケグンベツカイチョウ', '別海', 'ベツカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道野付郡別海町中西別緑町', '01', '01691', '0860341', '北海道', 'ホッカイドウ', '野付郡別海町', 'ノツケグンベツカイチョウ', '中西別緑町', 'ナカニシベツミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道野付郡別海町中西別朝日町', '01', '01691', '0860342', '北海道', 'ホッカイドウ', '野付郡別海町', 'ノツケグンベツカイチョウ', '中西別朝日町', 'ナカニシベツアサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道野付郡別海町中西別光町', '01', '01691', '0860343', '北海道', 'ホッカイドウ', '野付郡別海町', 'ノツケグンベツカイチョウ', '中西別光町', 'ナカニシベツヒカリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道野付郡別海町中西別本町', '01', '01691', '0860344', '北海道', 'ホッカイドウ', '野付郡別海町', 'ノツケグンベツカイチョウ', '中西別本町', 'ナカニシベツホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道野付郡別海町中西別', '01', '01691', '0860345', '北海道', 'ホッカイドウ', '野付郡別海町', 'ノツケグンベツカイチョウ', '中西別', 'ナカニシベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道野付郡別海町矢臼別', '01', '01691', '0860346', '北海道', 'ホッカイドウ', '野付郡別海町', 'ノツケグンベツカイチョウ', '矢臼別', 'ヤウスベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道野付郡別海町床丹', '01', '01691', '0860521', '北海道', 'ホッカイドウ', '野付郡別海町', 'ノツケグンベツカイチョウ', '床丹', 'トコタン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道野付郡別海町本別海', '01', '01691', '0860522', '北海道', 'ホッカイドウ', '野付郡別海町', 'ノツケグンベツカイチョウ', '本別海', 'ホンベッカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道野付郡別海町走古丹', '01', '01691', '0860523', '北海道', 'ホッカイドウ', '野付郡別海町', 'ノツケグンベツカイチョウ', '走古丹', 'ハシリコタン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道野付郡別海町中春別東町', '01', '01691', '0860651', '北海道', 'ホッカイドウ', '野付郡別海町', 'ノツケグンベツカイチョウ', '中春別東町', 'ナカシュンベツヒガシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道野付郡別海町中春別南町', '01', '01691', '0860652', '北海道', 'ホッカイドウ', '野付郡別海町', 'ノツケグンベツカイチョウ', '中春別南町', 'ナカシュンベツミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道野付郡別海町中春別西町', '01', '01691', '0860653', '北海道', 'ホッカイドウ', '野付郡別海町', 'ノツケグンベツカイチョウ', '中春別西町', 'ナカシュンベツニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道野付郡別海町中春別', '01', '01691', '0860654', '北海道', 'ホッカイドウ', '野付郡別海町', 'ノツケグンベツカイチョウ', '中春別', 'ナカシュンベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道野付郡別海町床丹', '01', '01691', '0860655', '北海道', 'ホッカイドウ', '野付郡別海町', 'ノツケグンベツカイチョウ', '床丹', 'トコタン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道野付郡別海町美原', '01', '01691', '0860656', '北海道', 'ホッカイドウ', '野付郡別海町', 'ノツケグンベツカイチョウ', '美原', 'ミハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道野付郡別海町豊原', '01', '01691', '0860657', '北海道', 'ホッカイドウ', '野付郡別海町', 'ノツケグンベツカイチョウ', '豊原', 'トヨハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市', '43', '43201', '8610000', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('110752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町東1条南', '01', '01692', '0861001', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '東1条南', 'ヒガシ01ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町東2条南', '01', '01692', '0861002', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '東2条南', 'ヒガシ02ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町東3条南', '01', '01692', '0861003', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '東3条南', 'ヒガシ03ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町東4条南', '01', '01692', '0861004', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '東4条南', 'ヒガシ04ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町東5条南', '01', '01692', '0861005', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '東5条南', 'ヒガシ05ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町東6条南', '01', '01692', '0861006', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '東6条南', 'ヒガシ06ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町東7条南', '01', '01692', '0861007', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '東7条南', 'ヒガシ07ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町東8条南', '01', '01692', '0861008', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '東8条南', 'ヒガシ08ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町東9条南', '01', '01692', '0861009', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '東9条南', 'ヒガシ09ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町東10条南', '01', '01692', '0861010', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '東10条南', 'ヒガシ10ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県鹿本郡植木町', '43', '43385', '8610100', '熊本県', 'クマモトケン', '鹿本郡植木町', 'カモトグンウエキマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('110763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県鹿本郡植木町山本', '43', '43385', '8610101', '熊本県', 'クマモトケン', '鹿本郡植木町', 'カモトグンウエキマチ', '山本', 'ヤマモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県鹿本郡植木町内', '43', '43385', '8610102', '熊本県', 'クマモトケン', '鹿本郡植木町', 'カモトグンウエキマチ', '内', 'ウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県鹿本郡植木町清水', '43', '43385', '8610103', '熊本県', 'クマモトケン', '鹿本郡植木町', 'カモトグンウエキマチ', '清水', 'キヨミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県鹿本郡植木町今藤', '43', '43385', '8610104', '熊本県', 'クマモトケン', '鹿本郡植木町', 'カモトグンウエキマチ', '今藤', 'イマフジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県鹿本郡植木町味取', '43', '43385', '8610105', '熊本県', 'クマモトケン', '鹿本郡植木町', 'カモトグンウエキマチ', '味取', 'ミトリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県鹿本郡植木町豊田', '43', '43385', '8610106', '熊本県', 'クマモトケン', '鹿本郡植木町', 'カモトグンウエキマチ', '豊田', 'トヨダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町東11条南', '01', '01692', '0861011', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '東11条南', 'ヒガシ11ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県鹿本郡植木町宮原', '43', '43385', '8610111', '熊本県', 'クマモトケン', '鹿本郡植木町', 'カモトグンウエキマチ', '宮原', 'ミヤバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県鹿本郡植木町田底', '43', '43385', '8610112', '熊本県', 'クマモトケン', '鹿本郡植木町', 'カモトグンウエキマチ', '田底', 'タソコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県鹿本郡植木町伊知坊', '43', '43385', '8610113', '熊本県', 'クマモトケン', '鹿本郡植木町', 'カモトグンウエキマチ', '伊知坊', 'イチボウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県鹿本郡植木町舟島', '43', '43385', '8610114', '熊本県', 'クマモトケン', '鹿本郡植木町', 'カモトグンウエキマチ', '舟島', 'フナジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県鹿本郡植木町米塚', '43', '43385', '8610115', '熊本県', 'クマモトケン', '鹿本郡植木町', 'カモトグンウエキマチ', '米塚', 'ヨネツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県鹿本郡植木町色出', '43', '43385', '8610116', '熊本県', 'クマモトケン', '鹿本郡植木町', 'カモトグンウエキマチ', '色出', 'シキデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県鹿本郡植木町正清', '43', '43385', '8610117', '熊本県', 'クマモトケン', '鹿本郡植木町', 'カモトグンウエキマチ', '正清', 'ショウセイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町東12条南', '01', '01692', '0861012', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '東12条南', 'ヒガシ12ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県鹿本郡植木町平井', '43', '43385', '8610121', '熊本県', 'クマモトケン', '鹿本郡植木町', 'カモトグンウエキマチ', '平井', 'ヒライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県鹿本郡植木町古閑', '43', '43385', '8610122', '熊本県', 'クマモトケン', '鹿本郡植木町', 'カモトグンウエキマチ', '古閑', 'コガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県鹿本郡植木町有泉', '43', '43385', '8610123', '熊本県', 'クマモトケン', '鹿本郡植木町', 'カモトグンウエキマチ', '有泉', 'アリイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県鹿本郡植木町石川', '43', '43385', '8610124', '熊本県', 'クマモトケン', '鹿本郡植木町', 'カモトグンウエキマチ', '石川', 'イシカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県鹿本郡植木町小野', '43', '43385', '8610125', '熊本県', 'クマモトケン', '鹿本郡植木町', 'カモトグンウエキマチ', '小野', 'オノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県鹿本郡植木町大井', '43', '43385', '8610126', '熊本県', 'クマモトケン', '鹿本郡植木町', 'カモトグンウエキマチ', '大井', 'オオイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県鹿本郡植木町亀甲', '43', '43385', '8610127', '熊本県', 'クマモトケン', '鹿本郡植木町', 'カモトグンウエキマチ', '亀甲', 'カメコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町東13条南', '01', '01692', '0861013', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '東13条南', 'ヒガシ13ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県鹿本郡植木町広住', '43', '43385', '8610131', '熊本県', 'クマモトケン', '鹿本郡植木町', 'カモトグンウエキマチ', '広住', 'ヒロズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県鹿本郡植木町植木', '43', '43385', '8610132', '熊本県', 'クマモトケン', '鹿本郡植木町', 'カモトグンウエキマチ', '植木', 'ウエキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県鹿本郡植木町滴水', '43', '43385', '8610133', '熊本県', 'クマモトケン', '鹿本郡植木町', 'カモトグンウエキマチ', '滴水', 'タルミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県鹿本郡植木町舞尾', '43', '43385', '8610134', '熊本県', 'クマモトケン', '鹿本郡植木町', 'カモトグンウエキマチ', '舞尾', 'モウノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県鹿本郡植木町一木', '43', '43385', '8610135', '熊本県', 'クマモトケン', '鹿本郡植木町', 'カモトグンウエキマチ', '一木', 'ヒトツギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県鹿本郡植木町岩野', '43', '43385', '8610136', '熊本県', 'クマモトケン', '鹿本郡植木町', 'カモトグンウエキマチ', '岩野', 'イワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町東14条南', '01', '01692', '0861014', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '東14条南', 'ヒガシ14ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県鹿本郡植木町投刀塚', '43', '43385', '8610141', '熊本県', 'クマモトケン', '鹿本郡植木町', 'カモトグンウエキマチ', '投刀塚', 'ナタツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県鹿本郡植木町鐙田', '43', '43385', '8610142', '熊本県', 'クマモトケン', '鹿本郡植木町', 'カモトグンウエキマチ', '鐙田', 'アブミダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県鹿本郡植木町大和', '43', '43385', '8610143', '熊本県', 'クマモトケン', '鹿本郡植木町', 'カモトグンウエキマチ', '大和', 'ダイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県鹿本郡植木町平野', '43', '43385', '8610144', '熊本県', 'クマモトケン', '鹿本郡植木町', 'カモトグンウエキマチ', '平野', 'ヒラノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県鹿本郡植木町荻迫', '43', '43385', '8610145', '熊本県', 'クマモトケン', '鹿本郡植木町', 'カモトグンウエキマチ', '荻迫', 'オギサコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県鹿本郡植木町辺田野', '43', '43385', '8610146', '熊本県', 'クマモトケン', '鹿本郡植木町', 'カモトグンウエキマチ', '辺田野', 'ヘタノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町東15条南', '01', '01692', '0861015', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '東15条南', 'ヒガシ15ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県鹿本郡植木町木留', '43', '43385', '8610151', '熊本県', 'クマモトケン', '鹿本郡植木町', 'カモトグンウエキマチ', '木留', 'キトメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県鹿本郡植木町上古閑', '43', '43385', '8610152', '熊本県', 'クマモトケン', '鹿本郡植木町', 'カモトグンウエキマチ', '上古閑', 'ウエコガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県鹿本郡植木町円台寺', '43', '43385', '8610153', '熊本県', 'クマモトケン', '鹿本郡植木町', 'カモトグンウエキマチ', '円台寺', 'エンダイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県鹿本郡植木町那知', '43', '43385', '8610154', '熊本県', 'クマモトケン', '鹿本郡植木町', 'カモトグンウエキマチ', '那知', 'ナチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県鹿本郡植木町轟', '43', '43385', '8610155', '熊本県', 'クマモトケン', '鹿本郡植木町', 'カモトグンウエキマチ', '轟', 'トドロキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県鹿本郡植木町後古閑', '43', '43385', '8610156', '熊本県', 'クマモトケン', '鹿本郡植木町', 'カモトグンウエキマチ', '後古閑', 'ウシロコガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町東16条南', '01', '01692', '0861016', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '東16条南', 'ヒガシ16ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県鹿本郡植木町鞍掛', '43', '43385', '8610161', '熊本県', 'クマモトケン', '鹿本郡植木町', 'カモトグンウエキマチ', '鞍掛', 'クラカケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県鹿本郡植木町富応', '43', '43385', '8610162', '熊本県', 'クマモトケン', '鹿本郡植木町', 'カモトグンウエキマチ', '富応', 'トミオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県鹿本郡植木町豊岡', '43', '43385', '8610163', '熊本県', 'クマモトケン', '鹿本郡植木町', 'カモトグンウエキマチ', '豊岡', 'トヨオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県鹿本郡植木町鈴麦', '43', '43385', '8610164', '熊本県', 'クマモトケン', '鹿本郡植木町', 'カモトグンウエキマチ', '鈴麦', 'スズムギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県鹿本郡植木町平原', '43', '43385', '8610165', '熊本県', 'クマモトケン', '鹿本郡植木町', 'カモトグンウエキマチ', '平原', 'ヒラバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町東17条南', '01', '01692', '0861017', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '東17条南', 'ヒガシ17ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町東18条南', '01', '01692', '0861018', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '東18条南', 'ヒガシ18ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町東19条南', '01', '01692', '0861019', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '東19条南', 'ヒガシ19ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町東20条南', '01', '01692', '0861020', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '東20条南', 'ヒガシ20ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町東21条南', '01', '01692', '0861021', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '東21条南', 'ヒガシ21ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町東22条南', '01', '01692', '0861022', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '東22条南', 'ヒガシ22ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町東23条南', '01', '01692', '0861023', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '東23条南', 'ヒガシ23ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町東24条南', '01', '01692', '0861024', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '東24条南', 'ヒガシ24ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町東25条南', '01', '01692', '0861025', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '東25条南', 'ヒガシ25ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町東26条南', '01', '01692', '0861026', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '東26条南', 'ヒガシ26ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町東27条南', '01', '01692', '0861027', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '東27条南', 'ヒガシ27ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町東28条南', '01', '01692', '0861028', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '東28条南', 'ヒガシ28ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町東29条南', '01', '01692', '0861029', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '東29条南', 'ヒガシ29ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町東30条南', '01', '01692', '0861030', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '東30条南', 'ヒガシ30ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県山鹿市鹿本町庄', '43', '43208', '8610301', '熊本県', 'クマモトケン', '山鹿市', 'ヤマガシ', '鹿本町庄', 'カモトマチショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県山鹿市鹿本町津袋', '43', '43208', '8610302', '熊本県', 'クマモトケン', '山鹿市', 'ヤマガシ', '鹿本町津袋', 'カモトマチツブクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県山鹿市鹿本町高橋', '43', '43208', '8610303', '熊本県', 'クマモトケン', '山鹿市', 'ヤマガシ', '鹿本町高橋', 'カモトマチタカハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県山鹿市鹿本町御宇田', '43', '43208', '8610304', '熊本県', 'クマモトケン', '山鹿市', 'ヤマガシ', '鹿本町御宇田', 'カモトマチミウタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町東31条南', '01', '01692', '0861031', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '東31条南', 'ヒガシ31ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県山鹿市鹿本町石渕', '43', '43208', '8610311', '熊本県', 'クマモトケン', '山鹿市', 'ヤマガシ', '鹿本町石渕', 'カモトマチイシブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県山鹿市鹿本町梶屋', '43', '43208', '8610312', '熊本県', 'クマモトケン', '山鹿市', 'ヤマガシ', '鹿本町梶屋', 'カモトマチカジヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県山鹿市鹿本町中富', '43', '43208', '8610313', '熊本県', 'クマモトケン', '山鹿市', 'ヤマガシ', '鹿本町中富', 'カモトマチナカドミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県山鹿市鹿本町中川', '43', '43208', '8610314', '熊本県', 'クマモトケン', '山鹿市', 'ヤマガシ', '鹿本町中川', 'カモトマチナカガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県山鹿市鹿本町小嶋', '43', '43208', '8610315', '熊本県', 'クマモトケン', '山鹿市', 'ヤマガシ', '鹿本町小嶋', 'カモトマチオシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県山鹿市鹿本町下高橋', '43', '43208', '8610316', '熊本県', 'クマモトケン', '山鹿市', 'ヤマガシ', '鹿本町下高橋', 'カモトマチシモタカハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町東32条南', '01', '01692', '0861032', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '東32条南', 'ヒガシ32ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県山鹿市鹿本町分田', '43', '43208', '8610321', '熊本県', 'クマモトケン', '山鹿市', 'ヤマガシ', '鹿本町分田', 'カモトマチブンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県山鹿市鹿本町中分田', '43', '43208', '8610322', '熊本県', 'クマモトケン', '山鹿市', 'ヤマガシ', '鹿本町中分田', 'カモトマチナカブンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県山鹿市鹿本町下分田', '43', '43208', '8610323', '熊本県', 'クマモトケン', '山鹿市', 'ヤマガシ', '鹿本町下分田', 'カモトマチシモブンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県山鹿市鹿本町小柳', '43', '43208', '8610324', '熊本県', 'クマモトケン', '山鹿市', 'ヤマガシ', '鹿本町小柳', 'カモトマチコヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町東33条南', '01', '01692', '0861033', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '東33条南', 'ヒガシ33ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県山鹿市鹿本町来民', '43', '43208', '8610331', '熊本県', 'クマモトケン', '山鹿市', 'ヤマガシ', '鹿本町来民', 'カモトマチクタミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町東34条南', '01', '01692', '0861034', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '東34条南', 'ヒガシ34ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町東35条南', '01', '01692', '0861035', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '東35条南', 'ヒガシ35ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町東36条南', '01', '01692', '0861036', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '東36条南', 'ヒガシ36ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町東37条南', '01', '01692', '0861037', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '東37条南', 'ヒガシ37ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町東38条南', '01', '01692', '0861038', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '東38条南', 'ヒガシ38ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県山鹿市藤井', '43', '43208', '8610381', '熊本県', 'クマモトケン', '山鹿市', 'ヤマガシ', '藤井', 'フジイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県山鹿市方保田', '43', '43208', '8610382', '熊本県', 'クマモトケン', '山鹿市', 'ヤマガシ', '方保田', 'カトウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町東39条南', '01', '01692', '0861039', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '東39条南', 'ヒガシ39ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県山鹿市菊鹿町長', '43', '43208', '8610401', '熊本県', 'クマモトケン', '山鹿市', 'ヤマガシ', '菊鹿町長', 'キクカマチナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県山鹿市菊鹿町太田', '43', '43208', '8610402', '熊本県', 'クマモトケン', '山鹿市', 'ヤマガシ', '菊鹿町太田', 'キクカマチオオダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県山鹿市菊鹿町五郎丸', '43', '43208', '8610403', '熊本県', 'クマモトケン', '山鹿市', 'ヤマガシ', '菊鹿町五郎丸', 'キクカマチゴロウマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県山鹿市菊鹿町上永野', '43', '43208', '8610404', '熊本県', 'クマモトケン', '山鹿市', 'ヤマガシ', '菊鹿町上永野', 'キクカマチカミナガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県山鹿市菊鹿町下永野', '43', '43208', '8610405', '熊本県', 'クマモトケン', '山鹿市', 'ヤマガシ', '菊鹿町下永野', 'キクカマチシモナガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県山鹿市菊鹿町下内田', '43', '43208', '8610406', '熊本県', 'クマモトケン', '山鹿市', 'ヤマガシ', '菊鹿町下内田', 'キクカマチシモウチダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町東1条北', '01', '01692', '0861041', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '東1条北', 'ヒガシ01ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県山鹿市菊鹿町山内', '43', '43208', '8610411', '熊本県', 'クマモトケン', '山鹿市', 'ヤマガシ', '菊鹿町山内', 'キクカマチヤマウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県山鹿市菊鹿町相良', '43', '43208', '8610412', '熊本県', 'クマモトケン', '山鹿市', 'ヤマガシ', '菊鹿町相良', 'キクカマチアイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県山鹿市菊鹿町矢谷', '43', '43208', '8610413', '熊本県', 'クマモトケン', '山鹿市', 'ヤマガシ', '菊鹿町矢谷', 'キクカマチヤタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県山鹿市菊鹿町上内田', '43', '43208', '8610414', '熊本県', 'クマモトケン', '山鹿市', 'ヤマガシ', '菊鹿町上内田', 'キクカマチカミウチダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町東2条北', '01', '01692', '0861042', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '東2条北', 'ヒガシ02ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県山鹿市菊鹿町阿佐古', '43', '43208', '8610421', '熊本県', 'クマモトケン', '山鹿市', 'ヤマガシ', '菊鹿町阿佐古', 'キクカマチアサゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県山鹿市菊鹿町宮原', '43', '43208', '8610422', '熊本県', 'クマモトケン', '山鹿市', 'ヤマガシ', '菊鹿町宮原', 'キクカマチミヤノハル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県山鹿市菊鹿町池永', '43', '43208', '8610423', '熊本県', 'クマモトケン', '山鹿市', 'ヤマガシ', '菊鹿町池永', 'キクカマチイケナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県山鹿市菊鹿町松尾', '43', '43208', '8610424', '熊本県', 'クマモトケン', '山鹿市', 'ヤマガシ', '菊鹿町松尾', 'キクカマチマツオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県山鹿市菊鹿町米原', '43', '43208', '8610425', '熊本県', 'クマモトケン', '山鹿市', 'ヤマガシ', '菊鹿町米原', 'キクカマチヨナバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県山鹿市菊鹿町木野', '43', '43208', '8610426', '熊本県', 'クマモトケン', '山鹿市', 'ヤマガシ', '菊鹿町木野', 'キクカマチキノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町東3条北', '01', '01692', '0861043', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '東3条北', 'ヒガシ03ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町東4条北', '01', '01692', '0861044', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '東4条北', 'ヒガシ04ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町東5条北', '01', '01692', '0861045', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '東5条北', 'ヒガシ05ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町東6条北', '01', '01692', '0861046', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '東6条北', 'ヒガシ06ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町東7条北', '01', '01692', '0861047', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '東7条北', 'ヒガシ07ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町東8条北', '01', '01692', '0861048', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '東8条北', 'ヒガシ08ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町東9条北', '01', '01692', '0861049', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '東9条北', 'ヒガシ09ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町東10条北', '01', '01692', '0861050', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '東10条北', 'ヒガシ10ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県山鹿市', '43', '43208', '8610500', '熊本県', 'クマモトケン', '山鹿市', 'ヤマガシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('110882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県山鹿市山鹿', '43', '43208', '8610501', '熊本県', 'クマモトケン', '山鹿市', 'ヤマガシ', '山鹿', 'ヤマガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町東11条北', '01', '01692', '0861051', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '東11条北', 'ヒガシ11ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県山鹿市熊入町', '43', '43208', '8610511', '熊本県', 'クマモトケン', '山鹿市', 'ヤマガシ', '熊入町', 'クマイリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県山鹿市泉町', '43', '43208', '8610512', '熊本県', 'クマモトケン', '山鹿市', 'ヤマガシ', '泉町', 'イズミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県山鹿市宗方', '43', '43208', '8610513', '熊本県', 'クマモトケン', '山鹿市', 'ヤマガシ', '宗方', 'ムナカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県山鹿市新町', '43', '43208', '8610514', '熊本県', 'クマモトケン', '山鹿市', 'ヤマガシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県山鹿市昭和町', '43', '43208', '8610515', '熊本県', 'クマモトケン', '山鹿市', 'ヤマガシ', '昭和町', 'ショウワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県山鹿市中央通', '43', '43208', '8610516', '熊本県', 'クマモトケン', '山鹿市', 'ヤマガシ', '中央通', 'チュウオウドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県山鹿市大橋通', '43', '43208', '8610517', '熊本県', 'クマモトケン', '山鹿市', 'ヤマガシ', '大橋通', 'オオハシドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県山鹿市宗方通', '43', '43208', '8610518', '熊本県', 'クマモトケン', '山鹿市', 'ヤマガシ', '宗方通', 'ムナカタドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県山鹿市川端町', '43', '43208', '8610519', '熊本県', 'クマモトケン', '山鹿市', 'ヤマガシ', '川端町', 'カワバタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町東12条北', '01', '01692', '0861052', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '東12条北', 'ヒガシ12ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県山鹿市小坂', '43', '43208', '8610521', '熊本県', 'クマモトケン', '山鹿市', 'ヤマガシ', '小坂', 'オサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県山鹿市久原', '43', '43208', '8610522', '熊本県', 'クマモトケン', '山鹿市', 'ヤマガシ', '久原', 'クバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県山鹿市蒲生', '43', '43208', '8610523', '熊本県', 'クマモトケン', '山鹿市', 'ヤマガシ', '蒲生', 'カモウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県山鹿市上吉田', '43', '43208', '8610524', '熊本県', 'クマモトケン', '山鹿市', 'ヤマガシ', '上吉田', 'カミヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県山鹿市名塚', '43', '43208', '8610525', '熊本県', 'クマモトケン', '山鹿市', 'ヤマガシ', '名塚', 'ナヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県山鹿市下吉田', '43', '43208', '8610526', '熊本県', 'クマモトケン', '山鹿市', 'ヤマガシ', '下吉田', 'シモヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県山鹿市寺島', '43', '43208', '8610527', '熊本県', 'クマモトケン', '山鹿市', 'ヤマガシ', '寺島', 'テラジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町東13条北', '01', '01692', '0861053', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '東13条北', 'ヒガシ13ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県山鹿市中', '43', '43208', '8610531', '熊本県', 'クマモトケン', '山鹿市', 'ヤマガシ', '中', 'ナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県山鹿市鹿校通', '43', '43208', '8610532', '熊本県', 'クマモトケン', '山鹿市', 'ヤマガシ', '鹿校通', 'カコウトオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県山鹿市古閑', '43', '43208', '8610533', '熊本県', 'クマモトケン', '山鹿市', 'ヤマガシ', '古閑', 'コガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県山鹿市長坂', '43', '43208', '8610534', '熊本県', 'クマモトケン', '山鹿市', 'ヤマガシ', '長坂', 'ナガサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県山鹿市南島', '43', '43208', '8610535', '熊本県', 'クマモトケン', '山鹿市', 'ヤマガシ', '南島', 'ミナミジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町東14条北', '01', '01692', '0861054', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '東14条北', 'ヒガシ14ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県山鹿市鍋田', '43', '43208', '8610541', '熊本県', 'クマモトケン', '山鹿市', 'ヤマガシ', '鍋田', 'ナベタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県山鹿市志々岐', '43', '43208', '8610542', '熊本県', 'クマモトケン', '山鹿市', 'ヤマガシ', '志々岐', 'シジキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県山鹿市小原', '43', '43208', '8610543', '熊本県', 'クマモトケン', '山鹿市', 'ヤマガシ', '小原', 'オバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県山鹿市保多田', '43', '43208', '8610544', '熊本県', 'クマモトケン', '山鹿市', 'ヤマガシ', '保多田', 'ホダタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県山鹿市西牧', '43', '43208', '8610545', '熊本県', 'クマモトケン', '山鹿市', 'ヤマガシ', '西牧', 'ニシマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県山鹿市坂田', '43', '43208', '8610546', '熊本県', 'クマモトケン', '山鹿市', 'ヤマガシ', '坂田', 'サカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県山鹿市麻生野', '43', '43208', '8610547', '熊本県', 'クマモトケン', '山鹿市', 'ヤマガシ', '麻生野', 'アゾノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県山鹿市椿井', '43', '43208', '8610548', '熊本県', 'クマモトケン', '山鹿市', 'ヤマガシ', '椿井', 'ツバイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町東15条北', '01', '01692', '0861055', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '東15条北', 'ヒガシ15ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県山鹿市津留', '43', '43208', '8610551', '熊本県', 'クマモトケン', '山鹿市', 'ヤマガシ', '津留', 'ツル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県山鹿市杉', '43', '43208', '8610552', '熊本県', 'クマモトケン', '山鹿市', 'ヤマガシ', '杉', 'スギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県山鹿市石', '43', '43208', '8610553', '熊本県', 'クマモトケン', '山鹿市', 'ヤマガシ', '石', 'イシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県山鹿市城', '43', '43208', '8610554', '熊本県', 'クマモトケン', '山鹿市', 'ヤマガシ', '城', 'ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県山鹿市小群', '43', '43208', '8610555', '熊本県', 'クマモトケン', '山鹿市', 'ヤマガシ', '小群', 'オムレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県山鹿市平山', '43', '43208', '8610556', '熊本県', 'クマモトケン', '山鹿市', 'ヤマガシ', '平山', 'ヒラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町東16条北', '01', '01692', '0861056', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '東16条北', 'ヒガシ16ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県山鹿市鹿央町岩原', '43', '43208', '8610561', '熊本県', 'クマモトケン', '山鹿市', 'ヤマガシ', '鹿央町岩原', 'カオウマチイワバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県山鹿市鹿央町持松', '43', '43208', '8610562', '熊本県', 'クマモトケン', '山鹿市', 'ヤマガシ', '鹿央町持松', 'カオウマチモチマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県山鹿市鹿央町千田', '43', '43208', '8610563', '熊本県', 'クマモトケン', '山鹿市', 'ヤマガシ', '鹿央町千田', 'カオウマチチダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県山鹿市鹿央町広', '43', '43208', '8610564', '熊本県', 'クマモトケン', '山鹿市', 'ヤマガシ', '鹿央町広', 'カオウマチヒロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県山鹿市鹿央町合里', '43', '43208', '8610565', '熊本県', 'クマモトケン', '山鹿市', 'ヤマガシ', '鹿央町合里', 'カオウマチアイザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町東17条北', '01', '01692', '0861057', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '東17条北', 'ヒガシ17ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県山鹿市鹿央町北谷', '43', '43208', '8610571', '熊本県', 'クマモトケン', '山鹿市', 'ヤマガシ', '鹿央町北谷', 'カオウマチキタダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県山鹿市鹿央町仁王堂', '43', '43208', '8610572', '熊本県', 'クマモトケン', '山鹿市', 'ヤマガシ', '鹿央町仁王堂', 'カオウマチニオウドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県山鹿市鹿央町霜野', '43', '43208', '8610573', '熊本県', 'クマモトケン', '山鹿市', 'ヤマガシ', '鹿央町霜野', 'カオウマチシモノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県山鹿市鹿央町梅木谷', '43', '43208', '8610574', '熊本県', 'クマモトケン', '山鹿市', 'ヤマガシ', '鹿央町梅木谷', 'カオウマチウメノキダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県山鹿市鹿央町中浦', '43', '43208', '8610575', '熊本県', 'クマモトケン', '山鹿市', 'ヤマガシ', '鹿央町中浦', 'カオウマチチュウノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県山鹿市鹿央町大浦', '43', '43208', '8610576', '熊本県', 'クマモトケン', '山鹿市', 'ヤマガシ', '鹿央町大浦', 'カオウマチオオウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町東18条北', '01', '01692', '0861058', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '東18条北', 'ヒガシ18ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町東19条北', '01', '01692', '0861059', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '東19条北', 'ヒガシ19ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町東20条北', '01', '01692', '0861060', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '東20条北', 'ヒガシ20ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県山鹿市鹿北町四丁', '43', '43208', '8610601', '熊本県', 'クマモトケン', '山鹿市', 'ヤマガシ', '鹿北町四丁', 'カホクマチシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県山鹿市鹿北町芋生', '43', '43208', '8610602', '熊本県', 'クマモトケン', '山鹿市', 'ヤマガシ', '鹿北町芋生', 'カホクマチイモウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県山鹿市鹿北町岩野', '43', '43208', '8610603', '熊本県', 'クマモトケン', '山鹿市', 'ヤマガシ', '鹿北町岩野', 'カホクマチイワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県山鹿市鹿北町椎持', '43', '43208', '8610604', '熊本県', 'クマモトケン', '山鹿市', 'ヤマガシ', '鹿北町椎持', 'カホクマチシイモチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県山鹿市鹿北町多久', '43', '43208', '8610605', '熊本県', 'クマモトケン', '山鹿市', 'ヤマガシ', '鹿北町多久', 'カホクマチタク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町東21条北', '01', '01692', '0861061', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '東21条北', 'ヒガシ21ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町東22条北', '01', '01692', '0861062', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '東22条北', 'ヒガシ22ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町東23条北', '01', '01692', '0861063', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '東23条北', 'ヒガシ23ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町東24条北', '01', '01692', '0861064', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '東24条北', 'ヒガシ24ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町東25条北', '01', '01692', '0861065', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '東25条北', 'ヒガシ25ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町東26条北', '01', '01692', '0861066', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '東26条北', 'ヒガシ26ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町東27条北', '01', '01692', '0861067', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '東27条北', 'ヒガシ27ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町東28条北', '01', '01692', '0861068', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '東28条北', 'ヒガシ28ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町東29条北', '01', '01692', '0861069', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '東29条北', 'ヒガシ29ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町東30条北', '01', '01692', '0861070', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '東30条北', 'ヒガシ30ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町東31条北', '01', '01692', '0861071', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '東31条北', 'ヒガシ31ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町東32条北', '01', '01692', '0861072', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '東32条北', 'ヒガシ32ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町東33条北', '01', '01692', '0861073', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '東33条北', 'ヒガシ33ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町東34条北', '01', '01692', '0861074', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '東34条北', 'ヒガシ34ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町東35条北', '01', '01692', '0861075', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '東35条北', 'ヒガシ35ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町東36条北', '01', '01692', '0861076', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '東36条北', 'ヒガシ36ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町東37条北', '01', '01692', '0861077', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '東37条北', 'ヒガシ37ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町東38条北', '01', '01692', '0861078', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '東38条北', 'ヒガシ38ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町東39条北', '01', '01692', '0861079', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '東39条北', 'ヒガシ39ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町東40条北', '01', '01692', '0861080', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '東40条北', 'ヒガシ40ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名郡南関町', '43', '43367', '8610800', '熊本県', 'クマモトケン', '玉名郡南関町', 'タマナグンナンカンマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('110973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町東40条南', '01', '01692', '0861080', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '東40条南', 'ヒガシ40ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名郡南関町関外目', '43', '43367', '8610801', '熊本県', 'クマモトケン', '玉名郡南関町', 'タマナグンナンカンマチ', '関外目', 'セキホカメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名郡南関町関東', '43', '43367', '8610802', '熊本県', 'クマモトケン', '玉名郡南関町', 'タマナグンナンカンマチ', '関東', 'セキヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名郡南関町関町', '43', '43367', '8610803', '熊本県', 'クマモトケン', '玉名郡南関町', 'タマナグンナンカンマチ', '関町', 'セキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名郡南関町関村', '43', '43367', '8610804', '熊本県', 'クマモトケン', '玉名郡南関町', 'タマナグンナンカンマチ', '関村', 'セキムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名郡南関町関下', '43', '43367', '8610805', '熊本県', 'クマモトケン', '玉名郡南関町', 'タマナグンナンカンマチ', '関下', 'セキシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町東41条北', '01', '01692', '0861081', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '東41条北', 'ヒガシ41ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町東41条南', '01', '01692', '0861081', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '東41条南', 'ヒガシ41ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名郡南関町小原', '43', '43367', '8610811', '熊本県', 'クマモトケン', '玉名郡南関町', 'タマナグンナンカンマチ', '小原', 'コバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名郡南関町相谷', '43', '43367', '8610812', '熊本県', 'クマモトケン', '玉名郡南関町', 'タマナグンナンカンマチ', '相谷', 'アイノタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名郡南関町肥猪町', '43', '43367', '8610813', '熊本県', 'クマモトケン', '玉名郡南関町', 'タマナグンナンカンマチ', '肥猪町', 'コエイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名郡南関町肥猪', '43', '43367', '8610814', '熊本県', 'クマモトケン', '玉名郡南関町', 'タマナグンナンカンマチ', '肥猪', 'コエイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名郡南関町豊永', '43', '43367', '8610815', '熊本県', 'クマモトケン', '玉名郡南関町', 'タマナグンナンカンマチ', '豊永', 'トヨナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町東42条北', '01', '01692', '0861082', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '東42条北', 'ヒガシ42ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町東42条南', '01', '01692', '0861082', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '東42条南', 'ヒガシ42ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名郡南関町下坂下', '43', '43367', '8610821', '熊本県', 'クマモトケン', '玉名郡南関町', 'タマナグンナンカンマチ', '下坂下', 'シモサカシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名郡南関町上坂下', '43', '43367', '8610822', '熊本県', 'クマモトケン', '玉名郡南関町', 'タマナグンナンカンマチ', '上坂下', 'カミサカシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名郡南関町四ツ原', '43', '43367', '8610823', '熊本県', 'クマモトケン', '玉名郡南関町', 'タマナグンナンカンマチ', '四ツ原', 'ヨツハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町東中', '01', '01692', '0861083', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '東中', 'ヒガシナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名郡南関町細永', '43', '43367', '8610831', '熊本県', 'クマモトケン', '玉名郡南関町', 'タマナグンナンカンマチ', '細永', 'ホソナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名郡南関町今', '43', '43367', '8610832', '熊本県', 'クマモトケン', '玉名郡南関町', 'タマナグンナンカンマチ', '今', 'イマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名郡南関町高久野', '43', '43367', '8610833', '熊本県', 'クマモトケン', '玉名郡南関町', 'タマナグンナンカンマチ', '高久野', 'タカクノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名郡南関町宮尾', '43', '43367', '8610834', '熊本県', 'クマモトケン', '玉名郡南関町', 'タマナグンナンカンマチ', '宮尾', 'ミヤオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名郡南関町長山', '43', '43367', '8610835', '熊本県', 'クマモトケン', '玉名郡南関町', 'タマナグンナンカンマチ', '長山', 'ナガヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名郡南関町久重', '43', '43367', '8610836', '熊本県', 'クマモトケン', '玉名郡南関町', 'タマナグンナンカンマチ', '久重', 'クシゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('110998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名郡南関町上長田', '43', '43367', '8610837', '熊本県', 'クマモトケン', '玉名郡南関町', 'タマナグンナンカンマチ', '上長田', 'カミナガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名郡和水町上和仁', '43', '43369', '8610901', '熊本県', 'クマモトケン', '玉名郡和水町', 'タマナグンナゴミマチ', '上和仁', 'カミワニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名郡和水町中和仁', '43', '43369', '8610902', '熊本県', 'クマモトケン', '玉名郡和水町', 'タマナグンナゴミマチ', '中和仁', 'ナカワニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名郡和水町和仁', '43', '43369', '8610903', '熊本県', 'クマモトケン', '玉名郡和水町', 'タマナグンナゴミマチ', '和仁', 'ワニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名郡和水町東吉地', '43', '43369', '8610904', '熊本県', 'クマモトケン', '玉名郡和水町', 'タマナグンナゴミマチ', '東吉地', 'ヒガシヨシジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名郡和水町中林', '43', '43369', '8610905', '熊本県', 'クマモトケン', '玉名郡和水町', 'タマナグンナゴミマチ', '中林', 'ナカバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名郡和水町西吉地', '43', '43369', '8610906', '熊本県', 'クマモトケン', '玉名郡和水町', 'タマナグンナゴミマチ', '西吉地', 'ニシヨシジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名郡和水町上十町', '43', '43369', '8610911', '熊本県', 'クマモトケン', '玉名郡和水町', 'タマナグンナゴミマチ', '上十町', 'カミジッチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名郡和水町中十町', '43', '43369', '8610912', '熊本県', 'クマモトケン', '玉名郡和水町', 'タマナグンナゴミマチ', '中十町', 'ナカジッチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名郡和水町板楠', '43', '43369', '8610913', '熊本県', 'クマモトケン', '玉名郡和水町', 'タマナグンナゴミマチ', '板楠', 'イタクス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名郡和水町上板楠', '43', '43369', '8610914', '熊本県', 'クマモトケン', '玉名郡和水町', 'タマナグンナゴミマチ', '上板楠', 'カミイタクス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名郡和水町山十町', '43', '43369', '8610915', '熊本県', 'クマモトケン', '玉名郡和水町', 'タマナグンナゴミマチ', '山十町', 'ヤマジッチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名郡和水町津田', '43', '43369', '8610921', '熊本県', 'クマモトケン', '玉名郡和水町', 'タマナグンナゴミマチ', '津田', 'ツダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名郡和水町岩', '43', '43369', '8610922', '熊本県', 'クマモトケン', '玉名郡和水町', 'タマナグンナゴミマチ', '岩', 'イワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名郡和水町平野', '43', '43369', '8610923', '熊本県', 'クマモトケン', '玉名郡和水町', 'タマナグンナゴミマチ', '平野', 'ヒラノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名郡和水町大田黒', '43', '43369', '8610924', '熊本県', 'クマモトケン', '玉名郡和水町', 'タマナグンナゴミマチ', '大田黒', 'オオタグロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名郡和水町野田', '43', '43369', '8610925', '熊本県', 'クマモトケン', '玉名郡和水町', 'タマナグンナゴミマチ', '野田', 'ノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町', '01', '01692', '0861100', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('111019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町西1条南', '01', '01692', '0861101', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '西1条南', 'ニシ01ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町西2条南', '01', '01692', '0861102', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '西2条南', 'ニシ02ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町西3条南', '01', '01692', '0861103', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '西3条南', 'ニシ03ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町西4条南', '01', '01692', '0861104', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '西4条南', 'ニシ04ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町西5条南', '01', '01692', '0861105', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '西5条南', 'ニシ05ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町西6条南', '01', '01692', '0861106', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '西6条南', 'ニシ06ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町西7条南', '01', '01692', '0861107', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '西7条南', 'ニシ07ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町西8条南', '01', '01692', '0861108', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '西8条南', 'ニシ08ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町西9条南', '01', '01692', '0861109', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '西9条南', 'ニシ09ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町西10条南', '01', '01692', '0861110', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '西10条南', 'ニシ10ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県合志市', '43', '43216', '8611100', '熊本県', 'クマモトケン', '合志市', 'コウシシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('111030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県合志市合生', '43', '43216', '8611101', '熊本県', 'クマモトケン', '合志市', 'コウシシ', '合生', 'アイオイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県合志市須屋', '43', '43216', '8611102', '熊本県', 'クマモトケン', '合志市', 'コウシシ', '須屋', 'スヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県合志市野々島', '43', '43216', '8611103', '熊本県', 'クマモトケン', '合志市', 'コウシシ', '野々島', 'ノノシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県合志市御代志', '43', '43216', '8611104', '熊本県', 'クマモトケン', '合志市', 'コウシシ', '御代志', 'ミヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県合志市上生', '43', '43216', '8611105', '熊本県', 'クマモトケン', '合志市', 'コウシシ', '上生', 'ワブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町西11条南', '01', '01692', '0861111', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '西11条南', 'ニシ11ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県合志市上庄', '43', '43216', '8611111', '熊本県', 'クマモトケン', '合志市', 'コウシシ', '上庄', 'カミノショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県合志市幾久富', '43', '43216', '8611112', '熊本県', 'クマモトケン', '合志市', 'コウシシ', '幾久富', 'キクドミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県合志市栄', '43', '43216', '8611113', '熊本県', 'クマモトケン', '合志市', 'コウシシ', '栄', 'サカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県合志市竹迫', '43', '43216', '8611114', '熊本県', 'クマモトケン', '合志市', 'コウシシ', '竹迫', 'タカバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県合志市豊岡', '43', '43216', '8611115', '熊本県', 'クマモトケン', '合志市', 'コウシシ', '豊岡', 'トヨオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県合志市福原', '43', '43216', '8611116', '熊本県', 'クマモトケン', '合志市', 'コウシシ', '福原', 'フクハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町西12条南', '01', '01692', '0861112', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '西12条南', 'ニシ12ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池市泗水町吉富', '43', '43210', '8611201', '熊本県', 'クマモトケン', '菊池市', 'キクチシ', '泗水町吉富', 'シスイマチヨシトミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池市泗水町富納', '43', '43210', '8611202', '熊本県', 'クマモトケン', '菊池市', 'キクチシ', '泗水町富納', 'シスイマチトミノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池市泗水町住吉', '43', '43210', '8611203', '熊本県', 'クマモトケン', '菊池市', 'キクチシ', '泗水町住吉', 'シスイマチスミヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池市泗水町永', '43', '43210', '8611204', '熊本県', 'クマモトケン', '菊池市', 'キクチシ', '泗水町永', 'シスイマチナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池市泗水町福本', '43', '43210', '8611205', '熊本県', 'クマモトケン', '菊池市', 'キクチシ', '泗水町福本', 'シスイマチフクモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町西1条北', '01', '01692', '0861121', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '西1条北', 'ニシ01ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池市泗水町亀尾', '43', '43210', '8611211', '熊本県', 'クマモトケン', '菊池市', 'キクチシ', '泗水町亀尾', 'シスイマチカメオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池市泗水町豊水', '43', '43210', '8611212', '熊本県', 'クマモトケン', '菊池市', 'キクチシ', '泗水町豊水', 'シスイマチトヨミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池市泗水町南田島', '43', '43210', '8611213', '熊本県', 'クマモトケン', '菊池市', 'キクチシ', '泗水町南田島', 'シスイマチミナミタシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池市泗水町田島', '43', '43210', '8611214', '熊本県', 'クマモトケン', '菊池市', 'キクチシ', '泗水町田島', 'シスイマチタシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町西2条北', '01', '01692', '0861122', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '西2条北', 'ニシ02ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町西3条北', '01', '01692', '0861123', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '西3条北', 'ニシ03ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町西4条北', '01', '01692', '0861124', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '西4条北', 'ニシ04ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町西5条北', '01', '01692', '0861125', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '西5条北', 'ニシ05ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町西6条北', '01', '01692', '0861126', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '西6条北', 'ニシ06ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町西7条北', '01', '01692', '0861127', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '西7条北', 'ニシ07ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町西8条北', '01', '01692', '0861128', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '西8条北', 'ニシ08ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町西9条北', '01', '01692', '0861129', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '西9条北', 'ニシ09ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町西10条北', '01', '01692', '0861130', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '西10条北', 'ニシ10ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池市', '43', '43210', '8611300', '熊本県', 'クマモトケン', '菊池市', 'キクチシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('111069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池市木庭', '43', '43210', '8611301', '熊本県', 'クマモトケン', '菊池市', 'キクチシ', '木庭', 'コバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池市下河原', '43', '43210', '8611302', '熊本県', 'クマモトケン', '菊池市', 'キクチシ', '下河原', 'シモカワハル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池市今', '43', '43210', '8611303', '熊本県', 'クマモトケン', '菊池市', 'キクチシ', '今', 'イマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池市深川', '43', '43210', '8611304', '熊本県', 'クマモトケン', '菊池市', 'キクチシ', '深川', 'フカガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池市北宮', '43', '43210', '8611305', '熊本県', 'クマモトケン', '菊池市', 'キクチシ', '北宮', 'キタミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池市大琳寺', '43', '43210', '8611306', '熊本県', 'クマモトケン', '菊池市', 'キクチシ', '大琳寺', 'ダイリンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池市片角', '43', '43210', '8611307', '熊本県', 'クマモトケン', '菊池市', 'キクチシ', '片角', 'カタカク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池市亘', '43', '43210', '8611308', '熊本県', 'クマモトケン', '菊池市', 'キクチシ', '亘', 'ワタル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池市藤田', '43', '43210', '8611309', '熊本県', 'クマモトケン', '菊池市', 'キクチシ', '藤田', 'フジタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町西11条北', '01', '01692', '0861131', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '西11条北', 'ニシ11ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池市赤星', '43', '43210', '8611311', '熊本県', 'クマモトケン', '菊池市', 'キクチシ', '赤星', 'アカホシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池市森北', '43', '43210', '8611312', '熊本県', 'クマモトケン', '菊池市', 'キクチシ', '森北', 'モリキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池市出田', '43', '43210', '8611313', '熊本県', 'クマモトケン', '菊池市', 'キクチシ', '出田', 'イデタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池市広瀬', '43', '43210', '8611314', '熊本県', 'クマモトケン', '菊池市', 'キクチシ', '広瀬', 'ヒロセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池市木柑子', '43', '43210', '8611315', '熊本県', 'クマモトケン', '菊池市', 'キクチシ', '木柑子', 'キコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池市長田', '43', '43210', '8611316', '熊本県', 'クマモトケン', '菊池市', 'キクチシ', '長田', 'ナガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池市村田', '43', '43210', '8611317', '熊本県', 'クマモトケン', '菊池市', 'キクチシ', '村田', 'ムラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町西12条北', '01', '01692', '0861132', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '西12条北', 'ニシ12ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池市稗方', '43', '43210', '8611321', '熊本県', 'クマモトケン', '菊池市', 'キクチシ', '稗方', 'ヒエガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池市玉祥寺', '43', '43210', '8611322', '熊本県', 'クマモトケン', '菊池市', 'キクチシ', '玉祥寺', 'ギョクショウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池市西寺', '43', '43210', '8611323', '熊本県', 'クマモトケン', '菊池市', 'キクチシ', '西寺', 'ニシデラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池市野間口', '43', '43210', '8611324', '熊本県', 'クマモトケン', '菊池市', 'キクチシ', '野間口', 'ノマグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池市袈裟尾', '43', '43210', '8611325', '熊本県', 'クマモトケン', '菊池市', 'キクチシ', '袈裟尾', 'ケサオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池市木野', '43', '43210', '8611326', '熊本県', 'クマモトケン', '菊池市', 'キクチシ', '木野', 'キノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町西13条北', '01', '01692', '0861133', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '西13条北', 'ニシ13ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池市隈府', '43', '43210', '8611331', '熊本県', 'クマモトケン', '菊池市', 'キクチシ', '隈府', 'ワイフ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町西14条北', '01', '01692', '0861134', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '西14条北', 'ニシ14ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池市七城町清水', '43', '43210', '8611341', '熊本県', 'クマモトケン', '菊池市', 'キクチシ', '七城町清水', 'シチジョウマチキヨミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池市七城町亀尾', '43', '43210', '8611342', '熊本県', 'クマモトケン', '菊池市', 'キクチシ', '七城町亀尾', 'シチジョウマチカメオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池市七城町林原', '43', '43210', '8611343', '熊本県', 'クマモトケン', '菊池市', 'キクチシ', '七城町林原', 'シチジョウマチハヤシバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池市七城町蘇崎', '43', '43210', '8611344', '熊本県', 'クマモトケン', '菊池市', 'キクチシ', '七城町蘇崎', 'シチジョウマチソサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池市七城町小野崎', '43', '43210', '8611345', '熊本県', 'クマモトケン', '菊池市', 'キクチシ', '七城町小野崎', 'シチジョウマチオノザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池市七城町橋田', '43', '43210', '8611346', '熊本県', 'クマモトケン', '菊池市', 'キクチシ', '七城町橋田', 'シチジョウマチハシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町旭ケ丘', '01', '01692', '0861135', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '旭ケ丘', 'アサヒガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池市七城町砂田', '43', '43210', '8611351', '熊本県', 'クマモトケン', '菊池市', 'キクチシ', '七城町砂田', 'シチジョウマチスナダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池市七城町新古閑', '43', '43210', '8611352', '熊本県', 'クマモトケン', '菊池市', 'キクチシ', '七城町新古閑', 'シチジョウマチシンコガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池市七城町甲佐町', '43', '43210', '8611353', '熊本県', 'クマモトケン', '菊池市', 'キクチシ', '七城町甲佐町', 'シチジョウマチコウサマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池市七城町菰入', '43', '43210', '8611354', '熊本県', 'クマモトケン', '菊池市', 'キクチシ', '七城町菰入', 'シチジョウマチコモイリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池市七城町高島', '43', '43210', '8611355', '熊本県', 'クマモトケン', '菊池市', 'キクチシ', '七城町高島', 'シチジョウマチタカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池市七城町加恵', '43', '43210', '8611356', '熊本県', 'クマモトケン', '菊池市', 'キクチシ', '七城町加恵', 'シチジョウマチカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池市七城町高田', '43', '43210', '8611357', '熊本県', 'クマモトケン', '菊池市', 'キクチシ', '七城町高田', 'シチジョウマチタカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町協和', '01', '01692', '0861136', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '協和', 'キョウワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池市七城町水次', '43', '43210', '8611361', '熊本県', 'クマモトケン', '菊池市', 'キクチシ', '七城町水次', 'シチジョウマチミツギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池市七城町山崎', '43', '43210', '8611362', '熊本県', 'クマモトケン', '菊池市', 'キクチシ', '七城町山崎', 'シチジョウマチヤマサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池市七城町荒牧', '43', '43210', '8611363', '熊本県', 'クマモトケン', '菊池市', 'キクチシ', '七城町荒牧', 'シチジョウマチアラマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池市七城町辺田', '43', '43210', '8611364', '熊本県', 'クマモトケン', '菊池市', 'キクチシ', '七城町辺田', 'シチジョウマチヘタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池市七城町台', '43', '43210', '8611365', '熊本県', 'クマモトケン', '菊池市', 'キクチシ', '七城町台', 'シチジョウマチウテナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池市七城町瀬戸口', '43', '43210', '8611366', '熊本県', 'クマモトケン', '菊池市', 'キクチシ', '七城町瀬戸口', 'シチジョウマチセトグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池市七城町流川', '43', '43210', '8611367', '熊本県', 'クマモトケン', '菊池市', 'キクチシ', '七城町流川', 'シチジョウマチナガレカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池市七城町岡田', '43', '43210', '8611368', '熊本県', 'クマモトケン', '菊池市', 'キクチシ', '七城町岡田', 'シチジョウマチオカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町俵橋', '01', '01692', '0861137', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '俵橋', 'タワラバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町豊岡', '01', '01692', '0861139', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '豊岡', 'トヨオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町大通北', '01', '01692', '0861141', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '大通北', 'オオドオリキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町大通南', '01', '01692', '0861142', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '大通南', 'オオドオリミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町当幌本通', '01', '01692', '0861143', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '当幌本通', 'トウホロホンドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町東当幌', '01', '01692', '0861144', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '東当幌', 'ヒガシトウホロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池市原', '43', '43210', '8611441', '熊本県', 'クマモトケン', '菊池市', 'キクチシ', '原', 'ハル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池市四町分', '43', '43210', '8611442', '熊本県', 'クマモトケン', '菊池市', 'キクチシ', '四町分', 'シチョウブン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町北中', '01', '01692', '0861145', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '北中', 'キタナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町南町', '01', '01692', '0861146', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '南町', 'ミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町共立', '01', '01692', '0861147', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '共立', 'キョウリツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町緑ケ丘', '01', '01692', '0861148', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '緑ケ丘', 'ミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町南中', '01', '01692', '0861150', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '南中', 'ミナミナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町川西', '01', '01692', '0861151', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '川西', 'カワニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町北町', '01', '01692', '0861152', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '北町', 'キタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町桜ケ丘', '01', '01692', '0861153', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '桜ケ丘', 'サクラガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町並美ケ丘', '01', '01692', '0861156', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '並美ケ丘', 'ナラビガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町西町', '01', '01692', '0861157', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '西町', 'ニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町青葉台', '01', '01692', '0861159', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '青葉台', 'アオバダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町りんどう町', '01', '01692', '0861160', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', 'りんどう町', 'リンドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町俵中', '01', '01692', '0861163', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '俵中', 'ヒョウチュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町丸山', '01', '01692', '0861164', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '丸山', 'マルヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町緑町北', '01', '01692', '0861165', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '緑町北', 'ミドリマチキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町緑町南', '01', '01692', '0861166', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '緑町南', 'ミドリマチミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池市班蛇口', '43', '43210', '8611671', '熊本県', 'クマモトケン', '菊池市', 'キクチシ', '班蛇口', 'ハンジャク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池市龍門', '43', '43210', '8611672', '熊本県', 'クマモトケン', '菊池市', 'キクチシ', '龍門', 'リュウモン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池市小木', '43', '43210', '8611673', '熊本県', 'クマモトケン', '菊池市', 'キクチシ', '小木', 'オギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池市雪野', '43', '43210', '8611681', '熊本県', 'クマモトケン', '菊池市', 'キクチシ', '雪野', 'ユキノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池市重味', '43', '43210', '8611682', '熊本県', 'クマモトケン', '菊池市', 'キクチシ', '重味', 'シゲミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池市大平', '43', '43210', '8611683', '熊本県', 'クマモトケン', '菊池市', 'キクチシ', '大平', 'オオヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池市豊間', '43', '43210', '8611684', '熊本県', 'クマモトケン', '菊池市', 'キクチシ', '豊間', 'トヨマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池市西迫間', '43', '43210', '8611685', '熊本県', 'クマモトケン', '菊池市', 'キクチシ', '西迫間', 'ニシハザマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池市市野瀬', '43', '43210', '8611686', '熊本県', 'クマモトケン', '菊池市', 'キクチシ', '市野瀬', 'イチノセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市桜木', '43', '43201', '8612101', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '桜木', 'サクラギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市沼山津', '43', '43201', '8612102', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '沼山津', 'ヌヤマヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市若葉4丁目', '43', '43201', '8612103', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '若葉', 'ワカバ', null, null, '4丁目', '04チョウメ');
INSERT INTO `ms_addresses` VALUES ('111158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市若葉5丁目', '43', '43201', '8612103', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '若葉', 'ワカバ', null, null, '5丁目', '05チョウメ');
INSERT INTO `ms_addresses` VALUES ('111159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市若葉6丁目', '43', '43201', '8612103', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '若葉', 'ワカバ', null, null, '6丁目', '06チョウメ');
INSERT INTO `ms_addresses` VALUES ('111160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市秋津', '43', '43201', '8612104', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '秋津', 'アキツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市秋津町秋田', '43', '43201', '8612105', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '秋津町秋田', 'アキツマチアキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市東野', '43', '43201', '8612106', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '東野', 'ヒガシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市秋津新町', '43', '43201', '8612107', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '秋津新町', 'アキツシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市昭和町', '43', '43201', '8612108', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '昭和町', 'ショウワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市花立1丁目', '43', '43201', '8612118', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '花立', 'ハナタテ', null, null, '1丁目', '01チョウメ');
INSERT INTO `ms_addresses` VALUES ('111166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市花立2丁目', '43', '43201', '8612118', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '花立', 'ハナタテ', null, null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('111167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市花立3丁目', '43', '43201', '8612118', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '花立', 'ハナタテ', null, null, '3丁目', '03チョウメ');
INSERT INTO `ms_addresses` VALUES ('111168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市花立4丁目', '43', '43201', '8612118', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '花立', 'ハナタテ', null, null, '4丁目', '04チョウメ');
INSERT INTO `ms_addresses` VALUES ('111170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡益城町', '43', '43443', '8612200', '熊本県', 'クマモトケン', '上益城郡益城町', 'カミマシキグンマシキマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('111171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡益城町寺中', '43', '43443', '8612201', '熊本県', 'クマモトケン', '上益城郡益城町', 'カミマシキグンマシキマチ', '寺中', 'ジチュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡益城町田原', '43', '43443', '8612202', '熊本県', 'クマモトケン', '上益城郡益城町', 'カミマシキグンマシキマチ', '田原', 'タバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡益城町上陳', '43', '43443', '8612203', '熊本県', 'クマモトケン', '上益城郡益城町', 'カミマシキグンマシキマチ', '上陳', 'カミジン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡益城町小谷', '43', '43443', '8612204', '熊本県', 'クマモトケン', '上益城郡益城町', 'カミマシキグンマシキマチ', '小谷', 'オヤツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡益城町杉堂', '43', '43443', '8612205', '熊本県', 'クマモトケン', '上益城郡益城町', 'カミマシキグンマシキマチ', '杉堂', 'スギドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡益城町下陳', '43', '43443', '8612206', '熊本県', 'クマモトケン', '上益城郡益城町', 'カミマシキグンマシキマチ', '下陳', 'シモジン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡益城町福原', '43', '43443', '8612211', '熊本県', 'クマモトケン', '上益城郡益城町', 'カミマシキグンマシキマチ', '福原', 'フクハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡益城町平田', '43', '43443', '8612212', '熊本県', 'クマモトケン', '上益城郡益城町', 'カミマシキグンマシキマチ', '平田', 'ヒラタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡益城町赤井', '43', '43443', '8612221', '熊本県', 'クマモトケン', '上益城郡益城町', 'カミマシキグンマシキマチ', '赤井', 'アカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡益城町砥川', '43', '43443', '8612222', '熊本県', 'クマモトケン', '上益城郡益城町', 'カミマシキグンマシキマチ', '砥川', 'トガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡益城町小池', '43', '43443', '8612223', '熊本県', 'クマモトケン', '上益城郡益城町', 'カミマシキグンマシキマチ', '小池', 'オイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡益城町島田', '43', '43443', '8612224', '熊本県', 'クマモトケン', '上益城郡益城町', 'カミマシキグンマシキマチ', '島田', 'シマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡益城町安永', '43', '43443', '8612231', '熊本県', 'クマモトケン', '上益城郡益城町', 'カミマシキグンマシキマチ', '安永', 'ヤスナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡益城町馬水', '43', '43443', '8612232', '熊本県', 'クマモトケン', '上益城郡益城町', 'カミマシキグンマシキマチ', '馬水', 'マミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡益城町惣領', '43', '43443', '8612233', '熊本県', 'クマモトケン', '上益城郡益城町', 'カミマシキグンマシキマチ', '惣領', 'ソウリョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡益城町古閑', '43', '43443', '8612234', '熊本県', 'クマモトケン', '上益城郡益城町', 'カミマシキグンマシキマチ', '古閑', 'コガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡益城町福富', '43', '43443', '8612235', '熊本県', 'クマモトケン', '上益城郡益城町', 'カミマシキグンマシキマチ', '福富', 'フクドミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡益城町広崎', '43', '43443', '8612236', '熊本県', 'クマモトケン', '上益城郡益城町', 'カミマシキグンマシキマチ', '広崎', 'ヒロサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡益城町宮園', '43', '43443', '8612241', '熊本県', 'クマモトケン', '上益城郡益城町', 'カミマシキグンマシキマチ', '宮園', 'ミヤゾノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡益城町木山', '43', '43443', '8612242', '熊本県', 'クマモトケン', '上益城郡益城町', 'カミマシキグンマシキマチ', '木山', 'キヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡益城町辻の城', '43', '43443', '8612243', '熊本県', 'クマモトケン', '上益城郡益城町', 'カミマシキグンマシキマチ', '辻の城', 'ツジノシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡益城町寺迫', '43', '43443', '8612244', '熊本県', 'クマモトケン', '上益城郡益城町', 'カミマシキグンマシキマチ', '寺迫', 'テラサコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県阿蘇郡西原村', '43', '43432', '8612400', '熊本県', 'クマモトケン', '阿蘇郡西原村', 'アソグンニシハラムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('111199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県阿蘇郡西原村鳥子', '43', '43432', '8612401', '熊本県', 'クマモトケン', '阿蘇郡西原村', 'アソグンニシハラムラ', '鳥子', 'トリコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県阿蘇郡西原村小森', '43', '43432', '8612402', '熊本県', 'クマモトケン', '阿蘇郡西原村', 'アソグンニシハラムラ', '小森', 'コモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県阿蘇郡西原村布田', '43', '43432', '8612403', '熊本県', 'クマモトケン', '阿蘇郡西原村', 'アソグンニシハラムラ', '布田', 'フタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県阿蘇郡西原村河原', '43', '43432', '8612404', '熊本県', 'クマモトケン', '阿蘇郡西原村', 'アソグンニシハラムラ', '河原', 'カワハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県阿蘇郡西原村宮山', '43', '43432', '8612405', '熊本県', 'クマモトケン', '阿蘇郡西原村', 'アソグンニシハラムラ', '宮山', 'ミヤヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町武佐', '01', '01692', '0861271', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '武佐', 'ムサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町開陽', '01', '01692', '0861272', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '開陽', 'カイヨウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町俣落', '01', '01692', '0861273', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '俣落', 'マタオチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡嘉島町', '43', '43442', '8613100', '熊本県', 'クマモトケン', '上益城郡嘉島町', 'カミマシキグンカシママチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('111209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡嘉島町鯰', '43', '43442', '8613101', '熊本県', 'クマモトケン', '上益城郡嘉島町', 'カミマシキグンカシママチ', '鯰', 'ナマズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡嘉島町下六嘉', '43', '43442', '8613102', '熊本県', 'クマモトケン', '上益城郡嘉島町', 'カミマシキグンカシママチ', '下六嘉', 'シモロッカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡嘉島町井寺', '43', '43442', '8613103', '熊本県', 'クマモトケン', '上益城郡嘉島町', 'カミマシキグンカシママチ', '井寺', 'イテラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡嘉島町北甘木', '43', '43442', '8613104', '熊本県', 'クマモトケン', '上益城郡嘉島町', 'カミマシキグンカシママチ', '北甘木', 'キタアマギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡嘉島町上六嘉', '43', '43442', '8613105', '熊本県', 'クマモトケン', '上益城郡嘉島町', 'カミマシキグンカシママチ', '上六嘉', 'カミロッカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡嘉島町上島', '43', '43442', '8613106', '熊本県', 'クマモトケン', '上益城郡嘉島町', 'カミマシキグンカシママチ', '上島', 'ウエジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡嘉島町上仲間', '43', '43442', '8613107', '熊本県', 'クマモトケン', '上益城郡嘉島町', 'カミマシキグンカシママチ', '上仲間', 'カミナカマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡嘉島町下仲間', '43', '43442', '8613108', '熊本県', 'クマモトケン', '上益城郡嘉島町', 'カミマシキグンカシママチ', '下仲間', 'シモナカマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡嘉島町犬渕', '43', '43442', '8613109', '熊本県', 'クマモトケン', '上益城郡嘉島町', 'カミマシキグンカシママチ', '犬渕', 'イヌブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡御船町豊秋', '43', '43441', '8613131', '熊本県', 'クマモトケン', '上益城郡御船町', 'カミマシキグンミフネマチ', '豊秋', 'トヨアキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡御船町', '43', '43441', '8613200', '熊本県', 'クマモトケン', '上益城郡御船町', 'カミマシキグンミフネマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('111224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡御船町陣', '43', '43441', '8613201', '熊本県', 'クマモトケン', '上益城郡御船町', 'カミマシキグンミフネマチ', '陣', 'ジン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡御船町小坂', '43', '43441', '8613202', '熊本県', 'クマモトケン', '上益城郡御船町', 'カミマシキグンミフネマチ', '小坂', 'オザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡御船町高木', '43', '43441', '8613203', '熊本県', 'クマモトケン', '上益城郡御船町', 'カミマシキグンミフネマチ', '高木', 'タカキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡御船町木倉', '43', '43441', '8613204', '熊本県', 'クマモトケン', '上益城郡御船町', 'カミマシキグンミフネマチ', '木倉', 'キノクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡御船町滝川', '43', '43441', '8613205', '熊本県', 'クマモトケン', '上益城郡御船町', 'カミマシキグンミフネマチ', '滝川', 'タキガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡御船町辺田見', '43', '43441', '8613206', '熊本県', 'クマモトケン', '上益城郡御船町', 'カミマシキグンミフネマチ', '辺田見', 'ヘタミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡御船町御船', '43', '43441', '8613207', '熊本県', 'クマモトケン', '上益城郡御船町', 'カミマシキグンミフネマチ', '御船', 'ミフネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡御船町滝尾', '43', '43441', '8613208', '熊本県', 'クマモトケン', '上益城郡御船町', 'カミマシキグンミフネマチ', '滝尾', 'タキオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡御船町水越', '43', '43441', '8613211', '熊本県', 'クマモトケン', '上益城郡御船町', 'カミマシキグンミフネマチ', '水越', 'ミズコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡甲佐町早川', '43', '43444', '8613241', '熊本県', 'クマモトケン', '上益城郡甲佐町', 'カミマシキグンコウサマチ', '早川', 'ソウガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡甲佐町糸田', '43', '43444', '8613242', '熊本県', 'クマモトケン', '上益城郡甲佐町', 'カミマシキグンコウサマチ', '糸田', 'イトダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡甲佐町白旗', '43', '43444', '8613243', '熊本県', 'クマモトケン', '上益城郡甲佐町', 'カミマシキグンコウサマチ', '白旗', 'シラハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡甲佐町芝原', '43', '43444', '8613244', '熊本県', 'クマモトケン', '上益城郡甲佐町', 'カミマシキグンコウサマチ', '芝原', 'シバワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡甲佐町吉田', '43', '43444', '8613245', '熊本県', 'クマモトケン', '上益城郡甲佐町', 'カミマシキグンコウサマチ', '吉田', 'ヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡御船町七滝', '43', '43441', '8613321', '熊本県', 'クマモトケン', '上益城郡御船町', 'カミマシキグンミフネマチ', '七滝', 'ナナタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡御船町上野', '43', '43441', '8613322', '熊本県', 'クマモトケン', '上益城郡御船町', 'カミマシキグンミフネマチ', '上野', 'ウエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡御船町田代', '43', '43441', '8613323', '熊本県', 'クマモトケン', '上益城郡御船町', 'カミマシキグンミフネマチ', '田代', 'タシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡御船町七滝松ノ生', '43', '43441', '8613421', '熊本県', 'クマモトケン', '上益城郡御船町', 'カミマシキグンミフネマチ', '七滝', 'ナナタキ', null, null, '松ノ生', 'マツノハエ');
INSERT INTO `ms_addresses` VALUES ('111244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡山都町金内', '43', '43447', '8613451', '熊本県', 'クマモトケン', '上益城郡山都町', 'カミマシキグンヤマトチョウ', '金内', 'カネウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡山都町田小野', '43', '43447', '8613452', '熊本県', 'クマモトケン', '上益城郡山都町', 'カミマシキグンヤマトチョウ', '田小野', 'タオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡山都町原', '43', '43447', '8613453', '熊本県', 'クマモトケン', '上益城郡山都町', 'カミマシキグンヤマトチョウ', '原', 'ハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡山都町島木', '43', '43447', '8613454', '熊本県', 'クマモトケン', '上益城郡山都町', 'カミマシキグンヤマトチョウ', '島木', 'シマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡山都町北中島', '43', '43447', '8613455', '熊本県', 'クマモトケン', '上益城郡山都町', 'カミマシキグンヤマトチョウ', '北中島', 'キタナカシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡山都町', '43', '43447', '8613500', '熊本県', 'クマモトケン', '上益城郡山都町', 'カミマシキグンヤマトチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('111250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡山都町黒川', '43', '43447', '8613501', '熊本県', 'クマモトケン', '上益城郡山都町', 'カミマシキグンヤマトチョウ', '黒川', 'クロカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡山都町御所', '43', '43447', '8613502', '熊本県', 'クマモトケン', '上益城郡山都町', 'カミマシキグンヤマトチョウ', '御所', 'ゴショ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡山都町下名連石', '43', '43447', '8613503', '熊本県', 'クマモトケン', '上益城郡山都町', 'カミマシキグンヤマトチョウ', '下名連石', 'シモナレイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡山都町入佐', '43', '43447', '8613511', '熊本県', 'クマモトケン', '上益城郡山都町', 'カミマシキグンヤマトチョウ', '入佐', 'イリサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡山都町下馬尾', '43', '43447', '8613512', '熊本県', 'クマモトケン', '上益城郡山都町', 'カミマシキグンヤマトチョウ', '下馬尾', 'ゲバオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡山都町下市', '43', '43447', '8613513', '熊本県', 'クマモトケン', '上益城郡山都町', 'カミマシキグンヤマトチョウ', '下市', 'シモイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡山都町城原', '43', '43447', '8613514', '熊本県', 'クマモトケン', '上益城郡山都町', 'カミマシキグンヤマトチョウ', '城原', 'ジョウハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡山都町城平', '43', '43447', '8613515', '熊本県', 'クマモトケン', '上益城郡山都町', 'カミマシキグンヤマトチョウ', '城平', 'ジョウヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡山都町千滝', '43', '43447', '8613516', '熊本県', 'クマモトケン', '上益城郡山都町', 'カミマシキグンヤマトチョウ', '千滝', 'センダキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡山都町畑', '43', '43447', '8613517', '熊本県', 'クマモトケン', '上益城郡山都町', 'カミマシキグンヤマトチョウ', '畑', 'ハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡山都町浜町', '43', '43447', '8613518', '熊本県', 'クマモトケン', '上益城郡山都町', 'カミマシキグンヤマトチョウ', '浜町', 'ハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡山都町荒谷', '43', '43447', '8613521', '熊本県', 'クマモトケン', '上益城郡山都町', 'カミマシキグンヤマトチョウ', '荒谷', 'アラダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡山都町白小野', '43', '43447', '8613522', '熊本県', 'クマモトケン', '上益城郡山都町', 'カミマシキグンヤマトチョウ', '白小野', 'シラオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡山都町勢井', '43', '43447', '8613523', '熊本県', 'クマモトケン', '上益城郡山都町', 'カミマシキグンヤマトチョウ', '勢井', 'ゼイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡山都町藤木', '43', '43447', '8613524', '熊本県', 'クマモトケン', '上益城郡山都町', 'カミマシキグンヤマトチョウ', '藤木', 'フジキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡山都町牧野', '43', '43447', '8613525', '熊本県', 'クマモトケン', '上益城郡山都町', 'カミマシキグンヤマトチョウ', '牧野', 'マキノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡山都町万坂', '43', '43447', '8613526', '熊本県', 'クマモトケン', '上益城郡山都町', 'カミマシキグンヤマトチョウ', '万坂', 'マンザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡山都町葛原', '43', '43447', '8613531', '熊本県', 'クマモトケン', '上益城郡山都町', 'カミマシキグンヤマトチョウ', '葛原', 'クズハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡山都町猿渡', '43', '43447', '8613532', '熊本県', 'クマモトケン', '上益城郡山都町', 'カミマシキグンヤマトチョウ', '猿渡', 'サルワタリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡山都町三ケ', '43', '43447', '8613533', '熊本県', 'クマモトケン', '上益城郡山都町', 'カミマシキグンヤマトチョウ', '三ケ', 'サンガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡山都町柚木', '43', '43447', '8613534', '熊本県', 'クマモトケン', '上益城郡山都町', 'カミマシキグンヤマトチョウ', '柚木', 'ユノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡山都町芦屋田', '43', '43447', '8613541', '熊本県', 'クマモトケン', '上益城郡山都町', 'カミマシキグンヤマトチョウ', '芦屋田', 'アシヤダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡山都町市原', '43', '43447', '8613542', '熊本県', 'クマモトケン', '上益城郡山都町', 'カミマシキグンヤマトチョウ', '市原', 'イチバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡山都町上寺', '43', '43447', '8613543', '熊本県', 'クマモトケン', '上益城郡山都町', 'カミマシキグンヤマトチョウ', '上寺', 'ジョウテラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡山都町杉木', '43', '43447', '8613544', '熊本県', 'クマモトケン', '上益城郡山都町', 'カミマシキグンヤマトチョウ', '杉木', 'スギキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡山都町長田', '43', '43447', '8613545', '熊本県', 'クマモトケン', '上益城郡山都町', 'カミマシキグンヤマトチョウ', '長田', 'ナガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡山都町南田', '43', '43447', '8613546', '熊本県', 'クマモトケン', '上益城郡山都町', 'カミマシキグンヤマトチョウ', '南田', 'ミナミダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡山都町山田', '43', '43447', '8613547', '熊本県', 'クマモトケン', '上益城郡山都町', 'カミマシキグンヤマトチョウ', '山田', 'ヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡山都町長原', '43', '43447', '8613661', '熊本県', 'クマモトケン', '上益城郡山都町', 'カミマシキグンヤマトチョウ', '長原', 'ナガハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡山都町田吉', '43', '43447', '8613662', '熊本県', 'クマモトケン', '上益城郡山都町', 'カミマシキグンヤマトチョウ', '田吉', 'タヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡山都町新小', '43', '43447', '8613663', '熊本県', 'クマモトケン', '上益城郡山都町', 'カミマシキグンヤマトチョウ', '新小', 'シンコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡山都町白藤', '43', '43447', '8613664', '熊本県', 'クマモトケン', '上益城郡山都町', 'カミマシキグンヤマトチョウ', '白藤', 'シラフジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡山都町犬飼', '43', '43447', '8613665', '熊本県', 'クマモトケン', '上益城郡山都町', 'カミマシキグンヤマトチョウ', '犬飼', 'イヌカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡山都町菅', '43', '43447', '8613671', '熊本県', 'クマモトケン', '上益城郡山都町', 'カミマシキグンヤマトチョウ', '菅', 'スゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡山都町目丸', '43', '43447', '8613672', '熊本県', 'クマモトケン', '上益城郡山都町', 'カミマシキグンヤマトチョウ', '目丸', 'メマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡山都町津留', '43', '43447', '8613673', '熊本県', 'クマモトケン', '上益城郡山都町', 'カミマシキグンヤマトチョウ', '津留', 'ツル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡山都町麻山', '43', '43447', '8613781', '熊本県', 'クマモトケン', '上益城郡山都町', 'カミマシキグンヤマトチョウ', '麻山', 'アサヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡山都町上川井野', '43', '43447', '8613782', '熊本県', 'クマモトケン', '上益城郡山都町', 'カミマシキグンヤマトチョウ', '上川井野', 'カミガワイノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡山都町成君', '43', '43447', '8613783', '熊本県', 'クマモトケン', '上益城郡山都町', 'カミマシキグンヤマトチョウ', '成君', 'ナリギミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡山都町川野', '43', '43447', '8613784', '熊本県', 'クマモトケン', '上益城郡山都町', 'カミマシキグンヤマトチョウ', '川野', 'カワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡山都町田所', '43', '43447', '8613785', '熊本県', 'クマモトケン', '上益城郡山都町', 'カミマシキグンヤマトチョウ', '田所', 'タドコロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡山都町下川井野', '43', '43447', '8613786', '熊本県', 'クマモトケン', '上益城郡山都町', 'カミマシキグンヤマトチョウ', '下川井野', 'シモガワイノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡山都町野尻', '43', '43447', '8613787', '熊本県', 'クマモトケン', '上益城郡山都町', 'カミマシキグンヤマトチョウ', '野尻', 'ノジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡山都町小笹', '43', '43447', '8613788', '熊本県', 'クマモトケン', '上益城郡山都町', 'カミマシキグンヤマトチョウ', '小笹', 'オザサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡山都町男成', '43', '43447', '8613789', '熊本県', 'クマモトケン', '上益城郡山都町', 'カミマシキグンヤマトチョウ', '男成', 'オトコナリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡山都町小峰', '43', '43447', '8613801', '熊本県', 'クマモトケン', '上益城郡山都町', 'カミマシキグンヤマトチョウ', '小峰', 'オミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡山都町木原谷', '43', '43447', '8613802', '熊本県', 'クマモトケン', '上益城郡山都町', 'カミマシキグンヤマトチョウ', '木原谷', 'キハラダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡山都町小中竹', '43', '43447', '8613803', '熊本県', 'クマモトケン', '上益城郡山都町', 'カミマシキグンヤマトチョウ', '小中竹', 'コナカダケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡山都町貫原', '43', '43447', '8613804', '熊本県', 'クマモトケン', '上益城郡山都町', 'カミマシキグンヤマトチョウ', '貫原', 'ヌキハル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡山都町須原', '43', '43447', '8613805', '熊本県', 'クマモトケン', '上益城郡山都町', 'カミマシキグンヤマトチョウ', '須原', 'スバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡山都町米生', '43', '43447', '8613806', '熊本県', 'クマモトケン', '上益城郡山都町', 'カミマシキグンヤマトチョウ', '米生', 'ヨネオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡山都町大平', '43', '43447', '8613811', '熊本県', 'クマモトケン', '上益城郡山都町', 'カミマシキグンヤマトチョウ', '大平', 'オオヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡山都町鶴ケ田', '43', '43447', '8613812', '熊本県', 'クマモトケン', '上益城郡山都町', 'カミマシキグンヤマトチョウ', '鶴ケ田', 'ツルケタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡山都町川口', '43', '43447', '8613813', '熊本県', 'クマモトケン', '上益城郡山都町', 'カミマシキグンヤマトチョウ', '川口', 'カワグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡山都町郷野原', '43', '43447', '8613831', '熊本県', 'クマモトケン', '上益城郡山都町', 'カミマシキグンヤマトチョウ', '郷野原', 'ゴウノハル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡山都町井無田', '43', '43447', '8613832', '熊本県', 'クマモトケン', '上益城郡山都町', 'カミマシキグンヤマトチョウ', '井無田', 'イムタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡山都町安方', '43', '43447', '8613833', '熊本県', 'クマモトケン', '上益城郡山都町', 'カミマシキグンヤマトチョウ', '安方', 'ヤスカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡山都町高月', '43', '43447', '8613834', '熊本県', 'クマモトケン', '上益城郡山都町', 'カミマシキグンヤマトチョウ', '高月', 'コウヅキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡山都町仏原', '43', '43447', '8613835', '熊本県', 'クマモトケン', '上益城郡山都町', 'カミマシキグンヤマトチョウ', '仏原', 'ホトケバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡山都町仮屋', '43', '43447', '8613841', '熊本県', 'クマモトケン', '上益城郡山都町', 'カミマシキグンヤマトチョウ', '仮屋', 'カリヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡山都町市野原', '43', '43447', '8613842', '熊本県', 'クマモトケン', '上益城郡山都町', 'カミマシキグンヤマトチョウ', '市野原', 'イチノハル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡山都町鎌野', '43', '43447', '8613843', '熊本県', 'クマモトケン', '上益城郡山都町', 'カミマシキグンヤマトチョウ', '鎌野', 'カマノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡山都町尾野尻', '43', '43447', '8613844', '熊本県', 'クマモトケン', '上益城郡山都町', 'カミマシキグンヤマトチョウ', '尾野尻', 'オノジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡山都町緑川', '43', '43447', '8613845', '熊本県', 'クマモトケン', '上益城郡山都町', 'カミマシキグンヤマトチョウ', '緑川', 'ミドリカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡山都町馬見原', '43', '43447', '8613901', '熊本県', 'クマモトケン', '上益城郡山都町', 'カミマシキグンヤマトチョウ', '馬見原', 'マミハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡山都町滝上', '43', '43447', '8613902', '熊本県', 'クマモトケン', '上益城郡山都町', 'カミマシキグンヤマトチョウ', '滝上', 'タキガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡山都町柳井原', '43', '43447', '8613903', '熊本県', 'クマモトケン', '上益城郡山都町', 'カミマシキグンヤマトチョウ', '柳井原', 'ヤナイバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡山都町方ケ野', '43', '43447', '8613904', '熊本県', 'クマモトケン', '上益城郡山都町', 'カミマシキグンヤマトチョウ', '方ケ野', 'ホウガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡山都町大野', '43', '43447', '8613905', '熊本県', 'クマモトケン', '上益城郡山都町', 'カミマシキグンヤマトチョウ', '大野', 'オオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡山都町神ノ前', '43', '43447', '8613906', '熊本県', 'クマモトケン', '上益城郡山都町', 'カミマシキグンヤマトチョウ', '神ノ前', 'カミノマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡山都町白石', '43', '43447', '8613907', '熊本県', 'クマモトケン', '上益城郡山都町', 'カミマシキグンヤマトチョウ', '白石', 'シライシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡山都町長崎', '43', '43447', '8613908', '熊本県', 'クマモトケン', '上益城郡山都町', 'カミマシキグンヤマトチョウ', '長崎', 'ナガサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡山都町菅尾', '43', '43447', '8613911', '熊本県', 'クマモトケン', '上益城郡山都町', 'カミマシキグンヤマトチョウ', '菅尾', 'スゲオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡山都町米迫', '43', '43447', '8613912', '熊本県', 'クマモトケン', '上益城郡山都町', 'カミマシキグンヤマトチョウ', '米迫', 'ヨネサコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡山都町今', '43', '43447', '8613913', '熊本県', 'クマモトケン', '上益城郡山都町', 'カミマシキグンヤマトチョウ', '今', 'イマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡山都町花上', '43', '43447', '8613914', '熊本県', 'クマモトケン', '上益城郡山都町', 'カミマシキグンヤマトチョウ', '花上', 'ハナガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡山都町塩出迫', '43', '43447', '8613915', '熊本県', 'クマモトケン', '上益城郡山都町', 'カミマシキグンヤマトチョウ', '塩出迫', 'シオイデサコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡山都町塩原', '43', '43447', '8613916', '熊本県', 'クマモトケン', '上益城郡山都町', 'カミマシキグンヤマトチョウ', '塩原', 'シオバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡山都町八木', '43', '43447', '8613921', '熊本県', 'クマモトケン', '上益城郡山都町', 'カミマシキグンヤマトチョウ', '八木', 'ハチボク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡山都町二瀬本', '43', '43447', '8613922', '熊本県', 'クマモトケン', '上益城郡山都町', 'カミマシキグンヤマトチョウ', '二瀬本', 'ニセモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡山都町柏', '43', '43447', '8613923', '熊本県', 'クマモトケン', '上益城郡山都町', 'カミマシキグンヤマトチョウ', '柏', 'カシワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡山都町二津留', '43', '43447', '8613924', '熊本県', 'クマモトケン', '上益城郡山都町', 'カミマシキグンヤマトチョウ', '二津留', 'フタヅル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡山都町上差尾', '43', '43447', '8613925', '熊本県', 'クマモトケン', '上益城郡山都町', 'カミマシキグンヤマトチョウ', '上差尾', 'カミザシオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡山都町大見口', '43', '43447', '8613926', '熊本県', 'クマモトケン', '上益城郡山都町', 'カミマシキグンヤマトチョウ', '大見口', 'オオミクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡山都町玉目', '43', '43447', '8613927', '熊本県', 'クマモトケン', '上益城郡山都町', 'カミマシキグンヤマトチョウ', '玉目', 'タマメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡山都町長谷', '43', '43447', '8613928', '熊本県', 'クマモトケン', '上益城郡山都町', 'カミマシキグンヤマトチョウ', '長谷', 'ナガタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡山都町橘', '43', '43447', '8613931', '熊本県', 'クマモトケン', '上益城郡山都町', 'カミマシキグンヤマトチョウ', '橘', 'タチバナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡山都町下山', '43', '43447', '8613932', '熊本県', 'クマモトケン', '上益城郡山都町', 'カミマシキグンヤマトチョウ', '下山', 'シモヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡山都町高辻', '43', '43447', '8613933', '熊本県', 'クマモトケン', '上益城郡山都町', 'カミマシキグンヤマトチョウ', '高辻', 'タカツジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡山都町高畑', '43', '43447', '8613934', '熊本県', 'クマモトケン', '上益城郡山都町', 'カミマシキグンヤマトチョウ', '高畑', 'タカバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡山都町東竹原', '43', '43447', '8613935', '熊本県', 'クマモトケン', '上益城郡山都町', 'カミマシキグンヤマトチョウ', '東竹原', 'ヒガシタケバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡山都町柳', '43', '43447', '8613936', '熊本県', 'クマモトケン', '上益城郡山都町', 'カミマシキグンヤマトチョウ', '柳', 'ヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡山都町伊勢', '43', '43447', '8613937', '熊本県', 'クマモトケン', '上益城郡山都町', 'カミマシキグンヤマトチョウ', '伊勢', 'イセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市近見', '43', '43201', '8614101', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '近見', 'チカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市御幸西無田町', '43', '43201', '8614102', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '御幸西無田町', 'ミユキニシムタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市御幸笛田町', '43', '43201', '8614103', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '御幸笛田町', 'ミユキフエダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市御幸木部町', '43', '43201', '8614104', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '御幸木部町', 'ミユキキベマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市元三町', '43', '43201', '8614105', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '元三町', 'モトミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市南高江', '43', '43201', '8614106', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '南高江', 'ミナミタカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市幸田', '43', '43201', '8614108', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '幸田', 'コウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市日吉', '43', '43201', '8614109', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '日吉', 'ヒヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市合志', '43', '43201', '8614111', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '合志', 'ゴウシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市合志町', '43', '43201', '8614111', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '合志町', 'ゴウシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市白藤', '43', '43201', '8614112', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '白藤', 'シラフジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市白藤町', '43', '43201', '8614112', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '白藤町', 'シラフジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市八幡', '43', '43201', '8614113', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '八幡', 'ヤハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市野田', '43', '43201', '8614114', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '野田', 'ノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市川尻', '43', '43201', '8614115', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '川尻', 'カワシリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市中無田町', '43', '43201', '8614116', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '中無田町', 'ナカムタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市護藤町', '43', '43201', '8614117', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '護藤町', 'ゴンドウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市会富町', '43', '43201', '8614121', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '会富町', 'アイドミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市美登里町', '43', '43201', '8614122', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '美登里町', 'ミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市川口町', '43', '43201', '8614123', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '川口町', 'カワグチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市海路口町', '43', '43201', '8614124', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '海路口町', 'ウジグチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市奥古閑町', '43', '43201', '8614125', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '奥古閑町', 'オクコガマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市銭塘町', '43', '43201', '8614126', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '銭塘町', 'ゼンドモマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市内田町', '43', '43201', '8614127', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '内田町', 'ウチダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市薄場', '43', '43201', '8614131', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '薄場', 'ウスバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市薄場町', '43', '43201', '8614131', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '薄場町', 'ウスバマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市上ノ郷', '43', '43201', '8614132', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '上ノ郷', 'カミノゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市上ノ郷町', '43', '43201', '8614132', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '上ノ郷町', 'カミノゴウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市島町', '43', '43201', '8614133', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '島町', 'シママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市刈草', '43', '43201', '8614134', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '刈草', 'カリクサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市刈草町', '43', '43201', '8614134', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '刈草町', 'カリクサマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市鳶町', '43', '43201', '8614135', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '鳶町', 'トビマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市荒尾', '43', '43201', '8614136', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '荒尾', 'アラオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市荒尾町', '43', '43201', '8614136', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '荒尾町', 'アラオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市野口', '43', '43201', '8614137', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '野口', 'ノグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市野口町', '43', '43201', '8614137', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '野口町', 'ノグチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市富合町御船手', '43', '43201', '8614141', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '富合町御船手', 'トミアイマチオフナテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市富合町杉島', '43', '43201', '8614142', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '富合町杉島', 'トミアイマチスギシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市富合町上杉', '43', '43201', '8614143', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '富合町上杉', 'トミアイマチカミスギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市富合町釈迦堂', '43', '43201', '8614144', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '富合町釈迦堂', 'トミアイマチシャカドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市富合町大町', '43', '43201', '8614145', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '富合町大町', 'トミアイマチオオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市富合町榎津', '43', '43201', '8614146', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '富合町榎津', 'トミアイマチエノキヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市富合町廻江', '43', '43201', '8614147', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '富合町廻江', 'トミアイマチマイノエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市富合町清藤', '43', '43201', '8614151', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '富合町清藤', 'トミアイマチキヨフジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市富合町新', '43', '43201', '8614152', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '富合町新', 'トミアイマチシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市富合町木原', '43', '43201', '8614153', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '富合町木原', 'トミアイマチキワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市富合町平原', '43', '43201', '8614154', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '富合町平原', 'トミアイマチヒラバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市富合町南田尻', '43', '43201', '8614155', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '富合町南田尻', 'トミアイマチミナミタノシリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市富合町田尻', '43', '43201', '8614156', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '富合町田尻', 'トミアイマチタノシリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市富合町古閑', '43', '43201', '8614157', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '富合町古閑', 'トミアイマチコガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市富合町小岩瀬', '43', '43201', '8614161', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '富合町小岩瀬', 'トミアイマチコイワセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市富合町国町', '43', '43201', '8614162', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '富合町国町', 'トミアイマチコクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市富合町志々水', '43', '43201', '8614163', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '富合町志々水', 'トミアイマチシジミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市富合町西田尻', '43', '43201', '8614164', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '富合町西田尻', 'トミアイマチニシタノシリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市富合町硴江', '43', '43201', '8614165', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '富合町硴江', 'トミアイマチカキノエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市富合町莎崎', '43', '43201', '8614166', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '富合町莎崎', 'トミアイマチコウザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市富合町菰江', '43', '43201', '8614167', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '富合町菰江', 'トミアイマチコモノエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市御幸西', '43', '43201', '8614171', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '御幸西', 'ミユキニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市御幸笛田', '43', '43201', '8614172', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '御幸笛田', 'ミユキフエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市御幸木部', '43', '43201', '8614173', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '御幸木部', 'ミユキキベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県下益城郡城南町', '43', '43341', '8614200', '熊本県', 'クマモトケン', '下益城郡城南町', 'シモマシキグンジョウナンマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('111411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県下益城郡城南町坂野', '43', '43341', '8614201', '熊本県', 'クマモトケン', '下益城郡城南町', 'シモマシキグンジョウナンマチ', '坂野', 'サカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県下益城郡城南町宮地', '43', '43341', '8614202', '熊本県', 'クマモトケン', '下益城郡城南町', 'シモマシキグンジョウナンマチ', '宮地', 'ミヤジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県下益城郡城南町隈庄', '43', '43341', '8614203', '熊本県', 'クマモトケン', '下益城郡城南町', 'シモマシキグンジョウナンマチ', '隈庄', 'クマノショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県下益城郡城南町下宮地', '43', '43341', '8614204', '熊本県', 'クマモトケン', '下益城郡城南町', 'シモマシキグンジョウナンマチ', '下宮地', 'シモミヤジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県下益城郡城南町碇', '43', '43341', '8614205', '熊本県', 'クマモトケン', '下益城郡城南町', 'シモマシキグンジョウナンマチ', '碇', 'イカリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県下益城郡城南町今吉野', '43', '43341', '8614211', '熊本県', 'クマモトケン', '下益城郡城南町', 'シモマシキグンジョウナンマチ', '今吉野', 'イマヨシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県下益城郡城南町築地', '43', '43341', '8614212', '熊本県', 'クマモトケン', '下益城郡城南町', 'シモマシキグンジョウナンマチ', '築地', 'ツイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県下益城郡城南町出水', '43', '43341', '8614213', '熊本県', 'クマモトケン', '下益城郡城南町', 'シモマシキグンジョウナンマチ', '出水', 'イズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県下益城郡城南町舞原', '43', '43341', '8614214', '熊本県', 'クマモトケン', '下益城郡城南町', 'シモマシキグンジョウナンマチ', '舞原', 'マイノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県下益城郡城南町沈目', '43', '43341', '8614215', '熊本県', 'クマモトケン', '下益城郡城南町', 'シモマシキグンジョウナンマチ', '沈目', 'シズメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県下益城郡城南町陳内', '43', '43341', '8614221', '熊本県', 'クマモトケン', '下益城郡城南町', 'シモマシキグンジョウナンマチ', '陳内', 'ジンナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県下益城郡城南町鰐瀬', '43', '43341', '8614222', '熊本県', 'クマモトケン', '下益城郡城南町', 'シモマシキグンジョウナンマチ', '鰐瀬', 'ワニゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県下益城郡城南町藤山', '43', '43341', '8614223', '熊本県', 'クマモトケン', '下益城郡城南町', 'シモマシキグンジョウナンマチ', '藤山', 'フジヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県下益城郡城南町阿高', '43', '43341', '8614224', '熊本県', 'クマモトケン', '下益城郡城南町', 'シモマシキグンジョウナンマチ', '阿高', 'アダカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県下益城郡城南町東阿高', '43', '43341', '8614225', '熊本県', 'クマモトケン', '下益城郡城南町', 'シモマシキグンジョウナンマチ', '東阿高', 'ヒガシアダカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県下益城郡城南町塚原', '43', '43341', '8614226', '熊本県', 'クマモトケン', '下益城郡城南町', 'シモマシキグンジョウナンマチ', '塚原', 'ツカハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県下益城郡城南町赤見', '43', '43341', '8614231', '熊本県', 'クマモトケン', '下益城郡城南町', 'シモマシキグンジョウナンマチ', '赤見', 'アカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県下益城郡城南町高', '43', '43341', '8614232', '熊本県', 'クマモトケン', '下益城郡城南町', 'シモマシキグンジョウナンマチ', '高', 'タカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県下益城郡城南町丹生宮', '43', '43341', '8614233', '熊本県', 'クマモトケン', '下益城郡城南町', 'シモマシキグンジョウナンマチ', '丹生宮', 'ニュウノミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県下益城郡城南町永', '43', '43341', '8614234', '熊本県', 'クマモトケン', '下益城郡城南町', 'シモマシキグンジョウナンマチ', '永', 'ナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県下益城郡城南町千町', '43', '43341', '8614235', '熊本県', 'クマモトケン', '下益城郡城南町', 'シモマシキグンジョウナンマチ', '千町', 'チマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県下益城郡城南町島田', '43', '43341', '8614236', '熊本県', 'クマモトケン', '下益城郡城南町', 'シモマシキグンジョウナンマチ', '島田', 'シマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県下益城郡城南町六田', '43', '43341', '8614237', '熊本県', 'クマモトケン', '下益城郡城南町', 'シモマシキグンジョウナンマチ', '六田', 'ロクタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇城市豊野町糸石', '43', '43213', '8614301', '熊本県', 'クマモトケン', '宇城市', 'ウキシ', '豊野町糸石', 'トヨノマチイトイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇城市豊野町中間', '43', '43213', '8614302', '熊本県', 'クマモトケン', '宇城市', 'ウキシ', '豊野町中間', 'トヨノマチナカマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇城市豊野町上郷', '43', '43213', '8614303', '熊本県', 'クマモトケン', '宇城市', 'ウキシ', '豊野町上郷', 'トヨノマチカミゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇城市豊野町下郷', '43', '43213', '8614304', '熊本県', 'クマモトケン', '宇城市', 'ウキシ', '豊野町下郷', 'トヨノマチシモゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇城市豊野町山崎', '43', '43213', '8614305', '熊本県', 'クマモトケン', '宇城市', 'ウキシ', '豊野町山崎', 'トヨノマチヤマサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇城市豊野町安見', '43', '43213', '8614306', '熊本県', 'クマモトケン', '宇城市', 'ウキシ', '豊野町安見', 'トヨノマチヤスミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇城市豊野町巣林', '43', '43213', '8614307', '熊本県', 'クマモトケン', '宇城市', 'ウキシ', '豊野町巣林', 'トヨノマチスバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県下益城郡美里町大沢水', '43', '43348', '8614401', '熊本県', 'クマモトケン', '下益城郡美里町', 'シモマシキグンミサトマチ', '大沢水', 'オオソウズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県下益城郡美里町堅志田', '43', '43348', '8614402', '熊本県', 'クマモトケン', '下益城郡美里町', 'シモマシキグンミサトマチ', '堅志田', 'カタシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県下益城郡美里町中郡', '43', '43348', '8614403', '熊本県', 'クマモトケン', '下益城郡美里町', 'シモマシキグンミサトマチ', '中郡', 'ナカゴオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県下益城郡美里町岩下', '43', '43348', '8614404', '熊本県', 'クマモトケン', '下益城郡美里町', 'シモマシキグンミサトマチ', '岩下', 'イワシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県下益城郡美里町萱野', '43', '43348', '8614405', '熊本県', 'クマモトケン', '下益城郡美里町', 'シモマシキグンミサトマチ', '萱野', 'カヤノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県下益城郡美里町馬場', '43', '43348', '8614406', '熊本県', 'クマモトケン', '下益城郡美里町', 'シモマシキグンミサトマチ', '馬場', 'ババ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県下益城郡美里町中小路', '43', '43348', '8614407', '熊本県', 'クマモトケン', '下益城郡美里町', 'シモマシキグンミサトマチ', '中小路', 'ナカショウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県下益城郡美里町小筵', '43', '43348', '8614411', '熊本県', 'クマモトケン', '下益城郡美里町', 'シモマシキグンミサトマチ', '小筵', 'コムシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県下益城郡美里町佐俣', '43', '43348', '8614412', '熊本県', 'クマモトケン', '下益城郡美里町', 'シモマシキグンミサトマチ', '佐俣', 'サマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県下益城郡美里町岩野', '43', '43348', '8614413', '熊本県', 'クマモトケン', '下益城郡美里町', 'シモマシキグンミサトマチ', '岩野', 'イワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県下益城郡美里町椿', '43', '43348', '8614414', '熊本県', 'クマモトケン', '下益城郡美里町', 'シモマシキグンミサトマチ', '椿', 'ツバキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県下益城郡美里町坂本', '43', '43348', '8614415', '熊本県', 'クマモトケン', '下益城郡美里町', 'シモマシキグンミサトマチ', '坂本', 'サカモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県下益城郡美里町払川', '43', '43348', '8614416', '熊本県', 'クマモトケン', '下益城郡美里町', 'シモマシキグンミサトマチ', '払川', 'ハライガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県下益城郡美里町中', '43', '43348', '8614417', '熊本県', 'クマモトケン', '下益城郡美里町', 'シモマシキグンミサトマチ', '中', 'ナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県下益城郡美里町原田', '43', '43348', '8614421', '熊本県', 'クマモトケン', '下益城郡美里町', 'シモマシキグンミサトマチ', '原田', 'ハラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県下益城郡美里町長尾野', '43', '43348', '8614422', '熊本県', 'クマモトケン', '下益城郡美里町', 'シモマシキグンミサトマチ', '長尾野', 'ナガオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県下益城郡美里町松野原', '43', '43348', '8614423', '熊本県', 'クマモトケン', '下益城郡美里町', 'シモマシキグンミサトマチ', '松野原', 'マツノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県下益城郡美里町小市野', '43', '43348', '8614424', '熊本県', 'クマモトケン', '下益城郡美里町', 'シモマシキグンミサトマチ', '小市野', 'コイチノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県下益城郡美里町木早川内', '43', '43348', '8614425', '熊本県', 'クマモトケン', '下益城郡美里町', 'シモマシキグンミサトマチ', '木早川内', 'キソガワチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県下益城郡美里町白石野', '43', '43348', '8614426', '熊本県', 'クマモトケン', '下益城郡美里町', 'シモマシキグンミサトマチ', '白石野', 'シライシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県下益城郡美里町津留', '43', '43348', '8614427', '熊本県', 'クマモトケン', '下益城郡美里町', 'シモマシキグンミサトマチ', '津留', 'ツル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡標津町川北', '01', '01693', '0861451', '北海道', 'ホッカイドウ', '標津郡標津町', 'シベツグンシベツチョウ', '川北', 'カワキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡甲佐町', '43', '43444', '8614600', '熊本県', 'クマモトケン', '上益城郡甲佐町', 'カミマシキグンコウサマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('111466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡甲佐町岩下', '43', '43444', '8614601', '熊本県', 'クマモトケン', '上益城郡甲佐町', 'カミマシキグンコウサマチ', '岩下', 'イワシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡甲佐町緑町', '43', '43444', '8614602', '熊本県', 'クマモトケン', '上益城郡甲佐町', 'カミマシキグンコウサマチ', '緑町', 'ミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡甲佐町仁田子', '43', '43444', '8614603', '熊本県', 'クマモトケン', '上益城郡甲佐町', 'カミマシキグンコウサマチ', '仁田子', 'ニタゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡甲佐町大町', '43', '43444', '8614604', '熊本県', 'クマモトケン', '上益城郡甲佐町', 'カミマシキグンコウサマチ', '大町', 'オオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡甲佐町有安', '43', '43444', '8614605', '熊本県', 'クマモトケン', '上益城郡甲佐町', 'カミマシキグンコウサマチ', '有安', 'アリヤス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡甲佐町横田', '43', '43444', '8614606', '熊本県', 'クマモトケン', '上益城郡甲佐町', 'カミマシキグンコウサマチ', '横田', 'ヨコタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡甲佐町豊内', '43', '43444', '8614607', '熊本県', 'クマモトケン', '上益城郡甲佐町', 'カミマシキグンコウサマチ', '豊内', 'トヨウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡甲佐町東寒野', '43', '43444', '8614608', '熊本県', 'クマモトケン', '上益城郡甲佐町', 'カミマシキグンコウサマチ', '東寒野', 'ヒガシサマノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡甲佐町西寒野', '43', '43444', '8614609', '熊本県', 'クマモトケン', '上益城郡甲佐町', 'カミマシキグンコウサマチ', '西寒野', 'ニシサマノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡甲佐町船津', '43', '43444', '8614611', '熊本県', 'クマモトケン', '上益城郡甲佐町', 'カミマシキグンコウサマチ', '船津', 'フナツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡甲佐町世持', '43', '43444', '8614612', '熊本県', 'クマモトケン', '上益城郡甲佐町', 'カミマシキグンコウサマチ', '世持', 'ヨモチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡甲佐町南三箇', '43', '43444', '8614613', '熊本県', 'クマモトケン', '上益城郡甲佐町', 'カミマシキグンコウサマチ', '南三箇', 'ミナミサンガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡甲佐町中山', '43', '43444', '8614614', '熊本県', 'クマモトケン', '上益城郡甲佐町', 'カミマシキグンコウサマチ', '中山', 'ナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡甲佐町府領', '43', '43444', '8614615', '熊本県', 'クマモトケン', '上益城郡甲佐町', 'カミマシキグンコウサマチ', '府領', 'フリョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡甲佐町田口', '43', '43444', '8614616', '熊本県', 'クマモトケン', '上益城郡甲佐町', 'カミマシキグンコウサマチ', '田口', 'タグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡甲佐町津志田', '43', '43444', '8614617', '熊本県', 'クマモトケン', '上益城郡甲佐町', 'カミマシキグンコウサマチ', '津志田', 'ツシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡甲佐町麻生原', '43', '43444', '8614618', '熊本県', 'クマモトケン', '上益城郡甲佐町', 'カミマシキグンコウサマチ', '麻生原', 'アソバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡甲佐町下横田', '43', '43444', '8614621', '熊本県', 'クマモトケン', '上益城郡甲佐町', 'カミマシキグンコウサマチ', '下横田', 'シモヨコタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡甲佐町上早川', '43', '43444', '8614622', '熊本県', 'クマモトケン', '上益城郡甲佐町', 'カミマシキグンコウサマチ', '上早川', 'カミソウガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡甲佐町中横田', '43', '43444', '8614623', '熊本県', 'クマモトケン', '上益城郡甲佐町', 'カミマシキグンコウサマチ', '中横田', 'ナカヨコタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡甲佐町上揚', '43', '43444', '8614631', '熊本県', 'クマモトケン', '上益城郡甲佐町', 'カミマシキグンコウサマチ', '上揚', 'カミアゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡甲佐町坂谷', '43', '43444', '8614632', '熊本県', 'クマモトケン', '上益城郡甲佐町', 'カミマシキグンコウサマチ', '坂谷', 'サカダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡甲佐町西原', '43', '43444', '8614633', '熊本県', 'クマモトケン', '上益城郡甲佐町', 'カミマシキグンコウサマチ', '西原', 'ニシハル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡甲佐町小鹿', '43', '43444', '8614634', '熊本県', 'クマモトケン', '上益城郡甲佐町', 'カミマシキグンコウサマチ', '小鹿', 'オガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上益城郡甲佐町安平', '43', '43444', '8614635', '熊本県', 'クマモトケン', '上益城郡甲佐町', 'カミマシキグンコウサマチ', '安平', 'ヤスヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県下益城郡美里町', '43', '43348', '8614700', '熊本県', 'クマモトケン', '下益城郡美里町', 'シモマシキグンミサトマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('111493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県下益城郡美里町大井早', '43', '43348', '8614701', '熊本県', 'クマモトケン', '下益城郡美里町', 'シモマシキグンミサトマチ', '大井早', 'オオイソウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県下益城郡美里町遠野', '43', '43348', '8614702', '熊本県', 'クマモトケン', '下益城郡美里町', 'シモマシキグンミサトマチ', '遠野', 'トオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県下益城郡美里町畝野', '43', '43348', '8614703', '熊本県', 'クマモトケン', '下益城郡美里町', 'シモマシキグンミサトマチ', '畝野', 'ウネノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県下益城郡美里町涌井', '43', '43348', '8614704', '熊本県', 'クマモトケン', '下益城郡美里町', 'シモマシキグンミサトマチ', '涌井', 'ユイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県下益城郡美里町豊富', '43', '43348', '8614705', '熊本県', 'クマモトケン', '下益城郡美里町', 'シモマシキグンミサトマチ', '豊富', 'トヨトミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県下益城郡美里町甲佐平', '43', '43348', '8614706', '熊本県', 'クマモトケン', '下益城郡美里町', 'シモマシキグンミサトマチ', '甲佐平', 'コウサビラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県下益城郡美里町川越', '43', '43348', '8614707', '熊本県', 'クマモトケン', '下益城郡美里町', 'シモマシキグンミサトマチ', '川越', 'カワゴシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県下益城郡美里町洞岳', '43', '43348', '8614711', '熊本県', 'クマモトケン', '下益城郡美里町', 'シモマシキグンミサトマチ', '洞岳', 'ホラオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県下益城郡美里町柏川', '43', '43348', '8614712', '熊本県', 'クマモトケン', '下益城郡美里町', 'シモマシキグンミサトマチ', '柏川', 'カシワガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県下益城郡美里町早楠', '43', '43348', '8614713', '熊本県', 'クマモトケン', '下益城郡美里町', 'シモマシキグンミサトマチ', '早楠', 'ハヤクス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県下益城郡美里町安部', '43', '43348', '8614714', '熊本県', 'クマモトケン', '下益城郡美里町', 'シモマシキグンミサトマチ', '安部', 'アベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県下益城郡美里町清水', '43', '43348', '8614715', '熊本県', 'クマモトケン', '下益城郡美里町', 'シモマシキグンミサトマチ', '清水', 'キヨミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県下益城郡美里町石野', '43', '43348', '8614716', '熊本県', 'クマモトケン', '下益城郡美里町', 'シモマシキグンミサトマチ', '石野', 'イシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県下益城郡美里町土喰', '43', '43348', '8614721', '熊本県', 'クマモトケン', '下益城郡美里町', 'シモマシキグンミサトマチ', '土喰', 'ツチバミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県下益城郡美里町永富', '43', '43348', '8614722', '熊本県', 'クマモトケン', '下益城郡美里町', 'シモマシキグンミサトマチ', '永富', 'ナガトミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県下益城郡美里町境', '43', '43348', '8614723', '熊本県', 'クマモトケン', '下益城郡美里町', 'シモマシキグンミサトマチ', '境', 'サカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県下益城郡美里町坂貫', '43', '43348', '8614725', '熊本県', 'クマモトケン', '下益城郡美里町', 'シモマシキグンミサトマチ', '坂貫', 'サカヌキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県下益城郡美里町大窪', '43', '43348', '8614726', '熊本県', 'クマモトケン', '下益城郡美里町', 'シモマシキグンミサトマチ', '大窪', 'オオクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県下益城郡美里町原町', '43', '43348', '8614727', '熊本県', 'クマモトケン', '下益城郡美里町', 'シモマシキグンミサトマチ', '原町', 'ハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県下益城郡美里町栗崎', '43', '43348', '8614731', '熊本県', 'クマモトケン', '下益城郡美里町', 'シモマシキグンミサトマチ', '栗崎', 'クリザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県下益城郡美里町三和', '43', '43348', '8614732', '熊本県', 'クマモトケン', '下益城郡美里町', 'シモマシキグンミサトマチ', '三和', 'ミツワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県下益城郡美里町二和田', '43', '43348', '8614733', '熊本県', 'クマモトケン', '下益城郡美里町', 'シモマシキグンミサトマチ', '二和田', 'ニワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県下益城郡美里町今', '43', '43348', '8614734', '熊本県', 'クマモトケン', '下益城郡美里町', 'シモマシキグンミサトマチ', '今', 'イマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県下益城郡美里町三加', '43', '43348', '8614735', '熊本県', 'クマモトケン', '下益城郡美里町', 'シモマシキグンミサトマチ', '三加', 'サンガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県下益城郡美里町名越谷', '43', '43348', '8614736', '熊本県', 'クマモトケン', '下益城郡美里町', 'シモマシキグンミサトマチ', '名越谷', 'ナゴシダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県下益城郡美里町古閑', '43', '43348', '8614737', '熊本県', 'クマモトケン', '下益城郡美里町', 'シモマシキグンミサトマチ', '古閑', 'コガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市今町', '43', '43201', '8615251', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '今町', 'イママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市土河原町', '43', '43201', '8615252', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '土河原町', 'トガワラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市八分字町', '43', '43201', '8615253', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '八分字町', 'ハフジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市孫代町', '43', '43201', '8615254', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '孫代町', 'マゴダイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市砂原町', '43', '43201', '8615255', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '砂原町', 'スナハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市無田口町', '43', '43201', '8615261', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '無田口町', 'ムタグチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市浜口町', '43', '43201', '8615262', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '浜口町', 'ハマグチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市並建町', '43', '43201', '8615263', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '並建町', 'ナミタテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市白石町', '43', '43201', '8615264', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '白石町', 'シロイシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市畠口町', '43', '43201', '8615265', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '畠口町', 'ハタグチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市中原町', '43', '43201', '8615271', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '中原町', 'ナカハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市中島町', '43', '43201', '8615272', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '中島町', 'ナカシママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市沖新町', '43', '43201', '8615273', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '沖新町', 'オキシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市新港', '43', '43201', '8615274', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '新港', 'シンミナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市松尾町近津', '43', '43201', '8615281', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '松尾町近津', 'マツオマチチコウヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市松尾町平山', '43', '43201', '8615282', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '松尾町平山', 'マツオマチヒラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市松尾町上松尾', '43', '43201', '8615283', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '松尾町上松尾', 'マツオマチカミマツオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市小島下町', '43', '43201', '8615284', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '小島下町', 'オシマシモマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市小島上町', '43', '43201', '8615285', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '小島上町', 'オシマカミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市小島', '43', '43201', '8615287', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '小島', 'オシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市河内町大多尾', '43', '43201', '8615341', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '河内町大多尾', 'カワチマチオオタオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市河内町東門寺', '43', '43201', '8615342', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '河内町東門寺', 'カワチマチトウモンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市河内町野出', '43', '43201', '8615343', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '河内町野出', 'カワチマチノイデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市河内町岳', '43', '43201', '8615344', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '河内町岳', 'カワチマチタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市河内町面木', '43', '43201', '8615345', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '河内町面木', 'カワチマチオモノギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市河内町河内', '43', '43201', '8615346', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '河内町河内', 'カワチマチカワチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市河内町船津', '43', '43201', '8615347', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '河内町船津', 'カワチマチフナツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市河内町白浜', '43', '43201', '8615348', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '河内町白浜', 'カワチマチシラハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名市天水町小天', '43', '43206', '8615401', '熊本県', 'クマモトケン', '玉名市', 'タマナシ', '天水町小天', 'テンスイマチオアマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名市天水町立花', '43', '43206', '8615402', '熊本県', 'クマモトケン', '玉名市', 'タマナシ', '天水町立花', 'テンスイマチタチバナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名市天水町部田見', '43', '43206', '8615403', '熊本県', 'クマモトケン', '玉名市', 'タマナシ', '天水町部田見', 'テンスイマチヘタミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名市天水町竹崎', '43', '43206', '8615404', '熊本県', 'クマモトケン', '玉名市', 'タマナシ', '天水町竹崎', 'テンスイマチタケザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名市天水町野部田', '43', '43206', '8615405', '熊本県', 'クマモトケン', '玉名市', 'タマナシ', '天水町野部田', 'テンスイマチノベタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名市天水町尾田', '43', '43206', '8615406', '熊本県', 'クマモトケン', '玉名市', 'タマナシ', '天水町尾田', 'テンスイマチオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市改寄町', '43', '43201', '8615501', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '改寄町', 'アラキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市大鳥居町', '43', '43201', '8615502', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '大鳥居町', 'オオトリイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市明徳町', '43', '43201', '8615503', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '明徳町', 'メイトクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市小糸山町', '43', '43201', '8615504', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '小糸山町', 'コイトヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市楠野町', '43', '43201', '8615511', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '楠野町', 'クスノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市梶尾町', '43', '43201', '8615512', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '梶尾町', 'カジオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市鶴羽田町', '43', '43201', '8615513', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '鶴羽田町', 'ツルハダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市飛田', '43', '43201', '8615514', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '飛田', 'ヒダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市四方寄町', '43', '43201', '8615515', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '四方寄町', 'ヨモギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市西梶尾町', '43', '43201', '8615516', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '西梶尾町', 'ニシカジオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市鹿子木町', '43', '43201', '8615521', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '鹿子木町', 'カノコギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市下硯川町', '43', '43201', '8615522', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '下硯川町', 'シモスズリカワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市徳王町', '43', '43201', '8615523', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '徳王町', 'トクオウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市硯川町', '43', '43201', '8615524', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '硯川町', 'スズリカワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市徳王', '43', '43201', '8615525', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '徳王', 'トクオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市北迫町', '43', '43201', '8615531', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '北迫町', 'キタザコマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市太郎迫町', '43', '43201', '8615532', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '太郎迫町', 'タロウザコマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市和泉町', '43', '43201', '8615533', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '和泉町', 'イズミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市釜尾町', '43', '43201', '8615534', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '釜尾町', 'カマオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市貢町', '43', '43201', '8615535', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '貢町', 'ミツグマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市立福寺町', '43', '43201', '8615536', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '立福寺町', 'リュウフクジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市万楽寺町', '43', '43201', '8615537', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '万楽寺町', 'マンラクジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡標津町', '01', '01693', '0861600', '北海道', 'ホッカイドウ', '標津郡標津町', 'シベツグンシベツチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('111582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡標津町忠類', '01', '01693', '0861601', '北海道', 'ホッカイドウ', '標津郡標津町', 'シベツグンシベツチョウ', '忠類', 'チュウルイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡標津町伊茶仁', '01', '01693', '0861602', '北海道', 'ホッカイドウ', '標津郡標津町', 'シベツグンシベツチョウ', '伊茶仁', 'イチャニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上天草市松島町阿村', '43', '43212', '8616101', '熊本県', 'クマモトケン', '上天草市', 'カミアマクサシ', '松島町阿村', 'マツシママチアムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上天草市松島町合津', '43', '43212', '8616102', '熊本県', 'クマモトケン', '上天草市', 'カミアマクサシ', '松島町合津', 'マツシママチアイツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上天草市松島町今泉', '43', '43212', '8616103', '熊本県', 'クマモトケン', '上天草市', 'カミアマクサシ', '松島町今泉', 'マツシママチイマイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上天草市松島町内野河内', '43', '43212', '8616104', '熊本県', 'クマモトケン', '上天草市', 'カミアマクサシ', '松島町内野河内', 'マツシママチウチノカワウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上天草市松島町教良木', '43', '43212', '8616105', '熊本県', 'クマモトケン', '上天草市', 'カミアマクサシ', '松島町教良木', 'マツシママチキョウラギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡標津町茶志骨パイロット', '01', '01693', '0861621', '北海道', 'ホッカイドウ', '標津郡標津町', 'シベツグンシベツチョウ', '茶志骨', 'チャシコツ', null, null, 'パイロット', 'パイロット');
INSERT INTO `ms_addresses` VALUES ('111591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡標津町茶志骨', '01', '01693', '0861622', '北海道', 'ホッカイドウ', '標津郡標津町', 'シベツグンシベツチョウ', '茶志骨', 'チャシコツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡標津町茶志骨東茶志骨', '01', '01693', '0861623', '北海道', 'ホッカイドウ', '標津郡標津町', 'シベツグンシベツチョウ', '茶志骨', 'チャシコツ', null, null, '東茶志骨', 'ヒガシチャシコツ');
INSERT INTO `ms_addresses` VALUES ('111593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡標津町茶志骨住吉町', '01', '01693', '0861625', '北海道', 'ホッカイドウ', '標津郡標津町', 'シベツグンシベツチョウ', '茶志骨', 'チャシコツ', null, null, '住吉町', 'スミヨシチョウ');
INSERT INTO `ms_addresses` VALUES ('111594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡標津町茶志骨東浜町', '01', '01693', '0861626', '北海道', 'ホッカイドウ', '標津郡標津町', 'シベツグンシベツチョウ', '茶志骨', 'チャシコツ', null, null, '東浜町', 'ヒガシハマチョウ');
INSERT INTO `ms_addresses` VALUES ('111595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡標津町北10条', '01', '01693', '0861630', '北海道', 'ホッカイドウ', '標津郡標津町', 'シベツグンシベツチョウ', '北10条', 'キタ10ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草市栖本町打田', '43', '43215', '8616301', '熊本県', 'クマモトケン', '天草市', 'アマクサシ', '栖本町打田', 'スモトマチウチダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草市栖本町河内', '43', '43215', '8616302', '熊本県', 'クマモトケン', '天草市', 'アマクサシ', '栖本町河内', 'スモトマチカワチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草市栖本町馬場', '43', '43215', '8616303', '熊本県', 'クマモトケン', '天草市', 'アマクサシ', '栖本町馬場', 'スモトマチババ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草市栖本町古江', '43', '43215', '8616304', '熊本県', 'クマモトケン', '天草市', 'アマクサシ', '栖本町古江', 'スモトマチフルエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草市栖本町湯船原', '43', '43215', '8616305', '熊本県', 'クマモトケン', '天草市', 'アマクサシ', '栖本町湯船原', 'スモトマチユフネハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡標津町北1条', '01', '01693', '0861631', '北海道', 'ホッカイドウ', '標津郡標津町', 'シベツグンシベツチョウ', '北1条', 'キタ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡標津町北2条', '01', '01693', '0861632', '北海道', 'ホッカイドウ', '標津郡標津町', 'シベツグンシベツチョウ', '北2条', 'キタ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡標津町北3条', '01', '01693', '0861633', '北海道', 'ホッカイドウ', '標津郡標津町', 'シベツグンシベツチョウ', '北3条', 'キタ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡標津町北4条', '01', '01693', '0861634', '北海道', 'ホッカイドウ', '標津郡標津町', 'シベツグンシベツチョウ', '北4条', 'キタ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡標津町北5条', '01', '01693', '0861635', '北海道', 'ホッカイドウ', '標津郡標津町', 'シベツグンシベツチョウ', '北5条', 'キタ05ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡標津町北6条', '01', '01693', '0861636', '北海道', 'ホッカイドウ', '標津郡標津町', 'シベツグンシベツチョウ', '北6条', 'キタ06ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡標津町北7条', '01', '01693', '0861637', '北海道', 'ホッカイドウ', '標津郡標津町', 'シベツグンシベツチョウ', '北7条', 'キタ07ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡標津町北8条', '01', '01693', '0861638', '北海道', 'ホッカイドウ', '標津郡標津町', 'シベツグンシベツチョウ', '北8条', 'キタ08ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡標津町北9条', '01', '01693', '0861639', '北海道', 'ホッカイドウ', '標津郡標津町', 'シベツグンシベツチョウ', '北9条', 'キタ09ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草市倉岳町浦', '43', '43215', '8616401', '熊本県', 'クマモトケン', '天草市', 'アマクサシ', '倉岳町浦', 'クラタケマチウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草市倉岳町棚底', '43', '43215', '8616402', '熊本県', 'クマモトケン', '天草市', 'アマクサシ', '倉岳町棚底', 'クラタケマチタナソコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草市倉岳町宮田', '43', '43215', '8616403', '熊本県', 'クマモトケン', '天草市', 'アマクサシ', '倉岳町宮田', 'クラタケマチミヤダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道野付郡別海町尾岱沼', '01', '01691', '0861641', '北海道', 'ホッカイドウ', '野付郡別海町', 'ノツケグンベツカイチョウ', '尾岱沼', 'オダイトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道野付郡別海町尾岱沼岬町', '01', '01691', '0861642', '北海道', 'ホッカイドウ', '野付郡別海町', 'ノツケグンベツカイチョウ', '尾岱沼岬町', 'オダイトウミサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道野付郡別海町尾岱沼港町', '01', '01691', '0861643', '北海道', 'ホッカイドウ', '野付郡別海町', 'ノツケグンベツカイチョウ', '尾岱沼港町', 'オダイトウミナトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道野付郡別海町尾岱沼潮見町', '01', '01691', '0861644', '北海道', 'ホッカイドウ', '野付郡別海町', 'ノツケグンベツカイチョウ', '尾岱沼潮見町', 'オダイトウシオミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道野付郡別海町野付', '01', '01691', '0861645', '北海道', 'ホッカイドウ', '野付郡別海町', 'ノツケグンベツカイチョウ', '野付', 'ノッケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡標津町南1条', '01', '01693', '0861651', '北海道', 'ホッカイドウ', '標津郡標津町', 'シベツグンシベツチョウ', '南1条', 'ミナミ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡標津町南2条', '01', '01693', '0861652', '北海道', 'ホッカイドウ', '標津郡標津町', 'シベツグンシベツチョウ', '南2条', 'ミナミ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡標津町南3条', '01', '01693', '0861653', '北海道', 'ホッカイドウ', '標津郡標津町', 'シベツグンシベツチョウ', '南3条', 'ミナミ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡標津町南4条', '01', '01693', '0861654', '北海道', 'ホッカイドウ', '標津郡標津町', 'シベツグンシベツチョウ', '南4条', 'ミナミ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡標津町南5条', '01', '01693', '0861655', '北海道', 'ホッカイドウ', '標津郡標津町', 'シベツグンシベツチョウ', '南5条', 'ミナミ05ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草市下浦町', '43', '43215', '8616551', '熊本県', 'クマモトケン', '天草市', 'アマクサシ', '下浦町', 'シモウラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡標津町南6条', '01', '01693', '0861656', '北海道', 'ホッカイドウ', '標津郡標津町', 'シベツグンシベツチョウ', '南6条', 'ミナミ06ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡標津町南7条', '01', '01693', '0861657', '北海道', 'ホッカイドウ', '標津郡標津町', 'シベツグンシベツチョウ', '南7条', 'ミナミ07ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡標津町南8条', '01', '01693', '0861658', '北海道', 'ホッカイドウ', '標津郡標津町', 'シベツグンシベツチョウ', '南8条', 'ミナミ08ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草市有明町赤崎', '43', '43215', '8617201', '熊本県', 'クマモトケン', '天草市', 'アマクサシ', '有明町赤崎', 'アリアケマチアカサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草市有明町須子', '43', '43215', '8617202', '熊本県', 'クマモトケン', '天草市', 'アマクサシ', '有明町須子', 'アリアケマチスジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草市有明町大浦', '43', '43215', '8617203', '熊本県', 'クマモトケン', '天草市', 'アマクサシ', '有明町大浦', 'アリアケマチオオウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草市有明町楠甫', '43', '43215', '8617204', '熊本県', 'クマモトケン', '天草市', 'アマクサシ', '有明町楠甫', 'アリアケマチクスボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡標津町古多糠', '01', '01693', '0861731', '北海道', 'ホッカイドウ', '標津郡標津町', 'シベツグンシベツチョウ', '古多糠', 'コタヌカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草市有明町上津浦', '43', '43215', '8617311', '熊本県', 'クマモトケン', '天草市', 'アマクサシ', '有明町上津浦', 'アリアケマチコウツウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草市有明町下津浦', '43', '43215', '8617312', '熊本県', 'クマモトケン', '天草市', 'アマクサシ', '有明町下津浦', 'アリアケマチシモツウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草市有明町小島子', '43', '43215', '8617313', '熊本県', 'クマモトケン', '天草市', 'アマクサシ', '有明町小島子', 'アリアケマチコシマゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草市有明町大島子', '43', '43215', '8617314', '熊本県', 'クマモトケン', '天草市', 'アマクサシ', '有明町大島子', 'アリアケマチオオシマゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡標津町薫別', '01', '01693', '0861732', '北海道', 'ホッカイドウ', '標津郡標津町', 'シベツグンシベツチョウ', '薫別', 'クンベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡標津町崎無異', '01', '01693', '0861733', '北海道', 'ホッカイドウ', '標津郡標津町', 'シベツグンシベツチョウ', '崎無異', 'サキムイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道目梨郡羅臼町峯浜町', '01', '01694', '0861751', '北海道', 'ホッカイドウ', '目梨郡羅臼町', 'メナシグンラウスチョウ', '峯浜町', 'ミネハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道目梨郡羅臼町幌萌町', '01', '01694', '0861752', '北海道', 'ホッカイドウ', '目梨郡羅臼町', 'メナシグンラウスチョウ', '幌萌町', 'ホロモエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道目梨郡羅臼町', '01', '01694', '0861800', '北海道', 'ホッカイドウ', '目梨郡羅臼町', 'メナシグンラウスチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('111643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市武蔵ケ丘', '43', '43201', '8618001', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '武蔵ケ丘', 'ムサシガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市龍田町弓削', '43', '43201', '8618002', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '龍田町弓削', 'タツダマチユゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市楠', '43', '43201', '8618003', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '楠', 'クスノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市龍田陳内', '43', '43201', '8618005', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '龍田陳内', 'タツダジンナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市龍田', '43', '43201', '8618006', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '龍田', 'タツダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市龍田弓削', '43', '43201', '8618007', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '龍田弓削', 'タツダユゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道目梨郡羅臼町知床岬', '01', '01694', '0861801', '北海道', 'ホッカイドウ', '目梨郡羅臼町', 'メナシグンラウスチョウ', '知床岬', 'シレトコミサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市上南部', '43', '43201', '8618010', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '上南部', 'カミナベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市鹿帰瀬町', '43', '43201', '8618011', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '鹿帰瀬町', 'カキゼマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市平山町', '43', '43201', '8618012', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '平山町', 'ヒラヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市弓削町', '43', '43201', '8618013', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '弓削町', 'ユゲマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市石原町', '43', '43201', '8618014', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '石原町', 'イシワラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市中江町', '43', '43201', '8618015', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '中江町', 'ナカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市吉原町', '43', '43201', '8618016', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '吉原町', 'ヨシワラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市上南部町', '43', '43201', '8618017', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '上南部町', 'カミナベマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市下南部', '43', '43201', '8618019', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '下南部', 'シモナベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道目梨郡羅臼町滝ノ下', '01', '01694', '0861802', '北海道', 'ホッカイドウ', '目梨郡羅臼町', 'メナシグンラウスチョウ', '滝ノ下', 'タキノシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市新南部町', '43', '43201', '8618027', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '新南部町', 'シンナベマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市新南部', '43', '43201', '8618028', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '新南部', 'シンナベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市西原', '43', '43201', '8618029', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '西原', 'ニシバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道目梨郡羅臼町船泊', '01', '01694', '0861803', '北海道', 'ホッカイドウ', '目梨郡羅臼町', 'メナシグンラウスチョウ', '船泊', 'フナドマリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市小山町', '43', '43201', '8618030', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '小山町', 'オヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市戸島町', '43', '43201', '8618031', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '戸島町', 'トシママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市八反田', '43', '43201', '8618034', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '八反田', 'ハッタンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市御領', '43', '43201', '8618035', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '御領', 'ゴリョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市長嶺西', '43', '43201', '8618037', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '長嶺西', 'ナガミネニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市長嶺東', '43', '43201', '8618038', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '長嶺東', 'ナガミネヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市長嶺南', '43', '43201', '8618039', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '長嶺南', 'ナガミネミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道目梨郡羅臼町化石浜', '01', '01694', '0861804', '北海道', 'ホッカイドウ', '目梨郡羅臼町', 'メナシグンラウスチョウ', '化石浜', 'カセキハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市戸島', '43', '43201', '8618041', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '戸島', 'トシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市戸島本町', '43', '43201', '8618042', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '戸島本町', 'トシマホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市戸島西', '43', '43201', '8618043', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '戸島西', 'トシマニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市神園', '43', '43201', '8618044', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '神園', 'コウゾノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市小山', '43', '43201', '8618045', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '小山', 'オヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市石原', '43', '43201', '8618046', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '石原', 'イシワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道目梨郡羅臼町崩浜', '01', '01694', '0861805', '北海道', 'ホッカイドウ', '目梨郡羅臼町', 'メナシグンラウスチョウ', '崩浜', 'クズレハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道目梨郡羅臼町相泊', '01', '01694', '0861806', '北海道', 'ホッカイドウ', '目梨郡羅臼町', 'メナシグンラウスチョウ', '相泊', 'アイドマリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市八景水谷', '43', '43201', '8618064', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '八景水谷', 'ハケノミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市清水東町', '43', '43201', '8618065', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '清水東町', 'シミズヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市清水亀井町', '43', '43201', '8618066', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '清水亀井町', 'シミズカメイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市清水万石', '43', '43201', '8618068', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '清水万石', 'シミズマンゴク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市清水町室園', '43', '43201', '8618071', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '清水町室園', 'シミズマチムロゾノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市室園町', '43', '43201', '8618072', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '室園町', 'ムロゾノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市清水町松崎', '43', '43201', '8618073', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '清水町松崎', 'シミズマチマツザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市清水本町', '43', '43201', '8618074', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '清水本町', 'シミズホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市清水新地', '43', '43201', '8618075', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '清水新地', 'シミズシンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市麻生田', '43', '43201', '8618081', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '麻生田', 'アソウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市兎谷', '43', '43201', '8618082', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '兎谷', 'ウサギダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市楡木', '43', '43201', '8618083', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '楡木', 'ニレノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市清水岩倉', '43', '43201', '8618084', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '清水岩倉', 'シミズイワクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道目梨郡羅臼町瀬石', '01', '01694', '0861811', '北海道', 'ホッカイドウ', '目梨郡羅臼町', 'メナシグンラウスチョウ', '瀬石', 'セセキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道目梨郡羅臼町昆布浜', '01', '01694', '0861812', '北海道', 'ホッカイドウ', '目梨郡羅臼町', 'メナシグンラウスチョウ', '昆布浜', 'コンブハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道目梨郡羅臼町北浜', '01', '01694', '0861813', '北海道', 'ホッカイドウ', '目梨郡羅臼町', 'メナシグンラウスチョウ', '北浜', 'キタハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道目梨郡羅臼町岬町', '01', '01694', '0861814', '北海道', 'ホッカイドウ', '目梨郡羅臼町', 'メナシグンラウスチョウ', '岬町', 'ミサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道目梨郡羅臼町海岸町', '01', '01694', '0861815', '北海道', 'ホッカイドウ', '目梨郡羅臼町', 'メナシグンラウスチョウ', '海岸町', 'カイガンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道目梨郡羅臼町共栄町', '01', '01694', '0861816', '北海道', 'ホッカイドウ', '目梨郡羅臼町', 'メナシグンラウスチョウ', '共栄町', 'キョウエイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道目梨郡羅臼町緑町', '01', '01694', '0861821', '北海道', 'ホッカイドウ', '目梨郡羅臼町', 'メナシグンラウスチョウ', '緑町', 'ミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道目梨郡羅臼町湯ノ沢町', '01', '01694', '0861822', '北海道', 'ホッカイドウ', '目梨郡羅臼町', 'メナシグンラウスチョウ', '湯ノ沢町', 'ユノサワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道目梨郡羅臼町栄町', '01', '01694', '0861823', '北海道', 'ホッカイドウ', '目梨郡羅臼町', 'メナシグンラウスチョウ', '栄町', 'サカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道目梨郡羅臼町富士見町', '01', '01694', '0861831', '北海道', 'ホッカイドウ', '目梨郡羅臼町', 'メナシグンラウスチョウ', '富士見町', 'フジミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道目梨郡羅臼町船見町', '01', '01694', '0861832', '北海道', 'ホッカイドウ', '目梨郡羅臼町', 'メナシグンラウスチョウ', '船見町', 'フナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道目梨郡羅臼町本町', '01', '01694', '0861833', '北海道', 'ホッカイドウ', '目梨郡羅臼町', 'メナシグンラウスチョウ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道目梨郡羅臼町礼文町', '01', '01694', '0861834', '北海道', 'ホッカイドウ', '目梨郡羅臼町', 'メナシグンラウスチョウ', '礼文町', 'レブンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道目梨郡羅臼町松法町', '01', '01694', '0861835', '北海道', 'ホッカイドウ', '目梨郡羅臼町', 'メナシグンラウスチョウ', '松法町', 'マツノリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道目梨郡羅臼町知昭町', '01', '01694', '0861836', '北海道', 'ホッカイドウ', '目梨郡羅臼町', 'メナシグンラウスチョウ', '知昭町', 'チショウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道目梨郡羅臼町八木浜町', '01', '01694', '0861841', '北海道', 'ホッカイドウ', '目梨郡羅臼町', 'メナシグンラウスチョウ', '八木浜町', 'ヤギハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道目梨郡羅臼町麻布町', '01', '01694', '0861842', '北海道', 'ホッカイドウ', '目梨郡羅臼町', 'メナシグンラウスチョウ', '麻布町', 'アザブチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道目梨郡羅臼町春日町', '01', '01694', '0861843', '北海道', 'ホッカイドウ', '目梨郡羅臼町', 'メナシグンラウスチョウ', '春日町', 'カスガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道目梨郡羅臼町幌萌町', '01', '01694', '0861844', '北海道', 'ホッカイドウ', '目梨郡羅臼町', 'メナシグンラウスチョウ', '幌萌町', 'ホロモエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市東町', '43', '43201', '8620901', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '東町', 'ヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市東本町', '43', '43201', '8620902', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '東本町', 'ヒガシホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市若葉1丁目', '43', '43201', '8620903', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '若葉', 'ワカバ', null, null, '1丁目', '01チョウメ');
INSERT INTO `ms_addresses` VALUES ('111723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市若葉2丁目', '43', '43201', '8620903', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '若葉', 'ワカバ', null, null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('111724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市若葉3丁目', '43', '43201', '8620903', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '若葉', 'ワカバ', null, null, '3丁目', '03チョウメ');
INSERT INTO `ms_addresses` VALUES ('111725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市栄町', '43', '43201', '8620904', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市南町', '43', '43201', '8620905', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '南町', 'ミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市広木町', '43', '43201', '8620906', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '広木町', 'ヒロギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市水源', '43', '43201', '8620907', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '水源', 'スイゲン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市新生', '43', '43201', '8620908', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '新生', 'シンセイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市湖東', '43', '43201', '8620909', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '湖東', 'コトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市健軍本町', '43', '43201', '8620910', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '健軍本町', 'ケングンホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市健軍', '43', '43201', '8620911', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '健軍', 'ケングン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市錦ケ丘', '43', '43201', '8620912', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '錦ケ丘', 'ニシキガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市尾ノ上', '43', '43201', '8620913', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '尾ノ上', 'オノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市山ノ内', '43', '43201', '8620914', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '山ノ内', 'ヤマノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市山ノ神', '43', '43201', '8620915', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '山ノ神', 'ヤマノカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市佐土原', '43', '43201', '8620916', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '佐土原', 'サドワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市榎町', '43', '43201', '8620917', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '榎町', 'エノキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市花立5丁目', '43', '43201', '8620918', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '花立', 'ハナタテ', null, null, '5丁目', '05チョウメ');
INSERT INTO `ms_addresses` VALUES ('111740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市花立6丁目', '43', '43201', '8620918', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '花立', 'ハナタテ', null, null, '6丁目', '06チョウメ');
INSERT INTO `ms_addresses` VALUES ('111741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市月出', '43', '43201', '8620920', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '月出', 'ツキデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市新外', '43', '43201', '8620921', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '新外', 'シンホカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市三郎', '43', '43201', '8620922', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '三郎', 'サブロウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市東京塚町', '43', '43201', '8620923', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '東京塚町', 'ヒガシキョウヅカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市帯山', '43', '43201', '8620924', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '帯山', 'オビヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市保田窪本町', '43', '43201', '8620925', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '保田窪本町', 'ホタクボホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市保田窪', '43', '43201', '8620926', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '保田窪', 'ホタクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市小峯', '43', '43201', '8620933', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '小峯', 'オミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市出水', '43', '43201', '8620941', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '出水', 'イズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市江津', '43', '43201', '8620942', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '江津', 'エヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市画図町下江津', '43', '43201', '8620943', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '画図町下江津', 'エズマチシモエヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市画図町上無田', '43', '43201', '8620944', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '画図町上無田', 'エズマチカミムタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市画図町下無田', '43', '43201', '8620945', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '画図町下無田', 'エズマチシモムタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市画図町所島', '43', '43201', '8620946', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '画図町所島', 'エズマチトコロジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市画図町重富', '43', '43201', '8620947', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '画図町重富', 'エズマチシゲドミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市国府本町', '43', '43201', '8620948', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '国府本町', 'コクブホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市国府', '43', '43201', '8620949', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '国府', 'コクブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市水前寺', '43', '43201', '8620950', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '水前寺', 'スイゼンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市上水前寺', '43', '43201', '8620951', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '上水前寺', 'カミスイゼンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市京塚本町', '43', '43201', '8620952', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '京塚本町', 'キョウヅカホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市上京塚町', '43', '43201', '8620953', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '上京塚町', 'カミキョウヅカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市神水', '43', '43201', '8620954', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '神水', 'クワミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市神水本町', '43', '43201', '8620955', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '神水本町', 'クワミズホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市水前寺公園', '43', '43201', '8620956', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '水前寺公園', 'スイゼンジコウエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市菅原町', '43', '43201', '8620957', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '菅原町', 'スガワラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市岡田町', '43', '43201', '8620958', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '岡田町', 'オカダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市白山', '43', '43201', '8620959', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '白山', 'ハクザン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市下江津', '43', '43201', '8620960', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '下江津', 'シモエヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市画図東', '43', '43201', '8620961', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '画図東', 'エズヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市田迎', '43', '43201', '8620962', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '田迎', 'タムカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市出仲間', '43', '43201', '8620963', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '出仲間', 'イデナカマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市田井島', '43', '43201', '8620965', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '田井島', 'タイノシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市田迎町田井島', '43', '43201', '8620965', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '田迎町田井島', 'タムカエマチタイノシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市田迎町良町', '43', '43201', '8620966', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '田迎町良町', 'タムカエマチヤヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市流通団地', '43', '43201', '8620967', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '流通団地', 'リュウツウダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市馬渡', '43', '43201', '8620968', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '馬渡', 'マワタリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市良町', '43', '43201', '8620969', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '良町', 'ヤヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市渡鹿', '43', '43201', '8620970', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '渡鹿', 'トロク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市大江', '43', '43201', '8620971', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '大江', 'オオエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市新大江', '43', '43201', '8620972', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '新大江', 'シンオオエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市大江本町', '43', '43201', '8620973', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '大江本町', 'オオエホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市大江町渡鹿', '43', '43201', '8620974', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '大江町渡鹿', 'オオエマチトロク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市新屋敷', '43', '43201', '8620975', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '新屋敷', 'シンヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県熊本市九品寺', '43', '43201', '8620976', '熊本県', 'クマモトケン', '熊本市', 'クマモトシ', '九品寺', 'クホンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草市', '43', '43215', '8630000', '熊本県', 'クマモトケン', '天草市', 'アマクサシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('111821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草市本渡町広瀬', '43', '43215', '8630001', '熊本県', 'クマモトケン', '天草市', 'アマクサシ', '本渡町広瀬', 'ホンドマチヒロセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草市本渡町本戸馬場', '43', '43215', '8630002', '熊本県', 'クマモトケン', '天草市', 'アマクサシ', '本渡町本戸馬場', 'ホンドマチホントババ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草市本渡町本渡', '43', '43215', '8630003', '熊本県', 'クマモトケン', '天草市', 'アマクサシ', '本渡町本渡', 'ホンドマチホンド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草市本渡町本泉', '43', '43215', '8630004', '熊本県', 'クマモトケン', '天草市', 'アマクサシ', '本渡町本泉', 'ホンドマチモトイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草市本町新休', '43', '43215', '8630005', '熊本県', 'クマモトケン', '天草市', 'アマクサシ', '本町新休', 'ホンマチシンキュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草市本町下河内', '43', '43215', '8630006', '熊本県', 'クマモトケン', '天草市', 'アマクサシ', '本町下河内', 'ホンマチシモガワチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草市本町本', '43', '43215', '8630007', '熊本県', 'クマモトケン', '天草市', 'アマクサシ', '本町本', 'ホンマチホン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草市北浜町', '43', '43215', '8630011', '熊本県', 'クマモトケン', '天草市', 'アマクサシ', '北浜町', 'キタハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草市今釜町', '43', '43215', '8630012', '熊本県', 'クマモトケン', '天草市', 'アマクサシ', '今釜町', 'イマガママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草市今釜新町', '43', '43215', '8630013', '熊本県', 'クマモトケン', '天草市', 'アマクサシ', '今釜新町', 'イマガマシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草市東浜町', '43', '43215', '8630014', '熊本県', 'クマモトケン', '天草市', 'アマクサシ', '東浜町', 'ヒガシハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草市大浜町', '43', '43215', '8630015', '熊本県', 'クマモトケン', '天草市', 'アマクサシ', '大浜町', 'オオハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草市城下町', '43', '43215', '8630016', '熊本県', 'クマモトケン', '天草市', 'アマクサシ', '城下町', 'ジョウカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草市船之尾町', '43', '43215', '8630017', '熊本県', 'クマモトケン', '天草市', 'アマクサシ', '船之尾町', 'フネノオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草市浜崎町', '43', '43215', '8630018', '熊本県', 'クマモトケン', '天草市', 'アマクサシ', '浜崎町', 'ハマサキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草市小松原町', '43', '43215', '8630019', '熊本県', 'クマモトケン', '天草市', 'アマクサシ', '小松原町', 'コマツバラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草市港町', '43', '43215', '8630021', '熊本県', 'クマモトケン', '天草市', 'アマクサシ', '港町', 'ミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草市栄町', '43', '43215', '8630022', '熊本県', 'クマモトケン', '天草市', 'アマクサシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草市中央新町', '43', '43215', '8630023', '熊本県', 'クマモトケン', '天草市', 'アマクサシ', '中央新町', 'チュウオウシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草市川原町', '43', '43215', '8630024', '熊本県', 'クマモトケン', '天草市', 'アマクサシ', '川原町', 'カワラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草市古川町', '43', '43215', '8630025', '熊本県', 'クマモトケン', '天草市', 'アマクサシ', '古川町', 'フルカワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草市南新町', '43', '43215', '8630031', '熊本県', 'クマモトケン', '天草市', 'アマクサシ', '南新町', 'ミナミシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草市太田町', '43', '43215', '8630032', '熊本県', 'クマモトケン', '天草市', 'アマクサシ', '太田町', 'オオタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草市東町', '43', '43215', '8630033', '熊本県', 'クマモトケン', '天草市', 'アマクサシ', '東町', 'ヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草市浄南町', '43', '43215', '8630034', '熊本県', 'クマモトケン', '天草市', 'アマクサシ', '浄南町', 'ジョウナンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草市山の手町', '43', '43215', '8630035', '熊本県', 'クマモトケン', '天草市', 'アマクサシ', '山の手町', 'ヤマノテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草市川原新町', '43', '43215', '8630036', '熊本県', 'クマモトケン', '天草市', 'アマクサシ', '川原新町', 'カワラシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草市諏訪町', '43', '43215', '8630037', '熊本県', 'クマモトケン', '天草市', 'アマクサシ', '諏訪町', 'スワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草市南町', '43', '43215', '8630038', '熊本県', 'クマモトケン', '天草市', 'アマクサシ', '南町', 'ミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草市志柿町', '43', '43215', '8630041', '熊本県', 'クマモトケン', '天草市', 'アマクサシ', '志柿町', 'シカキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草市瀬戸町', '43', '43215', '8630042', '熊本県', 'クマモトケン', '天草市', 'アマクサシ', '瀬戸町', 'セドマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草市亀場町亀川', '43', '43215', '8630043', '熊本県', 'クマモトケン', '天草市', 'アマクサシ', '亀場町亀川', 'カメバマチカメガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草市楠浦町', '43', '43215', '8630044', '熊本県', 'クマモトケン', '天草市', 'アマクサシ', '楠浦町', 'クスウラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草市枦宇土町', '43', '43215', '8630045', '熊本県', 'クマモトケン', '天草市', 'アマクサシ', '枦宇土町', 'ハジウトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草市亀場町食場', '43', '43215', '8630046', '熊本県', 'クマモトケン', '天草市', 'アマクサシ', '亀場町食場', 'カメバマチジキバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草市八幡町', '43', '43215', '8630047', '熊本県', 'クマモトケン', '天草市', 'アマクサシ', '八幡町', 'ハチマンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草市中村町', '43', '43215', '8630048', '熊本県', 'クマモトケン', '天草市', 'アマクサシ', '中村町', 'ナカムラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草市北原町', '43', '43215', '8630049', '熊本県', 'クマモトケン', '天草市', 'アマクサシ', '北原町', 'キタハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草市丸尾町', '43', '43215', '8630050', '熊本県', 'クマモトケン', '天草市', 'アマクサシ', '丸尾町', 'マルオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草市新和町小宮地', '43', '43215', '8630101', '熊本県', 'クマモトケン', '天草市', 'アマクサシ', '新和町小宮地', 'シンワマチコミヤジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草市新和町大多尾', '43', '43215', '8630102', '熊本県', 'クマモトケン', '天草市', 'アマクサシ', '新和町大多尾', 'シンワマチオオタオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草市新和町大宮地', '43', '43215', '8630103', '熊本県', 'クマモトケン', '天草市', 'アマクサシ', '新和町大宮地', 'シンワマチオオミヤジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草市新和町碇石', '43', '43215', '8631111', '熊本県', 'クマモトケン', '天草市', 'アマクサシ', '新和町碇石', 'シンワマチイカリイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草市新和町中田', '43', '43215', '8631112', '熊本県', 'クマモトケン', '天草市', 'アマクサシ', '新和町中田', 'シンワマチナカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草市宮地岳町', '43', '43215', '8631161', '熊本県', 'クマモトケン', '天草市', 'アマクサシ', '宮地岳町', 'ミヤジダケマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草市河浦町今田', '43', '43215', '8631201', '熊本県', 'クマモトケン', '天草市', 'アマクサシ', '河浦町今田', 'カワウラマチイマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草市河浦町河浦', '43', '43215', '8631202', '熊本県', 'クマモトケン', '天草市', 'アマクサシ', '河浦町河浦', 'カワウラマチカワウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草市河浦町今富', '43', '43215', '8631203', '熊本県', 'クマモトケン', '天草市', 'アマクサシ', '河浦町今富', 'カワウラマチイマトミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草市河浦町崎津', '43', '43215', '8631204', '熊本県', 'クマモトケン', '天草市', 'アマクサシ', '河浦町崎津', 'カワウラマチサキツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草市天草町高浜北', '43', '43215', '8631205', '熊本県', 'クマモトケン', '天草市', 'アマクサシ', '天草町高浜北', 'アマクサマチタカハマキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草市河浦町立原', '43', '43215', '8631211', '熊本県', 'クマモトケン', '天草市', 'アマクサシ', '河浦町立原', 'カワウラマチタチハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草市河浦町宮野河内', '43', '43215', '8631212', '熊本県', 'クマモトケン', '天草市', 'アマクサシ', '河浦町宮野河内', 'カワウラマチミヤノカワチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草市河浦町路木', '43', '43215', '8631213', '熊本県', 'クマモトケン', '天草市', 'アマクサシ', '河浦町路木', 'カワウラマチロギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草市河浦町久留', '43', '43215', '8631214', '熊本県', 'クマモトケン', '天草市', 'アマクサシ', '河浦町久留', 'カワウラマチヒサドメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草市河浦町白木河内', '43', '43215', '8631215', '熊本県', 'クマモトケン', '天草市', 'アマクサシ', '河浦町白木河内', 'カワウラマチシラキカワチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草市河浦町新合', '43', '43215', '8631216', '熊本県', 'クマモトケン', '天草市', 'アマクサシ', '河浦町新合', 'カワウラマチシンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草市天草町大江向', '43', '43215', '8631401', '熊本県', 'クマモトケン', '天草市', 'アマクサシ', '天草町大江向', 'アマクサマチオオエムコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草市河浦町今富', '43', '43215', '8631403', '熊本県', 'クマモトケン', '天草市', 'アマクサシ', '河浦町今富', 'カワウラマチイマトミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草市河浦町崎津', '43', '43215', '8631404', '熊本県', 'クマモトケン', '天草市', 'アマクサシ', '河浦町崎津', 'カワウラマチサキツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草市二浦町早浦', '43', '43215', '8631431', '熊本県', 'クマモトケン', '天草市', 'アマクサシ', '二浦町早浦', 'フタウラマチハヤウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草市二浦町亀浦', '43', '43215', '8631432', '熊本県', 'クマモトケン', '天草市', 'アマクサシ', '二浦町亀浦', 'フタウラマチカメウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草市深海町', '43', '43215', '8631511', '熊本県', 'クマモトケン', '天草市', 'アマクサシ', '深海町', 'フカミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草市魚貫町', '43', '43215', '8631721', '熊本県', 'クマモトケン', '天草市', 'アマクサシ', '魚貫町', 'オニキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草市牛深町', '43', '43215', '8631901', '熊本県', 'クマモトケン', '天草市', 'アマクサシ', '牛深町', 'ウシブカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草市久玉町', '43', '43215', '8631902', '熊本県', 'クマモトケン', '天草市', 'アマクサシ', '久玉町', 'クタママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草市五和町城河原', '43', '43215', '8632114', '熊本県', 'クマモトケン', '天草市', 'アマクサシ', '五和町城河原', 'イツワマチジョウガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草市佐伊津町', '43', '43215', '8632171', '熊本県', 'クマモトケン', '天草市', 'アマクサシ', '佐伊津町', 'サイツマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草市旭町', '43', '43215', '8632172', '熊本県', 'クマモトケン', '天草市', 'アマクサシ', '旭町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草市五和町御領', '43', '43215', '8632201', '熊本県', 'クマモトケン', '天草市', 'アマクサシ', '五和町御領', 'イツワマチゴリョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草市五和町御領大島', '43', '43215', '8632301', '熊本県', 'クマモトケン', '天草市', 'アマクサシ', '五和町御領', 'イツワマチゴリョウ', null, null, '大島', 'オオシマ');
INSERT INTO `ms_addresses` VALUES ('111893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草市五和町鬼池', '43', '43215', '8632331', '熊本県', 'クマモトケン', '天草市', 'アマクサシ', '五和町鬼池', 'イツワマチオニイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草市五和町二江', '43', '43215', '8632421', '熊本県', 'クマモトケン', '天草市', 'アマクサシ', '五和町二江', 'イツワマチフタエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草市五和町手野', '43', '43215', '8632424', '熊本県', 'クマモトケン', '天草市', 'アマクサシ', '五和町手野', 'イツワマチテノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草郡苓北町', '43', '43531', '8632500', '熊本県', 'クマモトケン', '天草郡苓北町', 'アマクサグンレイホクマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('111897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草郡苓北町坂瀬川', '43', '43531', '8632501', '熊本県', 'クマモトケン', '天草郡苓北町', 'アマクサグンレイホクマチ', '坂瀬川', 'サカセガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草郡苓北町上津深江', '43', '43531', '8632502', '熊本県', 'クマモトケン', '天草郡苓北町', 'アマクサグンレイホクマチ', '上津深江', 'コウツフカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草郡苓北町志岐', '43', '43531', '8632503', '熊本県', 'クマモトケン', '天草郡苓北町', 'アマクサグンレイホクマチ', '志岐', 'シキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草郡苓北町年柄', '43', '43531', '8632504', '熊本県', 'クマモトケン', '天草郡苓北町', 'アマクサグンレイホクマチ', '年柄', 'トシカラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草郡苓北町内田', '43', '43531', '8632505', '熊本県', 'クマモトケン', '天草郡苓北町', 'アマクサグンレイホクマチ', '内田', 'ウチダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草郡苓北町白木尾', '43', '43531', '8632506', '熊本県', 'クマモトケン', '天草郡苓北町', 'アマクサグンレイホクマチ', '白木尾', 'シラキオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草郡苓北町富岡', '43', '43531', '8632507', '熊本県', 'クマモトケン', '天草郡苓北町', 'アマクサグンレイホクマチ', '富岡', 'トミオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草郡苓北町都呂々', '43', '43531', '8632611', '熊本県', 'クマモトケン', '天草郡苓北町', 'アマクサグンレイホクマチ', '都呂々', 'トロロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草市天草町大江', '43', '43215', '8632801', '熊本県', 'クマモトケン', '天草市', 'アマクサシ', '天草町大江', 'アマクサマチオオエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草市天草町大江軍浦', '43', '43215', '8632801', '熊本県', 'クマモトケン', '天草市', 'アマクサシ', '天草町大江軍浦', 'アマクサマチオオエイクサガウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草市天草町下田南', '43', '43215', '8632802', '熊本県', 'クマモトケン', '天草市', 'アマクサシ', '天草町下田南', 'アマクサマチシモダミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草市天草町下田北', '43', '43215', '8632803', '熊本県', 'クマモトケン', '天草市', 'アマクサシ', '天草町下田北', 'アマクサマチシモダキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草市天草町高浜南', '43', '43215', '8632804', '熊本県', 'クマモトケン', '天草市', 'アマクサシ', '天草町高浜南', 'アマクサマチタカハマミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草市天草町高浜北', '43', '43215', '8632805', '熊本県', 'クマモトケン', '天草市', 'アマクサシ', '天草町高浜北', 'アマクサマチタカハマキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草市天草町福連木', '43', '43215', '8632806', '熊本県', 'クマモトケン', '天草市', 'アマクサシ', '天草町福連木', 'アマクサマチフクレギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県荒尾市', '43', '43204', '8640000', '熊本県', 'クマモトケン', '荒尾市', 'アラオシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('111918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県荒尾市原万田', '43', '43204', '8640001', '熊本県', 'クマモトケン', '荒尾市', 'アラオシ', '原万田', 'ハラマンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県荒尾市万田', '43', '43204', '8640002', '熊本県', 'クマモトケン', '荒尾市', 'アラオシ', '万田', 'マンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県荒尾市宮内出目', '43', '43204', '8640003', '熊本県', 'クマモトケン', '荒尾市', 'アラオシ', '宮内出目', 'クナイデメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県荒尾市宮内', '43', '43204', '8640004', '熊本県', 'クマモトケン', '荒尾市', 'アラオシ', '宮内', 'クナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県荒尾市大平町', '43', '43204', '8640005', '熊本県', 'クマモトケン', '荒尾市', 'アラオシ', '大平町', 'オオヒラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県荒尾市住吉町', '43', '43204', '8640006', '熊本県', 'クマモトケン', '荒尾市', 'アラオシ', '住吉町', 'スミヨシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県荒尾市下井手', '43', '43204', '8640011', '熊本県', 'クマモトケン', '荒尾市', 'アラオシ', '下井手', 'シモイデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県荒尾市本井手', '43', '43204', '8640012', '熊本県', 'クマモトケン', '荒尾市', 'アラオシ', '本井手', 'ホンイデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県荒尾市上井手', '43', '43204', '8640013', '熊本県', 'クマモトケン', '荒尾市', 'アラオシ', '上井手', 'カミイデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県荒尾市上平山', '43', '43204', '8640014', '熊本県', 'クマモトケン', '荒尾市', 'アラオシ', '上平山', 'カミヒラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県荒尾市平山', '43', '43204', '8640015', '熊本県', 'クマモトケン', '荒尾市', 'アラオシ', '平山', 'ヒラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県荒尾市一部', '43', '43204', '8640021', '熊本県', 'クマモトケン', '荒尾市', 'アラオシ', '一部', 'イチブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県荒尾市桜山町', '43', '43204', '8640022', '熊本県', 'クマモトケン', '荒尾市', 'アラオシ', '桜山町', 'サクラヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県荒尾市水野', '43', '43204', '8640023', '熊本県', 'クマモトケン', '荒尾市', 'アラオシ', '水野', 'ミズノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県荒尾市高浜', '43', '43204', '8640025', '熊本県', 'クマモトケン', '荒尾市', 'アラオシ', '高浜', 'タカハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県荒尾市牛水', '43', '43204', '8640026', '熊本県', 'クマモトケン', '荒尾市', 'アラオシ', '牛水', 'ウシノミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県荒尾市蔵満', '43', '43204', '8640027', '熊本県', 'クマモトケン', '荒尾市', 'アラオシ', '蔵満', 'クラミツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県荒尾市川登', '43', '43204', '8640031', '熊本県', 'クマモトケン', '荒尾市', 'アラオシ', '川登', 'カワノボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県荒尾市増永', '43', '43204', '8640032', '熊本県', 'クマモトケン', '荒尾市', 'アラオシ', '増永', 'マスナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県荒尾市緑ケ丘', '43', '43204', '8640033', '熊本県', 'クマモトケン', '荒尾市', 'アラオシ', '緑ケ丘', 'ミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県荒尾市荒尾', '43', '43204', '8640041', '熊本県', 'クマモトケン', '荒尾市', 'アラオシ', '荒尾', 'アラオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県荒尾市東屋形', '43', '43204', '8640042', '熊本県', 'クマモトケン', '荒尾市', 'アラオシ', '東屋形', 'ヒガシヤカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県荒尾市大島町', '43', '43204', '8640051', '熊本県', 'クマモトケン', '荒尾市', 'アラオシ', '大島町', 'オオシママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県荒尾市四ツ山町', '43', '43204', '8640052', '熊本県', 'クマモトケン', '荒尾市', 'アラオシ', '四ツ山町', 'ヨツヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県荒尾市西原町', '43', '43204', '8640053', '熊本県', 'クマモトケン', '荒尾市', 'アラオシ', '西原町', 'ニシバルマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県荒尾市大正町', '43', '43204', '8640054', '熊本県', 'クマモトケン', '荒尾市', 'アラオシ', '大正町', 'タイショウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県荒尾市日の出町', '43', '43204', '8640055', '熊本県', 'クマモトケン', '荒尾市', 'アラオシ', '日の出町', 'ヒノデマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県荒尾市昭和町', '43', '43204', '8640056', '熊本県', 'クマモトケン', '荒尾市', 'アラオシ', '昭和町', 'ショウワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県荒尾市大島', '43', '43204', '8640057', '熊本県', 'クマモトケン', '荒尾市', 'アラオシ', '大島', 'オオシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県荒尾市川登', '43', '43204', '8640131', '熊本県', 'クマモトケン', '荒尾市', 'アラオシ', '川登', 'カワノボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県荒尾市菰屋', '43', '43204', '8640161', '熊本県', 'クマモトケン', '荒尾市', 'アラオシ', '菰屋', 'コモヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県荒尾市金山', '43', '43204', '8640162', '熊本県', 'クマモトケン', '荒尾市', 'アラオシ', '金山', 'カナヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県荒尾市野原', '43', '43204', '8640163', '熊本県', 'クマモトケン', '荒尾市', 'アラオシ', '野原', 'ノバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県荒尾市八幡台', '43', '43204', '8640164', '熊本県', 'クマモトケン', '荒尾市', 'アラオシ', '八幡台', 'ハチマンダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県荒尾市樺', '43', '43204', '8640165', '熊本県', 'クマモトケン', '荒尾市', 'アラオシ', '樺', 'カバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県荒尾市府本', '43', '43204', '8640166', '熊本県', 'クマモトケン', '荒尾市', 'アラオシ', '府本', 'フモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名市', '43', '43206', '8650000', '熊本県', 'クマモトケン', '玉名市', 'タマナシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('111958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名市月田', '43', '43206', '8650001', '熊本県', 'クマモトケン', '玉名市', 'タマナシ', '月田', 'ツキダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名市箱谷', '43', '43206', '8650002', '熊本県', 'クマモトケン', '玉名市', 'タマナシ', '箱谷', 'ハコダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名市溝上', '43', '43206', '8650003', '熊本県', 'クマモトケン', '玉名市', 'タマナシ', '溝上', 'ミゾノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名市青木', '43', '43206', '8650004', '熊本県', 'クマモトケン', '玉名市', 'タマナシ', '青木', 'アオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名市玉名', '43', '43206', '8650005', '熊本県', 'クマモトケン', '玉名市', 'タマナシ', '玉名', 'タマナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名市両迫間', '43', '43206', '8650006', '熊本県', 'クマモトケン', '玉名市', 'タマナシ', '両迫間', 'リョウハザマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名市河崎', '43', '43206', '8650007', '熊本県', 'クマモトケン', '玉名市', 'タマナシ', '河崎', 'カワサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名市石貫', '43', '43206', '8650008', '熊本県', 'クマモトケン', '玉名市', 'タマナシ', '石貫', 'イシヌキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名市三ツ川', '43', '43206', '8650009', '熊本県', 'クマモトケン', '玉名市', 'タマナシ', '三ツ川', 'ミツカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名市上小田', '43', '43206', '8650011', '熊本県', 'クマモトケン', '玉名市', 'タマナシ', '上小田', 'カミオダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名市山部田', '43', '43206', '8650012', '熊本県', 'クマモトケン', '玉名市', 'タマナシ', '山部田', 'ヤマベタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名市下', '43', '43206', '8650013', '熊本県', 'クマモトケン', '玉名市', 'タマナシ', '下', 'シモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名市安楽寺', '43', '43206', '8650014', '熊本県', 'クマモトケン', '玉名市', 'タマナシ', '安楽寺', 'アンラクジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名市亀甲', '43', '43206', '8650015', '熊本県', 'クマモトケン', '玉名市', 'タマナシ', '亀甲', 'カメノコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名市岩崎', '43', '43206', '8650016', '熊本県', 'クマモトケン', '玉名市', 'タマナシ', '岩崎', 'イワサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名市川部田', '43', '43206', '8650017', '熊本県', 'クマモトケン', '玉名市', 'タマナシ', '川部田', 'カワベタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名市下小田', '43', '43206', '8650018', '熊本県', 'クマモトケン', '玉名市', 'タマナシ', '下小田', 'シモオダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名市津留', '43', '43206', '8650021', '熊本県', 'クマモトケン', '玉名市', 'タマナシ', '津留', 'ツル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名市寺田', '43', '43206', '8650022', '熊本県', 'クマモトケン', '玉名市', 'タマナシ', '寺田', 'テラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名市大倉', '43', '43206', '8650023', '熊本県', 'クマモトケン', '玉名市', 'タマナシ', '大倉', 'オオクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名市永徳寺', '43', '43206', '8650024', '熊本県', 'クマモトケン', '玉名市', 'タマナシ', '永徳寺', 'エイトクジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名市高瀬', '43', '43206', '8650025', '熊本県', 'クマモトケン', '玉名市', 'タマナシ', '高瀬', 'タカセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名市秋丸', '43', '43206', '8650026', '熊本県', 'クマモトケン', '玉名市', 'タマナシ', '秋丸', 'アキマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名市向津留', '43', '43206', '8650027', '熊本県', 'クマモトケン', '玉名市', 'タマナシ', '向津留', 'ムコウヅル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名市田崎', '43', '43206', '8650031', '熊本県', 'クマモトケン', '玉名市', 'タマナシ', '田崎', 'タサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名市北坂門田', '43', '43206', '8650032', '熊本県', 'クマモトケン', '玉名市', 'タマナシ', '北坂門田', 'キタサカモンタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名市中坂門田', '43', '43206', '8650033', '熊本県', 'クマモトケン', '玉名市', 'タマナシ', '中坂門田', 'ナカサカモンタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名市南坂門田', '43', '43206', '8650034', '熊本県', 'クマモトケン', '玉名市', 'タマナシ', '南坂門田', 'ミナミサカモンタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名市青野', '43', '43206', '8650035', '熊本県', 'クマモトケン', '玉名市', 'タマナシ', '青野', 'アオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名市伊倉北方', '43', '43206', '8650041', '熊本県', 'クマモトケン', '玉名市', 'タマナシ', '伊倉北方', 'イクラキタカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名市宮原', '43', '43206', '8650042', '熊本県', 'クマモトケン', '玉名市', 'タマナシ', '宮原', 'ミヤバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名市横田', '43', '43206', '8650043', '熊本県', 'クマモトケン', '玉名市', 'タマナシ', '横田', 'ヨコタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名市片諏訪', '43', '43206', '8650044', '熊本県', 'クマモトケン', '玉名市', 'タマナシ', '片諏訪', 'カタスワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名市伊倉南方', '43', '43206', '8650045', '熊本県', 'クマモトケン', '玉名市', 'タマナシ', '伊倉南方', 'イクラミナミカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名市北牟田', '43', '43206', '8650046', '熊本県', 'クマモトケン', '玉名市', 'タマナシ', '北牟田', 'キタムタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名市川島', '43', '43206', '8650047', '熊本県', 'クマモトケン', '玉名市', 'タマナシ', '川島', 'カワシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名市小野尻', '43', '43206', '8650048', '熊本県', 'クマモトケン', '玉名市', 'タマナシ', '小野尻', 'オノジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名市繁根木', '43', '43206', '8650051', '熊本県', 'クマモトケン', '玉名市', 'タマナシ', '繁根木', 'ハネギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名市松木', '43', '43206', '8650052', '熊本県', 'クマモトケン', '玉名市', 'タマナシ', '松木', 'マツキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名市千田川原', '43', '43206', '8650053', '熊本県', 'クマモトケン', '玉名市', 'タマナシ', '千田川原', 'センダガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名市小島', '43', '43206', '8650054', '熊本県', 'クマモトケン', '玉名市', 'タマナシ', '小島', 'オシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('111999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名市大浜町', '43', '43206', '8650055', '熊本県', 'クマモトケン', '玉名市', 'タマナシ', '大浜町', 'オオハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名市滑石', '43', '43206', '8650056', '熊本県', 'クマモトケン', '玉名市', 'タマナシ', '滑石', 'ナメイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名市小浜', '43', '43206', '8650057', '熊本県', 'クマモトケン', '玉名市', 'タマナシ', '小浜', 'コバマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名市六田', '43', '43206', '8650058', '熊本県', 'クマモトケン', '玉名市', 'タマナシ', '六田', 'ロクタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名市立願寺', '43', '43206', '8650061', '熊本県', 'クマモトケン', '玉名市', 'タマナシ', '立願寺', 'リュウガンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名市富尾', '43', '43206', '8650062', '熊本県', 'クマモトケン', '玉名市', 'タマナシ', '富尾', 'トミノオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名市中尾', '43', '43206', '8650063', '熊本県', 'クマモトケン', '玉名市', 'タマナシ', '中尾', 'ナカオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名市中', '43', '43206', '8650064', '熊本県', 'クマモトケン', '玉名市', 'タマナシ', '中', 'ナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名市築地', '43', '43206', '8650065', '熊本県', 'クマモトケン', '玉名市', 'タマナシ', '築地', 'ツイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名市山田', '43', '43206', '8650066', '熊本県', 'クマモトケン', '玉名市', 'タマナシ', '山田', 'ヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名市横島町大園', '43', '43206', '8650071', '熊本県', 'クマモトケン', '玉名市', 'タマナシ', '横島町大園', 'ヨコシママチオオゾノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名市横島町横島', '43', '43206', '8650072', '熊本県', 'クマモトケン', '玉名市', 'タマナシ', '横島町横島', 'ヨコシママチヨコシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名市横島町共栄', '43', '43206', '8650073', '熊本県', 'クマモトケン', '玉名市', 'タマナシ', '横島町共栄', 'ヨコシママチキョウエイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名郡和水町', '43', '43369', '8650100', '熊本県', 'クマモトケン', '玉名郡和水町', 'タマナグンナゴミマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('112013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名郡和水町江栗', '43', '43369', '8650101', '熊本県', 'クマモトケン', '玉名郡和水町', 'タマナグンナゴミマチ', '江栗', 'エグリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名郡和水町久井原', '43', '43369', '8650102', '熊本県', 'クマモトケン', '玉名郡和水町', 'タマナグンナゴミマチ', '久井原', 'ヒサイバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名郡和水町長小田', '43', '43369', '8650103', '熊本県', 'クマモトケン', '玉名郡和水町', 'タマナグンナゴミマチ', '長小田', 'ナガオダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名郡和水町内田', '43', '43369', '8650104', '熊本県', 'クマモトケン', '玉名郡和水町', 'タマナグンナゴミマチ', '内田', 'ウチダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名郡和水町下津原', '43', '43369', '8650111', '熊本県', 'クマモトケン', '玉名郡和水町', 'タマナグンナゴミマチ', '下津原', 'シモツワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名郡和水町大屋', '43', '43369', '8650112', '熊本県', 'クマモトケン', '玉名郡和水町', 'タマナグンナゴミマチ', '大屋', 'オオヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名郡和水町焼米', '43', '43369', '8650113', '熊本県', 'クマモトケン', '玉名郡和水町', 'タマナグンナゴミマチ', '焼米', 'ヤイゴメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名郡和水町岩尻', '43', '43369', '8650114', '熊本県', 'クマモトケン', '玉名郡和水町', 'タマナグンナゴミマチ', '岩尻', 'イワシリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名郡和水町久米野', '43', '43369', '8650115', '熊本県', 'クマモトケン', '玉名郡和水町', 'タマナグンナゴミマチ', '久米野', 'クベノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名郡和水町竈門', '43', '43369', '8650116', '熊本県', 'クマモトケン', '玉名郡和水町', 'タマナグンナゴミマチ', '竈門', 'カマド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名郡和水町志口永', '43', '43369', '8650117', '熊本県', 'クマモトケン', '玉名郡和水町', 'タマナグンナゴミマチ', '志口永', 'シグチナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名郡和水町榎原', '43', '43369', '8650121', '熊本県', 'クマモトケン', '玉名郡和水町', 'タマナグンナゴミマチ', '榎原', 'エノキバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名郡和水町高野', '43', '43369', '8650122', '熊本県', 'クマモトケン', '玉名郡和水町', 'タマナグンナゴミマチ', '高野', 'タカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名郡和水町米渡尾', '43', '43369', '8650123', '熊本県', 'クマモトケン', '玉名郡和水町', 'タマナグンナゴミマチ', '米渡尾', 'メドオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名郡和水町原口', '43', '43369', '8650124', '熊本県', 'クマモトケン', '玉名郡和水町', 'タマナグンナゴミマチ', '原口', 'ハルグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名郡和水町藤田', '43', '43369', '8650125', '熊本県', 'クマモトケン', '玉名郡和水町', 'タマナグンナゴミマチ', '藤田', 'フジタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名郡和水町前原', '43', '43369', '8650126', '熊本県', 'クマモトケン', '玉名郡和水町', 'タマナグンナゴミマチ', '前原', 'マエバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名郡和水町用木', '43', '43369', '8650131', '熊本県', 'クマモトケン', '玉名郡和水町', 'タマナグンナゴミマチ', '用木', 'モテギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名郡和水町萩原', '43', '43369', '8650132', '熊本県', 'クマモトケン', '玉名郡和水町', 'タマナグンナゴミマチ', '萩原', 'ハギワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名郡和水町蜻浦', '43', '43369', '8650133', '熊本県', 'クマモトケン', '玉名郡和水町', 'タマナグンナゴミマチ', '蜻浦', 'ヘボウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名郡和水町日平', '43', '43369', '8650134', '熊本県', 'クマモトケン', '玉名郡和水町', 'タマナグンナゴミマチ', '日平', 'ヒビラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名郡和水町瀬川', '43', '43369', '8650135', '熊本県', 'クマモトケン', '玉名郡和水町', 'タマナグンナゴミマチ', '瀬川', 'セガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名郡和水町江田', '43', '43369', '8650136', '熊本県', 'クマモトケン', '玉名郡和水町', 'タマナグンナゴミマチ', '江田', 'エタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市', '43', '43202', '8660000', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('112046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市郡築十二番町', '43', '43202', '8660001', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '郡築十二番町', 'グンチク12バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市郡築十一番町', '43', '43202', '8660002', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '郡築十一番町', 'グンチク11バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市郡築十番町', '43', '43202', '8660003', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '郡築十番町', 'グンチク10バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市郡築九番町', '43', '43202', '8660004', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '郡築九番町', 'グンチク09バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市郡築八番町', '43', '43202', '8660005', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '郡築八番町', 'グンチク08バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市郡築七番町', '43', '43202', '8660006', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '郡築七番町', 'グンチク07バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市郡築六番町', '43', '43202', '8660007', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '郡築六番町', 'グンチク06バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市郡築五番町', '43', '43202', '8660008', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '郡築五番町', 'グンチク05バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市井揚町', '43', '43202', '8660011', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '井揚町', 'イアゲマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市高小原町', '43', '43202', '8660012', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '高小原町', 'コウゴバラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市沖町', '43', '43202', '8660013', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '沖町', 'オキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市高島町', '43', '43202', '8660014', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '高島町', 'タカシママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市築添町', '43', '43202', '8660015', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '築添町', 'ツキゾエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市新地町', '43', '43202', '8660016', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '新地町', 'シンチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市三楽町', '43', '43202', '8660017', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '三楽町', 'サンラクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市郡築四番町', '43', '43202', '8660021', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '郡築四番町', 'グンチク04バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市郡築三番町', '43', '43202', '8660022', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '郡築三番町', 'グンチク03バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市郡築二番町', '43', '43202', '8660023', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '郡築二番町', 'グンチク02バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市郡築一番町', '43', '43202', '8660024', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '郡築一番町', 'グンチク01バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市新浜町', '43', '43202', '8660031', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '新浜町', 'シンハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市新開町', '43', '43202', '8660032', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '新開町', 'シンカイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市港町', '43', '43202', '8660033', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '港町', 'ミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市新港町', '43', '43202', '8660034', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '新港町', 'シンミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市大島町', '43', '43202', '8660035', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '大島町', 'オオシママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市八幡町', '43', '43202', '8660041', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '八幡町', 'ハチマンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市蛇籠町', '43', '43202', '8660042', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '蛇籠町', 'ジャカゴマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市古城町', '43', '43202', '8660043', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '古城町', 'フルシロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市中北町', '43', '43202', '8660044', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '中北町', 'ナカキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市建馬町', '43', '43202', '8660045', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '建馬町', 'タテウママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市麦島東町', '43', '43202', '8660051', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '麦島東町', 'ムギシマヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市麦島西町', '43', '43202', '8660052', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '麦島西町', 'ムギシマニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市千反町', '43', '43202', '8660053', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '千反町', 'センダンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市栴檀町', '43', '43202', '8660054', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '栴檀町', 'センダンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市迎町', '43', '43202', '8660055', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '迎町', 'ムカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市渡町', '43', '43202', '8660061', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '渡町', 'ワタシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市豊原中町', '43', '43202', '8660062', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '豊原中町', 'ブイワラナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市豊原上町', '43', '43202', '8660063', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '豊原上町', 'ブイワラカミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市奈良木町', '43', '43202', '8660064', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '奈良木町', 'ナラギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市豊原下町', '43', '43202', '8660065', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '豊原下町', 'ブイワラシモマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市高下東町', '43', '43202', '8660071', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '高下東町', 'コウゲヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市高下西町', '43', '43202', '8660072', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '高下西町', 'コウゲニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市本野町', '43', '43202', '8660073', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '本野町', 'ホンノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市平山新町', '43', '43202', '8660074', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '平山新町', 'ヒラヤマシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市植柳上町', '43', '43202', '8660081', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '植柳上町', 'ウヤナギカミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市大福寺町', '43', '43202', '8660082', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '大福寺町', 'ダイフクジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市植柳下町', '43', '43202', '8660083', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '植柳下町', 'ウヤナギシモマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市植柳新町', '43', '43202', '8660084', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '植柳新町', 'ウヤナギシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市植柳元町', '43', '43202', '8660085', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '植柳元町', 'ウヤナギモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上天草市姫戸町姫浦', '43', '43212', '8660101', '熊本県', 'クマモトケン', '上天草市', 'カミアマクサシ', '姫戸町姫浦', 'ヒメドマチヒメウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上天草市姫戸町二間戸', '43', '43212', '8660102', '熊本県', 'クマモトケン', '上天草市', 'カミアマクサシ', '姫戸町二間戸', 'ヒメドマチフタマド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上天草市龍ケ岳町大道', '43', '43212', '8660201', '熊本県', 'クマモトケン', '上天草市', 'カミアマクサシ', '龍ケ岳町大道', 'リュウガタケマチオオドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上天草市龍ケ岳町高戸', '43', '43212', '8660202', '熊本県', 'クマモトケン', '上天草市', 'カミアマクサシ', '龍ケ岳町高戸', 'リュウガタケマチタカド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上天草市龍ケ岳町樋島', '43', '43212', '8660203', '熊本県', 'クマモトケン', '上天草市', 'カミアマクサシ', '龍ケ岳町樋島', 'リュウガタケマチヒノシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草市御所浦町横浦', '43', '43215', '8660303', '熊本県', 'クマモトケン', '天草市', 'アマクサシ', '御所浦町横浦', 'ゴショウラマチヨコウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草市御所浦町御所浦', '43', '43215', '8660313', '熊本県', 'クマモトケン', '天草市', 'アマクサシ', '御所浦町御所浦', 'ゴショウラマチゴショウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県天草市御所浦町牧島', '43', '43215', '8660334', '熊本県', 'クマモトケン', '天草市', 'アマクサシ', '御所浦町牧島', 'ゴショウラマチマキシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市東町', '43', '43202', '8660801', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '東町', 'ヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市妙見町', '43', '43202', '8660802', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '妙見町', 'ミョウケンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市古麓町', '43', '43202', '8660803', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '古麓町', 'フルフモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市西宮町', '43', '43202', '8660804', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '西宮町', 'ニシミヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市宮地町', '43', '43202', '8660805', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '宮地町', 'ミヤジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市西片町', '43', '43202', '8660811', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '西片町', 'ニシカタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市中片町', '43', '43202', '8660812', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '中片町', 'ナカカタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市上片町', '43', '43202', '8660813', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '上片町', 'カミカタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市東片町', '43', '43202', '8660814', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '東片町', 'ヒガシカタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市長田町', '43', '43202', '8660815', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '長田町', 'ナガタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市福正町', '43', '43202', '8660821', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '福正町', 'フクショウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市福正元町', '43', '43202', '8660822', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '福正元町', 'フクショウモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市十条町', '43', '43202', '8660823', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '十条町', 'ジュウジョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市上日置町', '43', '43202', '8660824', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '上日置町', 'カミヒオキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市井上町', '43', '43202', '8660825', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '井上町', 'イノウエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市竹原町', '43', '43202', '8660826', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '竹原町', 'タケハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市島田町', '43', '43202', '8660827', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '島田町', 'シマダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市萩原町', '43', '43202', '8660831', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '萩原町', 'ハギワラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市末広町', '43', '43202', '8660832', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '末広町', 'スエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市夕葉町', '43', '43202', '8660833', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '夕葉町', 'ユウバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市錦町', '43', '43202', '8660834', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '錦町', 'ニシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市緑町', '43', '43202', '8660841', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '緑町', 'ミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市若草町', '43', '43202', '8660842', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '若草町', 'ワカクサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市花園町', '43', '43202', '8660843', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '花園町', 'ハナゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市旭中央通', '43', '43202', '8660844', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '旭中央通', 'アサヒチュウオウドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市黄金町', '43', '43202', '8660845', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '黄金町', 'コガネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市弥生町', '43', '43202', '8660846', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '弥生町', 'ヤヨイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市毘舎丸町', '43', '43202', '8660851', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '毘舎丸町', 'ビシャマルマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市大手町', '43', '43202', '8660852', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '大手町', 'オオテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市清水町', '43', '43202', '8660853', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '清水町', 'シミズマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市新町', '43', '43202', '8660854', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市袋町', '43', '43202', '8660855', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '袋町', 'フクロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市通町', '43', '43202', '8660856', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '通町', 'トオリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市出町', '43', '43202', '8660857', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '出町', 'デマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市本町', '43', '43202', '8660861', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市松江城町', '43', '43202', '8660862', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '松江城町', 'マツエジョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市西松江城町', '43', '43202', '8660863', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '西松江城町', 'ニシマツエジョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市塩屋町', '43', '43202', '8660864', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '塩屋町', 'シオヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市北の丸町', '43', '43202', '8660865', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '北の丸町', 'キタノマルマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市鷹辻町', '43', '43202', '8660866', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '鷹辻町', 'タカツジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市田中東町', '43', '43202', '8660871', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '田中東町', 'タナカヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市田中町', '43', '43202', '8660872', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '田中町', 'タナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市横手町', '43', '43202', '8660873', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '横手町', 'ヨコテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市横手本町', '43', '43202', '8660874', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '横手本町', 'ヨコテホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市横手新町', '43', '43202', '8660875', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '横手新町', 'ヨコテシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市田中西町', '43', '43202', '8660876', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '田中西町', 'タナカニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市田中北町', '43', '43202', '8660877', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '田中北町', 'タナカキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市興国町', '43', '43202', '8660881', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '興国町', 'コウコクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市松江本町', '43', '43202', '8660882', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '松江本町', 'マツエホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市松江町', '43', '43202', '8660883', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '松江町', 'マツエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市松崎町', '43', '43202', '8660884', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '松崎町', 'マツザキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市永碇町', '43', '43202', '8660885', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '永碇町', 'ナガイカリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市古閑浜町', '43', '43202', '8660891', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '古閑浜町', 'コガハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市古閑下町', '43', '43202', '8660892', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '古閑下町', 'コガシモマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市海士江町', '43', '43202', '8660893', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '海士江町', 'アマガエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市上野町', '43', '43202', '8660894', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '上野町', 'コウズケマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市大村町', '43', '43202', '8660895', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '大村町', 'オオムラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市日置町', '43', '43202', '8660896', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '日置町', 'ヒオキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市古閑上町', '43', '43202', '8660897', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '古閑上町', 'コガカミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市古閑中町', '43', '43202', '8660898', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '古閑中町', 'コガナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県水俣市', '43', '43205', '8670000', '熊本県', 'クマモトケン', '水俣市', 'ミナマタシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('112180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県水俣市小津奈木', '43', '43205', '8670001', '熊本県', 'クマモトケン', '水俣市', 'ミナマタシ', '小津奈木', 'コツナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県水俣市初野', '43', '43205', '8670002', '熊本県', 'クマモトケン', '水俣市', 'ミナマタシ', '初野', 'ハツノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県水俣市ひばりケ丘', '43', '43205', '8670003', '熊本県', 'クマモトケン', '水俣市', 'ミナマタシ', 'ひばりケ丘', 'ヒバリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県水俣市わらび野', '43', '43205', '8670004', '熊本県', 'クマモトケン', '水俣市', 'ミナマタシ', 'わらび野', 'ワラビノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県水俣市牧ノ内', '43', '43205', '8670005', '熊本県', 'クマモトケン', '水俣市', 'ミナマタシ', '牧ノ内', 'マキノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県水俣市白浜町', '43', '43205', '8670006', '熊本県', 'クマモトケン', '水俣市', 'ミナマタシ', '白浜町', 'シラハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県水俣市桜ケ丘', '43', '43205', '8670007', '熊本県', 'クマモトケン', '水俣市', 'ミナマタシ', '桜ケ丘', 'サクラガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県水俣市浜', '43', '43205', '8670008', '熊本県', 'クマモトケン', '水俣市', 'ミナマタシ', '浜', 'ハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県水俣市大迫', '43', '43205', '8670009', '熊本県', 'クマモトケン', '水俣市', 'ミナマタシ', '大迫', 'オオサコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県水俣市陣内', '43', '43205', '8670011', '熊本県', 'クマモトケン', '水俣市', 'ミナマタシ', '陣内', 'ジンナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県水俣市古城', '43', '43205', '8670012', '熊本県', 'クマモトケン', '水俣市', 'ミナマタシ', '古城', 'コジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県水俣市長野町', '43', '43205', '8670013', '熊本県', 'クマモトケン', '水俣市', 'ミナマタシ', '長野町', 'ナガノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県水俣市中鶴', '43', '43205', '8670014', '熊本県', 'クマモトケン', '水俣市', 'ミナマタシ', '中鶴', 'ナカヅル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県水俣市深川', '43', '43205', '8670015', '熊本県', 'クマモトケン', '水俣市', 'ミナマタシ', '深川', 'フカガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県水俣市薄原芦刈赤林', '43', '43205', '8670016', '熊本県', 'クマモトケン', '水俣市', 'ミナマタシ', '薄原', 'ススバル', null, null, '芦刈赤林', 'アシカリアカバヤシ');
INSERT INTO `ms_addresses` VALUES ('112195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県水俣市薄原桜野', '43', '43205', '8670016', '熊本県', 'クマモトケン', '水俣市', 'ミナマタシ', '薄原', 'ススバル', null, null, '桜野', 'サクラノ');
INSERT INTO `ms_addresses` VALUES ('112196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県水俣市薄原桜野上場', '43', '43205', '8670016', '熊本県', 'クマモトケン', '水俣市', 'ミナマタシ', '薄原', 'ススバル', null, null, '桜野上場', 'サクラノウワバ');
INSERT INTO `ms_addresses` VALUES ('112197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県水俣市平町', '43', '43205', '8670021', '熊本県', 'クマモトケン', '水俣市', 'ミナマタシ', '平町', 'ヒラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県水俣市江南町', '43', '43205', '8670022', '熊本県', 'クマモトケン', '水俣市', 'ミナマタシ', '江南町', 'エナンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県水俣市南福寺', '43', '43205', '8670023', '熊本県', 'クマモトケン', '水俣市', 'ミナマタシ', '南福寺', 'ナンプクジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県水俣市長野', '43', '43205', '8670024', '熊本県', 'クマモトケン', '水俣市', 'ミナマタシ', '長野', 'ナガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県水俣市湯出', '43', '43205', '8670025', '熊本県', 'クマモトケン', '水俣市', 'ミナマタシ', '湯出', 'ユデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県水俣市八ノ窪町', '43', '43205', '8670031', '熊本県', 'クマモトケン', '水俣市', 'ミナマタシ', '八ノ窪町', 'ハチノクボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県水俣市江添', '43', '43205', '8670032', '熊本県', 'クマモトケン', '水俣市', 'ミナマタシ', '江添', 'エゾエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県水俣市長崎', '43', '43205', '8670033', '熊本県', 'クマモトケン', '水俣市', 'ミナマタシ', '長崎', 'ナガサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県水俣市袋', '43', '43205', '8670034', '熊本県', 'クマモトケン', '水俣市', 'ミナマタシ', '袋', 'フクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県水俣市月浦', '43', '43205', '8670035', '熊本県', 'クマモトケン', '水俣市', 'ミナマタシ', '月浦', 'ツキノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県水俣市浦上町', '43', '43205', '8670036', '熊本県', 'クマモトケン', '水俣市', 'ミナマタシ', '浦上町', 'ウラガミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県水俣市天神町', '43', '43205', '8670041', '熊本県', 'クマモトケン', '水俣市', 'ミナマタシ', '天神町', 'テンジンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県水俣市大園町', '43', '43205', '8670042', '熊本県', 'クマモトケン', '水俣市', 'ミナマタシ', '大園町', 'オオゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県水俣市大黒町', '43', '43205', '8670043', '熊本県', 'クマモトケン', '水俣市', 'ミナマタシ', '大黒町', 'ダイコクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県水俣市旭町', '43', '43205', '8670044', '熊本県', 'クマモトケン', '水俣市', 'ミナマタシ', '旭町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県水俣市桜井町', '43', '43205', '8670045', '熊本県', 'クマモトケン', '水俣市', 'ミナマタシ', '桜井町', 'サクライチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県水俣市山手町', '43', '43205', '8670046', '熊本県', 'クマモトケン', '水俣市', 'ミナマタシ', '山手町', 'ヤマテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県水俣市緑ケ丘', '43', '43205', '8670047', '熊本県', 'クマモトケン', '水俣市', 'ミナマタシ', '緑ケ丘', 'ミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県水俣市多々良町', '43', '43205', '8670048', '熊本県', 'クマモトケン', '水俣市', 'ミナマタシ', '多々良町', 'タタラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県水俣市百間町', '43', '43205', '8670049', '熊本県', 'クマモトケン', '水俣市', 'ミナマタシ', '百間町', 'ヒャクケンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県水俣市昭和町', '43', '43205', '8670051', '熊本県', 'クマモトケン', '水俣市', 'ミナマタシ', '昭和町', 'ショウワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県水俣市港町', '43', '43205', '8670052', '熊本県', 'クマモトケン', '水俣市', 'ミナマタシ', '港町', 'ミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県水俣市野口町', '43', '43205', '8670053', '熊本県', 'クマモトケン', '水俣市', 'ミナマタシ', '野口町', 'ノグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県水俣市汐見町', '43', '43205', '8670054', '熊本県', 'クマモトケン', '水俣市', 'ミナマタシ', '汐見町', 'シオミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県水俣市明神町', '43', '43205', '8670055', '熊本県', 'クマモトケン', '水俣市', 'ミナマタシ', '明神町', 'ミョウジンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県水俣市梅戸町', '43', '43205', '8670056', '熊本県', 'クマモトケン', '水俣市', 'ミナマタシ', '梅戸町', 'ウメドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県水俣市祇園町', '43', '43205', '8670057', '熊本県', 'クマモトケン', '水俣市', 'ミナマタシ', '祇園町', 'ギオンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県水俣市丸島町', '43', '43205', '8670058', '熊本県', 'クマモトケン', '水俣市', 'ミナマタシ', '丸島町', 'マルシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県水俣市栄町', '43', '43205', '8670059', '熊本県', 'クマモトケン', '水俣市', 'ミナマタシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県水俣市八幡町', '43', '43205', '8670061', '熊本県', 'クマモトケン', '水俣市', 'ミナマタシ', '八幡町', 'ハチマンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県水俣市築地', '43', '43205', '8670062', '熊本県', 'クマモトケン', '水俣市', 'ミナマタシ', '築地', 'ツキジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県水俣市洗切町', '43', '43205', '8670063', '熊本県', 'クマモトケン', '水俣市', 'ミナマタシ', '洗切町', 'アライキリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県水俣市幸町', '43', '43205', '8670064', '熊本県', 'クマモトケン', '水俣市', 'ミナマタシ', '幸町', 'サイワイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県水俣市浜町', '43', '43205', '8670065', '熊本県', 'クマモトケン', '水俣市', 'ミナマタシ', '浜町', 'ハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県水俣市古賀町', '43', '43205', '8670066', '熊本県', 'クマモトケン', '水俣市', 'ミナマタシ', '古賀町', 'コガマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県水俣市塩浜町', '43', '43205', '8670067', '熊本県', 'クマモトケン', '水俣市', 'ミナマタシ', '塩浜町', 'シオハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県水俣市浜松町', '43', '43205', '8670068', '熊本県', 'クマモトケン', '水俣市', 'ミナマタシ', '浜松町', 'ハママツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県水俣市薄原', '43', '43205', '8670116', '熊本県', 'クマモトケン', '水俣市', 'ミナマタシ', '薄原', 'ススバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県水俣市宝川内', '43', '43205', '8670171', '熊本県', 'クマモトケン', '水俣市', 'ミナマタシ', '宝川内', 'ホウガワチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県水俣市市渡瀬', '43', '43205', '8670172', '熊本県', 'クマモトケン', '水俣市', 'ミナマタシ', '市渡瀬', 'イチワタセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県水俣市葛渡', '43', '43205', '8670173', '熊本県', 'クマモトケン', '水俣市', 'ミナマタシ', '葛渡', 'クズワタリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県水俣市石坂川', '43', '43205', '8670174', '熊本県', 'クマモトケン', '水俣市', 'ミナマタシ', '石坂川', 'イシザカガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県水俣市久木野', '43', '43205', '8670281', '熊本県', 'クマモトケン', '水俣市', 'ミナマタシ', '久木野', 'クギノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県水俣市古里', '43', '43205', '8670282', '熊本県', 'クマモトケン', '水俣市', 'ミナマタシ', '古里', 'フルサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県水俣市大川', '43', '43205', '8670283', '熊本県', 'クマモトケン', '水俣市', 'ミナマタシ', '大川', 'オオカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県水俣市越小場', '43', '43205', '8670284', '熊本県', 'クマモトケン', '水俣市', 'ミナマタシ', '越小場', 'コシコバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県人吉市', '43', '43203', '8680000', '熊本県', 'クマモトケン', '人吉市', 'ヒトヨシシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('112247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県球磨郡相良村', '43', '43510', '8680000', '熊本県', 'クマモトケン', '球磨郡相良村', 'クマグンサガラムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('112248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県球磨郡山江村', '43', '43512', '8680000', '熊本県', 'クマモトケン', '球磨郡山江村', 'クマグンヤマエムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('112249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県人吉市鍛冶屋町', '43', '43203', '8680001', '熊本県', 'クマモトケン', '人吉市', 'ヒトヨシシ', '鍛冶屋町', 'カジヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県人吉市大工町', '43', '43203', '8680002', '熊本県', 'クマモトケン', '人吉市', 'ヒトヨシシ', '大工町', 'ダイクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県人吉市紺屋町', '43', '43203', '8680003', '熊本県', 'クマモトケン', '人吉市', 'ヒトヨシシ', '紺屋町', 'コウヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県人吉市九日町', '43', '43203', '8680004', '熊本県', 'クマモトケン', '人吉市', 'ヒトヨシシ', '九日町', 'ココノカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県人吉市上青井町', '43', '43203', '8680005', '熊本県', 'クマモトケン', '人吉市', 'ヒトヨシシ', '上青井町', 'カミアオイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県人吉市駒井田町', '43', '43203', '8680006', '熊本県', 'クマモトケン', '人吉市', 'ヒトヨシシ', '駒井田町', 'コマイダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県人吉市下青井町', '43', '43203', '8680007', '熊本県', 'クマモトケン', '人吉市', 'ヒトヨシシ', '下青井町', 'シモアオイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県人吉市中青井町', '43', '43203', '8680008', '熊本県', 'クマモトケン', '人吉市', 'ヒトヨシシ', '中青井町', 'ナカアオイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県人吉市宝来町', '43', '43203', '8680011', '熊本県', 'クマモトケン', '人吉市', 'ヒトヨシシ', '宝来町', 'ホウライマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県人吉市相良町', '43', '43203', '8680012', '熊本県', 'クマモトケン', '人吉市', 'ヒトヨシシ', '相良町', 'サガラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県人吉市上薩摩瀬町', '43', '43203', '8680013', '熊本県', 'クマモトケン', '人吉市', 'ヒトヨシシ', '上薩摩瀬町', 'カミサツマゼマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県人吉市下薩摩瀬町', '43', '43203', '8680014', '熊本県', 'クマモトケン', '人吉市', 'ヒトヨシシ', '下薩摩瀬町', 'シモサツマゼマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県人吉市下城本町', '43', '43203', '8680015', '熊本県', 'クマモトケン', '人吉市', 'ヒトヨシシ', '下城本町', 'シモシロモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県人吉市城本町', '43', '43203', '8680016', '熊本県', 'クマモトケン', '人吉市', 'ヒトヨシシ', '城本町', 'シロモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県人吉市鬼木町', '43', '43203', '8680021', '熊本県', 'クマモトケン', '人吉市', 'ヒトヨシシ', '鬼木町', 'オニキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県人吉市願成寺町', '43', '43203', '8680022', '熊本県', 'クマモトケン', '人吉市', 'ヒトヨシシ', '願成寺町', 'ガンジョウジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県人吉市北願成寺町', '43', '43203', '8680022', '熊本県', 'クマモトケン', '人吉市', 'ヒトヨシシ', '北願成寺町', 'キタガンジョウジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県人吉市北泉田町', '43', '43203', '8680023', '熊本県', 'クマモトケン', '人吉市', 'ヒトヨシシ', '北泉田町', 'キタイズミダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県人吉市鶴田町', '43', '43203', '8680024', '熊本県', 'クマモトケン', '人吉市', 'ヒトヨシシ', '鶴田町', 'ツルダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県人吉市瓦屋町', '43', '43203', '8680025', '熊本県', 'クマモトケン', '人吉市', 'ヒトヨシシ', '瓦屋町', 'カワラヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県人吉市合ノ原町', '43', '43203', '8680026', '熊本県', 'クマモトケン', '人吉市', 'ヒトヨシシ', '合ノ原町', 'ゴウノハルマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県人吉市井ノ口町', '43', '43203', '8680027', '熊本県', 'クマモトケン', '人吉市', 'ヒトヨシシ', '井ノ口町', 'イノクチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県人吉市南願成寺町', '43', '43203', '8680031', '熊本県', 'クマモトケン', '人吉市', 'ヒトヨシシ', '南願成寺町', 'ミナミガンジョウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県人吉市上新町', '43', '43203', '8680032', '熊本県', 'クマモトケン', '人吉市', 'ヒトヨシシ', '上新町', 'カミシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県人吉市下新町', '43', '43203', '8680033', '熊本県', 'クマモトケン', '人吉市', 'ヒトヨシシ', '下新町', 'シモシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県人吉市七日町', '43', '43203', '8680034', '熊本県', 'クマモトケン', '人吉市', 'ヒトヨシシ', '七日町', 'ナヌカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県人吉市五日町', '43', '43203', '8680035', '熊本県', 'クマモトケン', '人吉市', 'ヒトヨシシ', '五日町', 'イツカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県人吉市二日町', '43', '43203', '8680036', '熊本県', 'クマモトケン', '人吉市', 'ヒトヨシシ', '二日町', 'ニノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県人吉市南泉田町', '43', '43203', '8680037', '熊本県', 'クマモトケン', '人吉市', 'ヒトヨシシ', '南泉田町', 'ミナミイズミダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県人吉市七地町', '43', '43203', '8680041', '熊本県', 'クマモトケン', '人吉市', 'ヒトヨシシ', '七地町', 'シチチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県人吉市蟹作町', '43', '43203', '8680042', '熊本県', 'クマモトケン', '人吉市', 'ヒトヨシシ', '蟹作町', 'ガンツクリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県人吉市東間上町', '43', '43203', '8680043', '熊本県', 'クマモトケン', '人吉市', 'ヒトヨシシ', '東間上町', 'ヒガシアイダカミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県人吉市東間下町', '43', '43203', '8680044', '熊本県', 'クマモトケン', '人吉市', 'ヒトヨシシ', '東間下町', 'ヒガシアイダシモマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県人吉市浪床町', '43', '43203', '8680045', '熊本県', 'クマモトケン', '人吉市', 'ヒトヨシシ', '浪床町', 'ナミトコマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県人吉市原城町', '43', '43203', '8680046', '熊本県', 'クマモトケン', '人吉市', 'ヒトヨシシ', '原城町', 'ハラノジョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県人吉市上原町', '43', '43203', '8680047', '熊本県', 'クマモトケン', '人吉市', 'ヒトヨシシ', '上原町', 'ウエハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県人吉市富ケ尾町', '43', '43203', '8680048', '熊本県', 'クマモトケン', '人吉市', 'ヒトヨシシ', '富ケ尾町', 'トミガオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県人吉市麓町', '43', '43203', '8680051', '熊本県', 'クマモトケン', '人吉市', 'ヒトヨシシ', '麓町', 'フモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県人吉市新町', '43', '43203', '8680052', '熊本県', 'クマモトケン', '人吉市', 'ヒトヨシシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県人吉市老神町', '43', '43203', '8680053', '熊本県', 'クマモトケン', '人吉市', 'ヒトヨシシ', '老神町', 'オイカミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県人吉市田町', '43', '43203', '8680054', '熊本県', 'クマモトケン', '人吉市', 'ヒトヨシシ', '田町', 'タマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県人吉市南町', '43', '43203', '8680055', '熊本県', 'クマモトケン', '人吉市', 'ヒトヨシシ', '南町', 'ミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県人吉市寺町', '43', '43203', '8680056', '熊本県', 'クマモトケン', '人吉市', 'ヒトヨシシ', '寺町', 'テラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県人吉市土手町', '43', '43203', '8680057', '熊本県', 'クマモトケン', '人吉市', 'ヒトヨシシ', '土手町', 'ドテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県人吉市灰久保町', '43', '43203', '8680058', '熊本県', 'クマモトケン', '人吉市', 'ヒトヨシシ', '灰久保町', 'ハイクボマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県人吉市蓑野町', '43', '43203', '8680061', '熊本県', 'クマモトケン', '人吉市', 'ヒトヨシシ', '蓑野町', 'ミノノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県人吉市古仏頂町', '43', '43203', '8680062', '熊本県', 'クマモトケン', '人吉市', 'ヒトヨシシ', '古仏頂町', 'コブツチョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県人吉市木地屋町', '43', '43203', '8680063', '熊本県', 'クマモトケン', '人吉市', 'ヒトヨシシ', '木地屋町', 'キジヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県人吉市東大塚町', '43', '43203', '8680064', '熊本県', 'クマモトケン', '人吉市', 'ヒトヨシシ', '東大塚町', 'ヒガシオオツカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県人吉市西大塚町', '43', '43203', '8680065', '熊本県', 'クマモトケン', '人吉市', 'ヒトヨシシ', '西大塚町', 'ニシオオツカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県人吉市田野町', '43', '43203', '8680066', '熊本県', 'クマモトケン', '人吉市', 'ヒトヨシシ', '田野町', 'タノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県人吉市西間上町', '43', '43203', '8680071', '熊本県', 'クマモトケン', '人吉市', 'ヒトヨシシ', '西間上町', 'ニシアイダカミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県人吉市西間下町', '43', '43203', '8680072', '熊本県', 'クマモトケン', '人吉市', 'ヒトヨシシ', '西間下町', 'ニシアイダシモマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県人吉市上永野町', '43', '43203', '8680073', '熊本県', 'クマモトケン', '人吉市', 'ヒトヨシシ', '上永野町', 'カミナガノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県人吉市下永野町', '43', '43203', '8680074', '熊本県', 'クマモトケン', '人吉市', 'ヒトヨシシ', '下永野町', 'シモナガノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県人吉市矢黒町', '43', '43203', '8680075', '熊本県', 'クマモトケン', '人吉市', 'ヒトヨシシ', '矢黒町', 'ヤグロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県人吉市上戸越町', '43', '43203', '8680076', '熊本県', 'クマモトケン', '人吉市', 'ヒトヨシシ', '上戸越町', 'カミトゴエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県人吉市下戸越町', '43', '43203', '8680077', '熊本県', 'クマモトケン', '人吉市', 'ヒトヨシシ', '下戸越町', 'シモトゴエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県人吉市鹿目町', '43', '43203', '8680078', '熊本県', 'クマモトケン', '人吉市', 'ヒトヨシシ', '鹿目町', 'カナメマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県人吉市上林町', '43', '43203', '8680081', '熊本県', 'クマモトケン', '人吉市', 'ヒトヨシシ', '上林町', 'カミバヤシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県人吉市中林町', '43', '43203', '8680082', '熊本県', 'クマモトケン', '人吉市', 'ヒトヨシシ', '中林町', 'ナカバヤシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県人吉市下林町', '43', '43203', '8680083', '熊本県', 'クマモトケン', '人吉市', 'ヒトヨシシ', '下林町', 'シモバヤシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県人吉市温泉町', '43', '43203', '8680084', '熊本県', 'クマモトケン', '人吉市', 'ヒトヨシシ', '温泉町', 'オンセンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県人吉市中神町', '43', '43203', '8680085', '熊本県', 'クマモトケン', '人吉市', 'ヒトヨシシ', '中神町', 'ナカガミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県人吉市下原田町', '43', '43203', '8680086', '熊本県', 'クマモトケン', '人吉市', 'ヒトヨシシ', '下原田町', 'シモハラダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県人吉市上原田町', '43', '43203', '8680087', '熊本県', 'クマモトケン', '人吉市', 'ヒトヨシシ', '上原田町', 'カミハラダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県球磨郡山江村万江', '43', '43512', '8680091', '熊本県', 'クマモトケン', '球磨郡山江村', 'クマグンヤマエムラ', '万江', 'マエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県球磨郡山江村山田', '43', '43512', '8680092', '熊本県', 'クマモトケン', '球磨郡山江村', 'クマグンヤマエムラ', '山田', 'ヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県球磨郡相良村川辺', '43', '43510', '8680093', '熊本県', 'クマモトケン', '球磨郡相良村', 'クマグンサガラムラ', '川辺', 'カワベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県球磨郡相良村深水', '43', '43510', '8680094', '熊本県', 'クマモトケン', '球磨郡相良村', 'クマグンサガラムラ', '深水', 'フカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県球磨郡相良村柳瀬', '43', '43510', '8680095', '熊本県', 'クマモトケン', '球磨郡相良村', 'クマグンサガラムラ', '柳瀬', 'ヤナセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県球磨郡相良村四浦', '43', '43510', '8680101', '熊本県', 'クマモトケン', '球磨郡相良村', 'クマグンサガラムラ', '四浦', 'ヨウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県球磨郡五木村', '43', '43511', '8680200', '熊本県', 'クマモトケン', '球磨郡五木村', 'クマグンイツキムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('112322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県球磨郡五木村甲', '43', '43511', '8680201', '熊本県', 'クマモトケン', '球磨郡五木村', 'クマグンイツキムラ', '甲', 'コウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県球磨郡五木村乙', '43', '43511', '8680202', '熊本県', 'クマモトケン', '球磨郡五木村', 'クマグンイツキムラ', '乙', 'オツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県球磨郡五木村丙', '43', '43511', '8680203', '熊本県', 'クマモトケン', '球磨郡五木村', 'クマグンイツキムラ', '丙', 'ヘイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県球磨郡錦町', '43', '43501', '8680300', '熊本県', 'クマモトケン', '球磨郡錦町', 'クマグンニシキマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('112326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県球磨郡錦町木上', '43', '43501', '8680301', '熊本県', 'クマモトケン', '球磨郡錦町', 'クマグンニシキマチ', '木上', 'キノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県球磨郡錦町一武', '43', '43501', '8680302', '熊本県', 'クマモトケン', '球磨郡錦町', 'クマグンニシキマチ', '一武', 'イチブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県球磨郡錦町西', '43', '43501', '8680303', '熊本県', 'クマモトケン', '球磨郡錦町', 'クマグンニシキマチ', '西', 'ニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県球磨郡あさぎり町', '43', '43514', '8680400', '熊本県', 'クマモトケン', '球磨郡あさぎり町', 'クマグンアサギリチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('112332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県球磨郡あさぎり町免田東', '43', '43514', '8680408', '熊本県', 'クマモトケン', '球磨郡あさぎり町', 'クマグンアサギリチョウ', '免田東', 'メンダヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県球磨郡あさぎり町免田西', '43', '43514', '8680415', '熊本県', 'クマモトケン', '球磨郡あさぎり町', 'クマグンアサギリチョウ', '免田西', 'メンダニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県球磨郡あさぎり町上東', '43', '43514', '8680421', '熊本県', 'クマモトケン', '球磨郡あさぎり町', 'クマグンアサギリチョウ', '上東', 'ウエヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県球磨郡あさぎり町上北', '43', '43514', '8680422', '熊本県', 'クマモトケン', '球磨郡あさぎり町', 'クマグンアサギリチョウ', '上北', 'ウエキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県球磨郡あさぎり町上南', '43', '43514', '8680423', '熊本県', 'クマモトケン', '球磨郡あさぎり町', 'クマグンアサギリチョウ', '上南', 'ウエミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県球磨郡あさぎり町上西', '43', '43514', '8680424', '熊本県', 'クマモトケン', '球磨郡あさぎり町', 'クマグンアサギリチョウ', '上西', 'ウエニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県球磨郡あさぎり町皆越', '43', '43514', '8680425', '熊本県', 'クマモトケン', '球磨郡あさぎり町', 'クマグンアサギリチョウ', '皆越', 'ミナゴエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県球磨郡あさぎり町岡原北', '43', '43514', '8680431', '熊本県', 'クマモトケン', '球磨郡あさぎり町', 'クマグンアサギリチョウ', '岡原北', 'オカハルキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県球磨郡あさぎり町岡原南', '43', '43514', '8680432', '熊本県', 'クマモトケン', '球磨郡あさぎり町', 'クマグンアサギリチョウ', '岡原南', 'オカハルミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県球磨郡あさぎり町深田北', '43', '43514', '8680441', '熊本県', 'クマモトケン', '球磨郡あさぎり町', 'クマグンアサギリチョウ', '深田北', 'フカダキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県球磨郡あさぎり町深田東', '43', '43514', '8680442', '熊本県', 'クマモトケン', '球磨郡あさぎり町', 'クマグンアサギリチョウ', '深田東', 'フカダヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県球磨郡あさぎり町深田南', '43', '43514', '8680443', '熊本県', 'クマモトケン', '球磨郡あさぎり町', 'クマグンアサギリチョウ', '深田南', 'フカダミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県球磨郡あさぎり町深田西', '43', '43514', '8680444', '熊本県', 'クマモトケン', '球磨郡あさぎり町', 'クマグンアサギリチョウ', '深田西', 'フカダニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県球磨郡あさぎり町須恵', '43', '43514', '8680451', '熊本県', 'クマモトケン', '球磨郡あさぎり町', 'クマグンアサギリチョウ', '須恵', 'スエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県球磨郡多良木町', '43', '43505', '8680500', '熊本県', 'クマモトケン', '球磨郡多良木町', 'クマグンタラギマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('112347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県球磨郡多良木町多良木', '43', '43505', '8680501', '熊本県', 'クマモトケン', '球磨郡多良木町', 'クマグンタラギマチ', '多良木', 'タラギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県球磨郡多良木町黒肥地', '43', '43505', '8680502', '熊本県', 'クマモトケン', '球磨郡多良木町', 'クマグンタラギマチ', '黒肥地', 'クロヒジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県球磨郡多良木町久米', '43', '43505', '8680503', '熊本県', 'クマモトケン', '球磨郡多良木町', 'クマグンタラギマチ', '久米', 'クメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県球磨郡多良木町奥野', '43', '43505', '8680504', '熊本県', 'クマモトケン', '球磨郡多良木町', 'クマグンタラギマチ', '奥野', 'オクノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県球磨郡多良木町槻木', '43', '43505', '8680505', '熊本県', 'クマモトケン', '球磨郡多良木町', 'クマグンタラギマチ', '槻木', 'ツキギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県球磨郡湯前町', '43', '43506', '8680600', '熊本県', 'クマモトケン', '球磨郡湯前町', 'クマグンユノマエマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('112358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県球磨郡湯前町下城', '43', '43506', '8680601', '熊本県', 'クマモトケン', '球磨郡湯前町', 'クマグンユノマエマチ', '下城', 'シタジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県球磨郡湯前町浜川', '43', '43506', '8680602', '熊本県', 'クマモトケン', '球磨郡湯前町', 'クマグンユノマエマチ', '浜川', 'ハマゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県球磨郡湯前町古城', '43', '43506', '8680603', '熊本県', 'クマモトケン', '球磨郡湯前町', 'クマグンユノマエマチ', '古城', 'フルジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県球磨郡湯前町浅ケ野', '43', '43506', '8680604', '熊本県', 'クマモトケン', '球磨郡湯前町', 'クマグンユノマエマチ', '浅ケ野', 'アサカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県球磨郡湯前町下染田', '43', '43506', '8680605', '熊本県', 'クマモトケン', '球磨郡湯前町', 'クマグンユノマエマチ', '下染田', 'シモソメダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県球磨郡湯前町中里', '43', '43506', '8680606', '熊本県', 'クマモトケン', '球磨郡湯前町', 'クマグンユノマエマチ', '中里', 'ナカザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県球磨郡湯前町下里', '43', '43506', '8680607', '熊本県', 'クマモトケン', '球磨郡湯前町', 'クマグンユノマエマチ', '下里', 'シモザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県球磨郡湯前町植木', '43', '43506', '8680611', '熊本県', 'クマモトケン', '球磨郡湯前町', 'クマグンユノマエマチ', '植木', 'ウエキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県球磨郡湯前町上村', '43', '43506', '8680612', '熊本県', 'クマモトケン', '球磨郡湯前町', 'クマグンユノマエマチ', '上村', 'カミムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県球磨郡湯前町田上', '43', '43506', '8680613', '熊本県', 'クマモトケン', '球磨郡湯前町', 'クマグンユノマエマチ', '田上', 'タノエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県球磨郡湯前町馬場', '43', '43506', '8680614', '熊本県', 'クマモトケン', '球磨郡湯前町', 'クマグンユノマエマチ', '馬場', 'ババ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県球磨郡湯前町瀬戸口', '43', '43506', '8680615', '熊本県', 'クマモトケン', '球磨郡湯前町', 'クマグンユノマエマチ', '瀬戸口', 'セドクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県球磨郡湯前町下村', '43', '43506', '8680616', '熊本県', 'クマモトケン', '球磨郡湯前町', 'クマグンユノマエマチ', '下村', 'シモムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県球磨郡湯前町上里', '43', '43506', '8680621', '熊本県', 'クマモトケン', '球磨郡湯前町', 'クマグンユノマエマチ', '上里', 'カミザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県球磨郡湯前町上染田', '43', '43506', '8680622', '熊本県', 'クマモトケン', '球磨郡湯前町', 'クマグンユノマエマチ', '上染田', 'カミソメダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県球磨郡湯前町野中田', '43', '43506', '8680623', '熊本県', 'クマモトケン', '球磨郡湯前町', 'クマグンユノマエマチ', '野中田', 'ノナカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県球磨郡湯前町中猪', '43', '43506', '8680624', '熊本県', 'クマモトケン', '球磨郡湯前町', 'クマグンユノマエマチ', '中猪', 'ナカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県球磨郡湯前町上猪', '43', '43506', '8680625', '熊本県', 'クマモトケン', '球磨郡湯前町', 'クマグンユノマエマチ', '上猪', 'カミイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県球磨郡水上村', '43', '43507', '8680700', '熊本県', 'クマモトケン', '球磨郡水上村', 'クマグンミズカミムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('112377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県球磨郡水上村岩野', '43', '43507', '8680701', '熊本県', 'クマモトケン', '球磨郡水上村', 'クマグンミズカミムラ', '岩野', 'イワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県球磨郡水上村江代', '43', '43507', '8680702', '熊本県', 'クマモトケン', '球磨郡水上村', 'クマグンミズカミムラ', '江代', 'エシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県球磨郡水上村湯山', '43', '43507', '8680703', '熊本県', 'クマモトケン', '球磨郡水上村', 'クマグンミズカミムラ', '湯山', 'ユヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県人吉市上田代町', '43', '43203', '8680801', '熊本県', 'クマモトケン', '人吉市', 'ヒトヨシシ', '上田代町', 'カミタシロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県人吉市下田代町', '43', '43203', '8680802', '熊本県', 'クマモトケン', '人吉市', 'ヒトヨシシ', '下田代町', 'シモタシロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県人吉市大畑町', '43', '43203', '8680803', '熊本県', 'クマモトケン', '人吉市', 'ヒトヨシシ', '大畑町', 'オコバマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県人吉市大畑麓町', '43', '43203', '8680811', '熊本県', 'クマモトケン', '人吉市', 'ヒトヨシシ', '大畑麓町', 'オコバフモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県人吉市大野町', '43', '43203', '8680812', '熊本県', 'クマモトケン', '人吉市', 'ヒトヨシシ', '大野町', 'オオノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県人吉市矢岳町', '43', '43203', '8680813', '熊本県', 'クマモトケン', '人吉市', 'ヒトヨシシ', '矢岳町', 'ヤタケマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県人吉市上漆田町', '43', '43203', '8680821', '熊本県', 'クマモトケン', '人吉市', 'ヒトヨシシ', '上漆田町', 'カミウルシダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県人吉市下漆田町', '43', '43203', '8680822', '熊本県', 'クマモトケン', '人吉市', 'ヒトヨシシ', '下漆田町', 'シモウルシダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県人吉市東漆田町', '43', '43203', '8680823', '熊本県', 'クマモトケン', '人吉市', 'ヒトヨシシ', '東漆田町', 'ヒガシウルシダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県人吉市赤池水無町', '43', '43203', '8680824', '熊本県', 'クマモトケン', '人吉市', 'ヒトヨシシ', '赤池水無町', 'アカイケミズナシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県人吉市赤池原町', '43', '43203', '8680825', '熊本県', 'クマモトケン', '人吉市', 'ヒトヨシシ', '赤池原町', 'アカイケハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名郡長洲町', '43', '43368', '8690100', '熊本県', 'クマモトケン', '玉名郡長洲町', 'タマナグンナガスマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('112402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名郡長洲町宮野', '43', '43368', '8690101', '熊本県', 'クマモトケン', '玉名郡長洲町', 'タマナグンナガスマチ', '宮野', 'ミヤノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名郡長洲町折崎', '43', '43368', '8690102', '熊本県', 'クマモトケン', '玉名郡長洲町', 'タマナグンナガスマチ', '折崎', 'オリサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名郡長洲町腹赤', '43', '43368', '8690103', '熊本県', 'クマモトケン', '玉名郡長洲町', 'タマナグンナガスマチ', '腹赤', 'ハラカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名郡長洲町上沖洲', '43', '43368', '8690104', '熊本県', 'クマモトケン', '玉名郡長洲町', 'タマナグンナガスマチ', '上沖洲', 'カミオキノス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名郡長洲町清源寺', '43', '43368', '8690105', '熊本県', 'クマモトケン', '玉名郡長洲町', 'タマナグンナガスマチ', '清源寺', 'セイゲンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名郡長洲町永塩', '43', '43368', '8690106', '熊本県', 'クマモトケン', '玉名郡長洲町', 'タマナグンナガスマチ', '永塩', 'ナガシオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名郡長洲町名石浜', '43', '43368', '8690111', '熊本県', 'クマモトケン', '玉名郡長洲町', 'タマナグンナガスマチ', '名石浜', 'メイシハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名郡長洲町姫ケ浦', '43', '43368', '8690112', '熊本県', 'クマモトケン', '玉名郡長洲町', 'タマナグンナガスマチ', '姫ケ浦', 'ヒメガウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名郡長洲町有明', '43', '43368', '8690113', '熊本県', 'クマモトケン', '玉名郡長洲町', 'タマナグンナガスマチ', '有明', 'アリアケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名郡長洲町高浜', '43', '43368', '8690121', '熊本県', 'クマモトケン', '玉名郡長洲町', 'タマナグンナガスマチ', '高浜', 'タカハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名郡長洲町梅田', '43', '43368', '8690122', '熊本県', 'クマモトケン', '玉名郡長洲町', 'タマナグンナガスマチ', '梅田', 'ウメダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名郡長洲町長洲', '43', '43368', '8690123', '熊本県', 'クマモトケン', '玉名郡長洲町', 'タマナグンナガスマチ', '長洲', 'ナガス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名市岱明町山下', '43', '43206', '8690201', '熊本県', 'クマモトケン', '玉名市', 'タマナシ', '岱明町山下', 'タイメイマチヤマシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名市岱明町高道', '43', '43206', '8690202', '熊本県', 'クマモトケン', '玉名市', 'タマナシ', '岱明町高道', 'タイメイマチタカミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名市岱明町浜田', '43', '43206', '8690203', '熊本県', 'クマモトケン', '玉名市', 'タマナシ', '岱明町浜田', 'タイメイマチハマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名市岱明町鍋', '43', '43206', '8690211', '熊本県', 'クマモトケン', '玉名市', 'タマナシ', '岱明町鍋', 'タイメイマチナベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名市岱明町下沖洲', '43', '43206', '8690212', '熊本県', 'クマモトケン', '玉名市', 'タマナシ', '岱明町下沖洲', 'タイメイマチシモオキノス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名市岱明町扇崎', '43', '43206', '8690213', '熊本県', 'クマモトケン', '玉名市', 'タマナシ', '岱明町扇崎', 'タイメイマチオウギザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名市岱明町下前原', '43', '43206', '8690221', '熊本県', 'クマモトケン', '玉名市', 'タマナシ', '岱明町下前原', 'タイメイマチシモマエハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名市岱明町野口', '43', '43206', '8690222', '熊本県', 'クマモトケン', '玉名市', 'タマナシ', '岱明町野口', 'タイメイマチノグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名市岱明町中土', '43', '43206', '8690223', '熊本県', 'クマモトケン', '玉名市', 'タマナシ', '岱明町中土', 'タイメイマチナカド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名市岱明町大野下', '43', '43206', '8690224', '熊本県', 'クマモトケン', '玉名市', 'タマナシ', '岱明町大野下', 'タイメイマチオオノシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名市岱明町庄山', '43', '43206', '8690231', '熊本県', 'クマモトケン', '玉名市', 'タマナシ', '岱明町庄山', 'タイメイマチショウヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名市岱明町上', '43', '43206', '8690232', '熊本県', 'クマモトケン', '玉名市', 'タマナシ', '岱明町上', 'タイメイマチジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名市岱明町古閑', '43', '43206', '8690233', '熊本県', 'クマモトケン', '玉名市', 'タマナシ', '岱明町古閑', 'タイメイマチコガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名市岱明町三崎', '43', '43206', '8690234', '熊本県', 'クマモトケン', '玉名市', 'タマナシ', '岱明町三崎', 'タイメイマチミサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名市岱明町古閑雲雀丘', '43', '43206', '8690235', '熊本県', 'クマモトケン', '玉名市', 'タマナシ', '岱明町古閑', 'タイメイマチコガ', null, null, '雲雀丘', 'ヒバリガオカ');
INSERT INTO `ms_addresses` VALUES ('112432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名市岱明町西照寺雲雀丘', '43', '43206', '8690235', '熊本県', 'クマモトケン', '玉名市', 'タマナシ', '岱明町西照寺', 'タイメイマチサイショウジ', null, null, '雲雀丘', 'ヒバリガオカ');
INSERT INTO `ms_addresses` VALUES ('112433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名市岱明町上雲雀丘', '43', '43206', '8690235', '熊本県', 'クマモトケン', '玉名市', 'タマナシ', '岱明町上', 'タイメイマチジョウ', null, null, '雲雀丘', 'ヒバリガオカ');
INSERT INTO `ms_addresses` VALUES ('112434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名市岱明町西照寺', '43', '43206', '8690236', '熊本県', 'クマモトケン', '玉名市', 'タマナシ', '岱明町西照寺', 'タイメイマチサイショウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名市岱明町開田', '43', '43206', '8690238', '熊本県', 'クマモトケン', '玉名市', 'タマナシ', '岱明町開田', 'タイメイマチヒラキダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名郡玉東町', '43', '43364', '8690300', '熊本県', 'クマモトケン', '玉名郡玉東町', 'タマナグンギョクトウマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('112440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名郡玉東町稲佐', '43', '43364', '8690301', '熊本県', 'クマモトケン', '玉名郡玉東町', 'タマナグンギョクトウマチ', '稲佐', 'イナサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名郡玉東町山口', '43', '43364', '8690302', '熊本県', 'クマモトケン', '玉名郡玉東町', 'タマナグンギョクトウマチ', '山口', 'ヤマグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名郡玉東町木葉', '43', '43364', '8690303', '熊本県', 'クマモトケン', '玉名郡玉東町', 'タマナグンギョクトウマチ', '木葉', 'コノハ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名郡玉東町浦田', '43', '43364', '8690304', '熊本県', 'クマモトケン', '玉名郡玉東町', 'タマナグンギョクトウマチ', '浦田', 'ウラタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名郡玉東町上木葉', '43', '43364', '8690305', '熊本県', 'クマモトケン', '玉名郡玉東町', 'タマナグンギョクトウマチ', '上木葉', 'カミコノハ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名郡玉東町二俣', '43', '43364', '8690311', '熊本県', 'クマモトケン', '玉名郡玉東町', 'タマナグンギョクトウマチ', '二俣', 'フタマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名郡玉東町白木', '43', '43364', '8690312', '熊本県', 'クマモトケン', '玉名郡玉東町', 'タマナグンギョクトウマチ', '白木', 'シラキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名郡玉東町上白木', '43', '43364', '8690313', '熊本県', 'クマモトケン', '玉名郡玉東町', 'タマナグンギョクトウマチ', '上白木', 'カミシラキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名郡玉東町西安寺', '43', '43364', '8690321', '熊本県', 'クマモトケン', '玉名郡玉東町', 'タマナグンギョクトウマチ', '西安寺', 'サイアンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県玉名郡玉東町原倉', '43', '43364', '8690322', '熊本県', 'クマモトケン', '玉名郡玉東町', 'タマナグンギョクトウマチ', '原倉', 'ハラクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇土市', '43', '43211', '8690400', '熊本県', 'クマモトケン', '宇土市', 'ウトシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('112451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇土市住吉町', '43', '43211', '8690401', '熊本県', 'クマモトケン', '宇土市', 'ウトシ', '住吉町', 'スミヨシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇土市笹原町', '43', '43211', '8690402', '熊本県', 'クマモトケン', '宇土市', 'ウトシ', '笹原町', 'ササワラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇土市新開町', '43', '43211', '8690403', '熊本県', 'クマモトケン', '宇土市', 'ウトシ', '新開町', 'シンガイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇土市走潟町', '43', '43211', '8690404', '熊本県', 'クマモトケン', '宇土市', 'ウトシ', '走潟町', 'ハシリガタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇土市馬之瀬町', '43', '43211', '8690405', '熊本県', 'クマモトケン', '宇土市', 'ウトシ', '馬之瀬町', 'ウマノセマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇土市三拾町', '43', '43211', '8690406', '熊本県', 'クマモトケン', '宇土市', 'ウトシ', '三拾町', 'サジッチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇土市松原町', '43', '43211', '8690407', '熊本県', 'クマモトケン', '宇土市', 'ウトシ', '松原町', 'マツワラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇土市築籠町', '43', '43211', '8690408', '熊本県', 'クマモトケン', '宇土市', 'ウトシ', '築籠町', 'ツイゴメマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇土市花園台町', '43', '43211', '8690410', '熊本県', 'クマモトケン', '宇土市', 'ウトシ', '花園台町', 'ハナゾノダイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇土市水町', '43', '43211', '8690411', '熊本県', 'クマモトケン', '宇土市', 'ウトシ', '水町', 'ミズマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇土市岩古曽町', '43', '43211', '8690412', '熊本県', 'クマモトケン', '宇土市', 'ウトシ', '岩古曽町', 'イワコソマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇土市花園町', '43', '43211', '8690413', '熊本県', 'クマモトケン', '宇土市', 'ウトシ', '花園町', 'ハナゾノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇土市立岡町', '43', '43211', '8690414', '熊本県', 'クマモトケン', '宇土市', 'ウトシ', '立岡町', 'タチオカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇土市古保里町', '43', '43211', '8690415', '熊本県', 'クマモトケン', '宇土市', 'ウトシ', '古保里町', 'コオザトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇土市松山町', '43', '43211', '8690416', '熊本県', 'クマモトケン', '宇土市', 'ウトシ', '松山町', 'マツヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇土市境目町', '43', '43211', '8690417', '熊本県', 'クマモトケン', '宇土市', 'ウトシ', '境目町', 'サカイメマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇土市善道寺町', '43', '43211', '8690418', '熊本県', 'クマモトケン', '宇土市', 'ウトシ', '善道寺町', 'ゼンドウジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇土市新松原町', '43', '43211', '8690419', '熊本県', 'クマモトケン', '宇土市', 'ウトシ', '新松原町', 'シンマツワラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇土市南段原町', '43', '43211', '8690421', '熊本県', 'クマモトケン', '宇土市', 'ウトシ', '南段原町', 'ミナミダンバラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇土市入地町', '43', '43211', '8690422', '熊本県', 'クマモトケン', '宇土市', 'ウトシ', '入地町', 'イリチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇土市伊無田町', '43', '43211', '8690423', '熊本県', 'クマモトケン', '宇土市', 'ウトシ', '伊無田町', 'イムタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇土市神馬町', '43', '43211', '8690424', '熊本県', 'クマモトケン', '宇土市', 'ウトシ', '神馬町', 'シンメマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇土市栗崎町', '43', '43211', '8690425', '熊本県', 'クマモトケン', '宇土市', 'ウトシ', '栗崎町', 'クリザキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇土市神合町', '43', '43211', '8690426', '熊本県', 'クマモトケン', '宇土市', 'ウトシ', '神合町', 'コウアイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇土市本町', '43', '43211', '8690431', '熊本県', 'クマモトケン', '宇土市', 'ウトシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇土市旭町', '43', '43211', '8690432', '熊本県', 'クマモトケン', '宇土市', 'ウトシ', '旭町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇土市新小路町', '43', '43211', '8690433', '熊本県', 'クマモトケン', '宇土市', 'ウトシ', '新小路町', 'シンコウジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇土市門内町', '43', '43211', '8690434', '熊本県', 'クマモトケン', '宇土市', 'ウトシ', '門内町', 'モンナイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇土市一里木町', '43', '43211', '8690435', '熊本県', 'クマモトケン', '宇土市', 'ウトシ', '一里木町', 'イチリギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇土市定府町', '43', '43211', '8690436', '熊本県', 'クマモトケン', '宇土市', 'ウトシ', '定府町', 'ジョウフマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇土市石小路町', '43', '43211', '8690441', '熊本県', 'クマモトケン', '宇土市', 'ウトシ', '石小路町', 'イシコウジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇土市城之浦町', '43', '43211', '8690442', '熊本県', 'クマモトケン', '宇土市', 'ウトシ', '城之浦町', 'ジョウノウラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇土市船場町', '43', '43211', '8690443', '熊本県', 'クマモトケン', '宇土市', 'ウトシ', '船場町', 'センバマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇土市新町', '43', '43211', '8690444', '熊本県', 'クマモトケン', '宇土市', 'ウトシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇土市浦田町', '43', '43211', '8690445', '熊本県', 'クマモトケン', '宇土市', 'ウトシ', '浦田町', 'ウラタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇土市北段原町', '43', '43211', '8690451', '熊本県', 'クマモトケン', '宇土市', 'ウトシ', '北段原町', 'キタダンバラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇土市高柳町', '43', '43211', '8690452', '熊本県', 'クマモトケン', '宇土市', 'ウトシ', '高柳町', 'タカヤナギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇土市栄町', '43', '43211', '8690453', '熊本県', 'クマモトケン', '宇土市', 'ウトシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇土市古城町', '43', '43211', '8690454', '熊本県', 'クマモトケン', '宇土市', 'ウトシ', '古城町', 'コジョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇土市椿原町', '43', '43211', '8690455', '熊本県', 'クマモトケン', '宇土市', 'ウトシ', '椿原町', 'ツバワラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇土市石橋町', '43', '43211', '8690456', '熊本県', 'クマモトケン', '宇土市', 'ウトシ', '石橋町', 'イシバシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇土市宮庄町', '43', '43211', '8690457', '熊本県', 'クマモトケン', '宇土市', 'ウトシ', '宮庄町', 'ミヤノショウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇土市網津町', '43', '43211', '8690461', '熊本県', 'クマモトケン', '宇土市', 'ウトシ', '網津町', 'アミヅマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇土市城塚町', '43', '43211', '8690462', '熊本県', 'クマモトケン', '宇土市', 'ウトシ', '城塚町', 'ジョウツカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇土市野鶴町', '43', '43211', '8690463', '熊本県', 'クマモトケン', '宇土市', 'ウトシ', '野鶴町', 'ノヅルマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇土市恵塚町', '43', '43211', '8690464', '熊本県', 'クマモトケン', '宇土市', 'ウトシ', '恵塚町', 'エヅカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇土市網引町', '43', '43211', '8690465', '熊本県', 'クマモトケン', '宇土市', 'ウトシ', '網引町', 'アビキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇城市', '43', '43213', '8690500', '熊本県', 'クマモトケン', '宇城市', 'ウキシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('112502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇城市松橋町松山', '43', '43213', '8690501', '熊本県', 'クマモトケン', '宇城市', 'ウキシ', '松橋町松山', 'マツバセマチマツヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇城市松橋町松橋', '43', '43213', '8690502', '熊本県', 'クマモトケン', '宇城市', 'ウキシ', '松橋町松橋', 'マツバセマチマツバセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇城市松橋町きらら', '43', '43213', '8690503', '熊本県', 'クマモトケン', '宇城市', 'ウキシ', '松橋町きらら', 'マツバセマチキララ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇城市松橋町曲野', '43', '43213', '8690511', '熊本県', 'クマモトケン', '宇城市', 'ウキシ', '松橋町曲野', 'マツバセマチマガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇城市松橋町古保山', '43', '43213', '8690512', '熊本県', 'クマモトケン', '宇城市', 'ウキシ', '松橋町古保山', 'マツバセマチコオヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇城市松橋町萩尾', '43', '43213', '8690513', '熊本県', 'クマモトケン', '宇城市', 'ウキシ', '松橋町萩尾', 'マツバセマチハギオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇城市松橋町浦川内', '43', '43213', '8690521', '熊本県', 'クマモトケン', '宇城市', 'ウキシ', '松橋町浦川内', 'マツバセマチウラカワチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇城市松橋町内田', '43', '43213', '8690522', '熊本県', 'クマモトケン', '宇城市', 'ウキシ', '松橋町内田', 'マツバセマチウチダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇城市松橋町竹崎', '43', '43213', '8690523', '熊本県', 'クマモトケン', '宇城市', 'ウキシ', '松橋町竹崎', 'マツバセマチタケザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇城市松橋町豊福', '43', '43213', '8690524', '熊本県', 'クマモトケン', '宇城市', 'ウキシ', '松橋町豊福', 'マツバセマチトヨフク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇城市松橋町大野', '43', '43213', '8690531', '熊本県', 'クマモトケン', '宇城市', 'ウキシ', '松橋町大野', 'マツバセマチオオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇城市松橋町久具', '43', '43213', '8690532', '熊本県', 'クマモトケン', '宇城市', 'ウキシ', '松橋町久具', 'マツバセマチクグ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇城市松橋町両仲間', '43', '43213', '8690533', '熊本県', 'クマモトケン', '宇城市', 'ウキシ', '松橋町両仲間', 'マツバセマチリョウナカマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇城市松橋町西下郷', '43', '43213', '8690534', '熊本県', 'クマモトケン', '宇城市', 'ウキシ', '松橋町西下郷', 'マツバセマチニシシモゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇城市松橋町東松崎', '43', '43213', '8690541', '熊本県', 'クマモトケン', '宇城市', 'ウキシ', '松橋町東松崎', 'マツバセマチヒガシマツザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇城市松橋町豊崎', '43', '43213', '8690542', '熊本県', 'クマモトケン', '宇城市', 'ウキシ', '松橋町豊崎', 'マツバセマチトヨザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇城市松橋町南豊崎', '43', '43213', '8690543', '熊本県', 'クマモトケン', '宇城市', 'ウキシ', '松橋町南豊崎', 'マツバセマチミナミトヨザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇城市松橋町浅川', '43', '43213', '8690544', '熊本県', 'クマモトケン', '宇城市', 'ウキシ', '松橋町浅川', 'マツバセマチアサカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇城市松橋町砂川', '43', '43213', '8690545', '熊本県', 'クマモトケン', '宇城市', 'ウキシ', '松橋町砂川', 'マツバセマチスナガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇城市松橋町御船', '43', '43213', '8690546', '熊本県', 'クマモトケン', '宇城市', 'ウキシ', '松橋町御船', 'マツバセマチミフネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇城市不知火町御領', '43', '43213', '8690551', '熊本県', 'クマモトケン', '宇城市', 'ウキシ', '不知火町御領', 'シラヌヒマチゴリョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇城市不知火町高良', '43', '43213', '8690552', '熊本県', 'クマモトケン', '宇城市', 'ウキシ', '不知火町高良', 'シラヌヒマチコウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇城市不知火町小曽部', '43', '43213', '8690553', '熊本県', 'クマモトケン', '宇城市', 'ウキシ', '不知火町小曽部', 'シラヌヒマチコソブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇城市不知火町柏原', '43', '43213', '8690554', '熊本県', 'クマモトケン', '宇城市', 'ウキシ', '不知火町柏原', 'シラヌヒマチカシワハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇城市不知火町亀松', '43', '43213', '8690561', '熊本県', 'クマモトケン', '宇城市', 'ウキシ', '不知火町亀松', 'シラヌヒマチカメマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇城市不知火町長崎', '43', '43213', '8690562', '熊本県', 'クマモトケン', '宇城市', 'ウキシ', '不知火町長崎', 'シラヌヒマチナガサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇城市不知火町浦上', '43', '43213', '8690563', '熊本県', 'クマモトケン', '宇城市', 'ウキシ', '不知火町浦上', 'シラヌヒマチウラガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇城市小川町北小野', '43', '43213', '8690601', '熊本県', 'クマモトケン', '宇城市', 'ウキシ', '小川町北小野', 'オガワマチキタオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇城市小川町中小野', '43', '43213', '8690602', '熊本県', 'クマモトケン', '宇城市', 'ウキシ', '小川町中小野', 'オガワマチナカオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇城市小川町南小野', '43', '43213', '8690603', '熊本県', 'クマモトケン', '宇城市', 'ウキシ', '小川町南小野', 'オガワマチミナミオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇城市小川町北部田', '43', '43213', '8690604', '熊本県', 'クマモトケン', '宇城市', 'ウキシ', '小川町北部田', 'オガワマチキタベタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇城市小川町南部田', '43', '43213', '8690605', '熊本県', 'クマモトケン', '宇城市', 'ウキシ', '小川町南部田', 'オガワマチミナミベタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇城市小川町河江', '43', '43213', '8690606', '熊本県', 'クマモトケン', '宇城市', 'ウキシ', '小川町河江', 'オガワマチゴウノエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇城市小川町東海東', '43', '43213', '8690611', '熊本県', 'クマモトケン', '宇城市', 'ウキシ', '小川町東海東', 'オガワマチヒガシカイトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇城市小川町南海東', '43', '43213', '8690612', '熊本県', 'クマモトケン', '宇城市', 'ウキシ', '小川町南海東', 'オガワマチミナミカイトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇城市小川町東小川', '43', '43213', '8690613', '熊本県', 'クマモトケン', '宇城市', 'ウキシ', '小川町東小川', 'オガワマチヒガシオガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇城市小川町南小川', '43', '43213', '8690614', '熊本県', 'クマモトケン', '宇城市', 'ウキシ', '小川町南小川', 'オガワマチミナミオガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇城市小川町西海東', '43', '43213', '8690615', '熊本県', 'クマモトケン', '宇城市', 'ウキシ', '小川町西海東', 'オガワマチニシカイトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇城市小川町北海東', '43', '43213', '8690616', '熊本県', 'クマモトケン', '宇城市', 'ウキシ', '小川町北海東', 'オガワマチキタカイトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇城市小川町小川', '43', '43213', '8690621', '熊本県', 'クマモトケン', '宇城市', 'ウキシ', '小川町小川', 'オガワマチオガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇城市小川町西北小川', '43', '43213', '8690622', '熊本県', 'クマモトケン', '宇城市', 'ウキシ', '小川町西北小川', 'オガワマチニシキタオガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇城市小川町川尻', '43', '43213', '8690623', '熊本県', 'クマモトケン', '宇城市', 'ウキシ', '小川町川尻', 'オガワマチカワジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇城市小川町江頭', '43', '43213', '8690624', '熊本県', 'クマモトケン', '宇城市', 'ウキシ', '小川町江頭', 'オガワマチエガシラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇城市小川町北新田', '43', '43213', '8690631', '熊本県', 'クマモトケン', '宇城市', 'ウキシ', '小川町北新田', 'オガワマチキタシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇城市小川町南新田', '43', '43213', '8690632', '熊本県', 'クマモトケン', '宇城市', 'ウキシ', '小川町南新田', 'オガワマチミナミシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇城市小川町新田', '43', '43213', '8690633', '熊本県', 'クマモトケン', '宇城市', 'ウキシ', '小川町新田', 'オガワマチシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇城市小川町住吉', '43', '43213', '8690634', '熊本県', 'クマモトケン', '宇城市', 'ウキシ', '小川町住吉', 'オガワマチスミヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇城市小川町不知火', '43', '43213', '8690635', '熊本県', 'クマモトケン', '宇城市', 'ウキシ', '小川町不知火', 'オガワマチシラヌイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇城市小川町新田出', '43', '43213', '8690636', '熊本県', 'クマモトケン', '宇城市', 'ウキシ', '小川町新田出', 'オガワマチシンデンデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池郡菊陽町', '43', '43404', '8691100', '熊本県', 'クマモトケン', '菊池郡菊陽町', 'キクチグンキクヨウマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('112556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池郡菊陽町津久礼', '43', '43404', '8691101', '熊本県', 'クマモトケン', '菊池郡菊陽町', 'キクチグンキクヨウマチ', '津久礼', 'ツクレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池郡菊陽町原水', '43', '43404', '8691102', '熊本県', 'クマモトケン', '菊池郡菊陽町', 'キクチグンキクヨウマチ', '原水', 'ハラミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池郡菊陽町久保田', '43', '43404', '8691103', '熊本県', 'クマモトケン', '菊池郡菊陽町', 'キクチグンキクヨウマチ', '久保田', 'クボタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池郡菊陽町戸次', '43', '43404', '8691104', '熊本県', 'クマモトケン', '菊池郡菊陽町', 'キクチグンキクヨウマチ', '戸次', 'トツギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池郡菊陽町馬場楠', '43', '43404', '8691105', '熊本県', 'クマモトケン', '菊池郡菊陽町', 'キクチグンキクヨウマチ', '馬場楠', 'ババグス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池郡菊陽町曲手', '43', '43404', '8691106', '熊本県', 'クマモトケン', '菊池郡菊陽町', 'キクチグンキクヨウマチ', '曲手', 'マガテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池郡菊陽町辛川', '43', '43404', '8691107', '熊本県', 'クマモトケン', '菊池郡菊陽町', 'キクチグンキクヨウマチ', '辛川', 'カラカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池郡菊陽町光の森', '43', '43404', '8691108', '熊本県', 'クマモトケン', '菊池郡菊陽町', 'キクチグンキクヨウマチ', '光の森', 'ヒカリノモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池郡菊陽町新山', '43', '43404', '8691109', '熊本県', 'クマモトケン', '菊池郡菊陽町', 'キクチグンキクヨウマチ', '新山', 'シンヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池郡菊陽町杉並台', '43', '43404', '8691110', '熊本県', 'クマモトケン', '菊池郡菊陽町', 'キクチグンキクヨウマチ', '杉並台', 'スギナミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池郡大津町', '43', '43403', '8691200', '熊本県', 'クマモトケン', '菊池郡大津町', 'キクチグンオオヅマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('112569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池市旭志弁利', '43', '43210', '8691201', '熊本県', 'クマモトケン', '菊池市', 'キクチシ', '旭志弁利', 'キョクシベンリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池市旭志麓', '43', '43210', '8691202', '熊本県', 'クマモトケン', '菊池市', 'キクチシ', '旭志麓', 'キョクシフモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池市旭志尾足', '43', '43210', '8691203', '熊本県', 'クマモトケン', '菊池市', 'キクチシ', '旭志尾足', 'キョクシオタル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池市旭志小原', '43', '43210', '8691204', '熊本県', 'クマモトケン', '菊池市', 'キクチシ', '旭志小原', 'キョクシオバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池市旭志川辺', '43', '43210', '8691205', '熊本県', 'クマモトケン', '菊池市', 'キクチシ', '旭志川辺', 'キョクシカワベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池市旭志伊坂', '43', '43210', '8691206', '熊本県', 'クマモトケン', '菊池市', 'キクチシ', '旭志伊坂', 'キョクシイサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池市旭志新明', '43', '43210', '8691207', '熊本県', 'クマモトケン', '菊池市', 'キクチシ', '旭志新明', 'キョクシシンメイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池市旭志伊萩', '43', '43210', '8691208', '熊本県', 'クマモトケン', '菊池市', 'キクチシ', '旭志伊萩', 'キョクシイハギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池郡大津町矢護川', '43', '43403', '8691211', '熊本県', 'クマモトケン', '菊池郡大津町', 'キクチグンオオヅマチ', '矢護川', 'ヤゴガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池郡大津町真木', '43', '43403', '8691212', '熊本県', 'クマモトケン', '菊池郡大津町', 'キクチグンオオヅマチ', '真木', 'マキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池郡大津町古城', '43', '43403', '8691213', '熊本県', 'クマモトケン', '菊池郡大津町', 'キクチグンオオヅマチ', '古城', 'フルジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池郡大津町瀬田', '43', '43403', '8691214', '熊本県', 'クマモトケン', '菊池郡大津町', 'キクチグンオオヅマチ', '瀬田', 'セタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池郡大津町外牧', '43', '43403', '8691215', '熊本県', 'クマモトケン', '菊池郡大津町', 'キクチグンオオヅマチ', '外牧', 'ホカマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池郡大津町錦野', '43', '43403', '8691216', '熊本県', 'クマモトケン', '菊池郡大津町', 'キクチグンオオヅマチ', '錦野', 'ニシキノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池郡大津町森', '43', '43403', '8691217', '熊本県', 'クマモトケン', '菊池郡大津町', 'キクチグンオオヅマチ', '森', 'モリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池郡大津町吹田', '43', '43403', '8691218', '熊本県', 'クマモトケン', '菊池郡大津町', 'キクチグンオオヅマチ', '吹田', 'フケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池郡大津町大林', '43', '43403', '8691219', '熊本県', 'クマモトケン', '菊池郡大津町', 'キクチグンオオヅマチ', '大林', 'オオバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池郡大津町陣内', '43', '43403', '8691221', '熊本県', 'クマモトケン', '菊池郡大津町', 'キクチグンオオヅマチ', '陣内', 'ジンナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池郡大津町岩坂', '43', '43403', '8691222', '熊本県', 'クマモトケン', '菊池郡大津町', 'キクチグンオオヅマチ', '岩坂', 'イワサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池郡大津町中島', '43', '43403', '8691223', '熊本県', 'クマモトケン', '菊池郡大津町', 'キクチグンオオヅマチ', '中島', 'ナカシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池郡大津町町', '43', '43403', '8691224', '熊本県', 'クマモトケン', '菊池郡大津町', 'キクチグンオオヅマチ', '町', 'マチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池郡大津町下町', '43', '43403', '8691225', '熊本県', 'クマモトケン', '菊池郡大津町', 'キクチグンオオヅマチ', '下町', 'シモマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池郡大津町灰塚', '43', '43403', '8691226', '熊本県', 'クマモトケン', '菊池郡大津町', 'キクチグンオオヅマチ', '灰塚', 'ハイヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池郡大津町新', '43', '43403', '8691227', '熊本県', 'クマモトケン', '菊池郡大津町', 'キクチグンオオヅマチ', '新', 'シン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池郡大津町平川', '43', '43403', '8691231', '熊本県', 'クマモトケン', '菊池郡大津町', 'キクチグンオオヅマチ', '平川', 'ヒラカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池郡大津町高尾野', '43', '43403', '8691232', '熊本県', 'クマモトケン', '菊池郡大津町', 'キクチグンオオヅマチ', '高尾野', 'タカオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池郡大津町大津', '43', '43403', '8691233', '熊本県', 'クマモトケン', '菊池郡大津町', 'キクチグンオオヅマチ', '大津', 'オオヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池郡大津町引水', '43', '43403', '8691234', '熊本県', 'クマモトケン', '菊池郡大津町', 'キクチグンオオヅマチ', '引水', 'ヒキノミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池郡大津町室', '43', '43403', '8691235', '熊本県', 'クマモトケン', '菊池郡大津町', 'キクチグンオオヅマチ', '室', 'ムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池郡大津町杉水', '43', '43403', '8691236', '熊本県', 'クマモトケン', '菊池郡大津町', 'キクチグンオオヅマチ', '杉水', 'スギミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県菊池郡大津町美咲野', '43', '43403', '8691237', '熊本県', 'クマモトケン', '菊池郡大津町', 'キクチグンオオヅマチ', '美咲野', 'ミサキノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県阿蘇郡南阿蘇村', '43', '43433', '8691400', '熊本県', 'クマモトケン', '阿蘇郡南阿蘇村', 'アソグンミナミアソムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('112605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県阿蘇郡南阿蘇村立野', '43', '43433', '8691401', '熊本県', 'クマモトケン', '阿蘇郡南阿蘇村', 'アソグンミナミアソムラ', '立野', 'タテノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県阿蘇郡南阿蘇村下野', '43', '43433', '8691402', '熊本県', 'クマモトケン', '阿蘇郡南阿蘇村', 'アソグンミナミアソムラ', '下野', 'シモノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県阿蘇郡南阿蘇村長野', '43', '43433', '8691403', '熊本県', 'クマモトケン', '阿蘇郡南阿蘇村', 'アソグンミナミアソムラ', '長野', 'ナガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県阿蘇郡南阿蘇村河陽', '43', '43433', '8691404', '熊本県', 'クマモトケン', '阿蘇郡南阿蘇村', 'アソグンミナミアソムラ', '河陽', 'カワヨウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県阿蘇郡南阿蘇村河陰', '43', '43433', '8691411', '熊本県', 'クマモトケン', '阿蘇郡南阿蘇村', 'アソグンミナミアソムラ', '河陰', 'カイン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県阿蘇郡南阿蘇村久石', '43', '43433', '8691412', '熊本県', 'クマモトケン', '阿蘇郡南阿蘇村', 'アソグンミナミアソムラ', '久石', 'ヒサイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県阿蘇郡南阿蘇村両併', '43', '43433', '8691501', '熊本県', 'クマモトケン', '阿蘇郡南阿蘇村', 'アソグンミナミアソムラ', '両併', 'リョウヘイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県阿蘇郡南阿蘇村白川', '43', '43433', '8691502', '熊本県', 'クマモトケン', '阿蘇郡南阿蘇村', 'アソグンミナミアソムラ', '白川', 'シラカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県阿蘇郡南阿蘇村吉田', '43', '43433', '8691503', '熊本県', 'クマモトケン', '阿蘇郡南阿蘇村', 'アソグンミナミアソムラ', '吉田', 'ヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県阿蘇郡南阿蘇村一関', '43', '43433', '8691504', '熊本県', 'クマモトケン', '阿蘇郡南阿蘇村', 'アソグンミナミアソムラ', '一関', 'イチゼキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県阿蘇郡南阿蘇村中松', '43', '43433', '8691505', '熊本県', 'クマモトケン', '阿蘇郡南阿蘇村', 'アソグンミナミアソムラ', '中松', 'ナカマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県阿蘇郡高森町', '43', '43428', '8691600', '熊本県', 'クマモトケン', '阿蘇郡高森町', 'アソグンタカモリマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('112617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県阿蘇郡高森町上色見', '43', '43428', '8691601', '熊本県', 'クマモトケン', '阿蘇郡高森町', 'アソグンタカモリマチ', '上色見', 'カミシキミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県阿蘇郡高森町高森', '43', '43428', '8691602', '熊本県', 'クマモトケン', '阿蘇郡高森町', 'アソグンタカモリマチ', '高森', 'タカモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県阿蘇郡高森町色見', '43', '43428', '8691603', '熊本県', 'クマモトケン', '阿蘇郡高森町', 'アソグンタカモリマチ', '色見', 'シキミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県阿蘇郡高森町草部', '43', '43428', '8691811', '熊本県', 'クマモトケン', '阿蘇郡高森町', 'アソグンタカモリマチ', '草部', 'クサカベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県阿蘇郡高森町芹口', '43', '43428', '8691812', '熊本県', 'クマモトケン', '阿蘇郡高森町', 'アソグンタカモリマチ', '芹口', 'セリグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県阿蘇郡高森町菅山', '43', '43428', '8691813', '熊本県', 'クマモトケン', '阿蘇郡高森町', 'アソグンタカモリマチ', '菅山', 'スガヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県阿蘇郡高森町永野原', '43', '43428', '8691814', '熊本県', 'クマモトケン', '阿蘇郡高森町', 'アソグンタカモリマチ', '永野原', 'ナガノハル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県阿蘇郡高森町下切', '43', '43428', '8691815', '熊本県', 'クマモトケン', '阿蘇郡高森町', 'アソグンタカモリマチ', '下切', 'シタギリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県阿蘇郡高森町中', '43', '43428', '8691821', '熊本県', 'クマモトケン', '阿蘇郡高森町', 'アソグンタカモリマチ', '中', 'ナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県阿蘇郡高森町矢津田', '43', '43428', '8691822', '熊本県', 'クマモトケン', '阿蘇郡高森町', 'アソグンタカモリマチ', '矢津田', 'ヤツダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県阿蘇郡高森町津留', '43', '43428', '8691823', '熊本県', 'クマモトケン', '阿蘇郡高森町', 'アソグンタカモリマチ', '津留', 'ツル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県阿蘇郡高森町野尻', '43', '43428', '8691824', '熊本県', 'クマモトケン', '阿蘇郡高森町', 'アソグンタカモリマチ', '野尻', 'ノジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県阿蘇郡高森町尾下', '43', '43428', '8691825', '熊本県', 'クマモトケン', '阿蘇郡高森町', 'アソグンタカモリマチ', '尾下', 'オクダリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県阿蘇郡高森町河原', '43', '43428', '8691826', '熊本県', 'クマモトケン', '阿蘇郡高森町', 'アソグンタカモリマチ', '河原', 'カワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県阿蘇郡南阿蘇村中松古坊中', '43', '43433', '8692205', '熊本県', 'クマモトケン', '阿蘇郡南阿蘇村', 'アソグンミナミアソムラ', '中松', 'ナカマツ', null, null, '古坊中', 'フルボウチュウ');
INSERT INTO `ms_addresses` VALUES ('112632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県阿蘇市役犬原', '43', '43214', '8692221', '熊本県', 'クマモトケン', '阿蘇市', 'アソシ', '役犬原', 'ヤクインバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県阿蘇市西町', '43', '43214', '8692222', '熊本県', 'クマモトケン', '阿蘇市', 'アソシ', '西町', 'ニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県阿蘇市竹原', '43', '43214', '8692223', '熊本県', 'クマモトケン', '阿蘇市', 'アソシ', '竹原', 'タカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県阿蘇市蔵原', '43', '43214', '8692224', '熊本県', 'クマモトケン', '阿蘇市', 'アソシ', '蔵原', 'クラバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県阿蘇市黒川', '43', '43214', '8692225', '熊本県', 'クマモトケン', '阿蘇市', 'アソシ', '黒川', 'クロカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県阿蘇市乙姫', '43', '43214', '8692226', '熊本県', 'クマモトケン', '阿蘇市', 'アソシ', '乙姫', 'オトヒメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県阿蘇市永草', '43', '43214', '8692231', '熊本県', 'クマモトケン', '阿蘇市', 'アソシ', '永草', 'ナガクサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県阿蘇市赤水', '43', '43214', '8692232', '熊本県', 'クマモトケン', '阿蘇市', 'アソシ', '赤水', 'アカミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県阿蘇市無田', '43', '43214', '8692233', '熊本県', 'クマモトケン', '阿蘇市', 'アソシ', '無田', 'ムタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県阿蘇市車帰', '43', '43214', '8692234', '熊本県', 'クマモトケン', '阿蘇市', 'アソシ', '車帰', 'クルマガエリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県阿蘇市狩尾', '43', '43214', '8692235', '熊本県', 'クマモトケン', '阿蘇市', 'アソシ', '狩尾', 'カリオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県阿蘇市跡ケ瀬', '43', '43214', '8692236', '熊本県', 'クマモトケン', '阿蘇市', 'アソシ', '跡ケ瀬', 'アトガセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県阿蘇市的石', '43', '43214', '8692237', '熊本県', 'クマモトケン', '阿蘇市', 'アソシ', '的石', 'マトイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県阿蘇市内牧', '43', '43214', '8692301', '熊本県', 'クマモトケン', '阿蘇市', 'アソシ', '内牧', 'ウチノマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県阿蘇市三久保', '43', '43214', '8692302', '熊本県', 'クマモトケン', '阿蘇市', 'アソシ', '三久保', 'ミクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県阿蘇市西小園', '43', '43214', '8692303', '熊本県', 'クマモトケン', '阿蘇市', 'アソシ', '西小園', 'ニシコゾノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県阿蘇市西湯浦', '43', '43214', '8692304', '熊本県', 'クマモトケン', '阿蘇市', 'アソシ', '西湯浦', 'ニシユノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県阿蘇市湯浦', '43', '43214', '8692305', '熊本県', 'クマモトケン', '阿蘇市', 'アソシ', '湯浦', 'ユノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県阿蘇市南宮原', '43', '43214', '8692306', '熊本県', 'クマモトケン', '阿蘇市', 'アソシ', '南宮原', 'ミナミミヤバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県阿蘇市小里', '43', '43214', '8692307', '熊本県', 'クマモトケン', '阿蘇市', 'アソシ', '小里', 'オザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県阿蘇市小池', '43', '43214', '8692311', '熊本県', 'クマモトケン', '阿蘇市', 'アソシ', '小池', 'コウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県阿蘇市小倉', '43', '43214', '8692312', '熊本県', 'クマモトケン', '阿蘇市', 'アソシ', '小倉', 'オクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県阿蘇市山田', '43', '43214', '8692313', '熊本県', 'クマモトケン', '阿蘇市', 'アソシ', '山田', 'ヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県阿蘇市小野田', '43', '43214', '8692314', '熊本県', 'クマモトケン', '阿蘇市', 'アソシ', '小野田', 'オノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県阿蘇市今町', '43', '43214', '8692315', '熊本県', 'クマモトケン', '阿蘇市', 'アソシ', '今町', 'イママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県阿蘇市黒流町', '43', '43214', '8692316', '熊本県', 'クマモトケン', '阿蘇市', 'アソシ', '黒流町', 'クロナガレマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県阿蘇郡南小国町', '43', '43423', '8692400', '熊本県', 'クマモトケン', '阿蘇郡南小国町', 'アソグンミナミオグニマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('112659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県阿蘇郡南小国町赤馬場', '43', '43423', '8692401', '熊本県', 'クマモトケン', '阿蘇郡南小国町', 'アソグンミナミオグニマチ', '赤馬場', 'アカババ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県阿蘇郡南小国町満願寺', '43', '43423', '8692402', '熊本県', 'クマモトケン', '阿蘇郡南小国町', 'アソグンミナミオグニマチ', '満願寺', 'マンガンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県阿蘇郡南小国町中原', '43', '43423', '8692403', '熊本県', 'クマモトケン', '阿蘇郡南小国町', 'アソグンミナミオグニマチ', '中原', 'ナカバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県阿蘇市山田蔵床', '43', '43214', '8692413', '熊本県', 'クマモトケン', '阿蘇市', 'アソシ', '山田', 'ヤマダ', null, null, '蔵床', 'クラトコ');
INSERT INTO `ms_addresses` VALUES ('112663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県阿蘇市山田橋台', '43', '43214', '8692413', '熊本県', 'クマモトケン', '阿蘇市', 'アソシ', '山田', 'ヤマダ', null, null, '橋台', 'ハシダイ');
INSERT INTO `ms_addresses` VALUES ('112664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県阿蘇市山田茗ケ原', '43', '43214', '8692413', '熊本県', 'クマモトケン', '阿蘇市', 'アソシ', '山田', 'ヤマダ', null, null, '茗ケ原', 'ミョウガハラ');
INSERT INTO `ms_addresses` VALUES ('112667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県阿蘇郡小国町', '43', '43424', '8692500', '熊本県', 'クマモトケン', '阿蘇郡小国町', 'アソグンオグニマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('112668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県阿蘇郡小国町宮原', '43', '43424', '8692501', '熊本県', 'クマモトケン', '阿蘇郡小国町', 'アソグンオグニマチ', '宮原', 'ミヤハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県阿蘇郡小国町黒渕', '43', '43424', '8692502', '熊本県', 'クマモトケン', '阿蘇郡小国町', 'アソグンオグニマチ', '黒渕', 'クロブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県阿蘇郡小国町下城', '43', '43424', '8692503', '熊本県', 'クマモトケン', '阿蘇郡小国町', 'アソグンオグニマチ', '下城', 'シモジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県阿蘇郡小国町西里', '43', '43424', '8692504', '熊本県', 'クマモトケン', '阿蘇郡小国町', 'アソグンオグニマチ', '西里', 'ニシザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県阿蘇郡小国町北里', '43', '43424', '8692505', '熊本県', 'クマモトケン', '阿蘇郡小国町', 'アソグンオグニマチ', '北里', 'キタザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県阿蘇郡小国町上田', '43', '43424', '8692506', '熊本県', 'クマモトケン', '阿蘇郡小国町', 'アソグンオグニマチ', '上田', 'カミダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県阿蘇市', '43', '43214', '8692600', '熊本県', 'クマモトケン', '阿蘇市', 'アソシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('112679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県阿蘇市一の宮町手野', '43', '43214', '8692601', '熊本県', 'クマモトケン', '阿蘇市', 'アソシ', '一の宮町手野', 'イチノミヤマチテノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県阿蘇市一の宮町三野', '43', '43214', '8692602', '熊本県', 'クマモトケン', '阿蘇市', 'アソシ', '一の宮町三野', 'イチノミヤマチサンノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県阿蘇市一の宮町北坂梨', '43', '43214', '8692603', '熊本県', 'クマモトケン', '阿蘇市', 'アソシ', '一の宮町北坂梨', 'イチノミヤマチキタサカナシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県阿蘇市一の宮町中坂梨', '43', '43214', '8692604', '熊本県', 'クマモトケン', '阿蘇市', 'アソシ', '一の宮町中坂梨', 'イチノミヤマチナカサカナシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県阿蘇市一の宮町坂梨', '43', '43214', '8692611', '熊本県', 'クマモトケン', '阿蘇市', 'アソシ', '一の宮町坂梨', 'イチノミヤマチサカナシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県阿蘇市一の宮町宮地', '43', '43214', '8692612', '熊本県', 'クマモトケン', '阿蘇市', 'アソシ', '一の宮町宮地', 'イチノミヤマチミヤジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県阿蘇市一の宮町中通', '43', '43214', '8692613', '熊本県', 'クマモトケン', '阿蘇市', 'アソシ', '一の宮町中通', 'イチノミヤマチナカドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県阿蘇市一の宮町荻の草', '43', '43214', '8692621', '熊本県', 'クマモトケン', '阿蘇市', 'アソシ', '一の宮町荻の草', 'イチノミヤマチオギノクサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県阿蘇郡産山村', '43', '43425', '8692700', '熊本県', 'クマモトケン', '阿蘇郡産山村', 'アソグンウブヤマムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('112692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県阿蘇郡産山村片俣', '43', '43425', '8692701', '熊本県', 'クマモトケン', '阿蘇郡産山村', 'アソグンウブヤマムラ', '片俣', 'カタマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県阿蘇郡産山村大利', '43', '43425', '8692702', '熊本県', 'クマモトケン', '阿蘇郡産山村', 'アソグンウブヤマムラ', '大利', 'オオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県阿蘇郡産山村山鹿', '43', '43425', '8692703', '熊本県', 'クマモトケン', '阿蘇郡産山村', 'アソグンウブヤマムラ', '山鹿', 'ヤマガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県阿蘇郡産山村田尻', '43', '43425', '8692704', '熊本県', 'クマモトケン', '阿蘇郡産山村', 'アソグンウブヤマムラ', '田尻', 'タジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県阿蘇郡産山村産山', '43', '43425', '8692705', '熊本県', 'クマモトケン', '阿蘇郡産山村', 'アソグンウブヤマムラ', '産山', 'ウブヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県阿蘇市波野小地野', '43', '43214', '8692801', '熊本県', 'クマモトケン', '阿蘇市', 'アソシ', '波野小地野', 'ナミノショウチノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県阿蘇市波野小園', '43', '43214', '8692802', '熊本県', 'クマモトケン', '阿蘇市', 'アソシ', '波野小園', 'ナミノオゾノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県阿蘇市波野赤仁田', '43', '43214', '8692803', '熊本県', 'クマモトケン', '阿蘇市', 'アソシ', '波野赤仁田', 'ナミノアカニタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県阿蘇市波野滝水', '43', '43214', '8692804', '熊本県', 'クマモトケン', '阿蘇市', 'アソシ', '波野滝水', 'ナミノタキミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県阿蘇市波野中江', '43', '43214', '8692805', '熊本県', 'クマモトケン', '阿蘇市', 'アソシ', '波野中江', 'ナミノナカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県阿蘇市波野波野', '43', '43214', '8692806', '熊本県', 'クマモトケン', '阿蘇市', 'アソシ', '波野波野', 'ナミノナミノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県阿蘇市波野新波野', '43', '43214', '8692807', '熊本県', 'クマモトケン', '阿蘇市', 'アソシ', '波野新波野', 'ナミノシンナミノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇土市長浜町', '43', '43211', '8693171', '熊本県', 'クマモトケン', '宇土市', 'ウトシ', '長浜町', 'ナガハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇土市上網田町', '43', '43211', '8693172', '熊本県', 'クマモトケン', '宇土市', 'ウトシ', '上網田町', 'カミオウダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇土市下網田町', '43', '43211', '8693173', '熊本県', 'クマモトケン', '宇土市', 'ウトシ', '下網田町', 'シモオウダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇土市戸口町', '43', '43211', '8693174', '熊本県', 'クマモトケン', '宇土市', 'ウトシ', '戸口町', 'トグチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇土市赤瀬町', '43', '43211', '8693175', '熊本県', 'クマモトケン', '宇土市', 'ウトシ', '赤瀬町', 'アカセマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇城市三角町大田尾', '43', '43213', '8693201', '熊本県', 'クマモトケン', '宇城市', 'ウキシ', '三角町大田尾', 'ミスミマチオオタオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇城市三角町郡浦', '43', '43213', '8693202', '熊本県', 'クマモトケン', '宇城市', 'ウキシ', '三角町郡浦', 'ミスミマチコオノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇城市三角町戸馳', '43', '43213', '8693203', '熊本県', 'クマモトケン', '宇城市', 'ウキシ', '三角町戸馳', 'ミスミマチトバセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇城市三角町中村', '43', '43213', '8693204', '熊本県', 'クマモトケン', '宇城市', 'ウキシ', '三角町中村', 'ミスミマチナカムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇城市三角町波多', '43', '43213', '8693205', '熊本県', 'クマモトケン', '宇城市', 'ウキシ', '三角町波多', 'ミスミマチハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇城市三角町前越', '43', '43213', '8693206', '熊本県', 'クマモトケン', '宇城市', 'ウキシ', '三角町前越', 'ミスミマチマエゴシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇城市三角町三角浦', '43', '43213', '8693207', '熊本県', 'クマモトケン', '宇城市', 'ウキシ', '三角町三角浦', 'ミスミマチミスミウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇城市三角町大口', '43', '43213', '8693411', '熊本県', 'クマモトケン', '宇城市', 'ウキシ', '三角町大口', 'ミスミマチオオクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇城市三角町手場', '43', '43213', '8693412', '熊本県', 'クマモトケン', '宇城市', 'ウキシ', '三角町手場', 'ミスミマチテバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇城市三角町里浦', '43', '43213', '8693413', '熊本県', 'クマモトケン', '宇城市', 'ウキシ', '三角町里浦', 'ミスミマチサトノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇城市不知火町永尾', '43', '43213', '8693471', '熊本県', 'クマモトケン', '宇城市', 'ウキシ', '不知火町永尾', 'シラヌヒマチエイノオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇城市不知火町松合', '43', '43213', '8693472', '熊本県', 'クマモトケン', '宇城市', 'ウキシ', '不知火町松合', 'シラヌヒマチマツアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県宇城市不知火町大見', '43', '43213', '8693473', '熊本県', 'クマモトケン', '宇城市', 'ウキシ', '不知火町大見', 'シラヌヒマチオオミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上天草市', '43', '43212', '8693600', '熊本県', 'クマモトケン', '上天草市', 'カミアマクサシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('112724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上天草市大矢野町登立', '43', '43212', '8693601', '熊本県', 'クマモトケン', '上天草市', 'カミアマクサシ', '大矢野町登立', 'オオヤノマチノボリタテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上天草市大矢野町上', '43', '43212', '8693602', '熊本県', 'クマモトケン', '上天草市', 'カミアマクサシ', '大矢野町上', 'オオヤノマチカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上天草市大矢野町中', '43', '43212', '8693603', '熊本県', 'クマモトケン', '上天草市', 'カミアマクサシ', '大矢野町中', 'オオヤノマチナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上天草市大矢野町維和', '43', '43212', '8693604', '熊本県', 'クマモトケン', '上天草市', 'カミアマクサシ', '大矢野町維和', 'オオヤノマチイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県上天草市大矢野町湯島', '43', '43212', '8693711', '熊本県', 'クマモトケン', '上天草市', 'カミアマクサシ', '大矢野町湯島', 'オオヤノマチユシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市鏡町鏡村', '43', '43202', '8694201', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '鏡町鏡村', 'カガミマチカガミムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市鏡町内田', '43', '43202', '8694202', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '鏡町内田', 'カガミマチウチダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市鏡町鏡', '43', '43202', '8694203', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '鏡町鏡', 'カガミマチカガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市鏡町芝口', '43', '43202', '8694204', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '鏡町芝口', 'カガミマチシバクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市鏡町野崎', '43', '43202', '8694205', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '鏡町野崎', 'カガミマチノザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市鏡町上鏡', '43', '43202', '8694211', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '鏡町上鏡', 'カガミマチカミカガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市鏡町下有佐', '43', '43202', '8694212', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '鏡町下有佐', 'カガミマチシモアリサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市鏡町有佐', '43', '43202', '8694213', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '鏡町有佐', 'カガミマチアリサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市鏡町中島', '43', '43202', '8694214', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '鏡町中島', 'カガミマチナカシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市鏡町下村', '43', '43202', '8694215', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '鏡町下村', 'カガミマチシモムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市鏡町宝出', '43', '43202', '8694221', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '鏡町宝出', 'カガミマチホウデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市鏡町両出', '43', '43202', '8694222', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '鏡町両出', 'カガミマチリョウデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市鏡町貝洲', '43', '43202', '8694223', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '鏡町貝洲', 'カガミマチカイズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市鏡町塩浜', '43', '43202', '8694224', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '鏡町塩浜', 'カガミマチシオハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市鏡町北新地', '43', '43202', '8694225', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '鏡町北新地', 'カガミマチキタシンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市東陽町南', '43', '43202', '8694301', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '東陽町南', 'トウヨウマチミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市東陽町北', '43', '43202', '8694302', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '東陽町北', 'トウヨウマチキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市東陽町河俣', '43', '43202', '8694303', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '東陽町河俣', 'トウヨウマチカワマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市東陽町小浦', '43', '43202', '8694304', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '東陽町小浦', 'トウヨウマチコウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市泉町柿迫', '43', '43202', '8694401', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '泉町柿迫', 'イズミマチカキザコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市泉町栗木', '43', '43202', '8694402', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '泉町栗木', 'イズミマチクリギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市泉町下岳', '43', '43202', '8694403', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '泉町下岳', 'イズミマチシモダケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市泉町柿迫', '43', '43202', '8694501', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '泉町柿迫', 'イズミマチカキザコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市泉町葉木', '43', '43202', '8694511', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '泉町葉木', 'イズミマチハギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市泉町樅木', '43', '43202', '8694512', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '泉町樅木', 'イズミマチモミギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市泉町久連子', '43', '43202', '8694513', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '泉町久連子', 'イズミマチクレコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市泉町椎原', '43', '43202', '8694514', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '泉町椎原', 'イズミマチシイバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市泉町仁田尾', '43', '43202', '8694515', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '泉町仁田尾', 'イズミマチニタオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代郡氷川町', '43', '43468', '8694600', '熊本県', 'クマモトケン', '八代郡氷川町', 'ヤツシログンヒカワチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('112760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代郡氷川町今', '43', '43468', '8694601', '熊本県', 'クマモトケン', '八代郡氷川町', 'ヤツシログンヒカワチョウ', '今', 'イマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代郡氷川町宮原', '43', '43468', '8694602', '熊本県', 'クマモトケン', '八代郡氷川町', 'ヤツシログンヒカワチョウ', '宮原', 'ミヤハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代郡氷川町立神', '43', '43468', '8694603', '熊本県', 'クマモトケン', '八代郡氷川町', 'ヤツシログンヒカワチョウ', '立神', 'タテガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代郡氷川町有佐', '43', '43468', '8694604', '熊本県', 'クマモトケン', '八代郡氷川町', 'ヤツシログンヒカワチョウ', '有佐', 'アリサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代郡氷川町中島', '43', '43468', '8694605', '熊本県', 'クマモトケン', '八代郡氷川町', 'ヤツシログンヒカワチョウ', '中島', 'ナカシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代郡氷川町早尾', '43', '43468', '8694606', '熊本県', 'クマモトケン', '八代郡氷川町', 'ヤツシログンヒカワチョウ', '早尾', 'ハヤオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代郡氷川町栫', '43', '43468', '8694607', '熊本県', 'クマモトケン', '八代郡氷川町', 'ヤツシログンヒカワチョウ', '栫', 'カコイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代郡氷川町宮原栄久', '43', '43468', '8694608', '熊本県', 'クマモトケン', '八代郡氷川町', 'ヤツシログンヒカワチョウ', '宮原栄久', 'ミヤハラエイキュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市岡町小路', '43', '43202', '8694611', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '岡町小路', 'オカマチショウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市岡町中', '43', '43202', '8694612', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '岡町中', 'オカマチナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市岡町谷川', '43', '43202', '8694613', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '岡町谷川', 'オカマチタニガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市興善寺町', '43', '43202', '8694614', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '興善寺町', 'コウゼンジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市川田町東', '43', '43202', '8694615', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '川田町東', 'カワタマチヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市川田町西', '43', '43202', '8694616', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '川田町西', 'カワタマチニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市千丁町太牟田', '43', '43202', '8694701', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '千丁町太牟田', 'センチョウマチオオムタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市千丁町吉王丸', '43', '43202', '8694702', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '千丁町吉王丸', 'センチョウマチヨシオウマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市千丁町新牟田', '43', '43202', '8694703', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '千丁町新牟田', 'センチョウマチシンムタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市千丁町古閑出', '43', '43202', '8694704', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '千丁町古閑出', 'センチョウマチコガデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市昭和日進町', '43', '43202', '8694721', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '昭和日進町', 'ショウワニッシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市昭和明徴町', '43', '43202', '8694722', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '昭和明徴町', 'ショウワメイチョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市昭和同仁町', '43', '43202', '8694723', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '昭和同仁町', 'ショウワドウジンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代郡氷川町新田', '43', '43468', '8694801', '熊本県', 'クマモトケン', '八代郡氷川町', 'ヤツシログンヒカワチョウ', '新田', 'シンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代郡氷川町高塚', '43', '43468', '8694802', '熊本県', 'クマモトケン', '八代郡氷川町', 'ヤツシログンヒカワチョウ', '高塚', 'タカツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代郡氷川町吉本', '43', '43468', '8694803', '熊本県', 'クマモトケン', '八代郡氷川町', 'ヤツシログンヒカワチョウ', '吉本', 'ヨシモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代郡氷川町大野', '43', '43468', '8694804', '熊本県', 'クマモトケン', '八代郡氷川町', 'ヤツシログンヒカワチョウ', '大野', 'オオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代郡氷川町野津', '43', '43468', '8694805', '熊本県', 'クマモトケン', '八代郡氷川町', 'ヤツシログンヒカワチョウ', '野津', 'ノヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代郡氷川町河原', '43', '43468', '8694806', '熊本県', 'クマモトケン', '八代郡氷川町', 'ヤツシログンヒカワチョウ', '河原', 'カワハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代郡氷川町鹿野', '43', '43468', '8694811', '熊本県', 'クマモトケン', '八代郡氷川町', 'ヤツシログンヒカワチョウ', '鹿野', 'カノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代郡氷川町網道', '43', '43468', '8694812', '熊本県', 'クマモトケン', '八代郡氷川町', 'ヤツシログンヒカワチョウ', '網道', 'アミドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代郡氷川町若洲', '43', '43468', '8694813', '熊本県', 'クマモトケン', '八代郡氷川町', 'ヤツシログンヒカワチョウ', '若洲', 'ワカス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代郡氷川町島地', '43', '43468', '8694814', '熊本県', 'クマモトケン', '八代郡氷川町', 'ヤツシログンヒカワチョウ', '島地', 'シマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代郡氷川町鹿島', '43', '43468', '8694815', '熊本県', 'クマモトケン', '八代郡氷川町', 'ヤツシログンヒカワチョウ', '鹿島', 'カシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市日奈久馬越町', '43', '43202', '8695131', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '日奈久馬越町', 'ヒナグマゴシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市日奈久下西町', '43', '43202', '8695132', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '日奈久下西町', 'ヒナグシモニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市日奈久中西町', '43', '43202', '8695133', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '日奈久中西町', 'ヒナグナカニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市日奈久上西町', '43', '43202', '8695134', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '日奈久上西町', 'ヒナグカミニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市日奈久中町', '43', '43202', '8695135', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '日奈久中町', 'ヒナグナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市日奈久東町', '43', '43202', '8695136', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '日奈久東町', 'ヒナグヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市日奈久浜町', '43', '43202', '8695137', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '日奈久浜町', 'ヒナグハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市日奈久平成町', '43', '43202', '8695138', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '日奈久平成町', 'ヒナグヘイセイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市日奈久塩南町', '43', '43202', '8695141', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '日奈久塩南町', 'ヒナグシオミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市日奈久塩北町', '43', '43202', '8695142', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '日奈久塩北町', 'ヒナグシオキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市日奈久竹之内町', '43', '43202', '8695143', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '日奈久竹之内町', 'ヒナグタケノウチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市日奈久山下町', '43', '43202', '8695144', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '日奈久山下町', 'ヒナグヤマシタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市日奈久新田町', '43', '43202', '8695145', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '日奈久新田町', 'ヒナグシンデンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市日奈久大坪町', '43', '43202', '8695146', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '日奈久大坪町', 'ヒナグオオツボマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市日奈久新開町', '43', '43202', '8695147', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '日奈久新開町', 'ヒナグシンカイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市日奈久栄町', '43', '43202', '8695148', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '日奈久栄町', 'ヒナグサカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市敷川内町', '43', '43202', '8695151', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '敷川内町', 'シキガワチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市揚町', '43', '43202', '8695152', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '揚町', 'アゲマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市催合町', '43', '43202', '8695153', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '催合町', 'モヤイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市高植本町', '43', '43202', '8695154', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '高植本町', 'タカウエホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市水島町', '43', '43202', '8695155', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '水島町', 'ミズシママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市葭牟田町', '43', '43202', '8695161', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '葭牟田町', 'ヨシムタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市北原町', '43', '43202', '8695162', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '北原町', 'キタバラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市三江湖町', '43', '43202', '8695163', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '三江湖町', 'ミツエゴマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市鼠蔵町', '43', '43202', '8695164', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '鼠蔵町', 'ソゾウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市南平和町', '43', '43202', '8695165', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '南平和町', 'ミナミヘイワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市北平和町', '43', '43202', '8695166', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '北平和町', 'キタヘイワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市二見洲口町', '43', '43202', '8695171', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '二見洲口町', 'フタミスグチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市二見本町', '43', '43202', '8695172', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '二見本町', 'フタミホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市二見赤松町', '43', '43202', '8695173', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '二見赤松町', 'フタミアカマツマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市二見下大野町', '43', '43202', '8695174', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '二見下大野町', 'フタミシモオオノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市二見野田崎町', '43', '43202', '8695175', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '二見野田崎町', 'フタミノタザキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市坂本町川嶽', '43', '43202', '8695221', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '坂本町川嶽', 'サカモトマチカワタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市坂本町鶴喰', '43', '43202', '8695222', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '坂本町鶴喰', 'サカモトマチツルバミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市坂本町田上', '43', '43202', '8695223', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '坂本町田上', 'サカモトマチタガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市坂本町百済来下', '43', '43202', '8695224', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '坂本町百済来下', 'サカモトマチクダラギシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市坂本町百済来上', '43', '43202', '8695225', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '坂本町百済来上', 'サカモトマチクダラギカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県葦北郡芦北町横居木', '43', '43482', '8695301', '熊本県', 'クマモトケン', '葦北郡芦北町', 'アシキタグンアシキタマチ', '横居木', 'ヨコイギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県葦北郡芦北町田浦', '43', '43482', '8695302', '熊本県', 'クマモトケン', '葦北郡芦北町', 'アシキタグンアシキタマチ', '田浦', 'タノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県葦北郡芦北町小田浦', '43', '43482', '8695303', '熊本県', 'クマモトケン', '葦北郡芦北町', 'アシキタグンアシキタマチ', '小田浦', 'コダノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県葦北郡芦北町海浦', '43', '43482', '8695304', '熊本県', 'クマモトケン', '葦北郡芦北町', 'アシキタグンアシキタマチ', '海浦', 'ウミノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県葦北郡芦北町田浦町', '43', '43482', '8695305', '熊本県', 'クマモトケン', '葦北郡芦北町', 'アシキタグンアシキタマチ', '田浦町', 'タノウラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県葦北郡芦北町波多島', '43', '43482', '8695306', '熊本県', 'クマモトケン', '葦北郡芦北町', 'アシキタグンアシキタマチ', '波多島', 'ハタトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県葦北郡芦北町井牟田', '43', '43482', '8695307', '熊本県', 'クマモトケン', '葦北郡芦北町', 'アシキタグンアシキタマチ', '井牟田', 'イムタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県葦北郡芦北町', '43', '43482', '8695400', '熊本県', 'クマモトケン', '葦北郡芦北町', 'アシキタグンアシキタマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('112839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県葦北郡芦北町立川', '43', '43482', '8695421', '熊本県', 'クマモトケン', '葦北郡芦北町', 'アシキタグンアシキタマチ', '立川', 'タチカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県葦北郡芦北町大尼田', '43', '43482', '8695422', '熊本県', 'クマモトケン', '葦北郡芦北町', 'アシキタグンアシキタマチ', '大尼田', 'オオニタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県葦北郡芦北町松生', '43', '43482', '8695423', '熊本県', 'クマモトケン', '葦北郡芦北町', 'アシキタグンアシキタマチ', '松生', 'マツバエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県葦北郡芦北町伏木氏', '43', '43482', '8695424', '熊本県', 'クマモトケン', '葦北郡芦北町', 'アシキタグンアシキタマチ', '伏木氏', 'フシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県葦北郡芦北町乙千屋', '43', '43482', '8695431', '熊本県', 'クマモトケン', '葦北郡芦北町', 'アシキタグンアシキタマチ', '乙千屋', 'オトジヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県葦北郡芦北町宮浦', '43', '43482', '8695432', '熊本県', 'クマモトケン', '葦北郡芦北町', 'アシキタグンアシキタマチ', '宮浦', 'ミヤノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県葦北郡芦北町八幡', '43', '43482', '8695433', '熊本県', 'クマモトケン', '葦北郡芦北町', 'アシキタグンアシキタマチ', '八幡', 'ヤハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県葦北郡芦北町桑原', '43', '43482', '8695434', '熊本県', 'クマモトケン', '葦北郡芦北町', 'アシキタグンアシキタマチ', '桑原', 'クワバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県葦北郡芦北町佐敷', '43', '43482', '8695441', '熊本県', 'クマモトケン', '葦北郡芦北町', 'アシキタグンアシキタマチ', '佐敷', 'サシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県葦北郡芦北町花岡', '43', '43482', '8695442', '熊本県', 'クマモトケン', '葦北郡芦北町', 'アシキタグンアシキタマチ', '花岡', 'ハナオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県葦北郡芦北町田川', '43', '43482', '8695443', '熊本県', 'クマモトケン', '葦北郡芦北町', 'アシキタグンアシキタマチ', '田川', 'タガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県葦北郡芦北町道川内', '43', '43482', '8695451', '熊本県', 'クマモトケン', '葦北郡芦北町', 'アシキタグンアシキタマチ', '道川内', 'ミチガワチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県葦北郡芦北町白岩', '43', '43482', '8695452', '熊本県', 'クマモトケン', '葦北郡芦北町', 'アシキタグンアシキタマチ', '白岩', 'シライワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県葦北郡芦北町計石', '43', '43482', '8695453', '熊本県', 'クマモトケン', '葦北郡芦北町', 'アシキタグンアシキタマチ', '計石', 'ハカリイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県葦北郡芦北町鶴木山', '43', '43482', '8695454', '熊本県', 'クマモトケン', '葦北郡芦北町', 'アシキタグンアシキタマチ', '鶴木山', 'ツルギヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県葦北郡芦北町芦北', '43', '43482', '8695461', '熊本県', 'クマモトケン', '葦北郡芦北町', 'アシキタグンアシキタマチ', '芦北', 'アシキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県葦北郡芦北町芦北北田', '43', '43482', '8695561', '熊本県', 'クマモトケン', '葦北郡芦北町', 'アシキタグンアシキタマチ', '芦北', 'アシキタ', null, null, '北田', 'キタダ');
INSERT INTO `ms_addresses` VALUES ('112857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県葦北郡芦北町芦北中割', '43', '43482', '8695561', '熊本県', 'クマモトケン', '葦北郡芦北町', 'アシキタグンアシキタマチ', '芦北', 'アシキタ', null, null, '中割', 'ナカワリ');
INSERT INTO `ms_addresses` VALUES ('112858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県葦北郡芦北町芦北西割', '43', '43482', '8695561', '熊本県', 'クマモトケン', '葦北郡芦北町', 'アシキタグンアシキタマチ', '芦北', 'アシキタ', null, null, '西割', 'ニシワリ');
INSERT INTO `ms_addresses` VALUES ('112859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県葦北郡芦北町芦北松崎', '43', '43482', '8695561', '熊本県', 'クマモトケン', '葦北郡芦北町', 'アシキタグンアシキタマチ', '芦北', 'アシキタ', null, null, '松崎', 'マツザキ');
INSERT INTO `ms_addresses` VALUES ('112860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県葦北郡芦北町宮崎', '43', '43482', '8695562', '熊本県', 'クマモトケン', '葦北郡芦北町', 'アシキタグンアシキタマチ', '宮崎', 'ミヤザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県葦北郡芦北町湯浦', '43', '43482', '8695563', '熊本県', 'クマモトケン', '葦北郡芦北町', 'アシキタグンアシキタマチ', '湯浦', 'ユノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県葦北郡芦北町女島', '43', '43482', '8695564', '熊本県', 'クマモトケン', '葦北郡芦北町', 'アシキタグンアシキタマチ', '女島', 'メシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県葦北郡芦北町豊岡', '43', '43482', '8695571', '熊本県', 'クマモトケン', '葦北郡芦北町', 'アシキタグンアシキタマチ', '豊岡', 'トヨオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県葦北郡芦北町丸山', '43', '43482', '8695572', '熊本県', 'クマモトケン', '葦北郡芦北町', 'アシキタグンアシキタマチ', '丸山', 'マルヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県葦北郡芦北町米田', '43', '43482', '8695573', '熊本県', 'クマモトケン', '葦北郡芦北町', 'アシキタグンアシキタマチ', '米田', 'ヨネダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県葦北郡芦北町大川内', '43', '43482', '8695574', '熊本県', 'クマモトケン', '葦北郡芦北町', 'アシキタグンアシキタマチ', '大川内', 'オオカワチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県葦北郡芦北町古石', '43', '43482', '8695575', '熊本県', 'クマモトケン', '葦北郡芦北町', 'アシキタグンアシキタマチ', '古石', 'フルイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県葦北郡芦北町高岡', '43', '43482', '8695576', '熊本県', 'クマモトケン', '葦北郡芦北町', 'アシキタグンアシキタマチ', '高岡', 'タカオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県葦北郡津奈木町', '43', '43484', '8695600', '熊本県', 'クマモトケン', '葦北郡津奈木町', 'アシキタグンツナギマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('112870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県葦北郡津奈木町千代', '43', '43484', '8695601', '熊本県', 'クマモトケン', '葦北郡津奈木町', 'アシキタグンツナギマチ', '千代', 'チヨ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県葦北郡津奈木町津奈木', '43', '43484', '8695602', '熊本県', 'クマモトケン', '葦北郡津奈木町', 'アシキタグンツナギマチ', '津奈木', 'ツナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県葦北郡津奈木町岩城', '43', '43484', '8695603', '熊本県', 'クマモトケン', '葦北郡津奈木町', 'アシキタグンツナギマチ', '岩城', 'イワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県葦北郡津奈木町小津奈木', '43', '43484', '8695604', '熊本県', 'クマモトケン', '葦北郡津奈木町', 'アシキタグンツナギマチ', '小津奈木', 'コツナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県葦北郡津奈木町福浜', '43', '43484', '8695605', '熊本県', 'クマモトケン', '葦北郡津奈木町', 'アシキタグンツナギマチ', '福浜', 'フクハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市坂本町西部', '43', '43202', '8696101', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '坂本町西部', 'サカモトマチサイブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市坂本町深水', '43', '43202', '8696102', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '坂本町深水', 'サカモトマチフカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市坂本町中谷', '43', '43202', '8696103', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '坂本町中谷', 'サカモトマチナカタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市坂本町鮎帰', '43', '43202', '8696104', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '坂本町鮎帰', 'サカモトマチアユガエリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市坂本町坂本', '43', '43202', '8696105', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '坂本町坂本', 'サカモトマチサカモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市坂本町葉木', '43', '43202', '8696111', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '坂本町葉木', 'サカモトマチハギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市坂本町鎌瀬', '43', '43202', '8696112', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '坂本町鎌瀬', 'サカモトマチカマセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市坂本町中津道', '43', '43202', '8696113', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '坂本町中津道', 'サカモトマチナカツミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市坂本町市ノ俣', '43', '43202', '8696114', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '坂本町市ノ俣', 'サカモトマチイチノマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県八代市坂本町荒瀬', '43', '43202', '8696115', '熊本県', 'クマモトケン', '八代市', 'ヤツシロシ', '坂本町荒瀬', 'サカモトマチアラセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県球磨郡球磨村神瀬', '43', '43513', '8696204', '熊本県', 'クマモトケン', '球磨郡球磨村', 'クマグンクマムラ', '神瀬', 'コウノセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県球磨郡球磨村大瀬', '43', '43513', '8696205', '熊本県', 'クマモトケン', '球磨郡球磨村', 'クマグンクマムラ', '大瀬', 'オオセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県葦北郡芦北町箙瀬', '43', '43482', '8696211', '熊本県', 'クマモトケン', '葦北郡芦北町', 'アシキタグンアシキタマチ', '箙瀬', 'エビラセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県葦北郡芦北町吉尾', '43', '43482', '8696212', '熊本県', 'クマモトケン', '葦北郡芦北町', 'アシキタグンアシキタマチ', '吉尾', 'ヨシオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県葦北郡芦北町大岩', '43', '43482', '8696213', '熊本県', 'クマモトケン', '葦北郡芦北町', 'アシキタグンアシキタマチ', '大岩', 'オオイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県葦北郡芦北町黒岩', '43', '43482', '8696214', '熊本県', 'クマモトケン', '葦北郡芦北町', 'アシキタグンアシキタマチ', '黒岩', 'クロイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県葦北郡芦北町上原', '43', '43482', '8696215', '熊本県', 'クマモトケン', '葦北郡芦北町', 'アシキタグンアシキタマチ', '上原', 'ウワバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県葦北郡芦北町海路', '43', '43482', '8696216', '熊本県', 'クマモトケン', '葦北郡芦北町', 'アシキタグンアシキタマチ', '海路', 'カイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県葦北郡芦北町天月', '43', '43482', '8696301', '熊本県', 'クマモトケン', '葦北郡芦北町', 'アシキタグンアシキタマチ', '天月', 'アマツキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県葦北郡芦北町白石', '43', '43482', '8696302', '熊本県', 'クマモトケン', '葦北郡芦北町', 'アシキタグンアシキタマチ', '白石', 'シライシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県葦北郡芦北町告', '43', '43482', '8696303', '熊本県', 'クマモトケン', '葦北郡芦北町', 'アシキタグンアシキタマチ', '告', 'ツゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県葦北郡芦北町国見', '43', '43482', '8696304', '熊本県', 'クマモトケン', '葦北郡芦北町', 'アシキタグンアシキタマチ', '国見', 'クニミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県葦北郡芦北町大野', '43', '43482', '8696305', '熊本県', 'クマモトケン', '葦北郡芦北町', 'アシキタグンアシキタマチ', '大野', 'オオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県葦北郡芦北町市野瀬', '43', '43482', '8696306', '熊本県', 'クマモトケン', '葦北郡芦北町', 'アシキタグンアシキタマチ', '市野瀬', 'イチノセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県葦北郡芦北町塩浸', '43', '43482', '8696307', '熊本県', 'クマモトケン', '葦北郡芦北町', 'アシキタグンアシキタマチ', '塩浸', 'シオヒタシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県葦北郡芦北町白木', '43', '43482', '8696308', '熊本県', 'クマモトケン', '葦北郡芦北町', 'アシキタグンアシキタマチ', '白木', 'シラキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県球磨郡球磨村', '43', '43513', '8696400', '熊本県', 'クマモトケン', '球磨郡球磨村', 'クマグンクマムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('112903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県球磨郡球磨村渡', '43', '43513', '8696401', '熊本県', 'クマモトケン', '球磨郡球磨村', 'クマグンクマムラ', '渡', 'ワタリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県球磨郡球磨村三ケ浦', '43', '43513', '8696402', '熊本県', 'クマモトケン', '球磨郡球磨村', 'クマグンクマムラ', '三ケ浦', 'サンガウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県球磨郡球磨村一勝地', '43', '43513', '8696403', '熊本県', 'クマモトケン', '球磨郡球磨村', 'クマグンクマムラ', '一勝地', 'イッショウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県球磨郡球磨村神瀬大槻', '43', '43513', '8696404', '熊本県', 'クマモトケン', '球磨郡球磨村', 'クマグンクマムラ', '神瀬', 'コウノセ', null, null, '大槻', 'オオツキ');
INSERT INTO `ms_addresses` VALUES ('112907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県球磨郡球磨村神瀬蔵谷', '43', '43513', '8696404', '熊本県', 'クマモトケン', '球磨郡球磨村', 'クマグンクマムラ', '神瀬', 'コウノセ', null, null, '蔵谷', 'クラタニ');
INSERT INTO `ms_addresses` VALUES ('112908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県球磨郡球磨村神瀬坂口', '43', '43513', '8696404', '熊本県', 'クマモトケン', '球磨郡球磨村', 'クマグンクマムラ', '神瀬', 'コウノセ', null, null, '坂口', 'サカグチ');
INSERT INTO `ms_addresses` VALUES ('112909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県球磨郡球磨村神瀬高沢', '43', '43513', '8696404', '熊本県', 'クマモトケン', '球磨郡球磨村', 'クマグンクマムラ', '神瀬', 'コウノセ', null, null, '高沢', 'タカザワ');
INSERT INTO `ms_addresses` VALUES ('112910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県球磨郡球磨村神瀬横井', '43', '43513', '8696404', '熊本県', 'クマモトケン', '球磨郡球磨村', 'クマグンクマムラ', '神瀬', 'コウノセ', null, null, '横井', 'ヨコイ');
INSERT INTO `ms_addresses` VALUES ('112911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '熊本県球磨郡球磨村大瀬沢見', '43', '43513', '8696405', '熊本県', 'クマモトケン', '球磨郡球磨村', 'クマグンクマムラ', '大瀬', 'オオセ', null, null, '沢見', 'サワミ');
INSERT INTO `ms_addresses` VALUES ('112912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道根室市', '01', '01223', '0870000', '北海道', 'ホッカイドウ', '根室市', 'ネムロシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('112913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市生石港町', '44', '44201', '8700001', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '生石港町', 'イクシミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市浜の市', '44', '44201', '8700002', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '浜の市', 'ハマノイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市生石', '44', '44201', '8700003', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '生石', 'イクシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市王子港町', '44', '44201', '8700004', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '王子港町', 'オウジミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市王子北町', '44', '44201', '8700005', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '王子北町', 'オウジキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市王子中町', '44', '44201', '8700006', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '王子中町', 'オウジナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市王子南町', '44', '44201', '8700007', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '王子南町', 'オウジミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市王子西町', '44', '44201', '8700008', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '王子西町', 'オウジニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市王子町', '44', '44201', '8700009', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '王子町', 'オウジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道根室市北浜町', '01', '01223', '0870001', '北海道', 'ホッカイドウ', '根室市', 'ネムロシ', '北浜町', 'キタハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市春日浦', '44', '44201', '8700011', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '春日浦', 'カスガウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市浜町北', '44', '44201', '8700012', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '浜町北', 'ハママチキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市浜町東', '44', '44201', '8700013', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '浜町東', 'ハママチヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市芦崎', '44', '44201', '8700014', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '芦崎', 'アシザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市新川西', '44', '44201', '8700015', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '新川西', 'シンカワニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市新川町', '44', '44201', '8700016', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '新川町', 'シンカワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市弁天', '44', '44201', '8700017', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '弁天', 'ベンテン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市豊海', '44', '44201', '8700018', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '豊海', 'トヨミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道根室市牧の内', '01', '01223', '0870002', '北海道', 'ホッカイドウ', '根室市', 'ネムロシ', '牧の内', 'マキノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市府内町', '44', '44201', '8700021', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '府内町', 'フナイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市大手町', '44', '44201', '8700022', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '大手町', 'オオテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市長浜町', '44', '44201', '8700023', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '長浜町', 'ナガハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市錦町', '44', '44201', '8700024', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '錦町', 'ニシキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市顕徳町', '44', '44201', '8700025', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '顕徳町', 'ケントクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市金池町', '44', '44201', '8700026', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '金池町', 'カナイケマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市末広町', '44', '44201', '8700027', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '末広町', 'スエヒロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市新町', '44', '44201', '8700028', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市高砂町', '44', '44201', '8700029', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '高砂町', 'タカサゴマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道根室市明治町', '01', '01223', '0870003', '北海道', 'ホッカイドウ', '根室市', 'ネムロシ', '明治町', 'メイジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市三芳', '44', '44201', '8700030', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '三芳', 'ミヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市勢家町', '44', '44201', '8700031', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '勢家町', 'セイケマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市住吉町', '44', '44201', '8700032', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '住吉町', 'スミヨシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市千代町', '44', '44201', '8700033', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '千代町', 'チヨマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市都町', '44', '44201', '8700034', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '都町', 'ミヤコマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市中央町', '44', '44201', '8700035', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '中央町', 'チュウオウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市寿町', '44', '44201', '8700036', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '寿町', 'コトブキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市東春日町', '44', '44201', '8700037', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '東春日町', 'ヒガシカスガマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市西春日町', '44', '44201', '8700038', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '西春日町', 'ニシカスガマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市中春日町', '44', '44201', '8700039', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '中春日町', 'ナカカスガマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道根室市光洋町', '01', '01223', '0870004', '北海道', 'ホッカイドウ', '根室市', 'ネムロシ', '光洋町', 'コウヨウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市泉町', '44', '44201', '8700041', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '泉町', 'イズミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市豊町', '44', '44201', '8700042', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '豊町', 'ユタカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市中島東', '44', '44201', '8700043', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '中島東', 'ナカシマヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市舞鶴町', '44', '44201', '8700044', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '舞鶴町', 'マイヅルマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市城崎町', '44', '44201', '8700045', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '城崎町', 'シロサキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市荷揚町', '44', '44201', '8700046', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '荷揚町', 'ニアゲマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市中島西', '44', '44201', '8700047', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '中島西', 'ナカシマニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市碩田町', '44', '44201', '8700048', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '碩田町', 'セキデンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市中島中央', '44', '44201', '8700049', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '中島中央', 'ナカシマチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道根室市宝町', '01', '01223', '0870005', '北海道', 'ホッカイドウ', '根室市', 'ネムロシ', '宝町', 'タカラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道根室市曙町', '01', '01223', '0870006', '北海道', 'ホッカイドウ', '根室市', 'ネムロシ', '曙町', 'アケボノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道根室市月見町', '01', '01223', '0870007', '北海道', 'ホッカイドウ', '根室市', 'ネムロシ', '月見町', 'ツキミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道根室市有磯町', '01', '01223', '0870008', '北海道', 'ホッカイドウ', '根室市', 'ネムロシ', '有磯町', 'アリイソチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道根室市弥栄町', '01', '01223', '0870009', '北海道', 'ホッカイドウ', '根室市', 'ネムロシ', '弥栄町', 'ヤサカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道根室市栄町', '01', '01223', '0870010', '北海道', 'ホッカイドウ', '根室市', 'ネムロシ', '栄町', 'サカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市', '44', '44201', '8700100', '大分県', 'オオイタケン', '大分市', 'オオイタシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('112969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市中鶴崎', '44', '44201', '8700101', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '中鶴崎', 'ナカツルサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市北鶴崎', '44', '44201', '8700102', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '北鶴崎', 'キタツルサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市東鶴崎', '44', '44201', '8700103', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '東鶴崎', 'ヒガシツルサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市南鶴崎', '44', '44201', '8700104', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '南鶴崎', 'ミナミツルサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市西鶴崎', '44', '44201', '8700105', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '西鶴崎', 'ニシツルサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市鶴崎', '44', '44201', '8700106', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '鶴崎', 'ツルサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市海原', '44', '44201', '8700107', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '海原', 'カイワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市三佐', '44', '44201', '8700108', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '三佐', 'ミサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市徳島', '44', '44201', '8700109', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '徳島', 'トクシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道根室市弁天町', '01', '01223', '0870011', '北海道', 'ホッカイドウ', '根室市', 'ネムロシ', '弁天町', 'ベンテンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市中ノ洲', '44', '44201', '8700111', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '中ノ洲', 'ナカノス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市一の洲', '44', '44201', '8700112', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '一の洲', 'イチノス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市家島', '44', '44201', '8700113', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '家島', 'イエジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市小中島', '44', '44201', '8700114', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '小中島', 'オナカシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市関園', '44', '44201', '8700115', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '関園', 'セキゾノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市常行', '44', '44201', '8700116', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '常行', 'ツネユキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市南', '44', '44201', '8700117', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '南', 'ミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市下徳丸', '44', '44201', '8700118', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '下徳丸', 'シモトクマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道根室市駒場町', '01', '01223', '0870012', '北海道', 'ホッカイドウ', '根室市', 'ネムロシ', '駒場町', 'コマバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市鶴崎コスモス団地', '44', '44201', '8700120', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '鶴崎コスモス団地', 'ツルサキコスモスダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市鶴瀬', '44', '44201', '8700121', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '鶴瀬', 'ツルセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市丸亀', '44', '44201', '8700122', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '丸亀', 'マルガメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市大津留', '44', '44201', '8700123', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '大津留', 'オオツル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市毛井', '44', '44201', '8700124', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '毛井', 'ケイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市松岡', '44', '44201', '8700125', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '松岡', 'マツオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市横尾', '44', '44201', '8700126', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '横尾', 'ヨコオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市森町', '44', '44201', '8700127', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '森町', 'モリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市森', '44', '44201', '8700128', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '森', 'モリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市京が丘南', '44', '44201', '8700129', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '京が丘南', 'キョウガオカミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市皆春', '44', '44201', '8700131', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '皆春', 'ミナハル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('112999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市千歳', '44', '44201', '8700132', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '千歳', 'センザイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市葛木', '44', '44201', '8700133', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '葛木', 'カツラギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市猪野', '44', '44201', '8700134', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '猪野', 'イノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市仲西町', '44', '44201', '8700135', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '仲西町', 'ナカニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市山津町', '44', '44201', '8700136', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '山津町', 'ヤマヅマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市寺崎町', '44', '44201', '8700137', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '寺崎町', 'テラサキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市原川', '44', '44201', '8700138', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '原川', 'ハルカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市桃園団地', '44', '44201', '8700139', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '桃園団地', 'モモゾノダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道根室市朝日町', '01', '01223', '0870014', '北海道', 'ホッカイドウ', '根室市', 'ネムロシ', '朝日町', 'アサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市三川新町', '44', '44201', '8700141', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '三川新町', 'ミツガワシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市三川下', '44', '44201', '8700142', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '三川下', 'ミツガワシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市三川上', '44', '44201', '8700143', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '三川上', 'ミツガワカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市乙津', '44', '44201', '8700144', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '乙津', 'オトヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市乙津町', '44', '44201', '8700145', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '乙津町', 'オトヅマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市乙津港町', '44', '44201', '8700146', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '乙津港町', 'オトヅミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市小池原', '44', '44201', '8700147', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '小池原', 'コイケバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市高城台', '44', '44201', '8700148', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '高城台', 'タカジョウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市高城団地', '44', '44201', '8700149', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '高城団地', 'タカジョウダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道根室市花咲町', '01', '01223', '0870015', '北海道', 'ホッカイドウ', '根室市', 'ネムロシ', '花咲町', 'ハナサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市東原', '44', '44201', '8700150', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '東原', 'ヒガシバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市東明野', '44', '44201', '8700151', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '東明野', 'ヒガシアケノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市牧', '44', '44201', '8700152', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '牧', 'マキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市城東町', '44', '44201', '8700153', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '城東町', 'ジョウトウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市高城西町', '44', '44201', '8700154', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '高城西町', 'タカジョウニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市高城南町', '44', '44201', '8700155', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '高城南町', 'タカジョウミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市高城新町', '44', '44201', '8700156', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '高城新町', 'タカジョウシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市高城本町', '44', '44201', '8700157', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '高城本町', 'タカジョウホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市岡', '44', '44201', '8700158', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '岡', 'オカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市岡新町', '44', '44201', '8700159', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '岡新町', 'オカシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道根室市松ケ枝町', '01', '01223', '0870016', '北海道', 'ホッカイドウ', '根室市', 'ネムロシ', '松ケ枝町', 'マツガエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市明野東', '44', '44201', '8700161', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '明野東', 'アケノヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市明野高尾', '44', '44201', '8700162', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '明野高尾', 'アケノタカオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市明野南', '44', '44201', '8700163', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '明野南', 'アケノミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市明野西', '44', '44201', '8700164', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '明野西', 'アケノニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市明野北', '44', '44201', '8700165', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '明野北', 'アケノキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市明野北町', '44', '44201', '8700166', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '明野北町', 'アケノキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市明野紅陽台', '44', '44201', '8700167', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '明野紅陽台', 'アケノコウヨウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市明野ハイツ', '44', '44201', '8700168', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '明野ハイツ', 'アケノハイツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道根室市鳴海町', '01', '01223', '0870017', '北海道', 'ホッカイドウ', '根室市', 'ネムロシ', '鳴海町', 'ナルミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市法勝台', '44', '44201', '8700171', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '法勝台', 'ホウショウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市新明治', '44', '44201', '8700172', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '新明治', 'シンメイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市公園通り', '44', '44201', '8700173', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '公園通り', 'コウエンドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市公園通り西', '44', '44201', '8700174', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '公園通り西', 'コウエンドオリニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道根室市千島町', '01', '01223', '0870018', '北海道', 'ホッカイドウ', '根室市', 'ネムロシ', '千島町', 'チシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道根室市汐見町', '01', '01223', '0870019', '北海道', 'ホッカイドウ', '根室市', 'ネムロシ', '汐見町', 'シオミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道根室市幸町', '01', '01223', '0870021', '北海道', 'ホッカイドウ', '根室市', 'ネムロシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道根室市昭和町', '01', '01223', '0870022', '北海道', 'ホッカイドウ', '根室市', 'ネムロシ', '昭和町', 'ショウワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道根室市桂木', '01', '01223', '0870023', '北海道', 'ホッカイドウ', '根室市', 'ネムロシ', '桂木', 'カツラギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道根室市宝林町', '01', '01223', '0870024', '北海道', 'ホッカイドウ', '根室市', 'ネムロシ', '宝林町', 'ホウリンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市庄境', '44', '44201', '8700241', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '庄境', 'ショウザカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市角子南', '44', '44201', '8700242', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '角子南', 'ツノゴミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市花江川', '44', '44201', '8700243', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '花江川', 'ハナエガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市須賀', '44', '44201', '8700244', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '須賀', 'スガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市大在北', '44', '44201', '8700245', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '大在北', 'オオザイキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道根室市西浜町', '01', '01223', '0870025', '北海道', 'ホッカイドウ', '根室市', 'ネムロシ', '西浜町', 'ニシハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市大在中央', '44', '44201', '8700251', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '大在中央', 'オオザイチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市大在浜', '44', '44201', '8700252', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '大在浜', 'オオザイハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市汐見', '44', '44201', '8700253', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '汐見', 'シオミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市横塚', '44', '44201', '8700254', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '横塚', 'ヨコヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道根室市敷島町', '01', '01223', '0870026', '北海道', 'ホッカイドウ', '根室市', 'ネムロシ', '敷島町', 'シキシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市志村', '44', '44201', '8700261', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '志村', 'シムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市横田', '44', '44201', '8700263', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '横田', 'ヨコタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市竹下', '44', '44201', '8700265', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '竹下', 'タケシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市大在', '44', '44201', '8700266', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '大在', 'オオザイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市城原', '44', '44201', '8700267', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '城原', 'ジョウハル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市政所', '44', '44201', '8700268', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '政所', 'マドコロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道根室市光和町', '01', '01223', '0870027', '北海道', 'ホッカイドウ', '根室市', 'ネムロシ', '光和町', 'コウワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市望みが丘', '44', '44201', '8700270', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '望みが丘', 'ノゾミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市角子原', '44', '44201', '8700271', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '角子原', 'ツノコバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市迫', '44', '44201', '8700272', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '迫', 'サコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市曙台', '44', '44201', '8700273', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '曙台', 'アケボノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市種具', '44', '44201', '8700274', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '種具', 'タネグ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市宮河内ハイランド', '44', '44201', '8700275', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '宮河内ハイランド', 'ミヤカワウチハイランド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市宮河内', '44', '44201', '8700276', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '宮河内', 'ミヤカワウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市広内', '44', '44201', '8700277', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '広内', 'ヒロウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市青崎', '44', '44201', '8700278', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '青崎', 'アオサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市つるさき陽光台', '44', '44201', '8700279', '大分県', 'オオイタケン', '大分市', 'オオイタシ', 'つるさき陽光台', 'ツルサキヨウコウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道根室市大正町', '01', '01223', '0870028', '北海道', 'ホッカイドウ', '根室市', 'ネムロシ', '大正町', 'タイショウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市日吉原', '44', '44201', '8700301', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '日吉原', 'ヒヨシバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市坂ノ市', '44', '44201', '8700302', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '坂ノ市', 'サカノイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市里', '44', '44201', '8700303', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '里', 'サト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市久原', '44', '44201', '8700304', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '久原', 'クバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市細', '44', '44201', '8700305', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '細', 'ホソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市東上野', '44', '44201', '8700306', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '東上野', 'ヒガシウエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市坂ノ市中央', '44', '44201', '8700307', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '坂ノ市中央', 'サカノイチチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市坂ノ市南', '44', '44201', '8700308', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '坂ノ市南', 'サカノイチミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市坂ノ市西', '44', '44201', '8700309', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '坂ノ市西', 'サカノイチニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道根室市月岡町', '01', '01223', '0870031', '北海道', 'ホッカイドウ', '根室市', 'ネムロシ', '月岡町', 'ツキオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市木田', '44', '44201', '8700311', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '木田', 'キダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市市尾', '44', '44201', '8700312', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '市尾', 'イチノオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市屋山', '44', '44201', '8700313', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '屋山', 'ヤヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市久土', '44', '44201', '8700314', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '久土', 'クド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市佐野', '44', '44201', '8700315', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '佐野', 'サノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市一木', '44', '44201', '8700316', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '一木', 'イチギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市丹川', '44', '44201', '8700317', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '丹川', 'アカガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市丹生', '44', '44201', '8700318', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '丹生', 'ニュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市大分流通業務団地', '44', '44201', '8700319', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '大分流通業務団地', 'オオイタリュウツウギョウムダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道根室市花咲港', '01', '01223', '0870032', '北海道', 'ホッカイドウ', '根室市', 'ネムロシ', '花咲港', 'ハナサキミナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市王ノ瀬', '44', '44201', '8700321', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '王ノ瀬', 'オウノセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市恵比寿町', '44', '44201', '8700322', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '恵比寿町', 'エビスマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市浜中', '44', '44201', '8700323', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '浜中', 'ハマナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市久原北', '44', '44201', '8700324', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '久原北', 'クバルキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市久原中央', '44', '44201', '8700325', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '久原中央', 'クバルチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市久原南', '44', '44201', '8700326', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '久原南', 'クバルミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市小佐井', '44', '44201', '8700327', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '小佐井', 'コザイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道根室市西和田', '01', '01223', '0870033', '北海道', 'ホッカイドウ', '根室市', 'ネムロシ', '西和田', 'ニシワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道根室市東和田', '01', '01223', '0870034', '北海道', 'ホッカイドウ', '根室市', 'ネムロシ', '東和田', 'ヒガシワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道根室市温根沼', '01', '01223', '0870035', '北海道', 'ホッカイドウ', '根室市', 'ネムロシ', '温根沼', 'オンネトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道根室市幌茂尻', '01', '01223', '0870036', '北海道', 'ホッカイドウ', '根室市', 'ネムロシ', '幌茂尻', 'ホロモシリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道根室市穂香', '01', '01223', '0870037', '北海道', 'ホッカイドウ', '根室市', 'ネムロシ', '穂香', 'ホニオイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道根室市常盤町', '01', '01223', '0870041', '北海道', 'ホッカイドウ', '根室市', 'ネムロシ', '常盤町', 'トキワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道根室市清隆町', '01', '01223', '0870042', '北海道', 'ホッカイドウ', '根室市', 'ネムロシ', '清隆町', 'キヨタカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道根室市北斗町', '01', '01223', '0870043', '北海道', 'ホッカイドウ', '根室市', 'ネムロシ', '北斗町', 'ホクトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道根室市松本町', '01', '01223', '0870044', '北海道', 'ホッカイドウ', '根室市', 'ネムロシ', '松本町', 'マツモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道根室市花園町', '01', '01223', '0870045', '北海道', 'ホッカイドウ', '根室市', 'ネムロシ', '花園町', 'ハナゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道根室市岬町', '01', '01223', '0870046', '北海道', 'ホッカイドウ', '根室市', 'ネムロシ', '岬町', 'ミサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道根室市定基町', '01', '01223', '0870047', '北海道', 'ホッカイドウ', '根室市', 'ネムロシ', '定基町', 'サダモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道根室市平内町', '01', '01223', '0870048', '北海道', 'ホッカイドウ', '根室市', 'ネムロシ', '平内町', 'ヘイナイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道根室市弥生町', '01', '01223', '0870049', '北海道', 'ホッカイドウ', '根室市', 'ネムロシ', '弥生町', 'ヤヨイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道根室市緑町', '01', '01223', '0870051', '北海道', 'ホッカイドウ', '根室市', 'ネムロシ', '緑町', 'ミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道根室市梅ケ枝町', '01', '01223', '0870052', '北海道', 'ホッカイドウ', '根室市', 'ネムロシ', '梅ケ枝町', 'ウメガエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道根室市本町', '01', '01223', '0870053', '北海道', 'ホッカイドウ', '根室市', 'ネムロシ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道根室市海岸町', '01', '01223', '0870054', '北海道', 'ホッカイドウ', '根室市', 'ネムロシ', '海岸町', 'カイガンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道根室市琴平町', '01', '01223', '0870055', '北海道', 'ホッカイドウ', '根室市', 'ネムロシ', '琴平町', 'コトヒラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市鳴川', '44', '44201', '8700801', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '鳴川', 'ナルカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市田ノ浦', '44', '44201', '8700802', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '田ノ浦', 'タノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市下白木', '44', '44201', '8700803', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '下白木', 'シモシラキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市御幸町', '44', '44201', '8700804', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '御幸町', 'ミユキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市上白木', '44', '44201', '8700805', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '上白木', 'カミシラキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市大久保', '44', '44201', '8700806', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '大久保', 'オオクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市下八幡', '44', '44201', '8700807', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '下八幡', 'シモヤハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市上八幡', '44', '44201', '8700808', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '上八幡', 'カミヤハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市机張原', '44', '44201', '8700809', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '机張原', 'キチョウバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市南生石西', '44', '44201', '8700811', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '南生石西', 'ミナミイクシニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市南生石東', '44', '44201', '8700812', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '南生石東', 'ミナミイクシヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市王子山の手町', '44', '44201', '8700813', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '王子山の手町', 'オウジヤマノテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市南王子町', '44', '44201', '8700814', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '南王子町', 'ミナミオウジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市南春日町', '44', '44201', '8700815', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '南春日町', 'ミナミカスガマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市田室町', '44', '44201', '8700816', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '田室町', 'タムロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市上春日町', '44', '44201', '8700817', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '上春日町', 'カミカスガマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市新春日町', '44', '44201', '8700818', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '新春日町', 'シンカスガマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市王子新町', '44', '44201', '8700819', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '王子新町', 'オウジシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市西大道', '44', '44201', '8700820', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '西大道', 'ニシオオミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市志手', '44', '44201', '8700821', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '志手', 'シテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市大道町', '44', '44201', '8700822', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '大道町', 'オオミチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市東大道', '44', '44201', '8700823', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '東大道', 'ヒガシオオミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市城南東町', '44', '44201', '8700824', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '城南東町', 'ジョウナンヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市城南南町', '44', '44201', '8700825', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '城南南町', 'ジョウナンミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市城南西町', '44', '44201', '8700826', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '城南西町', 'ジョウナンニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市城南北町', '44', '44201', '8700827', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '城南北町', 'ジョウナンキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市城南山手台', '44', '44201', '8700828', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '城南山手台', 'ジョウナンヤマテダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市椎迫', '44', '44201', '8700829', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '椎迫', 'シイザコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市要町', '44', '44201', '8700831', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '要町', 'カナメマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市上野町', '44', '44201', '8700832', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '上野町', 'ウエノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市上野丘東', '44', '44201', '8700833', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '上野丘東', 'ウエノガオカヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市上野丘西', '44', '44201', '8700834', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '上野丘西', 'ウエノガオカニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市上野丘', '44', '44201', '8700835', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '上野丘', 'ウエノガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市上野南', '44', '44201', '8700836', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '上野南', 'ウエノミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市太平町', '44', '44201', '8700837', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '太平町', 'タイヘイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市桜ケ丘', '44', '44201', '8700838', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '桜ケ丘', 'サクラガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市金池南', '44', '44201', '8700839', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '金池南', 'カナイケミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市六坊北町', '44', '44201', '8700841', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '六坊北町', 'ロクボウキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市六坊南町', '44', '44201', '8700842', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '六坊南町', 'ロクボウミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市元町', '44', '44201', '8700843', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '元町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市古国府', '44', '44201', '8700844', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '古国府', 'フルゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市古国府東', '44', '44201', '8700845', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '古国府東', 'フルゴウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市花園', '44', '44201', '8700846', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '花園', 'ハナゾノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市広瀬町', '44', '44201', '8700847', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '広瀬町', 'ヒロセマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市賀来北', '44', '44201', '8700848', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '賀来北', 'カクキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市賀来南', '44', '44201', '8700849', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '賀来南', 'カクミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市大石町', '44', '44201', '8700851', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '大石町', 'オオイシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市田中町', '44', '44201', '8700852', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '田中町', 'タナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市羽屋新町', '44', '44201', '8700853', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '羽屋新町', 'ハヤシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市羽屋', '44', '44201', '8700854', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '羽屋', 'ハヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市豊饒', '44', '44201', '8700855', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '豊饒', 'ブニョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市畑中', '44', '44201', '8700856', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '畑中', 'ハタケナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市明磧', '44', '44201', '8700857', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '明磧', 'アケガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市尼ケ瀬', '44', '44201', '8700858', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '尼ケ瀬', 'アマガセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市中の瀬団地', '44', '44201', '8700859', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '中の瀬団地', 'ナカノセダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市東院', '44', '44201', '8700861', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '東院', 'トイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市中尾', '44', '44201', '8700862', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '中尾', 'ナカオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市国分台', '44', '44201', '8700863', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '国分台', 'コクブダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市国分', '44', '44201', '8700864', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '国分', 'コクブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市国分団地', '44', '44201', '8700865', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '国分団地', 'コクブダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市平横瀬', '44', '44201', '8700866', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '平横瀬', 'ヒラヨコセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市東野台', '44', '44201', '8700867', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '東野台', 'トウノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市野田', '44', '44201', '8700868', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '野田', 'ノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市国分新町', '44', '44201', '8700869', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '国分新町', 'コクブシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市季の坂', '44', '44201', '8700870', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '季の坂', 'キノサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市東八幡', '44', '44201', '8700871', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '東八幡', 'ヒガシヤハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市高崎', '44', '44201', '8700872', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '高崎', 'タカサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市高尾台', '44', '44201', '8700873', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '高尾台', 'タカオダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市にじが丘', '44', '44201', '8700874', '大分県', 'オオイタケン', '大分市', 'オオイタシ', 'にじが丘', 'ニジガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市青葉台', '44', '44201', '8700875', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '青葉台', 'アオバダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市庄の原', '44', '44201', '8700876', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '庄の原', 'ショウノハル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市賀来', '44', '44201', '8700877', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '賀来', 'カク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市宮苑', '44', '44201', '8700878', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '宮苑', 'ミヤゾノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市金谷迫', '44', '44201', '8700879', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '金谷迫', 'カナヤザコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市はなの森', '44', '44201', '8700880', '大分県', 'オオイタケン', '大分市', 'オオイタシ', 'はなの森', 'ハナノモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市深河内', '44', '44201', '8700881', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '深河内', 'フカガワウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市竹の上', '44', '44201', '8700882', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '竹の上', 'タケノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市永興', '44', '44201', '8700883', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '永興', 'リョウゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市旭町', '44', '44201', '8700884', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '旭町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市南太平寺', '44', '44201', '8700885', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '南太平寺', 'ミナミタイヘイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市上田町', '44', '44201', '8700886', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '上田町', 'ウエダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市二又町', '44', '44201', '8700887', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '二又町', 'フタマタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市三ケ田町', '44', '44201', '8700888', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '三ケ田町', 'ミケタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市荏隈', '44', '44201', '8700889', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '荏隈', 'エノクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市西新地', '44', '44201', '8700901', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '西新地', 'ニシシンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市西ノ洲', '44', '44201', '8700902', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '西ノ洲', 'ニシノス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市向原沖', '44', '44201', '8700903', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '向原沖', 'ムカイバルオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市向原東', '44', '44201', '8700904', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '向原東', 'ムカイバルヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市向原西', '44', '44201', '8700905', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '向原西', 'ムカイバルニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市大州浜', '44', '44201', '8700906', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '大州浜', 'オオスハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市大津町', '44', '44201', '8700907', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '大津町', 'オオツマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市青葉町', '44', '44201', '8700908', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '青葉町', 'アオバマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市新貝', '44', '44201', '8700911', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '新貝', 'シンガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市原新町', '44', '44201', '8700912', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '原新町', 'ハルシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市松原町', '44', '44201', '8700913', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '松原町', 'マツバラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市日岡', '44', '44201', '8700914', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '日岡', 'ヒオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市花高松', '44', '44201', '8700915', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '花高松', 'ハナタカマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市高松東', '44', '44201', '8700916', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '高松東', 'タカマツヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市高松', '44', '44201', '8700917', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '高松', 'タカマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市日吉町', '44', '44201', '8700918', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '日吉町', 'ヒヨシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市新栄町', '44', '44201', '8700919', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '新栄町', 'シンサカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市萩原', '44', '44201', '8700921', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '萩原', 'ハギワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市城東町', '44', '44201', '8700922', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '城東町', 'ジョウトウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市高城西町', '44', '44201', '8700923', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '高城西町', 'タカジョウニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市牧', '44', '44201', '8700924', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '牧', 'マキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市牧1丁目', '44', '44201', '8700924', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '牧', 'マキ', null, null, '1丁目', '01チョウメ');
INSERT INTO `ms_addresses` VALUES ('113245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市牧2丁目', '44', '44201', '8700924', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '牧', 'マキ', null, null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('113246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市牧3丁目', '44', '44201', '8700924', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '牧', 'マキ', null, null, '3丁目', '03チョウメ');
INSERT INTO `ms_addresses` VALUES ('113247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市牧高見', '44', '44201', '8700924', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '牧', 'マキ', null, null, '高見', 'タカミ');
INSERT INTO `ms_addresses` VALUES ('113248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市牧上町', '44', '44201', '8700925', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '牧上町', 'マキカミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市加納', '44', '44201', '8700926', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '加納', 'カノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市北下郡', '44', '44201', '8700927', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '北下郡', 'キタシモゴオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市南下郡', '44', '44201', '8700928', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '南下郡', 'ミナミシモゴオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市長谷町', '44', '44201', '8700929', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '長谷町', 'ナガタニマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市西浜', '44', '44201', '8700931', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '西浜', 'ニシハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市東浜', '44', '44201', '8700932', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '東浜', 'ヒガシハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市花津留', '44', '44201', '8700933', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '花津留', 'ハナヅル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市東津留', '44', '44201', '8700934', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '東津留', 'ヒガシヅル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市古ケ鶴', '44', '44201', '8700935', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '古ケ鶴', 'コガヅル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市岩田町', '44', '44201', '8700936', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '岩田町', 'イワタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市南津留', '44', '44201', '8700937', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '南津留', 'ミナミヅル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市今津留', '44', '44201', '8700938', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '今津留', 'イマヅル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市中津留', '44', '44201', '8700939', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '中津留', 'ナカヅル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市下郡工業団地', '44', '44201', '8700941', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '下郡工業団地', 'シモゴオリコウギョウダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市羽田', '44', '44201', '8700942', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '羽田', 'ハダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市片島', '44', '44201', '8700943', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '片島', 'カタシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市米良', '44', '44201', '8700944', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '米良', 'メラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市津守', '44', '44201', '8700945', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '津守', 'ツモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市曲', '44', '44201', '8700946', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '曲', 'マガリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市富岡', '44', '44201', '8700947', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '富岡', 'トミオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市芳河原台', '44', '44201', '8700948', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '芳河原台', 'ホウガワラダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市かたしま台', '44', '44201', '8700949', '大分県', 'オオイタケン', '大分市', 'オオイタシ', 'かたしま台', 'カタシマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市下郡', '44', '44201', '8700951', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '下郡', 'シモゴオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市下郡北', '44', '44201', '8700952', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '下郡北', 'シモゴオリキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市下郡東', '44', '44201', '8700953', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '下郡東', 'シモゴオリヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市下郡中央', '44', '44201', '8700954', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '下郡中央', 'シモゴオリチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市下郡南', '44', '44201', '8700955', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '下郡南', 'シモゴオリミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市裏川団地', '44', '44201', '8700956', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '裏川団地', 'ウラカワダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市藤の台', '44', '44201', '8700957', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '藤の台', 'フジノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市ゆめが丘', '44', '44201', '8700958', '大分県', 'オオイタケン', '大分市', 'オオイタシ', 'ゆめが丘', 'ユメガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市希望が丘', '44', '44201', '8700959', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '希望が丘', 'キボウガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市敷戸北町', '44', '44201', '8701101', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '敷戸北町', 'シキドキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市敷戸新町', '44', '44201', '8701102', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '敷戸新町', 'シキドシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市敷戸西町', '44', '44201', '8701103', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '敷戸西町', 'シキドニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市敷戸東町', '44', '44201', '8701104', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '敷戸東町', 'シキドヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市敷戸南町', '44', '44201', '8701105', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '敷戸南町', 'シキドミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市敷戸台', '44', '44201', '8701106', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '敷戸台', 'シキドダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市敷戸駅北町', '44', '44201', '8701107', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '敷戸駅北町', 'シキドエキキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市判田台東', '44', '44201', '8701108', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '判田台東', 'ハンダダイヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市判田台南', '44', '44201', '8701109', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '判田台南', 'ハンダダイミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市判田台', '44', '44201', '8701110', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '判田台', 'ハンダダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市上判田', '44', '44201', '8701111', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '上判田', 'カミハンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市下判田', '44', '44201', '8701112', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '下判田', 'シモハンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市中判田', '44', '44201', '8701113', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '中判田', 'ナカハンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市星和台', '44', '44201', '8701114', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '星和台', 'セイワダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市ひばりケ丘', '44', '44201', '8701115', '大分県', 'オオイタケン', '大分市', 'オオイタシ', 'ひばりケ丘', 'ヒバリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市高江中央', '44', '44201', '8701116', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '高江中央', 'タカエチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市高江西', '44', '44201', '8701117', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '高江西', 'タカエニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市高江南', '44', '44201', '8701118', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '高江南', 'タカエミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市高江北', '44', '44201', '8701119', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '高江北', 'タカエキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市サンシヤイン敷戸', '44', '44201', '8701120', '大分県', 'オオイタケン', '大分市', 'オオイタシ', 'サンシヤイン敷戸', 'サンシャインシキド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市鴛野', '44', '44201', '8701121', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '鴛野', 'オシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市敷戸', '44', '44201', '8701122', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '敷戸', 'シキド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市寒田', '44', '44201', '8701123', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '寒田', 'ソウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市旦野原', '44', '44201', '8701124', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '旦野原', 'ダンノハル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市大園団地', '44', '44201', '8701125', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '大園団地', 'オオゾノダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市判田台北', '44', '44201', '8701126', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '判田台北', 'ハンダダイキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市花の木坂', '44', '44201', '8701128', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '花の木坂', 'ハナノキザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市岡川', '44', '44201', '8701131', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '岡川', 'オカガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市光吉', '44', '44201', '8701132', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '光吉', 'ミツヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市宮崎', '44', '44201', '8701133', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '宮崎', 'ミヤザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市小原団地', '44', '44201', '8701134', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '小原団地', 'コバルダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市光吉新町', '44', '44201', '8701135', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '光吉新町', 'ミツヨシシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市光吉台', '44', '44201', '8701136', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '光吉台', 'ミツヨシダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市宮崎台', '44', '44201', '8701137', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '宮崎台', 'ミヤザキダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市寒田北町', '44', '44201', '8701138', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '寒田北町', 'ソウダキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市寒田南町', '44', '44201', '8701139', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '寒田南町', 'ソウダミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市下宗方', '44', '44201', '8701141', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '下宗方', 'シモムナカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市高瀬', '44', '44201', '8701142', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '高瀬', 'タカセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市田尻', '44', '44201', '8701143', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '田尻', 'タジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市田尻グリーンハイツ', '44', '44201', '8701144', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '田尻グリーンハイツ', 'タジリグリーンハイツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市田尻南', '44', '44201', '8701145', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '田尻南', 'タジリミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市曲', '44', '44201', '8701146', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '曲', 'マガリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市ふじが丘', '44', '44201', '8701147', '大分県', 'オオイタケン', '大分市', 'オオイタシ', 'ふじが丘', 'フジガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市天領ハイツ', '44', '44201', '8701148', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '天領ハイツ', 'テンリョウハイツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市小野鶴南', '44', '44201', '8701150', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '小野鶴南', 'オノツルミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市市', '44', '44201', '8701151', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '市', 'イチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市上宗方', '44', '44201', '8701152', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '上宗方', 'カミムナカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市小野鶴', '44', '44201', '8701153', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '小野鶴', 'オノヅル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市田原', '44', '44201', '8701154', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '田原', 'タバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市玉沢', '44', '44201', '8701155', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '玉沢', 'タマザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市小野鶴新町', '44', '44201', '8701156', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '小野鶴新町', 'オノツルシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市宗方台東', '44', '44201', '8701157', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '宗方台東', 'ムナカタダイヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市宗方台西', '44', '44201', '8701158', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '宗方台西', 'ムナカタダイニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市宗方台北', '44', '44201', '8701159', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '宗方台北', 'ムナカタダイキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市木上', '44', '44201', '8701161', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '木上', 'キノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市口戸', '44', '44201', '8701162', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '口戸', 'クチド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市廻栖野', '44', '44201', '8701163', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '廻栖野', 'メグスノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市雄城台住宅地', '44', '44201', '8701164', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '雄城台住宅地', 'オギノダイジュウタクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市雄城台団地', '44', '44201', '8701165', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '雄城台団地', 'オギノダイダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市椿ケ丘', '44', '44201', '8701166', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '椿ケ丘', 'ツバキガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市二豊団地', '44', '44201', '8701167', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '二豊団地', 'ニホウダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市松が丘', '44', '44201', '8701168', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '松が丘', 'マツガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市鬼崎', '44', '44201', '8701171', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '鬼崎', 'オニザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市緑が丘', '44', '44201', '8701172', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '緑が丘', 'ミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市横瀬', '44', '44201', '8701173', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '横瀬', 'ヨコセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市萌葱台', '44', '44201', '8701174', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '萌葱台', 'モエギダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市富士見が丘東', '44', '44201', '8701176', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '富士見が丘東', 'フジミガオカヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市富士見が丘西', '44', '44201', '8701177', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '富士見が丘西', 'フジミガオカニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市廻栖野', '44', '44201', '8701201', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '廻栖野', 'メグスノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市入蔵', '44', '44201', '8701202', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '入蔵', 'イリクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市野津原', '44', '44201', '8701203', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '野津原', 'ノツハル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市辻原', '44', '44201', '8701204', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '辻原', 'ツジハル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市福宗', '44', '44201', '8701205', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '福宗', 'フクムネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市竹矢', '44', '44201', '8701211', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '竹矢', 'タケヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市沢田', '44', '44201', '8701212', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '沢田', 'サワタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市下原', '44', '44201', '8701213', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '下原', 'シモハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市太田', '44', '44201', '8701214', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '太田', 'オオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市上詰', '44', '44201', '8701215', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '上詰', 'カミツメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市荷尾杵', '44', '44201', '8701221', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '荷尾杵', 'ニオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市高原', '44', '44201', '8701222', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '高原', 'タカハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市今市', '44', '44201', '8701223', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '今市', 'イマイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道根室市友知', '01', '01223', '0870161', '北海道', 'ホッカイドウ', '根室市', 'ネムロシ', '友知', 'トモシリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道根室市双沖', '01', '01223', '0870162', '北海道', 'ホッカイドウ', '根室市', 'ネムロシ', '双沖', 'フタオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道根室市歯舞', '01', '01223', '0870163', '北海道', 'ホッカイドウ', '根室市', 'ネムロシ', '歯舞', 'ハボマイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道根室市珸瑤瑁', '01', '01223', '0870164', '北海道', 'ホッカイドウ', '根室市', 'ネムロシ', '珸瑤瑁', 'ゴヨウマイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道根室市納沙布', '01', '01223', '0870165', '北海道', 'ホッカイドウ', '根室市', 'ネムロシ', '納沙布', 'ノサップ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道根室市温根元', '01', '01223', '0870166', '北海道', 'ホッカイドウ', '根室市', 'ネムロシ', '温根元', 'オンネモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道根室市豊里', '01', '01223', '0870167', '北海道', 'ホッカイドウ', '根室市', 'ネムロシ', '豊里', 'トヨサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県築上郡吉富町', '40', '40642', '8710000', '福岡県', 'フクオカケン', '築上郡吉富町', 'チクジョウグンヨシトミマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('113418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市', '44', '44203', '8710000', '大分県', 'オオイタケン', '中津市', 'ナカツシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('113419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市大新田', '44', '44203', '8710001', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '大新田', 'オオシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市全徳', '44', '44203', '8710002', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '全徳', 'ゼントク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市是則', '44', '44203', '8710003', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '是則', 'コレノリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市上如水', '44', '44203', '8710004', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '上如水', 'カミジョスイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市合馬', '44', '44203', '8710005', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '合馬', 'オウマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市東浜', '44', '44203', '8710006', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '東浜', 'ヒガシハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市蛎瀬', '44', '44203', '8710007', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '蛎瀬', 'カキゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市大塚', '44', '44203', '8710008', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '大塚', 'オオツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市新大塚町', '44', '44203', '8710009', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '新大塚町', 'シンオオツカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市下池永', '44', '44203', '8710011', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '下池永', 'シモイケナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市宮夫', '44', '44203', '8710012', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '宮夫', 'ミヤブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市金手', '44', '44203', '8710013', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '金手', 'カナテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市一ツ松', '44', '44203', '8710014', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '一ツ松', 'ヒトツマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市牛神', '44', '44203', '8710015', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '牛神', 'ウシガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市牛神町', '44', '44203', '8710016', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '牛神町', 'ウシガミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市沖代町', '44', '44203', '8710021', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '沖代町', 'オキダイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市相原', '44', '44203', '8710022', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '相原', 'アイハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市湯屋', '44', '44203', '8710023', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '湯屋', 'ユヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市中央町', '44', '44203', '8710024', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '中央町', 'チュウオウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市万田', '44', '44203', '8710025', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '万田', 'マンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市高瀬', '44', '44203', '8710026', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '高瀬', 'タカセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市上宮永', '44', '44203', '8710027', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '上宮永', 'カミミヤナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市角木町', '44', '44203', '8710028', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '角木町', 'ツノギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市下宮永', '44', '44203', '8710029', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '下宮永', 'シモミヤナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市中殿町', '44', '44203', '8710030', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '中殿町', 'ナカドノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市中殿', '44', '44203', '8710031', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '中殿', 'ナカドノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市東本町', '44', '44203', '8710032', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '東本町', 'ヒガシホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市島田', '44', '44203', '8710033', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '島田', 'シマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市日ノ出町', '44', '44203', '8710034', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '日ノ出町', 'ヒノデマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市島田仲町', '44', '44203', '8710035', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '島田仲町', 'シマダナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市島田本町', '44', '44203', '8710036', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '島田本町', 'シマダホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市宮島町', '44', '44203', '8710037', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '宮島町', 'ミヤジママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市枝町', '44', '44203', '8710038', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '枝町', 'エダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市新天神町', '44', '44203', '8710039', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '新天神町', 'シンテンジンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市天神町', '44', '44203', '8710039', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '天神町', 'テンジンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市新博多町', '44', '44203', '8710041', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '新博多町', 'シンハカタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市上博多町', '44', '44203', '8710042', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '上博多町', 'カミハカタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市栄町', '44', '44203', '8710043', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市江三竹町', '44', '44203', '8710044', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '江三竹町', 'エミタケマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市萱津町', '44', '44203', '8710045', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '萱津町', 'カイヅマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市金谷上ノ丁', '44', '44203', '8710046', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '金谷', 'カナヤ', null, null, '上ノ丁', 'ウエノチョウ');
INSERT INTO `ms_addresses` VALUES ('113460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市金谷中ノ丁', '44', '44203', '8710046', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '金谷', 'カナヤ', null, null, '中ノ丁', 'ナカノチョウ');
INSERT INTO `ms_addresses` VALUES ('113461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市金谷西ノ丁', '44', '44203', '8710046', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '金谷', 'カナヤ', null, null, '西ノ丁', 'ニシノチョウ');
INSERT INTO `ms_addresses` VALUES ('113462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市金谷本町', '44', '44203', '8710046', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '金谷', 'カナヤ', null, null, '本町', 'ホンマチ');
INSERT INTO `ms_addresses` VALUES ('113463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市金谷南ノ丁', '44', '44203', '8710046', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '金谷', 'カナヤ', null, null, '南ノ丁', 'ミナミノチョウ');
INSERT INTO `ms_addresses` VALUES ('113464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市金谷森ノ丁', '44', '44203', '8710046', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '金谷', 'カナヤ', null, null, '森ノ丁', 'モリノチョウ');
INSERT INTO `ms_addresses` VALUES ('113465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市金谷山ノ神', '44', '44203', '8710046', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '金谷', 'カナヤ', null, null, '山ノ神', 'ヤマノカミ');
INSERT INTO `ms_addresses` VALUES ('113466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市西堀端', '44', '44203', '8710046', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '西堀端', 'ニシホリバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市東堀端', '44', '44203', '8710046', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '東堀端', 'ヒガシホリバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市古金谷', '44', '44203', '8710046', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '古金谷', 'フルカナヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市丸山町', '44', '44203', '8710047', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '丸山町', 'マルヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市新魚町', '44', '44203', '8710048', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '新魚町', 'シンウオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市諸町', '44', '44203', '8710049', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '諸町', 'モロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市二ノ丁', '44', '44203', '8710050', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '二ノ丁', 'ニノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市古博多町', '44', '44203', '8710051', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '古博多町', 'フルハカタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市古魚町', '44', '44203', '8710053', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '古魚町', 'フルウオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市京町', '44', '44203', '8710054', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '京町', 'キョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市殿町', '44', '44203', '8710055', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '殿町', 'トノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市片端町', '44', '44203', '8710056', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '片端町', 'カタハマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市三ノ丁', '44', '44203', '8710057', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '三ノ丁', 'サンノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市豊田町', '44', '44203', '8710058', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '豊田町', 'トヨダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市外馬場', '44', '44203', '8710059', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '外馬場', 'ソトババ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市北稲堀', '44', '44203', '8710060', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '北稲堀', 'キタイナボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市南稲堀', '44', '44203', '8710061', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '南稲堀', 'ミナミイナボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市山下', '44', '44203', '8710062', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '山下', 'ヤマシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市袋町', '44', '44203', '8710063', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '袋町', 'フクロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市餌指町', '44', '44203', '8710064', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '餌指町', 'エサシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市蛭子町', '44', '44203', '8710065', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '蛭子町', 'エビスマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市鷹匠町', '44', '44203', '8710066', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '鷹匠町', 'タカジョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市仲間町', '44', '44203', '8710067', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '仲間町', 'チュウゲンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市豊後町', '44', '44203', '8710068', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '豊後町', 'ブンゴマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市新堀', '44', '44203', '8710069', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '新堀', 'シンボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市鷹部屋', '44', '44203', '8710071', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '鷹部屋', 'タカベヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市船町', '44', '44203', '8710072', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '船町', 'フナマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市塩町', '44', '44203', '8710073', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '塩町', 'シオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市桜町', '44', '44203', '8710074', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '桜町', 'サクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市寺町', '44', '44203', '8710075', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '寺町', 'テラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市米町', '44', '44203', '8710076', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '米町', 'コメマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市姫路町', '44', '44203', '8710077', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '姫路町', 'ヒメジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市小祝上方町', '44', '44203', '8710078', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '小祝', 'コイワイ', null, null, '上方町', 'カミカタマチ');
INSERT INTO `ms_addresses` VALUES ('113499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市小祝中島町', '44', '44203', '8710078', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '小祝', 'コイワイ', null, null, '中島町', 'ナカシママチ');
INSERT INTO `ms_addresses` VALUES ('113500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市小祝本町', '44', '44203', '8710078', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '小祝', 'コイワイ', null, null, '本町', 'ホンマチ');
INSERT INTO `ms_addresses` VALUES ('113501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市小祝港町', '44', '44203', '8710078', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '小祝', 'コイワイ', null, null, '港町', 'ミナトマチ');
INSERT INTO `ms_addresses` VALUES ('113502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市北門通', '44', '44203', '8710079', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '北門通', 'キタモンドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市小祝新町', '44', '44203', '8710080', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '小祝新町', 'コイワイシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市北堀川町', '44', '44203', '8710081', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '北堀川町', 'キタホリカワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市水主町', '44', '44203', '8710082', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '水主町', 'カコマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市矢場', '44', '44203', '8710083', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '矢場', 'ヤバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市小堀', '44', '44203', '8710084', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '小堀', 'コボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市弓町', '44', '44203', '8710085', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '弓町', 'ユミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市船頭町', '44', '44203', '8710086', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '船頭町', 'センドマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市南堀川町', '44', '44203', '8710087', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '南堀川町', 'ミナミホリカワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市留守居町', '44', '44203', '8710088', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '留守居町', 'ルスイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市船場町', '44', '44203', '8710089', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '船場町', 'センバマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市北新地', '44', '44203', '8710090', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '北新地', 'キタシンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市闇無町', '44', '44203', '8710091', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '闇無町', 'クラナシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市角木', '44', '44203', '8710091', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '角木', 'ツノギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市南新地', '44', '44203', '8710092', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '南新地', 'ミナミシンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市浦町', '44', '44203', '8710093', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '浦町', 'ウラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市北浦町', '44', '44203', '8710094', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '北浦町', 'キタウラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市角木新町', '44', '44203', '8710095', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '角木新町', 'ツノギシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市竜王町', '44', '44203', '8710096', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '竜王町', 'リュウオウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市下正路', '44', '44203', '8710097', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '下正路', 'シモショウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市市場', '44', '44203', '8710098', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '市場', 'イチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市', '44', '44203', '8710099', '大分県', 'オオイタケン', '中津市', 'ナカツシ', null, '　', '（直番地）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('113524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市三光森山', '44', '44203', '8710101', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '三光森山', 'サンコウモリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市三光成恒', '44', '44203', '8710102', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '三光成恒', 'サンコウナリツネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市三光田口', '44', '44203', '8710103', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '三光田口', 'サンコウタグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市三光諫山', '44', '44203', '8710104', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '三光諫山', 'サンコウイサヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市三光原口', '44', '44203', '8710105', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '三光原口', 'サンコウハラグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市三光佐知', '44', '44203', '8710111', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '三光佐知', 'サンコウサチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市三光臼木', '44', '44203', '8710112', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '三光臼木', 'サンコウウスギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市三光土田', '44', '44203', '8710113', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '三光土田', 'サンコウツチダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市三光小袋', '44', '44203', '8710114', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '三光小袋', 'サンコウオブクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市相原', '44', '44203', '8710122', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '相原', 'アイハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市大悟法', '44', '44203', '8710151', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '大悟法', 'ダイゴボウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市加来', '44', '44203', '8710152', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '加来', 'カク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市大貞', '44', '44203', '8710153', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '大貞', 'オオサダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市古城', '44', '44203', '8710154', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '古城', 'コジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市八幡町', '44', '44203', '8710155', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '八幡町', 'ハチマンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市榊原町', '44', '44203', '8710156', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '榊原町', 'サカキバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市中原', '44', '44203', '8710157', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '中原', 'ナカバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市上池永', '44', '44203', '8710161', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '上池永', 'カミイケナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市永添', '44', '44203', '8710162', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '永添', 'ナガソエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市西永添', '44', '44203', '8710163', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '西永添', 'ニシナガソイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市下永添', '44', '44203', '8710164', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '下永添', 'シモナガソイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市本耶馬渓町樋田', '44', '44203', '8710201', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '本耶馬渓町樋田', 'ホンヤバケイマチヒダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市本耶馬渓町曽木', '44', '44203', '8710202', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '本耶馬渓町曽木', 'ホンヤバケイマチソギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市本耶馬渓町多志田', '44', '44203', '8710203', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '本耶馬渓町多志田', 'ホンヤバケイマチタシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市本耶馬渓町冠石野', '44', '44203', '8710204', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '本耶馬渓町冠石野', 'ホンヤバケイマチカブシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市本耶馬渓町下屋形', '44', '44203', '8710205', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '本耶馬渓町下屋形', 'ホンヤバケイマチシモヤカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市本耶馬渓町今行', '44', '44203', '8710206', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '本耶馬渓町今行', 'ホンヤバケイマチイマユク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市本耶馬渓町東屋形', '44', '44203', '8710207', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '本耶馬渓町東屋形', 'ホンヤバケイマチヒガシヤカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市本耶馬渓町西屋形', '44', '44203', '8710208', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '本耶馬渓町西屋形', 'ホンヤバケイマチニシヤカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県築上郡上毛町原井有野', '40', '40646', '8710226', '福岡県', 'フクオカケン', '築上郡上毛町', 'チクジョウグンコウゲマチ', '原井', 'ハライ', null, null, '有野', 'アリノ');
INSERT INTO `ms_addresses` VALUES ('113556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市本耶馬渓町跡田', '44', '44203', '8710311', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '本耶馬渓町跡田', 'ホンヤバケイマチアトダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市本耶馬渓町折元', '44', '44203', '8710312', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '本耶馬渓町折元', 'ホンヤバケイマチオリモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市本耶馬渓町落合', '44', '44203', '8710313', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '本耶馬渓町落合', 'ホンヤバケイマチオチアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市本耶馬渓町西谷', '44', '44203', '8710314', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '本耶馬渓町西谷', 'ホンヤバケイマチニシタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市本耶馬渓町東谷', '44', '44203', '8710315', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '本耶馬渓町東谷', 'ホンヤバケイマチヒガシタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市耶馬溪町平田', '44', '44203', '8710401', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '耶馬溪町平田', 'ヤバケイマチヒラタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市耶馬溪町冠石野', '44', '44203', '8710402', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '耶馬溪町冠石野', 'ヤバケイマチカブシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市耶馬溪町多志田', '44', '44203', '8710403', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '耶馬溪町多志田', 'ヤバケイマチタシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市耶馬溪町戸原', '44', '44203', '8710404', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '耶馬溪町戸原', 'ヤバケイマチトバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市耶馬溪町柿坂', '44', '44203', '8710405', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '耶馬溪町柿坂', 'ヤバケイマチカキサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市耶馬溪町小友田', '44', '44203', '8710406', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '耶馬溪町小友田', 'ヤバケイマチオトモダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市耶馬溪町三尾母', '44', '44203', '8710407', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '耶馬溪町三尾母', 'ヤバケイマチミオモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市耶馬溪町福土', '44', '44203', '8710408', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '耶馬溪町福土', 'ヤバケイマチフクツチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市耶馬溪町中畑', '44', '44203', '8710411', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '耶馬溪町中畑', 'ヤバケイマチナカハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市耶馬溪町栃木', '44', '44203', '8710412', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '耶馬溪町栃木', 'ヤバケイマチトチギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市耶馬溪町大野', '44', '44203', '8710413', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '耶馬溪町大野', 'ヤバケイマチオオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市耶馬溪町川原口', '44', '44203', '8710414', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '耶馬溪町川原口', 'ヤバケイマチカワラグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市耶馬溪町山移', '44', '44203', '8710421', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '耶馬溪町山移', 'ヤバケイマチヤマウツリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市耶馬溪町深耶馬', '44', '44203', '8710422', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '耶馬溪町深耶馬', 'ヤバケイマチシンヤバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市耶馬溪町大島', '44', '44203', '8710431', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '耶馬溪町大島', 'ヤバケイマチオオシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市耶馬溪町金吉', '44', '44203', '8710432', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '耶馬溪町金吉', 'ヤバケイマチカナヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市耶馬溪町宮園', '44', '44203', '8710433', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '耶馬溪町宮園', 'ヤバケイマチミヤソノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市耶馬溪町樋山路', '44', '44203', '8710434', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '耶馬溪町樋山路', 'ヤバケイマチヒヤマジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市山国町槻木', '44', '44203', '8710701', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '山国町槻木', 'ヤマクニマチツキノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市山国町草本', '44', '44203', '8710702', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '山国町草本', 'ヤマクニマチクサモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市山国町小屋川', '44', '44203', '8710703', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '山国町小屋川', 'ヤマクニマチコヤガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市山国町吉野', '44', '44203', '8710704', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '山国町吉野', 'ヤマクニマチヨシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市山国町平小野', '44', '44203', '8710711', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '山国町平小野', 'ヤマクニマチヒラオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市山国町守実', '44', '44203', '8710712', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '山国町守実', 'ヤマクニマチモリザネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市山国町藤野木', '44', '44203', '8710713', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '山国町藤野木', 'ヤマクニマチフジノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市山国町長尾野', '44', '44203', '8710714', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '山国町長尾野', 'ヤマクニマチナガオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市山国町宇曽', '44', '44203', '8710715', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '山国町宇曽', 'ヤマクニマチウソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市山国町中摩', '44', '44203', '8710716', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '山国町中摩', 'ヤマクニマチナカマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県築上郡吉富町小祝', '40', '40642', '8710801', '福岡県', 'フクオカケン', '築上郡吉富町', 'チクジョウグンヨシトミマチ', '小祝', 'コイワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県築上郡吉富町小犬丸', '40', '40642', '8710802', '福岡県', 'フクオカケン', '築上郡吉富町', 'チクジョウグンヨシトミマチ', '小犬丸', 'コイヌマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県築上郡吉富町広津', '40', '40642', '8710811', '福岡県', 'フクオカケン', '築上郡吉富町', 'チクジョウグンヨシトミマチ', '広津', 'ヒロツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県築上郡吉富町幸子', '40', '40642', '8710821', '福岡県', 'フクオカケン', '築上郡吉富町', 'チクジョウグンヨシトミマチ', '幸子', 'コウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県築上郡吉富町今吉', '40', '40642', '8710822', '福岡県', 'フクオカケン', '築上郡吉富町', 'チクジョウグンヨシトミマチ', '今吉', 'イマヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県築上郡吉富町別府', '40', '40642', '8710823', '福岡県', 'フクオカケン', '築上郡吉富町', 'チクジョウグンヨシトミマチ', '別府', 'ビョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県築上郡吉富町直江', '40', '40642', '8710831', '福岡県', 'フクオカケン', '築上郡吉富町', 'チクジョウグンヨシトミマチ', '直江', 'ナオエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県築上郡吉富町鈴熊', '40', '40642', '8710832', '福岡県', 'フクオカケン', '築上郡吉富町', 'チクジョウグンヨシトミマチ', '鈴熊', 'スズクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県築上郡吉富町楡生', '40', '40642', '8710833', '福岡県', 'フクオカケン', '築上郡吉富町', 'チクジョウグンヨシトミマチ', '楡生', 'ニリョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県築上郡吉富町土屋', '40', '40642', '8710834', '福岡県', 'フクオカケン', '築上郡吉富町', 'チクジョウグンヨシトミマチ', '土屋', 'ツチヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県築上郡上毛町', '40', '40646', '8710900', '福岡県', 'フクオカケン', '築上郡上毛町', 'チクジョウグンコウゲマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('113601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県築上郡上毛町成恒', '40', '40646', '8710901', '福岡県', 'フクオカケン', '築上郡上毛町', 'チクジョウグンコウゲマチ', '成恒', 'ナリツネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県築上郡上毛町大ノ瀬', '40', '40646', '8710902', '福岡県', 'フクオカケン', '築上郡上毛町', 'チクジョウグンコウゲマチ', '大ノ瀬', 'ダイノセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県築上郡上毛町八ツ並', '40', '40646', '8710903', '福岡県', 'フクオカケン', '築上郡上毛町', 'チクジョウグンコウゲマチ', '八ツ並', 'ヤツナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県築上郡上毛町安雲', '40', '40646', '8710904', '福岡県', 'フクオカケン', '築上郡上毛町', 'チクジョウグンコウゲマチ', '安雲', 'アクモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県築上郡上毛町尻高', '40', '40646', '8710905', '福岡県', 'フクオカケン', '築上郡上毛町', 'チクジョウグンコウゲマチ', '尻高', 'シダカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県築上郡上毛町矢方', '40', '40646', '8710906', '福岡県', 'フクオカケン', '築上郡上毛町', 'チクジョウグンコウゲマチ', '矢方', 'ヤカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県築上郡上毛町緒方', '40', '40646', '8710907', '福岡県', 'フクオカケン', '築上郡上毛町', 'チクジョウグンコウゲマチ', '緒方', 'オガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県築上郡上毛町中村', '40', '40646', '8710911', '福岡県', 'フクオカケン', '築上郡上毛町', 'チクジョウグンコウゲマチ', '中村', 'ナカムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県築上郡上毛町吉岡', '40', '40646', '8710912', '福岡県', 'フクオカケン', '築上郡上毛町', 'チクジョウグンコウゲマチ', '吉岡', 'ヨシオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県築上郡上毛町垂水', '40', '40646', '8710913', '福岡県', 'フクオカケン', '築上郡上毛町', 'チクジョウグンコウゲマチ', '垂水', 'タルミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県築上郡上毛町宇野', '40', '40646', '8710914', '福岡県', 'フクオカケン', '築上郡上毛町', 'チクジョウグンコウゲマチ', '宇野', 'ウノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県築上郡上毛町土佐井', '40', '40646', '8710921', '福岡県', 'フクオカケン', '築上郡上毛町', 'チクジョウグンコウゲマチ', '土佐井', 'ツチサイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県築上郡上毛町東下', '40', '40646', '8710922', '福岡県', 'フクオカケン', '築上郡上毛町', 'チクジョウグンコウゲマチ', '東下', 'ヒガシシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県築上郡上毛町下唐原', '40', '40646', '8710923', '福岡県', 'フクオカケン', '築上郡上毛町', 'チクジョウグンコウゲマチ', '下唐原', 'シモトウバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県築上郡上毛町上唐原', '40', '40646', '8710924', '福岡県', 'フクオカケン', '築上郡上毛町', 'チクジョウグンコウゲマチ', '上唐原', 'カミトウバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県築上郡上毛町百留', '40', '40646', '8710925', '福岡県', 'フクオカケン', '築上郡上毛町', 'チクジョウグンコウゲマチ', '百留', 'ヒャクドミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県築上郡上毛町原井', '40', '40646', '8710926', '福岡県', 'フクオカケン', '築上郡上毛町', 'チクジョウグンコウゲマチ', '原井', 'ハライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県築上郡上毛町東上', '40', '40646', '8710927', '福岡県', 'フクオカケン', '築上郡上毛町', 'チクジョウグンコウゲマチ', '東上', 'ヒガシカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福岡県築上郡上毛町西友枝', '40', '40646', '8710928', '福岡県', 'フクオカケン', '築上郡上毛町', 'チクジョウグンコウゲマチ', '西友枝', 'ニシトモエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市', '44', '44211', '8720000', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('113638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市長洲', '44', '44211', '8720001', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '長洲', 'ナガス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市岩保新田', '44', '44211', '8720011', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '岩保新田', 'イワホシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市久兵衛新田', '44', '44211', '8720012', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '久兵衛新田', 'キュウベエシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市北鶴田新田', '44', '44211', '8720013', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '北鶴田新田', 'キタツルダシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市南鶴田新田', '44', '44211', '8720014', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '南鶴田新田', 'ミナミツルダシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市松崎', '44', '44211', '8720015', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '松崎', 'マツサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市佐々礼', '44', '44211', '8720016', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '佐々礼', 'サザレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市金屋', '44', '44211', '8720021', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '金屋', 'カナヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市西大堀', '44', '44211', '8720022', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '西大堀', 'ニシオオボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市蜷木', '44', '44211', '8720023', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '蜷木', 'ニナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市沖須町', '44', '44211', '8720031', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '沖須町', 'オキスマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市江須賀', '44', '44211', '8720032', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '江須賀', 'エスカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市住吉町', '44', '44211', '8720033', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '住吉町', 'スミヨシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市神子山新田', '44', '44211', '8720041', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '神子山新田', 'ミコヤマシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市貴船町', '44', '44211', '8720042', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '貴船町', 'キフネマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市子安町', '44', '44211', '8720043', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '子安町', 'コヤスマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市住江', '44', '44211', '8720044', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '住江', 'スミエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市郡中新田', '44', '44211', '8720045', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '郡中新田', 'グンチュウシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市高砂新田', '44', '44211', '8720046', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '高砂新田', 'タカサゴシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市順風新田', '44', '44211', '8720047', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '順風新田', 'ジュンプウシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市高森', '44', '44211', '8720101', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '高森', 'タカモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市南宇佐', '44', '44211', '8720102', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '南宇佐', 'ミナミウサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市北宇佐', '44', '44211', '8720103', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '北宇佐', 'キタウサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市小向野', '44', '44211', '8720104', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '小向野', 'コムクノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市下矢部', '44', '44211', '8720111', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '下矢部', 'シモヤベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市上矢部', '44', '44211', '8720112', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '上矢部', 'カミヤベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市正覚寺', '44', '44211', '8720113', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '正覚寺', 'ショウガクジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市熊', '44', '44211', '8720114', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '熊', 'クマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市院内町御沓', '44', '44211', '8720301', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '院内町御沓', 'インナイマチミクツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市院内町二日市', '44', '44211', '8720302', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '院内町二日市', 'インナイマチフツカイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市院内町香下', '44', '44211', '8720311', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '院内町香下', 'インナイマチコウシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市院内町櫛野', '44', '44211', '8720312', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '院内町櫛野', 'インナイマチクシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市院内町新洞', '44', '44211', '8720313', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '院内町新洞', 'インナイマチシンドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市院内町沖', '44', '44211', '8720314', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '院内町沖', 'インナイマチオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市院内町北山', '44', '44211', '8720315', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '院内町北山', 'インナイマチキタヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市院内町小坂', '44', '44211', '8720316', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '院内町小坂', 'インナイマチオサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市院内町広瀬', '44', '44211', '8720317', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '院内町広瀬', 'インナイマチヒロセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市院内町副', '44', '44211', '8720318', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '院内町副', 'インナイマチソイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市院内町五名', '44', '44211', '8720321', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '院内町五名', 'インナイマチゴミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市院内町日岳', '44', '44211', '8720322', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '院内町日岳', 'インナイマチヒノタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市院内町大重見', '44', '44211', '8720323', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '院内町大重見', 'インナイマチオオシゲミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市院内町小野川内', '44', '44211', '8720324', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '院内町小野川内', 'インナイマチオノゴウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市院内町小稲', '44', '44211', '8720325', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '院内町小稲', 'インナイマチコイネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市院内町上船木', '44', '44211', '8720326', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '院内町上船木', 'インナイマチカミフナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市院内町下船木', '44', '44211', '8720327', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '院内町下船木', 'インナイマチシモフナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市院内町高並', '44', '44211', '8720328', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '院内町高並', 'インナイマチタカナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市院内町大副', '44', '44211', '8720331', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '院内町大副', 'インナイマチオオソイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市院内町山城', '44', '44211', '8720332', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '院内町山城', 'インナイマチヤマシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市院内町原口', '44', '44211', '8720333', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '院内町原口', 'インナイマチハルグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市院内町落狩倉', '44', '44211', '8720334', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '院内町落狩倉', 'インナイマチオチカクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市院内町斎藤', '44', '44211', '8720341', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '院内町斎藤', 'インナイマチサイトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市院内町景平', '44', '44211', '8720342', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '院内町景平', 'インナイマチカゲヘラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市院内町宮原', '44', '44211', '8720343', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '院内町宮原', 'インナイマチミヤバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市院内町大門', '44', '44211', '8720344', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '院内町大門', 'インナイマチダイモン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市院内町月俣', '44', '44211', '8720345', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '院内町月俣', 'インナイマチツキノマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市院内町定別当', '44', '44211', '8720346', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '院内町定別当', 'インナイマチジョウベットウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市上拝田新洞', '44', '44211', '8720366', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '上拝田', 'カミハイタ', null, null, '新洞', 'シンドウ');
INSERT INTO `ms_addresses` VALUES ('113695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市院内町下余', '44', '44211', '8720451', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '院内町下余', 'インナイマチシモアマリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市院内町上納持', '44', '44211', '8720452', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '院内町上納持', 'インナイマチカミノウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市院内町平原', '44', '44211', '8720453', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '院内町平原', 'インナイマチヒラバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市院内町滝貞', '44', '44211', '8720454', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '院内町滝貞', 'インナイマチタキサダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市院内町小平', '44', '44211', '8720455', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '院内町小平', 'インナイマチコビラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市院内町栗山', '44', '44211', '8720456', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '院内町栗山', 'インナイマチクリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市院内町岡', '44', '44211', '8720457', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '院内町岡', 'インナイマチオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市院内町大坪', '44', '44211', '8720458', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '院内町大坪', 'インナイマチオオツボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市院内町上余', '44', '44211', '8720459', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '院内町上余', 'インナイマチカミアマリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市院内町台', '44', '44211', '8720461', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '院内町台', 'インナイマチダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市院内町羽馬礼', '44', '44211', '8720462', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '院内町羽馬礼', 'インナイマチハバレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市院内町和田', '44', '44211', '8720463', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '院内町和田', 'インナイマチワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市院内町西椎屋', '44', '44211', '8720464', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '院内町西椎屋', 'インナイマチニシシイヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市院内町田平', '44', '44211', '8720465', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '院内町田平', 'インナイマチタビラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市院内町来鉢', '44', '44211', '8720466', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '院内町来鉢', 'インナイマチクバチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市院内町温見', '44', '44211', '8720471', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '院内町温見', 'インナイマチヌクミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市院内町野地', '44', '44211', '8720472', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '院内町野地', 'インナイマチノジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市院内町田所', '44', '44211', '8720473', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '院内町田所', 'インナイマチタドコロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市院内町下恵良', '44', '44211', '8720481', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '院内町下恵良', 'インナイマチシモエラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市院内町荻迫', '44', '44211', '8720482', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '院内町荻迫', 'インナイマチオギサコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市院内町土岩屋', '44', '44211', '8720483', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '院内町土岩屋', 'インナイマチツチイワヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市院内町上恵良', '44', '44211', '8720484', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '院内町上恵良', 'インナイマチカミエラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市安心院町原', '44', '44211', '8720501', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '安心院町原', 'アジムマチハル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市安心院町飯田', '44', '44211', '8720502', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '安心院町飯田', 'アジムマチハンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市安心院町新原', '44', '44211', '8720503', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '安心院町新原', 'アジムマチニイバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市安心院町荘', '44', '44211', '8720504', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '安心院町荘', 'アジムマチショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市安心院町戸方', '44', '44211', '8720505', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '安心院町戸方', 'アジムマチトカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市安心院町妻垣', '44', '44211', '8720506', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '安心院町妻垣', 'アジムマチツマガケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市安心院町木裳', '44', '44211', '8720507', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '安心院町木裳', 'アジムマチキノモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市安心院町有徳原', '44', '44211', '8720510', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '安心院町有徳原', 'アジムマチウットクバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市安心院町上市', '44', '44211', '8720511', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '安心院町上市', 'アジムマチカミイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市安心院町古市', '44', '44211', '8720512', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '安心院町古市', 'アジムマチフルイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市安心院町龍王', '44', '44211', '8720513', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '安心院町龍王', 'アジムマチリュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市安心院町鳥越', '44', '44211', '8720514', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '安心院町鳥越', 'アジムマチトリゴエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市安心院町野山', '44', '44211', '8720515', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '安心院町野山', 'アジムマチノヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市安心院町森', '44', '44211', '8720516', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '安心院町森', 'アジムマチモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市安心院町大', '44', '44211', '8720517', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '安心院町大', 'アジムマチダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市安心院町今井', '44', '44211', '8720518', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '安心院町今井', 'アジムマチイマイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市安心院町西衲', '44', '44211', '8720519', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '安心院町西衲', 'アジムマチニシノト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市安心院町下毛', '44', '44211', '8720521', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '安心院町下毛', 'アジムマチシモゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市安心院町折敷田', '44', '44211', '8720522', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '安心院町折敷田', 'アジムマチオシキダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市安心院町大佛', '44', '44211', '8720523', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '安心院町大佛', 'アジムマチダイブツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市安心院町恒松', '44', '44211', '8720524', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '安心院町恒松', 'アジムマチツネマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市安心院町中山', '44', '44211', '8720525', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '安心院町中山', 'アジムマチナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市安心院町田ノ口', '44', '44211', '8720526', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '安心院町田ノ口', 'アジムマチタノクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市安心院町辻', '44', '44211', '8720527', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '安心院町辻', 'アジムマチツジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市安心院町熊', '44', '44211', '8720541', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '安心院町熊', 'アジムマチクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市安心院町正覚寺', '44', '44211', '8720542', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '安心院町正覚寺', 'アジムマチショウガクジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市安心院町平ケ倉', '44', '44211', '8720543', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '安心院町平ケ倉', 'アジムマチヒラガクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市安心院町佐田', '44', '44211', '8720651', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '安心院町佐田', 'アジムマチサダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市安心院町山蔵', '44', '44211', '8720652', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '安心院町山蔵', 'アジムマチヤマゾウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市安心院町房ケ畑', '44', '44211', '8720653', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '安心院町房ケ畑', 'アジムマチボウガハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市安心院町内川野', '44', '44211', '8720654', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '安心院町内川野', 'アジムマチウチガワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市安心院町古川', '44', '44211', '8720655', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '安心院町古川', 'アジムマチフルカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市安心院町笹ケ平', '44', '44211', '8720661', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '安心院町笹ケ平', 'アジムマチササガヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市安心院町矢津', '44', '44211', '8720662', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '安心院町矢津', 'アジムマチヤヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市安心院町大見尾', '44', '44211', '8720663', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '安心院町大見尾', 'アジムマチオオミオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市安心院町塔尾', '44', '44211', '8720664', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '安心院町塔尾', 'アジムマチトウノオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市安心院町且尾', '44', '44211', '8720671', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '安心院町且尾', 'アジムマチカツオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市安心院町広谷', '44', '44211', '8720672', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '安心院町広谷', 'アジムマチヒロタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市安心院町口ノ坪', '44', '44211', '8720673', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '安心院町口ノ坪', 'アジムマチクチノツボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市安心院町久井田', '44', '44211', '8720674', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '安心院町久井田', 'アジムマチクイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市安心院町矢崎', '44', '44211', '8720675', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '安心院町矢崎', 'アジムマチヤザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市安心院町楢本', '44', '44211', '8720701', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '安心院町楢本', 'アジムマチナラモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市安心院町東恵良', '44', '44211', '8720702', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '安心院町東恵良', 'アジムマチヒガシエラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市安心院町尾立', '44', '44211', '8720703', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '安心院町尾立', 'アジムマチオダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市安心院町六郎丸', '44', '44211', '8720711', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '安心院町六郎丸', 'アジムマチロクロウマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市安心院町五郎丸', '44', '44211', '8720712', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '安心院町五郎丸', 'アジムマチゴロウマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市安心院町若林', '44', '44211', '8720721', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '安心院町若林', 'アジムマチワカバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市安心院町南畑', '44', '44211', '8720722', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '安心院町南畑', 'アジムマチミナミハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市安心院町萱籠', '44', '44211', '8720723', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '安心院町萱籠', 'アジムマチカヤゴモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市安心院町東椎屋', '44', '44211', '8720724', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '安心院町東椎屋', 'アジムマチヒガシシイヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市安心院町川崎', '44', '44211', '8720731', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '安心院町川崎', 'アジムマチカワサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市安心院町板場', '44', '44211', '8720732', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '安心院町板場', 'アジムマチイタバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市安心院町松本', '44', '44211', '8720733', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '安心院町松本', 'アジムマチマツモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市安心院町矢畑', '44', '44211', '8720841', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '安心院町矢畑', 'アジムマチヤハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市安心院町下内河野', '44', '44211', '8720842', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '安心院町下内河野', 'アジムマチシモウチガワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市安心院町筌ノ口', '44', '44211', '8720843', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '安心院町筌ノ口', 'アジムマチウケノクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市安心院町広連', '44', '44211', '8720851', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '安心院町広連', 'アジムマチヒロツレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市安心院町上内河野', '44', '44211', '8720852', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '安心院町上内河野', 'アジムマチカミウチガワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市安心院町元', '44', '44211', '8720853', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '安心院町元', 'アジムマチモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市安心院町寒水', '44', '44211', '8720854', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '安心院町寒水', 'アジムマチソウズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市安心院町福貴野', '44', '44211', '8720855', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '安心院町福貴野', 'アジムマチフキノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市安心院町山ノ口', '44', '44211', '8720856', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '安心院町山ノ口', 'アジムマチヤマノクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市安心院町畳石', '44', '44211', '8720857', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '安心院町畳石', 'アジムマチタタミイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市安心院町水車', '44', '44211', '8720858', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '安心院町水車', 'アジムマチミズクルマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市安心院町境ノ坪', '44', '44211', '8720861', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '安心院町境ノ坪', 'アジムマチサカイノツボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市安心院町川底', '44', '44211', '8720862', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '安心院町川底', 'アジムマチカワソコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市安心院町村部', '44', '44211', '8720863', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '安心院町村部', 'アジムマチソベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市安心院町番木', '44', '44211', '8720864', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '安心院町番木', 'アジムマチバンギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市安心院町佛木', '44', '44211', '8720865', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '安心院町佛木', 'アジムマチホトギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市安心院町平山', '44', '44211', '8720871', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '安心院町平山', 'アジムマチヒラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市安心院町舟板', '44', '44211', '8720872', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '安心院町舟板', 'アジムマチフナイタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市安心院町新貝', '44', '44211', '8720873', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '安心院町新貝', 'アジムマチシンガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後高田市中真玉', '44', '44209', '8721101', '大分県', 'オオイタケン', '豊後高田市', 'ブンゴタカダシ', '中真玉', 'ナカマタマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後高田市大岩屋', '44', '44209', '8721102', '大分県', 'オオイタケン', '豊後高田市', 'ブンゴタカダシ', '大岩屋', 'オオイワヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後高田市黒土', '44', '44209', '8721103', '大分県', 'オオイタケン', '豊後高田市', 'ブンゴタカダシ', '黒土', 'クロツチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後高田市城前', '44', '44209', '8721104', '大分県', 'オオイタケン', '豊後高田市', 'ブンゴタカダシ', '城前', 'ジョウゼン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後高田市西真玉', '44', '44209', '8721105', '大分県', 'オオイタケン', '豊後高田市', 'ブンゴタカダシ', '西真玉', 'ニシマタマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後高田市大平', '44', '44209', '8721106', '大分県', 'オオイタケン', '豊後高田市', 'ブンゴタカダシ', '大平', 'オオヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後高田市臼野', '44', '44209', '8721107', '大分県', 'オオイタケン', '豊後高田市', 'ブンゴタカダシ', '臼野', 'ウスノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後高田市夷', '44', '44209', '8721201', '大分県', 'オオイタケン', '豊後高田市', 'ブンゴタカダシ', '夷', 'エビス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後高田市香々地', '44', '44209', '8721202', '大分県', 'オオイタケン', '豊後高田市', 'ブンゴタカダシ', '香々地', 'カカヂ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後高田市堅来', '44', '44209', '8721203', '大分県', 'オオイタケン', '豊後高田市', 'ブンゴタカダシ', '堅来', 'カタク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後高田市上香々地', '44', '44209', '8721204', '大分県', 'オオイタケン', '豊後高田市', 'ブンゴタカダシ', '上香々地', 'カミカカヂ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後高田市小畑', '44', '44209', '8721205', '大分県', 'オオイタケン', '豊後高田市', 'ブンゴタカダシ', '小畑', 'コバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後高田市羽根', '44', '44209', '8721206', '大分県', 'オオイタケン', '豊後高田市', 'ブンゴタカダシ', '羽根', 'ハネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後高田市見目', '44', '44209', '8721207', '大分県', 'オオイタケン', '豊後高田市', 'ブンゴタカダシ', '見目', 'ミメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県国東市国見町竹田津', '44', '44214', '8721321', '大分県', 'オオイタケン', '国東市', 'クニサキシ', '国見町竹田津', 'クニミマチタケタヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県国東市国見町西方寺', '44', '44214', '8721322', '大分県', 'オオイタケン', '国東市', 'クニサキシ', '国見町西方寺', 'クニミマチサイホウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県国東市国見町鬼籠', '44', '44214', '8721323', '大分県', 'オオイタケン', '国東市', 'クニサキシ', '国見町鬼籠', 'クニミマチキコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県国東市国見町櫛海', '44', '44214', '8721324', '大分県', 'オオイタケン', '国東市', 'クニサキシ', '国見町櫛海', 'クニミマチクシノミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県国東市国見町伊美', '44', '44214', '8721401', '大分県', 'オオイタケン', '国東市', 'クニサキシ', '国見町伊美', 'クニミマチイミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県国東市国見町中', '44', '44214', '8721402', '大分県', 'オオイタケン', '国東市', 'クニサキシ', '国見町中', 'クニミマチナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県国東市国見町野田', '44', '44214', '8721403', '大分県', 'オオイタケン', '国東市', 'クニサキシ', '国見町野田', 'クニミマチノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県国東市国見町千燈', '44', '44214', '8721404', '大分県', 'オオイタケン', '国東市', 'クニサキシ', '国見町千燈', 'クニミマチセンド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県国東市国見町赤根', '44', '44214', '8721405', '大分県', 'オオイタケン', '国東市', 'クニサキシ', '国見町赤根', 'クニミマチアカネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県国東市国見町櫛来', '44', '44214', '8721406', '大分県', 'オオイタケン', '国東市', 'クニサキシ', '国見町櫛来', 'クニミマチクシク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県東国東郡姫島村', '44', '44322', '8721501', '大分県', 'オオイタケン', '東国東郡姫島村', 'ヒガシクニサキグンヒメシマムラ', null, '　', '（全域）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('113815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県国東市国見町向田', '44', '44214', '8721611', '大分県', 'オオイタケン', '国東市', 'クニサキシ', '国見町向田', 'クニミマチムカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県国東市国見町大熊毛', '44', '44214', '8721612', '大分県', 'オオイタケン', '国東市', 'クニサキシ', '国見町大熊毛', 'クニミマチオオクマゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県国東市国見町小熊毛', '44', '44214', '8721613', '大分県', 'オオイタケン', '国東市', 'クニサキシ', '国見町小熊毛', 'クニミマチコクマゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県国東市国見町岐部', '44', '44214', '8721614', '大分県', 'オオイタケン', '国東市', 'クニサキシ', '国見町岐部', 'クニミマチキベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県国東市国東町浜', '44', '44214', '8721651', '大分県', 'オオイタケン', '国東市', 'クニサキシ', '国東町浜', 'クニサキマチハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県国東市国東町来浦', '44', '44214', '8721652', '大分県', 'オオイタケン', '国東市', 'クニサキシ', '国東町来浦', 'クニサキマチクノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県国東市国東町岩戸寺', '44', '44214', '8721653', '大分県', 'オオイタケン', '国東市', 'クニサキシ', '国東町岩戸寺', 'クニサキマチイワドウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県杵築市', '44', '44210', '8730000', '大分県', 'オオイタケン', '杵築市', 'キツキシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('113823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県杵築市杵築', '44', '44210', '8730001', '大分県', 'オオイタケン', '杵築市', 'キツキシ', '杵築', 'キツキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県杵築市南杵築', '44', '44210', '8730002', '大分県', 'オオイタケン', '杵築市', 'キツキシ', '南杵築', 'ミナミキツキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県杵築市馬場尾', '44', '44210', '8730003', '大分県', 'オオイタケン', '杵築市', 'キツキシ', '馬場尾', 'ババオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県杵築市宮司', '44', '44210', '8730004', '大分県', 'オオイタケン', '杵築市', 'キツキシ', '宮司', 'ミヤジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県杵築市猪尾', '44', '44210', '8730005', '大分県', 'オオイタケン', '杵築市', 'キツキシ', '猪尾', 'イノオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県杵築市大内', '44', '44210', '8730006', '大分県', 'オオイタケン', '杵築市', 'キツキシ', '大内', 'オオウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県杵築市片野', '44', '44210', '8730007', '大分県', 'オオイタケン', '杵築市', 'キツキシ', '片野', 'カタノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県杵築市熊野', '44', '44210', '8730008', '大分県', 'オオイタケン', '杵築市', 'キツキシ', '熊野', 'クマノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県杵築市相原', '44', '44210', '8730011', '大分県', 'オオイタケン', '杵築市', 'キツキシ', '相原', 'アイワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県杵築市中', '44', '44210', '8730012', '大分県', 'オオイタケン', '杵築市', 'キツキシ', '中', 'ナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県杵築市日野', '44', '44210', '8730013', '大分県', 'オオイタケン', '杵築市', 'キツキシ', '日野', 'ヒノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県杵築市本庄', '44', '44210', '8730014', '大分県', 'オオイタケン', '杵築市', 'キツキシ', '本庄', 'ホンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県杵築市八坂', '44', '44210', '8730015', '大分県', 'オオイタケン', '杵築市', 'キツキシ', '八坂', 'ヤサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県杵築市岩谷', '44', '44210', '8730021', '大分県', 'オオイタケン', '杵築市', 'キツキシ', '岩谷', 'イワヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県杵築市大片平', '44', '44210', '8730022', '大分県', 'オオイタケン', '杵築市', 'キツキシ', '大片平', 'オオカタヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県杵築市鴨川', '44', '44210', '8730023', '大分県', 'オオイタケン', '杵築市', 'キツキシ', '鴨川', 'カモガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県杵築市船部', '44', '44210', '8730024', '大分県', 'オオイタケン', '杵築市', 'キツキシ', '船部', 'フナベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県杵築市溝井', '44', '44210', '8730025', '大分県', 'オオイタケン', '杵築市', 'キツキシ', '溝井', 'ミゾイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県杵築市狩宿', '44', '44210', '8730031', '大分県', 'オオイタケン', '杵築市', 'キツキシ', '狩宿', 'カリシュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県杵築市奈多', '44', '44210', '8730032', '大分県', 'オオイタケン', '杵築市', 'キツキシ', '奈多', 'ナダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県杵築市守江', '44', '44210', '8730033', '大分県', 'オオイタケン', '杵築市', 'キツキシ', '守江', 'モリエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県杵築市横城', '44', '44210', '8730034', '大分県', 'オオイタケン', '杵築市', 'キツキシ', '横城', 'ヨコギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県杵築市大田俣水天堤', '44', '44210', '8730041', '大分県', 'オオイタケン', '杵築市', 'キツキシ', '大田俣水', 'オオタマタミズ', null, null, '天堤', 'アマツツミ');
INSERT INTO `ms_addresses` VALUES ('113846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県国東市安岐町矢川天堤', '44', '44214', '8730053', '大分県', 'オオイタケン', '国東市', 'クニサキシ', '安岐町矢川', 'アキマチヤガワ', null, null, '天堤', 'アマツツミ');
INSERT INTO `ms_addresses` VALUES ('113847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県国東市安岐町吉松', '44', '44214', '8730201', '大分県', 'オオイタケン', '国東市', 'クニサキシ', '安岐町吉松', 'アキマチヨシマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県国東市安岐町瀬戸田', '44', '44214', '8730202', '大分県', 'オオイタケン', '国東市', 'クニサキシ', '安岐町瀬戸田', 'アキマチセドタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県国東市安岐町中園', '44', '44214', '8730203', '大分県', 'オオイタケン', '国東市', 'クニサキシ', '安岐町中園', 'アキマチナカソノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県国東市安岐町成久', '44', '44214', '8730204', '大分県', 'オオイタケン', '国東市', 'クニサキシ', '安岐町成久', 'アキマチナリヒサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県国東市安岐町掛樋', '44', '44214', '8730205', '大分県', 'オオイタケン', '国東市', 'クニサキシ', '安岐町掛樋', 'アキマチカケヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県国東市安岐町山浦', '44', '44214', '8730206', '大分県', 'オオイタケン', '国東市', 'クニサキシ', '安岐町山浦', 'アキマチヤマウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県国東市安岐町油留木', '44', '44214', '8730207', '大分県', 'オオイタケン', '国東市', 'クニサキシ', '安岐町油留木', 'アキマチユルギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県国東市安岐町馬場', '44', '44214', '8730211', '大分県', 'オオイタケン', '国東市', 'クニサキシ', '安岐町馬場', 'アキマチババ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県国東市安岐町塩屋', '44', '44214', '8730212', '大分県', 'オオイタケン', '国東市', 'クニサキシ', '安岐町塩屋', 'アキマチシオヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県国東市安岐町西本', '44', '44214', '8730221', '大分県', 'オオイタケン', '国東市', 'クニサキシ', '安岐町西本', 'アキマチニシモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県国東市安岐町下山口', '44', '44214', '8730222', '大分県', 'オオイタケン', '国東市', 'クニサキシ', '安岐町下山口', 'アキマチシモヤマグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県国東市安岐町大添', '44', '44214', '8730223', '大分県', 'オオイタケン', '国東市', 'クニサキシ', '安岐町大添', 'アキマチオオソエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県国東市安岐町山口', '44', '44214', '8730224', '大分県', 'オオイタケン', '国東市', 'クニサキシ', '安岐町山口', 'アキマチヤマグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県国東市安岐町下原', '44', '44214', '8730231', '大分県', 'オオイタケン', '国東市', 'クニサキシ', '安岐町下原', 'アキマチシモバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県国東市安岐町向陽台', '44', '44214', '8730232', '大分県', 'オオイタケン', '国東市', 'クニサキシ', '安岐町向陽台', 'アキマチコウヨウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県国東市安岐町朝来', '44', '44214', '8730351', '大分県', 'オオイタケン', '国東市', 'クニサキシ', '安岐町朝来', 'アキマチアサク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県国東市安岐町明治', '44', '44214', '8730352', '大分県', 'オオイタケン', '国東市', 'クニサキシ', '安岐町明治', 'アキマチメイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県国東市安岐町矢川', '44', '44214', '8730353', '大分県', 'オオイタケン', '国東市', 'クニサキシ', '安岐町矢川', 'アキマチヤガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県国東市安岐町糸永', '44', '44214', '8730354', '大分県', 'オオイタケン', '国東市', 'クニサキシ', '安岐町糸永', 'アキマチイトナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県国東市安岐町富清', '44', '44214', '8730355', '大分県', 'オオイタケン', '国東市', 'クニサキシ', '安岐町富清', 'アキマチトミキヨ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県国東市安岐町両子', '44', '44214', '8730356', '大分県', 'オオイタケン', '国東市', 'クニサキシ', '安岐町両子', 'アキマチフタゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県国東市武蔵町池ノ内', '44', '44214', '8730401', '大分県', 'オオイタケン', '国東市', 'クニサキシ', '武蔵町池ノ内', 'ムサシマチイケノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県国東市武蔵町内田', '44', '44214', '8730402', '大分県', 'オオイタケン', '国東市', 'クニサキシ', '武蔵町内田', 'ムサシマチウチダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県国東市武蔵町成吉', '44', '44214', '8730404', '大分県', 'オオイタケン', '国東市', 'クニサキシ', '武蔵町成吉', 'ムサシマチナリヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県国東市武蔵町麻田', '44', '44214', '8730405', '大分県', 'オオイタケン', '国東市', 'クニサキシ', '武蔵町麻田', 'ムサシマチアサダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県国東市武蔵町丸小野', '44', '44214', '8730406', '大分県', 'オオイタケン', '国東市', 'クニサキシ', '武蔵町丸小野', 'ムサシマチマルオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県国東市武蔵町狭間', '44', '44214', '8730407', '大分県', 'オオイタケン', '国東市', 'クニサキシ', '武蔵町狭間', 'ムサシマチハサマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県国東市武蔵町古市', '44', '44214', '8730412', '大分県', 'オオイタケン', '国東市', 'クニサキシ', '武蔵町古市', 'ムサシマチフルイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県国東市武蔵町手野', '44', '44214', '8730414', '大分県', 'オオイタケン', '国東市', 'クニサキシ', '武蔵町手野', 'ムサシマチテノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県国東市武蔵町吉広', '44', '44214', '8730415', '大分県', 'オオイタケン', '国東市', 'クニサキシ', '武蔵町吉広', 'ムサシマチヨシヒロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県国東市武蔵町糸原', '44', '44214', '8730421', '大分県', 'オオイタケン', '国東市', 'クニサキシ', '武蔵町糸原', 'ムサシマチイトハル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県国東市武蔵町小城', '44', '44214', '8730422', '大分県', 'オオイタケン', '国東市', 'クニサキシ', '武蔵町小城', 'ムサシマチオギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県国東市武蔵町三井寺', '44', '44214', '8730423', '大分県', 'オオイタケン', '国東市', 'クニサキシ', '武蔵町三井寺', 'ムサシマチミイデラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県国東市武蔵町志和利', '44', '44214', '8730424', '大分県', 'オオイタケン', '国東市', 'クニサキシ', '武蔵町志和利', 'ムサシマチシワリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県国東市武蔵町向陽台', '44', '44214', '8730432', '大分県', 'オオイタケン', '国東市', 'クニサキシ', '武蔵町向陽台', 'ムサシマチコウヨウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県国東市', '44', '44214', '8730500', '大分県', 'オオイタケン', '国東市', 'クニサキシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('113887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県国東市国東町北江', '44', '44214', '8730501', '大分県', 'オオイタケン', '国東市', 'クニサキシ', '国東町北江', 'クニサキマチキタエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県国東市国東町田深', '44', '44214', '8730502', '大分県', 'オオイタケン', '国東市', 'クニサキシ', '国東町田深', 'クニサキマチタブカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県国東市国東町鶴川', '44', '44214', '8730503', '大分県', 'オオイタケン', '国東市', 'クニサキシ', '国東町鶴川', 'クニサキマチツルガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県国東市国東町安国寺', '44', '44214', '8730504', '大分県', 'オオイタケン', '国東市', 'クニサキシ', '国東町安国寺', 'クニサキマチアンコクジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県国東市国東町小原', '44', '44214', '8730511', '大分県', 'オオイタケン', '国東市', 'クニサキシ', '国東町小原', 'クニサキマチオハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県国東市国東町治郎丸', '44', '44214', '8730512', '大分県', 'オオイタケン', '国東市', 'クニサキシ', '国東町治郎丸', 'クニサキマチジロウマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県国東市国東町綱井', '44', '44214', '8730513', '大分県', 'オオイタケン', '国東市', 'クニサキシ', '国東町綱井', 'クニサキマチツナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県国東市国東町重藤', '44', '44214', '8730514', '大分県', 'オオイタケン', '国東市', 'クニサキシ', '国東町重藤', 'クニサキマチシゲフジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県国東市国東町原', '44', '44214', '8730521', '大分県', 'オオイタケン', '国東市', 'クニサキシ', '国東町原', 'クニサキマチハル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県国東市国東町岩屋', '44', '44214', '8730522', '大分県', 'オオイタケン', '国東市', 'クニサキシ', '国東町岩屋', 'クニサキマチイワヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県国東市国東町赤松', '44', '44214', '8730523', '大分県', 'オオイタケン', '国東市', 'クニサキシ', '国東町赤松', 'クニサキマチアカマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県国東市国東町横手', '44', '44214', '8730524', '大分県', 'オオイタケン', '国東市', 'クニサキシ', '国東町横手', 'クニサキマチヨコテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県国東市国東町川原', '44', '44214', '8730531', '大分県', 'オオイタケン', '国東市', 'クニサキシ', '国東町川原', 'クニサキマチカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県国東市国東町中田', '44', '44214', '8730532', '大分県', 'オオイタケン', '国東市', 'クニサキシ', '国東町中田', 'クニサキマチナカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県国東市国東町見地', '44', '44214', '8730533', '大分県', 'オオイタケン', '国東市', 'クニサキシ', '国東町見地', 'クニサキマチケンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県国東市国東町下成仏', '44', '44214', '8730534', '大分県', 'オオイタケン', '国東市', 'クニサキシ', '国東町下成仏', 'クニサキマチシモジョウブツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県国東市国東町成仏', '44', '44214', '8730535', '大分県', 'オオイタケン', '国東市', 'クニサキシ', '国東町成仏', 'クニサキマチジョウブツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県国東市国東町深江', '44', '44214', '8730641', '大分県', 'オオイタケン', '国東市', 'クニサキシ', '国東町深江', 'クニサキマチフカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県国東市国東町東堅来', '44', '44214', '8730642', '大分県', 'オオイタケン', '国東市', 'クニサキシ', '国東町東堅来', 'クニサキマチヒガシカタク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県国東市国東町富来浦', '44', '44214', '8730643', '大分県', 'オオイタケン', '国東市', 'クニサキシ', '国東町富来浦', 'クニサキマチトミクウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県国東市国東町浜崎', '44', '44214', '8730644', '大分県', 'オオイタケン', '国東市', 'クニサキシ', '国東町浜崎', 'クニサキマチハマサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県国東市国東町富来', '44', '44214', '8730645', '大分県', 'オオイタケン', '国東市', 'クニサキシ', '国東町富来', 'クニサキマチトミク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県国東市国東町大恩寺', '44', '44214', '8730646', '大分県', 'オオイタケン', '国東市', 'クニサキシ', '国東町大恩寺', 'クニサキマチダイオンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市', '44', '44202', '8740000', '大分県', 'オオイタケン', '別府市', 'ベップシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('113912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市小坂', '44', '44202', '8740001', '大分県', 'オオイタケン', '別府市', 'ベップシ', '小坂', 'オサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市関の江新町', '44', '44202', '8740002', '大分県', 'オオイタケン', '別府市', 'ベップシ', '関の江新町', 'セキノエシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市大所', '44', '44202', '8740003', '大分県', 'オオイタケン', '別府市', 'ベップシ', '大所', 'オトコロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市湯山', '44', '44202', '8740004', '大分県', 'オオイタケン', '別府市', 'ベップシ', '湯山', 'ユヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市天間', '44', '44202', '8740005', '大分県', 'オオイタケン', '別府市', 'ベップシ', '天間', 'アママ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市内竈', '44', '44202', '8740011', '大分県', 'オオイタケン', '別府市', 'ベップシ', '内竈', 'ウチカマド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市スパランド豊海', '44', '44202', '8740012', '大分県', 'オオイタケン', '別府市', 'ベップシ', 'スパランド豊海', 'スパランドトヨミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市古市町', '44', '44202', '8740013', '大分県', 'オオイタケン', '別府市', 'ベップシ', '古市町', 'フルイチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市亀川浜田町', '44', '44202', '8740014', '大分県', 'オオイタケン', '別府市', 'ベップシ', '亀川浜田町', 'カメガワハマダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市国立', '44', '44202', '8740015', '大分県', 'オオイタケン', '別府市', 'ベップシ', '国立', 'クニタテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市野田', '44', '44202', '8740016', '大分県', 'オオイタケン', '別府市', 'ベップシ', '野田', 'ノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市亀川中央町', '44', '44202', '8740021', '大分県', 'オオイタケン', '別府市', 'ベップシ', '亀川中央町', 'カメガワチュウオウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市亀川東町', '44', '44202', '8740022', '大分県', 'オオイタケン', '別府市', 'ベップシ', '亀川東町', 'カメガワヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市上人ケ浜町', '44', '44202', '8740023', '大分県', 'オオイタケン', '別府市', 'ベップシ', '上人ケ浜町', 'ショウニンガハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市平田町', '44', '44202', '8740024', '大分県', 'オオイタケン', '別府市', 'ベップシ', '平田町', 'ヒラタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市亀川四の湯町', '44', '44202', '8740025', '大分県', 'オオイタケン', '別府市', 'ベップシ', '亀川四の湯町', 'カメガワシノユマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市照波園町', '44', '44202', '8740031', '大分県', 'オオイタケン', '別府市', 'ベップシ', '照波園町', 'ショウハエンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市上人本町', '44', '44202', '8740032', '大分県', 'オオイタケン', '別府市', 'ベップシ', '上人本町', 'ショウニンホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市上人南', '44', '44202', '8740033', '大分県', 'オオイタケン', '別府市', 'ベップシ', '上人南', 'ショウニンミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市上人仲町', '44', '44202', '8740034', '大分県', 'オオイタケン', '別府市', 'ベップシ', '上人仲町', 'ショウニンナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市上人西', '44', '44202', '8740035', '大分県', 'オオイタケン', '別府市', 'ベップシ', '上人西', 'ショウニンニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市上平田町', '44', '44202', '8740036', '大分県', 'オオイタケン', '別府市', 'ベップシ', '上平田町', 'カミヒラタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市大観山町', '44', '44202', '8740037', '大分県', 'オオイタケン', '別府市', 'ベップシ', '大観山町', 'ダイカンヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市北鉄輪', '44', '44202', '8740041', '大分県', 'オオイタケン', '別府市', 'ベップシ', '北鉄輪', 'キタカンナワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市鉄輪東', '44', '44202', '8740042', '大分県', 'オオイタケン', '別府市', 'ベップシ', '鉄輪東', 'カンナワヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市井田', '44', '44202', '8740043', '大分県', 'オオイタケン', '別府市', 'ベップシ', '井田', 'イダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市風呂本', '44', '44202', '8740044', '大分県', 'オオイタケン', '別府市', 'ベップシ', '風呂本', 'フロモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市御幸', '44', '44202', '8740045', '大分県', 'オオイタケン', '別府市', 'ベップシ', '御幸', 'ミユキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市鉄輪上', '44', '44202', '8740046', '大分県', 'オオイタケン', '別府市', 'ベップシ', '鉄輪上', 'カンナワカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市山の口', '44', '44202', '8740801', '大分県', 'オオイタケン', '別府市', 'ベップシ', '山の口', 'ヤマノクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市城島', '44', '44202', '8740802', '大分県', 'オオイタケン', '別府市', 'ベップシ', '城島', 'キジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市東山一区', '44', '44202', '8740803', '大分県', 'オオイタケン', '別府市', 'ベップシ', '東山一区', 'ヒガシヤマイック', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市東山二区', '44', '44202', '8740804', '大分県', 'オオイタケン', '別府市', 'ベップシ', '東山二区', 'ヒガシヤマニク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市枝郷', '44', '44202', '8740805', '大分県', 'オオイタケン', '別府市', 'ベップシ', '枝郷', 'エダゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市柳', '44', '44202', '8740811', '大分県', 'オオイタケン', '別府市', 'ベップシ', '柳', 'ヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市朝見', '44', '44202', '8740812', '大分県', 'オオイタケン', '別府市', 'ベップシ', '朝見', 'アサミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市両郡橋', '44', '44202', '8740813', '大分県', 'オオイタケン', '別府市', 'ベップシ', '両郡橋', 'リョウグンバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市浦田', '44', '44202', '8740814', '大分県', 'オオイタケン', '別府市', 'ベップシ', '浦田', 'ウラタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市田の口', '44', '44202', '8740815', '大分県', 'オオイタケン', '別府市', 'ベップシ', '田の口', 'タノクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市河内', '44', '44202', '8740816', '大分県', 'オオイタケン', '別府市', 'ベップシ', '河内', 'コウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市鳥越', '44', '44202', '8740817', '大分県', 'オオイタケン', '別府市', 'ベップシ', '鳥越', 'トリゴエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市山家', '44', '44202', '8740818', '大分県', 'オオイタケン', '別府市', 'ベップシ', '山家', 'ヤマガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市赤松', '44', '44202', '8740819', '大分県', 'オオイタケン', '別府市', 'ベップシ', '赤松', 'アカマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市原町', '44', '44202', '8740820', '大分県', 'オオイタケン', '別府市', 'ベップシ', '原町', 'ハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市乙原', '44', '44202', '8740821', '大分県', 'オオイタケン', '別府市', 'ベップシ', '乙原', 'オトバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市観海寺', '44', '44202', '8740822', '大分県', 'オオイタケン', '別府市', 'ベップシ', '観海寺', 'カンカイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市南立石本町', '44', '44202', '8740823', '大分県', 'オオイタケン', '別府市', 'ベップシ', '南立石本町', 'ミナミタテイシホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市南立石板地町', '44', '44202', '8740824', '大分県', 'オオイタケン', '別府市', 'ベップシ', '南立石板地町', 'ミナミタテイシイタジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市南立石八幡町', '44', '44202', '8740825', '大分県', 'オオイタケン', '別府市', 'ベップシ', '南立石八幡町', 'ミナミタテイシハチマンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市鶴見園町', '44', '44202', '8740826', '大分県', 'オオイタケン', '別府市', 'ベップシ', '鶴見園町', 'ツルミエンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市南立石二区', '44', '44202', '8740827', '大分県', 'オオイタケン', '別府市', 'ベップシ', '南立石二区', 'ミナミタテイシニク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市山の手町', '44', '44202', '8740828', '大分県', 'オオイタケン', '別府市', 'ベップシ', '山の手町', 'ヤマノテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市上原町', '44', '44202', '8740829', '大分県', 'オオイタケン', '別府市', 'ベップシ', '上原町', 'カミハルチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市堀田', '44', '44202', '8740831', '大分県', 'オオイタケン', '別府市', 'ベップシ', '堀田', 'ホリタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市南立石生目町', '44', '44202', '8740832', '大分県', 'オオイタケン', '別府市', 'ベップシ', '南立石生目町', 'ミナミタテイシイキメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市鶴見', '44', '44202', '8740833', '大分県', 'オオイタケン', '別府市', 'ベップシ', '鶴見', 'ツルミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市新別府', '44', '44202', '8740834', '大分県', 'オオイタケン', '別府市', 'ベップシ', '新別府', 'シンベップ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市実相寺', '44', '44202', '8740835', '大分県', 'オオイタケン', '別府市', 'ベップシ', '実相寺', 'ジッソウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市東荘園', '44', '44202', '8740836', '大分県', 'オオイタケン', '別府市', 'ベップシ', '東荘園', 'ヒガシソウエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市荘園北町', '44', '44202', '8740837', '大分県', 'オオイタケン', '別府市', 'ベップシ', '荘園北町', 'ソウエンキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市荘園', '44', '44202', '8740838', '大分県', 'オオイタケン', '別府市', 'ベップシ', '荘園', 'ソウエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市南立石一区', '44', '44202', '8740839', '大分県', 'オオイタケン', '別府市', 'ベップシ', '南立石一区', 'ミナミタテイシイック', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市鶴見', '44', '44202', '8740840', '大分県', 'オオイタケン', '別府市', 'ベップシ', '鶴見', 'ツルミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市鶴見', '44', '44202', '8740840', '大分県', 'オオイタケン', '別府市', 'ベップシ', '鶴見', 'ツルミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市竹の内', '44', '44202', '8740841', '大分県', 'オオイタケン', '別府市', 'ベップシ', '竹の内', 'タケノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市小倉', '44', '44202', '8740842', '大分県', 'オオイタケン', '別府市', 'ベップシ', '小倉', 'オグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市明礬', '44', '44202', '8740843', '大分県', 'オオイタケン', '別府市', 'ベップシ', '明礬', 'ミョウバン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市火売', '44', '44202', '8740844', '大分県', 'オオイタケン', '別府市', 'ベップシ', '火売', 'ホノメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市北中', '44', '44202', '8740845', '大分県', 'オオイタケン', '別府市', 'ベップシ', '北中', 'キタジュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市朝日ケ丘町', '44', '44202', '8740846', '大分県', 'オオイタケン', '別府市', 'ベップシ', '朝日ケ丘町', 'アサヒガオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市馬場', '44', '44202', '8740847', '大分県', 'オオイタケン', '別府市', 'ベップシ', '馬場', 'ババ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市大畑', '44', '44202', '8740848', '大分県', 'オオイタケン', '別府市', 'ベップシ', '大畑', 'オバタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市扇山', '44', '44202', '8740849', '大分県', 'オオイタケン', '別府市', 'ベップシ', '扇山', 'オウギヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市中島町', '44', '44202', '8740901', '大分県', 'オオイタケン', '別府市', 'ベップシ', '中島町', 'ナカシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市青山町', '44', '44202', '8740902', '大分県', 'オオイタケン', '別府市', 'ベップシ', '青山町', 'アオヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市野口原', '44', '44202', '8740903', '大分県', 'オオイタケン', '別府市', 'ベップシ', '野口原', 'ノグチハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市南荘園町', '44', '44202', '8740904', '大分県', 'オオイタケン', '別府市', 'ベップシ', '南荘園町', 'ミナミソウエンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市上野口町', '44', '44202', '8740905', '大分県', 'オオイタケン', '別府市', 'ベップシ', '上野口町', 'カミノグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市天満町', '44', '44202', '8740906', '大分県', 'オオイタケン', '別府市', 'ベップシ', '天満町', 'テンマンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市幸町', '44', '44202', '8740907', '大分県', 'オオイタケン', '別府市', 'ベップシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市上田の湯町', '44', '44202', '8740908', '大分県', 'オオイタケン', '別府市', 'ベップシ', '上田の湯町', 'カミタノユマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市田の湯町', '44', '44202', '8740909', '大分県', 'オオイタケン', '別府市', 'ベップシ', '田の湯町', 'タノユマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市石垣西', '44', '44202', '8740910', '大分県', 'オオイタケン', '別府市', 'ベップシ', '石垣西', 'イシガキニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市緑丘町', '44', '44202', '8740911', '大分県', 'オオイタケン', '別府市', 'ベップシ', '緑丘町', 'ミドリガオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市南須賀', '44', '44202', '8740912', '大分県', 'オオイタケン', '別府市', 'ベップシ', '南須賀', 'ミナミスカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市春木', '44', '44202', '8740913', '大分県', 'オオイタケン', '別府市', 'ベップシ', '春木', 'ハルキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市中須賀元町', '44', '44202', '8740914', '大分県', 'オオイタケン', '別府市', 'ベップシ', '中須賀元町', 'ナカスカモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('113999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市桜ケ丘', '44', '44202', '8740915', '大分県', 'オオイタケン', '別府市', 'ベップシ', '桜ケ丘', 'サクラガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市中須賀本町', '44', '44202', '8740916', '大分県', 'オオイタケン', '別府市', 'ベップシ', '中須賀本町', 'ナカスカホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市中須賀東町', '44', '44202', '8740917', '大分県', 'オオイタケン', '別府市', 'ベップシ', '中須賀東町', 'ナカスカヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市汐見町', '44', '44202', '8740918', '大分県', 'オオイタケン', '別府市', 'ベップシ', '汐見町', 'シオミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市石垣東', '44', '44202', '8740919', '大分県', 'オオイタケン', '別府市', 'ベップシ', '石垣東', 'イシガキヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市北浜', '44', '44202', '8740920', '大分県', 'オオイタケン', '別府市', 'ベップシ', '北浜', 'キタハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市富士見町', '44', '44202', '8740921', '大分県', 'オオイタケン', '別府市', 'ベップシ', '富士見町', 'フジミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市船小路町', '44', '44202', '8740922', '大分県', 'オオイタケン', '別府市', 'ベップシ', '船小路町', 'フナコウジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市新港町', '44', '44202', '8740923', '大分県', 'オオイタケン', '別府市', 'ベップシ', '新港町', 'シンミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市餅ケ浜町', '44', '44202', '8740924', '大分県', 'オオイタケン', '別府市', 'ベップシ', '餅ケ浜町', 'モチガハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市若草町', '44', '44202', '8740925', '大分県', 'オオイタケン', '別府市', 'ベップシ', '若草町', 'ワカクサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市京町', '44', '44202', '8740926', '大分県', 'オオイタケン', '別府市', 'ベップシ', '京町', 'キョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市弓ケ浜町', '44', '44202', '8740927', '大分県', 'オオイタケン', '別府市', 'ベップシ', '弓ケ浜町', 'ユミガハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市北的ケ浜町', '44', '44202', '8740928', '大分県', 'オオイタケン', '別府市', 'ベップシ', '北的ケ浜町', 'キタマトガハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市南的ケ浜町', '44', '44202', '8740929', '大分県', 'オオイタケン', '別府市', 'ベップシ', '南的ケ浜町', 'ミナミマトガハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市光町', '44', '44202', '8740930', '大分県', 'オオイタケン', '別府市', 'ベップシ', '光町', 'ヒカリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市西野口町', '44', '44202', '8740931', '大分県', 'オオイタケン', '別府市', 'ベップシ', '西野口町', 'ニシノグチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市野口中町', '44', '44202', '8740932', '大分県', 'オオイタケン', '別府市', 'ベップシ', '野口中町', 'ノグチナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市野口元町', '44', '44202', '8740933', '大分県', 'オオイタケン', '別府市', 'ベップシ', '野口元町', 'ノグチモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市駅前本町', '44', '44202', '8740934', '大分県', 'オオイタケン', '別府市', 'ベップシ', '駅前本町', 'エキマエホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市駅前町', '44', '44202', '8740935', '大分県', 'オオイタケン', '別府市', 'ベップシ', '駅前町', 'エキマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市中央町', '44', '44202', '8740936', '大分県', 'オオイタケン', '別府市', 'ベップシ', '中央町', 'チュウオウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市秋葉町', '44', '44202', '8740937', '大分県', 'オオイタケン', '別府市', 'ベップシ', '秋葉町', 'アキバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市末広町', '44', '44202', '8740938', '大分県', 'オオイタケン', '別府市', 'ベップシ', '末広町', 'スエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市立田町', '44', '44202', '8740939', '大分県', 'オオイタケン', '別府市', 'ベップシ', '立田町', 'タッタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市南町', '44', '44202', '8740941', '大分県', 'オオイタケン', '別府市', 'ベップシ', '南町', 'ミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市千代町', '44', '44202', '8740942', '大分県', 'オオイタケン', '別府市', 'ベップシ', '千代町', 'チヨマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市楠町', '44', '44202', '8740943', '大分県', 'オオイタケン', '別府市', 'ベップシ', '楠町', 'クスノキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市元町', '44', '44202', '8740944', '大分県', 'オオイタケン', '別府市', 'ベップシ', '元町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市浜町', '44', '44202', '8740945', '大分県', 'オオイタケン', '別府市', 'ベップシ', '浜町', 'ハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市松原町', '44', '44202', '8740946', '大分県', 'オオイタケン', '別府市', 'ベップシ', '松原町', 'マツバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市浜脇', '44', '44202', '8740947', '大分県', 'オオイタケン', '別府市', 'ベップシ', '浜脇', 'ハマワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県臼杵市', '44', '44206', '8750000', '大分県', 'オオイタケン', '臼杵市', 'ウスキシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('114045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県臼杵市佐志生', '44', '44206', '8750001', '大分県', 'オオイタケン', '臼杵市', 'ウスキシ', '佐志生', 'サシウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県臼杵市下ノ江', '44', '44206', '8750002', '大分県', 'オオイタケン', '臼杵市', 'ウスキシ', '下ノ江', 'シタノエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県臼杵市田井', '44', '44206', '8750003', '大分県', 'オオイタケン', '臼杵市', 'ウスキシ', '田井', 'タイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県臼杵市大野', '44', '44206', '8750004', '大分県', 'オオイタケン', '臼杵市', 'ウスキシ', '大野', 'オオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県臼杵市諏訪', '44', '44206', '8750011', '大分県', 'オオイタケン', '臼杵市', 'ウスキシ', '諏訪', 'スワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県臼杵市大浜', '44', '44206', '8750012', '大分県', 'オオイタケン', '臼杵市', 'ウスキシ', '大浜', 'オオハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県臼杵市中津浦', '44', '44206', '8750013', '大分県', 'オオイタケン', '臼杵市', 'ウスキシ', '中津浦', 'ナカツウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県臼杵市田尻', '44', '44206', '8750021', '大分県', 'オオイタケン', '臼杵市', 'ウスキシ', '田尻', 'タジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県臼杵市末広', '44', '44206', '8750022', '大分県', 'オオイタケン', '臼杵市', 'ウスキシ', '末広', 'スエヒロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県臼杵市江無田', '44', '44206', '8750023', '大分県', 'オオイタケン', '臼杵市', 'ウスキシ', '江無田', 'エムタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県臼杵市深江', '44', '44206', '8750031', '大分県', 'オオイタケン', '臼杵市', 'ウスキシ', '深江', 'フカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県臼杵市風成', '44', '44206', '8750032', '大分県', 'オオイタケン', '臼杵市', 'ウスキシ', '風成', 'カザナシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県臼杵市大泊', '44', '44206', '8750033', '大分県', 'オオイタケン', '臼杵市', 'ウスキシ', '大泊', 'オオトマリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県臼杵市板知屋', '44', '44206', '8750034', '大分県', 'オオイタケン', '臼杵市', 'ウスキシ', '板知屋', 'イタチヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県臼杵市臼杵', '44', '44206', '8750041', '大分県', 'オオイタケン', '臼杵市', 'ウスキシ', '臼杵', 'ウスキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県臼杵市海添', '44', '44206', '8750042', '大分県', 'オオイタケン', '臼杵市', 'ウスキシ', '海添', 'カイゾエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県臼杵市二王座', '44', '44206', '8750043', '大分県', 'オオイタケン', '臼杵市', 'ウスキシ', '二王座', 'ニオウザ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県臼杵市戸室', '44', '44206', '8750051', '大分県', 'オオイタケン', '臼杵市', 'ウスキシ', '戸室', 'トムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県臼杵市市浜', '44', '44206', '8750052', '大分県', 'オオイタケン', '臼杵市', 'ウスキシ', '市浜', 'イチハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県臼杵市福良', '44', '44206', '8750053', '大分県', 'オオイタケン', '臼杵市', 'ウスキシ', '福良', 'フクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県臼杵市前田', '44', '44206', '8750061', '大分県', 'オオイタケン', '臼杵市', 'ウスキシ', '前田', 'マエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県臼杵市野田', '44', '44206', '8750062', '大分県', 'オオイタケン', '臼杵市', 'ウスキシ', '野田', 'ノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県臼杵市望月', '44', '44206', '8750063', '大分県', 'オオイタケン', '臼杵市', 'ウスキシ', '望月', 'モチヅキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県臼杵市深田', '44', '44206', '8750064', '大分県', 'オオイタケン', '臼杵市', 'ウスキシ', '深田', 'フカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県臼杵市家野', '44', '44206', '8750065', '大分県', 'オオイタケン', '臼杵市', 'ウスキシ', '家野', 'イエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県臼杵市久木小野', '44', '44206', '8750070', '大分県', 'オオイタケン', '臼杵市', 'ウスキシ', '久木小野', 'クギオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県臼杵市吉小野', '44', '44206', '8750071', '大分県', 'オオイタケン', '臼杵市', 'ウスキシ', '吉小野', 'ヨシオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県臼杵市中臼杵', '44', '44206', '8750072', '大分県', 'オオイタケン', '臼杵市', 'ウスキシ', '中臼杵', 'ナカウスキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県臼杵市掻懐', '44', '44206', '8750073', '大分県', 'オオイタケン', '臼杵市', 'ウスキシ', '掻懐', 'カキダキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県臼杵市左津留', '44', '44206', '8750074', '大分県', 'オオイタケン', '臼杵市', 'ウスキシ', '左津留', 'サヅル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県臼杵市中尾', '44', '44206', '8750075', '大分県', 'オオイタケン', '臼杵市', 'ウスキシ', '中尾', 'ナカオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県臼杵市東神野', '44', '44206', '8750076', '大分県', 'オオイタケン', '臼杵市', 'ウスキシ', '東神野', 'ヒガシコウノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県臼杵市乙見', '44', '44206', '8750077', '大分県', 'オオイタケン', '臼杵市', 'ウスキシ', '乙見', 'オトミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県臼杵市高山', '44', '44206', '8750078', '大分県', 'オオイタケン', '臼杵市', 'ウスキシ', '高山', 'タカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県臼杵市武山', '44', '44206', '8750079', '大分県', 'オオイタケン', '臼杵市', 'ウスキシ', '武山', 'タケヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県臼杵市藤河内', '44', '44206', '8750081', '大分県', 'オオイタケン', '臼杵市', 'ウスキシ', '藤河内', 'フジカワチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県臼杵市稲田', '44', '44206', '8750082', '大分県', 'オオイタケン', '臼杵市', 'ウスキシ', '稲田', 'イナダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県臼杵市井村', '44', '44206', '8750083', '大分県', 'オオイタケン', '臼杵市', 'ウスキシ', '井村', 'イムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県臼杵市岳谷', '44', '44206', '8750084', '大分県', 'オオイタケン', '臼杵市', 'ウスキシ', '岳谷', 'タケヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県臼杵市野津町野津市', '44', '44206', '8750201', '大分県', 'オオイタケン', '臼杵市', 'ウスキシ', '野津町野津市', 'ノツマチノツイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県臼杵市野津町山頭', '44', '44206', '8750202', '大分県', 'オオイタケン', '臼杵市', 'ウスキシ', '野津町山頭', 'ノツマチヤマズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県臼杵市野津町前河内', '44', '44206', '8750203', '大分県', 'オオイタケン', '臼杵市', 'ウスキシ', '野津町前河内', 'ノツマチマエガワチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県臼杵市野津町都原', '44', '44206', '8750211', '大分県', 'オオイタケン', '臼杵市', 'ウスキシ', '野津町都原', 'ノツマチミヤコバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県臼杵市野津町老松', '44', '44206', '8750212', '大分県', 'オオイタケン', '臼杵市', 'ウスキシ', '野津町老松', 'ノツマチオイマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県臼杵市野津町八里合', '44', '44206', '8750213', '大分県', 'オオイタケン', '臼杵市', 'ウスキシ', '野津町八里合', 'ノツマチハチリゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県臼杵市野津町福良木', '44', '44206', '8750214', '大分県', 'オオイタケン', '臼杵市', 'ウスキシ', '野津町福良木', 'ノツマチフクラギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県臼杵市野津町王子', '44', '44206', '8750215', '大分県', 'オオイタケン', '臼杵市', 'ウスキシ', '野津町王子', 'ノツマチオウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県臼杵市野津町亀甲', '44', '44206', '8750216', '大分県', 'オオイタケン', '臼杵市', 'ウスキシ', '野津町亀甲', 'ノツマチカメコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県臼杵市野津町秋山', '44', '44206', '8750221', '大分県', 'オオイタケン', '臼杵市', 'ウスキシ', '野津町秋山', 'ノツマチアキヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県臼杵市野津町吉田', '44', '44206', '8750222', '大分県', 'オオイタケン', '臼杵市', 'ウスキシ', '野津町吉田', 'ノツマチヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県臼杵市野津町東谷', '44', '44206', '8750223', '大分県', 'オオイタケン', '臼杵市', 'ウスキシ', '野津町東谷', 'ノツマチヒガシタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県臼杵市野津町西畑', '44', '44206', '8750224', '大分県', 'オオイタケン', '臼杵市', 'ウスキシ', '野津町西畑', 'ノツマチニシハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県臼杵市野津町千塚', '44', '44206', '8750231', '大分県', 'オオイタケン', '臼杵市', 'ウスキシ', '野津町千塚', 'ノツマチチヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県臼杵市野津町烏嶽', '44', '44206', '8750232', '大分県', 'オオイタケン', '臼杵市', 'ウスキシ', '野津町烏嶽', 'ノツマチウガク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県臼杵市野津町宮原', '44', '44206', '8750233', '大分県', 'オオイタケン', '臼杵市', 'ウスキシ', '野津町宮原', 'ノツマチミヤバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県臼杵市野津町原', '44', '44206', '8750234', '大分県', 'オオイタケン', '臼杵市', 'ウスキシ', '野津町原', 'ノツマチハル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県臼杵市野津町藤小野', '44', '44206', '8750235', '大分県', 'オオイタケン', '臼杵市', 'ウスキシ', '野津町藤小野', 'ノツマチフジオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県臼杵市野津町柚野木', '44', '44206', '8750236', '大分県', 'オオイタケン', '臼杵市', 'ウスキシ', '野津町柚野木', 'ノツマチユノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県臼杵市野津町西寒田', '44', '44206', '8750237', '大分県', 'オオイタケン', '臼杵市', 'ウスキシ', '野津町西寒田', 'ノツマチササムタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県臼杵市野津町東谷三重谷', '44', '44206', '8750323', '大分県', 'オオイタケン', '臼杵市', 'ウスキシ', '野津町東谷', 'ノツマチヒガシタニ', null, null, '三重谷', 'ミエダニ');
INSERT INTO `ms_addresses` VALUES ('114106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県臼杵市野津町清水原', '44', '44206', '8750341', '大分県', 'オオイタケン', '臼杵市', 'ウスキシ', '野津町清水原', 'ノツマチソウズバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県臼杵市野津町落谷', '44', '44206', '8750342', '大分県', 'オオイタケン', '臼杵市', 'ウスキシ', '野津町落谷', 'ノツマチオチダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県臼杵市野津町岩屋', '44', '44206', '8750343', '大分県', 'オオイタケン', '臼杵市', 'ウスキシ', '野津町岩屋', 'ノツマチイワヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県臼杵市野津町白岩', '44', '44206', '8750344', '大分県', 'オオイタケン', '臼杵市', 'ウスキシ', '野津町白岩', 'ノツマチシライワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県臼杵市野津町泊', '44', '44206', '8750351', '大分県', 'オオイタケン', '臼杵市', 'ウスキシ', '野津町泊', 'ノツマチトマリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県臼杵市野津町垣河内', '44', '44206', '8750352', '大分県', 'オオイタケン', '臼杵市', 'ウスキシ', '野津町垣河内', 'ノツマチカキガワチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県臼杵市野津町西神野', '44', '44206', '8750353', '大分県', 'オオイタケン', '臼杵市', 'ウスキシ', '野津町西神野', 'ノツマチニシコウノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市', '44', '44205', '8760000', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('114118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市高松浦', '44', '44205', '8760001', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '高松浦', 'タカマツウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市日向泊浦', '44', '44205', '8760002', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '日向泊浦', 'ヒュウガドマリウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市塩内浦', '44', '44205', '8760003', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '塩内浦', 'シウチウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市荒網代浦', '44', '44205', '8760004', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '荒網代浦', 'アラジロウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市石間浦', '44', '44205', '8760005', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '石間浦', 'イシマウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市守後浦', '44', '44205', '8760006', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '守後浦', 'モリゴウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市久保浦', '44', '44205', '8760007', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '久保浦', 'クボウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市片神浦', '44', '44205', '8760008', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '片神浦', 'カタガミウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市坂の浦', '44', '44205', '8760011', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '坂の浦', 'サカノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市鶴望', '44', '44205', '8760012', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '鶴望', 'ツルミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市若宮町', '44', '44205', '8760013', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '若宮町', 'ワカミヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市白方', '44', '44205', '8760014', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '白方', 'シラカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市百谷', '44', '44205', '8760015', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '百谷', 'モモタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市王子丸', '44', '44205', '8760016', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '王子丸', 'オウジマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市野口', '44', '44205', '8760017', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '野口', 'ノグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市平', '44', '44205', '8760018', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '平', 'ヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市東灘', '44', '44205', '8760021', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '東灘', 'ヒガシナダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市上灘', '44', '44205', '8760022', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '上灘', 'カミナダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市蛇崎', '44', '44205', '8760023', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '蛇崎', 'ヘビザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市下久部', '44', '44205', '8760024', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '下久部', 'シモクベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市池田', '44', '44205', '8760025', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '池田', 'イケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市匠南', '44', '44205', '8760026', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '匠南', 'ショウナン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市上久部', '44', '44205', '8760027', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '上久部', 'カミクベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市川原', '44', '44205', '8760031', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '川原', 'カワバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市中山', '44', '44205', '8760032', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '中山', 'ナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市下城', '44', '44205', '8760033', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '下城', 'シモジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市上城', '44', '44205', '8760034', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '上城', 'カミジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市岸河内', '44', '44205', '8760035', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '岸河内', 'キシガワチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市大越', '44', '44205', '8760036', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '大越', 'オオコエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市長谷', '44', '44205', '8760037', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '長谷', 'ハセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市長瀬', '44', '44205', '8760041', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '長瀬', 'ナガセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市稲垣', '44', '44205', '8760042', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '稲垣', 'イナガキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市樫野', '44', '44205', '8760043', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '樫野', 'カシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市高畠', '44', '44205', '8760044', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '高畠', 'タカバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市上岡', '44', '44205', '8760045', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '上岡', 'カミオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市脇', '44', '44205', '8760046', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '脇', 'ワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市寺田', '44', '44205', '8760051', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '寺田', 'テラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市坂山', '44', '44205', '8760052', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '坂山', 'サカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市高畑', '44', '44205', '8760053', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '高畑', 'タカバタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市門前', '44', '44205', '8760061', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '門前', 'モンゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市古市', '44', '44205', '8760062', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '古市', 'フルイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市城西区', '44', '44205', '8760063', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '城西区', 'ジョウセイク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市八迫区', '44', '44205', '8760064', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '八迫区', 'ヤサコク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市弥生大坂本', '44', '44205', '8760101', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '弥生大坂本', 'ヤヨイオオサカモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市弥生尺間', '44', '44205', '8760102', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '弥生尺間', 'ヤヨイシャクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市弥生床木', '44', '44205', '8760103', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '弥生床木', 'ヤヨイユカギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市弥生井崎', '44', '44205', '8760111', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '弥生井崎', 'ヤヨイイサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市弥生上小倉', '44', '44205', '8760112', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '弥生上小倉', 'ヤヨイカミオグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市弥生山梨子', '44', '44205', '8760113', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '弥生山梨子', 'ヤヨイヤマナシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市弥生小田', '44', '44205', '8760121', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '弥生小田', 'ヤヨイコダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市弥生門田', '44', '44205', '8760122', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '弥生門田', 'ヤヨイカンタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市弥生平井', '44', '44205', '8760123', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '弥生平井', 'ヤヨイヒライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市弥生細田', '44', '44205', '8760124', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '弥生細田', 'ヤヨイサイタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市弥生江良', '44', '44205', '8760125', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '弥生江良', 'ヤヨイエラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市弥生提内', '44', '44205', '8760126', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '弥生提内', 'ヤヨイヒサギウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市本匠風戸', '44', '44205', '8760201', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '本匠風戸', 'ホンジョウカザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市本匠笠掛', '44', '44205', '8760202', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '本匠笠掛', 'ホンジョウカサカケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市本匠三股', '44', '44205', '8760203', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '本匠三股', 'ホンジョウミマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市本匠宇津々', '44', '44205', '8760204', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '本匠宇津々', 'ホンジョウウツツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市本匠波寄', '44', '44205', '8760205', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '本匠波寄', 'ホンジョウハキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市本匠小川', '44', '44205', '8760206', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '本匠小川', 'ホンジョウオガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市本匠井ノ上', '44', '44205', '8760211', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '本匠井ノ上', 'ホンジョウイノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市本匠因尾', '44', '44205', '8760212', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '本匠因尾', 'ホンジョウインビ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市本匠堂ノ間', '44', '44205', '8760213', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '本匠堂ノ間', 'ホンジョウドウノマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市本匠上津川', '44', '44205', '8760214', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '本匠上津川', 'ホンジョウコウヅガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市本匠小半', '44', '44205', '8760215', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '本匠小半', 'ホンジョウオナガラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市本匠山部', '44', '44205', '8760216', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '本匠山部', 'ホンジョウヤマブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市葛港', '44', '44205', '8760801', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '葛港', 'カヅラミナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市日の出町', '44', '44205', '8760802', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '日の出町', 'ヒノデマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市駅前', '44', '44205', '8760803', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '駅前', 'エキマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市蟹田', '44', '44205', '8760804', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '蟹田', 'ガンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市平野町', '44', '44205', '8760805', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '平野町', 'ヒラノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市春日町', '44', '44205', '8760806', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '春日町', 'カスガマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市田の浦町', '44', '44205', '8760807', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '田の浦町', 'タノウラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市鶴谷町', '44', '44205', '8760811', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '鶴谷町', 'ツルヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市中江町', '44', '44205', '8760812', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '中江町', 'ナカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市長島町', '44', '44205', '8760813', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '長島町', 'ナガシママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市東町', '44', '44205', '8760814', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '東町', 'ヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市野岡町', '44', '44205', '8760815', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '野岡町', 'ノオカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市東浜', '44', '44205', '8760821', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '東浜', 'ヒガシハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市西浜', '44', '44205', '8760822', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '西浜', 'ニシハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市女島', '44', '44205', '8760823', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '女島', 'メジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市新女島', '44', '44205', '8760824', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '新女島', 'シンメジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市女島団地', '44', '44205', '8760825', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '女島団地', 'メジマダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市大手町', '44', '44205', '8760831', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '大手町', 'オオテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市船頭町', '44', '44205', '8760832', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '船頭町', 'センドウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市池船町', '44', '44205', '8760833', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '池船町', 'イケフネマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市城南町', '44', '44205', '8760834', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '城南町', 'ジョウナンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市鶴岡町', '44', '44205', '8760835', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '鶴岡町', 'ツルオカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市西谷町', '44', '44205', '8760836', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '西谷町', 'ニシダニマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市来島町', '44', '44205', '8760841', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '来島町', 'クルシママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市中ノ島東町', '44', '44205', '8760842', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '中ノ島東町', 'ナカノシマヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市中の島', '44', '44205', '8760843', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '中の島', 'ナカノシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市向島', '44', '44205', '8760844', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '向島', 'ホウジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市内町', '44', '44205', '8760845', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '内町', 'ウチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市城東町', '44', '44205', '8760846', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '城東町', 'ジョウトウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市城下西町', '44', '44205', '8760847', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '城下西町', 'ジョウカニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市城下東町', '44', '44205', '8760848', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '城下東町', 'ジョウカヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市臼坪', '44', '44205', '8760849', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '臼坪', 'ウスツボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市常盤東町', '44', '44205', '8760851', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '常盤東町', 'トキワヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市常盤南町', '44', '44205', '8760852', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '常盤南町', 'トキワミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市中村東町', '44', '44205', '8760853', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '中村東町', 'ナカムラヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市中村南町', '44', '44205', '8760854', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '中村南町', 'ナカムラミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市中村西町', '44', '44205', '8760855', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '中村西町', 'ナカムラニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市中村北町', '44', '44205', '8760856', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '中村北町', 'ナカムラキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市常盤西町', '44', '44205', '8760857', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '常盤西町', 'トキワニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市狩生', '44', '44205', '8761101', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '狩生', 'カリウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市二栄', '44', '44205', '8761102', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '二栄', 'フタバエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市護江', '44', '44205', '8761103', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '護江', 'モリエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市霞ケ浦', '44', '44205', '8761104', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '霞ケ浦', 'カスミガウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市海崎', '44', '44205', '8761105', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '海崎', 'カイザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市戸穴', '44', '44205', '8761106', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '戸穴', 'ヒアナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市鶴見吹浦', '44', '44205', '8761201', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '鶴見吹浦', 'ツルミフキウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市鶴見地松浦', '44', '44205', '8761202', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '鶴見地松浦', 'ツルミジマツウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市鶴見沖松浦', '44', '44205', '8761203', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '鶴見沖松浦', 'ツルミオキマツウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市鶴見有明浦', '44', '44205', '8761204', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '鶴見有明浦', 'ツルミアリアケウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市鶴見羽出浦', '44', '44205', '8761205', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '鶴見羽出浦', 'ツルミハイデウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市鶴見中越浦', '44', '44205', '8761206', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '鶴見中越浦', 'ツルミナカゴシウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市米水津浦代浦間越', '44', '44205', '8761301', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '米水津浦代浦', 'ヨノウヅウラシロウラ', null, null, '間越', 'ハザコ');
INSERT INTO `ms_addresses` VALUES ('114237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市米水津浦代浦芳ケ浦', '44', '44205', '8761301', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '米水津浦代浦', 'ヨノウヅウラシロウラ', null, null, '芳ケ浦', 'ヨシガウラ');
INSERT INTO `ms_addresses` VALUES ('114238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市鶴見中越浦猿戸', '44', '44205', '8761306', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '鶴見中越浦', 'ツルミナカゴシウラ', null, null, '猿戸', 'サルト');
INSERT INTO `ms_addresses` VALUES ('114239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市鶴見中越浦広浦', '44', '44205', '8761306', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '鶴見中越浦', 'ツルミナカゴシウラ', null, null, '広浦', 'ヒロウラ');
INSERT INTO `ms_addresses` VALUES ('114240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市鶴見丹賀浦', '44', '44205', '8761311', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '鶴見丹賀浦', 'ツルミタンガウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市鶴見梶寄浦', '44', '44205', '8761312', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '鶴見梶寄浦', 'ツルミカジヨセウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市鶴見大島', '44', '44205', '8761313', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '鶴見大島', 'ツルミオオシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市米水津浦代浦', '44', '44205', '8761401', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '米水津浦代浦', 'ヨノウヅウラシロウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市米水津色利浦', '44', '44205', '8761402', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '米水津色利浦', 'ヨノウヅイロリウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市米水津宮野浦', '44', '44205', '8761403', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '米水津宮野浦', 'ヨノウヅミヤノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市米水津小浦', '44', '44205', '8761404', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '米水津小浦', 'ヨノウヅコウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市米水津竹野浦', '44', '44205', '8761405', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '米水津竹野浦', 'ヨノウヅタケノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市長良', '44', '44205', '8761511', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '長良', 'ナガラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市堅田', '44', '44205', '8761512', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '堅田', 'カタタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市青山', '44', '44205', '8761513', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '青山', 'アオヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市木立', '44', '44205', '8762121', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '木立', 'キタチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市蒲江畑野浦', '44', '44205', '8762201', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '蒲江畑野浦', 'カマエハタノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市蒲江尾浦', '44', '44205', '8762202', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '蒲江尾浦', 'カマエオウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市蒲江楠本浦', '44', '44205', '8762203', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '蒲江楠本浦', 'カマエクスモトウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市蒲江竹野浦河内', '44', '44205', '8762301', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '蒲江竹野浦河内', 'カマエタケノウラゴウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市蒲江西野浦', '44', '44205', '8762302', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '蒲江西野浦', 'カマエニシノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市蒲江蒲江浦', '44', '44205', '8762401', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '蒲江蒲江浦', 'カマエカマエウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市蒲江猪串浦', '44', '44205', '8762402', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '蒲江猪串浦', 'カマエイノクシウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市蒲江野々河内浦', '44', '44205', '8762403', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '蒲江野々河内浦', 'カマエノノカワチウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市蒲江森崎浦', '44', '44205', '8762404', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '蒲江森崎浦', 'カマエモリザキウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市蒲江丸市尾浦', '44', '44205', '8762405', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '蒲江丸市尾浦', 'カマエマルイチビウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市蒲江葛原浦', '44', '44205', '8762406', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '蒲江葛原浦', 'カマエカズラハラウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市蒲江波当津浦', '44', '44205', '8762407', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '蒲江波当津浦', 'カマエハトウヅウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市', '44', '44204', '8770000', '大分県', 'オオイタケン', '日田市', 'ヒタシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('114271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市秋山町', '44', '44204', '8770001', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '秋山町', 'アキヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市城内新町', '44', '44204', '8770002', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '城内新町', 'ジョウナイシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市上城内町', '44', '44204', '8770003', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '上城内町', 'カミジョウナイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市城町', '44', '44204', '8770004', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '城町', 'シロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市豆田町', '44', '44204', '8770005', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '豆田町', 'マメダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市港町', '44', '44204', '8770006', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '港町', 'ミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市丸の内町', '44', '44204', '8770007', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '丸の内町', 'マルノウチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市丸山', '44', '44204', '8770008', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '丸山', 'マルヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市中城町', '44', '44204', '8770011', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '中城町', 'ナカジョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市淡窓', '44', '44204', '8770012', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '淡窓', 'タンソウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市元町', '44', '44204', '8770013', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '元町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市本町', '44', '44204', '8770014', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市中央', '44', '44204', '8770015', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市三本松', '44', '44204', '8770016', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '三本松', 'サンボンマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市三本松新町', '44', '44204', '8770017', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '三本松新町', 'サンボンマツシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市求町', '44', '44204', '8770021', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '求町', 'モトメマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市神来町', '44', '44204', '8770022', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '神来町', 'カミクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市田島', '44', '44204', '8770023', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '田島', 'タシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市南元町', '44', '44204', '8770024', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '南元町', 'ミナミモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市田島', '44', '44204', '8770025', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '田島', 'タシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市田島本町', '44', '44204', '8770026', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '田島本町', 'タシマホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市古金町', '44', '44204', '8770031', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '古金町', 'コガネマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市小ケ瀬町', '44', '44204', '8770032', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '小ケ瀬町', 'オガセマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市大部町', '44', '44204', '8770033', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '大部町', 'オオベマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市桃山町', '44', '44204', '8770034', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '桃山町', 'モモヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市日高町', '44', '44204', '8770035', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '日高町', 'ヒダカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市三芳小渕町', '44', '44204', '8770036', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '三芳小渕町', 'ミヨシコブチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市若宮町', '44', '44204', '8770037', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '若宮町', 'ワカミヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市下井手町', '44', '44204', '8770038', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '下井手町', 'シモイデマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市刃連町', '44', '44204', '8770039', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '刃連町', 'ユキイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市竹田新町', '44', '44204', '8770041', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '竹田新町', 'タケダシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市東町', '44', '44204', '8770042', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '東町', 'ヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市川原町', '44', '44204', '8770043', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '川原町', 'カワハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市隈', '44', '44204', '8770044', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '隈', 'クマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市亀山町', '44', '44204', '8770045', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '亀山町', 'キザンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市本庄町', '44', '44204', '8770046', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '本庄町', 'ホンジョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市中本町', '44', '44204', '8770047', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '中本町', 'ナカホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市京町', '44', '44204', '8770051', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '京町', 'キョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市銭渕町', '44', '44204', '8770052', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '銭渕町', 'ゼニブチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市高瀬本町', '44', '44204', '8770053', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '高瀬本町', 'タカセホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市琴平町', '44', '44204', '8770054', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '琴平町', 'コトヒラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市大宮町', '44', '44204', '8770055', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '大宮町', 'オオミヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市誠和町', '44', '44204', '8770056', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '誠和町', 'セイワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市八幡町', '44', '44204', '8770057', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '八幡町', 'ヤハタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市南部町', '44', '44204', '8770058', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '南部町', 'ナンブマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市大日町', '44', '44204', '8770059', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '大日町', 'ダイニチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市石井', '44', '44204', '8770061', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '石井', 'イシイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市上野町', '44', '44204', '8770062', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '上野町', 'ウエノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市串川町', '44', '44204', '8770063', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '串川町', 'クシカワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市小山町', '44', '44204', '8770064', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '小山町', 'オヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市緑町', '44', '44204', '8770065', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '緑町', 'ミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市川下', '44', '44204', '8770066', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '川下', 'カワシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市高井町', '44', '44204', '8770067', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '高井町', 'タカイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市内河町', '44', '44204', '8770068', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '内河町', 'ウチカワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市玉川町', '44', '44204', '8770071', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '玉川町', 'タマガワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市新治町', '44', '44204', '8770072', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '新治町', 'ニイバルマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市日ノ隈町', '44', '44204', '8770073', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '日ノ隈町', 'ヒノクママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市中ノ島町', '44', '44204', '8770074', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '中ノ島町', 'ナカノシママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市中釣町', '44', '44204', '8770075', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '中釣町', 'ナカヅルマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市亀川町', '44', '44204', '8770076', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '亀川町', 'カメガワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市南友田町', '44', '44204', '8770077', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '南友田町', 'ミナミトモダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市北友田', '44', '44204', '8770078', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '北友田', 'キタトモダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市清岸寺町', '44', '44204', '8770081', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '清岸寺町', 'セイガンジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市日ノ出町', '44', '44204', '8770082', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '日ノ出町', 'ヒノデマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市吹上町', '44', '44204', '8770083', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '吹上町', 'フキアゲマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市朝日ケ丘', '44', '44204', '8770084', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '朝日ケ丘', 'アサヒガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市朝日町', '44', '44204', '8770085', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '朝日町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市二串町', '44', '44204', '8770086', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '二串町', 'ニクシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市君迫町', '44', '44204', '8770087', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '君迫町', 'キミザコマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市小迫町', '44', '44204', '8770088', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '小迫町', 'オザコマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市山田町', '44', '44204', '8770089', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '山田町', 'ヤマダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市天瀬町五馬市', '44', '44204', '8770111', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '天瀬町五馬市', 'アマガセマチイツマイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市天瀬町本城', '44', '44204', '8770112', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '天瀬町本城', 'アマガセマチホンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市天瀬町塚田', '44', '44204', '8770113', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '天瀬町塚田', 'アマガセマチツカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市天瀬町出口', '44', '44204', '8770114', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '天瀬町出口', 'アマガセマチイデグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市大山町西大山', '44', '44204', '8770201', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '大山町西大山', 'オオヤママチニシオオヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市大山町東大山', '44', '44204', '8770202', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '大山町東大山', 'オオヤママチヒガシオオヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市前津江町赤石', '44', '44204', '8770211', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '前津江町赤石', 'マエツエマチアカイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市前津江町大野', '44', '44204', '8770212', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '前津江町大野', 'マエツエマチオオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市前津江町柚木', '44', '44204', '8770221', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '前津江町柚木', 'マエツエマチユウギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市中津江村栃野', '44', '44204', '8770301', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '中津江村栃野', 'ナカツエムラトチノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市中津江村合瀬', '44', '44204', '8770302', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '中津江村合瀬', 'ナカツエムラゴウセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市上津江町川原', '44', '44204', '8770311', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '上津江町川原', 'カミツエマチカワバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市上津江町上野田', '44', '44204', '8770312', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '上津江町上野田', 'カミツエマチカミノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市鶴城町', '44', '44204', '8771101', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '鶴城町', 'ツルギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市上宮町', '44', '44204', '8771102', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '上宮町', 'ジョウグウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市鶴河内町', '44', '44204', '8771103', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '鶴河内町', 'ツルガワチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市大鶴本町', '44', '44204', '8771104', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '大鶴本町', 'オオツルホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市大肥町', '44', '44204', '8771105', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '大肥町', 'オオヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市大肥本町', '44', '44204', '8771106', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '大肥本町', 'オオヒホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市大鶴町', '44', '44204', '8771107', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '大鶴町', 'オオツルマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市夜明上町', '44', '44204', '8771111', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '夜明上町', 'ヨアケカミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市夜明中町', '44', '44204', '8771112', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '夜明中町', 'ヨアケナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市夜明関町', '44', '44204', '8771113', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '夜明関町', 'ヨアケセキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市源栄町池ノ鶴', '44', '44204', '8771121', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '源栄町', 'モトエマチ', null, null, '池ノ鶴', 'イケノツル');
INSERT INTO `ms_addresses` VALUES ('114369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市源栄町皿山', '44', '44204', '8771121', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '源栄町', 'モトエマチ', null, null, '皿山', 'サラヤマ');
INSERT INTO `ms_addresses` VALUES ('114370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市伏木町', '44', '44204', '8771221', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '伏木町', 'フシキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市小河内町', '44', '44204', '8771222', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '小河内町', 'オガワチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市市ノ瀬町', '44', '44204', '8771223', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '市ノ瀬町', 'イチノセマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市秋原町', '44', '44204', '8771224', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '秋原町', 'アキバルマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市藤山町', '44', '44204', '8771225', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '藤山町', 'フジヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市財津町', '44', '44204', '8771231', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '財津町', 'ザイツマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市清水町', '44', '44204', '8771232', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '清水町', 'シミズマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市三和団地', '44', '44204', '8771233', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '三和団地', 'ミワダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市天神町', '44', '44204', '8771234', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '天神町', 'テンジンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市源栄町', '44', '44204', '8771241', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '源栄町', 'モトエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市殿町', '44', '44204', '8771242', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '殿町', 'トノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市鈴連町', '44', '44204', '8771243', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '鈴連町', 'スズレマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市三河町', '44', '44204', '8771244', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '三河町', 'ミカワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市三ノ宮町', '44', '44204', '8771351', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '三ノ宮町', 'サンノミヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市石松町', '44', '44204', '8771352', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '石松町', 'イシマツマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市上手町', '44', '44204', '8771353', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '上手町', 'ノボテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市坂井町', '44', '44204', '8771354', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '坂井町', 'サカイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市有田町', '44', '44204', '8771361', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '有田町', 'アリタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市尾当町', '44', '44204', '8771362', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '尾当町', 'オトウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市中尾町', '44', '44204', '8771363', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '中尾町', 'ナカオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市三池町', '44', '44204', '8771364', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '三池町', 'ミイケマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市水目町', '44', '44204', '8771365', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '水目町', 'ミズメマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市諸留町', '44', '44204', '8771371', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '諸留町', 'モロドメマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市上諸留町', '44', '44204', '8771372', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '上諸留町', 'カミモロドメマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市月出町', '44', '44204', '8771373', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '月出町', 'ツキデマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市松野町', '44', '44204', '8771374', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '松野町', 'マツノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市池辺町', '44', '44204', '8771375', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '池辺町', 'イケベマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市東羽田町', '44', '44204', '8771381', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '東羽田町', 'ヒガシハタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市日の本町', '44', '44204', '8771382', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '日の本町', 'ヒノモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市岩美町', '44', '44204', '8771383', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '岩美町', 'イワミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市羽田町', '44', '44204', '8771384', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '羽田町', 'ハタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県竹田市', '44', '44208', '8780000', '大分県', 'オオイタケン', '竹田市', 'タケタシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('114408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県竹田市植木', '44', '44208', '8780001', '大分県', 'オオイタケン', '竹田市', 'タケタシ', '植木', 'ウエキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県竹田市枝', '44', '44208', '8780002', '大分県', 'オオイタケン', '竹田市', 'タケタシ', '枝', 'エダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県竹田市片ケ瀬', '44', '44208', '8780003', '大分県', 'オオイタケン', '竹田市', 'タケタシ', '片ケ瀬', 'カタカセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県竹田市中', '44', '44208', '8780004', '大分県', 'オオイタケン', '竹田市', 'タケタシ', '中', 'ナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県竹田市挾田', '44', '44208', '8780005', '大分県', 'オオイタケン', '竹田市', 'タケタシ', '挾田', 'ハサダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県竹田市平田', '44', '44208', '8780006', '大分県', 'オオイタケン', '竹田市', 'タケタシ', '平田', 'ヒラタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県竹田市三宅', '44', '44208', '8780007', '大分県', 'オオイタケン', '竹田市', 'タケタシ', '三宅', 'ミヤケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県竹田市会々', '44', '44208', '8780011', '大分県', 'オオイタケン', '竹田市', 'タケタシ', '会々', 'アイアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県竹田市竹田町', '44', '44208', '8780012', '大分県', 'オオイタケン', '竹田市', 'タケタシ', '竹田町', 'タケタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県竹田市竹田', '44', '44208', '8780013', '大分県', 'オオイタケン', '竹田市', 'タケタシ', '竹田', 'タケタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県竹田市穴井迫', '44', '44208', '8780021', '大分県', 'オオイタケン', '竹田市', 'タケタシ', '穴井迫', 'アナイザコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県竹田市岩瀬', '44', '44208', '8780022', '大分県', 'オオイタケン', '竹田市', 'タケタシ', '岩瀬', 'イワセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県竹田市君ケ園', '44', '44208', '8780023', '大分県', 'オオイタケン', '竹田市', 'タケタシ', '君ケ園', 'キミガソノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県竹田市玉来', '44', '44208', '8780024', '大分県', 'オオイタケン', '竹田市', 'タケタシ', '玉来', 'タマライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県竹田市拝田原', '44', '44208', '8780025', '大分県', 'オオイタケン', '竹田市', 'タケタシ', '拝田原', 'ハイタバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県竹田市飛田川', '44', '44208', '8780026', '大分県', 'オオイタケン', '竹田市', 'タケタシ', '飛田川', 'ヒダガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県竹田市向山田', '44', '44208', '8780027', '大分県', 'オオイタケン', '竹田市', 'タケタシ', '向山田', 'ムコウヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県竹田市渡瀬', '44', '44208', '8780028', '大分県', 'オオイタケン', '竹田市', 'タケタシ', '渡瀬', 'ワタセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県竹田市岩本', '44', '44208', '8780031', '大分県', 'オオイタケン', '竹田市', 'タケタシ', '岩本', 'イワモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県竹田市太田', '44', '44208', '8780032', '大分県', 'オオイタケン', '竹田市', 'タケタシ', '太田', 'オオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県竹田市入田', '44', '44208', '8780033', '大分県', 'オオイタケン', '竹田市', 'タケタシ', '入田', 'ニュウタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県竹田市門田', '44', '44208', '8780034', '大分県', 'オオイタケン', '竹田市', 'タケタシ', '門田', 'モンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県竹田市吉田', '44', '44208', '8780035', '大分県', 'オオイタケン', '竹田市', 'タケタシ', '吉田', 'ヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県竹田市小川', '44', '44208', '8780141', '大分県', 'オオイタケン', '竹田市', 'タケタシ', '小川', 'オガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県竹田市福原', '44', '44208', '8780142', '大分県', 'オオイタケン', '竹田市', 'タケタシ', '福原', 'フクハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県竹田市城原', '44', '44208', '8780143', '大分県', 'オオイタケン', '竹田市', 'タケタシ', '城原', 'キバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県竹田市高伏', '44', '44208', '8780144', '大分県', 'オオイタケン', '竹田市', 'タケタシ', '高伏', 'タカブシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県竹田市米納', '44', '44208', '8780145', '大分県', 'オオイタケン', '竹田市', 'タケタシ', '米納', 'ヨナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県竹田市古園', '44', '44208', '8780146', '大分県', 'オオイタケン', '竹田市', 'タケタシ', '古園', 'フルゾノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県竹田市下坂田', '44', '44208', '8780151', '大分県', 'オオイタケン', '竹田市', 'タケタシ', '下坂田', 'シモサカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県竹田市下志土知', '44', '44208', '8780152', '大分県', 'オオイタケン', '竹田市', 'タケタシ', '下志土知', 'シモシトチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県竹田市市用', '44', '44208', '8780153', '大分県', 'オオイタケン', '竹田市', 'タケタシ', '市用', 'イチモチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県竹田市川床', '44', '44208', '8780154', '大分県', 'オオイタケン', '竹田市', 'タケタシ', '川床', 'カワドコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県竹田市志土知', '44', '44208', '8780155', '大分県', 'オオイタケン', '竹田市', 'タケタシ', '志土知', 'シトチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県竹田市久保', '44', '44208', '8780156', '大分県', 'オオイタケン', '竹田市', 'タケタシ', '久保', 'クボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県竹田市上坂田', '44', '44208', '8780161', '大分県', 'オオイタケン', '竹田市', 'タケタシ', '上坂田', 'カミサカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県竹田市炭竈', '44', '44208', '8780162', '大分県', 'オオイタケン', '竹田市', 'タケタシ', '炭竈', 'スミカマド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県竹田市上畑', '44', '44208', '8780163', '大分県', 'オオイタケン', '竹田市', 'タケタシ', '上畑', 'カミハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県竹田市刈小野', '44', '44208', '8780164', '大分県', 'オオイタケン', '竹田市', 'タケタシ', '刈小野', 'カリオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県竹田市久住町久住', '44', '44208', '8780201', '大分県', 'オオイタケン', '竹田市', 'タケタシ', '久住町久住', 'クジュウマチクジュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県竹田市久住町有氏', '44', '44208', '8780202', '大分県', 'オオイタケン', '竹田市', 'タケタシ', '久住町有氏', 'クジュウマチアリウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県竹田市久住町仏原', '44', '44208', '8780203', '大分県', 'オオイタケン', '竹田市', 'タケタシ', '久住町仏原', 'クジュウマチブツバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県竹田市久住町栢木', '44', '44208', '8780204', '大分県', 'オオイタケン', '竹田市', 'タケタシ', '久住町栢木', 'クジュウマチカヤギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県竹田市久住町白丹', '44', '44208', '8780205', '大分県', 'オオイタケン', '竹田市', 'タケタシ', '久住町白丹', 'クジュウマチシラニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県竹田市久住町添ケ津留', '44', '44208', '8780206', '大分県', 'オオイタケン', '竹田市', 'タケタシ', '久住町添ケ津留', 'クジュウマチソエガツル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県竹田市久保', '44', '44208', '8780256', '大分県', 'オオイタケン', '竹田市', 'タケタシ', '久保', 'クボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県竹田市直入町神堤', '44', '44208', '8780401', '大分県', 'オオイタケン', '竹田市', 'タケタシ', '直入町神堤', 'ナオイリマチカミツツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県竹田市直入町長湯', '44', '44208', '8780402', '大分県', 'オオイタケン', '竹田市', 'タケタシ', '直入町長湯', 'ナオイリマチナガユ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県竹田市直入町上田北', '44', '44208', '8780403', '大分県', 'オオイタケン', '竹田市', 'タケタシ', '直入町上田北', 'ナオイリマチカミタギタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県竹田市直入町下田北', '44', '44208', '8780404', '大分県', 'オオイタケン', '竹田市', 'タケタシ', '直入町下田北', 'ナオイリマチシモタギタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県竹田市次倉', '44', '44208', '8780571', '大分県', 'オオイタケン', '竹田市', 'タケタシ', '次倉', 'ツギクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県竹田市九重野', '44', '44208', '8780572', '大分県', 'オオイタケン', '竹田市', 'タケタシ', '九重野', 'クジュウノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県竹田市中角', '44', '44208', '8780573', '大分県', 'オオイタケン', '竹田市', 'タケタシ', '中角', 'ナカツノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県竹田市神原', '44', '44208', '8780574', '大分県', 'オオイタケン', '竹田市', 'タケタシ', '神原', 'コウバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県竹田市田井', '44', '44208', '8780575', '大分県', 'オオイタケン', '竹田市', 'タケタシ', '田井', 'タイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県竹田市倉木', '44', '44208', '8780576', '大分県', 'オオイタケン', '竹田市', 'タケタシ', '倉木', 'クラキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市今津', '44', '44203', '8790101', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '今津', 'イマヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市鍋島', '44', '44203', '8790102', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '鍋島', 'ナベシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市植野', '44', '44203', '8790103', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '植野', 'ウエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市野依', '44', '44203', '8790104', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '野依', 'ノヨリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市犬丸', '44', '44203', '8790105', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '犬丸', 'イヌマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市赤迫', '44', '44203', '8790106', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '赤迫', 'アカサコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市昭和新田', '44', '44203', '8790107', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '昭和新田', 'ショウワシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市伊藤田', '44', '44203', '8790111', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '伊藤田', 'イドウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市福島', '44', '44203', '8790112', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '福島', 'フクシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市北原', '44', '44203', '8790113', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '北原', 'キタバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市諸田', '44', '44203', '8790121', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '諸田', 'モロタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市定留', '44', '44203', '8790122', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '定留', 'サダノミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市田尻', '44', '44203', '8790123', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '田尻', 'タジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市田尻崎', '44', '44203', '8790124', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '田尻崎', 'タジリザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市宮熊', '44', '44211', '8790151', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '宮熊', 'ミヤグマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市下庄', '44', '44211', '8790152', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '下庄', 'シモショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市上庄', '44', '44211', '8790153', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '上庄', 'カミショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市下敷田', '44', '44211', '8790161', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '下敷田', 'シモシキダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市中敷田', '44', '44211', '8790162', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '中敷田', 'ナカシキダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市上敷田', '44', '44211', '8790163', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '上敷田', 'カミシキダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市富山', '44', '44211', '8790164', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '富山', 'トミヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市三光上秣', '44', '44203', '8790221', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '三光上秣', 'サンコウカミマクサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市三光西秣', '44', '44203', '8790222', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '三光西秣', 'サンコウニシマクサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市三光下秣', '44', '44203', '8790223', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '三光下秣', 'サンコウシモマクサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市三光下深水', '44', '44203', '8790224', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '三光下深水', 'サンコウシモフコウズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県中津市三光上深水', '44', '44203', '8790225', '大分県', 'オオイタケン', '中津市', 'ナカツシ', '三光上深水', 'サンコウカミフコウズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市南敷田', '44', '44211', '8790231', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '南敷田', 'ミナミシキダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市大根川', '44', '44211', '8790232', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '大根川', 'オオネガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市赤尾', '44', '44211', '8790233', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '赤尾', 'アカオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市今仁', '44', '44211', '8790234', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '今仁', 'イマニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市木部', '44', '44211', '8790235', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '木部', 'キベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市清水', '44', '44211', '8790236', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '清水', 'シミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市佐野', '44', '44211', '8790237', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '佐野', 'サノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市乙女新田', '44', '44211', '8790301', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '乙女新田', 'オトメシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市下乙女', '44', '44211', '8790302', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '下乙女', 'シモオトメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市上乙女', '44', '44211', '8790303', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '上乙女', 'カミオトメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市尾永井', '44', '44211', '8790304', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '尾永井', 'オナガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市上高家', '44', '44211', '8790305', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '上高家', 'カミタケイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市西高家', '44', '44211', '8790306', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '西高家', 'ニシタケイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市浜高家', '44', '44211', '8790307', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '浜高家', 'ハマタケイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市下高家', '44', '44211', '8790308', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '下高家', 'シモタケイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市東高家', '44', '44211', '8790309', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '東高家', 'ヒガシタケイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市森山', '44', '44211', '8790311', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '森山', 'モリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市荒木', '44', '44211', '8790312', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '荒木', 'アラキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市上高', '44', '44211', '8790313', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '上高', 'カミタカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市猿渡', '44', '44211', '8790314', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '猿渡', 'サルワタリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市上時枝', '44', '44211', '8790315', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '上時枝', 'カミトキエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市下時枝', '44', '44211', '8790316', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '下時枝', 'シモトキエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市下高', '44', '44211', '8790317', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '下高', 'シモタカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市吉松', '44', '44211', '8790441', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '吉松', 'ヨシマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市城井', '44', '44211', '8790442', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '城井', 'ジョウイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市葛原', '44', '44211', '8790443', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '葛原', 'クズハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市石田', '44', '44211', '8790444', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '石田', 'イシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市畑田', '44', '44211', '8790451', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '畑田', 'ハタケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市川部', '44', '44211', '8790452', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '川部', 'カワベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市上田', '44', '44211', '8790453', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '上田', 'ウエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市法鏡寺', '44', '44211', '8790454', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '法鏡寺', 'ホウキョウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市閤', '44', '44211', '8790455', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '閤', 'ゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市辛島', '44', '44211', '8790456', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '辛島', 'カラシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市芝原', '44', '44211', '8790457', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '芝原', 'シバハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市樋田', '44', '44211', '8790461', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '樋田', 'ヒダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市別府', '44', '44211', '8790462', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '別府', 'ビュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市中原', '44', '44211', '8790463', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '中原', 'ナカハル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市大塚', '44', '44211', '8790464', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '大塚', 'オオツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市下拝田', '44', '44211', '8790465', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '下拝田', 'シモハイタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市上拝田', '44', '44211', '8790466', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '上拝田', 'カミハイタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市山本', '44', '44211', '8790467', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '山本', 'ヤマモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市四日市', '44', '44211', '8790471', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '四日市', 'ヨッカイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市上元重', '44', '44211', '8790472', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '上元重', 'カミモトシゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市下元重', '44', '44211', '8790473', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '下元重', 'シモモトシゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市山下', '44', '44211', '8790474', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '山下', 'ヤマシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市麻生', '44', '44211', '8790501', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '麻生', 'アソウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市岳ノ首', '44', '44211', '8790502', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '岳ノ首', 'タケノクビ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市灘', '44', '44211', '8790503', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '灘', 'ナダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市山口', '44', '44211', '8790504', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '山口', 'ヤマグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市山袋', '44', '44211', '8790511', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '山袋', 'ヤマブクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市黒', '44', '44211', '8790512', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '黒', 'クロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市中', '44', '44211', '8790513', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '中', 'ナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市今成', '44', '44211', '8790514', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '今成', 'イマナリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市末', '44', '44211', '8790515', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '末', 'スエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市木内', '44', '44211', '8790516', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '木内', 'キノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後高田市', '44', '44209', '8790600', '大分県', 'オオイタケン', '豊後高田市', 'ブンゴタカダシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('114556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後高田市草地', '44', '44209', '8790601', '大分県', 'オオイタケン', '豊後高田市', 'ブンゴタカダシ', '草地', 'クサジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後高田市払田', '44', '44209', '8790602', '大分県', 'オオイタケン', '豊後高田市', 'ブンゴタカダシ', '払田', 'ハライダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後高田市鼎', '44', '44209', '8790603', '大分県', 'オオイタケン', '豊後高田市', 'ブンゴタカダシ', '鼎', 'カナエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後高田市美和', '44', '44209', '8790604', '大分県', 'オオイタケン', '豊後高田市', 'ブンゴタカダシ', '美和', 'ミワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後高田市御玉', '44', '44209', '8790605', '大分県', 'オオイタケン', '豊後高田市', 'ブンゴタカダシ', '御玉', 'オダマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後高田市玉津', '44', '44209', '8790606', '大分県', 'オオイタケン', '豊後高田市', 'ブンゴタカダシ', '玉津', 'タマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後高田市新栄', '44', '44209', '8790607', '大分県', 'オオイタケン', '豊後高田市', 'ブンゴタカダシ', '新栄', 'シンエイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後高田市呉崎', '44', '44209', '8790608', '大分県', 'オオイタケン', '豊後高田市', 'ブンゴタカダシ', '呉崎', 'クレサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後高田市森', '44', '44209', '8790611', '大分県', 'オオイタケン', '豊後高田市', 'ブンゴタカダシ', '森', 'モリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後高田市佐野', '44', '44209', '8790612', '大分県', 'オオイタケン', '豊後高田市', 'ブンゴタカダシ', '佐野', 'サノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後高田市小田原', '44', '44209', '8790613', '大分県', 'オオイタケン', '豊後高田市', 'ブンゴタカダシ', '小田原', 'コダワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後高田市来縄', '44', '44209', '8790614', '大分県', 'オオイタケン', '豊後高田市', 'ブンゴタカダシ', '来縄', 'クナワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後高田市界', '44', '44209', '8790615', '大分県', 'オオイタケン', '豊後高田市', 'ブンゴタカダシ', '界', 'サカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後高田市水崎', '44', '44209', '8790616', '大分県', 'オオイタケン', '豊後高田市', 'ブンゴタカダシ', '水崎', 'ミズサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後高田市高田', '44', '44209', '8790617', '大分県', 'オオイタケン', '豊後高田市', 'ブンゴタカダシ', '高田', 'タカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後高田市中央通', '44', '44209', '8790618', '大分県', 'オオイタケン', '豊後高田市', 'ブンゴタカダシ', '中央通', 'チュウオウドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後高田市浜町', '44', '44209', '8790619', '大分県', 'オオイタケン', '豊後高田市', 'ブンゴタカダシ', '浜町', 'ハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後高田市是永町', '44', '44209', '8790621', '大分県', 'オオイタケン', '豊後高田市', 'ブンゴタカダシ', '是永町', 'コレナガマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後高田市鍛冶屋町', '44', '44209', '8790622', '大分県', 'オオイタケン', '豊後高田市', 'ブンゴタカダシ', '鍛冶屋町', 'カジヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後高田市金谷町', '44', '44209', '8790623', '大分県', 'オオイタケン', '豊後高田市', 'ブンゴタカダシ', '金谷町', 'カナヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後高田市本町', '44', '44209', '8790624', '大分県', 'オオイタケン', '豊後高田市', 'ブンゴタカダシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後高田市水取', '44', '44209', '8790625', '大分県', 'オオイタケン', '豊後高田市', 'ブンゴタカダシ', '水取', 'ミズトリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後高田市今町', '44', '44209', '8790626', '大分県', 'オオイタケン', '豊後高田市', 'ブンゴタカダシ', '今町', 'イママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後高田市新地', '44', '44209', '8790627', '大分県', 'オオイタケン', '豊後高田市', 'ブンゴタカダシ', '新地', 'シンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後高田市新町', '44', '44209', '8790628', '大分県', 'オオイタケン', '豊後高田市', 'ブンゴタカダシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後高田市加礼川', '44', '44209', '8790721', '大分県', 'オオイタケン', '豊後高田市', 'ブンゴタカダシ', '加礼川', 'カレガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後高田市一畑', '44', '44209', '8790722', '大分県', 'オオイタケン', '豊後高田市', 'ブンゴタカダシ', '一畑', 'イチハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後高田市梅ノ木', '44', '44209', '8790723', '大分県', 'オオイタケン', '豊後高田市', 'ブンゴタカダシ', '梅ノ木', 'ウメノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後高田市新城', '44', '44209', '8790724', '大分県', 'オオイタケン', '豊後高田市', 'ブンゴタカダシ', '新城', 'シンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後高田市長岩屋', '44', '44209', '8790731', '大分県', 'オオイタケン', '豊後高田市', 'ブンゴタカダシ', '長岩屋', 'ナガイワヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後高田市大力', '44', '44209', '8790732', '大分県', 'オオイタケン', '豊後高田市', 'ブンゴタカダシ', '大力', 'ダイリキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後高田市荒尾', '44', '44209', '8790733', '大分県', 'オオイタケン', '豊後高田市', 'ブンゴタカダシ', '荒尾', 'アラオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後高田市築地', '44', '44209', '8790734', '大分県', 'オオイタケン', '豊後高田市', 'ブンゴタカダシ', '築地', 'ツイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後高田市松行', '44', '44209', '8790735', '大分県', 'オオイタケン', '豊後高田市', 'ブンゴタカダシ', '松行', 'マツユキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後高田市田染蕗', '44', '44209', '8790841', '大分県', 'オオイタケン', '豊後高田市', 'ブンゴタカダシ', '田染蕗', 'タシブフキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後高田市田染池部', '44', '44209', '8790842', '大分県', 'オオイタケン', '豊後高田市', 'ブンゴタカダシ', '田染池部', 'タシブイケベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後高田市田染相原', '44', '44209', '8790843', '大分県', 'オオイタケン', '豊後高田市', 'ブンゴタカダシ', '田染相原', 'タシブアイワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後高田市田染上野', '44', '44209', '8790844', '大分県', 'オオイタケン', '豊後高田市', 'ブンゴタカダシ', '田染上野', 'タシブウエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後高田市田染横嶺', '44', '44209', '8790851', '大分県', 'オオイタケン', '豊後高田市', 'ブンゴタカダシ', '田染横嶺', 'タシブヨコミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後高田市田染真中', '44', '44209', '8790852', '大分県', 'オオイタケン', '豊後高田市', 'ブンゴタカダシ', '田染真中', 'タシブマナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後高田市田染平野', '44', '44209', '8790853', '大分県', 'オオイタケン', '豊後高田市', 'ブンゴタカダシ', '田染平野', 'タシブヒラノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後高田市田染小崎', '44', '44209', '8790854', '大分県', 'オオイタケン', '豊後高田市', 'ブンゴタカダシ', '田染小崎', 'タシブオサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後高田市田染真木', '44', '44209', '8790855', '大分県', 'オオイタケン', '豊後高田市', 'ブンゴタカダシ', '田染真木', 'タシブマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県杵築市大田石丸', '44', '44210', '8790901', '大分県', 'オオイタケン', '杵築市', 'キツキシ', '大田石丸', 'オオタイシマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県杵築市大田沓掛', '44', '44210', '8790902', '大分県', 'オオイタケン', '杵築市', 'キツキシ', '大田沓掛', 'オオタクツカケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県杵築市大田永松', '44', '44210', '8790903', '大分県', 'オオイタケン', '杵築市', 'キツキシ', '大田永松', 'オオタナガマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県杵築市大田小野', '44', '44210', '8790904', '大分県', 'オオイタケン', '杵築市', 'キツキシ', '大田小野', 'オオタオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県杵築市大田波多方', '44', '44210', '8790911', '大分県', 'オオイタケン', '杵築市', 'キツキシ', '大田波多方', 'オオタハダカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県杵築市大田白木原', '44', '44210', '8790912', '大分県', 'オオイタケン', '杵築市', 'キツキシ', '大田白木原', 'オオタシラキハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県杵築市大田俣水', '44', '44210', '8790941', '大分県', 'オオイタケン', '杵築市', 'キツキシ', '大田俣水', 'オオタマタミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市東大堀', '44', '44211', '8791121', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '東大堀', 'ヒガシオオボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市横田', '44', '44211', '8791122', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '横田', 'ヨコタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市立石', '44', '44211', '8791123', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '立石', 'タテイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市山', '44', '44211', '8791124', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '山', 'ヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市両戒', '44', '44211', '8791125', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '両戒', 'リョウカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市江熊', '44', '44211', '8791126', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '江熊', 'エグマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市西屋敷', '44', '44211', '8791127', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '西屋敷', 'ニシヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市金丸', '44', '44211', '8791128', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '金丸', 'カナマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市出光', '44', '44211', '8791131', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '出光', 'イデミツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市岩崎', '44', '44211', '8791132', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '岩崎', 'イワサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市日足', '44', '44211', '8791133', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '日足', 'ヒアシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市橋津', '44', '44211', '8791134', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '橋津', 'ハシヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市和気', '44', '44211', '8791135', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '和気', 'ワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市西木', '44', '44211', '8791136', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '西木', 'サイギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市苅宇田', '44', '44211', '8791137', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '苅宇田', 'カリウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県宇佐市青森', '44', '44211', '8791138', '大分県', 'オオイタケン', '宇佐市', 'ウサシ', '青森', 'アオモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県杵築市山香町向野', '44', '44210', '8791301', '大分県', 'オオイタケン', '杵築市', 'キツキシ', '山香町向野', 'ヤマガマチムクノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県杵築市山香町立石', '44', '44210', '8791302', '大分県', 'オオイタケン', '杵築市', 'キツキシ', '山香町立石', 'ヤマガマチタテイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県杵築市山香町下', '44', '44210', '8791303', '大分県', 'オオイタケン', '杵築市', 'キツキシ', '山香町下', 'ヤマガマチシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県杵築市山香町小武', '44', '44210', '8791304', '大分県', 'オオイタケン', '杵築市', 'キツキシ', '山香町小武', 'ヤマガマチオダケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県杵築市山香町倉成', '44', '44210', '8791305', '大分県', 'オオイタケン', '杵築市', 'キツキシ', '山香町倉成', 'ヤマガマチクラナリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県杵築市山香町広瀬', '44', '44210', '8791306', '大分県', 'オオイタケン', '杵築市', 'キツキシ', '山香町広瀬', 'ヤマガマチヒロセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県杵築市山香町野原', '44', '44210', '8791307', '大分県', 'オオイタケン', '杵築市', 'キツキシ', '山香町野原', 'ヤマガマチノハル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県杵築市山香町内河野', '44', '44210', '8791311', '大分県', 'オオイタケン', '杵築市', 'キツキシ', '山香町内河野', 'ヤマガマチウチガワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県杵築市山香町日指', '44', '44210', '8791312', '大分県', 'オオイタケン', '杵築市', 'キツキシ', '山香町日指', 'ヤマガマチヒサシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県杵築市山香町久木野尾', '44', '44210', '8791313', '大分県', 'オオイタケン', '杵築市', 'キツキシ', '山香町久木野尾', 'ヤマガマチクギノオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県杵築市山香町南畑', '44', '44210', '8791314', '大分県', 'オオイタケン', '杵築市', 'キツキシ', '山香町南畑', 'ヤマガマチミナミハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県杵築市山香町山浦', '44', '44210', '8791315', '大分県', 'オオイタケン', '杵築市', 'キツキシ', '山香町山浦', 'ヤマガマチヤマウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県杵築市山香町吉野渡', '44', '44210', '8791316', '大分県', 'オオイタケン', '杵築市', 'キツキシ', '山香町吉野渡', 'ヤマガマチヨシノワタリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県速見郡日出町', '44', '44341', '8791500', '大分県', 'オオイタケン', '速見郡日出町', 'ハヤミグンヒジマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('114637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県速見郡日出町広瀬', '44', '44341', '8791501', '大分県', 'オオイタケン', '速見郡日出町', 'ハヤミグンヒジマチ', '広瀬', 'ヒロセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県速見郡日出町藤原', '44', '44341', '8791502', '大分県', 'オオイタケン', '速見郡日出町', 'ハヤミグンヒジマチ', '藤原', 'フジワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県速見郡日出町真那井', '44', '44341', '8791503', '大分県', 'オオイタケン', '速見郡日出町', 'ハヤミグンヒジマチ', '真那井', 'マナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県速見郡日出町大神', '44', '44341', '8791504', '大分県', 'オオイタケン', '速見郡日出町', 'ハヤミグンヒジマチ', '大神', 'オオガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県速見郡日出町川崎', '44', '44341', '8791505', '大分県', 'オオイタケン', '速見郡日出町', 'ハヤミグンヒジマチ', '川崎', 'カワサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県速見郡日出町', '44', '44341', '8791506', '大分県', 'オオイタケン', '速見郡日出町', 'ハヤミグンヒジマチ', null, '　', '（直番地）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('114643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県速見郡日出町豊岡', '44', '44341', '8791507', '大分県', 'オオイタケン', '速見郡日出町', 'ハヤミグンヒジマチ', '豊岡', 'トヨオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県速見郡日出町平道', '44', '44341', '8791508', '大分県', 'オオイタケン', '速見郡日出町', 'ハヤミグンヒジマチ', '平道', 'ヒラミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県速見郡日出町南畑', '44', '44341', '8791509', '大分県', 'オオイタケン', '速見郡日出町', 'ハヤミグンヒジマチ', '南畑', 'ミナミハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市本神崎', '44', '44201', '8792111', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '本神崎', 'ホンコウザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市馬場', '44', '44201', '8792112', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '馬場', 'ババ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市木佐上', '44', '44201', '8792113', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '木佐上', 'キサガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市大平', '44', '44201', '8792114', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '大平', 'オオヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市志生木', '44', '44201', '8792115', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '志生木', 'シュウキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市佐賀関', '44', '44201', '8792201', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '佐賀関', 'サガノセキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市白木', '44', '44201', '8792202', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '白木', 'シラキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市一尺屋', '44', '44201', '8792203', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '一尺屋', 'イッシャクヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県津久見市', '44', '44207', '8792400', '大分県', 'オオイタケン', '津久見市', 'ツクミシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('114658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県津久見市千怒', '44', '44207', '8792401', '大分県', 'オオイタケン', '津久見市', 'ツクミシ', '千怒', 'チヌ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県津久見市岩屋町', '44', '44207', '8792411', '大分県', 'オオイタケン', '津久見市', 'ツクミシ', '岩屋町', 'イワヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県津久見市高洲町', '44', '44207', '8792412', '大分県', 'オオイタケン', '津久見市', 'ツクミシ', '高洲町', 'タカスマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県津久見市津久見浦', '44', '44207', '8792413', '大分県', 'オオイタケン', '津久見市', 'ツクミシ', '津久見浦', 'ツクミウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県津久見市津久見', '44', '44207', '8792421', '大分県', 'オオイタケン', '津久見市', 'ツクミシ', '津久見', 'ツクミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県津久見市八戸', '44', '44207', '8792422', '大分県', 'オオイタケン', '津久見市', 'ツクミシ', '八戸', 'ヤト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県津久見市大友町', '44', '44207', '8792431', '大分県', 'オオイタケン', '津久見市', 'ツクミシ', '大友町', 'オオトモマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県津久見市文京町', '44', '44207', '8792432', '大分県', 'オオイタケン', '津久見市', 'ツクミシ', '文京町', 'ブンキョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県津久見市中田町', '44', '44207', '8792433', '大分県', 'オオイタケン', '津久見市', 'ツクミシ', '中田町', 'ナカダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県津久見市立花町', '44', '44207', '8792434', '大分県', 'オオイタケン', '津久見市', 'ツクミシ', '立花町', 'タチバナマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県津久見市宮本町', '44', '44207', '8792435', '大分県', 'オオイタケン', '津久見市', 'ツクミシ', '宮本町', 'ミヤモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県津久見市上宮本町', '44', '44207', '8792436', '大分県', 'オオイタケン', '津久見市', 'ツクミシ', '上宮本町', 'カミミヤモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県津久見市中央町', '44', '44207', '8792441', '大分県', 'オオイタケン', '津久見市', 'ツクミシ', '中央町', 'チュウオウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県津久見市港町', '44', '44207', '8792442', '大分県', 'オオイタケン', '津久見市', 'ツクミシ', '港町', 'ミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県津久見市セメント町', '44', '44207', '8792443', '大分県', 'オオイタケン', '津久見市', 'ツクミシ', 'セメント町', 'セメントマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県津久見市元町', '44', '44207', '8792444', '大分県', 'オオイタケン', '津久見市', 'ツクミシ', '元町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県津久見市井無田町', '44', '44207', '8792445', '大分県', 'オオイタケン', '津久見市', 'ツクミシ', '井無田町', 'イムタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県津久見市下青江', '44', '44207', '8792446', '大分県', 'オオイタケン', '津久見市', 'ツクミシ', '下青江', 'シモアオエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県津久見市新町', '44', '44207', '8792451', '大分県', 'オオイタケン', '津久見市', 'ツクミシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県津久見市中町', '44', '44207', '8792452', '大分県', 'オオイタケン', '津久見市', 'ツクミシ', '中町', 'ナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県津久見市小園町', '44', '44207', '8792453', '大分県', 'オオイタケン', '津久見市', 'ツクミシ', '小園町', 'コゾノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県津久見市地蔵町', '44', '44207', '8792454', '大分県', 'オオイタケン', '津久見市', 'ツクミシ', '地蔵町', 'ジゾウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県津久見市岡町', '44', '44207', '8792455', '大分県', 'オオイタケン', '津久見市', 'ツクミシ', '岡町', 'オカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県津久見市門前町', '44', '44207', '8792456', '大分県', 'オオイタケン', '津久見市', 'ツクミシ', '門前町', 'モンゼンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県津久見市志手町', '44', '44207', '8792457', '大分県', 'オオイタケン', '津久見市', 'ツクミシ', '志手町', 'シテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県津久見市入船西町', '44', '44207', '8792458', '大分県', 'オオイタケン', '津久見市', 'ツクミシ', '入船西町', 'イリフネニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県津久見市入船東町', '44', '44207', '8792459', '大分県', 'オオイタケン', '津久見市', 'ツクミシ', '入船東町', 'イリフネヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県津久見市上青江', '44', '44207', '8792461', '大分県', 'オオイタケン', '津久見市', 'ツクミシ', '上青江', 'カミアオエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県津久見市合ノ元町', '44', '44207', '8792471', '大分県', 'オオイタケン', '津久見市', 'ツクミシ', '合ノ元町', 'ゴウノモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県津久見市徳浦本町', '44', '44207', '8792472', '大分県', 'オオイタケン', '津久見市', 'ツクミシ', '徳浦本町', 'トクウラホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県津久見市徳浦宮町', '44', '44207', '8792473', '大分県', 'オオイタケン', '津久見市', 'ツクミシ', '徳浦宮町', 'トクウラミヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県津久見市徳浦', '44', '44207', '8792474', '大分県', 'オオイタケン', '津久見市', 'ツクミシ', '徳浦', 'トクウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県津久見市堅浦', '44', '44207', '8792475', '大分県', 'オオイタケン', '津久見市', 'ツクミシ', '堅浦', 'カタウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県津久見市長目', '44', '44207', '8792476', '大分県', 'オオイタケン', '津久見市', 'ツクミシ', '長目', 'ナガメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県津久見市保戸島', '44', '44207', '8792501', '大分県', 'オオイタケン', '津久見市', 'ツクミシ', '保戸島', 'ホトジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市上浦浅海井浦', '44', '44205', '8792601', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '上浦浅海井浦', 'カミウラアザムイウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市上浦津井浦', '44', '44205', '8792602', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '上浦津井浦', 'カミウラツイウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市上浦最勝海浦', '44', '44205', '8792603', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '上浦最勝海浦', 'カミウラニイナメウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県津久見市日見', '44', '44207', '8792681', '大分県', 'オオイタケン', '津久見市', 'ツクミシ', '日見', 'ヒミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県津久見市網代', '44', '44207', '8792682', '大分県', 'オオイタケン', '津久見市', 'ツクミシ', '網代', 'アジロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県津久見市四浦', '44', '44207', '8792683', '大分県', 'オオイタケン', '津久見市', 'ツクミシ', '四浦', 'ヨウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市直川赤木', '44', '44205', '8793101', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '直川赤木', 'ナオカワアカギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市直川上直見', '44', '44205', '8793102', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '直川上直見', 'ナオカワカミナオミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市直川下直見', '44', '44205', '8793103', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '直川下直見', 'ナオカワシモナオミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市直川仁田原', '44', '44205', '8793104', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '直川仁田原', 'ナオカワニタハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市直川横川', '44', '44205', '8793105', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '直川横川', 'ナオカワヨコガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市宇目大平', '44', '44205', '8793201', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '宇目大平', 'ウメオオヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市宇目河内', '44', '44205', '8793202', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '宇目河内', 'ウメカワチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市宇目塩見園', '44', '44205', '8793203', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '宇目塩見園', 'ウメシオミゾノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市宇目重岡', '44', '44205', '8793204', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '宇目重岡', 'ウメシゲオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市宇目千束', '44', '44205', '8793205', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '宇目千束', 'ウメセンゾク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市宇目小野市', '44', '44205', '8793301', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '宇目小野市', 'ウメオノイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市宇目南田原', '44', '44205', '8793302', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '宇目南田原', 'ウメミナミタバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市宇目木浦鉱山', '44', '44205', '8793401', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '宇目木浦鉱山', 'ウメキウラコウザン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県佐伯市宇目木浦内', '44', '44205', '8793402', '大分県', 'オオイタケン', '佐伯市', 'サイキシ', '宇目木浦内', 'ウメキウラウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市天瀬町馬原', '44', '44204', '8794121', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '天瀬町馬原', 'アマガセマチマバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市天瀬町合田', '44', '44204', '8794122', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '天瀬町合田', 'アマガセマチゴウタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市天瀬町女子畑', '44', '44204', '8794123', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '天瀬町女子畑', 'アマガセマチオナゴハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市天瀬町桜竹', '44', '44204', '8794201', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '天瀬町桜竹', 'アマガセマチサクラダケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市天瀬町赤岩', '44', '44204', '8794202', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '天瀬町赤岩', 'アマガセマチアカイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県日田市天瀬町湯山', '44', '44204', '8794203', '大分県', 'オオイタケン', '日田市', 'ヒタシ', '天瀬町湯山', 'アマガセマチユヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県玖珠郡玖珠町四日市', '44', '44462', '8794301', '大分県', 'オオイタケン', '玖珠郡玖珠町', 'クスグンクスマチ', '四日市', 'ヨッカイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県玖珠郡玖珠町戸畑', '44', '44462', '8794331', '大分県', 'オオイタケン', '玖珠郡玖珠町', 'クスグンクスマチ', '戸畑', 'トバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県玖珠郡玖珠町山浦秋畑', '44', '44462', '8794332', '大分県', 'オオイタケン', '玖珠郡玖珠町', 'クスグンクスマチ', '山浦', 'ヤマウラ', null, null, '秋畑', 'アキハタ');
INSERT INTO `ms_addresses` VALUES ('114725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県玖珠郡玖珠町山浦荻原', '44', '44462', '8794332', '大分県', 'オオイタケン', '玖珠郡玖珠町', 'クスグンクスマチ', '山浦', 'ヤマウラ', null, null, '荻原', 'オギワラ');
INSERT INTO `ms_addresses` VALUES ('114726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県玖珠郡玖珠町山浦下園', '44', '44462', '8794332', '大分県', 'オオイタケン', '玖珠郡玖珠町', 'クスグンクスマチ', '山浦', 'ヤマウラ', null, null, '下園', 'シモソノ');
INSERT INTO `ms_addresses` VALUES ('114727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県玖珠郡玖珠町山浦下ノ寺', '44', '44462', '8794332', '大分県', 'オオイタケン', '玖珠郡玖珠町', 'クスグンクスマチ', '山浦', 'ヤマウラ', null, null, '下ノ寺', 'シモノテラ');
INSERT INTO `ms_addresses` VALUES ('114728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県玖珠郡玖珠町山浦杉河内', '44', '44462', '8794332', '大分県', 'オオイタケン', '玖珠郡玖珠町', 'クスグンクスマチ', '山浦', 'ヤマウラ', null, null, '杉河内', 'スギカワチ');
INSERT INTO `ms_addresses` VALUES ('114729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県玖珠郡玖珠町山浦千重', '44', '44462', '8794332', '大分県', 'オオイタケン', '玖珠郡玖珠町', 'クスグンクスマチ', '山浦', 'ヤマウラ', null, null, '千重', 'センシュウ');
INSERT INTO `ms_addresses` VALUES ('114730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県玖珠郡玖珠町山浦早水', '44', '44462', '8794332', '大分県', 'オオイタケン', '玖珠郡玖珠町', 'クスグンクスマチ', '山浦', 'ヤマウラ', null, null, '早水', 'ソウズ');
INSERT INTO `ms_addresses` VALUES ('114731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県玖珠郡玖珠町山浦中泊里', '44', '44462', '8794332', '大分県', 'オオイタケン', '玖珠郡玖珠町', 'クスグンクスマチ', '山浦', 'ヤマウラ', null, null, '中泊里', 'ナカヅマリ');
INSERT INTO `ms_addresses` VALUES ('114732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県玖珠郡玖珠町山浦中野', '44', '44462', '8794332', '大分県', 'オオイタケン', '玖珠郡玖珠町', 'クスグンクスマチ', '山浦', 'ヤマウラ', null, null, '中野', 'ナカノ');
INSERT INTO `ms_addresses` VALUES ('114733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県玖珠郡玖珠町山浦花香', '44', '44462', '8794332', '大分県', 'オオイタケン', '玖珠郡玖珠町', 'クスグンクスマチ', '山浦', 'ヤマウラ', null, null, '花香', 'ハナガ');
INSERT INTO `ms_addresses` VALUES ('114734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県玖珠郡玖珠町山浦牧場', '44', '44462', '8794332', '大分県', 'オオイタケン', '玖珠郡玖珠町', 'クスグンクスマチ', '山浦', 'ヤマウラ', null, null, '牧場', 'ボクジョウ');
INSERT INTO `ms_addresses` VALUES ('114735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県玖珠郡玖珠町', '44', '44462', '8794400', '大分県', 'オオイタケン', '玖珠郡玖珠町', 'クスグンクスマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('114736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県玖珠郡玖珠町四日市', '44', '44462', '8794401', '大分県', 'オオイタケン', '玖珠郡玖珠町', 'クスグンクスマチ', '四日市', 'ヨッカイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県玖珠郡玖珠町綾垣', '44', '44462', '8794402', '大分県', 'オオイタケン', '玖珠郡玖珠町', 'クスグンクスマチ', '綾垣', 'アヤガキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県玖珠郡玖珠町帆足', '44', '44462', '8794403', '大分県', 'オオイタケン', '玖珠郡玖珠町', 'クスグンクスマチ', '帆足', 'ホアシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県玖珠郡玖珠町森', '44', '44462', '8794404', '大分県', 'オオイタケン', '玖珠郡玖珠町', 'クスグンクスマチ', '森', 'モリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県玖珠郡玖珠町岩室', '44', '44462', '8794405', '大分県', 'オオイタケン', '玖珠郡玖珠町', 'クスグンクスマチ', '岩室', 'イワムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県玖珠郡玖珠町日出生', '44', '44462', '8794406', '大分県', 'オオイタケン', '玖珠郡玖珠町', 'クスグンクスマチ', '日出生', 'ヒジウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県玖珠郡玖珠町小田', '44', '44462', '8794411', '大分県', 'オオイタケン', '玖珠郡玖珠町', 'クスグンクスマチ', '小田', 'オタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県玖珠郡玖珠町山田', '44', '44462', '8794412', '大分県', 'オオイタケン', '玖珠郡玖珠町', 'クスグンクスマチ', '山田', 'ヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県玖珠郡玖珠町塚脇', '44', '44462', '8794413', '大分県', 'オオイタケン', '玖珠郡玖珠町', 'クスグンクスマチ', '塚脇', 'ツカワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県玖珠郡玖珠町大隈', '44', '44462', '8794414', '大分県', 'オオイタケン', '玖珠郡玖珠町', 'クスグンクスマチ', '大隈', 'オオクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県玖珠郡玖珠町太田', '44', '44462', '8794521', '大分県', 'オオイタケン', '玖珠郡玖珠町', 'クスグンクスマチ', '太田', 'オオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県玖珠郡玖珠町山下', '44', '44462', '8794522', '大分県', 'オオイタケン', '玖珠郡玖珠町', 'クスグンクスマチ', '山下', 'ヤマシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県玖珠郡玖珠町古後', '44', '44462', '8794523', '大分県', 'オオイタケン', '玖珠郡玖珠町', 'クスグンクスマチ', '古後', 'コゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県玖珠郡九重町右田', '44', '44461', '8794601', '大分県', 'オオイタケン', '玖珠郡九重町', 'クスグンココノエマチ', '右田', 'ミギタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県玖珠郡九重町恵良', '44', '44461', '8794631', '大分県', 'オオイタケン', '玖珠郡九重町', 'クスグンココノエマチ', '恵良', 'エラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県玖珠郡九重町松木', '44', '44461', '8794632', '大分県', 'オオイタケン', '玖珠郡九重町', 'クスグンココノエマチ', '松木', 'マツギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県玖珠郡九重町粟野', '44', '44461', '8794721', '大分県', 'オオイタケン', '玖珠郡九重町', 'クスグンココノエマチ', '粟野', 'アワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県玖珠郡九重町引治', '44', '44461', '8794722', '大分県', 'オオイタケン', '玖珠郡九重町', 'クスグンココノエマチ', '引治', 'ヒキジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県玖珠郡九重町町田', '44', '44461', '8794723', '大分県', 'オオイタケン', '玖珠郡九重町', 'クスグンココノエマチ', '町田', 'マチダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県玖珠郡九重町菅原', '44', '44461', '8794724', '大分県', 'オオイタケン', '玖珠郡九重町', 'クスグンココノエマチ', '菅原', 'スガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県玖珠郡玖珠町山浦阿蘇釣', '44', '44462', '8794732', '大分県', 'オオイタケン', '玖珠郡玖珠町', 'クスグンクスマチ', '山浦', 'ヤマウラ', null, null, '阿蘇釣', 'アソヅル');
INSERT INTO `ms_addresses` VALUES ('114760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県玖珠郡玖珠町山浦第一大原野', '44', '44462', '8794732', '大分県', 'オオイタケン', '玖珠郡玖珠町', 'クスグンクスマチ', '山浦', 'ヤマウラ', null, null, '第一大原野', 'ダイ01ダイゲンヤ');
INSERT INTO `ms_addresses` VALUES ('114761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県玖珠郡玖珠町山浦第二大原野', '44', '44462', '8794732', '大分県', 'オオイタケン', '玖珠郡玖珠町', 'クスグンクスマチ', '山浦', 'ヤマウラ', null, null, '第二大原野', 'ダイ02ダイゲンヤ');
INSERT INTO `ms_addresses` VALUES ('114762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県玖珠郡九重町', '44', '44461', '8794800', '大分県', 'オオイタケン', '玖珠郡九重町', 'クスグンココノエマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('114763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県玖珠郡九重町右田', '44', '44461', '8794801', '大分県', 'オオイタケン', '玖珠郡九重町', 'クスグンココノエマチ', '右田', 'ミギタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県玖珠郡九重町野上', '44', '44461', '8794802', '大分県', 'オオイタケン', '玖珠郡九重町', 'クスグンココノエマチ', '野上', 'ノガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県玖珠郡九重町後野上', '44', '44461', '8794803', '大分県', 'オオイタケン', '玖珠郡九重町', 'クスグンココノエマチ', '後野上', 'ウシロノガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県玖珠郡九重町田野', '44', '44461', '8794911', '大分県', 'オオイタケン', '玖珠郡九重町', 'クスグンココノエマチ', '田野', 'タノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県玖珠郡九重町湯坪', '44', '44461', '8794912', '大分県', 'オオイタケン', '玖珠郡九重町', 'クスグンココノエマチ', '湯坪', 'ユツボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県由布市湯布院町塚原', '44', '44213', '8795101', '大分県', 'オオイタケン', '由布市', 'ユフシ', '湯布院町塚原', 'ユフインチョウツカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県由布市湯布院町川上', '44', '44213', '8795102', '大分県', 'オオイタケン', '由布市', 'ユフシ', '湯布院町川上', 'ユフインチョウカワカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県由布市湯布院町川南', '44', '44213', '8795103', '大分県', 'オオイタケン', '由布市', 'ユフシ', '湯布院町川南', 'ユフインチョウカワミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県由布市湯布院町中川', '44', '44213', '8795104', '大分県', 'オオイタケン', '由布市', 'ユフシ', '湯布院町中川', 'ユフインチョウナカガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県由布市湯布院町下湯平', '44', '44213', '8795111', '大分県', 'オオイタケン', '由布市', 'ユフシ', '湯布院町下湯平', 'ユフインチョウシモユノヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県由布市湯布院町湯平', '44', '44213', '8795112', '大分県', 'オオイタケン', '由布市', 'ユフシ', '湯布院町湯平', 'ユフインチョウユノヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県由布市湯布院町川西', '44', '44213', '8795113', '大分県', 'オオイタケン', '由布市', 'ユフシ', '湯布院町川西', 'ユフインチョウカワニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県由布市湯布院町川北', '44', '44213', '8795114', '大分県', 'オオイタケン', '由布市', 'ユフシ', '湯布院町川北', 'ユフインチョウカワキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県由布市', '44', '44213', '8795400', '大分県', 'オオイタケン', '由布市', 'ユフシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('114784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県由布市庄内町北大津留', '44', '44213', '8795401', '大分県', 'オオイタケン', '由布市', 'ユフシ', '庄内町北大津留', 'ショウナイチョウキタオオツル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県由布市庄内町小挾間', '44', '44213', '8795402', '大分県', 'オオイタケン', '由布市', 'ユフシ', '庄内町小挾間', 'ショウナイチョウオバサマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県由布市庄内町東大津留', '44', '44213', '8795403', '大分県', 'オオイタケン', '由布市', 'ユフシ', '庄内町東大津留', 'ショウナイチョウヒガシオオツル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県由布市庄内町櫟木', '44', '44213', '8795404', '大分県', 'オオイタケン', '由布市', 'ユフシ', '庄内町櫟木', 'ショウナイチョウイチギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県由布市庄内町東長宝', '44', '44213', '8795405', '大分県', 'オオイタケン', '由布市', 'ユフシ', '庄内町東長宝', 'ショウナイチョウヒガシチョウホウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県由布市庄内町西長宝', '44', '44213', '8795406', '大分県', 'オオイタケン', '由布市', 'ユフシ', '庄内町西長宝', 'ショウナイチョウニシチョウホウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県由布市庄内町南大津留', '44', '44213', '8795407', '大分県', 'オオイタケン', '由布市', 'ユフシ', '庄内町南大津留', 'ショウナイチョウミナミオオツル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県由布市庄内町西大津留', '44', '44213', '8795408', '大分県', 'オオイタケン', '由布市', 'ユフシ', '庄内町西大津留', 'ショウナイチョウニシオオツル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県由布市庄内町龍原', '44', '44213', '8795411', '大分県', 'オオイタケン', '由布市', 'ユフシ', '庄内町龍原', 'ショウナイチョウタツハル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県由布市庄内町五ケ瀬', '44', '44213', '8795412', '大分県', 'オオイタケン', '由布市', 'ユフシ', '庄内町五ケ瀬', 'ショウナイチョウゴカセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県由布市庄内町大龍', '44', '44213', '8795413', '大分県', 'オオイタケン', '由布市', 'ユフシ', '庄内町大龍', 'ショウナイチョウオオタツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県由布市庄内町柿原', '44', '44213', '8795421', '大分県', 'オオイタケン', '由布市', 'ユフシ', '庄内町柿原', 'ショウナイチョウカキハル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県由布市庄内町野畑', '44', '44213', '8795422', '大分県', 'オオイタケン', '由布市', 'ユフシ', '庄内町野畑', 'ショウナイチョウノバタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県由布市庄内町阿蘇野', '44', '44213', '8795423', '大分県', 'オオイタケン', '由布市', 'ユフシ', '庄内町阿蘇野', 'ショウナイチョウアソノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県由布市庄内町直野内山', '44', '44213', '8795424', '大分県', 'オオイタケン', '由布市', 'ユフシ', '庄内町直野内山', 'ショウナイチョウナオノウチヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県由布市庄内町渕', '44', '44213', '8795425', '大分県', 'オオイタケン', '由布市', 'ユフシ', '庄内町渕', 'ショウナイチョウフチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県由布市庄内町長野', '44', '44213', '8795431', '大分県', 'オオイタケン', '由布市', 'ユフシ', '庄内町長野', 'ショウナイチョウナガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県由布市庄内町畑田', '44', '44213', '8795432', '大分県', 'オオイタケン', '由布市', 'ユフシ', '庄内町畑田', 'ショウナイチョウハタケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県由布市庄内町高岡', '44', '44213', '8795433', '大分県', 'オオイタケン', '由布市', 'ユフシ', '庄内町高岡', 'ショウナイチョウタカオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県由布市庄内町庄内原', '44', '44213', '8795434', '大分県', 'オオイタケン', '由布市', 'ユフシ', '庄内町庄内原', 'ショウナイチョウショウナイバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県由布市庄内町中', '44', '44213', '8795435', '大分県', 'オオイタケン', '由布市', 'ユフシ', '庄内町中', 'ショウナイチョウナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県由布市庄内町西', '44', '44213', '8795436', '大分県', 'オオイタケン', '由布市', 'ユフシ', '庄内町西', 'ショウナイチョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県由布市庄内町平石', '44', '44213', '8795437', '大分県', 'オオイタケン', '由布市', 'ユフシ', '庄内町平石', 'ショウナイチョウヒライシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県由布市挾間町鬼崎', '44', '44213', '8795501', '大分県', 'オオイタケン', '由布市', 'ユフシ', '挾間町鬼崎', 'ハサママチオニザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県由布市挾間町向原', '44', '44213', '8795502', '大分県', 'オオイタケン', '由布市', 'ユフシ', '挾間町向原', 'ハサママチムカイノハル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県由布市挾間町医大ケ丘', '44', '44213', '8795503', '大分県', 'オオイタケン', '由布市', 'ユフシ', '挾間町医大ケ丘', 'ハサママチイダイガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県由布市挾間町下市', '44', '44213', '8795504', '大分県', 'オオイタケン', '由布市', 'ユフシ', '挾間町下市', 'ハサママチシモイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県由布市挾間町挾間', '44', '44213', '8795506', '大分県', 'オオイタケン', '由布市', 'ユフシ', '挾間町挾間', 'ハサママチハサマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県由布市挾間町東院', '44', '44213', '8795510', '大分県', 'オオイタケン', '由布市', 'ユフシ', '挾間町東院', 'ハサママチトイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県由布市挾間町古野', '44', '44213', '8795511', '大分県', 'オオイタケン', '由布市', 'ユフシ', '挾間町古野', 'ハサママチフルノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県由布市挾間町来鉢', '44', '44213', '8795512', '大分県', 'オオイタケン', '由布市', 'ユフシ', '挾間町来鉢', 'ハサママチクバチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県由布市挾間町高崎', '44', '44213', '8795513', '大分県', 'オオイタケン', '由布市', 'ユフシ', '挾間町高崎', 'ハサママチタカザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県由布市挾間町七蔵司', '44', '44213', '8795514', '大分県', 'オオイタケン', '由布市', 'ユフシ', '挾間町七蔵司', 'ハサママチナナゾウシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県由布市挾間町三船', '44', '44213', '8795515', '大分県', 'オオイタケン', '由布市', 'ユフシ', '挾間町三船', 'ハサママチミフネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県由布市挾間町赤野', '44', '44213', '8795516', '大分県', 'オオイタケン', '由布市', 'ユフシ', '挾間町赤野', 'ハサママチアカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県由布市挾間町内成', '44', '44213', '8795517', '大分県', 'オオイタケン', '由布市', 'ユフシ', '挾間町内成', 'ハサママチウチナリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県由布市挾間町北方', '44', '44213', '8795518', '大分県', 'オオイタケン', '由布市', 'ユフシ', '挾間町北方', 'ハサママチキタガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県由布市挾間町田代', '44', '44213', '8795519', '大分県', 'オオイタケン', '由布市', 'ユフシ', '挾間町田代', 'ハサママチタシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県由布市挾間町鬼瀬', '44', '44213', '8795521', '大分県', 'オオイタケン', '由布市', 'ユフシ', '挾間町鬼瀬', 'ハサママチオニガセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県由布市挾間町小野', '44', '44213', '8795522', '大分県', 'オオイタケン', '由布市', 'ユフシ', '挾間町小野', 'ハサママチオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県由布市挾間町篠原', '44', '44213', '8795523', '大分県', 'オオイタケン', '由布市', 'ユフシ', '挾間町篠原', 'ハサママチシノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県由布市挾間町時松', '44', '44213', '8795524', '大分県', 'オオイタケン', '由布市', 'ユフシ', '挾間町時松', 'ハサママチトキマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県由布市挾間町朴木', '44', '44213', '8795525', '大分県', 'オオイタケン', '由布市', 'ユフシ', '挾間町朴木', 'ハサママチホオノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県由布市挾間町谷', '44', '44213', '8795531', '大分県', 'オオイタケン', '由布市', 'ユフシ', '挾間町谷', 'ハサママチタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県由布市挾間町筒口', '44', '44213', '8795532', '大分県', 'オオイタケン', '由布市', 'ユフシ', '挾間町筒口', 'ハサママチツツグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市内成', '44', '44202', '8795551', '大分県', 'オオイタケン', '別府市', 'ベップシ', '内成', 'ウチナリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県別府市古賀原', '44', '44202', '8795552', '大分県', 'オオイタケン', '別府市', 'ベップシ', '古賀原', 'コガノハル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県竹田市荻町木下', '44', '44208', '8796101', '大分県', 'オオイタケン', '竹田市', 'タケタシ', '荻町木下', 'オギマチキノシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県竹田市荻町政所', '44', '44208', '8796102', '大分県', 'オオイタケン', '竹田市', 'タケタシ', '荻町政所', 'オギマチマドコロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県竹田市荻町新藤', '44', '44208', '8796103', '大分県', 'オオイタケン', '竹田市', 'タケタシ', '荻町新藤', 'オギマチシンドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県竹田市荻町藤渡', '44', '44208', '8796104', '大分県', 'オオイタケン', '竹田市', 'タケタシ', '荻町藤渡', 'オギマチフジワタリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県竹田市荻町南河内', '44', '44208', '8796111', '大分県', 'オオイタケン', '竹田市', 'タケタシ', '荻町南河内', 'オギマチミナミガワチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県竹田市荻町馬背野', '44', '44208', '8796112', '大分県', 'オオイタケン', '竹田市', 'タケタシ', '荻町馬背野', 'オギマチマセノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県竹田市荻町恵良原', '44', '44208', '8796113', '大分県', 'オオイタケン', '竹田市', 'タケタシ', '荻町恵良原', 'オギマチエラハル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県竹田市荻町馬場', '44', '44208', '8796115', '大分県', 'オオイタケン', '竹田市', 'タケタシ', '荻町馬場', 'オギマチババ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県竹田市荻町高城', '44', '44208', '8796116', '大分県', 'オオイタケン', '竹田市', 'タケタシ', '荻町高城', 'オギマチタカジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県竹田市荻町桑木', '44', '44208', '8796121', '大分県', 'オオイタケン', '竹田市', 'タケタシ', '荻町桑木', 'オギマチクワギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県竹田市荻町柏原', '44', '44208', '8796122', '大分県', 'オオイタケン', '竹田市', 'タケタシ', '荻町柏原', 'オギマチカシワバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県竹田市荻町宮平', '44', '44208', '8796123', '大分県', 'オオイタケン', '竹田市', 'タケタシ', '荻町宮平', 'オギマチミヤビラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県竹田市荻町陽目', '44', '44208', '8796124', '大分県', 'オオイタケン', '竹田市', 'タケタシ', '荻町陽目', 'オギマチヒナタメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県竹田市荻町仏面', '44', '44208', '8796125', '大分県', 'オオイタケン', '竹田市', 'タケタシ', '荻町仏面', 'オギマチブチメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県竹田市荻町大平', '44', '44208', '8796126', '大分県', 'オオイタケン', '竹田市', 'タケタシ', '荻町大平', 'オギマチオオダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県竹田市荻町叶野', '44', '44208', '8796127', '大分県', 'オオイタケン', '竹田市', 'タケタシ', '荻町叶野', 'オギマチカナイノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県竹田市荻町高練木', '44', '44208', '8796128', '大分県', 'オオイタケン', '竹田市', 'タケタシ', '荻町高練木', 'オギマチタカネリキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県竹田市荻町鴫田', '44', '44208', '8796131', '大分県', 'オオイタケン', '竹田市', 'タケタシ', '荻町鴫田', 'オギマチシギタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県竹田市荻町西福寺', '44', '44208', '8796132', '大分県', 'オオイタケン', '竹田市', 'タケタシ', '荻町西福寺', 'オギマチサイフクジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県竹田市荻町田代', '44', '44208', '8796133', '大分県', 'オオイタケン', '竹田市', 'タケタシ', '荻町田代', 'オギマチタシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県竹田市荻町瓜作', '44', '44208', '8796134', '大分県', 'オオイタケン', '竹田市', 'タケタシ', '荻町瓜作', 'オギマチウリツクリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県竹田市荻町北原', '44', '44208', '8796135', '大分県', 'オオイタケン', '竹田市', 'タケタシ', '荻町北原', 'オギマチキタバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県竹田市小塚', '44', '44208', '8796181', '大分県', 'オオイタケン', '竹田市', 'タケタシ', '小塚', 'オヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県竹田市今', '44', '44208', '8796182', '大分県', 'オオイタケン', '竹田市', 'タケタシ', '今', 'イマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県竹田市戸上', '44', '44208', '8796183', '大分県', 'オオイタケン', '竹田市', 'タケタシ', '戸上', 'トウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県竹田市菅生', '44', '44208', '8796184', '大分県', 'オオイタケン', '竹田市', 'タケタシ', '菅生', 'スゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市朝地町市万田', '44', '44212', '8796201', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '朝地町市万田', 'アサジマチイチマンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市朝地町下野', '44', '44212', '8796202', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '朝地町下野', 'アサジマチシモノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市朝地町宮生', '44', '44212', '8796211', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '朝地町宮生', 'アサジマチミヤオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市朝地町志賀', '44', '44212', '8796212', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '朝地町志賀', 'アサジマチシガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市朝地町上尾塚', '44', '44212', '8796213', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '朝地町上尾塚', 'アサジマチカミオツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市朝地町坪泉', '44', '44212', '8796221', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '朝地町坪泉', 'アサジマチツボイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市朝地町朝地', '44', '44212', '8796222', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '朝地町朝地', 'アサジマチアサジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市朝地町板井迫', '44', '44212', '8796223', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '朝地町板井迫', 'アサジマチイタイザコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市朝地町池田', '44', '44212', '8796224', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '朝地町池田', 'アサジマチイケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市朝地町鳥田', '44', '44212', '8796331', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '朝地町鳥田', 'アサジマチトリタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市朝地町綿田', '44', '44212', '8796332', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '朝地町綿田', 'アサジマチワタダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市朝地町栗林', '44', '44212', '8796333', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '朝地町栗林', 'アサジマチクリバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市朝地町梨小', '44', '44212', '8796334', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '朝地町梨小', 'アサジマチナシコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市大野町安藤', '44', '44212', '8796401', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '大野町安藤', 'オオノマチアンドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市大野町中土師', '44', '44212', '8796402', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '大野町中土師', 'オオノマチナカハジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市大野町長畑', '44', '44212', '8796403', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '大野町長畑', 'オオノマチナガハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市大野町後田', '44', '44212', '8796404', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '大野町後田', 'オオノマチウシロダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市大野町代三五', '44', '44212', '8796405', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '大野町代三五', 'オオノマチダイサンゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市大野町杉園', '44', '44212', '8796406', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '大野町杉園', 'オオノマチスギゾノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市大野町十時', '44', '44212', '8796407', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '大野町十時', 'オオノマチトトキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市大野町沢田', '44', '44212', '8796408', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '大野町沢田', 'オオノマチサワタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市大野町中原', '44', '44212', '8796421', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '大野町中原', 'オオノマチナカバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市大野町小倉木', '44', '44212', '8796422', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '大野町小倉木', 'オオノマチコグラキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市大野町矢田', '44', '44212', '8796423', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '大野町矢田', 'オオノマチヤダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市大野町夏足', '44', '44212', '8796424', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '大野町夏足', 'オオノマチナタセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市大野町両家', '44', '44212', '8796425', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '大野町両家', 'オオノマチリョウケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市大野町郡山', '44', '44212', '8796426', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '大野町郡山', 'オオノマチコオリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市大野町酒井寺', '44', '44212', '8796431', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '大野町酒井寺', 'オオノマチサカイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市大野町屋原', '44', '44212', '8796432', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '大野町屋原', 'オオノマチヤバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市大野町大原', '44', '44212', '8796433', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '大野町大原', 'オオノマチオオハル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市大野町桑原', '44', '44212', '8796434', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '大野町桑原', 'オオノマチクワバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市大野町北園', '44', '44212', '8796435', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '大野町北園', 'オオノマチキタゾノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市大野町田中', '44', '44212', '8796441', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '大野町田中', 'オオノマチタナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市大野町藤北', '44', '44212', '8796442', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '大野町藤北', 'オオノマチフジキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市大野町宮迫', '44', '44212', '8796443', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '大野町宮迫', 'オオノマチミヤザコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市大野町田代', '44', '44212', '8796444', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '大野町田代', 'オオノマチタシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市大野町片島', '44', '44212', '8796445', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '大野町片島', 'オオノマチカタシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市緒方町馬場', '44', '44212', '8796601', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '緒方町馬場', 'オガタマチババ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市緒方町志賀', '44', '44212', '8796602', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '緒方町志賀', 'オガタマチシガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市緒方町夏足', '44', '44212', '8796611', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '緒方町夏足', 'オガタマチナタセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市緒方町越生', '44', '44212', '8796612', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '緒方町越生', 'オガタマチコシオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市緒方町井上', '44', '44212', '8796613', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '緒方町井上', 'オガタマチイノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市緒方町知田', '44', '44212', '8796614', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '緒方町知田', 'オガタマチチタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市緒方町鮒川', '44', '44212', '8796615', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '緒方町鮒川', 'オガタマチフナガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市緒方町久土知', '44', '44212', '8796616', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '緒方町久土知', 'オガタマチクドチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市緒方町野尻', '44', '44212', '8796621', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '緒方町野尻', 'オガタマチノジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市緒方町天神', '44', '44212', '8796622', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '緒方町天神', 'オガタマチテンジン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市緒方町馬背畑', '44', '44212', '8796623', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '緒方町馬背畑', 'オガタマチマセバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市緒方町平石', '44', '44212', '8796624', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '緒方町平石', 'オガタマチヒライシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市緒方町上犬塚', '44', '44212', '8796625', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '緒方町上犬塚', 'オガタマチカミイヌヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市緒方町大化', '44', '44212', '8796626', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '緒方町大化', 'オガタマチタイカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市緒方町原尻', '44', '44212', '8796631', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '緒方町原尻', 'オガタマチハラジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市緒方町辻', '44', '44212', '8796632', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '緒方町辻', 'オガタマチツジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市緒方町小宛', '44', '44212', '8796633', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '緒方町小宛', 'オガタマチオアテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市緒方町寺原', '44', '44212', '8796634', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '緒方町寺原', 'オガタマチテラバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市緒方町軸丸', '44', '44212', '8796635', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '緒方町軸丸', 'オガタマチジクマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市緒方町草深野', '44', '44212', '8796641', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '緒方町草深野', 'オガタマチクサブカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市緒方町上自在', '44', '44212', '8796642', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '緒方町上自在', 'オガタマチカミジザイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市緒方町下自在', '44', '44212', '8796643', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '緒方町下自在', 'オガタマチシモジザイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市緒方町上年野', '44', '44212', '8796751', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '緒方町上年野', 'オガタマチカミトシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市緒方町柚木', '44', '44212', '8796752', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '緒方町柚木', 'オガタマチユギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市緒方町下徳田', '44', '44212', '8796753', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '緒方町下徳田', 'オガタマチシモトクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市緒方町冬原', '44', '44212', '8796754', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '緒方町冬原', 'オガタマチフユバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市緒方町上冬原', '44', '44212', '8796755', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '緒方町上冬原', 'オガタマチカミフユバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市緒方町徳田', '44', '44212', '8796756', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '緒方町徳田', 'オガタマチトクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市緒方町木野', '44', '44212', '8796757', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '緒方町木野', 'オガタマチキノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市緒方町中野', '44', '44212', '8796758', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '緒方町中野', 'オガタマチナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市緒方町大石', '44', '44212', '8796759', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '緒方町大石', 'オガタマチオオイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市緒方町小原', '44', '44212', '8796861', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '緒方町小原', 'オガタマチオハル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市緒方町栗生', '44', '44212', '8796862', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '緒方町栗生', 'オガタマチクリウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市緒方町滞迫', '44', '44212', '8796863', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '緒方町滞迫', 'オガタマチタイザコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市緒方町上畑', '44', '44212', '8796864', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '緒方町上畑', 'オガタマチウワハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市緒方町尾平鉱山', '44', '44212', '8796865', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '緒方町尾平鉱山', 'オガタマチオビラコウザン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市清川町臼尾', '44', '44212', '8796901', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '清川町臼尾', 'キヨカワマチウスオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市清川町雨堤', '44', '44212', '8796902', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '清川町雨堤', 'キヨカワマチアマヅツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市清川町砂田', '44', '44212', '8796903', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '清川町砂田', 'キヨカワマチスナダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市清川町天神', '44', '44212', '8796904', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '清川町天神', 'キヨカワマチテンジン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市清川町三玉', '44', '44212', '8796905', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '清川町三玉', 'キヨカワマチミタマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市清川町宇田枝', '44', '44212', '8796911', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '清川町宇田枝', 'キヨカワマチウタエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市清川町六種', '44', '44212', '8796912', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '清川町六種', 'キヨカワマチムクサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市清川町平石', '44', '44212', '8796913', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '清川町平石', 'キヨカワマチヒライシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市清川町左右知', '44', '44212', '8796914', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '清川町左右知', 'キヨカワマチソウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市清川町伏野', '44', '44212', '8796921', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '清川町伏野', 'キヨカワマチフセノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市清川町大白谷', '44', '44212', '8796922', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '清川町大白谷', 'キヨカワマチオオシロタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市', '44', '44212', '8797100', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('114950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市三重町宮野', '44', '44212', '8797101', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '三重町宮野', 'ミエマチミヤノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市三重町菅生', '44', '44212', '8797102', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '三重町菅生', 'ミエマチスゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市三重町西畑', '44', '44212', '8797103', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '三重町西畑', 'ミエマチニシハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市三重町小坂', '44', '44212', '8797104', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '三重町小坂', 'ミエマチオサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市三重町芦刈', '44', '44212', '8797105', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '三重町芦刈', 'ミエマチアシカリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市三重町井迫', '44', '44212', '8797106', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '三重町井迫', 'ミエマチイサコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市三重町上田原', '44', '44212', '8797107', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '三重町上田原', 'ミエマチカミタワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市三重町浅瀬', '44', '44212', '8797108', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '三重町浅瀬', 'ミエマチアサセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市三重町赤嶺', '44', '44212', '8797111', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '三重町赤嶺', 'ミエマチアカミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市三重町山部', '44', '44212', '8797121', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '三重町山部', 'ミエマチヤマブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市三重町鷲谷', '44', '44212', '8797122', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '三重町鷲谷', 'ミエマチワシダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市三重町松尾', '44', '44212', '8797123', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '三重町松尾', 'ミエマチマツオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市三重町内山', '44', '44212', '8797124', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '三重町内山', 'ミエマチウチヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市三重町内田', '44', '44212', '8797125', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '三重町内田', 'ミエマチウチダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市三重町市場', '44', '44212', '8797131', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '三重町市場', 'ミエマチイチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市三重町秋葉', '44', '44212', '8797141', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '三重町秋葉', 'ミエマチアキバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市三重町小田', '44', '44212', '8797142', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '三重町小田', 'ミエマチオダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市三重町久田', '44', '44212', '8797143', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '三重町久田', 'ミエマチヒサダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市三重町本城', '44', '44212', '8797144', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '三重町本城', 'ミエマチホンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市三重町西泉', '44', '44212', '8797151', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '三重町西泉', 'ミエマチニシイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市三重町百枝', '44', '44212', '8797152', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '三重町百枝', 'ミエマチモモエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市三重町玉田', '44', '44212', '8797153', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '三重町玉田', 'ミエマチタマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市三重町川辺', '44', '44212', '8797154', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '三重町川辺', 'ミエマチカワベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市三重町向野', '44', '44212', '8797155', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '三重町向野', 'ミエマチムコウノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市三重町伏野', '44', '44212', '8797261', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '三重町伏野', 'ミエマチフセノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市三重町奥畑', '44', '44212', '8797262', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '三重町奥畑', 'ミエマチオクバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市三重町中津留', '44', '44212', '8797263', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '三重町中津留', 'ミエマチナカヅル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市三重町大白谷', '44', '44212', '8797264', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '三重町大白谷', 'ミエマチオオシロタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市犬飼町犬飼', '44', '44212', '8797301', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '犬飼町犬飼', 'イヌカイマチイヌカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市犬飼町久原', '44', '44212', '8797302', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '犬飼町久原', 'イヌカイマチクバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市犬飼町柚野木', '44', '44212', '8797303', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '犬飼町柚野木', 'イヌカイマチユノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市犬飼町大寒', '44', '44212', '8797304', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '犬飼町大寒', 'イヌカイマチオオソウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市犬飼町田原', '44', '44212', '8797305', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '犬飼町田原', 'イヌカイマチタハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市犬飼町下津尾', '44', '44212', '8797306', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '犬飼町下津尾', 'イヌカイマチシモツオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市犬飼町西寒田', '44', '44212', '8797307', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '犬飼町西寒田', 'イヌカイマチササムタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市犬飼町柴北', '44', '44212', '8797311', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '犬飼町柴北', 'イヌカイマチシバキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市犬飼町高津原', '44', '44212', '8797312', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '犬飼町高津原', 'イヌカイマチコウヅハル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市犬飼町黒松', '44', '44212', '8797313', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '犬飼町黒松', 'イヌカイマチクロマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市犬飼町栗ケ畑', '44', '44212', '8797314', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '犬飼町栗ケ畑', 'イヌカイマチクリガハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市犬飼町山内', '44', '44212', '8797315', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '犬飼町山内', 'イヌカイマチヤマウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市犬飼町長畑', '44', '44212', '8797316', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '犬飼町長畑', 'イヌカイマチナガハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市千歳町新殿', '44', '44212', '8797401', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '千歳町新殿', 'チトセマチニイドノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市千歳町船田', '44', '44212', '8797402', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '千歳町船田', 'チトセマチフナダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市千歳町石田', '44', '44212', '8797403', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '千歳町石田', 'チトセマチイシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市千歳町長峰', '44', '44212', '8797404', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '千歳町長峰', 'チトセマチナガミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市千歳町柴山', '44', '44212', '8797411', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '千歳町柴山', 'チトセマチシバヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市千歳町高畑', '44', '44212', '8797412', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '千歳町高畑', 'チトセマチタカハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('114999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市千歳町下山', '44', '44212', '8797413', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '千歳町下山', 'チトセマチシモヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県豊後大野市千歳町前田', '44', '44212', '8797414', '大分県', 'オオイタケン', '豊後大野市', 'ブンゴオオノシ', '千歳町前田', 'チトセマチマエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市竹中', '44', '44201', '8797501', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '竹中', 'タケナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市端登', '44', '44201', '8797502', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '端登', 'ハタノボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市河原内', '44', '44201', '8797503', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '河原内', 'カワラウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市安藤', '44', '44201', '8797504', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '安藤', 'アンドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市中戸次', '44', '44201', '8797761', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '中戸次', 'ナカヘツギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市けやき台', '44', '44201', '8797762', '大分県', 'オオイタケン', '大分市', 'オオイタシ', 'けやき台', 'ケヤキダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市下戸次', '44', '44201', '8797763', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '下戸次', 'シモヘツギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市上戸次', '44', '44201', '8797764', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '上戸次', 'カミヘツギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市美園団地', '44', '44201', '8797765', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '美園団地', 'ミソノダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市辻', '44', '44201', '8797871', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '辻', 'ツジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市月形', '44', '44201', '8797872', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '月形', 'ツキガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市宮尾', '44', '44201', '8797873', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '宮尾', 'ミヤオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市福良', '44', '44201', '8797874', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '福良', 'フクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市吉野原', '44', '44201', '8797875', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '吉野原', 'ヨシノハル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市奥', '44', '44201', '8797881', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '奥', 'オク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市杉原', '44', '44201', '8797882', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '杉原', 'スギバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市萩尾', '44', '44201', '8797883', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '萩尾', 'ハギオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市志津留', '44', '44201', '8797884', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '志津留', 'シツル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '大分県大分市梅が丘', '44', '44201', '8797885', '大分県', 'オオイタケン', '大分市', 'オオイタシ', '梅が丘', 'ウメガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市', '45', '45201', '8800000', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('115021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市橘通西', '45', '45201', '8800001', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '橘通西', 'タチバナドオリニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市中央通', '45', '45201', '8800002', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '中央通', 'チュウオウドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市高松町', '45', '45201', '8800003', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '高松町', 'タカマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市元宮町', '45', '45201', '8800004', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '元宮町', 'モトミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市南高松町', '45', '45201', '8800005', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '南高松町', 'ミナミタカマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市千草町', '45', '45201', '8800006', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '千草町', 'チグサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市原町', '45', '45201', '8800007', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '原町', 'ハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市上野町', '45', '45201', '8800011', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '上野町', 'カミノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市末広', '45', '45201', '8800012', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '末広', 'スエヒロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市松橋', '45', '45201', '8800013', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '松橋', 'マツバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市鶴島', '45', '45201', '8800014', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '鶴島', 'ツルノシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市大工', '45', '45201', '8800015', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '大工', 'ダイク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市西高松町', '45', '45201', '8800016', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '西高松町', 'ニシタカマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市北高松町', '45', '45201', '8800017', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '北高松町', 'キタタカマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市清水', '45', '45201', '8800021', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '清水', 'シミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市大橋', '45', '45201', '8800022', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '大橋', 'オオハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市和知川原', '45', '45201', '8800023', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '和知川原', 'ワチガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市祗園', '45', '45201', '8800024', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '祗園', 'ギオン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市中津瀬町', '45', '45201', '8800025', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '中津瀬町', 'ナカツセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市花殿町', '45', '45201', '8800026', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '花殿町', 'ハナドノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市西池町', '45', '45201', '8800027', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '西池町', 'ニシイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市船塚', '45', '45201', '8800031', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '船塚', 'フナツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市霧島', '45', '45201', '8800032', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '霧島', 'キリシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市神宮西', '45', '45201', '8800033', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '神宮西', 'ジングウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市矢の先町', '45', '45201', '8800034', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '矢の先町', 'ヤノサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市下北方町', '45', '45201', '8800035', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '下北方町', 'シモキタカタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市花ケ島町', '45', '45201', '8800036', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '花ケ島町', 'ハナガシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市南方町', '45', '45201', '8800037', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '南方町', 'ミナミカタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市池内町', '45', '45201', '8800041', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '池内町', 'イケウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市平和が丘東町', '45', '45201', '8800042', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '平和が丘東町', 'ヘイワガオカヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市上北方', '45', '45201', '8800043', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '上北方', 'カミキタカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市瓜生野', '45', '45201', '8800044', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '瓜生野', 'ウリュウノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市大瀬町', '45', '45201', '8800045', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '大瀬町', 'オオセマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市平和が丘北町', '45', '45201', '8800046', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '平和が丘北町', 'ヘイワガオカキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市平和が丘西町', '45', '45201', '8800047', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '平和が丘西町', 'ヘイワガオカニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市江平西', '45', '45201', '8800051', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '江平西', 'エヒラニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市丸山', '45', '45201', '8800052', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '丸山', 'マルヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市神宮', '45', '45201', '8800053', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '神宮', 'ジングウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市神宮町', '45', '45201', '8800054', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '神宮町', 'ジングウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市南花ケ島町', '45', '45201', '8800055', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '南花ケ島町', 'ミナミハナガシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市神宮東', '45', '45201', '8800056', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '神宮東', 'ジングウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市桜町', '45', '45201', '8800057', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '桜町', 'サクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市島之内', '45', '45201', '8800121', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '島之内', 'シマノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市塩路', '45', '45201', '8800122', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '塩路', 'シオジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市芳士', '45', '45201', '8800123', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '芳士', 'ホウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市新名爪', '45', '45201', '8800124', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '新名爪', 'ニイナヅメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市広原', '45', '45201', '8800125', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '広原', 'ヒロハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市佐土原町下富田', '45', '45201', '8800204', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '佐土原町下富田', 'サドワラチョウシモトンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市佐土原町下田島', '45', '45201', '8800211', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '佐土原町下田島', 'サドワラチョウシモタジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市佐土原町下那珂', '45', '45201', '8800212', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '佐土原町下那珂', 'サドワラチョウシモナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市佐土原町石崎', '45', '45201', '8800213', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '佐土原町石崎', 'サドワラチョウイシザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市佐土原町松小路', '45', '45201', '8800214', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '佐土原町松小路', 'サドワラチョウマツコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市佐土原町上田島', '45', '45201', '8800301', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '佐土原町上田島', 'サドワラチョウカミタジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市佐土原町西上那珂', '45', '45201', '8800302', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '佐土原町西上那珂', 'サドワラチョウニシカミナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市佐土原町東上那珂', '45', '45201', '8800303', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '佐土原町東上那珂', 'サドワラチョウヒガシカミナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県西都市現王島', '45', '45208', '8800341', '宮崎県', 'ミヤザキケン', '西都市', 'サイトシ', '現王島', 'ゲンノウジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市瓜生野下畑', '45', '45201', '8800344', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '瓜生野', 'ウリュウノ', null, null, '下畑', 'シモハタ');
INSERT INTO `ms_addresses` VALUES ('115083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市大瀬町上畑', '45', '45201', '8800345', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '大瀬町', 'オオセマチ', null, null, '上畑', 'カミハタ');
INSERT INTO `ms_addresses` VALUES ('115084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市老松', '45', '45201', '8800801', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '老松', 'オイマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市別府町', '45', '45201', '8800802', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '別府町', 'ベップチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市旭', '45', '45201', '8800803', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '旭', 'アサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市宮田町', '45', '45201', '8800804', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '宮田町', 'ミヤタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市橘通東', '45', '45201', '8800805', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '橘通東', 'タチバナドオリヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市広島', '45', '45201', '8800806', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '広島', 'ヒロシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市錦町', '45', '45201', '8800811', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '錦町', 'ニシキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市高千穂通', '45', '45201', '8800812', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '高千穂通', 'タカチホドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市丸島町', '45', '45201', '8800813', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '丸島町', 'マルシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市江平中町', '45', '45201', '8800814', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '江平中町', 'エヒラナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市江平町', '45', '45201', '8800815', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '江平町', 'エヒラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市江平東', '45', '45201', '8800816', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '江平東', 'エヒラヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市江平東町', '45', '45201', '8800817', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '江平東町', 'エヒラヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市錦本町', '45', '45201', '8800818', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '錦本町', 'ニシキホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市浮城町', '45', '45201', '8800821', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '浮城町', 'ウキノジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市権現町', '45', '45201', '8800822', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '権現町', 'ゴンゲンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市北権現町', '45', '45201', '8800823', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '北権現町', 'キタゴンゲンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市大島町', '45', '45201', '8800824', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '大島町', 'オオシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市東大宮', '45', '45201', '8800825', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '東大宮', 'ヒガシオオミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市波島', '45', '45201', '8800826', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '波島', 'ナミシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市新栄町', '45', '45201', '8800831', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '新栄町', 'シンエイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市稗原町', '45', '45201', '8800832', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '稗原町', 'ヒエバルチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市昭栄町', '45', '45201', '8800833', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '昭栄町', 'ショウエイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市新別府町', '45', '45201', '8800834', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '新別府町', 'シンベップチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市阿波岐原町', '45', '45201', '8800835', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '阿波岐原町', 'アワギガハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市山崎町', '45', '45201', '8800836', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '山崎町', 'ヤマサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市村角町', '45', '45201', '8800837', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '村角町', 'ムラスミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市吉村町', '45', '45201', '8800841', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '吉村町', 'ヨシムラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市青葉町', '45', '45201', '8800842', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '青葉町', 'アオバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市下原町', '45', '45201', '8800843', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '下原町', 'シモハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市柳丸町', '45', '45201', '8800844', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '柳丸町', 'ヤナギマルチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市新城町', '45', '45201', '8800845', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '新城町', 'シンジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市港東', '45', '45201', '8800851', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '港東', 'ミナトヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市高洲町', '45', '45201', '8800852', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '高洲町', 'タカスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市中西町', '45', '45201', '8800853', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '中西町', 'ナカニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市一の宮町', '45', '45201', '8800854', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '一の宮町', 'イチノミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市田代町', '45', '45201', '8800855', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '田代町', 'タシロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市日ノ出町', '45', '45201', '8800856', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '日ノ出町', 'ヒノデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市小戸町', '45', '45201', '8800857', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '小戸町', 'オドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市港', '45', '45201', '8800858', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '港', 'ミナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市出来島町', '45', '45201', '8800861', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '出来島町', 'デキジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市潮見町', '45', '45201', '8800862', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '潮見町', 'シオミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市前原町', '45', '45201', '8800863', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '前原町', 'マエバルチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市吾妻町', '45', '45201', '8800864', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '吾妻町', 'アヅマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市松山', '45', '45201', '8800865', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '松山', 'マツヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市川原町', '45', '45201', '8800866', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '川原町', 'カワラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市瀬頭', '45', '45201', '8800867', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '瀬頭', 'セガシラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市瀬頭町', '45', '45201', '8800868', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '瀬頭町', 'セガシラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市大王町', '45', '45201', '8800871', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '大王町', 'ダイオウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市永楽町', '45', '45201', '8800872', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '永楽町', 'エイラクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市堀川町', '45', '45201', '8800873', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '堀川町', 'ホリカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市昭和町', '45', '45201', '8800874', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '昭和町', 'ショウワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市曽師町', '45', '45201', '8800875', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '曽師町', 'ソシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市浄土江町', '45', '45201', '8800876', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '浄土江町', 'ジョウドエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市宮脇町', '45', '45201', '8800877', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '宮脇町', 'ミヤワキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市大和町', '45', '45201', '8800878', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '大和町', 'ヤマトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市宮崎駅東', '45', '45201', '8800879', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '宮崎駅東', 'ミヤザキエキヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市東大淀', '45', '45201', '8800901', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '東大淀', 'ヒガシオオヨド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市大淀', '45', '45201', '8800902', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '大淀', 'オオヨド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市太田', '45', '45201', '8800903', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '太田', 'オオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市中村東', '45', '45201', '8800904', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '中村東', 'ナカムラヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市中村西', '45', '45201', '8800905', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '中村西', 'ナカムラニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市南町', '45', '45201', '8800906', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '南町', 'ミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市淀川', '45', '45201', '8800907', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '淀川', 'ヨドガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市谷川', '45', '45201', '8800908', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '谷川', 'タニガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市谷川町', '45', '45201', '8800909', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '谷川町', 'タニガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市田吉', '45', '45201', '8800911', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '田吉', 'タヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市赤江', '45', '45201', '8800912', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '赤江', 'アカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市恒久', '45', '45201', '8800913', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '恒久', 'ツネヒサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市宮の元町', '45', '45201', '8800914', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '宮の元町', 'ミヤノモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市恒久南', '45', '45201', '8800915', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '恒久南', 'ツネヒサミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市恒久', '45', '45201', '8800916', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '恒久', 'ツネヒサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市城ケ崎', '45', '45201', '8800917', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '城ケ崎', 'ジョウガサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市本郷南方', '45', '45201', '8800921', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '本郷南方', 'ホンゴウミナミカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市本郷', '45', '45201', '8800922', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '本郷', 'ホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市希望ケ丘', '45', '45201', '8800923', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '希望ケ丘', 'キボウガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市郡司分', '45', '45201', '8800924', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '郡司分', 'グジブン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市本郷北方', '45', '45201', '8800925', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '本郷北方', 'ホンゴウキタカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市月見ケ丘', '45', '45201', '8800926', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '月見ケ丘', 'ツキミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市源藤町', '45', '45201', '8800927', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '源藤町', 'ゲンドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市東宮', '45', '45201', '8800928', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '東宮', 'トウグウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市まなび野', '45', '45201', '8800929', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', 'まなび野', 'マナビノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市花山手東', '45', '45201', '8800930', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '花山手東', 'ハナヤマテヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市古城町', '45', '45201', '8800931', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '古城町', 'フルジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市大坪西', '45', '45201', '8800932', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '大坪西', 'オオツボニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市大坪町', '45', '45201', '8800933', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '大坪町', 'オオツボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市大坪東', '45', '45201', '8800934', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '大坪東', 'オオツボヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市天満町', '45', '45201', '8800935', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '天満町', 'テンマンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市天満', '45', '45201', '8800936', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '天満', 'テンマン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市京塚', '45', '45201', '8800937', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '京塚', 'キョウツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市京塚町', '45', '45201', '8800938', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '京塚町', 'キョウヅカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市花山手西', '45', '45201', '8800939', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '花山手西', 'ハナヤマテニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市北川内町', '45', '45201', '8800941', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '北川内町', 'キタカワウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市生目台東', '45', '45201', '8800942', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '生目台東', 'イキメダイヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市生目台西', '45', '45201', '8800943', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '生目台西', 'イキメダイニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市江南', '45', '45201', '8800944', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '江南', 'コウナン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市福島町', '45', '45201', '8800945', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '福島町', 'フクシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市福島町', '45', '45201', '8800946', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '福島町', 'フクシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市薫る坂', '45', '45201', '8800947', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '薫る坂', 'カオルザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市大塚町', '45', '45201', '8800951', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '大塚町', 'オオツカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市大塚台東', '45', '45201', '8800952', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '大塚台東', 'オオツカダイヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市小松台東', '45', '45201', '8800953', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '小松台東', 'コマツダイヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市小松台西', '45', '45201', '8800954', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '小松台西', 'コマツダイニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市桜ケ丘町', '45', '45201', '8800955', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '桜ケ丘町', 'サクラガオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市小松台南町', '45', '45201', '8800956', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '小松台南町', 'コマツダイミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市音別町馬主来', '01', '01206', '0880101', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '音別町馬主来', 'オンベツチョウパシクル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市音別町中音別光和', '01', '01206', '0880102', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '音別町中音別', 'オンベツチョウナカオンベツ', null, null, '光和', 'コウワ');
INSERT INTO `ms_addresses` VALUES ('115191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市音別町中音別北栄', '01', '01206', '0880103', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '音別町中音別', 'オンベツチョウナカオンベツ', null, null, '北栄', 'ホクエイ');
INSERT INTO `ms_addresses` VALUES ('115192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市音別町音別原野基線二俣', '01', '01206', '0880104', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '音別町音別原野基線', 'オンベツチョウオンベツゲンヤキセン', null, null, '二俣', 'フタマタ');
INSERT INTO `ms_addresses` VALUES ('115193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市音別町ムリ', '01', '01206', '0880105', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '音別町ムリ', 'オンベツチョウムリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市音別町ヌプキベツ', '01', '01206', '0880106', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '音別町ヌプキベツ', 'オンベツチョウヌプキベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市音別町チヤンベツ', '01', '01206', '0880107', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '音別町チヤンベツ', 'オンベツチョウチャンベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市音別町音別原野基線二俣川向', '01', '01206', '0880108', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '音別町音別原野基線', 'オンベツチョウオンベツゲンヤキセン', null, null, '二俣川向', 'フタマタカワムカイ');
INSERT INTO `ms_addresses` VALUES ('115197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市音別町音別原野東', '01', '01206', '0880109', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '音別町音別原野東', 'オンベツチョウオンベツゲンヤヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県東諸県郡国富町', '45', '45382', '8801100', '宮崎県', 'ミヤザキケン', '東諸県郡国富町', 'ヒガシモロカタグンクニトミチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('115199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県東諸県郡国富町本庄', '45', '45382', '8801101', '宮崎県', 'ミヤザキケン', '東諸県郡国富町', 'ヒガシモロカタグンクニトミチョウ', '本庄', 'ホンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県東諸県郡国富町宮王丸', '45', '45382', '8801102', '宮崎県', 'ミヤザキケン', '東諸県郡国富町', 'ヒガシモロカタグンクニトミチョウ', '宮王丸', 'ミヤオウマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県東諸県郡国富町嵐田', '45', '45382', '8801103', '宮崎県', 'ミヤザキケン', '東諸県郡国富町', 'ヒガシモロカタグンクニトミチョウ', '嵐田', 'アラシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県東諸県郡国富町田尻', '45', '45382', '8801104', '宮崎県', 'ミヤザキケン', '東諸県郡国富町', 'ヒガシモロカタグンクニトミチョウ', '田尻', 'タジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県東諸県郡国富町向高', '45', '45382', '8801105', '宮崎県', 'ミヤザキケン', '東諸県郡国富町', 'ヒガシモロカタグンクニトミチョウ', '向高', 'ムコウタカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県東諸県郡国富町森永', '45', '45382', '8801106', '宮崎県', 'ミヤザキケン', '東諸県郡国富町', 'ヒガシモロカタグンクニトミチョウ', '森永', 'モリナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県東諸県郡国富町竹田', '45', '45382', '8801107', '宮崎県', 'ミヤザキケン', '東諸県郡国富町', 'ヒガシモロカタグンクニトミチョウ', '竹田', 'タケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県東諸県郡国富町須志田', '45', '45382', '8801108', '宮崎県', 'ミヤザキケン', '東諸県郡国富町', 'ヒガシモロカタグンクニトミチョウ', '須志田', 'スシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市音別町パシクル湖畔', '01', '01206', '0880111', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '音別町パシクル湖畔', 'オンベツチョウパシクルコハン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県東諸県郡国富町岩知野', '45', '45382', '8801111', '宮崎県', 'ミヤザキケン', '東諸県郡国富町', 'ヒガシモロカタグンクニトミチョウ', '岩知野', 'イワチノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県東諸県郡国富町塚原', '45', '45382', '8801112', '宮崎県', 'ミヤザキケン', '東諸県郡国富町', 'ヒガシモロカタグンクニトミチョウ', '塚原', 'ツカバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県東諸県郡国富町木脇', '45', '45382', '8801113', '宮崎県', 'ミヤザキケン', '東諸県郡国富町', 'ヒガシモロカタグンクニトミチョウ', '木脇', 'キワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県東諸県郡国富町三名', '45', '45382', '8801114', '宮崎県', 'ミヤザキケン', '東諸県郡国富町', 'ヒガシモロカタグンクニトミチョウ', '三名', 'サンミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市音別町中音別チノミ台', '01', '01206', '0880112', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '音別町中音別', 'オンベツチョウナカオンベツ', null, null, 'チノミ台', 'チノミダイ');
INSERT INTO `ms_addresses` VALUES ('115213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県東諸県郡国富町伊佐生吹上', '45', '45382', '8801121', '宮崎県', 'ミヤザキケン', '東諸県郡国富町', 'ヒガシモロカタグンクニトミチョウ', '伊佐生', 'イザオ', null, null, '吹上', 'フキアゲ');
INSERT INTO `ms_addresses` VALUES ('115214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市音別町風連', '01', '01206', '0880113', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '音別町風連', 'オンベツチョウフウレン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市音別町海光', '01', '01206', '0880114', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '音別町海光', 'オンベツチョウカイコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市音別町本町', '01', '01206', '0880115', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '音別町本町', 'オンベツチョウモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市音別町中園', '01', '01206', '0880116', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '音別町中園', 'オンベツチョウナカゾノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市音別町朝日', '01', '01206', '0880117', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '音別町朝日', 'オンベツチョウアサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市音別町中音別', '01', '01206', '0880118', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '音別町中音別', 'オンベツチョウナカオンベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市音別町若草', '01', '01206', '0880121', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '音別町若草', 'オンベツチョウワカクサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市音別町あけぼの', '01', '01206', '0880122', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '音別町あけぼの', 'オンベツチョウアケボノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県東諸県郡国富町伊佐生', '45', '45382', '8801221', '宮崎県', 'ミヤザキケン', '東諸県郡国富町', 'ヒガシモロカタグンクニトミチョウ', '伊佐生', 'イザオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県東諸県郡国富町八代北俣', '45', '45382', '8801222', '宮崎県', 'ミヤザキケン', '東諸県郡国富町', 'ヒガシモロカタグンクニトミチョウ', '八代北俣', 'ヤツシロキタマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県東諸県郡国富町八代南俣', '45', '45382', '8801223', '宮崎県', 'ミヤザキケン', '東諸県郡国富町', 'ヒガシモロカタグンクニトミチョウ', '八代南俣', 'ヤツシロミナミマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県東諸県郡国富町深年', '45', '45382', '8801224', '宮崎県', 'ミヤザキケン', '東諸県郡国富町', 'ヒガシモロカタグンクニトミチョウ', '深年', 'フカドシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市音別町川東', '01', '01206', '0880123', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '音別町川東', 'オンベツチョウカワヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市音別町緑町', '01', '01206', '0880124', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '音別町緑町', 'オンベツチョウミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市音別町共栄', '01', '01206', '0880125', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '音別町共栄', 'オンベツチョウキョウエイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市音別町音別原野西川西', '01', '01206', '0880126', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '音別町音別原野西', 'オンベツチョウオンベツゲンヤニシ', null, null, '川西', 'カワニシ');
INSERT INTO `ms_addresses` VALUES ('115235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県東諸県郡綾町', '45', '45383', '8801300', '宮崎県', 'ミヤザキケン', '東諸県郡綾町', 'ヒガシモロカタグンアヤチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('115236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県東諸県郡綾町入野', '45', '45383', '8801301', '宮崎県', 'ミヤザキケン', '東諸県郡綾町', 'ヒガシモロカタグンアヤチョウ', '入野', 'イリノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県東諸県郡綾町北俣', '45', '45383', '8801302', '宮崎県', 'ミヤザキケン', '東諸県郡綾町', 'ヒガシモロカタグンアヤチョウ', '北俣', 'キタマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県東諸県郡綾町南俣', '45', '45383', '8801303', '宮崎県', 'ミヤザキケン', '東諸県郡綾町', 'ヒガシモロカタグンアヤチョウ', '南俣', 'ミナミマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市音別町ノトロ', '01', '01206', '0880131', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '音別町ノトロ', 'オンベツチョウノトロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市音別町尺別岐線', '01', '01206', '0880132', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '音別町尺別', 'オンベツチョウシャクベツ', null, null, '岐線', 'キセン');
INSERT INTO `ms_addresses` VALUES ('115241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市音別町尺別', '01', '01206', '0880133', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '音別町尺別', 'オンベツチョウシャクベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市音別町キナシ別', '01', '01206', '0880134', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '音別町キナシ別', 'オンベツチョウキナシベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路市音別町直別', '01', '01206', '0880135', '北海道', 'ホッカイドウ', '釧路市', 'クシロシ', '音別町直別', 'オンベツチョウチョクベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道十勝郡浦幌町直別', '01', '01649', '0880181', '北海道', 'ホッカイドウ', '十勝郡浦幌町', 'トカチグンウラホロチョウ', '直別', 'チョクベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市跡江', '45', '45201', '8802101', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '跡江', 'アトエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市有田', '45', '45201', '8802102', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '有田', 'アリタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市生目', '45', '45201', '8802103', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '生目', 'イキメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市浮田', '45', '45201', '8802104', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '浮田', 'ウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市大塚台西', '45', '45201', '8802105', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '大塚台西', 'オオツカダイニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市柏原', '45', '45201', '8802111', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '柏原', 'カシワバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市小松', '45', '45201', '8802112', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '小松', 'コマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市小松台北町', '45', '45201', '8802113', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '小松台北町', 'コマツダイキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市富吉', '45', '45201', '8802114', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '富吉', 'トミヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市長嶺', '45', '45201', '8802115', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '長嶺', 'ナガミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市細江', '45', '45201', '8802116', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '細江', 'ホソエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市高岡町花見', '45', '45201', '8802211', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '高岡町花見', 'タカオカチョウハナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市高岡町下倉永', '45', '45201', '8802212', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '高岡町下倉永', 'タカオカチョウシモクラナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市高岡町上倉永', '45', '45201', '8802213', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '高岡町上倉永', 'タカオカチョウカミクラナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市高岡町小山田', '45', '45201', '8802214', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '高岡町小山田', 'タカオカチョウオヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市高岡町高浜', '45', '45201', '8802215', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '高岡町高浜', 'タカオカチョウタカハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市高岡町内山', '45', '45201', '8802221', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '高岡町内山', 'タカオカチョウウチヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市高岡町五町', '45', '45201', '8802222', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '高岡町五町', 'タカオカチョウゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市高岡町浦之名', '45', '45201', '8802223', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '高岡町浦之名', 'タカオカチョウウラノミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市高岡町飯田', '45', '45201', '8802224', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '高岡町飯田', 'タカオカチョウイイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市糸原', '45', '45201', '8802231', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '糸原', 'イトバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市堤内', '45', '45201', '8802232', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '堤内', 'ツツミウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市吉野', '45', '45201', '8802233', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '吉野', 'ヨシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市金崎', '45', '45201', '8802234', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '金崎', 'カネザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県都城市山之口町山之口上平野', '45', '45202', '8802303', '宮崎県', 'ミヤザキケン', '都城市', 'ミヤコノジョウシ', '山之口町山之口', 'ヤマノクチチョウヤマノクチ', null, null, '上平野', 'カミヒラノ');
INSERT INTO `ms_addresses` VALUES ('115277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県都城市山之口町山之口仲田', '45', '45202', '8802303', '宮崎県', 'ミヤザキケン', '都城市', 'ミヤコノジョウシ', '山之口町山之口', 'ヤマノクチチョウヤマノクチ', null, null, '仲田', 'ナカタ');
INSERT INTO `ms_addresses` VALUES ('115278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市高岡町内山', '45', '45201', '8802321', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '高岡町内山', 'タカオカチョウウチヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市高岡町五町', '45', '45201', '8802322', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '高岡町五町', 'タカオカチョウゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市高岡町浦之名', '45', '45201', '8802323', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '高岡町浦之名', 'タカオカチョウウラノミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市高岡町紙屋', '45', '45201', '8802325', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '高岡町紙屋', 'タカオカチョウカミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道白糠郡白糠町', '01', '01668', '0880300', '北海道', 'ホッカイドウ', '白糠郡白糠町', 'シラヌカグンシラヌカチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('115283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道白糠郡白糠町東1条南', '01', '01668', '0880301', '北海道', 'ホッカイドウ', '白糠郡白糠町', 'シラヌカグンシラヌカチョウ', '東1条南', 'ヒガシ01ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道白糠郡白糠町東2条南', '01', '01668', '0880302', '北海道', 'ホッカイドウ', '白糠郡白糠町', 'シラヌカグンシラヌカチョウ', '東2条南', 'ヒガシ02ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道白糠郡白糠町東3条南', '01', '01668', '0880303', '北海道', 'ホッカイドウ', '白糠郡白糠町', 'シラヌカグンシラヌカチョウ', '東3条南', 'ヒガシ03ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道白糠郡白糠町岬', '01', '01668', '0880304', '北海道', 'ホッカイドウ', '白糠郡白糠町', 'シラヌカグンシラヌカチョウ', '岬', 'ミサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道白糠郡白糠町刺牛', '01', '01668', '0880305', '北海道', 'ホッカイドウ', '白糠郡白糠町', 'シラヌカグンシラヌカチョウ', '刺牛', 'サシウシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道白糠郡白糠町西1条南', '01', '01668', '0880311', '北海道', 'ホッカイドウ', '白糠郡白糠町', 'シラヌカグンシラヌカチョウ', '西1条南', 'ニシ01ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道白糠郡白糠町西2条南', '01', '01668', '0880312', '北海道', 'ホッカイドウ', '白糠郡白糠町', 'シラヌカグンシラヌカチョウ', '西2条南', 'ニシ02ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道白糠郡白糠町西1条北', '01', '01668', '0880321', '北海道', 'ホッカイドウ', '白糠郡白糠町', 'シラヌカグンシラヌカチョウ', '西1条北', 'ニシ01ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道白糠郡白糠町西2条北', '01', '01668', '0880322', '北海道', 'ホッカイドウ', '白糠郡白糠町', 'シラヌカグンシラヌカチョウ', '西2条北', 'ニシ02ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道白糠郡白糠町西4条北', '01', '01668', '0880323', '北海道', 'ホッカイドウ', '白糠郡白糠町', 'シラヌカグンシラヌカチョウ', '西4条北', 'ニシ04ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道白糠郡白糠町西5条北', '01', '01668', '0880324', '北海道', 'ホッカイドウ', '白糠郡白糠町', 'シラヌカグンシラヌカチョウ', '西5条北', 'ニシ05ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道白糠郡白糠町東1条北', '01', '01668', '0880331', '北海道', 'ホッカイドウ', '白糠郡白糠町', 'シラヌカグンシラヌカチョウ', '東1条北', 'ヒガシ01ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道白糠郡白糠町東2条北', '01', '01668', '0880332', '北海道', 'ホッカイドウ', '白糠郡白糠町', 'シラヌカグンシラヌカチョウ', '東2条北', 'ヒガシ02ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道白糠郡白糠町東3条北', '01', '01668', '0880333', '北海道', 'ホッカイドウ', '白糠郡白糠町', 'シラヌカグンシラヌカチョウ', '東3条北', 'ヒガシ03ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道白糠郡白糠町大苗', '01', '01668', '0880341', '北海道', 'ホッカイドウ', '白糠郡白糠町', 'シラヌカグンシラヌカチョウ', '大苗', 'オオナエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道白糠郡白糠町下茶路', '01', '01668', '0880341', '北海道', 'ホッカイドウ', '白糠郡白糠町', 'シラヌカグンシラヌカチョウ', '下茶路', 'シモチャロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道白糠郡白糠町相互', '01', '01668', '0880341', '北海道', 'ホッカイドウ', '白糠郡白糠町', 'シラヌカグンシラヌカチョウ', '相互', 'ソウゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道白糠郡白糠町西茶路', '01', '01668', '0880341', '北海道', 'ホッカイドウ', '白糠郡白糠町', 'シラヌカグンシラヌカチョウ', '西茶路', 'ニシチャロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道白糠郡白糠町東茶路', '01', '01668', '0880341', '北海道', 'ホッカイドウ', '白糠郡白糠町', 'シラヌカグンシラヌカチョウ', '東茶路', 'ヒガシチャロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道白糠郡白糠町御札部', '01', '01668', '0880342', '北海道', 'ホッカイドウ', '白糠郡白糠町', 'シラヌカグンシラヌカチョウ', '御札部', 'オサッペ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道白糠郡白糠町御仁田', '01', '01668', '0880342', '北海道', 'ホッカイドウ', '白糠郡白糠町', 'シラヌカグンシラヌカチョウ', '御仁田', 'オニタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道白糠郡白糠町川西', '01', '01668', '0880342', '北海道', 'ホッカイドウ', '白糠郡白糠町', 'シラヌカグンシラヌカチョウ', '川西', 'カワニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道白糠郡白糠町高台', '01', '01668', '0880342', '北海道', 'ホッカイドウ', '白糠郡白糠町', 'シラヌカグンシラヌカチョウ', '高台', 'タカダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道白糠郡白糠町鍛高', '01', '01668', '0880342', '北海道', 'ホッカイドウ', '白糠郡白糠町', 'シラヌカグンシラヌカチョウ', '鍛高', 'タンタカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道白糠郡白糠町茶路共栄', '01', '01668', '0880342', '北海道', 'ホッカイドウ', '白糠郡白糠町', 'シラヌカグンシラヌカチョウ', '茶路', 'チャロ', null, null, '共栄', 'キョウエイ');
INSERT INTO `ms_addresses` VALUES ('115308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道白糠郡白糠町中茶路', '01', '01668', '0880342', '北海道', 'ホッカイドウ', '白糠郡白糠町', 'シラヌカグンシラヌカチョウ', '中茶路', 'ナカチャロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道白糠郡白糠町松川', '01', '01668', '0880342', '北海道', 'ホッカイドウ', '白糠郡白糠町', 'シラヌカグンシラヌカチョウ', '松川', 'マツカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道白糠郡白糠町上茶路', '01', '01668', '0880343', '北海道', 'ホッカイドウ', '白糠郡白糠町', 'シラヌカグンシラヌカチョウ', '上茶路', 'カミチャロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道白糠郡白糠町新縫別', '01', '01668', '0880343', '北海道', 'ホッカイドウ', '白糠郡白糠町', 'シラヌカグンシラヌカチョウ', '新縫別', 'シンヌイベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道白糠郡白糠町縫別', '01', '01668', '0880343', '北海道', 'ホッカイドウ', '白糠郡白糠町', 'シラヌカグンシラヌカチョウ', '縫別', 'ヌイベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道白糠郡白糠町南大曲', '01', '01668', '0880343', '北海道', 'ホッカイドウ', '白糠郡白糠町', 'シラヌカグンシラヌカチョウ', '南大曲', 'ミナミオオマガリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道白糠郡白糠町南上茶路', '01', '01668', '0880343', '北海道', 'ホッカイドウ', '白糠郡白糠町', 'シラヌカグンシラヌカチョウ', '南上茶路', 'ミナミカミチャロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道白糠郡白糠町左股', '01', '01668', '0880344', '北海道', 'ホッカイドウ', '白糠郡白糠町', 'シラヌカグンシラヌカチョウ', '左股', 'ヒダリマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道白糠郡白糠町二股', '01', '01668', '0880344', '北海道', 'ホッカイドウ', '白糠郡白糠町', 'シラヌカグンシラヌカチョウ', '二股', 'フタマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道白糠郡白糠町右股', '01', '01668', '0880344', '北海道', 'ホッカイドウ', '白糠郡白糠町', 'シラヌカグンシラヌカチョウ', '右股', 'ミギマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道白糠郡白糠町橋西', '01', '01668', '0880351', '北海道', 'ホッカイドウ', '白糠郡白糠町', 'シラヌカグンシラヌカチョウ', '橋西', 'キョウセイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道白糠郡白糠町坂の丘', '01', '01668', '0880351', '北海道', 'ホッカイドウ', '白糠郡白糠町', 'シラヌカグンシラヌカチョウ', '坂の丘', 'サカノオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道白糠郡白糠町下和天別', '01', '01668', '0880351', '北海道', 'ホッカイドウ', '白糠郡白糠町', 'シラヌカグンシラヌカチョウ', '下和天別', 'シモワテンベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道白糠郡白糠町和天別', '01', '01668', '0880351', '北海道', 'ホッカイドウ', '白糠郡白糠町', 'シラヌカグンシラヌカチョウ', '和天別', 'ワテンベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道白糠郡白糠町川島', '01', '01668', '0880352', '北海道', 'ホッカイドウ', '白糠郡白糠町', 'シラヌカグンシラヌカチョウ', '川島', 'カワシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道白糠郡白糠町大秋', '01', '01668', '0880352', '北海道', 'ホッカイドウ', '白糠郡白糠町', 'シラヌカグンシラヌカチョウ', '大秋', 'タイシュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道白糠郡白糠町馬主来', '01', '01668', '0880352', '北海道', 'ホッカイドウ', '白糠郡白糠町', 'シラヌカグンシラヌカチョウ', '馬主来', 'パシクル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道白糠郡白糠町緑', '01', '01668', '0880352', '北海道', 'ホッカイドウ', '白糠郡白糠町', 'シラヌカグンシラヌカチョウ', '緑', 'ミドリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道白糠郡白糠町大沢', '01', '01668', '0880353', '北海道', 'ホッカイドウ', '白糠郡白糠町', 'シラヌカグンシラヌカチョウ', '大沢', 'オオサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道白糠郡白糠町大平', '01', '01668', '0880353', '北海道', 'ホッカイドウ', '白糠郡白糠町', 'シラヌカグンシラヌカチョウ', '大平', 'オオヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道白糠郡白糠町河原', '01', '01668', '0880353', '北海道', 'ホッカイドウ', '白糠郡白糠町', 'シラヌカグンシラヌカチョウ', '河原', 'カワハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道白糠郡白糠町恋隠', '01', '01668', '0880353', '北海道', 'ホッカイドウ', '白糠郡白糠町', 'シラヌカグンシラヌカチョウ', '恋隠', 'コイカクシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道白糠郡白糠町中和天別', '01', '01668', '0880353', '北海道', 'ホッカイドウ', '白糠郡白糠町', 'シラヌカグンシラヌカチョウ', '中和天別', 'ナカワテンベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道白糠郡白糠町本郷', '01', '01668', '0880353', '北海道', 'ホッカイドウ', '白糠郡白糠町', 'シラヌカグンシラヌカチョウ', '本郷', 'ホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道白糠郡白糠町大楽毛', '01', '01668', '0880561', '北海道', 'ホッカイドウ', '白糠郡白糠町', 'シラヌカグンシラヌカチョウ', '大楽毛', 'オタノシケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道白糠郡白糠町コイトイ', '01', '01668', '0880562', '北海道', 'ホッカイドウ', '白糠郡白糠町', 'シラヌカグンシラヌカチョウ', 'コイトイ', 'コイトイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道白糠郡白糠町庶路甲区', '01', '01668', '0880563', '北海道', 'ホッカイドウ', '白糠郡白糠町', 'シラヌカグンシラヌカチョウ', '庶路甲区', 'ショロコウク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道白糠郡白糠町庶路1区', '01', '01668', '0880564', '北海道', 'ホッカイドウ', '白糠郡白糠町', 'シラヌカグンシラヌカチョウ', '庶路', 'ショロ', null, null, '1区', '01ク');
INSERT INTO `ms_addresses` VALUES ('115340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道白糠郡白糠町庶路2区', '01', '01668', '0880565', '北海道', 'ホッカイドウ', '白糠郡白糠町', 'シラヌカグンシラヌカチョウ', '庶路', 'ショロ', null, null, '2区', '02ク');
INSERT INTO `ms_addresses` VALUES ('115341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道白糠郡白糠町庶路宮下', '01', '01668', '0880566', '北海道', 'ホッカイドウ', '白糠郡白糠町', 'シラヌカグンシラヌカチョウ', '庶路', 'ショロ', null, null, '宮下', 'ミヤシタ');
INSERT INTO `ms_addresses` VALUES ('115342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道白糠郡白糠町庶路', '01', '01668', '0880567', '北海道', 'ホッカイドウ', '白糠郡白糠町', 'シラヌカグンシラヌカチョウ', '庶路', 'ショロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道白糠郡白糠町庶路乙区', '01', '01668', '0880568', '北海道', 'ホッカイドウ', '白糠郡白糠町', 'シラヌカグンシラヌカチョウ', '庶路乙区', 'ショロオツク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道白糠郡白糠町西庶路西1条北', '01', '01668', '0880571', '北海道', 'ホッカイドウ', '白糠郡白糠町', 'シラヌカグンシラヌカチョウ', '西庶路西1条北', 'ニシショロニシ01ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道白糠郡白糠町西庶路西2条北', '01', '01668', '0880571', '北海道', 'ホッカイドウ', '白糠郡白糠町', 'シラヌカグンシラヌカチョウ', '西庶路西2条北', 'ニシショロニシ02ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道白糠郡白糠町西庶路西3条北', '01', '01668', '0880571', '北海道', 'ホッカイドウ', '白糠郡白糠町', 'シラヌカグンシラヌカチョウ', '西庶路西3条北', 'ニシショロニシ03ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道白糠郡白糠町西庶路西1条南', '01', '01668', '0880572', '北海道', 'ホッカイドウ', '白糠郡白糠町', 'シラヌカグンシラヌカチョウ', '西庶路西1条南', 'ニシショロニシ01ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道白糠郡白糠町西庶路西2条南', '01', '01668', '0880572', '北海道', 'ホッカイドウ', '白糠郡白糠町', 'シラヌカグンシラヌカチョウ', '西庶路西2条南', 'ニシショロニシ02ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道白糠郡白糠町西庶路西3条南', '01', '01668', '0880572', '北海道', 'ホッカイドウ', '白糠郡白糠町', 'シラヌカグンシラヌカチョウ', '西庶路西3条南', 'ニシショロニシ03ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道白糠郡白糠町西庶路西4条南', '01', '01668', '0880572', '北海道', 'ホッカイドウ', '白糠郡白糠町', 'シラヌカグンシラヌカチョウ', '西庶路西4条南', 'ニシショロニシ04ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道白糠郡白糠町西庶路西5条南', '01', '01668', '0880572', '北海道', 'ホッカイドウ', '白糠郡白糠町', 'シラヌカグンシラヌカチョウ', '西庶路西5条南', 'ニシショロニシ05ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道白糠郡白糠町西庶路東1条北', '01', '01668', '0880573', '北海道', 'ホッカイドウ', '白糠郡白糠町', 'シラヌカグンシラヌカチョウ', '西庶路東1条北', 'ニシショロヒガシ01ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道白糠郡白糠町西庶路東2条北', '01', '01668', '0880573', '北海道', 'ホッカイドウ', '白糠郡白糠町', 'シラヌカグンシラヌカチョウ', '西庶路東2条北', 'ニシショロヒガシ02ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道白糠郡白糠町西庶路東3条北', '01', '01668', '0880573', '北海道', 'ホッカイドウ', '白糠郡白糠町', 'シラヌカグンシラヌカチョウ', '西庶路東3条北', 'ニシショロヒガシ03ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道白糠郡白糠町西庶路東1条南', '01', '01668', '0880574', '北海道', 'ホッカイドウ', '白糠郡白糠町', 'シラヌカグンシラヌカチョウ', '西庶路東1条南', 'ニシショロヒガシ01ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道白糠郡白糠町西庶路東2条南', '01', '01668', '0880574', '北海道', 'ホッカイドウ', '白糠郡白糠町', 'シラヌカグンシラヌカチョウ', '西庶路東2条南', 'ニシショロヒガシ02ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道白糠郡白糠町西庶路東3条南', '01', '01668', '0880574', '北海道', 'ホッカイドウ', '白糠郡白糠町', 'シラヌカグンシラヌカチョウ', '西庶路東3条南', 'ニシショロヒガシ03ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道白糠郡白糠町乳呑', '01', '01668', '0880581', '北海道', 'ホッカイドウ', '白糠郡白糠町', 'シラヌカグンシラヌカチョウ', '乳呑', 'チノミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道白糠郡白糠町中庶路', '01', '01668', '0880582', '北海道', 'ホッカイドウ', '白糠郡白糠町', 'シラヌカグンシラヌカチョウ', '中庶路', 'ナカショロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道白糠郡白糠町上庶路', '01', '01668', '0880583', '北海道', 'ホッカイドウ', '白糠郡白糠町', 'シラヌカグンシラヌカチョウ', '上庶路', 'カミショロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道白糠郡白糠町泊別', '01', '01668', '0880584', '北海道', 'ホッカイドウ', '白糠郡白糠町', 'シラヌカグンシラヌカチョウ', '泊別', 'トマリベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道白糠郡白糠町暁', '01', '01668', '0880585', '北海道', 'ホッカイドウ', '白糠郡白糠町', 'シラヌカグンシラヌカチョウ', '暁', 'アカツキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道白糠郡白糠町庶路東', '01', '01668', '0880586', '北海道', 'ホッカイドウ', '白糠郡白糠町', 'シラヌカグンシラヌカチョウ', '庶路東', 'ショロヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道白糠郡白糠町庶路西', '01', '01668', '0880587', '北海道', 'ホッカイドウ', '白糠郡白糠町', 'シラヌカグンシラヌカチョウ', '庶路西', 'ショロニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路郡釧路町', '01', '01661', '0880600', '北海道', 'ホッカイドウ', '釧路郡釧路町', 'クシログンクシロチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('115369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路郡釧路町上別保原野', '01', '01661', '0880601', '北海道', 'ホッカイドウ', '釧路郡釧路町', 'クシログンクシロチョウ', '上別保原野', 'カミベッポゲンヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路郡釧路町別保東', '01', '01661', '0880602', '北海道', 'ホッカイドウ', '釧路郡釧路町', 'クシログンクシロチョウ', '別保東', 'ベッポヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路郡釧路町別保南', '01', '01661', '0880603', '北海道', 'ホッカイドウ', '釧路郡釧路町', 'クシログンクシロチョウ', '別保南', 'ベッポミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路郡釧路町別保', '01', '01661', '0880604', '北海道', 'ホッカイドウ', '釧路郡釧路町', 'クシログンクシロチョウ', '別保', 'ベツホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路郡釧路町別保原野', '01', '01661', '0880605', '北海道', 'ホッカイドウ', '釧路郡釧路町', 'クシログンクシロチョウ', '別保原野', 'ベッポゲンヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路郡釧路町中央', '01', '01661', '0880606', '北海道', 'ホッカイドウ', '釧路郡釧路町', 'クシログンクシロチョウ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路郡釧路町床丹', '01', '01661', '0880607', '北海道', 'ホッカイドウ', '釧路郡釧路町', 'クシログンクシロチョウ', '床丹', 'トコタン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路郡釧路町釧望台', '01', '01661', '0880608', '北海道', 'ホッカイドウ', '釧路郡釧路町', 'クシログンクシロチョウ', '釧望台', 'センボウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路郡釧路町共和', '01', '01661', '0880609', '北海道', 'ホッカイドウ', '釧路郡釧路町', 'クシログンクシロチョウ', '共和', 'キョウワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路郡釧路町豊美', '01', '01661', '0880611', '北海道', 'ホッカイドウ', '釧路郡釧路町', 'クシログンクシロチョウ', '豊美', 'トヨミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路郡釧路町雁来', '01', '01661', '0880612', '北海道', 'ホッカイドウ', '釧路郡釧路町', 'クシログンクシロチョウ', '雁来', 'カリキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路郡釧路町若葉', '01', '01661', '0880613', '北海道', 'ホッカイドウ', '釧路郡釧路町', 'クシログンクシロチョウ', '若葉', 'ワカバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路郡釧路町国誉', '01', '01661', '0880614', '北海道', 'ホッカイドウ', '釧路郡釧路町', 'クシログンクシロチョウ', '国誉', 'コクヨ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路郡釧路町睦', '01', '01661', '0880615', '北海道', 'ホッカイドウ', '釧路郡釧路町', 'クシログンクシロチョウ', '睦', 'ムツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路郡釧路町曙', '01', '01661', '0880616', '北海道', 'ホッカイドウ', '釧路郡釧路町', 'クシログンクシロチョウ', '曙', 'アケボノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路郡釧路町北都', '01', '01661', '0880617', '北海道', 'ホッカイドウ', '釧路郡釧路町', 'クシログンクシロチョウ', '北都', 'ホクト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路郡釧路町富原', '01', '01661', '0880618', '北海道', 'ホッカイドウ', '釧路郡釧路町', 'クシログンクシロチョウ', '富原', 'トミハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路郡釧路町桂木', '01', '01661', '0880621', '北海道', 'ホッカイドウ', '釧路郡釧路町', 'クシログンクシロチョウ', '桂木', 'カツラギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路郡釧路町木場', '01', '01661', '0880622', '北海道', 'ホッカイドウ', '釧路郡釧路町', 'クシログンクシロチョウ', '木場', 'キバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路郡釧路町光和', '01', '01661', '0880623', '北海道', 'ホッカイドウ', '釧路郡釧路町', 'クシログンクシロチョウ', '光和', 'コウワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路郡釧路町新開', '01', '01661', '0880624', '北海道', 'ホッカイドウ', '釧路郡釧路町', 'クシログンクシロチョウ', '新開', 'シンカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路郡釧路町北見団地', '01', '01661', '0880625', '北海道', 'ホッカイドウ', '釧路郡釧路町', 'クシログンクシロチョウ', '北見団地', 'キタミダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路郡釧路町桂', '01', '01661', '0880626', '北海道', 'ホッカイドウ', '釧路郡釧路町', 'クシログンクシロチョウ', '桂', 'カツラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路郡釧路町東陽西', '01', '01661', '0880627', '北海道', 'ホッカイドウ', '釧路郡釧路町', 'クシログンクシロチョウ', '東陽西', 'トウヨウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路郡釧路町東陽大通西', '01', '01661', '0880628', '北海道', 'ホッカイドウ', '釧路郡釧路町', 'クシログンクシロチョウ', '東陽大通西', 'トウヨウオオドオリニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡厚岸町上尾幌', '01', '01662', '0880771', '北海道', 'ホッカイドウ', '厚岸郡厚岸町', 'アッケシグンアッケシチョウ', '上尾幌', 'カミオボロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路郡釧路町仙鳳趾村仙鳳趾', '01', '01661', '0880831', '北海道', 'ホッカイドウ', '釧路郡釧路町', 'クシログンクシロチョウ', '仙鳳趾村', 'センポウシムラ', null, null, '仙鳳趾', 'センポウシ');
INSERT INTO `ms_addresses` VALUES ('115397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路郡釧路町仙鳳趾村知方学', '01', '01661', '0880832', '北海道', 'ホッカイドウ', '釧路郡釧路町', 'クシログンクシロチョウ', '仙鳳趾村', 'センポウシムラ', null, null, '知方学', 'チッポマナイ');
INSERT INTO `ms_addresses` VALUES ('115398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路郡釧路町仙鳳趾村老者舞', '01', '01661', '0880833', '北海道', 'ホッカイドウ', '釧路郡釧路町', 'クシログンクシロチョウ', '仙鳳趾村', 'センポウシムラ', null, null, '老者舞', 'オシャマップ');
INSERT INTO `ms_addresses` VALUES ('115399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路郡釧路町仙鳳趾村汐見', '01', '01661', '0880834', '北海道', 'ホッカイドウ', '釧路郡釧路町', 'クシログンクシロチョウ', '仙鳳趾村', 'センポウシムラ', null, null, '汐見', 'シオミ');
INSERT INTO `ms_addresses` VALUES ('115400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路郡釧路町仙鳳趾村オタクパウシ', '01', '01661', '0880835', '北海道', 'ホッカイドウ', '釧路郡釧路町', 'クシログンクシロチョウ', '仙鳳趾村', 'センポウシムラ', null, null, 'オタクパウシ', 'オタクパウシ');
INSERT INTO `ms_addresses` VALUES ('115463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡厚岸町尾幌', '01', '01662', '0880871', '北海道', 'ホッカイドウ', '厚岸郡厚岸町', 'アッケシグンアッケシチョウ', '尾幌', 'オボロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡厚岸町来別', '01', '01662', '0880872', '北海道', 'ホッカイドウ', '厚岸郡厚岸町', 'アッケシグンアッケシチョウ', '来別', 'ライベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡厚岸町乙幌', '01', '01662', '0880873', '北海道', 'ホッカイドウ', '厚岸郡厚岸町', 'アッケシグンアッケシチョウ', '乙幌', 'オッポロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡厚岸町門静4丁目', '01', '01662', '0880874', '北海道', 'ホッカイドウ', '厚岸郡厚岸町', 'アッケシグンアッケシチョウ', '門静', 'モンシズ', null, null, '4丁目', '04チョウメ');
INSERT INTO `ms_addresses` VALUES ('115468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡厚岸町苫多', '01', '01662', '0880875', '北海道', 'ホッカイドウ', '厚岸郡厚岸町', 'アッケシグンアッケシチョウ', '苫多', 'トマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡厚岸町沖万別', '01', '01662', '0880876', '北海道', 'ホッカイドウ', '厚岸郡厚岸町', 'アッケシグンアッケシチョウ', '沖万別', 'オキマンベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡厚岸町敏内', '01', '01662', '0880877', '北海道', 'ホッカイドウ', '厚岸郡厚岸町', 'アッケシグンアッケシチョウ', '敏内', 'ビンナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡厚岸町ルークシュポール', '01', '01662', '0880878', '北海道', 'ホッカイドウ', '厚岸郡厚岸町', 'アッケシグンアッケシチョウ', 'ルークシュポール', 'ルークシュポール', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県西都市', '45', '45208', '8810000', '宮崎県', 'ミヤザキケン', '西都市', 'サイトシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('115473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県西都市岡富', '45', '45208', '8810001', '宮崎県', 'ミヤザキケン', '西都市', 'サイトシ', '岡富', 'オカドミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県西都市黒生野', '45', '45208', '8810002', '宮崎県', 'ミヤザキケン', '西都市', 'サイトシ', '黒生野', 'クロウノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県西都市右松', '45', '45208', '8810003', '宮崎県', 'ミヤザキケン', '西都市', 'サイトシ', '右松', 'ミギマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県西都市清水', '45', '45208', '8810004', '宮崎県', 'ミヤザキケン', '西都市', 'サイトシ', '清水', 'キヨミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県西都市三宅', '45', '45208', '8810005', '宮崎県', 'ミヤザキケン', '西都市', 'サイトシ', '三宅', 'ミヤケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県西都市新町', '45', '45208', '8810006', '宮崎県', 'ミヤザキケン', '西都市', 'サイトシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県西都市有吉町', '45', '45208', '8810011', '宮崎県', 'ミヤザキケン', '西都市', 'サイトシ', '有吉町', 'アリヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県西都市小野崎', '45', '45208', '8810012', '宮崎県', 'ミヤザキケン', '西都市', 'サイトシ', '小野崎', 'オノザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県西都市小野崎町', '45', '45208', '8810013', '宮崎県', 'ミヤザキケン', '西都市', 'サイトシ', '小野崎町', 'オノザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県西都市下妻', '45', '45208', '8810014', '宮崎県', 'ミヤザキケン', '西都市', 'サイトシ', '下妻', 'シモヅマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県西都市聖陵町', '45', '45208', '8810015', '宮崎県', 'ミヤザキケン', '西都市', 'サイトシ', '聖陵町', 'セイリョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県西都市御舟町', '45', '45208', '8810016', '宮崎県', 'ミヤザキケン', '西都市', 'サイトシ', '御舟町', 'ミフネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県西都市上町', '45', '45208', '8810021', '宮崎県', 'ミヤザキケン', '西都市', 'サイトシ', '上町', 'カミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県西都市桜川町', '45', '45208', '8810022', '宮崎県', 'ミヤザキケン', '西都市', 'サイトシ', '桜川町', 'サクラガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県西都市調殿', '45', '45208', '8810023', '宮崎県', 'ミヤザキケン', '西都市', 'サイトシ', '調殿', 'ツキドノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県西都市中妻', '45', '45208', '8810024', '宮崎県', 'ミヤザキケン', '西都市', 'サイトシ', '中妻', 'ナカヅマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県西都市童子丸', '45', '45208', '8810025', '宮崎県', 'ミヤザキケン', '西都市', 'サイトシ', '童子丸', 'ドウジマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県西都市穂北', '45', '45208', '8810026', '宮崎県', 'ミヤザキケン', '西都市', 'サイトシ', '穂北', 'ホキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県西都市南方', '45', '45208', '8810027', '宮崎県', 'ミヤザキケン', '西都市', 'サイトシ', '南方', 'ミナミカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県西都市旭', '45', '45208', '8810031', '宮崎県', 'ミヤザキケン', '西都市', 'サイトシ', '旭', 'アサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県西都市白馬町', '45', '45208', '8810032', '宮崎県', 'ミヤザキケン', '西都市', 'サイトシ', '白馬町', 'シラウマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県西都市妻', '45', '45208', '8810033', '宮崎県', 'ミヤザキケン', '西都市', 'サイトシ', '妻', 'ツマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県西都市妻町', '45', '45208', '8810034', '宮崎県', 'ミヤザキケン', '西都市', 'サイトシ', '妻町', 'ツマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県西都市中央町', '45', '45208', '8810035', '宮崎県', 'ミヤザキケン', '西都市', 'サイトシ', '中央町', 'チュウオウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県西都市水流崎町', '45', '45208', '8810036', '宮崎県', 'ミヤザキケン', '西都市', 'サイトシ', '水流崎町', 'ツルサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県西都市茶臼原', '45', '45208', '8810037', '宮崎県', 'ミヤザキケン', '西都市', 'サイトシ', '茶臼原', 'チャウスバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県西都市三納', '45', '45208', '8810101', '宮崎県', 'ミヤザキケン', '西都市', 'サイトシ', '三納', 'ミノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県西都市平郡', '45', '45208', '8810102', '宮崎県', 'ミヤザキケン', '西都市', 'サイトシ', '平郡', 'ヘゴオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県西都市加勢', '45', '45208', '8810103', '宮崎県', 'ミヤザキケン', '西都市', 'サイトシ', '加勢', 'カゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県西都市鹿野田', '45', '45208', '8810104', '宮崎県', 'ミヤザキケン', '西都市', 'サイトシ', '鹿野田', 'カノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県西都市都於郡町', '45', '45208', '8810105', '宮崎県', 'ミヤザキケン', '西都市', 'サイトシ', '都於郡町', 'トノコオリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県西都市岩爪', '45', '45208', '8810106', '宮崎県', 'ミヤザキケン', '西都市', 'サイトシ', '岩爪', 'イワヅメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県西都市荒武', '45', '45208', '8810111', '宮崎県', 'ミヤザキケン', '西都市', 'サイトシ', '荒武', 'アラタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県西都市山田', '45', '45208', '8810112', '宮崎県', 'ミヤザキケン', '西都市', 'サイトシ', '山田', 'ヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県西都市下三財', '45', '45208', '8810113', '宮崎県', 'ミヤザキケン', '西都市', 'サイトシ', '下三財', 'シモサンザイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県西都市藤田', '45', '45208', '8810114', '宮崎県', 'ミヤザキケン', '西都市', 'サイトシ', '藤田', 'トウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県西都市上三財', '45', '45208', '8810115', '宮崎県', 'ミヤザキケン', '西都市', 'サイトシ', '上三財', 'カミサンザイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県西都市寒川', '45', '45208', '8810116', '宮崎県', 'ミヤザキケン', '西都市', 'サイトシ', '寒川', 'サブカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡厚岸町', '01', '01662', '0881100', '北海道', 'ホッカイドウ', '厚岸郡厚岸町', 'アッケシグンアッケシチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('115512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡厚岸町糸魚沢', '01', '01662', '0881101', '北海道', 'ホッカイドウ', '厚岸郡厚岸町', 'アッケシグンアッケシチョウ', '糸魚沢', 'イトイザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡厚岸町神岩', '01', '01662', '0881101', '北海道', 'ホッカイドウ', '厚岸郡厚岸町', 'アッケシグンアッケシチョウ', '神岩', 'カムイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡厚岸町チライカリベツ', '01', '01662', '0881101', '北海道', 'ホッカイドウ', '厚岸郡厚岸町', 'アッケシグンアッケシチョウ', 'チライカリベツ', 'チライカリベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡厚岸町別寒辺牛', '01', '01662', '0881101', '北海道', 'ホッカイドウ', '厚岸郡厚岸町', 'アッケシグンアッケシチョウ', '別寒辺牛', 'ベカンベウシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡厚岸町ホロニタイ', '01', '01662', '0881101', '北海道', 'ホッカイドウ', '厚岸郡厚岸町', 'アッケシグンアッケシチョウ', 'ホロニタイ', 'ホロニタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡厚岸町若松', '01', '01662', '0881101', '北海道', 'ホッカイドウ', '厚岸郡厚岸町', 'アッケシグンアッケシチョウ', '若松', 'ワカマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡厚岸町登喜岱', '01', '01662', '0881102', '北海道', 'ホッカイドウ', '厚岸郡厚岸町', 'アッケシグンアッケシチョウ', '登喜岱', 'トキタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡厚岸町小島', '01', '01662', '0881103', '北海道', 'ホッカイドウ', '厚岸郡厚岸町', 'アッケシグンアッケシチョウ', '小島', 'コジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡厚岸町大黒島', '01', '01662', '0881104', '北海道', 'ホッカイドウ', '厚岸郡厚岸町', 'アッケシグンアッケシチョウ', '大黒島', 'ダイコクジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡厚岸町末広', '01', '01662', '0881105', '北海道', 'ホッカイドウ', '厚岸郡厚岸町', 'アッケシグンアッケシチョウ', '末広', 'マビロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡厚岸町東梅', '01', '01662', '0881106', '北海道', 'ホッカイドウ', '厚岸郡厚岸町', 'アッケシグンアッケシチョウ', '東梅', 'トウバイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡厚岸町床潭', '01', '01662', '0881107', '北海道', 'ホッカイドウ', '厚岸郡厚岸町', 'アッケシグンアッケシチョウ', '床潭', 'トコタン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡厚岸町筑紫恋', '01', '01662', '0881108', '北海道', 'ホッカイドウ', '厚岸郡厚岸町', 'アッケシグンアッケシチョウ', '筑紫恋', 'ツクシコイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡厚岸町奔渡', '01', '01662', '0881111', '北海道', 'ホッカイドウ', '厚岸郡厚岸町', 'アッケシグンアッケシチョウ', '奔渡', 'ポント', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡厚岸町有明', '01', '01662', '0881112', '北海道', 'ホッカイドウ', '厚岸郡厚岸町', 'アッケシグンアッケシチョウ', '有明', 'アリアケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県西都市尾八重', '45', '45208', '8811121', '宮崎県', 'ミヤザキケン', '西都市', 'サイトシ', '尾八重', 'オハエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県西都市片内', '45', '45208', '8811122', '宮崎県', 'ミヤザキケン', '西都市', 'サイトシ', '片内', 'カタウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県西都市中尾', '45', '45208', '8811123', '宮崎県', 'ミヤザキケン', '西都市', 'サイトシ', '中尾', 'ナカオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡厚岸町愛冠', '01', '01662', '0881113', '北海道', 'ホッカイドウ', '厚岸郡厚岸町', 'アッケシグンアッケシチョウ', '愛冠', 'アイカップ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡厚岸町湾月町', '01', '01662', '0881114', '北海道', 'ホッカイドウ', '厚岸郡厚岸町', 'アッケシグンアッケシチョウ', '湾月町', 'ワンゲツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡厚岸町梅香町', '01', '01662', '0881115', '北海道', 'ホッカイドウ', '厚岸郡厚岸町', 'アッケシグンアッケシチョウ', '梅香町', 'バイカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡厚岸町松葉町', '01', '01662', '0881116', '北海道', 'ホッカイドウ', '厚岸郡厚岸町', 'アッケシグンアッケシチョウ', '松葉町', 'マツバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡厚岸町御供', '01', '01662', '0881117', '北海道', 'ホッカイドウ', '厚岸郡厚岸町', 'アッケシグンアッケシチョウ', '御供', 'オソナエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡厚岸町若竹町', '01', '01662', '0881118', '北海道', 'ホッカイドウ', '厚岸郡厚岸町', 'アッケシグンアッケシチョウ', '若竹町', 'ワカタケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡厚岸町住の江', '01', '01662', '0881119', '北海道', 'ホッカイドウ', '厚岸郡厚岸町', 'アッケシグンアッケシチョウ', '住の江', 'スミノエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡厚岸町山の手', '01', '01662', '0881120', '北海道', 'ホッカイドウ', '厚岸郡厚岸町', 'アッケシグンアッケシチョウ', '山の手', 'ヤマノテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県西都市上揚', '45', '45208', '8811231', '宮崎県', 'ミヤザキケン', '西都市', 'サイトシ', '上揚', 'カミアゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県西都市銀鏡', '45', '45208', '8811232', '宮崎県', 'ミヤザキケン', '西都市', 'サイトシ', '銀鏡', 'シロミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県西都市八重', '45', '45208', '8811233', '宮崎県', 'ミヤザキケン', '西都市', 'サイトシ', '八重', 'ハエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡厚岸町宮園', '01', '01662', '0881124', '北海道', 'ホッカイドウ', '厚岸郡厚岸町', 'アッケシグンアッケシチョウ', '宮園', 'ミヤゾノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡厚岸町白浜', '01', '01662', '0881125', '北海道', 'ホッカイドウ', '厚岸郡厚岸町', 'アッケシグンアッケシチョウ', '白浜', 'シラハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡厚岸町門静', '01', '01662', '0881126', '北海道', 'ホッカイドウ', '厚岸郡厚岸町', 'アッケシグンアッケシチョウ', '門静', 'モンシズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡厚岸町港町', '01', '01662', '0881128', '北海道', 'ホッカイドウ', '厚岸郡厚岸町', 'アッケシグンアッケシチョウ', '港町', 'ミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡厚岸町光栄', '01', '01662', '0881129', '北海道', 'ホッカイドウ', '厚岸郡厚岸町', 'アッケシグンアッケシチョウ', '光栄', 'コウエイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡厚岸町太田南', '01', '01662', '0881130', '北海道', 'ホッカイドウ', '厚岸郡厚岸町', 'アッケシグンアッケシチョウ', '太田南', 'オオタミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県児湯郡西米良村越野尾', '45', '45403', '8811301', '宮崎県', 'ミヤザキケン', '児湯郡西米良村', 'コユグンニシメラソン', '越野尾', 'コシノオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県児湯郡西米良村小川', '45', '45403', '8811302', '宮崎県', 'ミヤザキケン', '児湯郡西米良村', 'コユグンニシメラソン', '小川', 'オガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県児湯郡西米良村横野', '45', '45403', '8811303', '宮崎県', 'ミヤザキケン', '児湯郡西米良村', 'コユグンニシメラソン', '横野', 'ヨコノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡厚岸町太田', '01', '01662', '0881131', '北海道', 'ホッカイドウ', '厚岸郡厚岸町', 'アッケシグンアッケシチョウ', '太田', 'オオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡厚岸町太田東', '01', '01662', '0881132', '北海道', 'ホッカイドウ', '厚岸郡厚岸町', 'アッケシグンアッケシチョウ', '太田東', 'オオタヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡厚岸町太田宏陽', '01', '01662', '0881133', '北海道', 'ホッカイドウ', '厚岸郡厚岸町', 'アッケシグンアッケシチョウ', '太田宏陽', 'オオタコウヨウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡厚岸町太田西', '01', '01662', '0881134', '北海道', 'ホッカイドウ', '厚岸郡厚岸町', 'アッケシグンアッケシチョウ', '太田西', 'オオタニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡厚岸町太田北', '01', '01662', '0881135', '北海道', 'ホッカイドウ', '厚岸郡厚岸町', 'アッケシグンアッケシチョウ', '太田北', 'オオタキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡厚岸町大別', '01', '01662', '0881136', '北海道', 'ホッカイドウ', '厚岸郡厚岸町', 'アッケシグンアッケシチョウ', '大別', 'オオベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡厚岸町片無去', '01', '01662', '0881137', '北海道', 'ホッカイドウ', '厚岸郡厚岸町', 'アッケシグンアッケシチョウ', '片無去', 'カタムサリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡厚岸町セタニウシ', '01', '01662', '0881138', '北海道', 'ホッカイドウ', '厚岸郡厚岸町', 'アッケシグンアッケシチョウ', 'セタニウシ', 'セタニウシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡厚岸町サッテベツ', '01', '01662', '0881139', '北海道', 'ホッカイドウ', '厚岸郡厚岸町', 'アッケシグンアッケシチョウ', 'サッテベツ', 'サッテベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡厚岸町サンヌシ', '01', '01662', '0881140', '北海道', 'ホッカイドウ', '厚岸郡厚岸町', 'アッケシグンアッケシチョウ', 'サンヌシ', 'サンヌシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県児湯郡西米良村', '45', '45403', '8811400', '宮崎県', 'ミヤザキケン', '児湯郡西米良村', 'コユグンニシメラソン', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('115561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡厚岸町太田1の通り', '01', '01662', '0881141', '北海道', 'ホッカイドウ', '厚岸郡厚岸町', 'アッケシグンアッケシチョウ', '太田1の通り', 'オオタ01ノトオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県児湯郡西米良村村所', '45', '45403', '8811411', '宮崎県', 'ミヤザキケン', '児湯郡西米良村', 'コユグンニシメラソン', '村所', 'ムラショ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県児湯郡西米良村板谷', '45', '45403', '8811412', '宮崎県', 'ミヤザキケン', '児湯郡西米良村', 'コユグンニシメラソン', '板谷', 'イタヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県児湯郡西米良村上米良', '45', '45403', '8811413', '宮崎県', 'ミヤザキケン', '児湯郡西米良村', 'コユグンニシメラソン', '上米良', 'カンメラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県児湯郡西米良村竹原', '45', '45403', '8811414', '宮崎県', 'ミヤザキケン', '児湯郡西米良村', 'コユグンニシメラソン', '竹原', 'タケワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡厚岸町太田2の通り', '01', '01662', '0881142', '北海道', 'ホッカイドウ', '厚岸郡厚岸町', 'アッケシグンアッケシチョウ', '太田2の通り', 'オオタ02ノトオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡厚岸町太田3の通り', '01', '01662', '0881143', '北海道', 'ホッカイドウ', '厚岸郡厚岸町', 'アッケシグンアッケシチョウ', '太田3の通り', 'オオタ03ノトオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡厚岸町太田4の通り', '01', '01662', '0881144', '北海道', 'ホッカイドウ', '厚岸郡厚岸町', 'アッケシグンアッケシチョウ', '太田4の通り', 'オオタ04ノトオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡厚岸町太田5の通り', '01', '01662', '0881145', '北海道', 'ホッカイドウ', '厚岸郡厚岸町', 'アッケシグンアッケシチョウ', '太田5の通り', 'オオタ05ノトオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡厚岸町太田6の通り', '01', '01662', '0881146', '北海道', 'ホッカイドウ', '厚岸郡厚岸町', 'アッケシグンアッケシチョウ', '太田6の通り', 'オオタ06ノトオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡厚岸町太田7の通り', '01', '01662', '0881147', '北海道', 'ホッカイドウ', '厚岸郡厚岸町', 'アッケシグンアッケシチョウ', '太田7の通り', 'オオタ07ノトオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡厚岸町太田8の通り', '01', '01662', '0881148', '北海道', 'ホッカイドウ', '厚岸郡厚岸町', 'アッケシグンアッケシチョウ', '太田8の通り', 'オオタ08ノトオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡厚岸町太田9の通り', '01', '01662', '0881149', '北海道', 'ホッカイドウ', '厚岸郡厚岸町', 'アッケシグンアッケシチョウ', '太田9の通り', 'オオタ09ノトオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡厚岸町真栄', '01', '01662', '0881151', '北海道', 'ホッカイドウ', '厚岸郡厚岸町', 'アッケシグンアッケシチョウ', '真栄', 'シンエイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡浜中町一番沢', '01', '01663', '0881301', '北海道', 'ホッカイドウ', '厚岸郡浜中町', 'アッケシグンハマナカチョウ', '一番沢', 'イチバンサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡浜中町二番沢', '01', '01663', '0881302', '北海道', 'ホッカイドウ', '厚岸郡浜中町', 'アッケシグンハマナカチョウ', '二番沢', 'ニバンサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡浜中町三番沢', '01', '01663', '0881303', '北海道', 'ホッカイドウ', '厚岸郡浜中町', 'アッケシグンハマナカチョウ', '三番沢', 'サンバンサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡浜中町四番沢', '01', '01663', '0881304', '北海道', 'ホッカイドウ', '厚岸郡浜中町', 'アッケシグンハマナカチョウ', '四番沢', 'ヨバンサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡浜中町六番沢', '01', '01663', '0881306', '北海道', 'ホッカイドウ', '厚岸郡浜中町', 'アッケシグンハマナカチョウ', '六番沢', 'ロクバンサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡浜中町散布村北の沢', '01', '01663', '0881360', '北海道', 'ホッカイドウ', '厚岸郡浜中町', 'アッケシグンハマナカチョウ', '散布村', 'チリップムラ', null, null, '北の沢', 'キタノサワ');
INSERT INTO `ms_addresses` VALUES ('115586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡浜中町茶内緑', '01', '01663', '0881361', '北海道', 'ホッカイドウ', '厚岸郡浜中町', 'アッケシグンハマナカチョウ', '茶内緑', 'チャナイミドリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡浜中町茶内本町', '01', '01663', '0881362', '北海道', 'ホッカイドウ', '厚岸郡浜中町', 'アッケシグンハマナカチョウ', '茶内本町', 'チャナイモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡浜中町茶内栄', '01', '01663', '0881363', '北海道', 'ホッカイドウ', '厚岸郡浜中町', 'アッケシグンハマナカチョウ', '茶内栄', 'チャナイサカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡浜中町茶内若葉', '01', '01663', '0881364', '北海道', 'ホッカイドウ', '厚岸郡浜中町', 'アッケシグンハマナカチョウ', '茶内若葉', 'チャナイワカバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡浜中町茶内橋北東', '01', '01663', '0881365', '北海道', 'ホッカイドウ', '厚岸郡浜中町', 'アッケシグンハマナカチョウ', '茶内橋北東', 'チャナイキョウホクヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡浜中町茶内橋北西', '01', '01663', '0881366', '北海道', 'ホッカイドウ', '厚岸郡浜中町', 'アッケシグンハマナカチョウ', '茶内橋北西', 'チャナイキョウホクニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡浜中町茶内旭', '01', '01663', '0881367', '北海道', 'ホッカイドウ', '厚岸郡浜中町', 'アッケシグンハマナカチョウ', '茶内旭', 'チャナイアサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡浜中町茶内基線', '01', '01663', '0881368', '北海道', 'ホッカイドウ', '厚岸郡浜中町', 'アッケシグンハマナカチョウ', '茶内基線', 'チャナイキセン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡浜中町茶内東1線', '01', '01663', '0881368', '北海道', 'ホッカイドウ', '厚岸郡浜中町', 'アッケシグンハマナカチョウ', '茶内東1線', 'チャナイヒガシ01セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡浜中町茶内東2線', '01', '01663', '0881368', '北海道', 'ホッカイドウ', '厚岸郡浜中町', 'アッケシグンハマナカチョウ', '茶内東2線', 'チャナイヒガシ02セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡浜中町茶内西', '01', '01663', '0881369', '北海道', 'ホッカイドウ', '厚岸郡浜中町', 'アッケシグンハマナカチョウ', '茶内西', 'チャナイニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡浜中町西円朱別西', '01', '01663', '0881370', '北海道', 'ホッカイドウ', '厚岸郡浜中町', 'アッケシグンハマナカチョウ', '西円朱別西', 'ニシエンシュベツニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡浜中町円朱別西', '01', '01663', '0881371', '北海道', 'ホッカイドウ', '厚岸郡浜中町', 'アッケシグンハマナカチョウ', '円朱別西', 'エンシュベツニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡厚岸町トライベツ', '01', '01662', '0881389', '北海道', 'ホッカイドウ', '厚岸郡厚岸町', 'アッケシグンアッケシチョウ', 'トライベツ', 'トライベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡浜中町榊町', '01', '01663', '0881401', '北海道', 'ホッカイドウ', '厚岸郡浜中町', 'アッケシグンハマナカチョウ', '榊町', 'サカキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡浜中町後静', '01', '01663', '0881402', '北海道', 'ホッカイドウ', '厚岸郡浜中町', 'アッケシグンハマナカチョウ', '後静', 'シリシズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡浜中町横浜', '01', '01663', '0881402', '北海道', 'ホッカイドウ', '厚岸郡浜中町', 'アッケシグンハマナカチョウ', '横浜', 'ヨコハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡浜中町アザラップ', '01', '01663', '0881403', '北海道', 'ホッカイドウ', '厚岸郡浜中町', 'アッケシグンハマナカチョウ', 'アザラップ', 'アザラップ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡浜中町幌戸', '01', '01663', '0881403', '北海道', 'ホッカイドウ', '厚岸郡浜中町', 'アッケシグンハマナカチョウ', '幌戸', 'ポロト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡浜中町ムギカラシナイ', '01', '01663', '0881404', '北海道', 'ホッカイドウ', '厚岸郡浜中町', 'アッケシグンハマナカチョウ', 'ムギカラシナイ', 'ムギカラシナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡浜中町奔幌戸', '01', '01663', '0881405', '北海道', 'ホッカイドウ', '厚岸郡浜中町', 'アッケシグンハマナカチョウ', '奔幌戸', 'ポンポロト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡浜中町赤泊', '01', '01663', '0881406', '北海道', 'ホッカイドウ', '厚岸郡浜中町', 'アッケシグンハマナカチョウ', '赤泊', 'アカドマリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡浜中町羨古丹', '01', '01663', '0881406', '北海道', 'ホッカイドウ', '厚岸郡浜中町', 'アッケシグンハマナカチョウ', '羨古丹', 'ウラヤコタン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡浜中町榊町西', '01', '01663', '0881407', '北海道', 'ホッカイドウ', '厚岸郡浜中町', 'アッケシグンハマナカチョウ', '榊町西', 'サカキマチニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡浜中町大津屋沢', '01', '01663', '0881408', '北海道', 'ホッカイドウ', '厚岸郡浜中町', 'アッケシグンハマナカチョウ', '大津屋沢', 'オオツヤザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡浜中町走古潭', '01', '01663', '0881409', '北海道', 'ホッカイドウ', '厚岸郡浜中町', 'アッケシグンハマナカチョウ', '走古潭', 'ハシリコタン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡浜中町後静村熊牛原野', '01', '01663', '0881412', '北海道', 'ホッカイドウ', '厚岸郡浜中町', 'アッケシグンハマナカチョウ', '後静村', 'シリシズムラ', null, null, '熊牛原野', 'クマウシゲンヤ');
INSERT INTO `ms_addresses` VALUES ('115613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡浜中町浜中', '01', '01663', '0881485', '北海道', 'ホッカイドウ', '厚岸郡浜中町', 'アッケシグンハマナカチョウ', '浜中', 'ハマナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡浜中町熊牛', '01', '01663', '0881486', '北海道', 'ホッカイドウ', '厚岸郡浜中町', 'アッケシグンハマナカチョウ', '熊牛', 'クマウシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡浜中町茶内東3線', '01', '01663', '0881487', '北海道', 'ホッカイドウ', '厚岸郡浜中町', 'アッケシグンハマナカチョウ', '茶内東3線', 'チャナイヒガシ03セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡浜中町茶内東4線', '01', '01663', '0881487', '北海道', 'ホッカイドウ', '厚岸郡浜中町', 'アッケシグンハマナカチョウ', '茶内東4線', 'チャナイヒガシ04セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡浜中町茶内東5線', '01', '01663', '0881487', '北海道', 'ホッカイドウ', '厚岸郡浜中町', 'アッケシグンハマナカチョウ', '茶内東5線', 'チャナイヒガシ05セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡浜中町茶内東6線', '01', '01663', '0881487', '北海道', 'ホッカイドウ', '厚岸郡浜中町', 'アッケシグンハマナカチョウ', '茶内東6線', 'チャナイヒガシ06セン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡浜中町', '01', '01663', '0881500', '北海道', 'ホッカイドウ', '厚岸郡浜中町', 'アッケシグンハマナカチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('115620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡浜中町霧多布東1条', '01', '01663', '0881511', '北海道', 'ホッカイドウ', '厚岸郡浜中町', 'アッケシグンハマナカチョウ', '霧多布東1条', 'キリタップヒガシ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡浜中町霧多布東2条', '01', '01663', '0881512', '北海道', 'ホッカイドウ', '厚岸郡浜中町', 'アッケシグンハマナカチョウ', '霧多布東2条', 'キリタップヒガシ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡浜中町霧多布東3条', '01', '01663', '0881513', '北海道', 'ホッカイドウ', '厚岸郡浜中町', 'アッケシグンハマナカチョウ', '霧多布東3条', 'キリタップヒガシ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡浜中町霧多布東4条', '01', '01663', '0881514', '北海道', 'ホッカイドウ', '厚岸郡浜中町', 'アッケシグンハマナカチョウ', '霧多布東4条', 'キリタップヒガシ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡浜中町湯沸', '01', '01663', '0881522', '北海道', 'ホッカイドウ', '厚岸郡浜中町', 'アッケシグンハマナカチョウ', '湯沸', 'トウフツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡浜中町暮帰別東', '01', '01663', '0881524', '北海道', 'ホッカイドウ', '厚岸郡浜中町', 'アッケシグンハマナカチョウ', '暮帰別東', 'ボキベツヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡浜中町暮帰別西', '01', '01663', '0881525', '北海道', 'ホッカイドウ', '厚岸郡浜中町', 'アッケシグンハマナカチョウ', '暮帰別西', 'ボキベツニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡浜中町新川', '01', '01663', '0881526', '北海道', 'ホッカイドウ', '厚岸郡浜中町', 'アッケシグンハマナカチョウ', '新川', 'シンカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡浜中町新川東', '01', '01663', '0881527', '北海道', 'ホッカイドウ', '厚岸郡浜中町', 'アッケシグンハマナカチョウ', '新川東', 'シンカワヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡浜中町新川西', '01', '01663', '0881528', '北海道', 'ホッカイドウ', '厚岸郡浜中町', 'アッケシグンハマナカチョウ', '新川西', 'シンカワニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡浜中町仲の浜', '01', '01663', '0881531', '北海道', 'ホッカイドウ', '厚岸郡浜中町', 'アッケシグンハマナカチョウ', '仲の浜', 'ナカノハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡浜中町琵琶瀬', '01', '01663', '0881532', '北海道', 'ホッカイドウ', '厚岸郡浜中町', 'アッケシグンハマナカチョウ', '琵琶瀬', 'ビワセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡浜中町渡散布', '01', '01663', '0881534', '北海道', 'ホッカイドウ', '厚岸郡浜中町', 'アッケシグンハマナカチョウ', '渡散布', 'ワタリチリップ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡浜中町養老散布', '01', '01663', '0881535', '北海道', 'ホッカイドウ', '厚岸郡浜中町', 'アッケシグンハマナカチョウ', '養老散布', 'ヨウロウチリップ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡浜中町火散布', '01', '01663', '0881536', '北海道', 'ホッカイドウ', '厚岸郡浜中町', 'アッケシグンハマナカチョウ', '火散布', 'ヒチリップ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡浜中町丸山散布', '01', '01663', '0881537', '北海道', 'ホッカイドウ', '厚岸郡浜中町', 'アッケシグンハマナカチョウ', '丸山散布', 'マルヤマチリップ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡浜中町藻散布', '01', '01663', '0881538', '北海道', 'ホッカイドウ', '厚岸郡浜中町', 'アッケシグンハマナカチョウ', '藻散布', 'モチリップ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡浜中町霧多布西1条', '01', '01663', '0881551', '北海道', 'ホッカイドウ', '厚岸郡浜中町', 'アッケシグンハマナカチョウ', '霧多布西1条', 'キリタップニシ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡浜中町霧多布西2条', '01', '01663', '0881552', '北海道', 'ホッカイドウ', '厚岸郡浜中町', 'アッケシグンハマナカチョウ', '霧多布西2条', 'キリタップニシ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡浜中町霧多布西3条', '01', '01663', '0881553', '北海道', 'ホッカイドウ', '厚岸郡浜中町', 'アッケシグンハマナカチョウ', '霧多布西3条', 'キリタップニシ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡浜中町霧多布西4条', '01', '01663', '0881554', '北海道', 'ホッカイドウ', '厚岸郡浜中町', 'アッケシグンハマナカチョウ', '霧多布西4条', 'キリタップニシ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡浜中町霧多布湿原', '01', '01663', '0881561', '北海道', 'ホッカイドウ', '厚岸郡浜中町', 'アッケシグンハマナカチョウ', '霧多布湿原', 'キリタップシツゲン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡浜中町道有林', '01', '01663', '0881571', '北海道', 'ホッカイドウ', '厚岸郡浜中町', 'アッケシグンハマナカチョウ', '道有林', 'ドウユウリン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡浜中町貰人', '01', '01663', '0881643', '北海道', 'ホッカイドウ', '厚岸郡浜中町', 'アッケシグンハマナカチョウ', '貰人', 'モウライト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡浜中町恵茶人', '01', '01663', '0881644', '北海道', 'ホッカイドウ', '厚岸郡浜中町', 'アッケシグンハマナカチョウ', '恵茶人', 'エサシト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡浜中町仙鳳趾', '01', '01663', '0881645', '北海道', 'ホッカイドウ', '厚岸郡浜中町', 'アッケシグンハマナカチョウ', '仙鳳趾', 'センポウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡浜中町姉別', '01', '01663', '0881646', '北海道', 'ホッカイドウ', '厚岸郡浜中町', 'アッケシグンハマナカチョウ', '姉別', 'アネベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡浜中町姉別南', '01', '01663', '0881647', '北海道', 'ホッカイドウ', '厚岸郡浜中町', 'アッケシグンハマナカチョウ', '姉別南', 'アネベツミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡浜中町姉別北', '01', '01663', '0881648', '北海道', 'ホッカイドウ', '厚岸郡浜中町', 'アッケシグンハマナカチョウ', '姉別北', 'アネベツキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道厚岸郡浜中町姉別緑栄', '01', '01663', '0881649', '北海道', 'ホッカイドウ', '厚岸郡浜中町', 'アッケシグンハマナカチョウ', '姉別緑栄', 'アネベツリョクエイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道根室市落石西', '01', '01223', '0881781', '北海道', 'ホッカイドウ', '根室市', 'ネムロシ', '落石西', 'オチイシニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道根室市落石東', '01', '01223', '0881782', '北海道', 'ホッカイドウ', '根室市', 'ネムロシ', '落石東', 'オチイシヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道根室市浜松', '01', '01223', '0881783', '北海道', 'ホッカイドウ', '根室市', 'ネムロシ', '浜松', 'ハママツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道根室市昆布盛', '01', '01223', '0881784', '北海道', 'ホッカイドウ', '根室市', 'ネムロシ', '昆布盛', 'コンブモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道根室市長節', '01', '01223', '0881785', '北海道', 'ホッカイドウ', '根室市', 'ネムロシ', '長節', 'チョウブシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市', '45', '45203', '8820000', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('115659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市大峡町', '45', '45203', '8820001', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '大峡町', 'オオカイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市差木野町', '45', '45203', '8820002', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '差木野町', 'サシキノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市稲葉崎町', '45', '45203', '8820003', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '稲葉崎町', 'イナバザキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市樫山町', '45', '45203', '8820004', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '樫山町', 'カシヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市夏田町', '45', '45203', '8820005', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '夏田町', 'ナツタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市尾崎町', '45', '45203', '8820006', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '尾崎町', 'オザキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市桜ケ丘', '45', '45203', '8820007', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '桜ケ丘', 'サクラガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市須佐町', '45', '45203', '8820011', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '須佐町', 'スサマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市鹿小路', '45', '45203', '8820012', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '鹿小路', 'カショウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市追内町', '45', '45203', '8820013', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '追内町', 'オイウチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市白石町', '45', '45203', '8820014', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '白石町', 'シロイシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市水尻町', '45', '45203', '8820015', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '水尻町', 'ミズシリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市東海町', '45', '45203', '8820016', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '東海町', 'トウミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市川島町', '45', '45203', '8820017', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '川島町', 'カワシママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市無鹿町', '45', '45203', '8820021', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '無鹿町', 'ムシカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市二ツ島町', '45', '45203', '8820022', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '二ツ島町', 'フタツシママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市牧町', '45', '45203', '8820023', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '牧町', 'マキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市大武町', '45', '45203', '8820024', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '大武町', 'オオダケマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市粟野名町', '45', '45203', '8820025', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '粟野名町', 'アワノミョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市柚の木田町', '45', '45203', '8820026', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '柚の木田町', 'ユノキダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市大門町', '45', '45203', '8820027', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '大門町', 'オオカドマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市中川原町', '45', '45203', '8820031', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '中川原町', 'ナカガワラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市中の瀬町', '45', '45203', '8820032', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '中の瀬町', 'ナカノセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市川原崎町', '45', '45203', '8820033', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '川原崎町', 'カワラサキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市昭和町', '45', '45203', '8820034', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '昭和町', 'ショウワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市日の出町', '45', '45203', '8820035', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '日の出町', 'ヒノデマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市桜園町', '45', '45203', '8820036', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '桜園町', 'サクラゾノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市山月町', '45', '45203', '8820037', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '山月町', 'ヤマツキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市北小路', '45', '45203', '8820041', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '北小路', 'キタコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市高千穂通', '45', '45203', '8820042', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '高千穂通', 'タカチホドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市祗園町', '45', '45203', '8820043', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '祗園町', 'ギオンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市博労町', '45', '45203', '8820044', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '博労町', 'バクロウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市瀬之口町', '45', '45203', '8820045', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '瀬之口町', 'セノクチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市恵比須町', '45', '45203', '8820046', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '恵比須町', 'エビスマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市紺屋町', '45', '45203', '8820047', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '紺屋町', 'コンヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市富美山町', '45', '45203', '8820051', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '富美山町', 'トミヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市萩町', '45', '45203', '8820052', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '萩町', 'ハギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市幸町', '45', '45203', '8820053', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '幸町', 'サイワイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市栄町', '45', '45203', '8820054', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市山下町', '45', '45203', '8820055', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '山下町', 'ヤマシタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市岡富町', '45', '45203', '8820056', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '岡富町', 'オカトミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市岡富山', '45', '45203', '8820057', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '岡富山', 'オカトミヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市小峯町', '45', '45203', '8820061', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '小峯町', 'コミネマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市松山町', '45', '45203', '8820062', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '松山町', 'マツヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市古川町', '45', '45203', '8820063', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '古川町', 'フルカワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市高野町', '45', '45203', '8820064', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '高野町', 'タカノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市平田町', '45', '45203', '8820065', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '平田町', 'ヒラタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市舞野町', '45', '45203', '8820066', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '舞野町', 'マイノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市天下町', '45', '45203', '8820071', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '天下町', 'アモリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市吉野町', '45', '45203', '8820072', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '吉野町', 'ヨシノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市貝の畑町', '45', '45203', '8820073', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '貝の畑町', 'カイノハタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市細見町', '45', '45203', '8820074', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '細見町', 'ホソミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市岡元町', '45', '45203', '8820075', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '岡元町', 'オカモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市小川町', '45', '45203', '8820076', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '小川町', 'コガワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市行縢町', '45', '45203', '8820077', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '行縢町', 'ムカバキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市佐野町', '45', '45203', '8820081', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '佐野町', 'サノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市祝子町', '45', '45203', '8820082', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '祝子町', 'ホウリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市柚木町', '45', '45203', '8820083', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '柚木町', 'ユウギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市宇和田町', '45', '45203', '8820084', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '宇和田町', 'ウワダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市鹿狩瀬町', '45', '45203', '8820085', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '鹿狩瀬町', 'カガセマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市大野町', '45', '45203', '8820086', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '大野町', 'オオノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市妙町', '45', '45203', '8820087', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '妙町', 'ミョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市桑平町', '45', '45203', '8820091', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '桑平町', 'クワヒラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市宮長町', '45', '45203', '8820092', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '宮長町', 'ミヤナガマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市神戸町', '45', '45203', '8820093', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '神戸町', 'コウベマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市安井町', '45', '45203', '8820094', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '安井町', 'ヤスイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市浦城町', '45', '45203', '8820095', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '浦城町', 'ウラシロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市島浦町', '45', '45203', '8820096', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '島浦町', 'シマウラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市北川町川内名祝子川', '45', '45203', '8820097', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '北川町川内名', 'キタガワマチカワチミョウ', null, null, '祝子川', 'ホウリガワ');
INSERT INTO `ms_addresses` VALUES ('115728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市北方町二股', '45', '45203', '8820101', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '北方町二股', 'キタカタマチフタマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市北方町角田', '45', '45203', '8820104', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '北方町角田', 'キタカタマチツノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市北方町笠下', '45', '45203', '8820106', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '北方町笠下', 'キタカタマチカサシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市北方町藤の木', '45', '45203', '8820107', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '北方町藤の木', 'キタカタマチフジノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市北方町板上', '45', '45203', '8820121', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '北方町板上', 'キタカタマチイタカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市北方町板下', '45', '45203', '8820122', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '北方町板下', 'キタカタマチイタシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市北方町うそ越', '45', '45203', '8820123', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '北方町うそ越', 'キタカタマチウソゴエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市北方町曽木', '45', '45203', '8820124', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '北方町曽木', 'キタカタマチソキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市北方町川水流', '45', '45203', '8820125', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '北方町川水流', 'キタカタマチカワズル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市北方町上崎', '45', '45203', '8820126', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '北方町上崎', 'キタカタマチカミザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市北方町蔵田', '45', '45203', '8820127', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '北方町蔵田', 'キタカタマチクラタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市北方町南久保山', '45', '45203', '8820128', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '北方町南久保山', 'キタカタマチミナミクボヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市北方町北久保山', '45', '45203', '8820129', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '北方町北久保山', 'キタカタマチキタクボヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市北方町上鹿川', '45', '45203', '8820231', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '北方町上鹿川', 'キタカタマチカミシシガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市北方町下鹿川', '45', '45203', '8820232', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '北方町下鹿川', 'キタカタマチシモシシガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市北方町菅原', '45', '45203', '8820233', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '北方町菅原', 'キタカタマチスゲバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市北方町美々地', '45', '45203', '8820234', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '北方町美々地', 'キタカタマチミミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市北方町槇峰', '45', '45203', '8820235', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '北方町槇峰', 'キタカタマチマキミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市北方町日平', '45', '45203', '8820236', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '北方町日平', 'キタカタマチヒビラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市北方町椎畑', '45', '45203', '8820237', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '北方町椎畑', 'キタカタマチシイバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市北方町滝下', '45', '45203', '8820238', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '北方町滝下', 'キタカタマチタキシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市北方町三ケ村', '45', '45203', '8820241', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '北方町三ケ村', 'キタカタマチサンガムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市北方町八峡', '45', '45203', '8820242', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '北方町八峡', 'キタカタマチヤカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市北方町早日渡', '45', '45203', '8820243', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '北方町早日渡', 'キタカタマチハヤヒト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市北方町早中', '45', '45203', '8820244', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '北方町早中', 'キタカタマチハヤナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市北方町早上', '45', '45203', '8820245', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '北方町早上', 'キタカタマチハヤカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県西臼杵郡日之影町七折阿下', '45', '45442', '8820301', '宮崎県', 'ミヤザキケン', '西臼杵郡日之影町', 'ニシウスキグンヒノカゲチョウ', '七折', 'ナナオリ', null, null, '阿下', 'アゲ');
INSERT INTO `ms_addresses` VALUES ('115756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県西臼杵郡日之影町七折笠戸', '45', '45442', '8820301', '宮崎県', 'ミヤザキケン', '西臼杵郡日之影町', 'ニシウスキグンヒノカゲチョウ', '七折', 'ナナオリ', null, null, '笠戸', 'カサド');
INSERT INTO `ms_addresses` VALUES ('115757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県西臼杵郡日之影町七折椛木', '45', '45442', '8820301', '宮崎県', 'ミヤザキケン', '西臼杵郡日之影町', 'ニシウスキグンヒノカゲチョウ', '七折', 'ナナオリ', null, null, '椛木', 'カバギ');
INSERT INTO `ms_addresses` VALUES ('115758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県西臼杵郡日之影町七折鹿川', '45', '45442', '8820301', '宮崎県', 'ミヤザキケン', '西臼杵郡日之影町', 'ニシウスキグンヒノカゲチョウ', '七折', 'ナナオリ', null, null, '鹿川', 'シシガワ');
INSERT INTO `ms_addresses` VALUES ('115759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県西臼杵郡日之影町七折新町', '45', '45442', '8820301', '宮崎県', 'ミヤザキケン', '西臼杵郡日之影町', 'ニシウスキグンヒノカゲチョウ', '七折', 'ナナオリ', null, null, '新町', 'シンマチ');
INSERT INTO `ms_addresses` VALUES ('115760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県西臼杵郡日之影町七折滝ノ内', '45', '45442', '8820301', '宮崎県', 'ミヤザキケン', '西臼杵郡日之影町', 'ニシウスキグンヒノカゲチョウ', '七折', 'ナナオリ', null, null, '滝ノ内', 'タキノウチ');
INSERT INTO `ms_addresses` VALUES ('115761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県西臼杵郡日之影町七折中川', '45', '45442', '8820301', '宮崎県', 'ミヤザキケン', '西臼杵郡日之影町', 'ニシウスキグンヒノカゲチョウ', '七折', 'ナナオリ', null, null, '中川', 'ナカガワ');
INSERT INTO `ms_addresses` VALUES ('115762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県西臼杵郡日之影町七折西ノ内', '45', '45442', '8820301', '宮崎県', 'ミヤザキケン', '西臼杵郡日之影町', 'ニシウスキグンヒノカゲチョウ', '七折', 'ナナオリ', null, null, '西ノ内', 'ニシノウチ');
INSERT INTO `ms_addresses` VALUES ('115763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県西臼杵郡日之影町七折舟ノ尾', '45', '45442', '8820301', '宮崎県', 'ミヤザキケン', '西臼杵郡日之影町', 'ニシウスキグンヒノカゲチョウ', '七折', 'ナナオリ', null, null, '舟ノ尾', 'フネノオ');
INSERT INTO `ms_addresses` VALUES ('115764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県西臼杵郡日之影町七折八戸', '45', '45442', '8820301', '宮崎県', 'ミヤザキケン', '西臼杵郡日之影町', 'ニシウスキグンヒノカゲチョウ', '七折', 'ナナオリ', null, null, '八戸', 'ヤト');
INSERT INTO `ms_addresses` VALUES ('115765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県西臼杵郡日之影町七折簗崎', '45', '45442', '8820301', '宮崎県', 'ミヤザキケン', '西臼杵郡日之影町', 'ニシウスキグンヒノカゲチョウ', '七折', 'ナナオリ', null, null, '簗崎', 'ヤナザキ');
INSERT INTO `ms_addresses` VALUES ('115766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県西臼杵郡日之影町岩井川境野', '45', '45442', '8820302', '宮崎県', 'ミヤザキケン', '西臼杵郡日之影町', 'ニシウスキグンヒノカゲチョウ', '岩井川', 'イワイカワ', null, null, '境野', 'サカイノ');
INSERT INTO `ms_addresses` VALUES ('115767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県西臼杵郡日之影町分城', '45', '45442', '8820304', '宮崎県', 'ミヤザキケン', '西臼杵郡日之影町', 'ニシウスキグンヒノカゲチョウ', '分城', 'ワケジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県西臼杵郡日之影町', '45', '45442', '8820400', '宮崎県', 'ミヤザキケン', '西臼杵郡日之影町', 'ニシウスキグンヒノカゲチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('115769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県西臼杵郡日之影町七折', '45', '45442', '8820401', '宮崎県', 'ミヤザキケン', '西臼杵郡日之影町', 'ニシウスキグンヒノカゲチョウ', '七折', 'ナナオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県西臼杵郡日之影町岩井川', '45', '45442', '8820402', '宮崎県', 'ミヤザキケン', '西臼杵郡日之影町', 'ニシウスキグンヒノカゲチョウ', '岩井川', 'イワイカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県西臼杵郡日之影町見立', '45', '45442', '8820403', '宮崎県', 'ミヤザキケン', '西臼杵郡日之影町', 'ニシウスキグンヒノカゲチョウ', '見立', 'ミタテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市野田町', '45', '45203', '8820801', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '野田町', 'ノタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市野地町', '45', '45203', '8820802', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '野地町', 'ノジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市大貫町', '45', '45203', '8820803', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '大貫町', 'オオヌキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市西階町', '45', '45203', '8820804', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '西階町', 'ニシシナマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市天神小路', '45', '45203', '8820811', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '天神小路', 'テンジンコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市本小路', '45', '45203', '8820812', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '本小路', 'ホンコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市東本小路', '45', '45203', '8820813', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '東本小路', 'ヒガシホンコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市北町', '45', '45203', '8820814', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '北町', 'キタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市柳沢町', '45', '45203', '8820815', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '柳沢町', 'ヤナザワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市桜小路', '45', '45203', '8820816', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '桜小路', 'サクラコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市本町', '45', '45203', '8820821', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市南町', '45', '45203', '8820822', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '南町', 'ミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市中町', '45', '45203', '8820823', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '中町', 'ナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市中央通', '45', '45203', '8820824', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '中央通', 'チュウオウドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市須崎町', '45', '45203', '8820825', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '須崎町', 'スザキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市船倉町', '45', '45203', '8820826', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '船倉町', 'フナグラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市新町', '45', '45203', '8820827', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市出口町', '45', '45203', '8820831', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '出口町', 'イデグチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市西小路', '45', '45203', '8820832', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '西小路', 'サイコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市上大瀬町', '45', '45203', '8820833', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '上大瀬町', 'カミオオセマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市北新小路', '45', '45203', '8820834', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '北新小路', 'キタシンコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市新小路', '45', '45203', '8820835', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '新小路', 'シンコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市恒富町', '45', '45203', '8820836', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '恒富町', 'ツネトミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市古城町', '45', '45203', '8820837', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '古城町', 'フルシロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市大瀬町', '45', '45203', '8820841', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '大瀬町', 'オオセマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市三ツ瀬町', '45', '45203', '8820842', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '三ツ瀬町', 'ミツゼマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市永池町', '45', '45203', '8820843', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '永池町', 'ナガイケマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市春日町', '45', '45203', '8820844', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '春日町', 'カスガマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市安賀多町', '45', '45203', '8820845', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '安賀多町', 'アガタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市中島町', '45', '45203', '8820846', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '中島町', 'ナカシママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市旭町', '45', '45203', '8820847', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '旭町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市浜砂', '45', '45203', '8820851', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '浜砂', 'ハマゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市東浜砂町', '45', '45203', '8820852', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '東浜砂町', 'ヒガシハマゴマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市方財町', '45', '45203', '8820853', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '方財町', 'ホウザイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市長浜町', '45', '45203', '8820854', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '長浜町', 'ナガハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市卸本町', '45', '45203', '8820855', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '卸本町', 'オロシホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市出北', '45', '45203', '8820856', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '出北', 'イデキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市惣領町', '45', '45203', '8820857', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '惣領町', 'ソウリョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市別府町', '45', '45203', '8820861', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '別府町', 'ビュウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市浜町', '45', '45203', '8820862', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '浜町', 'ハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市緑ケ丘', '45', '45203', '8820863', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '緑ケ丘', 'ミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市塩浜町', '45', '45203', '8820864', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '塩浜町', 'シオハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市鶴ケ丘', '45', '45203', '8820865', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '鶴ケ丘', 'ツルガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市平原町', '45', '45203', '8820866', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '平原町', 'ヒラバルマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市構口町', '45', '45203', '8820867', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '構口町', 'カマエグチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市愛宕山', '45', '45203', '8820871', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '愛宕山', 'アタゴヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市愛宕町', '45', '45203', '8820872', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '愛宕町', 'アタゴマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市共栄町', '45', '45203', '8820873', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '共栄町', 'キョウエイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市伊達町', '45', '45203', '8820874', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '伊達町', 'ダテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市若葉町', '45', '45203', '8820875', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '若葉町', 'ワカバマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市沖田町', '45', '45203', '8820876', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '沖田町', 'オキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市片田町', '45', '45203', '8820877', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '片田町', 'カタタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市三須町', '45', '45203', '8820881', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '三須町', 'ミスマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市小野町', '45', '45203', '8820882', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '小野町', 'コノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市下三輪町', '45', '45203', '8820883', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '下三輪町', 'シモミワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市中三輪町', '45', '45203', '8820884', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '中三輪町', 'ナカミワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市上三輪町', '45', '45203', '8820885', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '上三輪町', 'カミミワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県西臼杵郡高千穂町', '45', '45441', '8821100', '宮崎県', 'ミヤザキケン', '西臼杵郡高千穂町', 'ニシウスキグンタカチホチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('115830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県西臼杵郡高千穂町三田井', '45', '45441', '8821101', '宮崎県', 'ミヤザキケン', '西臼杵郡高千穂町', 'ニシウスキグンタカチホチョウ', '三田井', 'ミタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県西臼杵郡高千穂町押方', '45', '45441', '8821102', '宮崎県', 'ミヤザキケン', '西臼杵郡高千穂町', 'ニシウスキグンタカチホチョウ', '押方', 'オシカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県西臼杵郡高千穂町向山', '45', '45441', '8821103', '宮崎県', 'ミヤザキケン', '西臼杵郡高千穂町', 'ニシウスキグンタカチホチョウ', '向山', 'ムコウヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県西臼杵郡五ヶ瀬町', '45', '45443', '8821200', '宮崎県', 'ミヤザキケン', '西臼杵郡五ヶ瀬町', 'ニシウスキグンゴカセチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('115835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県西臼杵郡五ヶ瀬町鞍岡', '45', '45443', '8821201', '宮崎県', 'ミヤザキケン', '西臼杵郡五ヶ瀬町', 'ニシウスキグンゴカセチョウ', '鞍岡', 'クラオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県西臼杵郡五ヶ瀬町桑野内', '45', '45443', '8821202', '宮崎県', 'ミヤザキケン', '西臼杵郡五ヶ瀬町', 'ニシウスキグンゴカセチョウ', '桑野内', 'クワノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県西臼杵郡五ヶ瀬町三ヶ所', '45', '45443', '8821203', '宮崎県', 'ミヤザキケン', '西臼杵郡五ヶ瀬町', 'ニシウスキグンゴカセチョウ', '三ヶ所', 'サンカショ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路郡釧路町細岡', '01', '01661', '0882140', '北海道', 'ホッカイドウ', '釧路郡釧路町', 'クシログンクシロチョウ', '細岡', 'ホソオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路郡釧路町達古武', '01', '01661', '0882141', '北海道', 'ホッカイドウ', '釧路郡釧路町', 'クシログンクシロチョウ', '達古武', 'タッコブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県西臼杵郡高千穂町上野', '45', '45441', '8821411', '宮崎県', 'ミヤザキケン', '西臼杵郡高千穂町', 'ニシウスキグンタカチホチョウ', '上野', 'カミノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県西臼杵郡高千穂町下野', '45', '45441', '8821412', '宮崎県', 'ミヤザキケン', '西臼杵郡高千穂町', 'ニシウスキグンタカチホチョウ', '下野', 'シモノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県西臼杵郡高千穂町田原', '45', '45441', '8821413', '宮崎県', 'ミヤザキケン', '西臼杵郡高千穂町', 'ニシウスキグンタカチホチョウ', '田原', 'タバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県西臼杵郡高千穂町河内', '45', '45441', '8821414', '宮崎県', 'ミヤザキケン', '西臼杵郡高千穂町', 'ニシウスキグンタカチホチョウ', '河内', 'カワチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県西臼杵郡高千穂町五ケ所', '45', '45441', '8821415', '宮崎県', 'ミヤザキケン', '西臼杵郡高千穂町', 'ニシウスキグンタカチホチョウ', '五ケ所', 'ゴカショ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路郡釧路町遠野', '01', '01661', '0882142', '北海道', 'ホッカイドウ', '釧路郡釧路町', 'クシログンクシロチョウ', '遠野', 'トオヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路郡釧路町河畔', '01', '01661', '0882143', '北海道', 'ホッカイドウ', '釧路郡釧路町', 'クシログンクシロチョウ', '河畔', 'カハン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路郡釧路町鳥里', '01', '01661', '0882144', '北海道', 'ホッカイドウ', '釧路郡釧路町', 'クシログンクシロチョウ', '鳥里', 'トリサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路郡釧路町遠矢', '01', '01661', '0882145', '北海道', 'ホッカイドウ', '釧路郡釧路町', 'クシログンクシロチョウ', '遠矢', 'トオヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路郡釧路町鳥通西', '01', '01661', '0882146', '北海道', 'ホッカイドウ', '釧路郡釧路町', 'クシログンクシロチョウ', '鳥通西', 'トリトウシニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路郡釧路町鳥通東', '01', '01661', '0882147', '北海道', 'ホッカイドウ', '釧路郡釧路町', 'クシログンクシロチョウ', '鳥通東', 'トリトウシヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路郡釧路町鳥通', '01', '01661', '0882148', '北海道', 'ホッカイドウ', '釧路郡釧路町', 'クシログンクシロチョウ', '鳥通', 'トリトウシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路郡釧路町よし野', '01', '01661', '0882151', '北海道', 'ホッカイドウ', '釧路郡釧路町', 'クシログンクシロチョウ', 'よし野', 'ヨシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路郡釧路町南陽台', '01', '01661', '0882152', '北海道', 'ホッカイドウ', '釧路郡釧路町', 'クシログンクシロチョウ', '南陽台', 'ナンヨウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路郡釧路町緑', '01', '01661', '0882153', '北海道', 'ホッカイドウ', '釧路郡釧路町', 'クシログンクシロチョウ', '緑', 'ミドリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路郡釧路町柏東', '01', '01661', '0882154', '北海道', 'ホッカイドウ', '釧路郡釧路町', 'クシログンクシロチョウ', '柏東', 'カシワヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路郡釧路町柏西', '01', '01661', '0882155', '北海道', 'ホッカイドウ', '釧路郡釧路町', 'クシログンクシロチョウ', '柏西', 'カシワニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路郡釧路町遠矢南', '01', '01661', '0882156', '北海道', 'ホッカイドウ', '釧路郡釧路町', 'クシログンクシロチョウ', '遠矢南', 'トオヤミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道釧路郡釧路町わらび', '01', '01661', '0882157', '北海道', 'ホッカイドウ', '釧路郡釧路町', 'クシログンクシロチョウ', 'わらび', 'ワラビ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県西臼杵郡高千穂町岩戸', '45', '45441', '8821621', '宮崎県', 'ミヤザキケン', '西臼杵郡高千穂町', 'ニシウスキグンタカチホチョウ', '岩戸', 'イワト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県西臼杵郡高千穂町上岩戸', '45', '45441', '8821622', '宮崎県', 'ミヤザキケン', '西臼杵郡高千穂町', 'ニシウスキグンタカチホチョウ', '上岩戸', 'カミイワト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道川上郡標茶町塘路', '01', '01664', '0882261', '北海道', 'ホッカイドウ', '川上郡標茶町', 'カワカミグンシベチャチョウ', '塘路', 'トウロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道川上郡標茶町ウライヤ', '01', '01664', '0882262', '北海道', 'ホッカイドウ', '川上郡標茶町', 'カワカミグンシベチャチョウ', 'ウライヤ', 'ウライヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道川上郡標茶町沼ノ上', '01', '01664', '0882263', '北海道', 'ホッカイドウ', '川上郡標茶町', 'カワカミグンシベチャチョウ', '沼ノ上', 'ヌマノカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道川上郡標茶町塘路原野', '01', '01664', '0882264', '北海道', 'ホッカイドウ', '川上郡標茶町', 'カワカミグンシベチャチョウ', '塘路原野', 'トウロゲンヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道川上郡標茶町シラルトロ', '01', '01664', '0882265', '北海道', 'ホッカイドウ', '川上郡標茶町', 'カワカミグンシベチャチョウ', 'シラルトロ', 'シラルトロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道川上郡標茶町塘路', '01', '01664', '0882265', '北海道', 'ホッカイドウ', '川上郡標茶町', 'カワカミグンシベチャチョウ', '塘路', 'トウロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道川上郡標茶町茅沼', '01', '01664', '0882266', '北海道', 'ホッカイドウ', '川上郡標茶町', 'カワカミグンシベチャチョウ', '茅沼', 'カヤヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道川上郡標茶町コツタロ原野', '01', '01664', '0882266', '北海道', 'ホッカイドウ', '川上郡標茶町', 'カワカミグンシベチャチョウ', 'コツタロ原野', 'コツタロゲンヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道川上郡標茶町阿歴内', '01', '01664', '0882271', '北海道', 'ホッカイドウ', '川上郡標茶町', 'カワカミグンシベチャチョウ', '阿歴内', 'アレキナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道川上郡標茶町阿歴内原野', '01', '01664', '0882272', '北海道', 'ホッカイドウ', '川上郡標茶町', 'カワカミグンシベチャチョウ', '阿歴内原野', 'アレキナイゲンヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道川上郡標茶町西和', '01', '01664', '0882273', '北海道', 'ホッカイドウ', '川上郡標茶町', 'カワカミグンシベチャチョウ', '西和', 'セイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道川上郡標茶町東阿歴内', '01', '01664', '0882274', '北海道', 'ホッカイドウ', '川上郡標茶町', 'カワカミグンシベチャチョウ', '東阿歴内', 'ヒガシアレキナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道川上郡標茶町北片無去', '01', '01664', '0882275', '北海道', 'ホッカイドウ', '川上郡標茶町', 'カワカミグンシベチャチョウ', '北片無去', 'キタカタムサリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道川上郡標茶町', '01', '01664', '0882300', '北海道', 'ホッカイドウ', '川上郡標茶町', 'カワカミグンシベチャチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('115878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道川上郡標茶町旭', '01', '01664', '0882301', '北海道', 'ホッカイドウ', '川上郡標茶町', 'カワカミグンシベチャチョウ', '旭', 'アサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道川上郡標茶町富士', '01', '01664', '0882302', '北海道', 'ホッカイドウ', '川上郡標茶町', 'カワカミグンシベチャチョウ', '富士', 'フジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道川上郡標茶町桜', '01', '01664', '0882303', '北海道', 'ホッカイドウ', '川上郡標茶町', 'カワカミグンシベチャチョウ', '桜', 'サクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道川上郡標茶町平和', '01', '01664', '0882304', '北海道', 'ホッカイドウ', '川上郡標茶町', 'カワカミグンシベチャチョウ', '平和', 'ヘイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道川上郡標茶町麻生', '01', '01664', '0882305', '北海道', 'ホッカイドウ', '川上郡標茶町', 'カワカミグンシベチャチョウ', '麻生', 'アザブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道川上郡標茶町開運', '01', '01664', '0882311', '北海道', 'ホッカイドウ', '川上郡標茶町', 'カワカミグンシベチャチョウ', '開運', 'カイウン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道川上郡標茶町川上', '01', '01664', '0882312', '北海道', 'ホッカイドウ', '川上郡標茶町', 'カワカミグンシベチャチョウ', '川上', 'カワカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道川上郡標茶町常盤', '01', '01664', '0882313', '北海道', 'ホッカイドウ', '川上郡標茶町', 'カワカミグンシベチャチョウ', '常盤', 'トキワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道川上郡標茶町標茶', '01', '01664', '0882314', '北海道', 'ホッカイドウ', '川上郡標茶町', 'カワカミグンシベチャチョウ', '標茶', 'シベチャ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道川上郡標茶町上チャンベツ', '01', '01664', '0882321', '北海道', 'ホッカイドウ', '川上郡標茶町', 'カワカミグンシベチャチョウ', '上チャンベツ', 'カミチャンベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道川上郡標茶町中チャンベツ', '01', '01664', '0882322', '北海道', 'ホッカイドウ', '川上郡標茶町', 'カワカミグンシベチャチョウ', '中チャンベツ', 'ナカチャンベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道川上郡標茶町下チャンベツ', '01', '01664', '0882323', '北海道', 'ホッカイドウ', '川上郡標茶町', 'カワカミグンシベチャチョウ', '下チャンベツ', 'シモチャンベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道川上郡標茶町雷別', '01', '01664', '0882324', '北海道', 'ホッカイドウ', '川上郡標茶町', 'カワカミグンシベチャチョウ', '雷別', 'ライベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道川上郡標茶町オソツベツ', '01', '01664', '0882331', '北海道', 'ホッカイドウ', '川上郡標茶町', 'カワカミグンシベチャチョウ', 'オソツベツ', 'オソツベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道川上郡標茶町下オソツベツ', '01', '01664', '0882331', '北海道', 'ホッカイドウ', '川上郡標茶町', 'カワカミグンシベチャチョウ', '下オソツベツ', 'シモオソツベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道川上郡標茶町中オソツベツ', '01', '01664', '0882332', '北海道', 'ホッカイドウ', '川上郡標茶町', 'カワカミグンシベチャチョウ', '中オソツベツ', 'ナカオソツベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道川上郡標茶町上オソツベツ', '01', '01664', '0882333', '北海道', 'ホッカイドウ', '川上郡標茶町', 'カワカミグンシベチャチョウ', '上オソツベツ', 'カミオソツベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道川上郡標茶町厚生', '01', '01664', '0882334', '北海道', 'ホッカイドウ', '川上郡標茶町', 'カワカミグンシベチャチョウ', '厚生', 'コウセイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道川上郡標茶町五十石', '01', '01664', '0882335', '北海道', 'ホッカイドウ', '川上郡標茶町', 'カワカミグンシベチャチョウ', '五十石', 'ゴジュウコク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道川上郡標茶町ルルラン', '01', '01664', '0882336', '北海道', 'ホッカイドウ', '川上郡標茶町', 'カワカミグンシベチャチョウ', 'ルルラン', 'ルルラン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道川上郡標茶町北標茶', '01', '01664', '0882337', '北海道', 'ホッカイドウ', '川上郡標茶町', 'カワカミグンシベチャチョウ', '北標茶', 'キタシベチャ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道川上郡標茶町栄', '01', '01664', '0882337', '北海道', 'ホッカイドウ', '川上郡標茶町', 'カワカミグンシベチャチョウ', '栄', 'サカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道川上郡標茶町南標茶', '01', '01664', '0882338', '北海道', 'ホッカイドウ', '川上郡標茶町', 'カワカミグンシベチャチョウ', '南標茶', 'ミナミシベチャ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道川上郡標茶町上多和', '01', '01664', '0882339', '北海道', 'ホッカイドウ', '川上郡標茶町', 'カワカミグンシベチャチョウ', '上多和', 'カミタワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道川上郡標茶町多和', '01', '01664', '0882339', '北海道', 'ホッカイドウ', '川上郡標茶町', 'カワカミグンシベチャチョウ', '多和', 'タワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道川上郡標茶町虹別市街', '01', '01664', '0882461', '北海道', 'ホッカイドウ', '川上郡標茶町', 'カワカミグンシベチャチョウ', '虹別市街', 'ニジベツシガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道川上郡標茶町虹別', '01', '01664', '0882462', '北海道', 'ホッカイドウ', '川上郡標茶町', 'カワカミグンシベチャチョウ', '虹別', 'ニジベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道川上郡標茶町虹別上虹', '01', '01664', '0882463', '北海道', 'ホッカイドウ', '川上郡標茶町', 'カワカミグンシベチャチョウ', '虹別', 'ニジベツ', null, null, '上虹', 'カミニジ');
INSERT INTO `ms_addresses` VALUES ('115906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道川上郡標茶町虹別中虹', '01', '01664', '0882464', '北海道', 'ホッカイドウ', '川上郡標茶町', 'カワカミグンシベチャチョウ', '虹別', 'ニジベツ', null, null, '中虹', 'ナカニジ');
INSERT INTO `ms_addresses` VALUES ('115907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道川上郡標茶町虹別萩野', '01', '01664', '0882465', '北海道', 'ホッカイドウ', '川上郡標茶町', 'カワカミグンシベチャチョウ', '虹別', 'ニジベツ', null, null, '萩野', 'ハギノ');
INSERT INTO `ms_addresses` VALUES ('115908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道野付郡別海町西春別駅前柏町', '01', '01691', '0882561', '北海道', 'ホッカイドウ', '野付郡別海町', 'ノツケグンベツカイチョウ', '西春別駅前柏町', 'ニシシュンベツエキマエカシワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道野付郡別海町西春別駅前栄町', '01', '01691', '0882562', '北海道', 'ホッカイドウ', '野付郡別海町', 'ノツケグンベツカイチョウ', '西春別駅前栄町', 'ニシシュンベツエキマエサカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道野付郡別海町西春別駅前錦町', '01', '01691', '0882563', '北海道', 'ホッカイドウ', '野付郡別海町', 'ノツケグンベツカイチョウ', '西春別駅前錦町', 'ニシシュンベツエキマエニシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道野付郡別海町西春別駅前西町', '01', '01691', '0882564', '北海道', 'ホッカイドウ', '野付郡別海町', 'ノツケグンベツカイチョウ', '西春別駅前西町', 'ニシシュンベツエキマエニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道野付郡別海町西春別駅前寿町', '01', '01691', '0882565', '北海道', 'ホッカイドウ', '野付郡別海町', 'ノツケグンベツカイチョウ', '西春別駅前寿町', 'ニシシュンベツエキマエコトブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道野付郡別海町西春別駅前曙町', '01', '01691', '0882566', '北海道', 'ホッカイドウ', '野付郡別海町', 'ノツケグンベツカイチョウ', '西春別駅前曙町', 'ニシシュンベツエキマエアケボノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道野付郡別海町西春別幸町', '01', '01691', '0882571', '北海道', 'ホッカイドウ', '野付郡別海町', 'ノツケグンベツカイチョウ', '西春別幸町', 'ニシシュンベツサイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道野付郡別海町西春別清川町', '01', '01691', '0882572', '北海道', 'ホッカイドウ', '野付郡別海町', 'ノツケグンベツカイチョウ', '西春別清川町', 'ニシシュンベツキヨカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道野付郡別海町西春別本久町', '01', '01691', '0882573', '北海道', 'ホッカイドウ', '野付郡別海町', 'ノツケグンベツカイチョウ', '西春別本久町', 'ニシシュンベツホンキュウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道野付郡別海町西春別昭栄町', '01', '01691', '0882574', '北海道', 'ホッカイドウ', '野付郡別海町', 'ノツケグンベツカイチョウ', '西春別昭栄町', 'ニシシュンベツショウエイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道野付郡別海町西春別宮園町', '01', '01691', '0882575', '北海道', 'ホッカイドウ', '野付郡別海町', 'ノツケグンベツカイチョウ', '西春別宮園町', 'ニシシュンベツミヤゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道野付郡別海町西春別', '01', '01691', '0882576', '北海道', 'ホッカイドウ', '野付郡別海町', 'ノツケグンベツカイチョウ', '西春別', 'ニシシュンベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道野付郡別海町矢臼別', '01', '01691', '0882577', '北海道', 'ホッカイドウ', '野付郡別海町', 'ノツケグンベツカイチョウ', '矢臼別', 'ヤウスベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道野付郡別海町泉川', '01', '01691', '0882578', '北海道', 'ホッカイドウ', '野付郡別海町', 'ノツケグンベツカイチョウ', '泉川', 'イズミカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道野付郡別海町大成', '01', '01691', '0882601', '北海道', 'ホッカイドウ', '野付郡別海町', 'ノツケグンベツカイチョウ', '大成', 'タイセイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道野付郡別海町本別', '01', '01691', '0882602', '北海道', 'ホッカイドウ', '野付郡別海町', 'ノツケグンベツカイチョウ', '本別', 'ホンベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町当幌', '01', '01692', '0882681', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '当幌', 'トウホロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町計根別', '01', '01692', '0882682', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '計根別', 'ケネベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町上標津', '01', '01692', '0882683', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '上標津', 'カミシベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町養老牛', '01', '01692', '0882684', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '養老牛', 'ヨウロウウシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町西竹', '01', '01692', '0882685', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '西竹', 'ニシタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道標津郡中標津町俣落', '01', '01692', '0882686', '北海道', 'ホッカイドウ', '標津郡中標津町', 'シベツグンナカシベツチョウ', '俣落', 'マタオチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道野付郡別海町上春別緑町', '01', '01691', '0882721', '北海道', 'ホッカイドウ', '野付郡別海町', 'ノツケグンベツカイチョウ', '上春別緑町', 'カミシュンベツミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道野付郡別海町上春別旭町', '01', '01691', '0882722', '北海道', 'ホッカイドウ', '野付郡別海町', 'ノツケグンベツカイチョウ', '上春別旭町', 'カミシュンベツアサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道野付郡別海町上春別南町', '01', '01691', '0882723', '北海道', 'ホッカイドウ', '野付郡別海町', 'ノツケグンベツカイチョウ', '上春別南町', 'カミシュンベツミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道野付郡別海町上春別栄町', '01', '01691', '0882724', '北海道', 'ホッカイドウ', '野付郡別海町', 'ノツケグンベツカイチョウ', '上春別栄町', 'カミシュンベツサカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道野付郡別海町上春別', '01', '01691', '0882725', '北海道', 'ホッカイドウ', '野付郡別海町', 'ノツケグンベツカイチョウ', '上春別', 'カミシュンベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日向市', '45', '45206', '8830000', '宮崎県', 'ミヤザキケン', '日向市', 'ヒュウガシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('115945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日向市細島', '45', '45206', '8830001', '宮崎県', 'ミヤザキケン', '日向市', 'ヒュウガシ', '細島', 'ホソシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日向市平野町', '45', '45206', '8830002', '宮崎県', 'ミヤザキケン', '日向市', 'ヒュウガシ', '平野町', 'ヒラノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日向市伊勢ケ浜', '45', '45206', '8830003', '宮崎県', 'ミヤザキケン', '日向市', 'ヒュウガシ', '伊勢ケ浜', 'イセガハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日向市浜町', '45', '45206', '8830004', '宮崎県', 'ミヤザキケン', '日向市', 'ヒュウガシ', '浜町', 'ハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日向市中堀町', '45', '45206', '8830005', '宮崎県', 'ミヤザキケン', '日向市', 'ヒュウガシ', '中堀町', 'ナカホリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日向市山手町', '45', '45206', '8830006', '宮崎県', 'ミヤザキケン', '日向市', 'ヒュウガシ', '山手町', 'ヤマテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日向市曽根町', '45', '45206', '8830011', '宮崎県', 'ミヤザキケン', '日向市', 'ヒュウガシ', '曽根町', 'ソネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日向市江良町', '45', '45206', '8830012', '宮崎県', 'ミヤザキケン', '日向市', 'ヒュウガシ', '江良町', 'エラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日向市新生町', '45', '45206', '8830013', '宮崎県', 'ミヤザキケン', '日向市', 'ヒュウガシ', '新生町', 'シンセイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日向市原町', '45', '45206', '8830014', '宮崎県', 'ミヤザキケン', '日向市', 'ヒュウガシ', '原町', 'ハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日向市永江町', '45', '45206', '8830015', '宮崎県', 'ミヤザキケン', '日向市', 'ヒュウガシ', '永江町', 'ナガエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日向市財光寺', '45', '45206', '8830021', '宮崎県', 'ミヤザキケン', '日向市', 'ヒュウガシ', '財光寺', 'ザイコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日向市平岩', '45', '45206', '8830022', '宮崎県', 'ミヤザキケン', '日向市', 'ヒュウガシ', '平岩', 'ヒライワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日向市財光寺沖町', '45', '45206', '8830023', '宮崎県', 'ミヤザキケン', '日向市', 'ヒュウガシ', '財光寺沖町', 'ザイコウジオキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日向市財光寺往還町', '45', '45206', '8830024', '宮崎県', 'ミヤザキケン', '日向市', 'ヒュウガシ', '財光寺往還町', 'ザイコウジオウカンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日向市比良町', '45', '45206', '8830031', '宮崎県', 'ミヤザキケン', '日向市', 'ヒュウガシ', '比良町', 'ヒラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日向市山下町', '45', '45206', '8830032', '宮崎県', 'ミヤザキケン', '日向市', 'ヒュウガシ', '山下町', 'ヤマシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日向市塩見', '45', '45206', '8830033', '宮崎県', 'ミヤザキケン', '日向市', 'ヒュウガシ', '塩見', 'シオミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日向市富高', '45', '45206', '8830034', '宮崎県', 'ミヤザキケン', '日向市', 'ヒュウガシ', '富高', 'トミタカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日向市春原町', '45', '45206', '8830035', '宮崎県', 'ミヤザキケン', '日向市', 'ヒュウガシ', '春原町', 'ハルハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日向市南町', '45', '45206', '8830036', '宮崎県', 'ミヤザキケン', '日向市', 'ヒュウガシ', '南町', 'ミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日向市不動寺', '45', '45206', '8830037', '宮崎県', 'ミヤザキケン', '日向市', 'ヒュウガシ', '不動寺', 'フドウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日向市迎洋園', '45', '45206', '8830038', '宮崎県', 'ミヤザキケン', '日向市', 'ヒュウガシ', '迎洋園', 'ゲイヨウエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日向市北町', '45', '45206', '8830041', '宮崎県', 'ミヤザキケン', '日向市', 'ヒュウガシ', '北町', 'キタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日向市高砂町', '45', '45206', '8830042', '宮崎県', 'ミヤザキケン', '日向市', 'ヒュウガシ', '高砂町', 'タカサゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日向市都町', '45', '45206', '8830043', '宮崎県', 'ミヤザキケン', '日向市', 'ヒュウガシ', '都町', 'ミヤコマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日向市上町', '45', '45206', '8830044', '宮崎県', 'ミヤザキケン', '日向市', 'ヒュウガシ', '上町', 'ウエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日向市本町', '45', '45206', '8830045', '宮崎県', 'ミヤザキケン', '日向市', 'ヒュウガシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日向市中町', '45', '45206', '8830046', '宮崎県', 'ミヤザキケン', '日向市', 'ヒュウガシ', '中町', 'ナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日向市向江町', '45', '45206', '8830051', '宮崎県', 'ミヤザキケン', '日向市', 'ヒュウガシ', '向江町', 'ムカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日向市鶴町', '45', '45206', '8830052', '宮崎県', 'ミヤザキケン', '日向市', 'ヒュウガシ', '鶴町', 'ツルマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日向市梶木町', '45', '45206', '8830053', '宮崎県', 'ミヤザキケン', '日向市', 'ヒュウガシ', '梶木町', 'カジキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日向市大王町', '45', '45206', '8830061', '宮崎県', 'ミヤザキケン', '日向市', 'ヒュウガシ', '大王町', 'ダイオウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日向市日知屋', '45', '45206', '8830062', '宮崎県', 'ミヤザキケン', '日向市', 'ヒュウガシ', '日知屋', 'ヒチヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日向市竹島町', '45', '45206', '8830063', '宮崎県', 'ミヤザキケン', '日向市', 'ヒュウガシ', '竹島町', 'タケシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日向市日知屋古田町', '45', '45206', '8830064', '宮崎県', 'ミヤザキケン', '日向市', 'ヒュウガシ', '日知屋古田町', 'ヒチヤフルタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日向市船場町', '45', '45206', '8830065', '宮崎県', 'ミヤザキケン', '日向市', 'ヒュウガシ', '船場町', 'フナバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日向市亀崎', '45', '45206', '8830066', '宮崎県', 'ミヤザキケン', '日向市', 'ヒュウガシ', '亀崎', 'カメザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日向市亀崎東', '45', '45206', '8830067', '宮崎県', 'ミヤザキケン', '日向市', 'ヒュウガシ', '亀崎東', 'カメザキヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日向市亀崎西', '45', '45206', '8830068', '宮崎県', 'ミヤザキケン', '日向市', 'ヒュウガシ', '亀崎西', 'カメザキニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日向市東郷町山陰乙', '45', '45206', '8830101', '宮崎県', 'ミヤザキケン', '日向市', 'ヒュウガシ', '東郷町山陰乙', 'トウゴウチョウヤマゲオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日向市東郷町山陰丙', '45', '45206', '8830102', '宮崎県', 'ミヤザキケン', '日向市', 'ヒュウガシ', '東郷町山陰丙', 'トウゴウチョウヤマゲヘイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日向市東郷町山陰丁', '45', '45206', '8830103', '宮崎県', 'ミヤザキケン', '日向市', 'ヒュウガシ', '東郷町山陰丁', 'トウゴウチョウヤマゲテイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日向市東郷町山陰戊', '45', '45206', '8830104', '宮崎県', 'ミヤザキケン', '日向市', 'ヒュウガシ', '東郷町山陰戊', 'トウゴウチョウヤマゲボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日向市東郷町山陰己', '45', '45206', '8830105', '宮崎県', 'ミヤザキケン', '日向市', 'ヒュウガシ', '東郷町山陰己', 'トウゴウチョウヤマゲキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日向市東郷町山陰辛', '45', '45206', '8830106', '宮崎県', 'ミヤザキケン', '日向市', 'ヒュウガシ', '東郷町山陰辛', 'トウゴウチョウヤマゲシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日向市東郷町山陰庚', '45', '45206', '8830107', '宮崎県', 'ミヤザキケン', '日向市', 'ヒュウガシ', '東郷町山陰庚', 'トウゴウチョウヤマゲコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日向市東郷町八重原迫野内', '45', '45206', '8830108', '宮崎県', 'ミヤザキケン', '日向市', 'ヒュウガシ', '東郷町八重原迫野内', 'トウゴウチョウハエバルサコノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日向市東郷町山陰', '45', '45206', '8830109', '宮崎県', 'ミヤザキケン', '日向市', 'ヒュウガシ', '東郷町山陰', 'トウゴウチョウヤマゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日向市東郷町坪谷', '45', '45206', '8830211', '宮崎県', 'ミヤザキケン', '日向市', 'ヒュウガシ', '東郷町坪谷', 'トウゴウチョウツボヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日向市東郷町山陰戊', '45', '45206', '8830212', '宮崎県', 'ミヤザキケン', '日向市', 'ヒュウガシ', '東郷町山陰戊', 'トウゴウチョウヤマゲボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日向市東郷町下三ケ', '45', '45206', '8830213', '宮崎県', 'ミヤザキケン', '日向市', 'ヒュウガシ', '東郷町下三ケ', 'トウゴウチョウシモサンゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県東臼杵郡美郷町南郷区水清谷', '45', '45431', '8830301', '宮崎県', 'ミヤザキケン', '東臼杵郡美郷町', 'ヒガシウスキグンミサトチョウ', '南郷区水清谷', 'ナンゴウクミズシダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('115999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県東臼杵郡美郷町南郷区中渡川', '45', '45431', '8830302', '宮崎県', 'ミヤザキケン', '東臼杵郡美郷町', 'ヒガシウスキグンミサトチョウ', '南郷区中渡川', 'ナンゴウクナカドガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県東臼杵郡美郷町南郷区上渡川', '45', '45431', '8830303', '宮崎県', 'ミヤザキケン', '東臼杵郡美郷町', 'ヒガシウスキグンミサトチョウ', '南郷区上渡川', 'ナンゴウクカミドガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県東臼杵郡美郷町南郷区鬼神野', '45', '45431', '8830304', '宮崎県', 'ミヤザキケン', '東臼杵郡美郷町', 'ヒガシウスキグンミサトチョウ', '南郷区鬼神野', 'ナンゴウクキジノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県東臼杵郡美郷町南郷区山三ケ', '45', '45431', '8830305', '宮崎県', 'ミヤザキケン', '東臼杵郡美郷町', 'ヒガシウスキグンミサトチョウ', '南郷区山三ケ', 'ナンゴウクヤマサンガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県東臼杵郡美郷町南郷区神門', '45', '45431', '8830306', '宮崎県', 'ミヤザキケン', '東臼杵郡美郷町', 'ヒガシウスキグンミサトチョウ', '南郷区神門', 'ナンゴウクミカド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県東臼杵郡椎葉村大河内', '45', '45430', '8830402', '宮崎県', 'ミヤザキケン', '東臼杵郡椎葉村', 'ヒガシウスキグンシイバソン', '大河内', 'オオカワウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県東臼杵郡美郷町', '45', '45431', '8831100', '宮崎県', 'ミヤザキケン', '東臼杵郡美郷町', 'ヒガシウスキグンミサトチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('116006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県東臼杵郡美郷町西郷区田代', '45', '45431', '8831101', '宮崎県', 'ミヤザキケン', '東臼杵郡美郷町', 'ヒガシウスキグンミサトチョウ', '西郷区田代', 'サイゴウクタシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県東臼杵郡美郷町西郷区立石', '45', '45431', '8831102', '宮崎県', 'ミヤザキケン', '東臼杵郡美郷町', 'ヒガシウスキグンミサトチョウ', '西郷区立石', 'サイゴウクタテイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県東臼杵郡美郷町西郷区山三ケ', '45', '45431', '8831211', '宮崎県', 'ミヤザキケン', '東臼杵郡美郷町', 'ヒガシウスキグンミサトチョウ', '西郷区山三ケ', 'サイゴウクヤマサンガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県東臼杵郡美郷町西郷区小原', '45', '45431', '8831212', '宮崎県', 'ミヤザキケン', '東臼杵郡美郷町', 'ヒガシウスキグンミサトチョウ', '西郷区小原', 'サイゴウクオバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県東臼杵郡諸塚村', '45', '45429', '8831300', '宮崎県', 'ミヤザキケン', '東臼杵郡諸塚村', 'ヒガシウスキグンモロツカソン', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('116011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県東臼杵郡諸塚村家代', '45', '45429', '8831301', '宮崎県', 'ミヤザキケン', '東臼杵郡諸塚村', 'ヒガシウスキグンモロツカソン', '家代', 'エシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県東臼杵郡諸塚村七ツ山', '45', '45429', '8831302', '宮崎県', 'ミヤザキケン', '東臼杵郡諸塚村', 'ヒガシウスキグンモロツカソン', '七ツ山', 'ナナツヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県東臼杵郡諸塚村七ツ山飯干', '45', '45429', '8831402', '宮崎県', 'ミヤザキケン', '東臼杵郡諸塚村', 'ヒガシウスキグンモロツカソン', '七ツ山', 'ナナツヤマ', null, null, '飯干', 'イイボシ');
INSERT INTO `ms_addresses` VALUES ('116015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県東臼杵郡諸塚村七ツ山小原井', '45', '45429', '8831402', '宮崎県', 'ミヤザキケン', '東臼杵郡諸塚村', 'ヒガシウスキグンモロツカソン', '七ツ山', 'ナナツヤマ', null, null, '小原井', 'オバライ');
INSERT INTO `ms_addresses` VALUES ('116016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県東臼杵郡諸塚村七ツ山川内', '45', '45429', '8831402', '宮崎県', 'ミヤザキケン', '東臼杵郡諸塚村', 'ヒガシウスキグンモロツカソン', '七ツ山', 'ナナツヤマ', null, null, '川内', 'カワウチ');
INSERT INTO `ms_addresses` VALUES ('116017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県東臼杵郡諸塚村七ツ山立岩', '45', '45429', '8831402', '宮崎県', 'ミヤザキケン', '東臼杵郡諸塚村', 'ヒガシウスキグンモロツカソン', '七ツ山', 'ナナツヤマ', null, null, '立岩', 'タテイワ');
INSERT INTO `ms_addresses` VALUES ('116018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県東臼杵郡諸塚村七ツ山八重の平', '45', '45429', '8831402', '宮崎県', 'ミヤザキケン', '東臼杵郡諸塚村', 'ヒガシウスキグンモロツカソン', '七ツ山', 'ナナツヤマ', null, null, '八重の平', 'ハエノヒラ');
INSERT INTO `ms_addresses` VALUES ('116019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県東臼杵郡諸塚村七ツ山本村', '45', '45429', '8831402', '宮崎県', 'ミヤザキケン', '東臼杵郡諸塚村', 'ヒガシウスキグンモロツカソン', '七ツ山', 'ナナツヤマ', null, null, '本村', 'ホンムラ');
INSERT INTO `ms_addresses` VALUES ('116020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道川上郡標茶町多和', '01', '01664', '0883141', '北海道', 'ホッカイドウ', '川上郡標茶町', 'カワカミグンシベチャチョウ', '多和', 'タワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道川上郡標茶町上磯分内', '01', '01664', '0883142', '北海道', 'ホッカイドウ', '川上郡標茶町', 'カワカミグンシベチャチョウ', '上磯分内', 'カミイソブンナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道川上郡標茶町磯分内美幌', '01', '01664', '0883143', '北海道', 'ホッカイドウ', '川上郡標茶町', 'カワカミグンシベチャチョウ', '磯分内美幌', 'イソブンナイビホロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道川上郡標茶町中多和', '01', '01664', '0883144', '北海道', 'ホッカイドウ', '川上郡標茶町', 'カワカミグンシベチャチョウ', '中多和', 'ナカタワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道川上郡標茶町熊牛原野', '01', '01664', '0883145', '北海道', 'ホッカイドウ', '川上郡標茶町', 'カワカミグンシベチャチョウ', '熊牛原野', 'クマウシゲンヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道川上郡標茶町磯分内下', '01', '01664', '0883146', '北海道', 'ホッカイドウ', '川上郡標茶町', 'カワカミグンシベチャチョウ', '磯分内下', 'イソブンナイシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道川上郡標茶町磯分内市街', '01', '01664', '0883147', '北海道', 'ホッカイドウ', '川上郡標茶町', 'カワカミグンシベチャチョウ', '磯分内市街', 'イソブンナイシガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道川上郡標茶町磯分内福島', '01', '01664', '0883148', '北海道', 'ホッカイドウ', '川上郡標茶町', 'カワカミグンシベチャチョウ', '磯分内福島', 'イソブンナイフクシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道川上郡標茶町磯分内乙西', '01', '01664', '0883149', '北海道', 'ホッカイドウ', '川上郡標茶町', 'カワカミグンシベチャチョウ', '磯分内乙西', 'イソブンナイオツニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道川上郡標茶町磯分内上', '01', '01664', '0883151', '北海道', 'ホッカイドウ', '川上郡標茶町', 'カワカミグンシベチャチョウ', '磯分内上', 'イソブンナイカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道川上郡標茶町磯分内協盛', '01', '01664', '0883152', '北海道', 'ホッカイドウ', '川上郡標茶町', 'カワカミグンシベチャチョウ', '磯分内協盛', 'イソブンナイキョウセイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道川上郡標茶町磯分内小林', '01', '01664', '0883153', '北海道', 'ホッカイドウ', '川上郡標茶町', 'カワカミグンシベチャチョウ', '磯分内小林', 'イソブンナイコバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道川上郡標茶町栄', '01', '01664', '0883154', '北海道', 'ホッカイドウ', '川上郡標茶町', 'カワカミグンシベチャチョウ', '栄', 'サカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道川上郡標茶町磯分内平泉', '01', '01664', '0883155', '北海道', 'ホッカイドウ', '川上郡標茶町', 'カワカミグンシベチャチョウ', '磯分内平泉', 'イソブンナイヒライズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道川上郡標茶町磯分内平和', '01', '01664', '0883156', '北海道', 'ホッカイドウ', '川上郡標茶町', 'カワカミグンシベチャチョウ', '磯分内平和', 'イソブンナイヘイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道川上郡標茶町磯分内憩', '01', '01664', '0883157', '北海道', 'ホッカイドウ', '川上郡標茶町', 'カワカミグンシベチャチョウ', '磯分内憩', 'イソブンナイコイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県東臼杵郡椎葉村', '45', '45430', '8831600', '宮崎県', 'ミヤザキケン', '東臼杵郡椎葉村', 'ヒガシウスキグンシイバソン', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('116037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県東臼杵郡椎葉村下福良', '45', '45430', '8831601', '宮崎県', 'ミヤザキケン', '東臼杵郡椎葉村', 'ヒガシウスキグンシイバソン', '下福良', 'シモフクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県東臼杵郡椎葉村大河内', '45', '45430', '8831602', '宮崎県', 'ミヤザキケン', '東臼杵郡椎葉村', 'ヒガシウスキグンシイバソン', '大河内', 'オオカワウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県東臼杵郡椎葉村不土野', '45', '45430', '8831603', '宮崎県', 'ミヤザキケン', '東臼杵郡椎葉村', 'ヒガシウスキグンシイバソン', '不土野', 'フドノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県東臼杵郡椎葉村松尾', '45', '45430', '8831604', '宮崎県', 'ミヤザキケン', '東臼杵郡椎葉村', 'ヒガシウスキグンシイバソン', '松尾', 'マツオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道川上郡弟子屈町', '01', '01665', '0883200', '北海道', 'ホッカイドウ', '川上郡弟子屈町', 'カワカミグンテシカガチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('116042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道川上郡弟子屈町摩周', '01', '01665', '0883201', '北海道', 'ホッカイドウ', '川上郡弟子屈町', 'カワカミグンテシカガチョウ', '摩周', 'マシュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道川上郡弟子屈町鈴蘭', '01', '01665', '0883202', '北海道', 'ホッカイドウ', '川上郡弟子屈町', 'カワカミグンテシカガチョウ', '鈴蘭', 'スズラン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道川上郡弟子屈町湯の島', '01', '01665', '0883203', '北海道', 'ホッカイドウ', '川上郡弟子屈町', 'カワカミグンテシカガチョウ', '湯の島', 'ユノシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道川上郡弟子屈町朝日', '01', '01665', '0883204', '北海道', 'ホッカイドウ', '川上郡弟子屈町', 'カワカミグンテシカガチョウ', '朝日', 'アサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道川上郡弟子屈町中央', '01', '01665', '0883211', '北海道', 'ホッカイドウ', '川上郡弟子屈町', 'カワカミグンテシカガチョウ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道川上郡弟子屈町泉', '01', '01665', '0883212', '北海道', 'ホッカイドウ', '川上郡弟子屈町', 'カワカミグンテシカガチョウ', '泉', 'イズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道川上郡弟子屈町桜丘', '01', '01665', '0883213', '北海道', 'ホッカイドウ', '川上郡弟子屈町', 'カワカミグンテシカガチョウ', '桜丘', 'サクラオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道川上郡弟子屈町高栄', '01', '01665', '0883214', '北海道', 'ホッカイドウ', '川上郡弟子屈町', 'カワカミグンテシカガチョウ', '高栄', 'コウエイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道川上郡弟子屈町美里', '01', '01665', '0883215', '北海道', 'ホッカイドウ', '川上郡弟子屈町', 'カワカミグンテシカガチョウ', '美里', 'ミサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道川上郡弟子屈町鐺別', '01', '01665', '0883221', '北海道', 'ホッカイドウ', '川上郡弟子屈町', 'カワカミグンテシカガチョウ', '鐺別', 'トウベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道川上郡弟子屈町鐺別原野', '01', '01665', '0883221', '北海道', 'ホッカイドウ', '川上郡弟子屈町', 'カワカミグンテシカガチョウ', '鐺別原野', 'トウベツゲンヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道川上郡弟子屈町弟子屈原野', '01', '01665', '0883222', '北海道', 'ホッカイドウ', '川上郡弟子屈町', 'カワカミグンテシカガチョウ', '弟子屈原野', 'テシカガゲンヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道川上郡弟子屈町仁多', '01', '01665', '0883223', '北海道', 'ホッカイドウ', '川上郡弟子屈町', 'カワカミグンテシカガチョウ', '仁多', 'ニタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道川上郡弟子屈町平和', '01', '01665', '0883224', '北海道', 'ホッカイドウ', '川上郡弟子屈町', 'カワカミグンテシカガチョウ', '平和', 'ヘイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道川上郡弟子屈町最栄利別', '01', '01665', '0883225', '北海道', 'ホッカイドウ', '川上郡弟子屈町', 'カワカミグンテシカガチョウ', '最栄利別', 'モエリベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道川上郡弟子屈町奥オソベツ', '01', '01665', '0883226', '北海道', 'ホッカイドウ', '川上郡弟子屈町', 'カワカミグンテシカガチョウ', '奥オソベツ', 'オクオソベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道川上郡弟子屈町重内', '01', '01665', '0883227', '北海道', 'ホッカイドウ', '川上郡弟子屈町', 'カワカミグンテシカガチョウ', '重内', 'オモナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道川上郡弟子屈町奥春別', '01', '01665', '0883228', '北海道', 'ホッカイドウ', '川上郡弟子屈町', 'カワカミグンテシカガチョウ', '奥春別', 'オクシュンベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道川上郡弟子屈町南弟子屈', '01', '01665', '0883271', '北海道', 'ホッカイドウ', '川上郡弟子屈町', 'カワカミグンテシカガチョウ', '南弟子屈', 'ミナミテシカガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道川上郡弟子屈町美留和', '01', '01665', '0883331', '北海道', 'ホッカイドウ', '川上郡弟子屈町', 'カワカミグンテシカガチョウ', '美留和', 'ビルワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道川上郡弟子屈町美留和原野', '01', '01665', '0883331', '北海道', 'ホッカイドウ', '川上郡弟子屈町', 'カワカミグンテシカガチョウ', '美留和原野', 'ビルワゲンヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道川上郡弟子屈町札友内', '01', '01665', '0883332', '北海道', 'ホッカイドウ', '川上郡弟子屈町', 'カワカミグンテシカガチョウ', '札友内', 'サツトモナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道川上郡弟子屈町札友内原野', '01', '01665', '0883332', '北海道', 'ホッカイドウ', '川上郡弟子屈町', 'カワカミグンテシカガチョウ', '札友内原野', 'サツトモナイゲンヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道川上郡弟子屈町屈斜路', '01', '01665', '0883341', '北海道', 'ホッカイドウ', '川上郡弟子屈町', 'カワカミグンテシカガチョウ', '屈斜路', 'クッシヤロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道川上郡弟子屈町屈斜路原野', '01', '01665', '0883341', '北海道', 'ホッカイドウ', '川上郡弟子屈町', 'カワカミグンテシカガチョウ', '屈斜路原野', 'クッシヤロゲンヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道川上郡弟子屈町池の湯', '01', '01665', '0883351', '北海道', 'ホッカイドウ', '川上郡弟子屈町', 'カワカミグンテシカガチョウ', '池の湯', 'イケノユ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道川上郡弟子屈町屈斜路市街地', '01', '01665', '0883351', '北海道', 'ホッカイドウ', '川上郡弟子屈町', 'カワカミグンテシカガチョウ', '屈斜路市街地', 'クッシヤロシガイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道川上郡弟子屈町古丹', '01', '01665', '0883351', '北海道', 'ホッカイドウ', '川上郡弟子屈町', 'カワカミグンテシカガチョウ', '古丹', 'コタン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道川上郡弟子屈町砂湯', '01', '01665', '0883351', '北海道', 'ホッカイドウ', '川上郡弟子屈町', 'カワカミグンテシカガチョウ', '砂湯', 'スナユ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道川上郡弟子屈町跡佐登', '01', '01665', '0883461', '北海道', 'ホッカイドウ', '川上郡弟子屈町', 'カワカミグンテシカガチョウ', '跡佐登', 'アトサノボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道川上郡弟子屈町跡佐登原野', '01', '01665', '0883461', '北海道', 'ホッカイドウ', '川上郡弟子屈町', 'カワカミグンテシカガチョウ', '跡佐登原野', 'アトサノボリゲンヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道川上郡弟子屈町川湯駅前', '01', '01665', '0883462', '北海道', 'ホッカイドウ', '川上郡弟子屈町', 'カワカミグンテシカガチョウ', '川湯駅前', 'カワユエキマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道川上郡弟子屈町アトサヌプリ原野', '01', '01665', '0883463', '北海道', 'ホッカイドウ', '川上郡弟子屈町', 'カワカミグンテシカガチョウ', 'アトサヌプリ原野', 'アトサヌプリゲンヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道川上郡弟子屈町サワンチサップ', '01', '01665', '0883464', '北海道', 'ホッカイドウ', '川上郡弟子屈町', 'カワカミグンテシカガチョウ', 'サワンチサップ', 'サワンチサップ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道川上郡弟子屈町川湯温泉', '01', '01665', '0883465', '北海道', 'ホッカイドウ', '川上郡弟子屈町', 'カワカミグンテシカガチョウ', '川湯温泉', 'カワユオンセン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県児湯郡高鍋町', '45', '45401', '8840000', '宮崎県', 'ミヤザキケン', '児湯郡高鍋町', 'コユグンタカナベチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('116086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県児湯郡高鍋町高鍋町', '45', '45401', '8840001', '宮崎県', 'ミヤザキケン', '児湯郡高鍋町', 'コユグンタカナベチョウ', '高鍋町', 'タカナベマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県児湯郡高鍋町北高鍋', '45', '45401', '8840002', '宮崎県', 'ミヤザキケン', '児湯郡高鍋町', 'コユグンタカナベチョウ', '北高鍋', 'キタタカナベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県児湯郡高鍋町南高鍋', '45', '45401', '8840003', '宮崎県', 'ミヤザキケン', '児湯郡高鍋町', 'コユグンタカナベチョウ', '南高鍋', 'ミナミタカナベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県児湯郡高鍋町蚊口浦', '45', '45401', '8840004', '宮崎県', 'ミヤザキケン', '児湯郡高鍋町', 'コユグンタカナベチョウ', '蚊口浦', 'カグチウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県児湯郡高鍋町持田', '45', '45401', '8840005', '宮崎県', 'ミヤザキケン', '児湯郡高鍋町', 'コユグンタカナベチョウ', '持田', 'モチダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県児湯郡高鍋町上江', '45', '45401', '8840006', '宮崎県', 'ミヤザキケン', '児湯郡高鍋町', 'コユグンタカナベチョウ', '上江', 'ウワエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県児湯郡木城町', '45', '45404', '8840100', '宮崎県', 'ミヤザキケン', '児湯郡木城町', 'コユグンキジョウチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('116093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県児湯郡木城町高城', '45', '45404', '8840101', '宮崎県', 'ミヤザキケン', '児湯郡木城町', 'コユグンキジョウチョウ', '高城', 'タカジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県児湯郡木城町椎木', '45', '45404', '8840102', '宮崎県', 'ミヤザキケン', '児湯郡木城町', 'コユグンキジョウチョウ', '椎木', 'シイノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県児湯郡木城町川原', '45', '45404', '8840103', '宮崎県', 'ミヤザキケン', '児湯郡木城町', 'コユグンキジョウチョウ', '川原', 'カワバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県児湯郡木城町石河内', '45', '45404', '8840104', '宮崎県', 'ミヤザキケン', '児湯郡木城町', 'コユグンキジョウチョウ', '石河内', 'イシカワウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県児湯郡木城町中之又', '45', '45404', '8840105', '宮崎県', 'ミヤザキケン', '児湯郡木城町', 'コユグンキジョウチョウ', '中之又', 'ナカノマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県都城市', '45', '45202', '8850000', '宮崎県', 'ミヤザキケン', '都城市', 'ミヤコノジョウシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('116102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県都城市金田町', '45', '45202', '8850001', '宮崎県', 'ミヤザキケン', '都城市', 'ミヤコノジョウシ', '金田町', 'カナダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県都城市太郎坊町', '45', '45202', '8850002', '宮崎県', 'ミヤザキケン', '都城市', 'ミヤコノジョウシ', '太郎坊町', 'タロボウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県都城市高木町', '45', '45202', '8850003', '宮崎県', 'ミヤザキケン', '都城市', 'ミヤコノジョウシ', '高木町', 'タカギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県都城市都北町', '45', '45202', '8850004', '宮崎県', 'ミヤザキケン', '都城市', 'ミヤコノジョウシ', '都北町', 'トホクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県都城市神之山町', '45', '45202', '8850005', '宮崎県', 'ミヤザキケン', '都城市', 'ミヤコノジョウシ', '神之山町', 'ジンノヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県都城市吉尾町', '45', '45202', '8850006', '宮崎県', 'ミヤザキケン', '都城市', 'ミヤコノジョウシ', '吉尾町', 'ヨシオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県都城市下川東', '45', '45202', '8850011', '宮崎県', 'ミヤザキケン', '都城市', 'ミヤコノジョウシ', '下川東', 'シモカワヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県都城市上川東', '45', '45202', '8850012', '宮崎県', 'ミヤザキケン', '都城市', 'ミヤコノジョウシ', '上川東', 'カミカワヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県都城市郡元町', '45', '45202', '8850013', '宮崎県', 'ミヤザキケン', '都城市', 'ミヤコノジョウシ', '郡元町', 'コオリモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県都城市祝吉町', '45', '45202', '8850014', '宮崎県', 'ミヤザキケン', '都城市', 'ミヤコノジョウシ', '祝吉町', 'イワヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県都城市千町', '45', '45202', '8850015', '宮崎県', 'ミヤザキケン', '都城市', 'ミヤコノジョウシ', '千町', 'センチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県都城市早水町', '45', '45202', '8850016', '宮崎県', 'ミヤザキケン', '都城市', 'ミヤコノジョウシ', '早水町', 'ハヤミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県都城市年見町', '45', '45202', '8850017', '宮崎県', 'ミヤザキケン', '都城市', 'ミヤコノジョウシ', '年見町', 'トシミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県都城市郡元', '45', '45202', '8850018', '宮崎県', 'ミヤザキケン', '都城市', 'ミヤコノジョウシ', '郡元', 'コオリモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県都城市祝吉', '45', '45202', '8850019', '宮崎県', 'ミヤザキケン', '都城市', 'ミヤコノジョウシ', '祝吉', 'イワヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県都城市平江町', '45', '45202', '8850021', '宮崎県', 'ミヤザキケン', '都城市', 'ミヤコノジョウシ', '平江町', 'ヒラエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県都城市小松原町', '45', '45202', '8850022', '宮崎県', 'ミヤザキケン', '都城市', 'ミヤコノジョウシ', '小松原町', 'コマツバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県都城市栄町', '45', '45202', '8850023', '宮崎県', 'ミヤザキケン', '都城市', 'ミヤコノジョウシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県都城市北原町', '45', '45202', '8850024', '宮崎県', 'ミヤザキケン', '都城市', 'ミヤコノジョウシ', '北原町', 'キタハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県都城市前田町', '45', '45202', '8850025', '宮崎県', 'ミヤザキケン', '都城市', 'ミヤコノジョウシ', '前田町', 'マエダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県都城市大王町', '45', '45202', '8850026', '宮崎県', 'ミヤザキケン', '都城市', 'ミヤコノジョウシ', '大王町', 'ダイオウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県都城市天神町', '45', '45202', '8850031', '宮崎県', 'ミヤザキケン', '都城市', 'ミヤコノジョウシ', '天神町', 'テンジンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県都城市中原町', '45', '45202', '8850032', '宮崎県', 'ミヤザキケン', '都城市', 'ミヤコノジョウシ', '中原町', 'ナカハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県都城市妻ケ丘町', '45', '45202', '8850033', '宮崎県', 'ミヤザキケン', '都城市', 'ミヤコノジョウシ', '妻ケ丘町', 'ツマガオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県都城市菖蒲原町', '45', '45202', '8850034', '宮崎県', 'ミヤザキケン', '都城市', 'ミヤコノジョウシ', '菖蒲原町', 'アヤメバルチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県都城市立野町', '45', '45202', '8850035', '宮崎県', 'ミヤザキケン', '都城市', 'ミヤコノジョウシ', '立野町', 'タテノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県都城市広原町', '45', '45202', '8850036', '宮崎県', 'ミヤザキケン', '都城市', 'ミヤコノジョウシ', '広原町', 'ヒロハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県都城市花繰町', '45', '45202', '8850037', '宮崎県', 'ミヤザキケン', '都城市', 'ミヤコノジョウシ', '花繰町', 'ハナグリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県都城市一万城町', '45', '45202', '8850041', '宮崎県', 'ミヤザキケン', '都城市', 'ミヤコノジョウシ', '一万城町', 'イチマンジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県都城市上長飯町', '45', '45202', '8850042', '宮崎県', 'ミヤザキケン', '都城市', 'ミヤコノジョウシ', '上長飯町', 'カミナガエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県都城市豊満町', '45', '45202', '8850043', '宮崎県', 'ミヤザキケン', '都城市', 'ミヤコノジョウシ', '豊満町', 'トヨミツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県都城市安久町', '45', '45202', '8850044', '宮崎県', 'ミヤザキケン', '都城市', 'ミヤコノジョウシ', '安久町', 'ヤスヒサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県都城市蔵原町', '45', '45202', '8850051', '宮崎県', 'ミヤザキケン', '都城市', 'ミヤコノジョウシ', '蔵原町', 'クラハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県都城市東町', '45', '45202', '8850052', '宮崎県', 'ミヤザキケン', '都城市', 'ミヤコノジョウシ', '東町', 'ヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県都城市上東町', '45', '45202', '8850053', '宮崎県', 'ミヤザキケン', '都城市', 'ミヤコノジョウシ', '上東町', 'カミヒガシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県都城市若葉町', '45', '45202', '8850054', '宮崎県', 'ミヤザキケン', '都城市', 'ミヤコノジョウシ', '若葉町', 'ワカバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県都城市早鈴町', '45', '45202', '8850055', '宮崎県', 'ミヤザキケン', '都城市', 'ミヤコノジョウシ', '早鈴町', 'ハヤスズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県都城市下長飯町', '45', '45202', '8850061', '宮崎県', 'ミヤザキケン', '都城市', 'ミヤコノジョウシ', '下長飯町', 'シモナガエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県都城市大岩田町', '45', '45202', '8850062', '宮崎県', 'ミヤザキケン', '都城市', 'ミヤコノジョウシ', '大岩田町', 'オオイワダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県都城市梅北町', '45', '45202', '8850063', '宮崎県', 'ミヤザキケン', '都城市', 'ミヤコノジョウシ', '梅北町', 'ウメキタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県都城市今町', '45', '45202', '8850064', '宮崎県', 'ミヤザキケン', '都城市', 'ミヤコノジョウシ', '今町', 'イママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県都城市中町', '45', '45202', '8850071', '宮崎県', 'ミヤザキケン', '都城市', 'ミヤコノジョウシ', '中町', 'ナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県都城市上町', '45', '45202', '8850072', '宮崎県', 'ミヤザキケン', '都城市', 'ミヤコノジョウシ', '上町', 'カンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県都城市姫城町', '45', '45202', '8850073', '宮崎県', 'ミヤザキケン', '都城市', 'ミヤコノジョウシ', '姫城町', 'ヒメギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県都城市甲斐元町', '45', '45202', '8850074', '宮崎県', 'ミヤザキケン', '都城市', 'ミヤコノジョウシ', '甲斐元町', 'カイモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県都城市八幡町', '45', '45202', '8850075', '宮崎県', 'ミヤザキケン', '都城市', 'ミヤコノジョウシ', '八幡町', 'ハチマンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県都城市西町', '45', '45202', '8850076', '宮崎県', 'ミヤザキケン', '都城市', 'ミヤコノジョウシ', '西町', 'ニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県都城市松元町', '45', '45202', '8850077', '宮崎県', 'ミヤザキケン', '都城市', 'ミヤコノジョウシ', '松元町', 'マツモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県都城市宮丸町', '45', '45202', '8850078', '宮崎県', 'ミヤザキケン', '都城市', 'ミヤコノジョウシ', '宮丸町', 'ミヤマルチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県都城市牟田町', '45', '45202', '8850079', '宮崎県', 'ミヤザキケン', '都城市', 'ミヤコノジョウシ', '牟田町', 'ムタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県都城市鷹尾', '45', '45202', '8850081', '宮崎県', 'ミヤザキケン', '都城市', 'ミヤコノジョウシ', '鷹尾', 'タカオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県都城市南鷹尾町', '45', '45202', '8850082', '宮崎県', 'ミヤザキケン', '都城市', 'ミヤコノジョウシ', '南鷹尾町', 'ミナミタカオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県都城市都島町', '45', '45202', '8850083', '宮崎県', 'ミヤザキケン', '都城市', 'ミヤコノジョウシ', '都島町', 'ミヤコジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県都城市五十町', '45', '45202', '8850084', '宮崎県', 'ミヤザキケン', '都城市', 'ミヤコノジョウシ', '五十町', 'ゴジッチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県都城市平塚町', '45', '45202', '8850085', '宮崎県', 'ミヤザキケン', '都城市', 'ミヤコノジョウシ', '平塚町', 'ヒラツカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県都城市久保原町', '45', '45202', '8850086', '宮崎県', 'ミヤザキケン', '都城市', 'ミヤコノジョウシ', '久保原町', 'クボバルチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県都城市横市町', '45', '45202', '8850091', '宮崎県', 'ミヤザキケン', '都城市', 'ミヤコノジョウシ', '横市町', 'ヨコイチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県都城市南横市町', '45', '45202', '8850092', '宮崎県', 'ミヤザキケン', '都城市', 'ミヤコノジョウシ', '南横市町', 'ミナミヨコイチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県都城市志比田町', '45', '45202', '8850093', '宮崎県', 'ミヤザキケン', '都城市', 'ミヤコノジョウシ', '志比田町', 'シビタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県都城市都原町', '45', '45202', '8850094', '宮崎県', 'ミヤザキケン', '都城市', 'ミヤコノジョウシ', '都原町', 'ミヤコバルチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県都城市蓑原町', '45', '45202', '8850095', '宮崎県', 'ミヤザキケン', '都城市', 'ミヤコノジョウシ', '蓑原町', 'ミノバルチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県都城市菓子野町', '45', '45202', '8850111', '宮崎県', 'ミヤザキケン', '都城市', 'ミヤコノジョウシ', '菓子野町', 'カシノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県都城市乙房町', '45', '45202', '8850112', '宮崎県', 'ミヤザキケン', '都城市', 'ミヤコノジョウシ', '乙房町', 'オトボウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県都城市関之尾町', '45', '45202', '8850113', '宮崎県', 'ミヤザキケン', '都城市', 'ミヤコノジョウシ', '関之尾町', 'セキノオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県都城市庄内町', '45', '45202', '8850114', '宮崎県', 'ミヤザキケン', '都城市', 'ミヤコノジョウシ', '庄内町', 'ショウナイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県都城市高野町', '45', '45202', '8850221', '宮崎県', 'ミヤザキケン', '都城市', 'ミヤコノジョウシ', '高野町', 'タカノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県都城市美川町', '45', '45202', '8850222', '宮崎県', 'ミヤザキケン', '都城市', 'ミヤコノジョウシ', '美川町', 'ミカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県都城市吉之元町', '45', '45202', '8850223', '宮崎県', 'ミヤザキケン', '都城市', 'ミヤコノジョウシ', '吉之元町', 'ヨシノモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県都城市御池町', '45', '45202', '8850224', '宮崎県', 'ミヤザキケン', '都城市', 'ミヤコノジョウシ', '御池町', 'ミイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県都城市夏尾町', '45', '45202', '8850225', '宮崎県', 'ミヤザキケン', '都城市', 'ミヤコノジョウシ', '夏尾町', 'ナツオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県都城市岩満町', '45', '45202', '8851101', '宮崎県', 'ミヤザキケン', '都城市', 'ミヤコノジョウシ', '岩満町', 'イワミツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県都城市下水流町', '45', '45202', '8851102', '宮崎県', 'ミヤザキケン', '都城市', 'ミヤコノジョウシ', '下水流町', 'シモズルチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県都城市上水流町', '45', '45202', '8851103', '宮崎県', 'ミヤザキケン', '都城市', 'ミヤコノジョウシ', '上水流町', 'カミズルチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県都城市野々美谷町', '45', '45202', '8851104', '宮崎県', 'ミヤザキケン', '都城市', 'ミヤコノジョウシ', '野々美谷町', 'ノノミタニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県都城市丸谷町', '45', '45202', '8851105', '宮崎県', 'ミヤザキケン', '都城市', 'ミヤコノジョウシ', '丸谷町', 'マルタニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県都城市高城町高城', '45', '45202', '8851201', '宮崎県', 'ミヤザキケン', '都城市', 'ミヤコノジョウシ', '高城町高城', 'タカジョウチョウタカジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県都城市高城町穂満坊', '45', '45202', '8851202', '宮崎県', 'ミヤザキケン', '都城市', 'ミヤコノジョウシ', '高城町穂満坊', 'タカジョウチョウホマンボウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県都城市高城町大井手', '45', '45202', '8851203', '宮崎県', 'ミヤザキケン', '都城市', 'ミヤコノジョウシ', '高城町大井手', 'タカジョウチョウオオイデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県都城市高城町桜木', '45', '45202', '8851204', '宮崎県', 'ミヤザキケン', '都城市', 'ミヤコノジョウシ', '高城町桜木', 'タカジョウチョウサクラギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県都城市高城町石山', '45', '45202', '8851205', '宮崎県', 'ミヤザキケン', '都城市', 'ミヤコノジョウシ', '高城町石山', 'タカジョウチョウイシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県都城市高城町有水', '45', '45202', '8851311', '宮崎県', 'ミヤザキケン', '都城市', 'ミヤコノジョウシ', '高城町有水', 'タカジョウチョウアリミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県都城市高城町四家', '45', '45202', '8851312', '宮崎県', 'ミヤザキケン', '都城市', 'ミヤコノジョウシ', '高城町四家', 'タカジョウチョウシカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県小林市', '45', '45205', '8860000', '宮崎県', 'ミヤザキケン', '小林市', 'コバヤシシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('116201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県小林市東方', '45', '45205', '8860001', '宮崎県', 'ミヤザキケン', '小林市', 'コバヤシシ', '東方', 'ヒガシカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県小林市水流迫', '45', '45205', '8860002', '宮崎県', 'ミヤザキケン', '小林市', 'コバヤシシ', '水流迫', 'ツルザコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県小林市堤', '45', '45205', '8860003', '宮崎県', 'ミヤザキケン', '小林市', 'コバヤシシ', '堤', 'ツツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県小林市細野', '45', '45205', '8860004', '宮崎県', 'ミヤザキケン', '小林市', 'コバヤシシ', '細野', 'ホソノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県小林市南西方', '45', '45205', '8860005', '宮崎県', 'ミヤザキケン', '小林市', 'コバヤシシ', '南西方', 'ミナミニシカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県小林市北西方', '45', '45205', '8860006', '宮崎県', 'ミヤザキケン', '小林市', 'コバヤシシ', '北西方', 'キタニシカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県小林市真方', '45', '45205', '8860007', '宮崎県', 'ミヤザキケン', '小林市', 'コバヤシシ', '真方', 'マガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県小林市本町', '45', '45205', '8860008', '宮崎県', 'ミヤザキケン', '小林市', 'コバヤシシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県小林市東方木浦木', '45', '45205', '8860101', '宮崎県', 'ミヤザキケン', '小林市', 'コバヤシシ', '東方', 'ヒガシカタ', null, null, '木浦木', 'キウラキ');
INSERT INTO `ms_addresses` VALUES ('116210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県小林市須木中原', '45', '45205', '8860111', '宮崎県', 'ミヤザキケン', '小林市', 'コバヤシシ', '須木中原', 'スキナカハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県小林市須木下田', '45', '45205', '8860112', '宮崎県', 'ミヤザキケン', '小林市', 'コバヤシシ', '須木下田', 'スキシモダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県小林市須木鳥田町', '45', '45205', '8860113', '宮崎県', 'ミヤザキケン', '小林市', 'コバヤシシ', '須木鳥田町', 'スキトリダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県小林市須木奈佐木', '45', '45205', '8860114', '宮崎県', 'ミヤザキケン', '小林市', 'コバヤシシ', '須木奈佐木', 'スキナサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県小林市須木内山', '45', '45205', '8860115', '宮崎県', 'ミヤザキケン', '小林市', 'コバヤシシ', '須木内山', 'スキウチヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県西諸県郡野尻町', '45', '45362', '8860200', '宮崎県', 'ミヤザキケン', '西諸県郡野尻町', 'ニシモロカタグンノジリチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('116217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県東諸県郡綾町南俣釜牟田', '45', '45383', '8860203', '宮崎県', 'ミヤザキケン', '東諸県郡綾町', 'ヒガシモロカタグンアヤチョウ', '南俣', 'ミナミマタ', null, null, '釜牟田', 'カマムタ');
INSERT INTO `ms_addresses` VALUES ('116218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県西諸県郡野尻町紙屋', '45', '45362', '8860211', '宮崎県', 'ミヤザキケン', '西諸県郡野尻町', 'ニシモロカタグンノジリチョウ', '紙屋', 'カミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県西諸県郡野尻町東麓', '45', '45362', '8860212', '宮崎県', 'ミヤザキケン', '西諸県郡野尻町', 'ニシモロカタグンノジリチョウ', '東麓', 'ヒガシフモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県西諸県郡野尻町三ケ野山', '45', '45362', '8860213', '宮崎県', 'ミヤザキケン', '西諸県郡野尻町', 'ニシモロカタグンノジリチョウ', '三ケ野山', 'ミカノヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日南市', '45', '45204', '8870000', '宮崎県', 'ミヤザキケン', '日南市', 'ニチナンシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('116237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日南市油津', '45', '45204', '8870001', '宮崎県', 'ミヤザキケン', '日南市', 'ニチナンシ', '油津', 'アブラツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日南市西町', '45', '45204', '8870002', '宮崎県', 'ミヤザキケン', '日南市', 'ニチナンシ', '西町', 'ニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日南市瀬西', '45', '45204', '8870003', '宮崎県', 'ミヤザキケン', '日南市', 'ニチナンシ', '瀬西', 'セニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日南市天福', '45', '45204', '8870004', '宮崎県', 'ミヤザキケン', '日南市', 'ニチナンシ', '天福', 'テンプク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日南市材木町', '45', '45204', '8870005', '宮崎県', 'ミヤザキケン', '日南市', 'ニチナンシ', '材木町', 'ザイモクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日南市春日町', '45', '45204', '8870006', '宮崎県', 'ミヤザキケン', '日南市', 'ニチナンシ', '春日町', 'カスガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日南市乙姫町', '45', '45204', '8870007', '宮崎県', 'ミヤザキケン', '日南市', 'ニチナンシ', '乙姫町', 'オトヒメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日南市瀬貝', '45', '45204', '8870011', '宮崎県', 'ミヤザキケン', '日南市', 'ニチナンシ', '瀬貝', 'セガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日南市園田', '45', '45204', '8870012', '宮崎県', 'ミヤザキケン', '日南市', 'ニチナンシ', '園田', 'ソノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日南市木山', '45', '45204', '8870013', '宮崎県', 'ミヤザキケン', '日南市', 'ニチナンシ', '木山', 'キヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日南市岩崎', '45', '45204', '8870014', '宮崎県', 'ミヤザキケン', '日南市', 'ニチナンシ', '岩崎', 'イワサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日南市平野', '45', '45204', '8870015', '宮崎県', 'ミヤザキケン', '日南市', 'ニチナンシ', '平野', 'ヒラノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日南市中平野', '45', '45204', '8870016', '宮崎県', 'ミヤザキケン', '日南市', 'ニチナンシ', '中平野', 'ナカヒラノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日南市梅ケ浜', '45', '45204', '8870017', '宮崎県', 'ミヤザキケン', '日南市', 'ニチナンシ', '梅ケ浜', 'ウメガハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日南市中央通', '45', '45204', '8870021', '宮崎県', 'ミヤザキケン', '日南市', 'ニチナンシ', '中央通', 'チュウオウドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日南市上平野町', '45', '45204', '8870022', '宮崎県', 'ミヤザキケン', '日南市', 'ニチナンシ', '上平野町', 'カミヒラノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日南市隈谷', '45', '45204', '8870023', '宮崎県', 'ミヤザキケン', '日南市', 'ニチナンシ', '隈谷', 'クマヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日南市西弁分', '45', '45204', '8870024', '宮崎県', 'ミヤザキケン', '日南市', 'ニチナンシ', '西弁分', 'ニシベンブン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日南市戸高', '45', '45204', '8870031', '宮崎県', 'ミヤザキケン', '日南市', 'ニチナンシ', '戸高', 'トダカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日南市益安', '45', '45204', '8870032', '宮崎県', 'ミヤザキケン', '日南市', 'ニチナンシ', '益安', 'マスヤス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日南市平山', '45', '45204', '8870033', '宮崎県', 'ミヤザキケン', '日南市', 'ニチナンシ', '平山', 'ヒラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日南市風田', '45', '45204', '8870034', '宮崎県', 'ミヤザキケン', '日南市', 'ニチナンシ', '風田', 'カゼダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日南市吾田東1丁目', '45', '45204', '8870041', '宮崎県', 'ミヤザキケン', '日南市', 'ニチナンシ', '吾田東', 'アガタヒガシ', null, null, '1丁目', '01チョウメ');
INSERT INTO `ms_addresses` VALUES ('116260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日南市吾田東2丁目', '45', '45204', '8870041', '宮崎県', 'ミヤザキケン', '日南市', 'ニチナンシ', '吾田東', 'アガタヒガシ', null, null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('116261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日南市吾田東3丁目', '45', '45204', '8870041', '宮崎県', 'ミヤザキケン', '日南市', 'ニチナンシ', '吾田東', 'アガタヒガシ', null, null, '3丁目', '03チョウメ');
INSERT INTO `ms_addresses` VALUES ('116262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日南市吾田東4丁目', '45', '45204', '8870041', '宮崎県', 'ミヤザキケン', '日南市', 'ニチナンシ', '吾田東', 'アガタヒガシ', null, null, '4丁目', '04チョウメ');
INSERT INTO `ms_addresses` VALUES ('116263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日南市宮浦', '45', '45204', '8870101', '宮崎県', 'ミヤザキケン', '日南市', 'ニチナンシ', '宮浦', 'ミヤウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日南市富土', '45', '45204', '8870102', '宮崎県', 'ミヤザキケン', '日南市', 'ニチナンシ', '富土', 'フト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県串間市', '45', '45207', '8880000', '宮崎県', 'ミヤザキケン', '串間市', 'クシマシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('116268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県串間市西方', '45', '45207', '8880001', '宮崎県', 'ミヤザキケン', '串間市', 'クシマシ', '西方', 'ニシカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県串間市高松', '45', '45207', '8880002', '宮崎県', 'ミヤザキケン', '串間市', 'クシマシ', '高松', 'タカマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県串間市奴久見', '45', '45207', '8880003', '宮崎県', 'ミヤザキケン', '串間市', 'クシマシ', '奴久見', 'ヌクミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県串間市串間', '45', '45207', '8880004', '宮崎県', 'ミヤザキケン', '串間市', 'クシマシ', '串間', 'クシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県串間市北方', '45', '45207', '8880005', '宮崎県', 'ミヤザキケン', '串間市', 'クシマシ', '北方', 'キタカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県串間市秋山', '45', '45207', '8880006', '宮崎県', 'ミヤザキケン', '串間市', 'クシマシ', '秋山', 'アキヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県串間市南方', '45', '45207', '8880007', '宮崎県', 'ミヤザキケン', '串間市', 'クシマシ', '南方', 'ミナミカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県串間市本城', '45', '45207', '8880008', '宮崎県', 'ミヤザキケン', '串間市', 'クシマシ', '本城', 'ホンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県串間市崎田', '45', '45207', '8880009', '宮崎県', 'ミヤザキケン', '串間市', 'クシマシ', '崎田', 'サキダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県串間市寺里', '45', '45207', '8880011', '宮崎県', 'ミヤザキケン', '串間市', 'クシマシ', '寺里', 'テラザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県串間市西浜', '45', '45207', '8880012', '宮崎県', 'ミヤザキケン', '串間市', 'クシマシ', '西浜', 'ニシハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県串間市東町', '45', '45207', '8880013', '宮崎県', 'ミヤザキケン', '串間市', 'クシマシ', '東町', 'ヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県串間市大納', '45', '45207', '8880221', '宮崎県', 'ミヤザキケン', '串間市', 'クシマシ', '大納', 'オオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県串間市都井', '45', '45207', '8880222', '宮崎県', 'ミヤザキケン', '串間市', 'クシマシ', '都井', 'トイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市北川町川内名', '45', '45203', '8890101', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '北川町川内名', 'キタガワマチカワチミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市北川町長井', '45', '45203', '8890102', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '北川町長井', 'キタガワマチナガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市北浦町古江', '45', '45203', '8890301', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '北浦町古江', 'キタウラマチフルエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市北浦町市振', '45', '45203', '8890302', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '北浦町市振', 'キタウラマチイチブリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市北浦町宮野浦', '45', '45203', '8890303', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '北浦町宮野浦', 'キタウラマチミヤノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市北浦町三川内', '45', '45203', '8890304', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '北浦町三川内', 'キタウラマチミカワウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市須美江町', '45', '45203', '8890321', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '須美江町', 'スミエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市熊野江町', '45', '45203', '8890322', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '熊野江町', 'クマノエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市石田町', '45', '45203', '8890501', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '石田町', 'イシダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市上伊形町', '45', '45203', '8890502', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '上伊形町', 'カミイガダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市伊形町', '45', '45203', '8890503', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '伊形町', 'イガダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市下伊形町', '45', '45203', '8890504', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '下伊形町', 'シモイガダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市北一ケ岡', '45', '45203', '8890505', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '北一ケ岡', 'キタヒトツガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市南一ケ岡', '45', '45203', '8890506', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '南一ケ岡', 'ミナミヒトツガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市旭ケ丘', '45', '45203', '8890507', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '旭ケ丘', 'アサヒガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市松原町', '45', '45203', '8890511', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '松原町', 'マツバラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市新浜町', '45', '45203', '8890512', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '新浜町', 'シンハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市土々呂町', '45', '45203', '8890513', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '土々呂町', 'トトロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市櫛津町', '45', '45203', '8890514', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '櫛津町', 'クシツマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市妙見町', '45', '45203', '8890515', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '妙見町', 'ミョウケンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市鯛名町', '45', '45203', '8890516', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '鯛名町', 'タイナマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県延岡市赤水町', '45', '45203', '8890517', '宮崎県', 'ミヤザキケン', '延岡市', 'ノベオカシ', '赤水町', 'アカミズマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県東臼杵郡門川町', '45', '45421', '8890600', '宮崎県', 'ミヤザキケン', '東臼杵郡門川町', 'ヒガシウスキグンカドガワチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('116310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県東臼杵郡門川町須賀崎', '45', '45421', '8890601', '宮崎県', 'ミヤザキケン', '東臼杵郡門川町', 'ヒガシウスキグンカドガワチョウ', '須賀崎', 'スガサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県東臼杵郡門川町庵川', '45', '45421', '8890602', '宮崎県', 'ミヤザキケン', '東臼杵郡門川町', 'ヒガシウスキグンカドガワチョウ', '庵川', 'イオリガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県東臼杵郡門川町加草', '45', '45421', '8890603', '宮崎県', 'ミヤザキケン', '東臼杵郡門川町', 'ヒガシウスキグンカドガワチョウ', '加草', 'カクサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県東臼杵郡門川町川内', '45', '45421', '8890604', '宮崎県', 'ミヤザキケン', '東臼杵郡門川町', 'ヒガシウスキグンカドガワチョウ', '川内', 'カワチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県東臼杵郡門川町庵川西', '45', '45421', '8890605', '宮崎県', 'ミヤザキケン', '東臼杵郡門川町', 'ヒガシウスキグンカドガワチョウ', '庵川西', 'イオリガワニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県東臼杵郡門川町門川尾末', '45', '45421', '8890611', '宮崎県', 'ミヤザキケン', '東臼杵郡門川町', 'ヒガシウスキグンカドガワチョウ', '門川尾末', 'カドカワオズエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県東臼杵郡門川町中須', '45', '45421', '8890612', '宮崎県', 'ミヤザキケン', '東臼杵郡門川町', 'ヒガシウスキグンカドガワチョウ', '中須', 'ナカス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県東臼杵郡門川町本町', '45', '45421', '8890613', '宮崎県', 'ミヤザキケン', '東臼杵郡門川町', 'ヒガシウスキグンカドガワチョウ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県東臼杵郡門川町上町', '45', '45421', '8890614', '宮崎県', 'ミヤザキケン', '東臼杵郡門川町', 'ヒガシウスキグンカドガワチョウ', '上町', 'カミノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県東臼杵郡門川町栄ケ丘', '45', '45421', '8890615', '宮崎県', 'ミヤザキケン', '東臼杵郡門川町', 'ヒガシウスキグンカドガワチョウ', '栄ケ丘', 'サカエガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県東臼杵郡門川町南町', '45', '45421', '8890616', '宮崎県', 'ミヤザキケン', '東臼杵郡門川町', 'ヒガシウスキグンカドガワチョウ', '南町', 'ミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県東臼杵郡門川町南ケ丘', '45', '45421', '8890617', '宮崎県', 'ミヤザキケン', '東臼杵郡門川町', 'ヒガシウスキグンカドガワチョウ', '南ケ丘', 'ミナミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県東臼杵郡門川町東栄町', '45', '45421', '8890621', '宮崎県', 'ミヤザキケン', '東臼杵郡門川町', 'ヒガシウスキグンカドガワチョウ', '東栄町', 'ヒガシサカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県東臼杵郡門川町西栄町', '45', '45421', '8890622', '宮崎県', 'ミヤザキケン', '東臼杵郡門川町', 'ヒガシウスキグンカドガワチョウ', '西栄町', 'ニシサカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県東臼杵郡門川町宮ケ原', '45', '45421', '8890623', '宮崎県', 'ミヤザキケン', '東臼杵郡門川町', 'ヒガシウスキグンカドガワチョウ', '宮ケ原', 'ミヤガハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県東臼杵郡門川町城ケ丘', '45', '45421', '8890624', '宮崎県', 'ミヤザキケン', '東臼杵郡門川町', 'ヒガシウスキグンカドガワチョウ', '城ケ丘', 'ジョウガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県東臼杵郡門川町平城東', '45', '45421', '8890625', '宮崎県', 'ミヤザキケン', '東臼杵郡門川町', 'ヒガシウスキグンカドガワチョウ', '平城東', 'ヒラジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県東臼杵郡門川町平城西', '45', '45421', '8890626', '宮崎県', 'ミヤザキケン', '東臼杵郡門川町', 'ヒガシウスキグンカドガワチョウ', '平城西', 'ヒラジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県東臼杵郡美郷町北郷区宇納間', '45', '45431', '8890901', '宮崎県', 'ミヤザキケン', '東臼杵郡美郷町', 'ヒガシウスキグンミサトチョウ', '北郷区宇納間', 'キタゴウクウナマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県東臼杵郡美郷町北郷区入下', '45', '45431', '8890902', '宮崎県', 'ミヤザキケン', '東臼杵郡美郷町', 'ヒガシウスキグンミサトチョウ', '北郷区入下', 'キタゴウクニュウシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県東臼杵郡美郷町北郷区黒木', '45', '45431', '8890903', '宮崎県', 'ミヤザキケン', '東臼杵郡美郷町', 'ヒガシウスキグンミサトチョウ', '北郷区黒木', 'キタゴウククロギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日向市東郷町山陰乙鳥川', '45', '45206', '8891101', '宮崎県', 'ミヤザキケン', '日向市', 'ヒュウガシ', '東郷町山陰乙', 'トウゴウチョウヤマゲオツ', null, null, '鳥川', 'トリカワ');
INSERT INTO `ms_addresses` VALUES ('116338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日向市美々津町', '45', '45206', '8891111', '宮崎県', 'ミヤザキケン', '日向市', 'ヒュウガシ', '美々津町', 'ミミツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日向市幸脇', '45', '45206', '8891112', '宮崎県', 'ミヤザキケン', '日向市', 'ヒュウガシ', '幸脇', 'サイワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日向市東郷町山陰甲', '45', '45206', '8891121', '宮崎県', 'ミヤザキケン', '日向市', 'ヒュウガシ', '東郷町山陰甲', 'トウゴウチョウヤマゲコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県児湯郡都農町', '45', '45406', '8891200', '宮崎県', 'ミヤザキケン', '児湯郡都農町', 'コユグンツノチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('116343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県児湯郡都農町川北', '45', '45406', '8891201', '宮崎県', 'ミヤザキケン', '児湯郡都農町', 'コユグンツノチョウ', '川北', 'カワキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県児湯郡川南町', '45', '45405', '8891300', '宮崎県', 'ミヤザキケン', '児湯郡川南町', 'コユグンカワミナミチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('116345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県児湯郡川南町川南', '45', '45405', '8891301', '宮崎県', 'ミヤザキケン', '児湯郡川南町', 'コユグンカワミナミチョウ', '川南', 'カワミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県児湯郡川南町平田', '45', '45405', '8891302', '宮崎県', 'ミヤザキケン', '児湯郡川南町', 'コユグンカワミナミチョウ', '平田', 'ヘイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県児湯郡新富町', '45', '45402', '8891400', '宮崎県', 'ミヤザキケン', '児湯郡新富町', 'コユグンシントミチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('116348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県児湯郡新富町日置', '45', '45402', '8891401', '宮崎県', 'ミヤザキケン', '児湯郡新富町', 'コユグンシントミチョウ', '日置', 'ヒオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県児湯郡新富町三納代', '45', '45402', '8891402', '宮崎県', 'ミヤザキケン', '児湯郡新富町', 'コユグンシントミチョウ', '三納代', 'ミナシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県児湯郡新富町上富田', '45', '45402', '8891403', '宮崎県', 'ミヤザキケン', '児湯郡新富町', 'コユグンシントミチョウ', '上富田', 'カミトンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県児湯郡新富町下富田', '45', '45402', '8891404', '宮崎県', 'ミヤザキケン', '児湯郡新富町', 'コユグンシントミチョウ', '下富田', 'シモトンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県児湯郡新富町伊倉', '45', '45402', '8891405', '宮崎県', 'ミヤザキケン', '児湯郡新富町', 'コユグンシントミチョウ', '伊倉', 'イクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県児湯郡新富町新田', '45', '45402', '8891406', '宮崎県', 'ミヤザキケン', '児湯郡新富町', 'コユグンシントミチョウ', '新田', 'ニュウタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県児湯郡新富町富田', '45', '45402', '8891411', '宮崎県', 'ミヤザキケン', '児湯郡新富町', 'コユグンシントミチョウ', '富田', 'トンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県児湯郡新富町富田東', '45', '45402', '8891412', '宮崎県', 'ミヤザキケン', '児湯郡新富町', 'コユグンシントミチョウ', '富田東', 'トンダヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県児湯郡新富町富田西', '45', '45402', '8891413', '宮崎県', 'ミヤザキケン', '児湯郡新富町', 'コユグンシントミチョウ', '富田西', 'トンダニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県児湯郡新富町富田南', '45', '45402', '8891414', '宮崎県', 'ミヤザキケン', '児湯郡新富町', 'コユグンシントミチョウ', '富田南', 'トンダミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県児湯郡新富町富田北', '45', '45402', '8891415', '宮崎県', 'ミヤザキケン', '児湯郡新富町', 'コユグンシントミチョウ', '富田北', 'トンダキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎郡清武町', '45', '45301', '8891600', '宮崎県', 'ミヤザキケン', '宮崎郡清武町', 'ミヤザキグンキヨタケチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('116364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎郡清武町木原', '45', '45301', '8891601', '宮崎県', 'ミヤザキケン', '宮崎郡清武町', 'ミヤザキグンキヨタケチョウ', '木原', 'キハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎郡清武町今泉', '45', '45301', '8891602', '宮崎県', 'ミヤザキケン', '宮崎郡清武町', 'ミヤザキグンキヨタケチョウ', '今泉', 'イマイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎郡清武町正手', '45', '45301', '8891603', '宮崎県', 'ミヤザキケン', '宮崎郡清武町', 'ミヤザキグンキヨタケチョウ', '正手', 'ショウデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎郡清武町船引', '45', '45301', '8891604', '宮崎県', 'ミヤザキケン', '宮崎郡清武町', 'ミヤザキグンキヨタケチョウ', '船引', 'フナヒキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎郡清武町加納', '45', '45301', '8891605', '宮崎県', 'ミヤザキケン', '宮崎郡清武町', 'ミヤザキグンキヨタケチョウ', '加納', 'カノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎郡清武町池田台', '45', '45301', '8891606', '宮崎県', 'ミヤザキケン', '宮崎郡清武町', 'ミヤザキグンキヨタケチョウ', '池田台', 'イケダダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎郡清武町加納', '45', '45301', '8891607', '宮崎県', 'ミヤザキケン', '宮崎郡清武町', 'ミヤザキグンキヨタケチョウ', '加納', 'カノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎郡清武町池田台北', '45', '45301', '8891608', '宮崎県', 'ミヤザキケン', '宮崎郡清武町', 'ミヤザキグンキヨタケチョウ', '池田台北', 'イケダダイキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎郡清武町あさひ', '45', '45301', '8891609', '宮崎県', 'ミヤザキケン', '宮崎郡清武町', 'ミヤザキグンキヨタケチョウ', 'あさひ', 'アサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎郡清武町新町', '45', '45301', '8891611', '宮崎県', 'ミヤザキケン', '宮崎郡清武町', 'ミヤザキグンキヨタケチョウ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市田野町甲', '45', '45201', '8891701', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '田野町甲', 'タノチョウコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市田野町乙', '45', '45201', '8891702', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '田野町乙', 'タノチョウオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市田野町あけぼの', '45', '45201', '8891703', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '田野町あけぼの', 'タノチョウアケボノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市高岡町上倉永', '45', '45201', '8891713', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '高岡町上倉永', 'タカオカチョウカミクラナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市高岡町上倉永内の八重', '45', '45201', '8891713', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '高岡町上倉永', 'タカオカチョウカミクラナガ', null, null, '内の八重', 'ウチノヤエ');
INSERT INTO `ms_addresses` VALUES ('116383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市細江平和', '45', '45201', '8891716', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '細江', 'ホソエ', null, null, '平和', 'ヘイワ');
INSERT INTO `ms_addresses` VALUES ('116385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県都城市山之口町富吉', '45', '45202', '8891801', '宮崎県', 'ミヤザキケン', '都城市', 'ミヤコノジョウシ', '山之口町富吉', 'ヤマノクチチョウトミヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県都城市山之口町花木', '45', '45202', '8891802', '宮崎県', 'ミヤザキケン', '都城市', 'ミヤコノジョウシ', '山之口町花木', 'ヤマノクチチョウハナノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県都城市山之口町山之口', '45', '45202', '8891803', '宮崎県', 'ミヤザキケン', '都城市', 'ミヤコノジョウシ', '山之口町山之口', 'ヤマノクチチョウヤマノクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県北諸県郡三股町', '45', '45341', '8891900', '宮崎県', 'ミヤザキケン', '北諸県郡三股町', 'キタモロカタグンミマタチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('116390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県北諸県郡三股町樺山', '45', '45341', '8891901', '宮崎県', 'ミヤザキケン', '北諸県郡三股町', 'キタモロカタグンミマタチョウ', '樺山', 'カバヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県北諸県郡三股町五本松', '45', '45341', '8891902', '宮崎県', 'ミヤザキケン', '北諸県郡三股町', 'キタモロカタグンミマタチョウ', '五本松', 'ゴホンマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県北諸県郡三股町稗田', '45', '45341', '8891903', '宮崎県', 'ミヤザキケン', '北諸県郡三股町', 'キタモロカタグンミマタチョウ', '稗田', 'ヒエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県北諸県郡三股町新馬場', '45', '45341', '8891904', '宮崎県', 'ミヤザキケン', '北諸県郡三股町', 'キタモロカタグンミマタチョウ', '新馬場', 'シンババ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県北諸県郡三股町今市', '45', '45341', '8891905', '宮崎県', 'ミヤザキケン', '北諸県郡三股町', 'キタモロカタグンミマタチョウ', '今市', 'イマイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県北諸県郡三股町中原', '45', '45341', '8891906', '宮崎県', 'ミヤザキケン', '北諸県郡三股町', 'キタモロカタグンミマタチョウ', '中原', 'ナカバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県北諸県郡三股町花見原', '45', '45341', '8891907', '宮崎県', 'ミヤザキケン', '北諸県郡三股町', 'キタモロカタグンミマタチョウ', '花見原', 'ハナミバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県北諸県郡三股町長田', '45', '45341', '8891911', '宮崎県', 'ミヤザキケン', '北諸県郡三股町', 'キタモロカタグンミマタチョウ', '長田', 'ナガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県北諸県郡三股町宮村', '45', '45341', '8891912', '宮崎県', 'ミヤザキケン', '北諸県郡三股町', 'キタモロカタグンミマタチョウ', '宮村', 'ミヤムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県北諸県郡三股町餅原', '45', '45341', '8891913', '宮崎県', 'ミヤザキケン', '北諸県郡三股町', 'キタモロカタグンミマタチョウ', '餅原', 'モチバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県北諸県郡三股町蓼池', '45', '45341', '8891914', '宮崎県', 'ミヤザキケン', '北諸県郡三股町', 'キタモロカタグンミマタチョウ', '蓼池', 'タデイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市熊野', '45', '45201', '8892151', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '熊野', 'クマノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市学園木花台北', '45', '45201', '8892152', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '学園木花台北', 'ガクエンキバナダイキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市学園木花台南', '45', '45201', '8892153', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '学園木花台南', 'ガクエンキバナダイミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市学園木花台桜', '45', '45201', '8892154', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '学園木花台桜', 'ガクエンキハナダイサクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市学園木花台西', '45', '45201', '8892155', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '学園木花台西', 'ガクエンキバナダイニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市鏡洲', '45', '45201', '8892156', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '鏡洲', 'カガミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市加江田', '45', '45201', '8892161', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '加江田', 'カエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市青島', '45', '45201', '8892162', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '青島', 'アオシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市青島西', '45', '45201', '8892163', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '青島西', 'アオシマニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市折生迫', '45', '45201', '8892164', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '折生迫', 'オリウザコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県宮崎市内海', '45', '45201', '8892301', '宮崎県', 'ミヤザキケン', '宮崎市', 'ミヤザキシ', '内海', 'ウチウミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日南市伊比井', '45', '45204', '8892311', '宮崎県', 'ミヤザキケン', '日南市', 'ニチナンシ', '伊比井', 'イビイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日南市北郷町大藤', '45', '45204', '8892401', '宮崎県', 'ミヤザキケン', '日南市', 'ニチナンシ', '北郷町大藤', 'キタゴウチョウオオフジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日南市北郷町郷之原', '45', '45204', '8892402', '宮崎県', 'ミヤザキケン', '日南市', 'ニチナンシ', '北郷町郷之原', 'キタゴウチョウゴウノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日南市北郷町北河内', '45', '45204', '8892403', '宮崎県', 'ミヤザキケン', '日南市', 'ニチナンシ', '北郷町北河内', 'キタゴウチョウキタガワチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日南市酒谷乙', '45', '45204', '8892511', '宮崎県', 'ミヤザキケン', '日南市', 'ニチナンシ', '酒谷乙', 'サカタニオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日南市酒谷甲', '45', '45204', '8892512', '宮崎県', 'ミヤザキケン', '日南市', 'ニチナンシ', '酒谷甲', 'サカタニコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日南市吉野方', '45', '45204', '8892513', '宮崎県', 'ミヤザキケン', '日南市', 'ニチナンシ', '吉野方', 'ヨシノカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日南市楠原', '45', '45204', '8892514', '宮崎県', 'ミヤザキケン', '日南市', 'ニチナンシ', '楠原', 'クスバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日南市東弁分乙', '45', '45204', '8892521', '宮崎県', 'ミヤザキケン', '日南市', 'ニチナンシ', '東弁分乙', 'ヒガシベンブンオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日南市東弁分甲', '45', '45204', '8892522', '宮崎県', 'ミヤザキケン', '日南市', 'ニチナンシ', '東弁分甲', 'ヒガシベンブンコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日南市松永', '45', '45204', '8892523', '宮崎県', 'ミヤザキケン', '日南市', 'ニチナンシ', '松永', 'マツナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日南市殿所', '45', '45204', '8892524', '宮崎県', 'ミヤザキケン', '日南市', 'ニチナンシ', '殿所', 'トノトコロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日南市今町', '45', '45204', '8892525', '宮崎県', 'ミヤザキケン', '日南市', 'ニチナンシ', '今町', 'イママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日南市本町', '45', '45204', '8892531', '宮崎県', 'ミヤザキケン', '日南市', 'ニチナンシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日南市板敷', '45', '45204', '8892532', '宮崎県', 'ミヤザキケン', '日南市', 'ニチナンシ', '板敷', 'イタジキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日南市星倉', '45', '45204', '8892533', '宮崎県', 'ミヤザキケン', '日南市', 'ニチナンシ', '星倉', 'ホシクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日南市時任町', '45', '45204', '8892534', '宮崎県', 'ミヤザキケン', '日南市', 'ニチナンシ', '時任町', 'トキトウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日南市飫肥', '45', '45204', '8892535', '宮崎県', 'ミヤザキケン', '日南市', 'ニチナンシ', '飫肥', 'オビ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日南市吾田西', '45', '45204', '8892536', '宮崎県', 'ミヤザキケン', '日南市', 'ニチナンシ', '吾田西', 'アガタニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日南市吾田東5丁目', '45', '45204', '8892541', '宮崎県', 'ミヤザキケン', '日南市', 'ニチナンシ', '吾田東', 'アガタヒガシ', null, null, '5丁目', '05チョウメ');
INSERT INTO `ms_addresses` VALUES ('116439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日南市吾田東6丁目', '45', '45204', '8892541', '宮崎県', 'ミヤザキケン', '日南市', 'ニチナンシ', '吾田東', 'アガタヒガシ', null, null, '6丁目', '06チョウメ');
INSERT INTO `ms_addresses` VALUES ('116440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日南市吾田東7丁目', '45', '45204', '8892541', '宮崎県', 'ミヤザキケン', '日南市', 'ニチナンシ', '吾田東', 'アガタヒガシ', null, null, '7丁目', '07チョウメ');
INSERT INTO `ms_addresses` VALUES ('116441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日南市吾田東8丁目', '45', '45204', '8892541', '宮崎県', 'ミヤザキケン', '日南市', 'ニチナンシ', '吾田東', 'アガタヒガシ', null, null, '8丁目', '08チョウメ');
INSERT INTO `ms_addresses` VALUES ('116442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日南市吾田東9丁目', '45', '45204', '8892541', '宮崎県', 'ミヤザキケン', '日南市', 'ニチナンシ', '吾田東', 'アガタヒガシ', null, null, '9丁目', '09チョウメ');
INSERT INTO `ms_addresses` VALUES ('116443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日南市吾田東10丁目', '45', '45204', '8892541', '宮崎県', 'ミヤザキケン', '日南市', 'ニチナンシ', '吾田東', 'アガタヒガシ', null, null, '10丁目', '10チョウメ');
INSERT INTO `ms_addresses` VALUES ('116444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日南市吾田東11丁目', '45', '45204', '8892541', '宮崎県', 'ミヤザキケン', '日南市', 'ニチナンシ', '吾田東', 'アガタヒガシ', null, null, '11丁目', '11チョウメ');
INSERT INTO `ms_addresses` VALUES ('116445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日南市大堂津', '45', '45204', '8893141', '宮崎県', 'ミヤザキケン', '日南市', 'ニチナンシ', '大堂津', 'オオドウツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日南市塩鶴', '45', '45204', '8893142', '宮崎県', 'ミヤザキケン', '日南市', 'ニチナンシ', '塩鶴', 'シオヅル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日南市下方', '45', '45204', '8893143', '宮崎県', 'ミヤザキケン', '日南市', 'ニチナンシ', '下方', 'シモカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日南市上方', '45', '45204', '8893151', '宮崎県', 'ミヤザキケン', '日南市', 'ニチナンシ', '上方', 'カミカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日南市毛吉田', '45', '45204', '8893152', '宮崎県', 'ミヤザキケン', '日南市', 'ニチナンシ', '毛吉田', 'ケヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日南市萩之嶺', '45', '45204', '8893153', '宮崎県', 'ミヤザキケン', '日南市', 'ニチナンシ', '萩之嶺', 'ハギノミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日南市塚田甲', '45', '45204', '8893154', '宮崎県', 'ミヤザキケン', '日南市', 'ニチナンシ', '塚田甲', 'ツカダコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日南市塚田乙', '45', '45204', '8893155', '宮崎県', 'ミヤザキケン', '日南市', 'ニチナンシ', '塚田乙', 'ツカダオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日南市大窪', '45', '45204', '8893156', '宮崎県', 'ミヤザキケン', '日南市', 'ニチナンシ', '大窪', 'オオクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日南市南郷町津屋野', '45', '45204', '8893201', '宮崎県', 'ミヤザキケン', '日南市', 'ニチナンシ', '南郷町津屋野', 'ナンゴウチョウツヤノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日南市南郷町中村甲', '45', '45204', '8893202', '宮崎県', 'ミヤザキケン', '日南市', 'ニチナンシ', '南郷町中村甲', 'ナンゴウチョウナカムラコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日南市南郷町谷之口', '45', '45204', '8893203', '宮崎県', 'ミヤザキケン', '日南市', 'ニチナンシ', '南郷町谷之口', 'ナンゴウチョウタニノクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日南市南郷町中村乙', '45', '45204', '8893204', '宮崎県', 'ミヤザキケン', '日南市', 'ニチナンシ', '南郷町中村乙', 'ナンゴウチョウナカムラオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日南市南郷町西町', '45', '45204', '8893205', '宮崎県', 'ミヤザキケン', '日南市', 'ニチナンシ', '南郷町西町', 'ナンゴウチョウニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日南市南郷町南町', '45', '45204', '8893206', '宮崎県', 'ミヤザキケン', '日南市', 'ニチナンシ', '南郷町南町', 'ナンゴウチョウミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日南市南郷町東町', '45', '45204', '8893207', '宮崎県', 'ミヤザキケン', '日南市', 'ニチナンシ', '南郷町東町', 'ナンゴウチョウヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日南市南郷町贄波', '45', '45204', '8893211', '宮崎県', 'ミヤザキケン', '日南市', 'ニチナンシ', '南郷町贄波', 'ナンゴウチョウニエナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日南市南郷町脇本', '45', '45204', '8893212', '宮崎県', 'ミヤザキケン', '日南市', 'ニチナンシ', '南郷町脇本', 'ナンゴウチョウワキモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日南市南郷町潟上', '45', '45204', '8893213', '宮崎県', 'ミヤザキケン', '日南市', 'ニチナンシ', '南郷町潟上', 'ナンゴウチョウカタガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日南市南郷町榎原', '45', '45204', '8893214', '宮崎県', 'ミヤザキケン', '日南市', 'ニチナンシ', '南郷町榎原', 'ナンゴウチョウヨワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日南市南郷町榎原甲', '45', '45204', '8893215', '宮崎県', 'ミヤザキケン', '日南市', 'ニチナンシ', '南郷町榎原甲', 'ナンゴウチョウヨワラコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日南市南郷町榎原乙', '45', '45204', '8893216', '宮崎県', 'ミヤザキケン', '日南市', 'ニチナンシ', '南郷町榎原乙', 'ナンゴウチョウヨワラオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県日南市南郷町榎原丙', '45', '45204', '8893217', '宮崎県', 'ミヤザキケン', '日南市', 'ニチナンシ', '南郷町榎原丙', 'ナンゴウチョウヨワラヘイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県串間市市木', '45', '45207', '8893311', '宮崎県', 'ミヤザキケン', '串間市', 'クシマシ', '市木', 'イチキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県串間市奈留', '45', '45207', '8893531', '宮崎県', 'ミヤザキケン', '串間市', 'クシマシ', '奈留', 'ナル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県串間市大平', '45', '45207', '8893532', '宮崎県', 'ミヤザキケン', '串間市', 'クシマシ', '大平', 'オオヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県串間市一氏', '45', '45207', '8893533', '宮崎県', 'ミヤザキケン', '串間市', 'クシマシ', '一氏', 'イチウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県串間市大矢取', '45', '45207', '8893534', '宮崎県', 'ミヤザキケン', '串間市', 'クシマシ', '大矢取', 'オオヤドリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県えびの市向江', '45', '45209', '8894151', '宮崎県', 'ミヤザキケン', 'えびの市', 'エビノシ', '向江', 'ムカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県えびの市島内', '45', '45209', '8894152', '宮崎県', 'ミヤザキケン', 'えびの市', 'エビノシ', '島内', 'シマウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県えびの市浦', '45', '45209', '8894153', '宮崎県', 'ミヤザキケン', 'えびの市', 'エビノシ', '浦', 'ウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県えびの市柳水流', '45', '45209', '8894154', '宮崎県', 'ミヤザキケン', 'えびの市', 'エビノシ', '柳水流', 'ヤナギズル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県えびの市亀沢', '45', '45209', '8894155', '宮崎県', 'ミヤザキケン', 'えびの市', 'エビノシ', '亀沢', 'カメサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県えびの市岡松', '45', '45209', '8894161', '宮崎県', 'ミヤザキケン', 'えびの市', 'エビノシ', '岡松', 'オカマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県えびの市内竪', '45', '45209', '8894162', '宮崎県', 'ミヤザキケン', 'えびの市', 'エビノシ', '内竪', 'ウチタテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県えびの市水流', '45', '45209', '8894163', '宮崎県', 'ミヤザキケン', 'えびの市', 'エビノシ', '水流', 'ツル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県えびの市昌明寺', '45', '45209', '8894164', '宮崎県', 'ミヤザキケン', 'えびの市', 'エビノシ', '昌明寺', 'ショウミョウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県えびの市西川北', '45', '45209', '8894165', '宮崎県', 'ミヤザキケン', 'えびの市', 'エビノシ', '西川北', 'ニシカワキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県えびの市栗下', '45', '45209', '8894221', '宮崎県', 'ミヤザキケン', 'えびの市', 'エビノシ', '栗下', 'クリシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県えびの市小田', '45', '45209', '8894222', '宮崎県', 'ミヤザキケン', 'えびの市', 'エビノシ', '小田', 'オダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県えびの市東長江浦', '45', '45209', '8894231', '宮崎県', 'ミヤザキケン', 'えびの市', 'エビノシ', '東長江浦', 'ヒガシナガエウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県えびの市西長江浦', '45', '45209', '8894232', '宮崎県', 'ミヤザキケン', 'えびの市', 'エビノシ', '西長江浦', 'ニシナガエウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県えびの市灰塚', '45', '45209', '8894233', '宮崎県', 'ミヤザキケン', 'えびの市', 'エビノシ', '灰塚', 'ハイツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県えびの市永山', '45', '45209', '8894234', '宮崎県', 'ミヤザキケン', 'えびの市', 'エビノシ', '永山', 'ナガヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県えびの市西郷', '45', '45209', '8894241', '宮崎県', 'ミヤザキケン', 'えびの市', 'エビノシ', '西郷', 'サイゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県えびの市湯田', '45', '45209', '8894242', '宮崎県', 'ミヤザキケン', 'えびの市', 'エビノシ', '湯田', 'ユダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県えびの市榎田', '45', '45209', '8894243', '宮崎県', 'ミヤザキケン', 'えびの市', 'エビノシ', '榎田', 'エノキダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県えびの市東川北', '45', '45209', '8894244', '宮崎県', 'ミヤザキケン', 'えびの市', 'エビノシ', '東川北', 'ヒガシカワキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県えびの市', '45', '45209', '8894300', '宮崎県', 'ミヤザキケン', 'えびの市', 'エビノシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('116496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県えびの市原田', '45', '45209', '8894301', '宮崎県', 'ミヤザキケン', 'えびの市', 'エビノシ', '原田', 'ハラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県えびの市末永', '45', '45209', '8894302', '宮崎県', 'ミヤザキケン', 'えびの市', 'エビノシ', '末永', 'スエナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県えびの市池島', '45', '45209', '8894303', '宮崎県', 'ミヤザキケン', 'えびの市', 'エビノシ', '池島', 'イケジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県えびの市上江', '45', '45209', '8894304', '宮崎県', 'ミヤザキケン', 'えびの市', 'エビノシ', '上江', 'ウワエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県えびの市前田', '45', '45209', '8894305', '宮崎県', 'ミヤザキケン', 'えびの市', 'エビノシ', '前田', 'マエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県えびの市今西', '45', '45209', '8894306', '宮崎県', 'ミヤザキケン', 'えびの市', 'エビノシ', '今西', 'イマニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県えびの市大明司', '45', '45209', '8894311', '宮崎県', 'ミヤザキケン', 'えびの市', 'エビノシ', '大明司', 'ダイミョウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県えびの市坂元', '45', '45209', '8894312', '宮崎県', 'ミヤザキケン', 'えびの市', 'エビノシ', '坂元', 'サカモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県えびの市杉水流', '45', '45209', '8894313', '宮崎県', 'ミヤザキケン', 'えびの市', 'エビノシ', '杉水流', 'スギズル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県えびの市大河平', '45', '45209', '8894314', '宮崎県', 'ミヤザキケン', 'えびの市', 'エビノシ', '大河平', 'オオコウビラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県西諸県郡高原町', '45', '45361', '8894400', '宮崎県', 'ミヤザキケン', '西諸県郡高原町', 'ニシモロカタグンタカハルチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('116508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県西諸県郡高原町広原', '45', '45361', '8894411', '宮崎県', 'ミヤザキケン', '西諸県郡高原町', 'ニシモロカタグンタカハルチョウ', '広原', 'ヒロワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県西諸県郡高原町西麓', '45', '45361', '8894412', '宮崎県', 'ミヤザキケン', '西諸県郡高原町', 'ニシモロカタグンタカハルチョウ', '西麓', 'ニシフモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県西諸県郡高原町後川内', '45', '45361', '8894413', '宮崎県', 'ミヤザキケン', '西諸県郡高原町', 'ニシモロカタグンタカハルチョウ', '後川内', 'ウシロカワチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県西諸県郡高原町蒲牟田', '45', '45361', '8894414', '宮崎県', 'ミヤザキケン', '西諸県郡高原町', 'ニシモロカタグンタカハルチョウ', '蒲牟田', 'カマムタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県都城市高崎町笛水', '45', '45202', '8894501', '宮崎県', 'ミヤザキケン', '都城市', 'ミヤコノジョウシ', '高崎町笛水', 'タカザキチョウフエミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県都城市高崎町江平', '45', '45202', '8894502', '宮崎県', 'ミヤザキケン', '都城市', 'ミヤコノジョウシ', '高崎町江平', 'タカザキチョウエヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県都城市高崎町縄瀬', '45', '45202', '8894503', '宮崎県', 'ミヤザキケン', '都城市', 'ミヤコノジョウシ', '高崎町縄瀬', 'タカザキチョウナワゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県都城市高崎町東霧島', '45', '45202', '8894504', '宮崎県', 'ミヤザキケン', '都城市', 'ミヤコノジョウシ', '高崎町東霧島', 'タカザキチョウツマギリシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県都城市高崎町大牟田', '45', '45202', '8894505', '宮崎県', 'ミヤザキケン', '都城市', 'ミヤコノジョウシ', '高崎町大牟田', 'タカザキチョウオオムタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県都城市高崎町前田', '45', '45202', '8894506', '宮崎県', 'ミヤザキケン', '都城市', 'ミヤコノジョウシ', '高崎町前田', 'タカザキチョウマエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県都城市山田町山田', '45', '45202', '8894601', '宮崎県', 'ミヤザキケン', '都城市', 'ミヤコノジョウシ', '山田町山田', 'ヤマダチョウヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮崎県都城市山田町中霧島', '45', '45202', '8894602', '宮崎県', 'ミヤザキケン', '都城市', 'ミヤコノジョウシ', '山田町中霧島', 'ヤマダチョウナカギリシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市', '46', '46201', '8900000', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('116523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島郡三島村', '46', '46303', '8900000', '鹿児島県', 'カゴシマケン', '鹿児島郡三島村', 'カゴシマグンミシマムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('116524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市千年', '46', '46201', '8900001', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '千年', 'センネン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市西伊敷1丁目', '46', '46201', '8900002', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '西伊敷', 'ニシイシキ', null, null, '1丁目', '01チョウメ');
INSERT INTO `ms_addresses` VALUES ('116526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市西伊敷2丁目', '46', '46201', '8900002', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '西伊敷', 'ニシイシキ', null, null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('116527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市西伊敷3丁目', '46', '46201', '8900002', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '西伊敷', 'ニシイシキ', null, null, '3丁目', '03チョウメ');
INSERT INTO `ms_addresses` VALUES ('116528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市西伊敷4丁目', '46', '46201', '8900002', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '西伊敷', 'ニシイシキ', null, null, '4丁目', '04チョウメ');
INSERT INTO `ms_addresses` VALUES ('116529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市伊敷町', '46', '46201', '8900003', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '伊敷町', 'イシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市下伊敷町', '46', '46201', '8900004', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '下伊敷町', 'シモイシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市下伊敷', '46', '46201', '8900005', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '下伊敷', 'シモイシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市若葉町', '46', '46201', '8900006', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '若葉町', 'ワカバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市伊敷台', '46', '46201', '8900007', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '伊敷台', 'イシキダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市伊敷', '46', '46201', '8900008', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '伊敷', 'イシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市玉里団地1丁目', '46', '46201', '8900011', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '玉里団地', 'タマザトダンチ', null, null, '1丁目', '01チョウメ');
INSERT INTO `ms_addresses` VALUES ('116536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市玉里町', '46', '46201', '8900012', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '玉里町', 'タマザトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市城山1丁目', '46', '46201', '8900013', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '城山', 'シロヤマ', null, null, '1丁目', '01チョウメ');
INSERT INTO `ms_addresses` VALUES ('116538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市草牟田', '46', '46201', '8900014', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '草牟田', 'ソウムタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市草牟田町', '46', '46201', '8900015', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '草牟田町', 'ソウムタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市新照院町', '46', '46201', '8900016', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '新照院町', 'シンショウインチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市小野', '46', '46201', '8900021', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '小野', 'オノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市小野町', '46', '46201', '8900022', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '小野町', 'オノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市永吉', '46', '46201', '8900023', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '永吉', 'ナガヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市明和', '46', '46201', '8900024', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '明和', 'メイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市原良町', '46', '46201', '8900025', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '原良町', 'ハララチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市原良', '46', '46201', '8900026', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '原良', 'ハララ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市武岡', '46', '46201', '8900031', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '武岡', 'タケオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市西陵', '46', '46201', '8900032', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '西陵', 'セイリョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市西別府町', '46', '46201', '8900033', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '西別府町', 'ニシベップチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市田上', '46', '46201', '8900034', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '田上', 'タガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市田上町', '46', '46201', '8900035', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '田上町', 'タガミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市田上台', '46', '46201', '8900036', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '田上台', 'タガミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市城西', '46', '46201', '8900041', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '城西', 'ジョウセイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市薬師', '46', '46201', '8900042', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '薬師', 'ヤクシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市鷹師', '46', '46201', '8900043', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '鷹師', 'タカシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市常盤町', '46', '46201', '8900044', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '常盤町', 'トキワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市武', '46', '46201', '8900045', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '武', 'タケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市西田', '46', '46201', '8900046', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '西田', 'ニシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市常盤', '46', '46201', '8900047', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '常盤', 'トキワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市高麗町', '46', '46201', '8900051', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '高麗町', 'コウライチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市上之園町', '46', '46201', '8900052', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '上之園町', 'ウエノソノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市中央町', '46', '46201', '8900053', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '中央町', 'チュウオウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市荒田', '46', '46201', '8900054', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '荒田', 'アラタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市上荒田町', '46', '46201', '8900055', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '上荒田町', 'ウエアラタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市下荒田', '46', '46201', '8900056', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '下荒田', 'シモアラタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市天保山町', '46', '46201', '8900061', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '天保山町', 'テンポザンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市与次郎', '46', '46201', '8900062', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '与次郎', 'ヨジロウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市鴨池', '46', '46201', '8900063', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '鴨池', 'カモイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市鴨池新町', '46', '46201', '8900064', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '鴨池新町', 'カモイケシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市郡元', '46', '46201', '8900065', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '郡元', 'コオリモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市真砂町', '46', '46201', '8900066', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '真砂町', 'マサゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市真砂本町', '46', '46201', '8900067', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '真砂本町', 'マサゴホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市東郡元町', '46', '46201', '8900068', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '東郡元町', 'ヒガシコオリモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市南郡元町', '46', '46201', '8900069', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '南郡元町', 'ミナミコオリモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市三和町', '46', '46201', '8900071', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '三和町', 'サンワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市新栄町', '46', '46201', '8900072', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '新栄町', 'シンエイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市宇宿', '46', '46201', '8900073', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '宇宿', 'ウスキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市宇宿町', '46', '46201', '8900074', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '宇宿町', 'ウスキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市桜ケ丘7丁目', '46', '46201', '8900075', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '桜ケ丘', 'サクラガオカ', null, null, '7丁目', '07チョウメ');
INSERT INTO `ms_addresses` VALUES ('116580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市桜ケ丘8丁目', '46', '46201', '8900075', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '桜ケ丘', 'サクラガオカ', null, null, '8丁目', '08チョウメ');
INSERT INTO `ms_addresses` VALUES ('116581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市中央港新町', '46', '46201', '8900076', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '中央港新町', 'チュウオウコウシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市唐湊', '46', '46201', '8900081', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '唐湊', 'トソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市紫原', '46', '46201', '8900082', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '紫原', 'ムラサキバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市西紫原町', '46', '46201', '8900083', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '西紫原町', 'ニシムラサキバルチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市郡元町', '46', '46201', '8900084', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '郡元町', 'コオリモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市南新町', '46', '46201', '8900085', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '南新町', 'ミナミシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市日之出町', '46', '46201', '8900086', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '日之出町', 'ヒノデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島郡三島村硫黄島', '46', '46303', '8900901', '鹿児島県', 'カゴシマケン', '鹿児島郡三島村', 'カゴシマグンミシマムラ', '硫黄島', 'イオウジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島郡三島村黒島', '46', '46303', '8900902', '鹿児島県', 'カゴシマケン', '鹿児島郡三島村', 'カゴシマグンミシマムラ', '黒島', 'クロシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島郡三島村竹島', '46', '46303', '8900903', '鹿児島県', 'カゴシマケン', '鹿児島郡三島村', 'カゴシマグンミシマムラ', '竹島', 'タケシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡清水町', '01', '01636', '0890100', '北海道', 'ホッカイドウ', '上川郡清水町', 'カミカワグンシミズチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('116592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡清水町人舞', '01', '01636', '0890101', '北海道', 'ホッカイドウ', '上川郡清水町', 'カミカワグンシミズチョウ', '人舞', 'ヒトマイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡清水町下佐幌', '01', '01636', '0890102', '北海道', 'ホッカイドウ', '上川郡清水町', 'カミカワグンシミズチョウ', '下佐幌', 'シモサホロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡清水町清水', '01', '01636', '0890103', '北海道', 'ホッカイドウ', '上川郡清水町', 'カミカワグンシミズチョウ', '清水', 'シミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡清水町南3条西', '01', '01636', '0890104', '北海道', 'ホッカイドウ', '上川郡清水町', 'カミカワグンシミズチョウ', '南3条西', 'ミナミ03ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡清水町南4条西', '01', '01636', '0890105', '北海道', 'ホッカイドウ', '上川郡清水町', 'カミカワグンシミズチョウ', '南4条西', 'ミナミ04ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡清水町南5条西', '01', '01636', '0890106', '北海道', 'ホッカイドウ', '上川郡清水町', 'カミカワグンシミズチョウ', '南5条西', 'ミナミ05ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡清水町南6条西', '01', '01636', '0890107', '北海道', 'ホッカイドウ', '上川郡清水町', 'カミカワグンシミズチョウ', '南6条西', 'ミナミ06ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡清水町南3条', '01', '01636', '0890111', '北海道', 'ホッカイドウ', '上川郡清水町', 'カミカワグンシミズチョウ', '南3条', 'ミナミ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡清水町南4条', '01', '01636', '0890112', '北海道', 'ホッカイドウ', '上川郡清水町', 'カミカワグンシミズチョウ', '南4条', 'ミナミ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡清水町南5条', '01', '01636', '0890113', '北海道', 'ホッカイドウ', '上川郡清水町', 'カミカワグンシミズチョウ', '南5条', 'ミナミ05ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡清水町南6条', '01', '01636', '0890114', '北海道', 'ホッカイドウ', '上川郡清水町', 'カミカワグンシミズチョウ', '南6条', 'ミナミ06ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡清水町南7条', '01', '01636', '0890115', '北海道', 'ホッカイドウ', '上川郡清水町', 'カミカワグンシミズチョウ', '南7条', 'ミナミ07ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡清水町南8条', '01', '01636', '0890116', '北海道', 'ホッカイドウ', '上川郡清水町', 'カミカワグンシミズチョウ', '南8条', 'ミナミ08ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡清水町南9条', '01', '01636', '0890117', '北海道', 'ホッカイドウ', '上川郡清水町', 'カミカワグンシミズチョウ', '南9条', 'ミナミ09ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡清水町南10条', '01', '01636', '0890118', '北海道', 'ホッカイドウ', '上川郡清水町', 'カミカワグンシミズチョウ', '南10条', 'ミナミ10ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡清水町北4条西', '01', '01636', '0890121', '北海道', 'ホッカイドウ', '上川郡清水町', 'カミカワグンシミズチョウ', '北4条西', 'キタ04ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡清水町北3条西', '01', '01636', '0890122', '北海道', 'ホッカイドウ', '上川郡清水町', 'カミカワグンシミズチョウ', '北3条西', 'キタ03ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡清水町北2条西', '01', '01636', '0890123', '北海道', 'ホッカイドウ', '上川郡清水町', 'カミカワグンシミズチョウ', '北2条西', 'キタ02ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡清水町北1条西', '01', '01636', '0890124', '北海道', 'ホッカイドウ', '上川郡清水町', 'カミカワグンシミズチョウ', '北1条西', 'キタ01ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡清水町本通西', '01', '01636', '0890125', '北海道', 'ホッカイドウ', '上川郡清水町', 'カミカワグンシミズチョウ', '本通西', 'ホンドオリニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡清水町南1条西', '01', '01636', '0890126', '北海道', 'ホッカイドウ', '上川郡清水町', 'カミカワグンシミズチョウ', '南1条西', 'ミナミ01ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡清水町南2条西', '01', '01636', '0890127', '北海道', 'ホッカイドウ', '上川郡清水町', 'カミカワグンシミズチョウ', '南2条西', 'ミナミ02ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡清水町北5条', '01', '01636', '0890131', '北海道', 'ホッカイドウ', '上川郡清水町', 'カミカワグンシミズチョウ', '北5条', 'キタ05ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡清水町北4条', '01', '01636', '0890132', '北海道', 'ホッカイドウ', '上川郡清水町', 'カミカワグンシミズチョウ', '北4条', 'キタ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡清水町北3条', '01', '01636', '0890133', '北海道', 'ホッカイドウ', '上川郡清水町', 'カミカワグンシミズチョウ', '北3条', 'キタ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡清水町北2条', '01', '01636', '0890134', '北海道', 'ホッカイドウ', '上川郡清水町', 'カミカワグンシミズチョウ', '北2条', 'キタ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡清水町北1条', '01', '01636', '0890135', '北海道', 'ホッカイドウ', '上川郡清水町', 'カミカワグンシミズチョウ', '北1条', 'キタ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡清水町本通', '01', '01636', '0890136', '北海道', 'ホッカイドウ', '上川郡清水町', 'カミカワグンシミズチョウ', '本通', 'ホンドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡清水町南1条', '01', '01636', '0890137', '北海道', 'ホッカイドウ', '上川郡清水町', 'カミカワグンシミズチョウ', '南1条', 'ミナミ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡清水町南2条', '01', '01636', '0890138', '北海道', 'ホッカイドウ', '上川郡清水町', 'カミカワグンシミズチョウ', '南2条', 'ミナミ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡清水町熊牛', '01', '01636', '0890241', '北海道', 'ホッカイドウ', '上川郡清水町', 'カミカワグンシミズチョウ', '熊牛', 'クマウシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡清水町美蔓', '01', '01636', '0890242', '北海道', 'ホッカイドウ', '上川郡清水町', 'カミカワグンシミズチョウ', '美蔓', 'ビマン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡清水町上然別', '01', '01636', '0890243', '北海道', 'ホッカイドウ', '上川郡清水町', 'カミカワグンシミズチョウ', '上然別', 'カミシカリベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡清水町御影西1条', '01', '01636', '0890351', '北海道', 'ホッカイドウ', '上川郡清水町', 'カミカワグンシミズチョウ', '御影西1条', 'ミカゲニシ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡清水町御影西2条', '01', '01636', '0890352', '北海道', 'ホッカイドウ', '上川郡清水町', 'カミカワグンシミズチョウ', '御影西2条', 'ミカゲニシ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡清水町御影西3条', '01', '01636', '0890353', '北海道', 'ホッカイドウ', '上川郡清水町', 'カミカワグンシミズチョウ', '御影西3条', 'ミカゲニシ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡清水町御影本通', '01', '01636', '0890354', '北海道', 'ホッカイドウ', '上川郡清水町', 'カミカワグンシミズチョウ', '御影本通', 'ミカゲホンドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡清水町旭山', '01', '01636', '0890355', '北海道', 'ホッカイドウ', '上川郡清水町', 'カミカワグンシミズチョウ', '旭山', 'アサヒヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡清水町羽帯', '01', '01636', '0890356', '北海道', 'ホッカイドウ', '上川郡清水町', 'カミカワグンシミズチョウ', '羽帯', 'ハオビ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡清水町御影', '01', '01636', '0890357', '北海道', 'ホッカイドウ', '上川郡清水町', 'カミカワグンシミズチョウ', '御影', 'ミカゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡清水町御影東1条南', '01', '01636', '0890361', '北海道', 'ホッカイドウ', '上川郡清水町', 'カミカワグンシミズチョウ', '御影東1条南', 'ミカゲヒガシ01ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡清水町御影東2条南', '01', '01636', '0890362', '北海道', 'ホッカイドウ', '上川郡清水町', 'カミカワグンシミズチョウ', '御影東2条南', 'ミカゲヒガシ02ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡清水町御影東3条南', '01', '01636', '0890363', '北海道', 'ホッカイドウ', '上川郡清水町', 'カミカワグンシミズチョウ', '御影東3条南', 'ミカゲヒガシ03ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡清水町御影東1条', '01', '01636', '0890371', '北海道', 'ホッカイドウ', '上川郡清水町', 'カミカワグンシミズチョウ', '御影東1条', 'ミカゲヒガシ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡清水町御影東2条', '01', '01636', '0890372', '北海道', 'ホッカイドウ', '上川郡清水町', 'カミカワグンシミズチョウ', '御影東2条', 'ミカゲヒガシ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡清水町御影東3条', '01', '01636', '0890373', '北海道', 'ホッカイドウ', '上川郡清水町', 'カミカワグンシミズチョウ', '御影東3条', 'ミカゲヒガシ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡清水町御影東4条', '01', '01636', '0890374', '北海道', 'ホッカイドウ', '上川郡清水町', 'カミカワグンシミズチョウ', '御影東4条', 'ミカゲヒガシ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡清水町御影東5条', '01', '01636', '0890375', '北海道', 'ホッカイドウ', '上川郡清水町', 'カミカワグンシミズチョウ', '御影東5条', 'ミカゲヒガシ05ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡清水町御影東6条', '01', '01636', '0890376', '北海道', 'ホッカイドウ', '上川郡清水町', 'カミカワグンシミズチョウ', '御影東6条', 'ミカゲヒガシ06ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡清水町御影東7条', '01', '01636', '0890377', '北海道', 'ホッカイドウ', '上川郡清水町', 'カミカワグンシミズチョウ', '御影東7条', 'ミカゲヒガシ07ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡清水町御影東8条', '01', '01636', '0890378', '北海道', 'ホッカイドウ', '上川郡清水町', 'カミカワグンシミズチョウ', '御影東8条', 'ミカゲヒガシ08ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡幕別町札内暁町', '01', '01643', '0890531', '北海道', 'ホッカイドウ', '中川郡幕別町', 'ナカガワグンマクベツチョウ', '札内暁町', 'サツナイアカツキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡幕別町札内豊町', '01', '01643', '0890532', '北海道', 'ホッカイドウ', '中川郡幕別町', 'ナカガワグンマクベツチョウ', '札内豊町', 'サツナイユタカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡幕別町札内新北町', '01', '01643', '0890533', '北海道', 'ホッカイドウ', '中川郡幕別町', 'ナカガワグンマクベツチョウ', '札内新北町', 'サツナイシンキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡幕別町札内北町', '01', '01643', '0890534', '北海道', 'ホッカイドウ', '中川郡幕別町', 'ナカガワグンマクベツチョウ', '札内北町', 'サツナイキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡幕別町札内桜町', '01', '01643', '0890535', '北海道', 'ホッカイドウ', '中川郡幕別町', 'ナカガワグンマクベツチョウ', '札内桜町', 'サツナイサクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡幕別町札内西町', '01', '01643', '0890536', '北海道', 'ホッカイドウ', '中川郡幕別町', 'ナカガワグンマクベツチョウ', '札内西町', 'サツナイニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡幕別町札内北栄町', '01', '01643', '0890537', '北海道', 'ホッカイドウ', '中川郡幕別町', 'ナカガワグンマクベツチョウ', '札内北栄町', 'サツナイホクエイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡幕別町札内共栄町', '01', '01643', '0890538', '北海道', 'ホッカイドウ', '中川郡幕別町', 'ナカガワグンマクベツチョウ', '札内共栄町', 'サツナイキョウエイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡幕別町札内青葉町', '01', '01643', '0890541', '北海道', 'ホッカイドウ', '中川郡幕別町', 'ナカガワグンマクベツチョウ', '札内青葉町', 'サツナイアオバマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡幕別町札内春日町', '01', '01643', '0890542', '北海道', 'ホッカイドウ', '中川郡幕別町', 'ナカガワグンマクベツチョウ', '札内春日町', 'サツナイカスガマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡幕別町札内中央町', '01', '01643', '0890543', '北海道', 'ホッカイドウ', '中川郡幕別町', 'ナカガワグンマクベツチョウ', '札内中央町', 'サツナイチュウオウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡幕別町札内若草町', '01', '01643', '0890544', '北海道', 'ホッカイドウ', '中川郡幕別町', 'ナカガワグンマクベツチョウ', '札内若草町', 'サツナイワカクサマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡幕別町札内桂町', '01', '01643', '0890545', '北海道', 'ホッカイドウ', '中川郡幕別町', 'ナカガワグンマクベツチョウ', '札内桂町', 'サツナイカツラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡幕別町札内堤町', '01', '01643', '0890546', '北海道', 'ホッカイドウ', '中川郡幕別町', 'ナカガワグンマクベツチョウ', '札内堤町', 'サツナイツツミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡幕別町札内泉町', '01', '01643', '0890551', '北海道', 'ホッカイドウ', '中川郡幕別町', 'ナカガワグンマクベツチョウ', '札内泉町', 'サツナイイヅミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡幕別町札内あかしや町', '01', '01643', '0890552', '北海道', 'ホッカイドウ', '中川郡幕別町', 'ナカガワグンマクベツチョウ', '札内あかしや町', 'サツナイアカシヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡幕別町札内文京町', '01', '01643', '0890553', '北海道', 'ホッカイドウ', '中川郡幕別町', 'ナカガワグンマクベツチョウ', '札内文京町', 'サツナイブンキョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡幕別町札内みずほ町', '01', '01643', '0890554', '北海道', 'ホッカイドウ', '中川郡幕別町', 'ナカガワグンマクベツチョウ', '札内みずほ町', 'サツナイミズホマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡幕別町札内稔町', '01', '01643', '0890561', '北海道', 'ホッカイドウ', '中川郡幕別町', 'ナカガワグンマクベツチョウ', '札内稔町', 'サツナイミノリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡幕別町札内東町', '01', '01643', '0890562', '北海道', 'ホッカイドウ', '中川郡幕別町', 'ナカガワグンマクベツチョウ', '札内東町', 'サツナイヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡幕別町千住', '01', '01643', '0890563', '北海道', 'ホッカイドウ', '中川郡幕別町', 'ナカガワグンマクベツチョウ', '千住', 'センジュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡幕別町稲志別', '01', '01643', '0890564', '北海道', 'ホッカイドウ', '中川郡幕別町', 'ナカガワグンマクベツチョウ', '稲志別', 'イナシベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡幕別町新生', '01', '01643', '0890565', '北海道', 'ホッカイドウ', '中川郡幕別町', 'ナカガワグンマクベツチョウ', '新生', 'シンセイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡幕別町昭和', '01', '01643', '0890566', '北海道', 'ホッカイドウ', '中川郡幕別町', 'ナカガワグンマクベツチョウ', '昭和', 'ショウワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡幕別町明倫', '01', '01643', '0890567', '北海道', 'ホッカイドウ', '中川郡幕別町', 'ナカガワグンマクベツチョウ', '明倫', 'メイリン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡幕別町依田', '01', '01643', '0890571', '北海道', 'ホッカイドウ', '中川郡幕別町', 'ナカガワグンマクベツチョウ', '依田', 'ヨダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡幕別町西和', '01', '01643', '0890572', '北海道', 'ホッカイドウ', '中川郡幕別町', 'ナカガワグンマクベツチョウ', '西和', 'セイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡幕別町途別', '01', '01643', '0890573', '北海道', 'ホッカイドウ', '中川郡幕別町', 'ナカガワグンマクベツチョウ', '途別', 'トベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡幕別町日新', '01', '01643', '0890574', '北海道', 'ホッカイドウ', '中川郡幕別町', 'ナカガワグンマクベツチョウ', '日新', 'ニッシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡幕別町上稲志別', '01', '01643', '0890575', '北海道', 'ホッカイドウ', '中川郡幕別町', 'ナカガワグンマクベツチョウ', '上稲志別', 'カミイナシベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡幕別町古舞', '01', '01643', '0890576', '北海道', 'ホッカイドウ', '中川郡幕別町', 'ナカガワグンマクベツチョウ', '古舞', 'フルマイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡幕別町栄', '01', '01643', '0890577', '北海道', 'ホッカイドウ', '中川郡幕別町', 'ナカガワグンマクベツチョウ', '栄', 'サカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡幕別町中稲志別', '01', '01643', '0890578', '北海道', 'ホッカイドウ', '中川郡幕別町', 'ナカガワグンマクベツチョウ', '中稲志別', 'ナカイナシベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡幕別町', '01', '01643', '0890600', '北海道', 'ホッカイドウ', '中川郡幕別町', 'ナカガワグンマクベツチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('116683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡幕別町幸町', '01', '01643', '0890601', '北海道', 'ホッカイドウ', '中川郡幕別町', 'ナカガワグンマクベツチョウ', '幸町', 'サイワイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡幕別町旭町', '01', '01643', '0890602', '北海道', 'ホッカイドウ', '中川郡幕別町', 'ナカガワグンマクベツチョウ', '旭町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡幕別町本町', '01', '01643', '0890603', '北海道', 'ホッカイドウ', '中川郡幕別町', 'ナカガワグンマクベツチョウ', '本町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡幕別町錦町', '01', '01643', '0890604', '北海道', 'ホッカイドウ', '中川郡幕別町', 'ナカガワグンマクベツチョウ', '錦町', 'ニシキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡幕別町寿町', '01', '01643', '0890605', '北海道', 'ホッカイドウ', '中川郡幕別町', 'ナカガワグンマクベツチョウ', '寿町', 'コトブキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡幕別町新町', '01', '01643', '0890611', '北海道', 'ホッカイドウ', '中川郡幕別町', 'ナカガワグンマクベツチョウ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡幕別町明野', '01', '01643', '0890612', '北海道', 'ホッカイドウ', '中川郡幕別町', 'ナカガワグンマクベツチョウ', '明野', 'アケノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡幕別町新川', '01', '01643', '0890613', '北海道', 'ホッカイドウ', '中川郡幕別町', 'ナカガワグンマクベツチョウ', '新川', 'シンカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡幕別町緑町', '01', '01643', '0890614', '北海道', 'ホッカイドウ', '中川郡幕別町', 'ナカガワグンマクベツチョウ', '緑町', 'ミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡幕別町南町', '01', '01643', '0890615', '北海道', 'ホッカイドウ', '中川郡幕別町', 'ナカガワグンマクベツチョウ', '南町', 'ミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡幕別町宝町', '01', '01643', '0890616', '北海道', 'ホッカイドウ', '中川郡幕別町', 'ナカガワグンマクベツチョウ', '宝町', 'タカラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡幕別町相川', '01', '01643', '0890621', '北海道', 'ホッカイドウ', '中川郡幕別町', 'ナカガワグンマクベツチョウ', '相川', 'アイカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡幕別町大豊', '01', '01643', '0890622', '北海道', 'ホッカイドウ', '中川郡幕別町', 'ナカガワグンマクベツチョウ', '大豊', 'オオトヨ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡幕別町南勢', '01', '01643', '0890623', '北海道', 'ホッカイドウ', '中川郡幕別町', 'ナカガワグンマクベツチョウ', '南勢', 'ナンセイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡幕別町軍岡', '01', '01643', '0890624', '北海道', 'ホッカイドウ', '中川郡幕別町', 'ナカガワグンマクベツチョウ', '軍岡', 'イクサオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡幕別町猿別', '01', '01643', '0890625', '北海道', 'ホッカイドウ', '中川郡幕別町', 'ナカガワグンマクベツチョウ', '猿別', 'サルベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡幕別町西猿別', '01', '01643', '0890626', '北海道', 'ホッカイドウ', '中川郡幕別町', 'ナカガワグンマクベツチョウ', '西猿別', 'ニシサルベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡幕別町新和', '01', '01643', '0890627', '北海道', 'ホッカイドウ', '中川郡幕別町', 'ナカガワグンマクベツチョウ', '新和', 'シンワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡幕別町豊岡', '01', '01643', '0890628', '北海道', 'ホッカイドウ', '中川郡幕別町', 'ナカガワグンマクベツチョウ', '豊岡', 'トヨオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡幕別町五位', '01', '01643', '0890781', '北海道', 'ホッカイドウ', '中川郡幕別町', 'ナカガワグンマクベツチョウ', '五位', 'ゴイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡幕別町中里', '01', '01643', '0890782', '北海道', 'ホッカイドウ', '中川郡幕別町', 'ナカガワグンマクベツチョウ', '中里', 'ナカサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡幕別町駒畠', '01', '01643', '0890783', '北海道', 'ホッカイドウ', '中川郡幕別町', 'ナカガワグンマクベツチョウ', '駒畠', 'コマハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡幕別町弘和', '01', '01643', '0890784', '北海道', 'ホッカイドウ', '中川郡幕別町', 'ナカガワグンマクベツチョウ', '弘和', 'コウワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡幕別町美川', '01', '01643', '0890785', '北海道', 'ホッカイドウ', '中川郡幕別町', 'ナカガワグンマクベツチョウ', '美川', 'ミカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡幕別町糠内', '01', '01643', '0890786', '北海道', 'ホッカイドウ', '中川郡幕別町', 'ナカガワグンマクベツチョウ', '糠内', 'ヌカナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡幕別町明倫', '01', '01643', '0890787', '北海道', 'ホッカイドウ', '中川郡幕別町', 'ナカガワグンマクベツチョウ', '明倫', 'メイリン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡幕別町新和新田牧場', '01', '01643', '0890788', '北海道', 'ホッカイドウ', '中川郡幕別町', 'ナカガワグンマクベツチョウ', '新和', 'シンワ', null, null, '新田牧場', 'ニッタボクジョウ');
INSERT INTO `ms_addresses` VALUES ('116767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市五ケ別府町', '46', '46201', '8910101', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '五ケ別府町', 'ゴカベップチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市星ケ峯', '46', '46201', '8910102', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '星ケ峯', 'ホシガミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市皇徳寺台', '46', '46201', '8910103', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '皇徳寺台', 'コウトクジダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市山田町', '46', '46201', '8910104', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '山田町', 'ヤマダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市中山町', '46', '46201', '8910105', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '中山町', 'チュウザンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市自由ケ丘', '46', '46201', '8910106', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '自由ケ丘', 'ジユウガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市希望ケ丘町', '46', '46201', '8910107', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '希望ケ丘町', 'キボウガオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市中山', '46', '46201', '8910108', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '中山', 'チュウザン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市清和', '46', '46201', '8910109', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '清和', 'セイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市小原町', '46', '46201', '8910111', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '小原町', 'オバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市魚見町', '46', '46201', '8910112', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '魚見町', 'ウオミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市東谷山', '46', '46201', '8910113', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '東谷山', 'ヒガシタニヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市小松原', '46', '46201', '8910114', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '小松原', 'コマツバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市東開町', '46', '46201', '8910115', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '東開町', 'トウカイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市上福元町', '46', '46201', '8910116', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '上福元町', 'カミフクモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市谷山塩屋町', '46', '46201', '8910121', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '谷山塩屋町', 'タニヤマシオヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市南栄', '46', '46201', '8910122', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '南栄', 'ナンエイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市卸本町', '46', '46201', '8910123', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '卸本町', 'オロシホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市谷山港', '46', '46201', '8910131', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '谷山港', 'タニヤマコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市七ツ島', '46', '46201', '8910132', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '七ツ島', 'ナナツジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市平川町', '46', '46201', '8910133', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '平川町', 'ヒラカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市谷山中央', '46', '46201', '8910141', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '谷山中央', 'タニヤマチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市和田町', '46', '46201', '8910142', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '和田町', 'ワダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市和田', '46', '46201', '8910143', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '和田', 'ワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市下福元町', '46', '46201', '8910144', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '下福元町', 'シモフクモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市錦江台', '46', '46201', '8910145', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '錦江台', 'キンコウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市慈眼寺町', '46', '46201', '8910146', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '慈眼寺町', 'ジガンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市坂之上', '46', '46201', '8910150', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '坂之上', 'サカノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市光山', '46', '46201', '8910151', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '光山', 'ヒカリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市桜ケ丘1丁目', '46', '46201', '8910175', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '桜ケ丘', 'サクラガオカ', null, null, '1丁目', '01チョウメ');
INSERT INTO `ms_addresses` VALUES ('116797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市桜ケ丘2丁目', '46', '46201', '8910175', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '桜ケ丘', 'サクラガオカ', null, null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('116798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市桜ケ丘3丁目', '46', '46201', '8910175', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '桜ケ丘', 'サクラガオカ', null, null, '3丁目', '03チョウメ');
INSERT INTO `ms_addresses` VALUES ('116799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市桜ケ丘4丁目', '46', '46201', '8910175', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '桜ケ丘', 'サクラガオカ', null, null, '4丁目', '04チョウメ');
INSERT INTO `ms_addresses` VALUES ('116800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市桜ケ丘5丁目', '46', '46201', '8910175', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '桜ケ丘', 'サクラガオカ', null, null, '5丁目', '05チョウメ');
INSERT INTO `ms_addresses` VALUES ('116801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市桜ケ丘6丁目', '46', '46201', '8910175', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '桜ケ丘', 'サクラガオカ', null, null, '6丁目', '06チョウメ');
INSERT INTO `ms_addresses` VALUES ('116819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市喜入瀬々串町', '46', '46201', '8910201', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '喜入瀬々串町', 'キイレセセクシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市喜入中名町', '46', '46201', '8910202', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '喜入中名町', 'キイレナカミョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市喜入町', '46', '46201', '8910203', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '喜入町', 'キイレチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市喜入一倉町', '46', '46201', '8910204', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '喜入一倉町', 'キイレヒトクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市喜入前之浜町', '46', '46201', '8910205', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '喜入前之浜町', 'キイレマエノハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市喜入生見町', '46', '46201', '8910206', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '喜入生見町', 'キイレヌクミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県指宿市東方', '46', '46210', '8910304', '鹿児島県', 'カゴシマケン', '指宿市', 'イブスキシ', '東方', 'ヒガシカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県指宿市西方', '46', '46210', '8910311', '鹿児島県', 'カゴシマケン', '指宿市', 'イブスキシ', '西方', 'ニシカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県指宿市池田', '46', '46210', '8910312', '鹿児島県', 'カゴシマケン', '指宿市', 'イブスキシ', '池田', 'イケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県指宿市新西方', '46', '46210', '8910313', '鹿児島県', 'カゴシマケン', '指宿市', 'イブスキシ', '新西方', 'シンニシカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県指宿市小牧', '46', '46210', '8910314', '鹿児島県', 'カゴシマケン', '指宿市', 'イブスキシ', '小牧', 'コマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県指宿市岩本', '46', '46210', '8910315', '鹿児島県', 'カゴシマケン', '指宿市', 'イブスキシ', '岩本', 'イワモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県指宿市', '46', '46210', '8910400', '鹿児島県', 'カゴシマケン', '指宿市', 'イブスキシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('116832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県指宿市大牟礼', '46', '46210', '8910401', '鹿児島県', 'カゴシマケン', '指宿市', 'イブスキシ', '大牟礼', 'オオムレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県指宿市十町', '46', '46210', '8910402', '鹿児島県', 'カゴシマケン', '指宿市', 'イブスキシ', '十町', 'ジュッチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県指宿市十二町', '46', '46210', '8910403', '鹿児島県', 'カゴシマケン', '指宿市', 'イブスキシ', '十二町', 'ジュウニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県指宿市東方', '46', '46210', '8910404', '鹿児島県', 'カゴシマケン', '指宿市', 'イブスキシ', '東方', 'ヒガシカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県指宿市湊', '46', '46210', '8910405', '鹿児島県', 'カゴシマケン', '指宿市', 'イブスキシ', '湊', 'ミナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県指宿市湯の浜', '46', '46210', '8910406', '鹿児島県', 'カゴシマケン', '指宿市', 'イブスキシ', '湯の浜', 'ユノハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県指宿市山川新栄町', '46', '46210', '8910501', '鹿児島県', 'カゴシマケン', '指宿市', 'イブスキシ', '山川新栄町', 'ヤマガワシンエイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県指宿市山川朝日町', '46', '46210', '8910502', '鹿児島県', 'カゴシマケン', '指宿市', 'イブスキシ', '山川朝日町', 'ヤマガワアサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県指宿市山川潮見町', '46', '46210', '8910503', '鹿児島県', 'カゴシマケン', '指宿市', 'イブスキシ', '山川潮見町', 'ヤマガワシオミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県指宿市山川新生町', '46', '46210', '8910504', '鹿児島県', 'カゴシマケン', '指宿市', 'イブスキシ', '山川新生町', 'ヤマガワシンセイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県指宿市山川山下町', '46', '46210', '8910505', '鹿児島県', 'カゴシマケン', '指宿市', 'イブスキシ', '山川山下町', 'ヤマガワヤマシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県指宿市山川金生町', '46', '46210', '8910506', '鹿児島県', 'カゴシマケン', '指宿市', 'イブスキシ', '山川金生町', 'ヤマガワキンセイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県指宿市山川入船町', '46', '46210', '8910507', '鹿児島県', 'カゴシマケン', '指宿市', 'イブスキシ', '山川入船町', 'ヤマガワイリフネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県指宿市山川福元', '46', '46210', '8910511', '鹿児島県', 'カゴシマケン', '指宿市', 'イブスキシ', '山川福元', 'ヤマガワフクモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県指宿市山川浜児ケ水', '46', '46210', '8910512', '鹿児島県', 'カゴシマケン', '指宿市', 'イブスキシ', '山川浜児ケ水', 'ヤマガワハマチヨガミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県指宿市山川岡児ケ水', '46', '46210', '8910513', '鹿児島県', 'カゴシマケン', '指宿市', 'イブスキシ', '山川岡児ケ水', 'ヤマガワオカチヨガミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県指宿市山川大山', '46', '46210', '8910514', '鹿児島県', 'カゴシマケン', '指宿市', 'イブスキシ', '山川大山', 'ヤマガワオオヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県指宿市山川小川', '46', '46210', '8910515', '鹿児島県', 'カゴシマケン', '指宿市', 'イブスキシ', '山川小川', 'ヤマガワオガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県指宿市山川成川', '46', '46210', '8910516', '鹿児島県', 'カゴシマケン', '指宿市', 'イブスキシ', '山川成川', 'ヤマガワナリカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県指宿市開聞上野', '46', '46210', '8910601', '鹿児島県', 'カゴシマケン', '指宿市', 'イブスキシ', '開聞上野', 'カイモンウエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県指宿市開聞川尻', '46', '46210', '8910602', '鹿児島県', 'カゴシマケン', '指宿市', 'イブスキシ', '開聞川尻', 'カイモンカワシリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県指宿市開聞十町', '46', '46210', '8910603', '鹿児島県', 'カゴシマケン', '指宿市', 'イブスキシ', '開聞十町', 'カイモンジュッチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県指宿市開聞仙田', '46', '46210', '8910604', '鹿児島県', 'カゴシマケン', '指宿市', 'イブスキシ', '開聞仙田', 'カイモンセンタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県指宿市山川大山', '46', '46210', '8910614', '鹿児島県', 'カゴシマケン', '指宿市', 'イブスキシ', '山川大山', 'ヤマガワオオヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県指宿市山川利永', '46', '46210', '8910621', '鹿児島県', 'カゴシマケン', '指宿市', 'イブスキシ', '山川利永', 'ヤマガワトシナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県南九州市頴娃町郡', '46', '46223', '8910701', '鹿児島県', 'カゴシマケン', '南九州市', 'ミナミキュウシュウシ', '頴娃町郡', 'エイチョウコオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県南九州市頴娃町牧之内', '46', '46223', '8910702', '鹿児島県', 'カゴシマケン', '南九州市', 'ミナミキュウシュウシ', '頴娃町牧之内', 'エイチョウマキノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県南九州市頴娃町御領', '46', '46223', '8910703', '鹿児島県', 'カゴシマケン', '南九州市', 'ミナミキュウシュウシ', '頴娃町御領', 'エイチョウゴリョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県南九州市頴娃町別府', '46', '46223', '8910704', '鹿児島県', 'カゴシマケン', '南九州市', 'ミナミキュウシュウシ', '頴娃町別府', 'エイチョウベップ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県南九州市頴娃町上別府', '46', '46223', '8910705', '鹿児島県', 'カゴシマケン', '南九州市', 'ミナミキュウシュウシ', '頴娃町上別府', 'エイチョウカミベップ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県南九州市知覧町塩屋', '46', '46223', '8910911', '鹿児島県', 'カゴシマケン', '南九州市', 'ミナミキュウシュウシ', '知覧町塩屋', 'チランチョウシオヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県南九州市知覧町南別府', '46', '46223', '8910912', '鹿児島県', 'カゴシマケン', '南九州市', 'ミナミキュウシュウシ', '知覧町南別府', 'チランチョウミナミベップ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市花尾町', '46', '46201', '8911101', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '花尾町', 'ハナオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市東俣町', '46', '46201', '8911102', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '東俣町', 'ヒガシマタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市川田町', '46', '46201', '8911103', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '川田町', 'カワダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市油須木町', '46', '46201', '8911104', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '油須木町', 'ユスキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市郡山町', '46', '46201', '8911105', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '郡山町', 'コオリヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市西俣町', '46', '46201', '8911106', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '西俣町', 'ニシマタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市有屋田町', '46', '46201', '8911107', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '有屋田町', 'アリヤダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市郡山岳町', '46', '46201', '8911108', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '郡山岳町', 'コオリヤマタケマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市岡之原町', '46', '46201', '8911201', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '岡之原町', 'オカノハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市西伊敷5丁目', '46', '46201', '8911202', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '西伊敷', 'ニシイシキ', null, null, '5丁目', '05チョウメ');
INSERT INTO `ms_addresses` VALUES ('116880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市西伊敷6丁目', '46', '46201', '8911202', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '西伊敷', 'ニシイシキ', null, null, '6丁目', '06チョウメ');
INSERT INTO `ms_addresses` VALUES ('116881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市西伊敷7丁目', '46', '46201', '8911202', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '西伊敷', 'ニシイシキ', null, null, '7丁目', '07チョウメ');
INSERT INTO `ms_addresses` VALUES ('116882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市伊敷町', '46', '46201', '8911203', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '伊敷町', 'イシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市花野光ケ丘', '46', '46201', '8911204', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '花野光ケ丘', 'ケノヒカリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市犬迫町', '46', '46201', '8911205', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '犬迫町', 'イヌザコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市皆与志町', '46', '46201', '8911206', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '皆与志町', 'ミナヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市小野町', '46', '46201', '8911222', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '小野町', 'オノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市小山田町', '46', '46201', '8911231', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '小山田町', 'コヤマダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市緑ケ丘町', '46', '46201', '8911274', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '緑ケ丘町', 'ミドリガオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市川上町', '46', '46201', '8911275', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '川上町', 'カワカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市西佐多町', '46', '46201', '8911301', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '西佐多町', 'ニシサタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市東佐多町', '46', '46201', '8911302', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '東佐多町', 'ヒガシサタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市本城町', '46', '46201', '8911303', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '本城町', 'ホンジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市本名町', '46', '46201', '8911304', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '本名町', 'ホンミョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市宮之浦町', '46', '46201', '8911305', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '宮之浦町', 'ミヤノウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市牟礼岡', '46', '46201', '8911306', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '牟礼岡', 'ムレガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市黒神町', '46', '46201', '8911401', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '黒神町', 'クロカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市高免町', '46', '46201', '8911402', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '高免町', 'コウメンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市新島町', '46', '46201', '8911403', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '新島町', 'シンジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市桜島白浜町', '46', '46201', '8911411', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '桜島白浜町', 'サクラジマシラハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市桜島二俣町', '46', '46201', '8911412', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '桜島二俣町', 'サクラジマフタマタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市桜島松浦町', '46', '46201', '8911413', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '桜島松浦町', 'サクラジママツウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市桜島西道町', '46', '46201', '8911414', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '桜島西道町', 'サクラジマサイドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市桜島藤野町', '46', '46201', '8911415', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '桜島藤野町', 'サクラジマフジノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市桜島武町', '46', '46201', '8911416', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '桜島武町', 'サクラジマタケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市桜島赤生原町', '46', '46201', '8911417', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '桜島赤生原町', 'サクラジマアコウバルチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市桜島小池町', '46', '46201', '8911418', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '桜島小池町', 'サクラジマコイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市桜島横山町', '46', '46201', '8911419', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '桜島横山町', 'サクラジマヨコヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市桜島赤水町', '46', '46201', '8911420', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '桜島赤水町', 'サクラジマアカミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市黒神町枦ノ木ケ谷', '46', '46201', '8911501', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '黒神町', 'クロカミチョウ', null, null, '枦ノ木ケ谷', 'ハゼノキガダニ');
INSERT INTO `ms_addresses` VALUES ('116914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市野尻町', '46', '46201', '8911541', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '野尻町', 'ノジリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市持木町', '46', '46201', '8911542', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '持木町', 'モチキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市東桜島町', '46', '46201', '8911543', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '東桜島町', 'ヒガシサクラジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市古里町', '46', '46201', '8911544', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '古里町', 'フルサトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市有村町', '46', '46201', '8911545', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '有村町', 'アリムラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市愛国町', '01', '01207', '0891181', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '愛国町', 'アイコクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市川西町', '01', '01207', '0891182', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '川西町', 'カワニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市豊西町', '01', '01207', '0891183', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '豊西町', 'トヨニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市別府町', '01', '01207', '0891184', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '別府町', 'ベップチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県垂水市', '46', '46214', '8912100', '鹿児島県', 'カゴシマケン', '垂水市', 'タルミズシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('116927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県垂水市海潟', '46', '46214', '8912101', '鹿児島県', 'カゴシマケン', '垂水市', 'タルミズシ', '海潟', 'カイガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県垂水市中俣', '46', '46214', '8912102', '鹿児島県', 'カゴシマケン', '垂水市', 'タルミズシ', '中俣', 'ナカマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県垂水市市木', '46', '46214', '8912103', '鹿児島県', 'カゴシマケン', '垂水市', 'タルミズシ', '市木', 'イチキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県垂水市田神', '46', '46214', '8912104', '鹿児島県', 'カゴシマケン', '垂水市', 'タルミズシ', '田神', 'タガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県垂水市松原町', '46', '46214', '8912105', '鹿児島県', 'カゴシマケン', '垂水市', 'タルミズシ', '松原町', 'マツバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県垂水市中央町', '46', '46214', '8912106', '鹿児島県', 'カゴシマケン', '垂水市', 'タルミズシ', '中央町', 'チュウオウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県垂水市新御堂', '46', '46214', '8912111', '鹿児島県', 'カゴシマケン', '垂水市', 'タルミズシ', '新御堂', 'シンミドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県垂水市本城', '46', '46214', '8912112', '鹿児島県', 'カゴシマケン', '垂水市', 'タルミズシ', '本城', 'ホンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県垂水市高城', '46', '46214', '8912113', '鹿児島県', 'カゴシマケン', '垂水市', 'タルミズシ', '高城', 'タカジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県垂水市新城', '46', '46214', '8912114', '鹿児島県', 'カゴシマケン', '垂水市', 'タルミズシ', '新城', 'シンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県垂水市浜平', '46', '46214', '8912115', '鹿児島県', 'カゴシマケン', '垂水市', 'タルミズシ', '浜平', 'ハマビラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県垂水市柊原', '46', '46214', '8912116', '鹿児島県', 'カゴシマケン', '垂水市', 'タルミズシ', '柊原', 'クヌギバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県垂水市潮彩町', '46', '46214', '8912117', '鹿児島県', 'カゴシマケン', '垂水市', 'タルミズシ', '潮彩町', 'シオサイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県垂水市栄町', '46', '46214', '8912121', '鹿児島県', 'カゴシマケン', '垂水市', 'タルミズシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県垂水市上町', '46', '46214', '8912122', '鹿児島県', 'カゴシマケン', '垂水市', 'タルミズシ', '上町', 'カンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県垂水市本町', '46', '46214', '8912123', '鹿児島県', 'カゴシマケン', '垂水市', 'タルミズシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県垂水市錦江町', '46', '46214', '8912124', '鹿児島県', 'カゴシマケン', '垂水市', 'タルミズシ', '錦江町', 'キンコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県垂水市旭町', '46', '46214', '8912125', '鹿児島県', 'カゴシマケン', '垂水市', 'タルミズシ', '旭町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県垂水市南松原町', '46', '46214', '8912126', '鹿児島県', 'カゴシマケン', '垂水市', 'タルミズシ', '南松原町', 'ミナミマツバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県垂水市下宮町', '46', '46214', '8912127', '鹿児島県', 'カゴシマケン', '垂水市', 'タルミズシ', '下宮町', 'シモミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿屋市有武町', '46', '46203', '8912301', '鹿児島県', 'カゴシマケン', '鹿屋市', 'カノヤシ', '有武町', 'アリタケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿屋市小薄町', '46', '46203', '8912302', '鹿児島県', 'カゴシマケン', '鹿屋市', 'カノヤシ', '小薄町', 'オスキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿屋市海道町', '46', '46203', '8912303', '鹿児島県', 'カゴシマケン', '鹿屋市', 'カノヤシ', '海道町', 'カイドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿屋市花岡町', '46', '46203', '8912304', '鹿児島県', 'カゴシマケン', '鹿屋市', 'カノヤシ', '花岡町', 'ハナオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿屋市根木原町', '46', '46203', '8912305', '鹿児島県', 'カゴシマケン', '鹿屋市', 'カノヤシ', '根木原町', 'ネギバルチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿屋市花里町', '46', '46203', '8912306', '鹿児島県', 'カゴシマケン', '鹿屋市', 'カノヤシ', '花里町', 'ハナザトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿屋市白水町', '46', '46203', '8912311', '鹿児島県', 'カゴシマケン', '鹿屋市', 'カノヤシ', '白水町', 'シロミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿屋市小野原町', '46', '46203', '8912312', '鹿児島県', 'カゴシマケン', '鹿屋市', 'カノヤシ', '小野原町', 'オノバルチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿屋市天神町', '46', '46203', '8912313', '鹿児島県', 'カゴシマケン', '鹿屋市', 'カノヤシ', '天神町', 'テンジンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿屋市船間町', '46', '46203', '8912314', '鹿児島県', 'カゴシマケン', '鹿屋市', 'カノヤシ', '船間町', 'フナマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿屋市古江町', '46', '46203', '8912321', '鹿児島県', 'カゴシマケン', '鹿屋市', 'カノヤシ', '古江町', 'フルエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿屋市古里町', '46', '46203', '8912322', '鹿児島県', 'カゴシマケン', '鹿屋市', 'カノヤシ', '古里町', 'フルサトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市大正本町', '01', '01207', '0891241', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '大正本町', 'タイショウホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市大正町', '01', '01207', '0891242', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '大正町', 'タイショウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市桜木町', '01', '01207', '0891243', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '桜木町', 'サクラギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市以平町', '01', '01207', '0891244', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '以平町', 'イタイラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市泉町', '01', '01207', '0891245', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '泉町', 'イズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市幸福町', '01', '01207', '0891246', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '幸福町', 'コウフクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市昭和町', '01', '01207', '0891247', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '昭和町', 'ショウワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市富士町', '01', '01207', '0891251', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '富士町', 'フジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道帯広市中島町', '01', '01207', '0891252', '北海道', 'ホッカイドウ', '帯広市', 'オビヒロシ', '中島町', 'ナカジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡中札内村', '01', '01638', '0891300', '北海道', 'ホッカイドウ', '河西郡中札内村', 'カサイグンナカサツナイムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('116972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡中札内村大通北', '01', '01638', '0891310', '北海道', 'ホッカイドウ', '河西郡中札内村', 'カサイグンナカサツナイムラ', '大通北', 'オオドオリキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県西之表市', '46', '46213', '8913100', '鹿児島県', 'カゴシマケン', '西之表市', 'ニシノオモテシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('116974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県西之表市西之表', '46', '46213', '8913101', '鹿児島県', 'カゴシマケン', '西之表市', 'ニシノオモテシ', '西之表', 'ニシノオモテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県西之表市安納', '46', '46213', '8913102', '鹿児島県', 'カゴシマケン', '西之表市', 'ニシノオモテシ', '安納', 'アンノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県西之表市現和', '46', '46213', '8913103', '鹿児島県', 'カゴシマケン', '西之表市', 'ニシノオモテシ', '現和', 'ゲンナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県西之表市住吉', '46', '46213', '8913104', '鹿児島県', 'カゴシマケン', '西之表市', 'ニシノオモテシ', '住吉', 'スミヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡中札内村西1条北', '01', '01638', '0891311', '北海道', 'ホッカイドウ', '河西郡中札内村', 'カサイグンナカサツナイムラ', '西1条北', 'ニシ01ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県西之表市西町', '46', '46213', '8913111', '鹿児島県', 'カゴシマケン', '西之表市', 'ニシノオモテシ', '西町', 'ニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県西之表市栄町', '46', '46213', '8913112', '鹿児島県', 'カゴシマケン', '西之表市', 'ニシノオモテシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県西之表市東町', '46', '46213', '8913113', '鹿児島県', 'カゴシマケン', '西之表市', 'ニシノオモテシ', '東町', 'ヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県西之表市池田', '46', '46213', '8913114', '鹿児島県', 'カゴシマケン', '西之表市', 'ニシノオモテシ', '池田', 'イケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県西之表市天神町', '46', '46213', '8913115', '鹿児島県', 'カゴシマケン', '西之表市', 'ニシノオモテシ', '天神町', 'テンジンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県西之表市鴨女町', '46', '46213', '8913116', '鹿児島県', 'カゴシマケン', '西之表市', 'ニシノオモテシ', '鴨女町', 'カモメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県西之表市桜が丘', '46', '46213', '8913117', '鹿児島県', 'カゴシマケン', '西之表市', 'ニシノオモテシ', '桜が丘', 'サクラガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県西之表市馬毛島', '46', '46213', '8913118', '鹿児島県', 'カゴシマケン', '西之表市', 'ニシノオモテシ', '馬毛島', 'マゲシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡中札内村西2条北', '01', '01638', '0891312', '北海道', 'ホッカイドウ', '河西郡中札内村', 'カサイグンナカサツナイムラ', '西2条北', 'ニシ02ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡中札内村中札内西', '01', '01638', '0891313', '北海道', 'ホッカイドウ', '河西郡中札内村', 'カサイグンナカサツナイムラ', '中札内西', 'ナカサツナイニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県西之表市安納', '46', '46213', '8913202', '鹿児島県', 'カゴシマケン', '西之表市', 'ニシノオモテシ', '安納', 'アンノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡中札内村東1条北', '01', '01638', '0891321', '北海道', 'ホッカイドウ', '河西郡中札内村', 'カサイグンナカサツナイムラ', '東1条北', 'ヒガシ01ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡中札内村東2条北', '01', '01638', '0891322', '北海道', 'ホッカイドウ', '河西郡中札内村', 'カサイグンナカサツナイムラ', '東2条北', 'ヒガシ02ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県西之表市伊関', '46', '46213', '8913221', '鹿児島県', 'カゴシマケン', '西之表市', 'ニシノオモテシ', '伊関', 'イセキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('116999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県西之表市国上', '46', '46213', '8913222', '鹿児島県', 'カゴシマケン', '西之表市', 'ニシノオモテシ', '国上', 'クニガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡中札内村東3条北', '01', '01638', '0891323', '北海道', 'ホッカイドウ', '河西郡中札内村', 'カサイグンナカサツナイムラ', '東3条北', 'ヒガシ03ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡中札内村東4条北', '01', '01638', '0891324', '北海道', 'ホッカイドウ', '河西郡中札内村', 'カサイグンナカサツナイムラ', '東4条北', 'ヒガシ04ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡中札内村中札内基線', '01', '01638', '0891325', '北海道', 'ホッカイドウ', '河西郡中札内村', 'カサイグンナカサツナイムラ', '中札内基線', 'ナカサツナイキセン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡中札内村大通南', '01', '01638', '0891330', '北海道', 'ホッカイドウ', '河西郡中札内村', 'カサイグンナカサツナイムラ', '大通南', 'オオドオリミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡中札内村西1条南', '01', '01638', '0891331', '北海道', 'ホッカイドウ', '河西郡中札内村', 'カサイグンナカサツナイムラ', '西1条南', 'ニシ01ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡中札内村西2条南', '01', '01638', '0891332', '北海道', 'ホッカイドウ', '河西郡中札内村', 'カサイグンナカサツナイムラ', '西2条南', 'ニシ02ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡中札内村東1条南', '01', '01638', '0891341', '北海道', 'ホッカイドウ', '河西郡中札内村', 'カサイグンナカサツナイムラ', '東1条南', 'ヒガシ01ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡中札内村東2条南', '01', '01638', '0891342', '北海道', 'ホッカイドウ', '河西郡中札内村', 'カサイグンナカサツナイムラ', '東2条南', 'ヒガシ02ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡中札内村東3条南', '01', '01638', '0891343', '北海道', 'ホッカイドウ', '河西郡中札内村', 'カサイグンナカサツナイムラ', '東3条南', 'ヒガシ03ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県西之表市古田', '46', '46213', '8913431', '鹿児島県', 'カゴシマケン', '西之表市', 'ニシノオモテシ', '古田', 'フルタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県西之表市安城', '46', '46213', '8913432', '鹿児島県', 'カゴシマケン', '西之表市', 'ニシノオモテシ', '安城', 'アンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡中札内村東4条南', '01', '01638', '0891344', '北海道', 'ホッカイドウ', '河西郡中札内村', 'カサイグンナカサツナイムラ', '東4条南', 'ヒガシ04ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡中札内村東5条南', '01', '01638', '0891345', '北海道', 'ホッカイドウ', '河西郡中札内村', 'カサイグンナカサツナイムラ', '東5条南', 'ヒガシ05ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡中札内村東戸蔦', '01', '01638', '0891351', '北海道', 'ホッカイドウ', '河西郡中札内村', 'カサイグンナカサツナイムラ', '東戸蔦', 'ヒガシトツタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡中札内村中戸蔦', '01', '01638', '0891352', '北海道', 'ホッカイドウ', '河西郡中札内村', 'カサイグンナカサツナイムラ', '中戸蔦', 'ナカトツタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡中札内村西戸蔦', '01', '01638', '0891353', '北海道', 'ホッカイドウ', '河西郡中札内村', 'カサイグンナカサツナイムラ', '西戸蔦', 'ニシトツタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡中札内村新札内', '01', '01638', '0891354', '北海道', 'ホッカイドウ', '河西郡中札内村', 'カサイグンナカサツナイムラ', '新札内', 'シンサツナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡中札内村新札内南', '01', '01638', '0891355', '北海道', 'ホッカイドウ', '河西郡中札内村', 'カサイグンナカサツナイムラ', '新札内南', 'シンサツナイミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡中札内村西札内', '01', '01638', '0891356', '北海道', 'ホッカイドウ', '河西郡中札内村', 'カサイグンナカサツナイムラ', '西札内', 'ニシサツナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県熊毛郡中種子町', '46', '46501', '8913600', '鹿児島県', 'カゴシマケン', '熊毛郡中種子町', 'クマゲグンナカタネチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('117020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県熊毛郡中種子町納官', '46', '46501', '8913601', '鹿児島県', 'カゴシマケン', '熊毛郡中種子町', 'クマゲグンナカタネチョウ', '納官', 'ノウカン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県熊毛郡中種子町牧川', '46', '46501', '8913602', '鹿児島県', 'カゴシマケン', '熊毛郡中種子町', 'クマゲグンナカタネチョウ', '牧川', 'マキガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県熊毛郡中種子町増田', '46', '46501', '8913603', '鹿児島県', 'カゴシマケン', '熊毛郡中種子町', 'クマゲグンナカタネチョウ', '増田', 'マスダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県熊毛郡中種子町野間', '46', '46501', '8913604', '鹿児島県', 'カゴシマケン', '熊毛郡中種子町', 'クマゲグンナカタネチョウ', '野間', 'ノマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県熊毛郡中種子町油久', '46', '46501', '8913605', '鹿児島県', 'カゴシマケン', '熊毛郡中種子町', 'クマゲグンナカタネチョウ', '油久', 'ユク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県熊毛郡中種子町坂井', '46', '46501', '8913606', '鹿児島県', 'カゴシマケン', '熊毛郡中種子町', 'クマゲグンナカタネチョウ', '坂井', 'サカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県熊毛郡中種子町田島', '46', '46501', '8913607', '鹿児島県', 'カゴシマケン', '熊毛郡中種子町', 'クマゲグンナカタネチョウ', '田島', 'タシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡中札内村元大正', '01', '01638', '0891361', '北海道', 'ホッカイドウ', '河西郡中札内村', 'カサイグンナカサツナイムラ', '元大正', 'モトタイショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡中札内村新生', '01', '01638', '0891362', '北海道', 'ホッカイドウ', '河西郡中札内村', 'カサイグンナカサツナイムラ', '新生', 'シンセイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡中札内村興和', '01', '01638', '0891363', '北海道', 'ホッカイドウ', '河西郡中札内村', 'カサイグンナカサツナイムラ', '興和', 'コウワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡中札内村共栄', '01', '01638', '0891364', '北海道', 'ホッカイドウ', '河西郡中札内村', 'カサイグンナカサツナイムラ', '共栄', 'キョウエイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡中札内村協和', '01', '01638', '0891365', '北海道', 'ホッカイドウ', '河西郡中札内村', 'カサイグンナカサツナイムラ', '協和', 'キョウワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡中札内村栄', '01', '01638', '0891366', '北海道', 'ホッカイドウ', '河西郡中札内村', 'カサイグンナカサツナイムラ', '栄', 'サカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡中札内村常盤基線', '01', '01638', '0891367', '北海道', 'ホッカイドウ', '河西郡中札内村', 'カサイグンナカサツナイムラ', '常盤基線', 'トキワキセン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡中札内村南常盤', '01', '01638', '0891368', '北海道', 'ホッカイドウ', '河西郡中札内村', 'カサイグンナカサツナイムラ', '南常盤', 'ミナミトキワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県熊毛郡南種子町', '46', '46502', '8913700', '鹿児島県', 'カゴシマケン', '熊毛郡南種子町', 'クマゲグンミナミタネチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('117038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県熊毛郡南種子町中之上', '46', '46502', '8913701', '鹿児島県', 'カゴシマケン', '熊毛郡南種子町', 'クマゲグンミナミタネチョウ', '中之上', 'ナカノカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県熊毛郡南種子町平山', '46', '46502', '8913702', '鹿児島県', 'カゴシマケン', '熊毛郡南種子町', 'クマゲグンミナミタネチョウ', '平山', 'ヒラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県熊毛郡南種子町茎永', '46', '46502', '8913703', '鹿児島県', 'カゴシマケン', '熊毛郡南種子町', 'クマゲグンミナミタネチョウ', '茎永', 'クキナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県熊毛郡南種子町中之下', '46', '46502', '8913704', '鹿児島県', 'カゴシマケン', '熊毛郡南種子町', 'クマゲグンミナミタネチョウ', '中之下', 'ナカノシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県熊毛郡南種子町西之', '46', '46502', '8913705', '鹿児島県', 'カゴシマケン', '熊毛郡南種子町', 'クマゲグンミナミタネチョウ', '西之', 'ニシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県熊毛郡南種子町島間', '46', '46502', '8913706', '鹿児島県', 'カゴシマケン', '熊毛郡南種子町', 'クマゲグンミナミタネチョウ', '島間', 'シママ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡中札内村上札内', '01', '01638', '0891371', '北海道', 'ホッカイドウ', '河西郡中札内村', 'カサイグンナカサツナイムラ', '上札内', 'カミサツナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡中札内村元札内', '01', '01638', '0891372', '北海道', 'ホッカイドウ', '河西郡中札内村', 'カサイグンナカサツナイムラ', '元札内', 'モトサツナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡中札内村元更別', '01', '01638', '0891373', '北海道', 'ホッカイドウ', '河西郡中札内村', 'カサイグンナカサツナイムラ', '元更別', 'モトサラベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡中札内村南札内', '01', '01638', '0891374', '北海道', 'ホッカイドウ', '河西郡中札内村', 'カサイグンナカサツナイムラ', '南札内', 'ミナミサツナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県熊毛郡屋久島町', '46', '46505', '8914200', '鹿児島県', 'カゴシマケン', '熊毛郡屋久島町', 'クマゲグンヤクシマチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('117053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県熊毛郡屋久島町永田', '46', '46505', '8914201', '鹿児島県', 'カゴシマケン', '熊毛郡屋久島町', 'クマゲグンヤクシマチョウ', '永田', 'ナガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県熊毛郡屋久島町吉田', '46', '46505', '8914202', '鹿児島県', 'カゴシマケン', '熊毛郡屋久島町', 'クマゲグンヤクシマチョウ', '吉田', 'ヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県熊毛郡屋久島町一湊', '46', '46505', '8914203', '鹿児島県', 'カゴシマケン', '熊毛郡屋久島町', 'クマゲグンヤクシマチョウ', '一湊', 'イッソウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県熊毛郡屋久島町志戸子', '46', '46505', '8914204', '鹿児島県', 'カゴシマケン', '熊毛郡屋久島町', 'クマゲグンヤクシマチョウ', '志戸子', 'シトゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県熊毛郡屋久島町宮之浦', '46', '46505', '8914205', '鹿児島県', 'カゴシマケン', '熊毛郡屋久島町', 'クマゲグンヤクシマチョウ', '宮之浦', 'ミヤノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県熊毛郡屋久島町楠川', '46', '46505', '8914206', '鹿児島県', 'カゴシマケン', '熊毛郡屋久島町', 'クマゲグンヤクシマチョウ', '楠川', 'クスガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県熊毛郡屋久島町小瀬田', '46', '46505', '8914207', '鹿児島県', 'カゴシマケン', '熊毛郡屋久島町', 'クマゲグンヤクシマチョウ', '小瀬田', 'コセダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県熊毛郡屋久島町口永良部島', '46', '46505', '8914208', '鹿児島県', 'カゴシマケン', '熊毛郡屋久島町', 'クマゲグンヤクシマチョウ', '口永良部島', 'クチエラブジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県熊毛郡屋久島町安房', '46', '46505', '8914311', '鹿児島県', 'カゴシマケン', '熊毛郡屋久島町', 'クマゲグンヤクシマチョウ', '安房', 'アンボウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県熊毛郡屋久島町船行', '46', '46505', '8914312', '鹿児島県', 'カゴシマケン', '熊毛郡屋久島町', 'クマゲグンヤクシマチョウ', '船行', 'フナユキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県熊毛郡屋久島町麦生高平', '46', '46505', '8914401', '鹿児島県', 'カゴシマケン', '熊毛郡屋久島町', 'クマゲグンヤクシマチョウ', '麦生', 'ムギオ', null, null, '高平', 'タカビラ');
INSERT INTO `ms_addresses` VALUES ('117065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県熊毛郡屋久島町麦生', '46', '46505', '8914402', '鹿児島県', 'カゴシマケン', '熊毛郡屋久島町', 'クマゲグンヤクシマチョウ', '麦生', 'ムギオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県熊毛郡屋久島町原', '46', '46505', '8914403', '鹿児島県', 'カゴシマケン', '熊毛郡屋久島町', 'クマゲグンヤクシマチョウ', '原', 'ハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県熊毛郡屋久島町尾之間', '46', '46505', '8914404', '鹿児島県', 'カゴシマケン', '熊毛郡屋久島町', 'クマゲグンヤクシマチョウ', '尾之間', 'オノアイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県熊毛郡屋久島町小島', '46', '46505', '8914405', '鹿児島県', 'カゴシマケン', '熊毛郡屋久島町', 'クマゲグンヤクシマチョウ', '小島', 'コシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県熊毛郡屋久島町平内', '46', '46505', '8914406', '鹿児島県', 'カゴシマケン', '熊毛郡屋久島町', 'クマゲグンヤクシマチョウ', '平内', 'ヒラウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県熊毛郡屋久島町湯泊', '46', '46505', '8914407', '鹿児島県', 'カゴシマケン', '熊毛郡屋久島町', 'クマゲグンヤクシマチョウ', '湯泊', 'ユドマリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県熊毛郡屋久島町中間', '46', '46505', '8914408', '鹿児島県', 'カゴシマケン', '熊毛郡屋久島町', 'クマゲグンヤクシマチョウ', '中間', 'ナカマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県熊毛郡屋久島町栗生', '46', '46505', '8914409', '鹿児島県', 'カゴシマケン', '熊毛郡屋久島町', 'クマゲグンヤクシマチョウ', '栗生', 'クリオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡更別村', '01', '01639', '0891500', '北海道', 'ホッカイドウ', '河西郡更別村', 'カサイグンサラベツムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('117074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡更別村新栄町', '01', '01639', '0891501', '北海道', 'ホッカイドウ', '河西郡更別村', 'カサイグンサラベツムラ', '新栄町', 'シンエイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡更別村花園町', '01', '01639', '0891502', '北海道', 'ホッカイドウ', '河西郡更別村', 'カサイグンサラベツムラ', '花園町', 'ハナゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島郡十島村口之島', '46', '46304', '8915101', '鹿児島県', 'カゴシマケン', '鹿児島郡十島村', 'カゴシマグントシマムラ', '口之島', 'クチノシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡更別村柏町', '01', '01639', '0891511', '北海道', 'ホッカイドウ', '河西郡更別村', 'カサイグンサラベツムラ', '柏町', 'カシワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡更別村中央町', '01', '01639', '0891512', '北海道', 'ホッカイドウ', '河西郡更別村', 'カサイグンサラベツムラ', '中央町', 'チュウオウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡更別村本町', '01', '01639', '0891513', '北海道', 'ホッカイドウ', '河西郡更別村', 'カサイグンサラベツムラ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島郡十島村', '46', '46304', '8915200', '鹿児島県', 'カゴシマケン', '鹿児島郡十島村', 'カゴシマグントシマムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('117081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島郡十島村中之島', '46', '46304', '8915201', '鹿児島県', 'カゴシマケン', '鹿児島郡十島村', 'カゴシマグントシマムラ', '中之島', 'ナカノシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島郡十島村平島', '46', '46304', '8915202', '鹿児島県', 'カゴシマケン', '鹿児島郡十島村', 'カゴシマグントシマムラ', '平島', 'タイラジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島郡十島村諏訪之瀬島', '46', '46304', '8915203', '鹿児島県', 'カゴシマケン', '鹿児島郡十島村', 'カゴシマグントシマムラ', '諏訪之瀬島', 'スワノセジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島郡十島村悪石島', '46', '46304', '8915204', '鹿児島県', 'カゴシマケン', '鹿児島郡十島村', 'カゴシマグントシマムラ', '悪石島', 'アクセキジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島郡十島村小宝島', '46', '46304', '8915205', '鹿児島県', 'カゴシマケン', '鹿児島郡十島村', 'カゴシマグントシマムラ', '小宝島', 'コダカラジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡更別村錦町', '01', '01639', '0891521', '北海道', 'ホッカイドウ', '河西郡更別村', 'カサイグンサラベツムラ', '錦町', 'ニシキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡更別村若葉町', '01', '01639', '0891522', '北海道', 'ホッカイドウ', '河西郡更別村', 'カサイグンサラベツムラ', '若葉町', 'ワカバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島郡十島村宝島', '46', '46304', '8915301', '鹿児島県', 'カゴシマケン', '鹿児島郡十島村', 'カゴシマグントシマムラ', '宝島', 'タカラジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡更別村曙町', '01', '01639', '0891531', '北海道', 'ホッカイドウ', '河西郡更別村', 'カサイグンサラベツムラ', '曙町', 'アケボノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡更別村緑町', '01', '01639', '0891532', '北海道', 'ホッカイドウ', '河西郡更別村', 'カサイグンサラベツムラ', '緑町', 'ミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡更別村更南', '01', '01639', '0891541', '北海道', 'ホッカイドウ', '河西郡更別村', 'カサイグンサラベツムラ', '更南', 'コウナン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡更別村更別', '01', '01639', '0891542', '北海道', 'ホッカイドウ', '河西郡更別村', 'カサイグンサラベツムラ', '更別', 'サラベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡更別村昭和区', '01', '01639', '0891543', '北海道', 'ホッカイドウ', '河西郡更別村', 'カサイグンサラベツムラ', '昭和区', 'ショウワク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡更別村旭区', '01', '01639', '0891551', '北海道', 'ホッカイドウ', '河西郡更別村', 'カサイグンサラベツムラ', '旭区', 'アサヒク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡更別村勢雄', '01', '01639', '0891552', '北海道', 'ホッカイドウ', '河西郡更別村', 'カサイグンサラベツムラ', '勢雄', 'セオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡更別村平和区', '01', '01639', '0891553', '北海道', 'ホッカイドウ', '河西郡更別村', 'カサイグンサラベツムラ', '平和区', 'ヘイワク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡更別村北更別区', '01', '01639', '0891561', '北海道', 'ホッカイドウ', '河西郡更別村', 'カサイグンサラベツムラ', '北更別区', 'キタサラベツク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡更別村更別東区', '01', '01639', '0891562', '北海道', 'ホッカイドウ', '河西郡更別村', 'カサイグンサラベツムラ', '更別', 'サラベツ', null, null, '東区', 'ヒガシク');
INSERT INTO `ms_addresses` VALUES ('117099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡更別村南更別区', '01', '01639', '0891563', '北海道', 'ホッカイドウ', '河西郡更別村', 'カサイグンサラベツムラ', '南更別区', 'ミナミサラベツク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡更別村香川区', '01', '01639', '0891571', '北海道', 'ホッカイドウ', '河西郡更別村', 'カサイグンサラベツムラ', '香川区', 'カガワク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡更別村更生区', '01', '01639', '0891572', '北海道', 'ホッカイドウ', '河西郡更別村', 'カサイグンサラベツムラ', '更生区', 'コウセイク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡更別村弘和', '01', '01639', '0891573', '北海道', 'ホッカイドウ', '河西郡更別村', 'カサイグンサラベツムラ', '弘和', 'コウワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡更別村東栄', '01', '01639', '0891573', '北海道', 'ホッカイドウ', '河西郡更別村', 'カサイグンサラベツムラ', '東栄', 'トウエイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡更別村上更別南区', '01', '01639', '0891581', '北海道', 'ホッカイドウ', '河西郡更別村', 'カサイグンサラベツムラ', '上更別', 'カミサラベツ', null, null, '南区', 'ミナミク');
INSERT INTO `ms_addresses` VALUES ('117105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡更別村協和区', '01', '01639', '0891582', '北海道', 'ホッカイドウ', '河西郡更別村', 'カサイグンサラベツムラ', '協和区', 'キョウワク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道河西郡更別村上更別1区', '01', '01639', '0891583', '北海道', 'ホッカイドウ', '河西郡更別村', 'カサイグンサラベツムラ', '上更別', 'カミサラベツ', null, null, '1区', '01ク');
INSERT INTO `ms_addresses` VALUES ('117109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡喜界町伊実久', '46', '46529', '8916141', '鹿児島県', 'カゴシマケン', '大島郡喜界町', 'オオシマグンキカイチョウ', '伊実久', 'イサネク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡喜界町小野津', '46', '46529', '8916142', '鹿児島県', 'カゴシマケン', '大島郡喜界町', 'オオシマグンキカイチョウ', '小野津', 'オノツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡喜界町志戸桶', '46', '46529', '8916143', '鹿児島県', 'カゴシマケン', '大島郡喜界町', 'オオシマグンキカイチョウ', '志戸桶', 'シトオケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡喜界町佐手久', '46', '46529', '8916144', '鹿児島県', 'カゴシマケン', '大島郡喜界町', 'オオシマグンキカイチョウ', '佐手久', 'サデク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡喜界町塩道', '46', '46529', '8916151', '鹿児島県', 'カゴシマケン', '大島郡喜界町', 'オオシマグンキカイチョウ', '塩道', 'シオミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡喜界町早町', '46', '46529', '8916152', '鹿児島県', 'カゴシマケン', '大島郡喜界町', 'オオシマグンキカイチョウ', '早町', 'ソウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡喜界町長嶺', '46', '46529', '8916153', '鹿児島県', 'カゴシマケン', '大島郡喜界町', 'オオシマグンキカイチョウ', '長嶺', 'ナガミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡喜界町白水', '46', '46529', '8916154', '鹿児島県', 'カゴシマケン', '大島郡喜界町', 'オオシマグンキカイチョウ', '白水', 'シラミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡喜界町嘉鈍', '46', '46529', '8916161', '鹿児島県', 'カゴシマケン', '大島郡喜界町', 'オオシマグンキカイチョウ', '嘉鈍', 'カドン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡喜界町阿伝', '46', '46529', '8916162', '鹿児島県', 'カゴシマケン', '大島郡喜界町', 'オオシマグンキカイチョウ', '阿伝', 'アデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡喜界町花良治蒲生', '46', '46529', '8916163', '鹿児島県', 'カゴシマケン', '大島郡喜界町', 'オオシマグンキカイチョウ', '花良治', 'ケラジ', null, null, '蒲生', 'ガモウ');
INSERT INTO `ms_addresses` VALUES ('117120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡喜界町花良治', '46', '46529', '8916164', '鹿児島県', 'カゴシマケン', '大島郡喜界町', 'オオシマグンキカイチョウ', '花良治', 'ケラジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡喜界町', '46', '46529', '8916200', '鹿児島県', 'カゴシマケン', '大島郡喜界町', 'オオシマグンキカイチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('117122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡喜界町赤連', '46', '46529', '8916201', '鹿児島県', 'カゴシマケン', '大島郡喜界町', 'オオシマグンキカイチョウ', '赤連', 'アカレン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡喜界町湾', '46', '46529', '8916202', '鹿児島県', 'カゴシマケン', '大島郡喜界町', 'オオシマグンキカイチョウ', '湾', 'ワン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡喜界町中里', '46', '46529', '8916203', '鹿児島県', 'カゴシマケン', '大島郡喜界町', 'オオシマグンキカイチョウ', '中里', 'ナカサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡喜界町中間', '46', '46529', '8916211', '鹿児島県', 'カゴシマケン', '大島郡喜界町', 'オオシマグンキカイチョウ', '中間', 'ナカマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡喜界町中熊先内', '46', '46529', '8916212', '鹿児島県', 'カゴシマケン', '大島郡喜界町', 'オオシマグンキカイチョウ', '中熊', 'ナカグマ', null, null, '先内', 'サキナイ');
INSERT INTO `ms_addresses` VALUES ('117127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡喜界町大朝戸', '46', '46529', '8916213', '鹿児島県', 'カゴシマケン', '大島郡喜界町', 'オオシマグンキカイチョウ', '大朝戸', 'オオアサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡喜界町西目', '46', '46529', '8916214', '鹿児島県', 'カゴシマケン', '大島郡喜界町', 'オオシマグンキカイチョウ', '西目', 'ニシメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡喜界町中熊', '46', '46529', '8916215', '鹿児島県', 'カゴシマケン', '大島郡喜界町', 'オオシマグンキカイチョウ', '中熊', 'ナカグマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡喜界町坂嶺', '46', '46529', '8916216', '鹿児島県', 'カゴシマケン', '大島郡喜界町', 'オオシマグンキカイチョウ', '坂嶺', 'サカミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡喜界町伊砂', '46', '46529', '8916217', '鹿児島県', 'カゴシマケン', '大島郡喜界町', 'オオシマグンキカイチョウ', '伊砂', 'イサゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡喜界町池治', '46', '46529', '8916221', '鹿児島県', 'カゴシマケン', '大島郡喜界町', 'オオシマグンキカイチョウ', '池治', 'イケジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡喜界町島中', '46', '46529', '8916222', '鹿児島県', 'カゴシマケン', '大島郡喜界町', 'オオシマグンキカイチョウ', '島中', 'シマナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡喜界町滝川', '46', '46529', '8916223', '鹿児島県', 'カゴシマケン', '大島郡喜界町', 'オオシマグンキカイチョウ', '滝川', 'タキガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡喜界町城久', '46', '46529', '8916224', '鹿児島県', 'カゴシマケン', '大島郡喜界町', 'オオシマグンキカイチョウ', '城久', 'グスク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡喜界町山田', '46', '46529', '8916225', '鹿児島県', 'カゴシマケン', '大島郡喜界町', 'オオシマグンキカイチョウ', '山田', 'ヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡喜界町羽里', '46', '46529', '8916226', '鹿児島県', 'カゴシマケン', '大島郡喜界町', 'オオシマグンキカイチョウ', '羽里', 'ハサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡喜界町川嶺', '46', '46529', '8916227', '鹿児島県', 'カゴシマケン', '大島郡喜界町', 'オオシマグンキカイチョウ', '川嶺', 'カワミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡喜界町浦原', '46', '46529', '8916228', '鹿児島県', 'カゴシマケン', '大島郡喜界町', 'オオシマグンキカイチョウ', '浦原', 'ウラハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡喜界町先山', '46', '46529', '8916229', '鹿児島県', 'カゴシマケン', '大島郡喜界町', 'オオシマグンキカイチョウ', '先山', 'サキヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡喜界町荒木', '46', '46529', '8916231', '鹿児島県', 'カゴシマケン', '大島郡喜界町', 'オオシマグンキカイチョウ', '荒木', 'アラキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡喜界町手久津久', '46', '46529', '8916232', '鹿児島県', 'カゴシマケン', '大島郡喜界町', 'オオシマグンキカイチョウ', '手久津久', 'テクヅク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡喜界町上嘉鉄', '46', '46529', '8916233', '鹿児島県', 'カゴシマケン', '大島郡喜界町', 'オオシマグンキカイチョウ', '上嘉鉄', 'カミカテツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡幕別町忠類白銀町', '01', '01643', '0891701', '北海道', 'ホッカイドウ', '中川郡幕別町', 'ナカガワグンマクベツチョウ', '忠類白銀町', 'チュウルイシロガネマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡幕別町忠類栄町', '01', '01643', '0891703', '北海道', 'ホッカイドウ', '中川郡幕別町', 'ナカガワグンマクベツチョウ', '忠類栄町', 'チュウルイサカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡幕別町忠類本町', '01', '01643', '0891705', '北海道', 'ホッカイドウ', '中川郡幕別町', 'ナカガワグンマクベツチョウ', '忠類本町', 'チュウルイモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡幕別町忠類錦町', '01', '01643', '0891707', '北海道', 'ホッカイドウ', '中川郡幕別町', 'ナカガワグンマクベツチョウ', '忠類錦町', 'チュウルイニシキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡幕別町忠類幸町', '01', '01643', '0891709', '北海道', 'ホッカイドウ', '中川郡幕別町', 'ナカガワグンマクベツチョウ', '忠類幸町', 'チュウルイサイワイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡徳之島町', '46', '46530', '8917100', '鹿児島県', 'カゴシマケン', '大島郡徳之島町', 'オオシマグントクノシマチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('117151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡徳之島町亀津', '46', '46530', '8917101', '鹿児島県', 'カゴシマケン', '大島郡徳之島町', 'オオシマグントクノシマチョウ', '亀津', 'カメツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡徳之島町亀徳', '46', '46530', '8917102', '鹿児島県', 'カゴシマケン', '大島郡徳之島町', 'オオシマグントクノシマチョウ', '亀徳', 'カメトク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡徳之島町南原', '46', '46530', '8917103', '鹿児島県', 'カゴシマケン', '大島郡徳之島町', 'オオシマグントクノシマチョウ', '南原', 'ミナミハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡徳之島町尾母', '46', '46530', '8917104', '鹿児島県', 'カゴシマケン', '大島郡徳之島町', 'オオシマグントクノシマチョウ', '尾母', 'オモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡徳之島町白井', '46', '46530', '8917105', '鹿児島県', 'カゴシマケン', '大島郡徳之島町', 'オオシマグントクノシマチョウ', '白井', 'シライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡幕別町忠類東宝', '01', '01643', '0891711', '北海道', 'ホッカイドウ', '中川郡幕別町', 'ナカガワグンマクベツチョウ', '忠類東宝', 'チュウルイトウホウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡徳之島町徳和瀬', '46', '46530', '8917111', '鹿児島県', 'カゴシマケン', '大島郡徳之島町', 'オオシマグントクノシマチョウ', '徳和瀬', 'トクワセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡徳之島町諸田', '46', '46530', '8917112', '鹿児島県', 'カゴシマケン', '大島郡徳之島町', 'オオシマグントクノシマチョウ', '諸田', 'ショダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡徳之島町神之嶺', '46', '46530', '8917113', '鹿児島県', 'カゴシマケン', '大島郡徳之島町', 'オオシマグントクノシマチョウ', '神之嶺', 'カミノミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡徳之島町井之川', '46', '46530', '8917114', '鹿児島県', 'カゴシマケン', '大島郡徳之島町', 'オオシマグントクノシマチョウ', '井之川', 'イノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡徳之島町下久志', '46', '46530', '8917115', '鹿児島県', 'カゴシマケン', '大島郡徳之島町', 'オオシマグントクノシマチョウ', '下久志', 'シモクシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡徳之島町旭ケ丘', '46', '46530', '8917116', '鹿児島県', 'カゴシマケン', '大島郡徳之島町', 'オオシマグントクノシマチョウ', '旭ケ丘', 'アサヒガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡幕別町忠類新生', '01', '01643', '0891714', '北海道', 'ホッカイドウ', '中川郡幕別町', 'ナカガワグンマクベツチョウ', '忠類新生', 'チュウルイシンセイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡幕別町忠類幌内', '01', '01643', '0891715', '北海道', 'ホッカイドウ', '中川郡幕別町', 'ナカガワグンマクベツチョウ', '忠類幌内', 'チュウルイホロナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡幕別町忠類元忠類', '01', '01643', '0891716', '北海道', 'ホッカイドウ', '中川郡幕別町', 'ナカガワグンマクベツチョウ', '忠類元忠類', 'チュウルイモトチュウルイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡幕別町忠類朝日', '01', '01643', '0891717', '北海道', 'ホッカイドウ', '中川郡幕別町', 'ナカガワグンマクベツチョウ', '忠類朝日', 'チュウルイアサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡幕別町忠類西当', '01', '01643', '0891721', '北海道', 'ホッカイドウ', '中川郡幕別町', 'ナカガワグンマクベツチョウ', '忠類西当', 'チュウルイニシトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡幕別町忠類明和', '01', '01643', '0891724', '北海道', 'ホッカイドウ', '中川郡幕別町', 'ナカガワグンマクベツチョウ', '忠類明和', 'チュウルイメイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡幕別町忠類中当', '01', '01643', '0891725', '北海道', 'ホッカイドウ', '中川郡幕別町', 'ナカガワグンマクベツチョウ', '忠類中当', 'チュウルイナカトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡幕別町忠類古里', '01', '01643', '0891726', '北海道', 'ホッカイドウ', '中川郡幕別町', 'ナカガワグンマクベツチョウ', '忠類古里', 'チュウルイフルサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡幕別町忠類共栄', '01', '01643', '0891727', '北海道', 'ホッカイドウ', '中川郡幕別町', 'ナカガワグンマクベツチョウ', '忠類共栄', 'チュウルイキョウエイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡幕別町忠類協徳', '01', '01643', '0891728', '北海道', 'ホッカイドウ', '中川郡幕別町', 'ナカガワグンマクベツチョウ', '忠類協徳', 'チュウルイキョウトク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡幕別町忠類日和', '01', '01643', '0891729', '北海道', 'ホッカイドウ', '中川郡幕別町', 'ナカガワグンマクベツチョウ', '忠類日和', 'チュウルイヒヨリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡幕別町忠類公親', '01', '01643', '0891731', '北海道', 'ホッカイドウ', '中川郡幕別町', 'ナカガワグンマクベツチョウ', '忠類公親', 'チュウルイコウシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡徳之島町手々', '46', '46530', '8917421', '鹿児島県', 'カゴシマケン', '大島郡徳之島町', 'オオシマグントクノシマチョウ', '手々', 'テテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡徳之島町金見', '46', '46530', '8917422', '鹿児島県', 'カゴシマケン', '大島郡徳之島町', 'オオシマグントクノシマチョウ', '金見', 'カナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡徳之島町山', '46', '46530', '8917423', '鹿児島県', 'カゴシマケン', '大島郡徳之島町', 'オオシマグントクノシマチョウ', '山', 'サン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡徳之島町轟木', '46', '46530', '8917424', '鹿児島県', 'カゴシマケン', '大島郡徳之島町', 'オオシマグントクノシマチョウ', '轟木', 'トドロキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡徳之島町花徳', '46', '46530', '8917425', '鹿児島県', 'カゴシマケン', '大島郡徳之島町', 'オオシマグントクノシマチョウ', '花徳', 'ケドク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡徳之島町母間', '46', '46530', '8917426', '鹿児島県', 'カゴシマケン', '大島郡徳之島町', 'オオシマグントクノシマチョウ', '母間', 'ボマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡天城町', '46', '46531', '8917600', '鹿児島県', 'カゴシマケン', '大島郡天城町', 'オオシマグンアマギチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('117182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡天城町与名間', '46', '46531', '8917601', '鹿児島県', 'カゴシマケン', '大島郡天城町', 'オオシマグンアマギチョウ', '与名間', 'ヨナマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡天城町松原', '46', '46531', '8917602', '鹿児島県', 'カゴシマケン', '大島郡天城町', 'オオシマグンアマギチョウ', '松原', 'マツバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡天城町岡前', '46', '46531', '8917603', '鹿児島県', 'カゴシマケン', '大島郡天城町', 'オオシマグンアマギチョウ', '岡前', 'オカゼン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡天城町前野', '46', '46531', '8917604', '鹿児島県', 'カゴシマケン', '大島郡天城町', 'オオシマグンアマギチョウ', '前野', 'マエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡天城町浅間', '46', '46531', '8917605', '鹿児島県', 'カゴシマケン', '大島郡天城町', 'オオシマグンアマギチョウ', '浅間', 'アサマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡天城町天城', '46', '46531', '8917611', '鹿児島県', 'カゴシマケン', '大島郡天城町', 'オオシマグンアマギチョウ', '天城', 'アマギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡天城町平土野', '46', '46531', '8917612', '鹿児島県', 'カゴシマケン', '大島郡天城町', 'オオシマグンアマギチョウ', '平土野', 'ヘトノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡天城町兼久', '46', '46531', '8917621', '鹿児島県', 'カゴシマケン', '大島郡天城町', 'オオシマグンアマギチョウ', '兼久', 'カネク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡天城町大津川', '46', '46531', '8917622', '鹿児島県', 'カゴシマケン', '大島郡天城町', 'オオシマグンアマギチョウ', '大津川', 'オオツカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡天城町瀬滝', '46', '46531', '8917623', '鹿児島県', 'カゴシマケン', '大島郡天城町', 'オオシマグンアマギチョウ', '瀬滝', 'セタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡天城町当部', '46', '46531', '8917624', '鹿児島県', 'カゴシマケン', '大島郡天城町', 'オオシマグンアマギチョウ', '当部', 'トウベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡天城町西阿木名', '46', '46531', '8917731', '鹿児島県', 'カゴシマケン', '大島郡天城町', 'オオシマグンアマギチョウ', '西阿木名', 'ニシアギナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡伊仙町喜念', '46', '46532', '8918111', '鹿児島県', 'カゴシマケン', '大島郡伊仙町', 'オオシマグンイセンチョウ', '喜念', 'キネン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡伊仙町佐弁', '46', '46532', '8918112', '鹿児島県', 'カゴシマケン', '大島郡伊仙町', 'オオシマグンイセンチョウ', '佐弁', 'サベン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡伊仙町目手久', '46', '46532', '8918113', '鹿児島県', 'カゴシマケン', '大島郡伊仙町', 'オオシマグンイセンチョウ', '目手久', 'メテグ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡伊仙町面縄', '46', '46532', '8918114', '鹿児島県', 'カゴシマケン', '大島郡伊仙町', 'オオシマグンイセンチョウ', '面縄', 'オモナワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡伊仙町古里', '46', '46532', '8918115', '鹿児島県', 'カゴシマケン', '大島郡伊仙町', 'オオシマグンイセンチョウ', '古里', 'フルサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡伊仙町検福', '46', '46532', '8918116', '鹿児島県', 'カゴシマケン', '大島郡伊仙町', 'オオシマグンイセンチョウ', '検福', 'ケンブク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡伊仙町中山', '46', '46532', '8918117', '鹿児島県', 'カゴシマケン', '大島郡伊仙町', 'オオシマグンイセンチョウ', '中山', 'ナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡伊仙町伊仙', '46', '46532', '8918201', '鹿児島県', 'カゴシマケン', '大島郡伊仙町', 'オオシマグンイセンチョウ', '伊仙', 'イセン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡伊仙町検福', '46', '46532', '8918216', '鹿児島県', 'カゴシマケン', '大島郡伊仙町', 'オオシマグンイセンチョウ', '検福', 'ケンブク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡伊仙町阿三', '46', '46532', '8918221', '鹿児島県', 'カゴシマケン', '大島郡伊仙町', 'オオシマグンイセンチョウ', '阿三', 'アサン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡伊仙町', '46', '46532', '8918300', '鹿児島県', 'カゴシマケン', '大島郡伊仙町', 'オオシマグンイセンチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('117207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡伊仙町阿三', '46', '46532', '8918321', '鹿児島県', 'カゴシマケン', '大島郡伊仙町', 'オオシマグンイセンチョウ', '阿三', 'アサン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡伊仙町阿権', '46', '46532', '8918322', '鹿児島県', 'カゴシマケン', '大島郡伊仙町', 'オオシマグンイセンチョウ', '阿権', 'アゴン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡伊仙町木之香', '46', '46532', '8918323', '鹿児島県', 'カゴシマケン', '大島郡伊仙町', 'オオシマグンイセンチョウ', '木之香', 'キノコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡伊仙町糸木名', '46', '46532', '8918324', '鹿児島県', 'カゴシマケン', '大島郡伊仙町', 'オオシマグンイセンチョウ', '糸木名', 'イトキナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡伊仙町八重竿', '46', '46532', '8918325', '鹿児島県', 'カゴシマケン', '大島郡伊仙町', 'オオシマグンイセンチョウ', '八重竿', 'ヤエザオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡伊仙町馬根', '46', '46532', '8918326', '鹿児島県', 'カゴシマケン', '大島郡伊仙町', 'オオシマグンイセンチョウ', '馬根', 'バネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡伊仙町犬田布', '46', '46532', '8918327', '鹿児島県', 'カゴシマケン', '大島郡伊仙町', 'オオシマグンイセンチョウ', '犬田布', 'イヌタブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡伊仙町崎原', '46', '46532', '8918328', '鹿児島県', 'カゴシマケン', '大島郡伊仙町', 'オオシマグンイセンチョウ', '崎原', 'サキバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡伊仙町小島', '46', '46532', '8918329', '鹿児島県', 'カゴシマケン', '大島郡伊仙町', 'オオシマグンイセンチョウ', '小島', 'コジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡幕別町忠類晩成', '01', '01643', '0891871', '北海道', 'ホッカイドウ', '中川郡幕別町', 'ナカガワグンマクベツチョウ', '忠類晩成', 'チュウルイバンセイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道広尾郡大樹町生花', '01', '01641', '0891881', '北海道', 'ホッカイドウ', '広尾郡大樹町', 'ヒロオグンタイキチョウ', '生花', 'セイカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道広尾郡大樹町晩成', '01', '01641', '0891882', '北海道', 'ホッカイドウ', '広尾郡大樹町', 'ヒロオグンタイキチョウ', '晩成', 'バンセイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡和泊町', '46', '46533', '8919100', '鹿児島県', 'カゴシマケン', '大島郡和泊町', 'オオシマグンワドマリチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('117220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡和泊町国頭', '46', '46533', '8919101', '鹿児島県', 'カゴシマケン', '大島郡和泊町', 'オオシマグンワドマリチョウ', '国頭', 'クニガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡和泊町喜美留', '46', '46533', '8919102', '鹿児島県', 'カゴシマケン', '大島郡和泊町', 'オオシマグンワドマリチョウ', '喜美留', 'キビル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡和泊町出花', '46', '46533', '8919103', '鹿児島県', 'カゴシマケン', '大島郡和泊町', 'オオシマグンワドマリチョウ', '出花', 'デギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡和泊町西原', '46', '46533', '8919104', '鹿児島県', 'カゴシマケン', '大島郡和泊町', 'オオシマグンワドマリチョウ', '西原', 'ニシバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡和泊町手々知名', '46', '46533', '8919111', '鹿児島県', 'カゴシマケン', '大島郡和泊町', 'オオシマグンワドマリチョウ', '手々知名', 'テデチナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡和泊町和泊', '46', '46533', '8919112', '鹿児島県', 'カゴシマケン', '大島郡和泊町', 'オオシマグンワドマリチョウ', '和泊', 'ワドマリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡和泊町和', '46', '46533', '8919113', '鹿児島県', 'カゴシマケン', '大島郡和泊町', 'オオシマグンワドマリチョウ', '和', 'ワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡和泊町畦布', '46', '46533', '8919114', '鹿児島県', 'カゴシマケン', '大島郡和泊町', 'オオシマグンワドマリチョウ', '畦布', 'アゼフ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡和泊町伊延', '46', '46533', '8919115', '鹿児島県', 'カゴシマケン', '大島郡和泊町', 'オオシマグンワドマリチョウ', '伊延', 'イノベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡和泊町上手々知名', '46', '46533', '8919116', '鹿児島県', 'カゴシマケン', '大島郡和泊町', 'オオシマグンワドマリチョウ', '上手々知名', 'ウエテテチナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡和泊町根折', '46', '46533', '8919121', '鹿児島県', 'カゴシマケン', '大島郡和泊町', 'オオシマグンワドマリチョウ', '根折', 'ネオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡和泊町玉城', '46', '46533', '8919122', '鹿児島県', 'カゴシマケン', '大島郡和泊町', 'オオシマグンワドマリチョウ', '玉城', 'タマジロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡和泊町皆川', '46', '46533', '8919123', '鹿児島県', 'カゴシマケン', '大島郡和泊町', 'オオシマグンワドマリチョウ', '皆川', 'ミナカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡和泊町古里', '46', '46533', '8919124', '鹿児島県', 'カゴシマケン', '大島郡和泊町', 'オオシマグンワドマリチョウ', '古里', 'フルサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡和泊町大城', '46', '46533', '8919125', '鹿児島県', 'カゴシマケン', '大島郡和泊町', 'オオシマグンワドマリチョウ', '大城', 'オオジロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡和泊町内城', '46', '46533', '8919131', '鹿児島県', 'カゴシマケン', '大島郡和泊町', 'オオシマグンワドマリチョウ', '内城', 'ウチジロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡和泊町後蘭', '46', '46533', '8919132', '鹿児島県', 'カゴシマケン', '大島郡和泊町', 'オオシマグンワドマリチョウ', '後蘭', 'ゴラン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡和泊町谷山', '46', '46533', '8919133', '鹿児島県', 'カゴシマケン', '大島郡和泊町', 'オオシマグンワドマリチョウ', '谷山', 'タニヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡和泊町仁志', '46', '46533', '8919134', '鹿児島県', 'カゴシマケン', '大島郡和泊町', 'オオシマグンワドマリチョウ', '仁志', 'ニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡和泊町永嶺', '46', '46533', '8919135', '鹿児島県', 'カゴシマケン', '大島郡和泊町', 'オオシマグンワドマリチョウ', '永嶺', 'ナガミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡和泊町瀬名', '46', '46533', '8919136', '鹿児島県', 'カゴシマケン', '大島郡和泊町', 'オオシマグンワドマリチョウ', '瀬名', 'セナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡知名町', '46', '46534', '8919200', '鹿児島県', 'カゴシマケン', '大島郡知名町', 'オオシマグンチナチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('117243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡知名町余多', '46', '46534', '8919201', '鹿児島県', 'カゴシマケン', '大島郡知名町', 'オオシマグンチナチョウ', '余多', 'アマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡知名町屋者', '46', '46534', '8919202', '鹿児島県', 'カゴシマケン', '大島郡知名町', 'オオシマグンチナチョウ', '屋者', 'ヤジャ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡知名町下平川', '46', '46534', '8919203', '鹿児島県', 'カゴシマケン', '大島郡知名町', 'オオシマグンチナチョウ', '下平川', 'シモヒラカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡知名町上平川', '46', '46534', '8919204', '鹿児島県', 'カゴシマケン', '大島郡知名町', 'オオシマグンチナチョウ', '上平川', 'カミヒラカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡知名町久志検', '46', '46534', '8919205', '鹿児島県', 'カゴシマケン', '大島郡知名町', 'オオシマグンチナチョウ', '久志検', 'グシケン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡知名町赤嶺', '46', '46534', '8919206', '鹿児島県', 'カゴシマケン', '大島郡知名町', 'オオシマグンチナチョウ', '赤嶺', 'アカミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡知名町竿津', '46', '46534', '8919207', '鹿児島県', 'カゴシマケン', '大島郡知名町', 'オオシマグンチナチョウ', '竿津', 'サオヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡知名町芦清良', '46', '46534', '8919211', '鹿児島県', 'カゴシマケン', '大島郡知名町', 'オオシマグンチナチョウ', '芦清良', 'アシキヨウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡知名町黒貫', '46', '46534', '8919212', '鹿児島県', 'カゴシマケン', '大島郡知名町', 'オオシマグンチナチョウ', '黒貫', 'クロヌキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡知名町瀬利覚', '46', '46534', '8919213', '鹿児島県', 'カゴシマケン', '大島郡知名町', 'オオシマグンチナチョウ', '瀬利覚', 'セリカク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡知名町知名', '46', '46534', '8919214', '鹿児島県', 'カゴシマケン', '大島郡知名町', 'オオシマグンチナチョウ', '知名', 'チナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡知名町屋子母', '46', '46534', '8919215', '鹿児島県', 'カゴシマケン', '大島郡知名町', 'オオシマグンチナチョウ', '屋子母', 'ヤコモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡知名町大津勘', '46', '46534', '8919221', '鹿児島県', 'カゴシマケン', '大島郡知名町', 'オオシマグンチナチョウ', '大津勘', 'オオツカン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡知名町徳時', '46', '46534', '8919222', '鹿児島県', 'カゴシマケン', '大島郡知名町', 'オオシマグンチナチョウ', '徳時', 'トクドキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡知名町住吉', '46', '46534', '8919223', '鹿児島県', 'カゴシマケン', '大島郡知名町', 'オオシマグンチナチョウ', '住吉', 'スミヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡知名町正名', '46', '46534', '8919224', '鹿児島県', 'カゴシマケン', '大島郡知名町', 'オオシマグンチナチョウ', '正名', 'マサナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡知名町田皆', '46', '46534', '8919231', '鹿児島県', 'カゴシマケン', '大島郡知名町', 'オオシマグンチナチョウ', '田皆', 'タミナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡知名町新城', '46', '46534', '8919232', '鹿児島県', 'カゴシマケン', '大島郡知名町', 'オオシマグンチナチョウ', '新城', 'シンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡知名町下城', '46', '46534', '8919233', '鹿児島県', 'カゴシマケン', '大島郡知名町', 'オオシマグンチナチョウ', '下城', 'シモジロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡知名町上城', '46', '46534', '8919234', '鹿児島県', 'カゴシマケン', '大島郡知名町', 'オオシマグンチナチョウ', '上城', 'カミシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡与論町', '46', '46535', '8919300', '鹿児島県', 'カゴシマケン', '大島郡与論町', 'オオシマグンヨロンチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('117269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡与論町茶花', '46', '46535', '8919301', '鹿児島県', 'カゴシマケン', '大島郡与論町', 'オオシマグンヨロンチョウ', '茶花', 'チャバナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡与論町立長', '46', '46535', '8919302', '鹿児島県', 'カゴシマケン', '大島郡与論町', 'オオシマグンヨロンチョウ', '立長', 'リッチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡与論町城', '46', '46535', '8919303', '鹿児島県', 'カゴシマケン', '大島郡与論町', 'オオシマグンヨロンチョウ', '城', 'グスク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡与論町朝戸', '46', '46535', '8919304', '鹿児島県', 'カゴシマケン', '大島郡与論町', 'オオシマグンヨロンチョウ', '朝戸', 'アサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡与論町西区', '46', '46535', '8919305', '鹿児島県', 'カゴシマケン', '大島郡与論町', 'オオシマグンヨロンチョウ', '西区', 'ニシク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡与論町東区', '46', '46535', '8919306', '鹿児島県', 'カゴシマケン', '大島郡与論町', 'オオシマグンヨロンチョウ', '東区', 'ヒガシク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡与論町古里', '46', '46535', '8919307', '鹿児島県', 'カゴシマケン', '大島郡与論町', 'オオシマグンヨロンチョウ', '古里', 'フルサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡与論町那間', '46', '46535', '8919308', '鹿児島県', 'カゴシマケン', '大島郡与論町', 'オオシマグンヨロンチョウ', '那間', 'ナマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡与論町叶', '46', '46535', '8919309', '鹿児島県', 'カゴシマケン', '大島郡与論町', 'オオシマグンヨロンチョウ', '叶', 'カノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市稲荷町', '46', '46201', '8920801', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '稲荷町', 'イナリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市清水町', '46', '46201', '8920802', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '清水町', 'シミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市祇園之洲町', '46', '46201', '8920803', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '祇園之洲町', 'ギオンノスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市春日町', '46', '46201', '8920804', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '春日町', 'カスガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市大竜町', '46', '46201', '8920805', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '大竜町', 'ダイリュウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市池之上町', '46', '46201', '8920806', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '池之上町', 'イケノウエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市皷川町', '46', '46201', '8920807', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '皷川町', 'ツヅミガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市玉里団地2丁目', '46', '46201', '8920811', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '玉里団地', 'タマザトダンチ', null, null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('117286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市玉里団地3丁目', '46', '46201', '8920811', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '玉里団地', 'タマザトダンチ', null, null, '3丁目', '03チョウメ');
INSERT INTO `ms_addresses` VALUES ('117287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市浜町', '46', '46201', '8920812', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '浜町', 'ハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市城山2丁目', '46', '46201', '8920813', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '城山', 'シロヤマ', null, null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('117289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市本港新町', '46', '46201', '8920814', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '本港新町', 'ホンコウシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市易居町', '46', '46201', '8920815', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '易居町', 'ヤスイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市山下町', '46', '46201', '8920816', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '山下町', 'ヤマシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市小川町', '46', '46201', '8920817', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '小川町', 'オガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市上本町', '46', '46201', '8920818', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '上本町', 'カミホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市柳町', '46', '46201', '8920819', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '柳町', 'ヤナギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市名山町', '46', '46201', '8920821', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '名山町', 'メイザンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市泉町', '46', '46201', '8920822', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '泉町', 'イズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市住吉町', '46', '46201', '8920823', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '住吉町', 'スミヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市堀江町', '46', '46201', '8920824', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '堀江町', 'ホリエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市大黒町', '46', '46201', '8920825', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '大黒町', 'ダイコクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市呉服町', '46', '46201', '8920826', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '呉服町', 'ゴフクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市中町', '46', '46201', '8920827', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '中町', 'ナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市金生町', '46', '46201', '8920828', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '金生町', 'キンセイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市船津町', '46', '46201', '8920831', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '船津町', 'フナツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市新町', '46', '46201', '8920832', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市松原町', '46', '46201', '8920833', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '松原町', 'マツバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市南林寺町', '46', '46201', '8920834', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '南林寺町', 'ナンリンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市城南町', '46', '46201', '8920835', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '城南町', 'ジョウナンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市錦江町', '46', '46201', '8920836', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '錦江町', 'キンコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市甲突町', '46', '46201', '8920837', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '甲突町', 'コウツキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市新屋敷町', '46', '46201', '8920838', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '新屋敷町', 'シンヤシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市照国町', '46', '46201', '8920841', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '照国町', 'テルクニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市東千石町', '46', '46201', '8920842', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '東千石町', 'ヒガシセンゴクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市千日町', '46', '46201', '8920843', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '千日町', 'センニチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市山之口町', '46', '46201', '8920844', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '山之口町', 'ヤマノクチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市樋之口町', '46', '46201', '8920845', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '樋之口町', 'テノクチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市加治屋町', '46', '46201', '8920846', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '加治屋町', 'カジヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市西千石町', '46', '46201', '8920847', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '西千石町', 'ニシセンゴクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市平之町', '46', '46201', '8920848', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '平之町', 'ヒラノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市上竜尾町', '46', '46201', '8920851', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '上竜尾町', 'カミタツオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市下竜尾町', '46', '46201', '8920852', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '下竜尾町', 'シモタツオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市城山町', '46', '46201', '8920853', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '城山町', 'シロヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市長田町', '46', '46201', '8920854', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '長田町', 'ナガタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市冷水町', '46', '46201', '8920855', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '冷水町', 'ヒヤミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市東坂元', '46', '46201', '8920861', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '東坂元', 'ヒガシサカモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市坂元町', '46', '46201', '8920862', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '坂元町', 'サカモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市西坂元町', '46', '46201', '8920863', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '西坂元町', 'ニシサカモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市吉野町', '46', '46201', '8920871', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '吉野町', 'ヨシノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市大明丘', '46', '46201', '8920872', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '大明丘', 'ダイミョウガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市下田町', '46', '46201', '8920873', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '下田町', 'シモタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市緑ケ丘町', '46', '46201', '8920874', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '緑ケ丘町', 'ミドリガオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市川上町', '46', '46201', '8920875', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '川上町', 'カワカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市岡之原町', '46', '46201', '8920876', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '岡之原町', 'オカノハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道広尾郡大樹町', '01', '01641', '0892100', '北海道', 'ホッカイドウ', '広尾郡大樹町', 'ヒロオグンタイキチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('117334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道広尾郡大樹町東和', '01', '01641', '0892101', '北海道', 'ホッカイドウ', '広尾郡大樹町', 'ヒロオグンタイキチョウ', '東和', 'トウワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道広尾郡大樹町大和', '01', '01641', '0892102', '北海道', 'ホッカイドウ', '広尾郡大樹町', 'ヒロオグンタイキチョウ', '大和', 'ヤマト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道広尾郡大樹町上大樹', '01', '01641', '0892103', '北海道', 'ホッカイドウ', '広尾郡大樹町', 'ヒロオグンタイキチョウ', '上大樹', 'カミタイキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道広尾郡大樹町中大樹', '01', '01641', '0892104', '北海道', 'ホッカイドウ', '広尾郡大樹町', 'ヒロオグンタイキチョウ', '中大樹', 'ナカタイキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道広尾郡大樹町大樹', '01', '01641', '0892105', '北海道', 'ホッカイドウ', '広尾郡大樹町', 'ヒロオグンタイキチョウ', '大樹', 'タイキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道広尾郡大樹町下大樹', '01', '01641', '0892106', '北海道', 'ホッカイドウ', '広尾郡大樹町', 'ヒロオグンタイキチョウ', '下大樹', 'シモタイキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道広尾郡大樹町松山', '01', '01641', '0892107', '北海道', 'ホッカイドウ', '広尾郡大樹町', 'ヒロオグンタイキチョウ', '松山', 'マツヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道広尾郡大樹町上萠和', '01', '01641', '0892111', '北海道', 'ホッカイドウ', '広尾郡大樹町', 'ヒロオグンタイキチョウ', '上萠和', 'カミモイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道広尾郡大樹町萠和', '01', '01641', '0892112', '北海道', 'ホッカイドウ', '広尾郡大樹町', 'ヒロオグンタイキチョウ', '萠和', 'モイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道広尾郡大樹町芽武', '01', '01641', '0892113', '北海道', 'ホッカイドウ', '広尾郡大樹町', 'ヒロオグンタイキチョウ', '芽武', 'メム', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道広尾郡大樹町下芽武', '01', '01641', '0892114', '北海道', 'ホッカイドウ', '広尾郡大樹町', 'ヒロオグンタイキチョウ', '下芽武', 'シモメム', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道広尾郡大樹町美成', '01', '01641', '0892115', '北海道', 'ホッカイドウ', '広尾郡大樹町', 'ヒロオグンタイキチョウ', '美成', 'ビセイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道広尾郡大樹町浜大樹', '01', '01641', '0892116', '北海道', 'ホッカイドウ', '広尾郡大樹町', 'ヒロオグンタイキチョウ', '浜大樹', 'ハマタイキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道広尾郡大樹町更生', '01', '01641', '0892117', '北海道', 'ホッカイドウ', '広尾郡大樹町', 'ヒロオグンタイキチョウ', '更生', 'コウセイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道広尾郡大樹町旭浜', '01', '01641', '0892121', '北海道', 'ホッカイドウ', '広尾郡大樹町', 'ヒロオグンタイキチョウ', '旭浜', 'アサヒハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道広尾郡大樹町中島', '01', '01641', '0892122', '北海道', 'ホッカイドウ', '広尾郡大樹町', 'ヒロオグンタイキチョウ', '中島', 'ナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道広尾郡大樹町上中島', '01', '01641', '0892123', '北海道', 'ホッカイドウ', '広尾郡大樹町', 'ヒロオグンタイキチョウ', '上中島', 'カミナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道広尾郡大樹町日方', '01', '01641', '0892124', '北海道', 'ホッカイドウ', '広尾郡大樹町', 'ヒロオグンタイキチョウ', '日方', 'ヒカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道広尾郡大樹町石坂', '01', '01641', '0892125', '北海道', 'ホッカイドウ', '広尾郡大樹町', 'ヒロオグンタイキチョウ', '石坂', 'イシザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道広尾郡大樹町開進', '01', '01641', '0892126', '北海道', 'ホッカイドウ', '広尾郡大樹町', 'ヒロオグンタイキチョウ', '開進', 'カイシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道広尾郡大樹町振別', '01', '01641', '0892127', '北海道', 'ホッカイドウ', '広尾郡大樹町', 'ヒロオグンタイキチョウ', '振別', 'フルベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道広尾郡大樹町松山町', '01', '01641', '0892131', '北海道', 'ホッカイドウ', '広尾郡大樹町', 'ヒロオグンタイキチョウ', '松山町', 'マツヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道広尾郡大樹町双葉町', '01', '01641', '0892132', '北海道', 'ホッカイドウ', '広尾郡大樹町', 'ヒロオグンタイキチョウ', '双葉町', 'フタバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道広尾郡大樹町仲通', '01', '01641', '0892133', '北海道', 'ホッカイドウ', '広尾郡大樹町', 'ヒロオグンタイキチョウ', '仲通', 'ナカドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道広尾郡大樹町東本通', '01', '01641', '0892134', '北海道', 'ホッカイドウ', '広尾郡大樹町', 'ヒロオグンタイキチョウ', '東本通', 'ヒガシホンドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道広尾郡大樹町南通', '01', '01641', '0892135', '北海道', 'ホッカイドウ', '広尾郡大樹町', 'ヒロオグンタイキチョウ', '南通', 'ミナミドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道広尾郡大樹町新通', '01', '01641', '0892136', '北海道', 'ホッカイドウ', '広尾郡大樹町', 'ヒロオグンタイキチョウ', '新通', 'シンドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道広尾郡大樹町北通', '01', '01641', '0892137', '北海道', 'ホッカイドウ', '広尾郡大樹町', 'ヒロオグンタイキチョウ', '北通', 'キタドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道広尾郡大樹町柏木町', '01', '01641', '0892138', '北海道', 'ホッカイドウ', '広尾郡大樹町', 'ヒロオグンタイキチョウ', '柏木町', 'カシワギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道広尾郡大樹町栄通', '01', '01641', '0892140', '北海道', 'ホッカイドウ', '広尾郡大樹町', 'ヒロオグンタイキチョウ', '栄通', 'サカエドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道広尾郡大樹町1条通', '01', '01641', '0892141', '北海道', 'ホッカイドウ', '広尾郡大樹町', 'ヒロオグンタイキチョウ', '1条通', '01ジョウドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道広尾郡大樹町2条通', '01', '01641', '0892142', '北海道', 'ホッカイドウ', '広尾郡大樹町', 'ヒロオグンタイキチョウ', '2条通', '02ジョウドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道広尾郡大樹町3条通', '01', '01641', '0892143', '北海道', 'ホッカイドウ', '広尾郡大樹町', 'ヒロオグンタイキチョウ', '3条通', '03ジョウドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道広尾郡大樹町暁町', '01', '01641', '0892145', '北海道', 'ホッカイドウ', '広尾郡大樹町', 'ヒロオグンタイキチョウ', '暁町', 'アカツキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道広尾郡大樹町寿通', '01', '01641', '0892146', '北海道', 'ホッカイドウ', '広尾郡大樹町', 'ヒロオグンタイキチョウ', '寿通', 'コトブキドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道広尾郡大樹町鏡町', '01', '01641', '0892147', '北海道', 'ホッカイドウ', '広尾郡大樹町', 'ヒロオグンタイキチョウ', '鏡町', 'カガミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道広尾郡大樹町麻友', '01', '01641', '0892148', '北海道', 'ホッカイドウ', '広尾郡大樹町', 'ヒロオグンタイキチョウ', '麻友', 'マユウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道広尾郡大樹町高校通', '01', '01641', '0892151', '北海道', 'ホッカイドウ', '広尾郡大樹町', 'ヒロオグンタイキチョウ', '高校通', 'コウコウドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道広尾郡大樹町西本通', '01', '01641', '0892152', '北海道', 'ホッカイドウ', '広尾郡大樹町', 'ヒロオグンタイキチョウ', '西本通', 'ニシホンドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道広尾郡大樹町南町', '01', '01641', '0892153', '北海道', 'ホッカイドウ', '広尾郡大樹町', 'ヒロオグンタイキチョウ', '南町', 'ミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道広尾郡大樹町幸町', '01', '01641', '0892154', '北海道', 'ホッカイドウ', '広尾郡大樹町', 'ヒロオグンタイキチョウ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道広尾郡大樹町緑町', '01', '01641', '0892155', '北海道', 'ホッカイドウ', '広尾郡大樹町', 'ヒロオグンタイキチョウ', '緑町', 'ミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道広尾郡大樹町緑苑', '01', '01641', '0892156', '北海道', 'ホッカイドウ', '広尾郡大樹町', 'ヒロオグンタイキチョウ', '緑苑', 'ロクエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道広尾郡大樹町尾田', '01', '01641', '0892261', '北海道', 'ホッカイドウ', '広尾郡大樹町', 'ヒロオグンタイキチョウ', '尾田', 'オダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道広尾郡大樹町拓北', '01', '01641', '0892261', '北海道', 'ホッカイドウ', '広尾郡大樹町', 'ヒロオグンタイキチョウ', '拓北', 'タクホク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道広尾郡大樹町豊里', '01', '01641', '0892261', '北海道', 'ホッカイドウ', '広尾郡大樹町', 'ヒロオグンタイキチョウ', '豊里', 'トヨサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道広尾郡大樹町相川', '01', '01641', '0892262', '北海道', 'ホッカイドウ', '広尾郡大樹町', 'ヒロオグンタイキチョウ', '相川', 'アイカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道広尾郡大樹町拓進', '01', '01641', '0892263', '北海道', 'ホッカイドウ', '広尾郡大樹町', 'ヒロオグンタイキチョウ', '拓進', 'タクシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道広尾郡大樹町光地園', '01', '01641', '0892271', '北海道', 'ホッカイドウ', '広尾郡大樹町', 'ヒロオグンタイキチョウ', '光地園', 'コウチエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道広尾郡大樹町幸徳', '01', '01641', '0892272', '北海道', 'ホッカイドウ', '広尾郡大樹町', 'ヒロオグンタイキチョウ', '幸徳', 'コウトク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道広尾郡大樹町住吉', '01', '01641', '0892272', '北海道', 'ホッカイドウ', '広尾郡大樹町', 'ヒロオグンタイキチョウ', '住吉', 'スミヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道広尾郡大樹町大光', '01', '01641', '0892273', '北海道', 'ホッカイドウ', '広尾郡大樹町', 'ヒロオグンタイキチョウ', '大光', 'タイコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道広尾郡大樹町大全', '01', '01641', '0892273', '北海道', 'ホッカイドウ', '広尾郡大樹町', 'ヒロオグンタイキチョウ', '大全', 'タイゼン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道広尾郡広尾町カシュウンナイ', '01', '01642', '0892445', '北海道', 'ホッカイドウ', '広尾郡広尾町', 'ヒロオグンヒロオチョウ', 'カシュウンナイ', 'カシュウンナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道広尾郡広尾町紋別', '01', '01642', '0892446', '北海道', 'ホッカイドウ', '広尾郡広尾町', 'ヒロオグンヒロオチョウ', '紋別', 'モンベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道広尾郡広尾町上豊似', '01', '01642', '0892447', '北海道', 'ホッカイドウ', '広尾郡広尾町', 'ヒロオグンヒロオチョウ', '上豊似', 'カミトヨニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道広尾郡広尾町下トヨイ', '01', '01642', '0892447', '北海道', 'ホッカイドウ', '広尾郡広尾町', 'ヒロオグンヒロオチョウ', '下トヨイ', 'シモトヨイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道広尾郡広尾町下豊似', '01', '01642', '0892447', '北海道', 'ホッカイドウ', '広尾郡広尾町', 'ヒロオグンヒロオチョウ', '下豊似', 'シモトヨニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道広尾郡広尾町トヨイベツ', '01', '01642', '0892447', '北海道', 'ホッカイドウ', '広尾郡広尾町', 'ヒロオグンヒロオチョウ', 'トヨイベツ', 'トヨイベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道広尾郡広尾町上トヨイ', '01', '01642', '0892448', '北海道', 'ホッカイドウ', '広尾郡広尾町', 'ヒロオグンヒロオチョウ', '上トヨイ', 'カミトヨイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道広尾郡広尾町豊似', '01', '01642', '0892455', '北海道', 'ホッカイドウ', '広尾郡広尾町', 'ヒロオグンヒロオチョウ', '豊似', 'トヨニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道広尾郡広尾町野塚', '01', '01642', '0892561', '北海道', 'ホッカイドウ', '広尾郡広尾町', 'ヒロオグンヒロオチョウ', '野塚', 'ノヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道広尾郡広尾町野塚西通', '01', '01642', '0892562', '北海道', 'ホッカイドウ', '広尾郡広尾町', 'ヒロオグンヒロオチョウ', '野塚西通', 'ノヅカニシドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道広尾郡広尾町野塚東通', '01', '01642', '0892563', '北海道', 'ホッカイドウ', '広尾郡広尾町', 'ヒロオグンヒロオチョウ', '野塚東通', 'ノヅカヒガシドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道広尾郡広尾町野塚本通', '01', '01642', '0892564', '北海道', 'ホッカイドウ', '広尾郡広尾町', 'ヒロオグンヒロオチョウ', '野塚本通', 'ノヅカホンドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道広尾郡広尾町', '01', '01642', '0892600', '北海道', 'ホッカイドウ', '広尾郡広尾町', 'ヒロオグンヒロオチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('117402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道広尾郡広尾町東1条', '01', '01642', '0892601', '北海道', 'ホッカイドウ', '広尾郡広尾町', 'ヒロオグンヒロオチョウ', '東1条', 'ヒガシ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道広尾郡広尾町東2条', '01', '01642', '0892602', '北海道', 'ホッカイドウ', '広尾郡広尾町', 'ヒロオグンヒロオチョウ', '東2条', 'ヒガシ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道広尾郡広尾町東3条', '01', '01642', '0892603', '北海道', 'ホッカイドウ', '広尾郡広尾町', 'ヒロオグンヒロオチョウ', '東3条', 'ヒガシ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道広尾郡広尾町会所通', '01', '01642', '0892604', '北海道', 'ホッカイドウ', '広尾郡広尾町', 'ヒロオグンヒロオチョウ', '会所通', 'カイショドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道広尾郡広尾町会所前', '01', '01642', '0892605', '北海道', 'ホッカイドウ', '広尾郡広尾町', 'ヒロオグンヒロオチョウ', '会所前', 'カイショマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道広尾郡広尾町西1条', '01', '01642', '0892611', '北海道', 'ホッカイドウ', '広尾郡広尾町', 'ヒロオグンヒロオチョウ', '西1条', 'ニシ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道広尾郡広尾町西2条', '01', '01642', '0892612', '北海道', 'ホッカイドウ', '広尾郡広尾町', 'ヒロオグンヒロオチョウ', '西2条', 'ニシ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道広尾郡広尾町西3条', '01', '01642', '0892613', '北海道', 'ホッカイドウ', '広尾郡広尾町', 'ヒロオグンヒロオチョウ', '西3条', 'ニシ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道広尾郡広尾町西4条', '01', '01642', '0892614', '北海道', 'ホッカイドウ', '広尾郡広尾町', 'ヒロオグンヒロオチョウ', '西4条', 'ニシ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道広尾郡広尾町本通', '01', '01642', '0892615', '北海道', 'ホッカイドウ', '広尾郡広尾町', 'ヒロオグンヒロオチョウ', '本通', 'ホンドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道広尾郡広尾町陣屋', '01', '01642', '0892616', '北海道', 'ホッカイドウ', '広尾郡広尾町', 'ヒロオグンヒロオチョウ', '陣屋', 'ジンヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道広尾郡広尾町公園通北', '01', '01642', '0892621', '北海道', 'ホッカイドウ', '広尾郡広尾町', 'ヒロオグンヒロオチョウ', '公園通北', 'コウエンドオリキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道広尾郡広尾町公園通南', '01', '01642', '0892622', '北海道', 'ホッカイドウ', '広尾郡広尾町', 'ヒロオグンヒロオチョウ', '公園通南', 'コウエンドオリミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道広尾郡広尾町並木通西', '01', '01642', '0892623', '北海道', 'ホッカイドウ', '広尾郡広尾町', 'ヒロオグンヒロオチョウ', '並木通西', 'ナミキドオリニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道広尾郡広尾町並木通東', '01', '01642', '0892624', '北海道', 'ホッカイドウ', '広尾郡広尾町', 'ヒロオグンヒロオチョウ', '並木通東', 'ナミキドオリヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道広尾郡広尾町錦通北', '01', '01642', '0892625', '北海道', 'ホッカイドウ', '広尾郡広尾町', 'ヒロオグンヒロオチョウ', '錦通北', 'ニシキドオリキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道広尾郡広尾町錦通南', '01', '01642', '0892626', '北海道', 'ホッカイドウ', '広尾郡広尾町', 'ヒロオグンヒロオチョウ', '錦通南', 'ニシキドオリミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道広尾郡広尾町丸山通北', '01', '01642', '0892627', '北海道', 'ホッカイドウ', '広尾郡広尾町', 'ヒロオグンヒロオチョウ', '丸山通北', 'マルヤマドオリキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道広尾郡広尾町丸山通南', '01', '01642', '0892628', '北海道', 'ホッカイドウ', '広尾郡広尾町', 'ヒロオグンヒロオチョウ', '丸山通南', 'マルヤマドオリミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道広尾郡広尾町白樺通北', '01', '01642', '0892631', '北海道', 'ホッカイドウ', '広尾郡広尾町', 'ヒロオグンヒロオチョウ', '白樺通北', 'シラカバドオリキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道広尾郡広尾町白樺通南', '01', '01642', '0892632', '北海道', 'ホッカイドウ', '広尾郡広尾町', 'ヒロオグンヒロオチョウ', '白樺通南', 'シラカバドオリミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道広尾郡広尾町美幌', '01', '01642', '0892633', '北海道', 'ホッカイドウ', '広尾郡広尾町', 'ヒロオグンヒロオチョウ', '美幌', 'ビホロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道広尾郡広尾町フンベ', '01', '01642', '0892634', '北海道', 'ホッカイドウ', '広尾郡広尾町', 'ヒロオグンヒロオチョウ', 'フンベ', 'フンベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道広尾郡広尾町紅葉通北', '01', '01642', '0892635', '北海道', 'ホッカイドウ', '広尾郡広尾町', 'ヒロオグンヒロオチョウ', '紅葉通北', 'モミジドオリキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道広尾郡広尾町紅葉通南', '01', '01642', '0892636', '北海道', 'ホッカイドウ', '広尾郡広尾町', 'ヒロオグンヒロオチョウ', '紅葉通南', 'モミジドオリミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道広尾郡広尾町茂寄', '01', '01642', '0892637', '北海道', 'ホッカイドウ', '広尾郡広尾町', 'ヒロオグンヒロオチョウ', '茂寄', 'モヨリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道広尾郡広尾町茂寄南', '01', '01642', '0892638', '北海道', 'ホッカイドウ', '広尾郡広尾町', 'ヒロオグンヒロオチョウ', '茂寄南', 'モヨリミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道広尾郡広尾町音調津', '01', '01642', '0892771', '北海道', 'ホッカイドウ', '広尾郡広尾町', 'ヒロオグンヒロオチョウ', '音調津', 'オシラベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道広尾郡広尾町音調津区画外', '01', '01642', '0892772', '北海道', 'ホッカイドウ', '広尾郡広尾町', 'ヒロオグンヒロオチョウ', '音調津区画外', 'オシラベツクカクガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道広尾郡広尾町モエケシ', '01', '01642', '0892773', '北海道', 'ホッカイドウ', '広尾郡広尾町', 'ヒロオグンヒロオチョウ', 'モエケシ', 'モエケシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道広尾郡広尾町ルベシベツ', '01', '01642', '0892774', '北海道', 'ホッカイドウ', '広尾郡広尾町', 'ヒロオグンヒロオチョウ', 'ルベシベツ', 'ルベシベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道広尾郡広尾町タニイソ', '01', '01642', '0892775', '北海道', 'ホッカイドウ', '広尾郡広尾町', 'ヒロオグンヒロオチョウ', 'タニイソ', 'タニイソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道広尾郡広尾町ビタタヌンケ', '01', '01642', '0892776', '北海道', 'ホッカイドウ', '広尾郡広尾町', 'ヒロオグンヒロオチョウ', 'ビタタヌンケ', 'ビタタヌンケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿屋市', '46', '46203', '8930000', '鹿児島県', 'カゴシマケン', '鹿屋市', 'カノヤシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('117475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿屋市古前城町', '46', '46203', '8930001', '鹿児島県', 'カゴシマケン', '鹿屋市', 'カノヤシ', '古前城町', 'コセンジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿屋市本町', '46', '46203', '8930002', '鹿児島県', 'カゴシマケン', '鹿屋市', 'カノヤシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿屋市曽田町', '46', '46203', '8930003', '鹿児島県', 'カゴシマケン', '鹿屋市', 'カノヤシ', '曽田町', 'ソダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿屋市朝日町', '46', '46203', '8930004', '鹿児島県', 'カゴシマケン', '鹿屋市', 'カノヤシ', '朝日町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿屋市共栄町', '46', '46203', '8930005', '鹿児島県', 'カゴシマケン', '鹿屋市', 'カノヤシ', '共栄町', 'キョウエイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿屋市向江町', '46', '46203', '8930006', '鹿児島県', 'カゴシマケン', '鹿屋市', 'カノヤシ', '向江町', 'ムカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿屋市北田町', '46', '46203', '8930007', '鹿児島県', 'カゴシマケン', '鹿屋市', 'カノヤシ', '北田町', 'キタダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿屋市西大手町', '46', '46203', '8930008', '鹿児島県', 'カゴシマケン', '鹿屋市', 'カノヤシ', '西大手町', 'ニシオオテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿屋市大手町', '46', '46203', '8930009', '鹿児島県', 'カゴシマケン', '鹿屋市', 'カノヤシ', '大手町', 'オオテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿屋市打馬', '46', '46203', '8930011', '鹿児島県', 'カゴシマケン', '鹿屋市', 'カノヤシ', '打馬', 'ウツマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿屋市王子町', '46', '46203', '8930012', '鹿児島県', 'カゴシマケン', '鹿屋市', 'カノヤシ', '王子町', 'オウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿屋市札元', '46', '46203', '8930013', '鹿児島県', 'カゴシマケン', '鹿屋市', 'カノヤシ', '札元', 'フダモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿屋市寿', '46', '46203', '8930014', '鹿児島県', 'カゴシマケン', '鹿屋市', 'カノヤシ', '寿', 'コトブキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿屋市新川町', '46', '46203', '8930015', '鹿児島県', 'カゴシマケン', '鹿屋市', 'カノヤシ', '新川町', 'シンカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿屋市白崎町', '46', '46203', '8930016', '鹿児島県', 'カゴシマケン', '鹿屋市', 'カノヤシ', '白崎町', 'シラサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿屋市東原町', '46', '46203', '8930021', '鹿児島県', 'カゴシマケン', '鹿屋市', 'カノヤシ', '東原町', 'ヒガシバルチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿屋市旭原町', '46', '46203', '8930022', '鹿児島県', 'カゴシマケン', '鹿屋市', 'カノヤシ', '旭原町', 'アサヒバルチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿屋市笠之原町', '46', '46203', '8930023', '鹿児島県', 'カゴシマケン', '鹿屋市', 'カノヤシ', '笠之原町', 'カサノハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿屋市下祓川町', '46', '46203', '8930024', '鹿児島県', 'カゴシマケン', '鹿屋市', 'カノヤシ', '下祓川町', 'シモハライガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿屋市西祓川町', '46', '46203', '8930025', '鹿児島県', 'カゴシマケン', '鹿屋市', 'カノヤシ', '西祓川町', 'ニシハライガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿屋市祓川町', '46', '46203', '8930026', '鹿児島県', 'カゴシマケン', '鹿屋市', 'カノヤシ', '祓川町', 'ハライガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿屋市上祓川町', '46', '46203', '8930027', '鹿児島県', 'カゴシマケン', '鹿屋市', 'カノヤシ', '上祓川町', 'カミハライガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿屋市川東町', '46', '46203', '8930031', '鹿児島県', 'カゴシマケン', '鹿屋市', 'カノヤシ', '川東町', 'カワヒガシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿屋市川西町', '46', '46203', '8930032', '鹿児島県', 'カゴシマケン', '鹿屋市', 'カノヤシ', '川西町', 'カワニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿屋市永野田町', '46', '46203', '8930033', '鹿児島県', 'カゴシマケン', '鹿屋市', 'カノヤシ', '永野田町', 'ナガノダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿屋市名貫町', '46', '46203', '8930034', '鹿児島県', 'カゴシマケン', '鹿屋市', 'カノヤシ', '名貫町', 'ナヌキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿屋市飯隈町', '46', '46203', '8930035', '鹿児島県', 'カゴシマケン', '鹿屋市', 'カノヤシ', '飯隈町', 'イイクマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿屋市萩塚町', '46', '46203', '8930036', '鹿児島県', 'カゴシマケン', '鹿屋市', 'カノヤシ', '萩塚町', 'ハギツカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿屋市田崎町', '46', '46203', '8930037', '鹿児島県', 'カゴシマケン', '鹿屋市', 'カノヤシ', '田崎町', 'タサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿屋市星塚町', '46', '46203', '8930041', '鹿児島県', 'カゴシマケン', '鹿屋市', 'カノヤシ', '星塚町', 'ホシヅカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿屋市池園町', '46', '46203', '8930042', '鹿児島県', 'カゴシマケン', '鹿屋市', 'カノヤシ', '池園町', 'イケゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿屋市南町', '46', '46203', '8930043', '鹿児島県', 'カゴシマケン', '鹿屋市', 'カノヤシ', '南町', 'ミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿屋市獅子目町', '46', '46203', '8930044', '鹿児島県', 'カゴシマケン', '鹿屋市', 'カノヤシ', '獅子目町', 'シシメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿屋市田淵町', '46', '46203', '8930045', '鹿児島県', 'カゴシマケン', '鹿屋市', 'カノヤシ', '田淵町', 'タブチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿屋市横山町', '46', '46203', '8930046', '鹿児島県', 'カゴシマケン', '鹿屋市', 'カノヤシ', '横山町', 'ヨコヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿屋市下堀町', '46', '46203', '8930047', '鹿児島県', 'カゴシマケン', '鹿屋市', 'カノヤシ', '下堀町', 'シモホリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿屋市大姶良町', '46', '46203', '8930051', '鹿児島県', 'カゴシマケン', '鹿屋市', 'カノヤシ', '大姶良町', 'オオアイラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿屋市永小原町', '46', '46203', '8930052', '鹿児島県', 'カゴシマケン', '鹿屋市', 'カノヤシ', '永小原町', 'ナガオバルチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿屋市浜田町', '46', '46203', '8930053', '鹿児島県', 'カゴシマケン', '鹿屋市', 'カノヤシ', '浜田町', 'ハマダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿屋市高須町', '46', '46203', '8930054', '鹿児島県', 'カゴシマケン', '鹿屋市', 'カノヤシ', '高須町', 'タカスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿屋市野里町', '46', '46203', '8930055', '鹿児島県', 'カゴシマケン', '鹿屋市', 'カノヤシ', '野里町', 'ノザトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿屋市上野町', '46', '46203', '8930056', '鹿児島県', 'カゴシマケン', '鹿屋市', 'カノヤシ', '上野町', 'ウエノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿屋市今坂町', '46', '46203', '8930057', '鹿児島県', 'カゴシマケン', '鹿屋市', 'カノヤシ', '今坂町', 'イマサカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿屋市上谷町', '46', '46203', '8930061', '鹿児島県', 'カゴシマケン', '鹿屋市', 'カノヤシ', '上谷町', 'カミダニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿屋市新生町', '46', '46203', '8930062', '鹿児島県', 'カゴシマケン', '鹿屋市', 'カノヤシ', '新生町', 'シンセイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿屋市新栄町', '46', '46203', '8930063', '鹿児島県', 'カゴシマケン', '鹿屋市', 'カノヤシ', '新栄町', 'シンエイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿屋市西原', '46', '46203', '8930064', '鹿児島県', 'カゴシマケン', '鹿屋市', 'カノヤシ', '西原', 'ニシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿屋市郷之原町', '46', '46203', '8930065', '鹿児島県', 'カゴシマケン', '鹿屋市', 'カノヤシ', '郷之原町', 'ゴウノハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿屋市高牧町', '46', '46203', '8930066', '鹿児島県', 'カゴシマケン', '鹿屋市', 'カノヤシ', '高牧町', 'タカマキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿屋市大浦町', '46', '46203', '8930067', '鹿児島県', 'カゴシマケン', '鹿屋市', 'カノヤシ', '大浦町', 'オオウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿屋市上高隈町', '46', '46203', '8930131', '鹿児島県', 'カゴシマケン', '鹿屋市', 'カノヤシ', '上高隈町', 'カミタカクマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿屋市下高隈町', '46', '46203', '8930132', '鹿児島県', 'カゴシマケン', '鹿屋市', 'カノヤシ', '下高隈町', 'シモタカクマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿屋市輝北町上百引', '46', '46203', '8930201', '鹿児島県', 'カゴシマケン', '鹿屋市', 'カノヤシ', '輝北町上百引', 'キホクチョウカミモビキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿屋市輝北町下百引', '46', '46203', '8930202', '鹿児島県', 'カゴシマケン', '鹿屋市', 'カノヤシ', '輝北町下百引', 'キホクチョウシモモビキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿屋市輝北町平房', '46', '46203', '8930203', '鹿児島県', 'カゴシマケン', '鹿屋市', 'カノヤシ', '輝北町平房', 'キホクチョウヒラボウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿屋市吾平町上名', '46', '46203', '8931101', '鹿児島県', 'カゴシマケン', '鹿屋市', 'カノヤシ', '吾平町上名', 'アイラチョウカミミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿屋市吾平町下名', '46', '46203', '8931102', '鹿児島県', 'カゴシマケン', '鹿屋市', 'カノヤシ', '吾平町下名', 'アイラチョウシモミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿屋市吾平町麓', '46', '46203', '8931103', '鹿児島県', 'カゴシマケン', '鹿屋市', 'カノヤシ', '吾平町麓', 'アイラチョウフモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県肝属郡肝付町', '46', '46492', '8931200', '鹿児島県', 'カゴシマケン', '肝属郡肝付町', 'キモツキグンキモツキチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('117537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県肝属郡肝付町野崎', '46', '46492', '8931201', '鹿児島県', 'カゴシマケン', '肝属郡肝付町', 'キモツキグンキモツキチョウ', '野崎', 'ノサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県肝属郡肝付町波見', '46', '46492', '8931202', '鹿児島県', 'カゴシマケン', '肝属郡肝付町', 'キモツキグンキモツキチョウ', '波見', 'ハミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県肝属郡肝付町後田', '46', '46492', '8931203', '鹿児島県', 'カゴシマケン', '肝属郡肝付町', 'キモツキグンキモツキチョウ', '後田', 'ウシロダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県肝属郡肝付町富山', '46', '46492', '8931204', '鹿児島県', 'カゴシマケン', '肝属郡肝付町', 'キモツキグンキモツキチョウ', '富山', 'トミヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県肝属郡肝付町宮下', '46', '46492', '8931205', '鹿児島県', 'カゴシマケン', '肝属郡肝付町', 'キモツキグンキモツキチョウ', '宮下', 'ミヤゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県肝属郡肝付町前田', '46', '46492', '8931206', '鹿児島県', 'カゴシマケン', '肝属郡肝付町', 'キモツキグンキモツキチョウ', '前田', 'マエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県肝属郡肝付町新富', '46', '46492', '8931207', '鹿児島県', 'カゴシマケン', '肝属郡肝付町', 'キモツキグンキモツキチョウ', '新富', 'ニイトミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県肝属郡肝付町北方', '46', '46492', '8931401', '鹿児島県', 'カゴシマケン', '肝属郡肝付町', 'キモツキグンキモツキチョウ', '北方', 'キタカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県肝属郡肝付町南方', '46', '46492', '8931402', '鹿児島県', 'カゴシマケン', '肝属郡肝付町', 'キモツキグンキモツキチョウ', '南方', 'ミナミカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡池田町大森', '01', '01644', '0893151', '北海道', 'ホッカイドウ', '中川郡池田町', 'ナカガワグンイケダチョウ', '大森', 'オオモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県肝属郡肝付町岸良', '46', '46492', '8931511', '鹿児島県', 'カゴシマケン', '肝属郡肝付町', 'キモツキグンキモツキチョウ', '岸良', 'キシラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡池田町高島', '01', '01644', '0893152', '北海道', 'ホッカイドウ', '中川郡池田町', 'ナカガワグンイケダチョウ', '高島', 'タカシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡池田町近牛', '01', '01644', '0893153', '北海道', 'ホッカイドウ', '中川郡池田町', 'ナカガワグンイケダチョウ', '近牛', 'チカウシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡池田町信取', '01', '01644', '0893154', '北海道', 'ホッカイドウ', '中川郡池田町', 'ナカガワグンイケダチョウ', '信取', 'ノブトリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡池田町美加登', '01', '01644', '0893155', '北海道', 'ホッカイドウ', '中川郡池田町', 'ナカガワグンイケダチョウ', '美加登', 'ミカド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡池田町常盤', '01', '01644', '0893156', '北海道', 'ホッカイドウ', '中川郡池田町', 'ナカガワグンイケダチョウ', '常盤', 'トキワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県肝属郡東串良町', '46', '46482', '8931600', '鹿児島県', 'カゴシマケン', '肝属郡東串良町', 'キモツキグンヒガシクシラチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('117555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿屋市串良町細山田', '46', '46203', '8931601', '鹿児島県', 'カゴシマケン', '鹿屋市', 'カノヤシ', '串良町細山田', 'クシラチョウホソヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿屋市串良町有里', '46', '46203', '8931602', '鹿児島県', 'カゴシマケン', '鹿屋市', 'カノヤシ', '串良町有里', 'クシラチョウアリサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿屋市串良町岡崎', '46', '46203', '8931603', '鹿児島県', 'カゴシマケン', '鹿屋市', 'カノヤシ', '串良町岡崎', 'クシラチョウオカサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿屋市串良町下小原', '46', '46203', '8931604', '鹿児島県', 'カゴシマケン', '鹿屋市', 'カノヤシ', '串良町下小原', 'クシラチョウシモオバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿屋市串良町上小原', '46', '46203', '8931605', '鹿児島県', 'カゴシマケン', '鹿屋市', 'カノヤシ', '串良町上小原', 'クシラチョウカミオバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県肝属郡東串良町岩弘', '46', '46482', '8931611', '鹿児島県', 'カゴシマケン', '肝属郡東串良町', 'キモツキグンヒガシクシラチョウ', '岩弘', 'イワヒロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県肝属郡東串良町池之原', '46', '46482', '8931612', '鹿児島県', 'カゴシマケン', '肝属郡東串良町', 'キモツキグンヒガシクシラチョウ', '池之原', 'イケノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県肝属郡東串良町川西', '46', '46482', '8931613', '鹿児島県', 'カゴシマケン', '肝属郡東串良町', 'キモツキグンヒガシクシラチョウ', '川西', 'カワニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県肝属郡東串良町新川西', '46', '46482', '8931614', '鹿児島県', 'カゴシマケン', '肝属郡東串良町', 'キモツキグンヒガシクシラチョウ', '新川西', 'シンカワニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県肝属郡東串良町川東', '46', '46482', '8931615', '鹿児島県', 'カゴシマケン', '肝属郡東串良町', 'キモツキグンヒガシクシラチョウ', '川東', 'カワヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県肝属郡錦江町', '46', '46490', '8932300', '鹿児島県', 'カゴシマケン', '肝属郡錦江町', 'キモツキグンキンコウチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('117568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県肝属郡錦江町神川', '46', '46490', '8932301', '鹿児島県', 'カゴシマケン', '肝属郡錦江町', 'キモツキグンキンコウチョウ', '神川', 'カミカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県肝属郡錦江町城元', '46', '46490', '8932302', '鹿児島県', 'カゴシマケン', '肝属郡錦江町', 'キモツキグンキンコウチョウ', '城元', 'シロモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県肝属郡錦江町馬場', '46', '46490', '8932303', '鹿児島県', 'カゴシマケン', '肝属郡錦江町', 'キモツキグンキンコウチョウ', '馬場', 'ババ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県肝属郡錦江町田代麓', '46', '46490', '8932401', '鹿児島県', 'カゴシマケン', '肝属郡錦江町', 'キモツキグンキンコウチョウ', '田代麓', 'タシロフモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県肝属郡錦江町田代川原', '46', '46490', '8932402', '鹿児島県', 'カゴシマケン', '肝属郡錦江町', 'キモツキグンキンコウチョウ', '田代川原', 'タシロカワハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県肝属郡南大隅町', '46', '46491', '8932500', '鹿児島県', 'カゴシマケン', '肝属郡南大隅町', 'キモツキグンミナミオオスミチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('117576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県肝属郡南大隅町根占川北', '46', '46491', '8932501', '鹿児島県', 'カゴシマケン', '肝属郡南大隅町', 'キモツキグンミナミオオスミチョウ', '根占川北', 'ネジメカワキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県肝属郡南大隅町根占川南', '46', '46491', '8932502', '鹿児島県', 'カゴシマケン', '肝属郡南大隅町', 'キモツキグンミナミオオスミチョウ', '根占川南', 'ネジメカワミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県肝属郡南大隅町根占横別府', '46', '46491', '8932503', '鹿児島県', 'カゴシマケン', '肝属郡南大隅町', 'キモツキグンミナミオオスミチョウ', '根占横別府', 'ネジメヨコベップ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県肝属郡南大隅町根占山本', '46', '46491', '8932504', '鹿児島県', 'カゴシマケン', '肝属郡南大隅町', 'キモツキグンミナミオオスミチョウ', '根占山本', 'ネジメヤマモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県肝属郡南大隅町根占辺田', '46', '46491', '8932505', '鹿児島県', 'カゴシマケン', '肝属郡南大隅町', 'キモツキグンミナミオオスミチョウ', '根占辺田', 'ネジメヘタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県肝属郡南大隅町佐多伊座敷', '46', '46491', '8932601', '鹿児島県', 'カゴシマケン', '肝属郡南大隅町', 'キモツキグンミナミオオスミチョウ', '佐多伊座敷', 'サタイザシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県肝属郡南大隅町佐多辺塚', '46', '46491', '8932602', '鹿児島県', 'カゴシマケン', '肝属郡南大隅町', 'キモツキグンミナミオオスミチョウ', '佐多辺塚', 'サタヘツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県肝属郡南大隅町佐多郡', '46', '46491', '8932603', '鹿児島県', 'カゴシマケン', '肝属郡南大隅町', 'キモツキグンミナミオオスミチョウ', '佐多郡', 'サタコオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県肝属郡南大隅町佐多馬籠', '46', '46491', '8932604', '鹿児島県', 'カゴシマケン', '肝属郡南大隅町', 'キモツキグンミナミオオスミチョウ', '佐多馬籠', 'サタマゴメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡本別町勇足元町', '01', '01646', '0893281', '北海道', 'ホッカイドウ', '中川郡本別町', 'ナカガワグンホンベツチョウ', '勇足元町', 'ユウタリモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡本別町勇足', '01', '01646', '0893282', '北海道', 'ホッカイドウ', '中川郡本別町', 'ナカガワグンホンベツチョウ', '勇足', 'ユウタリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡本別町押帯', '01', '01646', '0893283', '北海道', 'ホッカイドウ', '中川郡本別町', 'ナカガワグンホンベツチョウ', '押帯', 'オショツプ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡本別町美蘭別', '01', '01646', '0893284', '北海道', 'ホッカイドウ', '中川郡本別町', 'ナカガワグンホンベツチョウ', '美蘭別', 'ビランベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡本別町', '01', '01646', '0893300', '北海道', 'ホッカイドウ', '中川郡本別町', 'ナカガワグンホンベツチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('117590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡本別町東本別', '01', '01646', '0893301', '北海道', 'ホッカイドウ', '中川郡本別町', 'ナカガワグンホンベツチョウ', '東本別', 'ヒガシホンベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡本別町東町', '01', '01646', '0893302', '北海道', 'ホッカイドウ', '中川郡本別町', 'ナカガワグンホンベツチョウ', '東町', 'ヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡本別町向陽町', '01', '01646', '0893303', '北海道', 'ホッカイドウ', '中川郡本別町', 'ナカガワグンホンベツチョウ', '向陽町', 'コウヨウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡本別町坂下町', '01', '01646', '0893304', '北海道', 'ホッカイドウ', '中川郡本別町', 'ナカガワグンホンベツチョウ', '坂下町', 'サカシタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡本別町共栄', '01', '01646', '0893305', '北海道', 'ホッカイドウ', '中川郡本別町', 'ナカガワグンホンベツチョウ', '共栄', 'キョウエイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡本別町チエトイ', '01', '01646', '0893306', '北海道', 'ホッカイドウ', '中川郡本別町', 'ナカガワグンホンベツチョウ', 'チエトイ', 'チエトイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡本別町負箙', '01', '01646', '0893307', '北海道', 'ホッカイドウ', '中川郡本別町', 'ナカガワグンホンベツチョウ', '負箙', 'オフイビラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡本別町弥生町', '01', '01646', '0893308', '北海道', 'ホッカイドウ', '中川郡本別町', 'ナカガワグンホンベツチョウ', '弥生町', 'ヤヨイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡本別町柏木町', '01', '01646', '0893311', '北海道', 'ホッカイドウ', '中川郡本別町', 'ナカガワグンホンベツチョウ', '柏木町', 'カシワギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡本別町緑町', '01', '01646', '0893312', '北海道', 'ホッカイドウ', '中川郡本別町', 'ナカガワグンホンベツチョウ', '緑町', 'ミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡本別町柳町', '01', '01646', '0893313', '北海道', 'ホッカイドウ', '中川郡本別町', 'ナカガワグンホンベツチョウ', '柳町', 'ヤナギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡本別町南', '01', '01646', '0893314', '北海道', 'ホッカイドウ', '中川郡本別町', 'ナカガワグンホンベツチョウ', '南', 'ミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡本別町上本別フラツナイ', '01', '01646', '0893321', '北海道', 'ホッカイドウ', '中川郡本別町', 'ナカガワグンホンベツチョウ', '上本別', 'カミホンベツ', null, null, 'フラツナイ', 'フラツナイ');
INSERT INTO `ms_addresses` VALUES ('117603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡本別町栄町', '01', '01646', '0893322', '北海道', 'ホッカイドウ', '中川郡本別町', 'ナカガワグンホンベツチョウ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡本別町美里別東下', '01', '01646', '0893323', '北海道', 'ホッカイドウ', '中川郡本別町', 'ナカガワグンホンベツチョウ', '美里別', 'ビリベツ', null, null, '東下', 'ヒガシシモ');
INSERT INTO `ms_addresses` VALUES ('117605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡本別町新町', '01', '01646', '0893324', '北海道', 'ホッカイドウ', '中川郡本別町', 'ナカガワグンホンベツチョウ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡本別町西美里別', '01', '01646', '0893325', '北海道', 'ホッカイドウ', '中川郡本別町', 'ナカガワグンホンベツチョウ', '西美里別', 'ニシビリベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡本別町美里別高東', '01', '01646', '0893326', '北海道', 'ホッカイドウ', '中川郡本別町', 'ナカガワグンホンベツチョウ', '美里別', 'ビリベツ', null, null, '高東', 'コウトウ');
INSERT INTO `ms_addresses` VALUES ('117608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡本別町追名牛', '01', '01646', '0893327', '北海道', 'ホッカイドウ', '中川郡本別町', 'ナカガワグンホンベツチョウ', '追名牛', 'オイナウシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡本別町錦町', '01', '01646', '0893331', '北海道', 'ホッカイドウ', '中川郡本別町', 'ナカガワグンホンベツチョウ', '錦町', 'ニシキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡本別町朝日町', '01', '01646', '0893332', '北海道', 'ホッカイドウ', '中川郡本別町', 'ナカガワグンホンベツチョウ', '朝日町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡本別町山手町', '01', '01646', '0893333', '北海道', 'ホッカイドウ', '中川郡本別町', 'ナカガワグンホンベツチョウ', '山手町', 'ヤマテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡本別町北', '01', '01646', '0893334', '北海道', 'ホッカイドウ', '中川郡本別町', 'ナカガワグンホンベツチョウ', '北', 'キタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡本別町清流町', '01', '01646', '0893334', '北海道', 'ホッカイドウ', '中川郡本別町', 'ナカガワグンホンベツチョウ', '清流町', 'セイリュウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡本別町美里別拓農', '01', '01646', '0893442', '北海道', 'ホッカイドウ', '中川郡本別町', 'ナカガワグンホンベツチョウ', '美里別', 'ビリベツ', null, null, '拓農', 'タクノウ');
INSERT INTO `ms_addresses` VALUES ('117616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡本別町美里別東活込', '01', '01646', '0893442', '北海道', 'ホッカイドウ', '中川郡本別町', 'ナカガワグンホンベツチョウ', '美里別', 'ビリベツ', null, null, '東活込', 'ヒガシカッコミ');
INSERT INTO `ms_addresses` VALUES ('117617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡本別町美里別東上', '01', '01646', '0893442', '北海道', 'ホッカイドウ', '中川郡本別町', 'ナカガワグンホンベツチョウ', '美里別', 'ビリベツ', null, null, '東上', 'ヒガシカミ');
INSERT INTO `ms_addresses` VALUES ('117618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡本別町美里別東中', '01', '01646', '0893442', '北海道', 'ホッカイドウ', '中川郡本別町', 'ナカガワグンホンベツチョウ', '美里別', 'ビリベツ', null, null, '東中', 'ヒガシナカ');
INSERT INTO `ms_addresses` VALUES ('117619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡本別町西美里別', '01', '01646', '0893443', '北海道', 'ホッカイドウ', '中川郡本別町', 'ナカガワグンホンベツチョウ', '西美里別', 'ニシビリベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡本別町西美里別西活込', '01', '01646', '0893443', '北海道', 'ホッカイドウ', '中川郡本別町', 'ナカガワグンホンベツチョウ', '西美里別', 'ニシビリベツ', null, null, '西活込', 'ニシカッコミ');
INSERT INTO `ms_addresses` VALUES ('117621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡本別町西美里別西上', '01', '01646', '0893443', '北海道', 'ホッカイドウ', '中川郡本別町', 'ナカガワグンホンベツチョウ', '西美里別', 'ニシビリベツ', null, null, '西上', 'ニシカミ');
INSERT INTO `ms_addresses` VALUES ('117622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡本別町西美里別西中', '01', '01646', '0893443', '北海道', 'ホッカイドウ', '中川郡本別町', 'ナカガワグンホンベツチョウ', '西美里別', 'ニシビリベツ', null, null, '西中', 'ニシナカ');
INSERT INTO `ms_addresses` VALUES ('117623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道十勝郡浦幌町恩根内', '01', '01649', '0893571', '北海道', 'ホッカイドウ', '十勝郡浦幌町', 'トカチグンウラホロチョウ', '恩根内', 'オンネナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道十勝郡浦幌町川流布', '01', '01649', '0893572', '北海道', 'ホッカイドウ', '十勝郡浦幌町', 'トカチグンウラホロチョウ', '川流布', 'カワリュウフ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道十勝郡浦幌町富川', '01', '01649', '0893573', '北海道', 'ホッカイドウ', '十勝郡浦幌町', 'トカチグンウラホロチョウ', '富川', 'トミカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道十勝郡浦幌町活平', '01', '01649', '0893574', '北海道', 'ホッカイドウ', '十勝郡浦幌町', 'トカチグンウラホロチョウ', '活平', 'カツヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道十勝郡浦幌町美園', '01', '01649', '0893575', '北海道', 'ホッカイドウ', '十勝郡浦幌町', 'トカチグンウラホロチョウ', '美園', 'ミソノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道十勝郡浦幌町相川', '01', '01649', '0893576', '北海道', 'ホッカイドウ', '十勝郡浦幌町', 'トカチグンウラホロチョウ', '相川', 'アイカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道十勝郡浦幌町合流', '01', '01649', '0893577', '北海道', 'ホッカイドウ', '十勝郡浦幌町', 'トカチグンウラホロチョウ', '合流', 'ゴウリュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道十勝郡浦幌町宝生', '01', '01649', '0893578', '北海道', 'ホッカイドウ', '十勝郡浦幌町', 'トカチグンウラホロチョウ', '宝生', 'ホウセイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道十勝郡浦幌町川上', '01', '01649', '0893585', '北海道', 'ホッカイドウ', '十勝郡浦幌町', 'トカチグンウラホロチョウ', '川上', 'カワカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道十勝郡浦幌町栄穂', '01', '01649', '0893586', '北海道', 'ホッカイドウ', '十勝郡浦幌町', 'トカチグンウラホロチョウ', '栄穂', 'エイホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道十勝郡浦幌町貴老路', '01', '01649', '0893587', '北海道', 'ホッカイドウ', '十勝郡浦幌町', 'トカチグンウラホロチョウ', '貴老路', 'キロロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡本別町美栄', '01', '01646', '0893661', '北海道', 'ホッカイドウ', '中川郡本別町', 'ナカガワグンホンベツチョウ', '美栄', 'ビエイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡本別町奥仙美里', '01', '01646', '0893662', '北海道', 'ホッカイドウ', '中川郡本別町', 'ナカガワグンホンベツチョウ', '奥仙美里', 'オクセンビリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡本別町仙美里', '01', '01646', '0893663', '北海道', 'ホッカイドウ', '中川郡本別町', 'ナカガワグンホンベツチョウ', '仙美里', 'センビリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡本別町仙美里元町', '01', '01646', '0893664', '北海道', 'ホッカイドウ', '中川郡本別町', 'ナカガワグンホンベツチョウ', '仙美里元町', 'センビリモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡本別町清里', '01', '01646', '0893665', '北海道', 'ホッカイドウ', '中川郡本別町', 'ナカガワグンホンベツチョウ', '清里', 'キヨサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡本別町上仙美里', '01', '01646', '0893666', '北海道', 'ホッカイドウ', '中川郡本別町', 'ナカガワグンホンベツチョウ', '上仙美里', 'カミセンビリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡本別町木札内', '01', '01646', '0893671', '北海道', 'ホッカイドウ', '中川郡本別町', 'ナカガワグンホンベツチョウ', '木札内', 'ボクサツナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡本別町追名牛', '01', '01646', '0893672', '北海道', 'ホッカイドウ', '中川郡本別町', 'ナカガワグンホンベツチョウ', '追名牛', 'オイナウシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡本別町東仙美里', '01', '01646', '0893673', '北海道', 'ホッカイドウ', '中川郡本別町', 'ナカガワグンホンベツチョウ', '東仙美里', 'ヒガシセンビリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡本別町下仙美里', '01', '01646', '0893674', '北海道', 'ホッカイドウ', '中川郡本別町', 'ナカガワグンホンベツチョウ', '下仙美里', 'シモセンビリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡本別町西仙美里', '01', '01646', '0893675', '北海道', 'ホッカイドウ', '中川郡本別町', 'ナカガワグンホンベツチョウ', '西仙美里', 'ニシセンビリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡本別町明美', '01', '01646', '0893676', '北海道', 'ホッカイドウ', '中川郡本別町', 'ナカガワグンホンベツチョウ', '明美', 'アケミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡本別町美里別', '01', '01646', '0893677', '北海道', 'ホッカイドウ', '中川郡本別町', 'ナカガワグンホンベツチョウ', '美里別', 'ビリベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道足寄郡足寄町', '01', '01647', '0893700', '北海道', 'ホッカイドウ', '足寄郡足寄町', 'アショログンアショロチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('117648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道足寄郡足寄町北1条', '01', '01647', '0893701', '北海道', 'ホッカイドウ', '足寄郡足寄町', 'アショログンアショロチョウ', '北1条', 'キタ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道足寄郡足寄町北2条', '01', '01647', '0893702', '北海道', 'ホッカイドウ', '足寄郡足寄町', 'アショログンアショロチョウ', '北2条', 'キタ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道足寄郡足寄町北3条', '01', '01647', '0893703', '北海道', 'ホッカイドウ', '足寄郡足寄町', 'アショログンアショロチョウ', '北3条', 'キタ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道足寄郡足寄町北4条', '01', '01647', '0893704', '北海道', 'ホッカイドウ', '足寄郡足寄町', 'アショログンアショロチョウ', '北4条', 'キタ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道足寄郡足寄町北5条', '01', '01647', '0893705', '北海道', 'ホッカイドウ', '足寄郡足寄町', 'アショログンアショロチョウ', '北5条', 'キタ05ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道足寄郡足寄町北6条', '01', '01647', '0893706', '北海道', 'ホッカイドウ', '足寄郡足寄町', 'アショログンアショロチョウ', '北6条', 'キタ06ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道足寄郡足寄町下愛冠', '01', '01647', '0893707', '北海道', 'ホッカイドウ', '足寄郡足寄町', 'アショログンアショロチョウ', '下愛冠', 'シモアイカップ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道足寄郡足寄町愛冠', '01', '01647', '0893708', '北海道', 'ホッカイドウ', '足寄郡足寄町', 'アショログンアショロチョウ', '愛冠', 'アイカップ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道足寄郡足寄町南1条', '01', '01647', '0893711', '北海道', 'ホッカイドウ', '足寄郡足寄町', 'アショログンアショロチョウ', '南1条', 'ミナミ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道足寄郡足寄町南2条', '01', '01647', '0893712', '北海道', 'ホッカイドウ', '足寄郡足寄町', 'アショログンアショロチョウ', '南2条', 'ミナミ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道足寄郡足寄町南3条', '01', '01647', '0893713', '北海道', 'ホッカイドウ', '足寄郡足寄町', 'アショログンアショロチョウ', '南3条', 'ミナミ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道足寄郡足寄町南4条', '01', '01647', '0893714', '北海道', 'ホッカイドウ', '足寄郡足寄町', 'アショログンアショロチョウ', '南4条', 'ミナミ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道足寄郡足寄町南5条', '01', '01647', '0893715', '北海道', 'ホッカイドウ', '足寄郡足寄町', 'アショログンアショロチョウ', '南5条', 'ミナミ05ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道足寄郡足寄町南6条', '01', '01647', '0893716', '北海道', 'ホッカイドウ', '足寄郡足寄町', 'アショログンアショロチョウ', '南6条', 'ミナミ06ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道足寄郡足寄町南7条', '01', '01647', '0893717', '北海道', 'ホッカイドウ', '足寄郡足寄町', 'アショログンアショロチョウ', '南7条', 'ミナミ07ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道足寄郡足寄町栄町', '01', '01647', '0893718', '北海道', 'ホッカイドウ', '足寄郡足寄町', 'アショログンアショロチョウ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道足寄郡足寄町旭町', '01', '01647', '0893721', '北海道', 'ホッカイドウ', '足寄郡足寄町', 'アショログンアショロチョウ', '旭町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道足寄郡足寄町新町', '01', '01647', '0893722', '北海道', 'ホッカイドウ', '足寄郡足寄町', 'アショログンアショロチョウ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道足寄郡足寄町中足寄', '01', '01647', '0893723', '北海道', 'ホッカイドウ', '足寄郡足寄町', 'アショログンアショロチョウ', '中足寄', 'ナカアショロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道足寄郡足寄町稲牛', '01', '01647', '0893724', '北海道', 'ホッカイドウ', '足寄郡足寄町', 'アショログンアショロチョウ', '稲牛', 'イナウシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道足寄郡足寄町平和', '01', '01647', '0893725', '北海道', 'ホッカイドウ', '足寄郡足寄町', 'アショログンアショロチョウ', '平和', 'ヘイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道足寄郡足寄町共栄町', '01', '01647', '0893726', '北海道', 'ホッカイドウ', '足寄郡足寄町', 'アショログンアショロチョウ', '共栄町', 'キョウエイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道足寄郡足寄町郊南', '01', '01647', '0893727', '北海道', 'ホッカイドウ', '足寄郡足寄町', 'アショログンアショロチョウ', '郊南', 'コウナン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道足寄郡足寄町中矢', '01', '01647', '0893731', '北海道', 'ホッカイドウ', '足寄郡足寄町', 'アショログンアショロチョウ', '中矢', 'ナカヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道足寄郡足寄町里見が丘', '01', '01647', '0893732', '北海道', 'ホッカイドウ', '足寄郡足寄町', 'アショログンアショロチョウ', '里見が丘', 'サトミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道足寄郡足寄町西町', '01', '01647', '0893733', '北海道', 'ホッカイドウ', '足寄郡足寄町', 'アショログンアショロチョウ', '西町', 'ニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道足寄郡足寄町常盤', '01', '01647', '0893734', '北海道', 'ホッカイドウ', '足寄郡足寄町', 'アショログンアショロチョウ', '常盤', 'トキワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道足寄郡足寄町美盛', '01', '01647', '0893735', '北海道', 'ホッカイドウ', '足寄郡足寄町', 'アショログンアショロチョウ', '美盛', 'ビセイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道足寄郡足寄町鷲府', '01', '01647', '0893736', '北海道', 'ホッカイドウ', '足寄郡足寄町', 'アショログンアショロチョウ', '鷲府', 'ワシップ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道足寄郡足寄町茂喜登牛', '01', '01647', '0893737', '北海道', 'ホッカイドウ', '足寄郡足寄町', 'アショログンアショロチョウ', '茂喜登牛', 'モキトウシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道足寄郡足寄町芽登本町', '01', '01647', '0893871', '北海道', 'ホッカイドウ', '足寄郡足寄町', 'アショログンアショロチョウ', '芽登本町', 'メトウモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道足寄郡足寄町芽登', '01', '01647', '0893872', '北海道', 'ホッカイドウ', '足寄郡足寄町', 'アショログンアショロチョウ', '芽登', 'メトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道足寄郡足寄町中矢', '01', '01647', '0893873', '北海道', 'ホッカイドウ', '足寄郡足寄町', 'アショログンアショロチョウ', '中矢', 'ナカヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道足寄郡足寄町喜登牛', '01', '01647', '0893874', '北海道', 'ホッカイドウ', '足寄郡足寄町', 'アショログンアショロチョウ', '喜登牛', 'キトウシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道足寄郡足寄町茂喜登牛', '01', '01647', '0893875', '北海道', 'ホッカイドウ', '足寄郡足寄町', 'アショログンアショロチョウ', '茂喜登牛', 'モキトウシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道足寄郡足寄町上足寄', '01', '01647', '0893961', '北海道', 'ホッカイドウ', '足寄郡足寄町', 'アショログンアショロチョウ', '上足寄', 'カミアショロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道足寄郡足寄町上足寄本町', '01', '01647', '0893962', '北海道', 'ホッカイドウ', '足寄郡足寄町', 'アショログンアショロチョウ', '上足寄本町', 'カミアショロモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道足寄郡足寄町上螺湾', '01', '01647', '0893963', '北海道', 'ホッカイドウ', '足寄郡足寄町', 'アショログンアショロチョウ', '上螺湾', 'カミラワン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道足寄郡足寄町茂足寄', '01', '01647', '0893964', '北海道', 'ホッカイドウ', '足寄郡足寄町', 'アショログンアショロチョウ', '茂足寄', 'モアショロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道足寄郡足寄町螺湾', '01', '01647', '0893965', '北海道', 'ホッカイドウ', '足寄郡足寄町', 'アショログンアショロチョウ', '螺湾', 'ラワン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道足寄郡足寄町螺湾本町', '01', '01647', '0893966', '北海道', 'ホッカイドウ', '足寄郡足寄町', 'アショログンアショロチョウ', '螺湾本町', 'ラワンモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県奄美市', '46', '46222', '8940000', '鹿児島県', 'カゴシマケン', '奄美市', 'アマミシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('117695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県奄美市名瀬大熊', '46', '46222', '8940001', '鹿児島県', 'カゴシマケン', '奄美市', 'アマミシ', '名瀬大熊', 'ナゼダイクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県奄美市名瀬有屋', '46', '46222', '8940002', '鹿児島県', 'カゴシマケン', '奄美市', 'アマミシ', '名瀬有屋', 'ナゼアリヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県奄美市名瀬仲勝', '46', '46222', '8940003', '鹿児島県', 'カゴシマケン', '奄美市', 'アマミシ', '名瀬仲勝', 'ナゼナカガチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県奄美市名瀬鳩浜町', '46', '46222', '8940004', '鹿児島県', 'カゴシマケン', '奄美市', 'アマミシ', '名瀬鳩浜町', 'ナゼハトハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県奄美市名瀬佐大熊町', '46', '46222', '8940005', '鹿児島県', 'カゴシマケン', '奄美市', 'アマミシ', '名瀬佐大熊町', 'ナゼサダイクマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県奄美市名瀬小浜町', '46', '46222', '8940006', '鹿児島県', 'カゴシマケン', '奄美市', 'アマミシ', '名瀬小浜町', 'ナゼコハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県奄美市名瀬和光町', '46', '46222', '8940007', '鹿児島県', 'カゴシマケン', '奄美市', 'アマミシ', '名瀬和光町', 'ナゼワコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県奄美市名瀬浦上', '46', '46222', '8940008', '鹿児島県', 'カゴシマケン', '奄美市', 'アマミシ', '名瀬浦上', 'ナゼウラガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県奄美市名瀬安勝町', '46', '46222', '8940011', '鹿児島県', 'カゴシマケン', '奄美市', 'アマミシ', '名瀬安勝町', 'ナゼアンガチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県奄美市名瀬小俣町', '46', '46222', '8940012', '鹿児島県', 'カゴシマケン', '奄美市', 'アマミシ', '名瀬小俣町', 'ナゼコマタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県奄美市名瀬春日町', '46', '46222', '8940013', '鹿児島県', 'カゴシマケン', '奄美市', 'アマミシ', '名瀬春日町', 'ナゼカスガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県奄美市名瀬平田町', '46', '46222', '8940014', '鹿児島県', 'カゴシマケン', '奄美市', 'アマミシ', '名瀬平田町', 'ナゼヒラタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県奄美市名瀬真名津町', '46', '46222', '8940015', '鹿児島県', 'カゴシマケン', '奄美市', 'アマミシ', '名瀬真名津町', 'ナゼマナヅチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県奄美市名瀬古田町', '46', '46222', '8940016', '鹿児島県', 'カゴシマケン', '奄美市', 'アマミシ', '名瀬古田町', 'ナゼフルタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県奄美市名瀬石橋町', '46', '46222', '8940017', '鹿児島県', 'カゴシマケン', '奄美市', 'アマミシ', '名瀬石橋町', 'ナゼイシバシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県奄美市名瀬伊津部町', '46', '46222', '8940021', '鹿児島県', 'カゴシマケン', '奄美市', 'アマミシ', '名瀬伊津部町', 'ナゼイツブチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県奄美市名瀬久里町', '46', '46222', '8940022', '鹿児島県', 'カゴシマケン', '奄美市', 'アマミシ', '名瀬久里町', 'ナゼクサトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県奄美市名瀬永田町', '46', '46222', '8940023', '鹿児島県', 'カゴシマケン', '奄美市', 'アマミシ', '名瀬永田町', 'ナゼナガタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県奄美市名瀬井根町', '46', '46222', '8940024', '鹿児島県', 'カゴシマケン', '奄美市', 'アマミシ', '名瀬井根町', 'ナゼイネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県奄美市名瀬幸町', '46', '46222', '8940025', '鹿児島県', 'カゴシマケン', '奄美市', 'アマミシ', '名瀬幸町', 'ナゼサイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県奄美市名瀬港町', '46', '46222', '8940026', '鹿児島県', 'カゴシマケン', '奄美市', 'アマミシ', '名瀬港町', 'ナゼミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県奄美市名瀬末広町', '46', '46222', '8940027', '鹿児島県', 'カゴシマケン', '奄美市', 'アマミシ', '名瀬末広町', 'ナゼスエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県奄美市名瀬金久町', '46', '46222', '8940031', '鹿児島県', 'カゴシマケン', '奄美市', 'アマミシ', '名瀬金久町', 'ナゼカネクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県奄美市名瀬柳町', '46', '46222', '8940032', '鹿児島県', 'カゴシマケン', '奄美市', 'アマミシ', '名瀬柳町', 'ナゼヤナギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県奄美市名瀬矢之脇町', '46', '46222', '8940033', '鹿児島県', 'カゴシマケン', '奄美市', 'アマミシ', '名瀬矢之脇町', 'ナゼヤノワキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県奄美市名瀬入舟町', '46', '46222', '8940034', '鹿児島県', 'カゴシマケン', '奄美市', 'アマミシ', '名瀬入舟町', 'ナゼイリフネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県奄美市名瀬塩浜町', '46', '46222', '8940035', '鹿児島県', 'カゴシマケン', '奄美市', 'アマミシ', '名瀬塩浜町', 'ナゼシオハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県奄美市名瀬長浜町', '46', '46222', '8940036', '鹿児島県', 'カゴシマケン', '奄美市', 'アマミシ', '名瀬長浜町', 'ナゼナガハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県奄美市名瀬朝仁新町', '46', '46222', '8940041', '鹿児島県', 'カゴシマケン', '奄美市', 'アマミシ', '名瀬朝仁新町', 'ナゼアサニシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県奄美市名瀬朝仁町', '46', '46222', '8940042', '鹿児島県', 'カゴシマケン', '奄美市', 'アマミシ', '名瀬朝仁町', 'ナゼアサニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県奄美市名瀬朝仁', '46', '46222', '8940043', '鹿児島県', 'カゴシマケン', '奄美市', 'アマミシ', '名瀬朝仁', 'ナゼアサニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県奄美市名瀬浜里町', '46', '46222', '8940044', '鹿児島県', 'カゴシマケン', '奄美市', 'アマミシ', '名瀬浜里町', 'ナゼハマサトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県奄美市名瀬平松町', '46', '46222', '8940045', '鹿児島県', 'カゴシマケン', '奄美市', 'アマミシ', '名瀬平松町', 'ナゼヒラマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県奄美市名瀬小宿', '46', '46222', '8940046', '鹿児島県', 'カゴシマケン', '奄美市', 'アマミシ', '名瀬小宿', 'ナゼコシュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県奄美市名瀬知名瀬', '46', '46222', '8940047', '鹿児島県', 'カゴシマケン', '奄美市', 'アマミシ', '名瀬知名瀬', 'ナゼチナセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県奄美市名瀬根瀬部', '46', '46222', '8940048', '鹿児島県', 'カゴシマケン', '奄美市', 'アマミシ', '名瀬根瀬部', 'ナゼネセブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県奄美市名瀬朝日町', '46', '46222', '8940061', '鹿児島県', 'カゴシマケン', '奄美市', 'アマミシ', '名瀬朝日町', 'ナゼアサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県奄美市名瀬有屋町', '46', '46222', '8940062', '鹿児島県', 'カゴシマケン', '奄美市', 'アマミシ', '名瀬有屋町', 'ナゼアリヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県奄美市名瀬仲勝町', '46', '46222', '8940063', '鹿児島県', 'カゴシマケン', '奄美市', 'アマミシ', '名瀬仲勝町', 'ナゼナカガチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県奄美市名瀬浦上町', '46', '46222', '8940068', '鹿児島県', 'カゴシマケン', '奄美市', 'アマミシ', '名瀬浦上町', 'ナゼウラガミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡龍郷町', '46', '46527', '8940100', '鹿児島県', 'カゴシマケン', '大島郡龍郷町', 'オオシマグンタツゴウチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('117736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡龍郷町屋入', '46', '46527', '8940101', '鹿児島県', 'カゴシマケン', '大島郡龍郷町', 'オオシマグンタツゴウチョウ', '屋入', 'ヤニュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡龍郷町瀬留', '46', '46527', '8940102', '鹿児島県', 'カゴシマケン', '大島郡龍郷町', 'オオシマグンタツゴウチョウ', '瀬留', 'セドメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡龍郷町玉里', '46', '46527', '8940103', '鹿児島県', 'カゴシマケン', '大島郡龍郷町', 'オオシマグンタツゴウチョウ', '玉里', 'タマザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡龍郷町浦', '46', '46527', '8940104', '鹿児島県', 'カゴシマケン', '大島郡龍郷町', 'オオシマグンタツゴウチョウ', '浦', 'ウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡龍郷町大勝', '46', '46527', '8940105', '鹿児島県', 'カゴシマケン', '大島郡龍郷町', 'オオシマグンタツゴウチョウ', '大勝', 'オオガチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡龍郷町中勝', '46', '46527', '8940106', '鹿児島県', 'カゴシマケン', '大島郡龍郷町', 'オオシマグンタツゴウチョウ', '中勝', 'ナカガチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡龍郷町戸口', '46', '46527', '8940107', '鹿児島県', 'カゴシマケン', '大島郡龍郷町', 'オオシマグンタツゴウチョウ', '戸口', 'トグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県奄美市名瀬浦上小又', '46', '46222', '8940108', '鹿児島県', 'カゴシマケン', '奄美市', 'アマミシ', '名瀬浦上', 'ナゼウラガミ', null, null, '小又', 'コマタ');
INSERT INTO `ms_addresses` VALUES ('117745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡龍郷町龍郷', '46', '46527', '8940321', '鹿児島県', 'カゴシマケン', '大島郡龍郷町', 'オオシマグンタツゴウチョウ', '龍郷', 'タツゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡龍郷町久場', '46', '46527', '8940322', '鹿児島県', 'カゴシマケン', '大島郡龍郷町', 'オオシマグンタツゴウチョウ', '久場', 'クバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡龍郷町安木屋場', '46', '46527', '8940323', '鹿児島県', 'カゴシマケン', '大島郡龍郷町', 'オオシマグンタツゴウチョウ', '安木屋場', 'アンキヤバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡龍郷町円', '46', '46527', '8940324', '鹿児島県', 'カゴシマケン', '大島郡龍郷町', 'オオシマグンタツゴウチョウ', '円', 'エン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡龍郷町嘉渡', '46', '46527', '8940331', '鹿児島県', 'カゴシマケン', '大島郡龍郷町', 'オオシマグンタツゴウチョウ', '嘉渡', 'カド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡龍郷町幾里', '46', '46527', '8940332', '鹿児島県', 'カゴシマケン', '大島郡龍郷町', 'オオシマグンタツゴウチョウ', '幾里', 'イクサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡龍郷町秋名', '46', '46527', '8940333', '鹿児島県', 'カゴシマケン', '大島郡龍郷町', 'オオシマグンタツゴウチョウ', '秋名', 'アキナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県奄美市名瀬芦花部', '46', '46222', '8940351', '鹿児島県', 'カゴシマケン', '奄美市', 'アマミシ', '名瀬芦花部', 'ナゼアシケブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県奄美市名瀬有良', '46', '46222', '8940352', '鹿児島県', 'カゴシマケン', '奄美市', 'アマミシ', '名瀬有良', 'ナゼアリラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡龍郷町赤尾木', '46', '46527', '8940411', '鹿児島県', 'カゴシマケン', '大島郡龍郷町', 'オオシマグンタツゴウチョウ', '赤尾木', 'アカオギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡龍郷町芦徳', '46', '46527', '8940412', '鹿児島県', 'カゴシマケン', '大島郡龍郷町', 'オオシマグンタツゴウチョウ', '芦徳', 'アシトク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県奄美市笠利町宇宿', '46', '46222', '8940501', '鹿児島県', 'カゴシマケン', '奄美市', 'アマミシ', '笠利町宇宿', 'カサリチョウウシュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県奄美市笠利町万屋', '46', '46222', '8940502', '鹿児島県', 'カゴシマケン', '奄美市', 'アマミシ', '笠利町万屋', 'カサリチョウマンヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県奄美市笠利町和野', '46', '46222', '8940503', '鹿児島県', 'カゴシマケン', '奄美市', 'アマミシ', '笠利町和野', 'カサリチョウワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県奄美市笠利町節田', '46', '46222', '8940504', '鹿児島県', 'カゴシマケン', '奄美市', 'アマミシ', '笠利町節田', 'カサリチョウセツタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県奄美市笠利町平', '46', '46222', '8940505', '鹿児島県', 'カゴシマケン', '奄美市', 'アマミシ', '笠利町平', 'カサリチョウタイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県奄美市笠利町手花部', '46', '46222', '8940506', '鹿児島県', 'カゴシマケン', '奄美市', 'アマミシ', '笠利町手花部', 'カサリチョウテケブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県奄美市笠利町喜瀬', '46', '46222', '8940507', '鹿児島県', 'カゴシマケン', '奄美市', 'アマミシ', '笠利町喜瀬', 'カサリチョウキセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県奄美市笠利町用安', '46', '46222', '8940508', '鹿児島県', 'カゴシマケン', '奄美市', 'アマミシ', '笠利町用安', 'カサリチョウヨウアン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県奄美市笠利町里', '46', '46222', '8940511', '鹿児島県', 'カゴシマケン', '奄美市', 'アマミシ', '笠利町里', 'カサリチョウサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県奄美市笠利町中金久', '46', '46222', '8940512', '鹿児島県', 'カゴシマケン', '奄美市', 'アマミシ', '笠利町中金久', 'カサリチョウナカガネク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県奄美市笠利町外金久', '46', '46222', '8940513', '鹿児島県', 'カゴシマケン', '奄美市', 'アマミシ', '笠利町外金久', 'カサリチョウソトガネク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県奄美市笠利町用', '46', '46222', '8940621', '鹿児島県', 'カゴシマケン', '奄美市', 'アマミシ', '笠利町用', 'カサリチョウヨウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県奄美市笠利町笠利', '46', '46222', '8940622', '鹿児島県', 'カゴシマケン', '奄美市', 'アマミシ', '笠利町笠利', 'カサリチョウカサリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県奄美市笠利町辺留', '46', '46222', '8940623', '鹿児島県', 'カゴシマケン', '奄美市', 'アマミシ', '笠利町辺留', 'カサリチョウベル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県奄美市笠利町須野', '46', '46222', '8940624', '鹿児島県', 'カゴシマケン', '奄美市', 'アマミシ', '笠利町須野', 'カサリチョウスノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県奄美市笠利町川上', '46', '46222', '8940625', '鹿児島県', 'カゴシマケン', '奄美市', 'アマミシ', '笠利町川上', 'カサリチョウカワカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県奄美市笠利町屋仁', '46', '46222', '8940626', '鹿児島県', 'カゴシマケン', '奄美市', 'アマミシ', '笠利町屋仁', 'カサリチョウヤニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県奄美市笠利町佐仁', '46', '46222', '8940627', '鹿児島県', 'カゴシマケン', '奄美市', 'アマミシ', '笠利町佐仁', 'カサリチョウサニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県奄美市名瀬小湊', '46', '46222', '8940771', '鹿児島県', 'カゴシマケン', '奄美市', 'アマミシ', '名瀬小湊', 'ナゼコミナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県奄美市名瀬西仲勝', '46', '46222', '8940772', '鹿児島県', 'カゴシマケン', '奄美市', 'アマミシ', '名瀬西仲勝', 'ナゼニシナカガチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県奄美市名瀬朝戸', '46', '46222', '8940773', '鹿児島県', 'カゴシマケン', '奄美市', 'アマミシ', '名瀬朝戸', 'ナゼアサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県奄美市名瀬伊津部勝', '46', '46222', '8940774', '鹿児島県', 'カゴシマケン', '奄美市', 'アマミシ', '名瀬伊津部勝', 'ナゼイツブガチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県奄美市名瀬名瀬勝', '46', '46222', '8940775', '鹿児島県', 'カゴシマケン', '奄美市', 'アマミシ', '名瀬名瀬勝', 'ナゼナゼガチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県奄美市名瀬崎原', '46', '46222', '8940776', '鹿児島県', 'カゴシマケン', '奄美市', 'アマミシ', '名瀬崎原', 'ナゼサキバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県奄美市住用町城', '46', '46222', '8941111', '鹿児島県', 'カゴシマケン', '奄美市', 'アマミシ', '住用町城', 'スミヨウチョウグスク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県奄美市住用町和瀬', '46', '46222', '8941112', '鹿児島県', 'カゴシマケン', '奄美市', 'アマミシ', '住用町和瀬', 'スミヨウチョウワセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県奄美市住用町見里', '46', '46222', '8941113', '鹿児島県', 'カゴシマケン', '奄美市', 'アマミシ', '住用町見里', 'スミヨウチョウミザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県奄美市住用町東仲間', '46', '46222', '8941114', '鹿児島県', 'カゴシマケン', '奄美市', 'アマミシ', '住用町東仲間', 'スミヨウチョウヒガシナカマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県奄美市住用町川内', '46', '46222', '8941115', '鹿児島県', 'カゴシマケン', '奄美市', 'アマミシ', '住用町川内', 'スミヨウチョウカワウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県奄美市住用町摺勝', '46', '46222', '8941116', '鹿児島県', 'カゴシマケン', '奄美市', 'アマミシ', '住用町摺勝', 'スミヨウチョウスリガチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県奄美市住用町石原', '46', '46222', '8941201', '鹿児島県', 'カゴシマケン', '奄美市', 'アマミシ', '住用町石原', 'スミヨウチョウイシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県奄美市住用町西仲間', '46', '46222', '8941202', '鹿児島県', 'カゴシマケン', '奄美市', 'アマミシ', '住用町西仲間', 'スミヨウチョウニシナカマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県奄美市住用町神屋', '46', '46222', '8941203', '鹿児島県', 'カゴシマケン', '奄美市', 'アマミシ', '住用町神屋', 'スミヨウチョウカミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県奄美市住用町山間', '46', '46222', '8941204', '鹿児島県', 'カゴシマケン', '奄美市', 'アマミシ', '住用町山間', 'スミヨウチョウヤンマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県奄美市住用町役勝', '46', '46222', '8941205', '鹿児島県', 'カゴシマケン', '奄美市', 'アマミシ', '住用町役勝', 'スミヨウチョウヤクガチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県奄美市住用町山間', '46', '46222', '8941304', '鹿児島県', 'カゴシマケン', '奄美市', 'アマミシ', '住用町山間', 'スミヨウチョウヤンマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県奄美市住用町山間戸玉', '46', '46222', '8941304', '鹿児島県', 'カゴシマケン', '奄美市', 'アマミシ', '住用町山間', 'スミヨウチョウヤンマ', null, null, '戸玉', 'トダマ');
INSERT INTO `ms_addresses` VALUES ('117795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県奄美市住用町市', '46', '46222', '8941321', '鹿児島県', 'カゴシマケン', '奄美市', 'アマミシ', '住用町市', 'スミヨウチョウイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道足寄郡足寄町上利別本町', '01', '01647', '0894141', '北海道', 'ホッカイドウ', '足寄郡足寄町', 'アショログンアショロチョウ', '上利別本町', 'カミトシベツモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道足寄郡足寄町上利別', '01', '01647', '0894142', '北海道', 'ホッカイドウ', '足寄郡足寄町', 'アショログンアショロチョウ', '上利別', 'カミトシベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道足寄郡足寄町白糸', '01', '01647', '0894143', '北海道', 'ホッカイドウ', '足寄郡足寄町', 'アショログンアショロチョウ', '白糸', 'シライト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道足寄郡足寄町大誉地', '01', '01647', '0894144', '北海道', 'ホッカイドウ', '足寄郡足寄町', 'アショログンアショロチョウ', '大誉地', 'オヨチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡瀬戸内町', '46', '46525', '8941500', '鹿児島県', 'カゴシマケン', '大島郡瀬戸内町', 'オオシマグンセトウチチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('117801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡瀬戸内町古仁屋高丘', '46', '46525', '8941501', '鹿児島県', 'カゴシマケン', '大島郡瀬戸内町', 'オオシマグンセトウチチョウ', '古仁屋', 'コニヤ', null, null, '高丘', 'タカオカ');
INSERT INTO `ms_addresses` VALUES ('117802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡瀬戸内町古仁屋宮前', '46', '46525', '8941502', '鹿児島県', 'カゴシマケン', '大島郡瀬戸内町', 'オオシマグンセトウチチョウ', '古仁屋', 'コニヤ', null, null, '宮前', 'ミヤマエ');
INSERT INTO `ms_addresses` VALUES ('117803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡瀬戸内町古仁屋大湊', '46', '46525', '8941503', '鹿児島県', 'カゴシマケン', '大島郡瀬戸内町', 'オオシマグンセトウチチョウ', '古仁屋', 'コニヤ', null, null, '大湊', 'オオミナト');
INSERT INTO `ms_addresses` VALUES ('117804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡瀬戸内町古仁屋春日', '46', '46525', '8941504', '鹿児島県', 'カゴシマケン', '大島郡瀬戸内町', 'オオシマグンセトウチチョウ', '古仁屋', 'コニヤ', null, null, '春日', 'カスガ');
INSERT INTO `ms_addresses` VALUES ('117805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡瀬戸内町古仁屋松江', '46', '46525', '8941505', '鹿児島県', 'カゴシマケン', '大島郡瀬戸内町', 'オオシマグンセトウチチョウ', '古仁屋', 'コニヤ', null, null, '松江', 'マツエ');
INSERT INTO `ms_addresses` VALUES ('117806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡瀬戸内町古仁屋船津', '46', '46525', '8941506', '鹿児島県', 'カゴシマケン', '大島郡瀬戸内町', 'オオシマグンセトウチチョウ', '古仁屋', 'コニヤ', null, null, '船津', 'フナツ');
INSERT INTO `ms_addresses` VALUES ('117807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡瀬戸内町古仁屋瀬久井', '46', '46525', '8941507', '鹿児島県', 'カゴシマケン', '大島郡瀬戸内町', 'オオシマグンセトウチチョウ', '古仁屋', 'コニヤ', null, null, '瀬久井', 'セクイ');
INSERT INTO `ms_addresses` VALUES ('117808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡瀬戸内町古仁屋', '46', '46525', '8941508', '鹿児島県', 'カゴシマケン', '大島郡瀬戸内町', 'オオシマグンセトウチチョウ', '古仁屋', 'コニヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡瀬戸内町古仁屋瀬久井東', '46', '46525', '8941509', '鹿児島県', 'カゴシマケン', '大島郡瀬戸内町', 'オオシマグンセトウチチョウ', '古仁屋瀬久井東', 'コニヤセクイヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡瀬戸内町古仁屋瀬久井西', '46', '46525', '8941510', '鹿児島県', 'カゴシマケン', '大島郡瀬戸内町', 'オオシマグンセトウチチョウ', '古仁屋瀬久井西', 'コニヤセクイニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡瀬戸内町阿木名', '46', '46525', '8941511', '鹿児島県', 'カゴシマケン', '大島郡瀬戸内町', 'オオシマグンセトウチチョウ', '阿木名', 'アギナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡瀬戸内町勝浦', '46', '46525', '8941512', '鹿児島県', 'カゴシマケン', '大島郡瀬戸内町', 'オオシマグンセトウチチョウ', '勝浦', 'カチウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡瀬戸内町網野子', '46', '46525', '8941513', '鹿児島県', 'カゴシマケン', '大島郡瀬戸内町', 'オオシマグンセトウチチョウ', '網野子', 'アミノコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡瀬戸内町節子', '46', '46525', '8941514', '鹿児島県', 'カゴシマケン', '大島郡瀬戸内町', 'オオシマグンセトウチチョウ', '節子', 'セツコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡瀬戸内町嘉徳', '46', '46525', '8941515', '鹿児島県', 'カゴシマケン', '大島郡瀬戸内町', 'オオシマグンセトウチチョウ', '嘉徳', 'カトク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡瀬戸内町清水', '46', '46525', '8941521', '鹿児島県', 'カゴシマケン', '大島郡瀬戸内町', 'オオシマグンセトウチチョウ', '清水', 'セイスイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡瀬戸内町嘉鉄', '46', '46525', '8941522', '鹿児島県', 'カゴシマケン', '大島郡瀬戸内町', 'オオシマグンセトウチチョウ', '嘉鉄', 'カテツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡瀬戸内町蘇刈', '46', '46525', '8941523', '鹿児島県', 'カゴシマケン', '大島郡瀬戸内町', 'オオシマグンセトウチチョウ', '蘇刈', 'ソカル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡瀬戸内町伊須', '46', '46525', '8941524', '鹿児島県', 'カゴシマケン', '大島郡瀬戸内町', 'オオシマグンセトウチチョウ', '伊須', 'イス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡瀬戸内町手安', '46', '46525', '8941531', '鹿児島県', 'カゴシマケン', '大島郡瀬戸内町', 'オオシマグンセトウチチョウ', '手安', 'テアン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡瀬戸内町篠川', '46', '46525', '8941741', '鹿児島県', 'カゴシマケン', '大島郡瀬戸内町', 'オオシマグンセトウチチョウ', '篠川', 'シノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡瀬戸内町阿室釜', '46', '46525', '8941742', '鹿児島県', 'カゴシマケン', '大島郡瀬戸内町', 'オオシマグンセトウチチョウ', '阿室釜', 'アムロガマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡瀬戸内町小名瀬', '46', '46525', '8941743', '鹿児島県', 'カゴシマケン', '大島郡瀬戸内町', 'オオシマグンセトウチチョウ', '小名瀬', 'コナセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡瀬戸内町阿鉄', '46', '46525', '8941744', '鹿児島県', 'カゴシマケン', '大島郡瀬戸内町', 'オオシマグンセトウチチョウ', '阿鉄', 'アテツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡瀬戸内町油井', '46', '46525', '8941745', '鹿児島県', 'カゴシマケン', '大島郡瀬戸内町', 'オオシマグンセトウチチョウ', '油井', 'ユイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡瀬戸内町久根津', '46', '46525', '8941746', '鹿児島県', 'カゴシマケン', '大島郡瀬戸内町', 'オオシマグンセトウチチョウ', '久根津', 'クネツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡瀬戸内町久慈', '46', '46525', '8941851', '鹿児島県', 'カゴシマケン', '大島郡瀬戸内町', 'オオシマグンセトウチチョウ', '久慈', 'クジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡瀬戸内町古志', '46', '46525', '8941852', '鹿児島県', 'カゴシマケン', '大島郡瀬戸内町', 'オオシマグンセトウチチョウ', '古志', 'コシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡瀬戸内町花天', '46', '46525', '8941853', '鹿児島県', 'カゴシマケン', '大島郡瀬戸内町', 'オオシマグンセトウチチョウ', '花天', 'ケテン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡瀬戸内町管鈍', '46', '46525', '8941854', '鹿児島県', 'カゴシマケン', '大島郡瀬戸内町', 'オオシマグンセトウチチョウ', '管鈍', 'クダドン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡瀬戸内町西古見', '46', '46525', '8941855', '鹿児島県', 'カゴシマケン', '大島郡瀬戸内町', 'オオシマグンセトウチチョウ', '西古見', 'ニシコミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡瀬戸内町諸鈍', '46', '46525', '8942141', '鹿児島県', 'カゴシマケン', '大島郡瀬戸内町', 'オオシマグンセトウチチョウ', '諸鈍', 'ショドン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡瀬戸内町生間', '46', '46525', '8942142', '鹿児島県', 'カゴシマケン', '大島郡瀬戸内町', 'オオシマグンセトウチチョウ', '生間', 'イケンマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡瀬戸内町渡連', '46', '46525', '8942143', '鹿児島県', 'カゴシマケン', '大島郡瀬戸内町', 'オオシマグンセトウチチョウ', '渡連', 'ドレン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡瀬戸内町諸数', '46', '46525', '8942144', '鹿児島県', 'カゴシマケン', '大島郡瀬戸内町', 'オオシマグンセトウチチョウ', '諸数', 'ショカズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡瀬戸内町押角', '46', '46525', '8942231', '鹿児島県', 'カゴシマケン', '大島郡瀬戸内町', 'オオシマグンセトウチチョウ', '押角', 'オシカク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡瀬戸内町勝能', '46', '46525', '8942232', '鹿児島県', 'カゴシマケン', '大島郡瀬戸内町', 'オオシマグンセトウチチョウ', '勝能', 'カチユキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡瀬戸内町野見山', '46', '46525', '8942233', '鹿児島県', 'カゴシマケン', '大島郡瀬戸内町', 'オオシマグンセトウチチョウ', '野見山', 'ノミヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡瀬戸内町秋徳', '46', '46525', '8942234', '鹿児島県', 'カゴシマケン', '大島郡瀬戸内町', 'オオシマグンセトウチチョウ', '秋徳', 'アキトク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡瀬戸内町於斉', '46', '46525', '8942235', '鹿児島県', 'カゴシマケン', '大島郡瀬戸内町', 'オオシマグンセトウチチョウ', '於斉', 'オサイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡瀬戸内町伊子茂', '46', '46525', '8942236', '鹿児島県', 'カゴシマケン', '大島郡瀬戸内町', 'オオシマグンセトウチチョウ', '伊子茂', 'イコモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡瀬戸内町花富', '46', '46525', '8942237', '鹿児島県', 'カゴシマケン', '大島郡瀬戸内町', 'オオシマグンセトウチチョウ', '花富', 'ケドミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡瀬戸内町西阿室', '46', '46525', '8942321', '鹿児島県', 'カゴシマケン', '大島郡瀬戸内町', 'オオシマグンセトウチチョウ', '西阿室', 'ニシアムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡瀬戸内町瀬相', '46', '46525', '8942322', '鹿児島県', 'カゴシマケン', '大島郡瀬戸内町', 'オオシマグンセトウチチョウ', '瀬相', 'セソウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡瀬戸内町俵', '46', '46525', '8942323', '鹿児島県', 'カゴシマケン', '大島郡瀬戸内町', 'オオシマグンセトウチチョウ', '俵', 'ヒョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡瀬戸内町瀬武', '46', '46525', '8942401', '鹿児島県', 'カゴシマケン', '大島郡瀬戸内町', 'オオシマグンセトウチチョウ', '瀬武', 'セタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡瀬戸内町薩川', '46', '46525', '8942402', '鹿児島県', 'カゴシマケン', '大島郡瀬戸内町', 'オオシマグンセトウチチョウ', '薩川', 'サツカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡瀬戸内町実久', '46', '46525', '8942403', '鹿児島県', 'カゴシマケン', '大島郡瀬戸内町', 'オオシマグンセトウチチョウ', '実久', 'サネク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡瀬戸内町芝', '46', '46525', '8942404', '鹿児島県', 'カゴシマケン', '大島郡瀬戸内町', 'オオシマグンセトウチチョウ', '芝', 'シバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡瀬戸内町阿多地', '46', '46525', '8942411', '鹿児島県', 'カゴシマケン', '大島郡瀬戸内町', 'オオシマグンセトウチチョウ', '阿多地', 'アダチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡瀬戸内町須子茂', '46', '46525', '8942412', '鹿児島県', 'カゴシマケン', '大島郡瀬戸内町', 'オオシマグンセトウチチョウ', '須子茂', 'スコモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡瀬戸内町嘉入', '46', '46525', '8942413', '鹿児島県', 'カゴシマケン', '大島郡瀬戸内町', 'オオシマグンセトウチチョウ', '嘉入', 'カニュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡瀬戸内町三浦', '46', '46525', '8942414', '鹿児島県', 'カゴシマケン', '大島郡瀬戸内町', 'オオシマグンセトウチチョウ', '三浦', 'ミウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡瀬戸内町知之浦', '46', '46525', '8942415', '鹿児島県', 'カゴシマケン', '大島郡瀬戸内町', 'オオシマグンセトウチチョウ', '知之浦', 'チノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡瀬戸内町武名', '46', '46525', '8942416', '鹿児島県', 'カゴシマケン', '大島郡瀬戸内町', 'オオシマグンセトウチチョウ', '武名', 'タケナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡瀬戸内町木慈', '46', '46525', '8942417', '鹿児島県', 'カゴシマケン', '大島郡瀬戸内町', 'オオシマグンセトウチチョウ', '木慈', 'キジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡瀬戸内町池地', '46', '46525', '8942501', '鹿児島県', 'カゴシマケン', '大島郡瀬戸内町', 'オオシマグンセトウチチョウ', '池地', 'イケジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡瀬戸内町請阿室', '46', '46525', '8942502', '鹿児島県', 'カゴシマケン', '大島郡瀬戸内町', 'オオシマグンセトウチチョウ', '請阿室', 'ウケアムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道足寄郡足寄町大誉地', '01', '01647', '0894251', '北海道', 'ホッカイドウ', '足寄郡足寄町', 'アショログンアショロチョウ', '大誉地', 'オヨチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道足寄郡足寄町大誉地本町', '01', '01647', '0894252', '北海道', 'ホッカイドウ', '足寄郡足寄町', 'アショログンアショロチョウ', '大誉地本町', 'オヨチモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡瀬戸内町与路', '46', '46525', '8942601', '鹿児島県', 'カゴシマケン', '大島郡瀬戸内町', 'オオシマグンセトウチチョウ', '与路', 'ヨロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道足寄郡陸別町登良利', '01', '01648', '0894261', '北海道', 'ホッカイドウ', '足寄郡陸別町', 'アショログンリクベツチョウ', '登良利', 'トラリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道足寄郡陸別町薫別', '01', '01648', '0894262', '北海道', 'ホッカイドウ', '足寄郡陸別町', 'アショログンリクベツチョウ', '薫別', 'クンベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道足寄郡陸別町', '01', '01648', '0894300', '北海道', 'ホッカイドウ', '足寄郡陸別町', 'アショログンリクベツチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('117866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道足寄郡陸別町ウエンベツ', '01', '01648', '0894301', '北海道', 'ホッカイドウ', '足寄郡陸別町', 'アショログンリクベツチョウ', 'ウエンベツ', 'ウエンベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道足寄郡陸別町若葉', '01', '01648', '0894302', '北海道', 'ホッカイドウ', '足寄郡陸別町', 'アショログンリクベツチョウ', '若葉', 'ワカバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道足寄郡陸別町下陸別', '01', '01648', '0894303', '北海道', 'ホッカイドウ', '足寄郡陸別町', 'アショログンリクベツチョウ', '下陸別', 'シモリクベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道足寄郡陸別町共和', '01', '01648', '0894304', '北海道', 'ホッカイドウ', '足寄郡陸別町', 'アショログンリクベツチョウ', '共和', 'キョウワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道足寄郡陸別町中陸別', '01', '01648', '0894305', '北海道', 'ホッカイドウ', '足寄郡陸別町', 'アショログンリクベツチョウ', '中陸別', 'ナカリクベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道足寄郡陸別町止若内', '01', '01648', '0894306', '北海道', 'ホッカイドウ', '足寄郡陸別町', 'アショログンリクベツチョウ', '止若内', 'ヤムワッカナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道足寄郡陸別町作集', '01', '01648', '0894307', '北海道', 'ホッカイドウ', '足寄郡陸別町', 'アショログンリクベツチョウ', '作集', 'サクシュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道足寄郡陸別町上陸別', '01', '01648', '0894308', '北海道', 'ホッカイドウ', '足寄郡陸別町', 'アショログンリクベツチョウ', '上陸別', 'カミリクベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡大和村', '46', '46523', '8943100', '鹿児島県', 'カゴシマケン', '大島郡大和村', 'オオシマグンヤマトソン', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('117875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡大和村国直', '46', '46523', '8943101', '鹿児島県', 'カゴシマケン', '大島郡大和村', 'オオシマグンヤマトソン', '国直', 'クニナオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡大和村湯湾釜', '46', '46523', '8943102', '鹿児島県', 'カゴシマケン', '大島郡大和村', 'オオシマグンヤマトソン', '湯湾釜', 'ユワンガマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡大和村津名久', '46', '46523', '8943103', '鹿児島県', 'カゴシマケン', '大島郡大和村', 'オオシマグンヤマトソン', '津名久', 'ツナグ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡大和村思勝', '46', '46523', '8943104', '鹿児島県', 'カゴシマケン', '大島郡大和村', 'オオシマグンヤマトソン', '思勝', 'オンガチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡大和村大和浜', '46', '46523', '8943105', '鹿児島県', 'カゴシマケン', '大島郡大和村', 'オオシマグンヤマトソン', '大和浜', 'ヤマトハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡大和村大棚', '46', '46523', '8943106', '鹿児島県', 'カゴシマケン', '大島郡大和村', 'オオシマグンヤマトソン', '大棚', 'オオダナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡大和村大金久', '46', '46523', '8943107', '鹿児島県', 'カゴシマケン', '大島郡大和村', 'オオシマグンヤマトソン', '大金久', 'オオガネク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道足寄郡陸別町東1条二区', '01', '01648', '0894311', '北海道', 'ホッカイドウ', '足寄郡陸別町', 'アショログンリクベツチョウ', '東1条二区', 'ヒガシ01ジョウ2ク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道足寄郡陸別町2', '01', '01648', '0894312', '北海道', 'ホッカイドウ', '足寄郡陸別町', 'アショログンリクベツチョウ', '2', 'キョウエイダイ02', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道足寄郡陸別町1', '01', '01648', '0894313', '北海道', 'ホッカイドウ', '足寄郡陸別町', 'アショログンリクベツチョウ', '1', 'キョウエイダイ01', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道足寄郡陸別町東1条一区', '01', '01648', '0894314', '北海道', 'ホッカイドウ', '足寄郡陸別町', 'アショログンリクベツチョウ', '東1条一区', 'ヒガシ01ジョウ1ク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道足寄郡陸別町大通', '01', '01648', '0894315', '北海道', 'ホッカイドウ', '足寄郡陸別町', 'アショログンリクベツチョウ', '大通', 'オオドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道足寄郡陸別町栄町', '01', '01648', '0894316', '北海道', 'ホッカイドウ', '足寄郡陸別町', 'アショログンリクベツチョウ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道足寄郡陸別町恩根内', '01', '01648', '0894321', '北海道', 'ホッカイドウ', '足寄郡陸別町', 'アショログンリクベツチョウ', '恩根内', 'オンネナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡大和村戸円', '46', '46523', '8943211', '鹿児島県', 'カゴシマケン', '大島郡大和村', 'オオシマグンヤマトソン', '戸円', 'トエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡大和村名音', '46', '46523', '8943212', '鹿児島県', 'カゴシマケン', '大島郡大和村', 'オオシマグンヤマトソン', '名音', 'ナオン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡大和村志戸勘', '46', '46523', '8943213', '鹿児島県', 'カゴシマケン', '大島郡大和村', 'オオシマグンヤマトソン', '志戸勘', 'シドカン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡大和村今里', '46', '46523', '8943214', '鹿児島県', 'カゴシマケン', '大島郡大和村', 'オオシマグンヤマトソン', '今里', 'イマザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道足寄郡陸別町新町一区', '01', '01648', '0894322', '北海道', 'ホッカイドウ', '足寄郡陸別町', 'アショログンリクベツチョウ', '新町一区', 'シンマチ01ク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道足寄郡陸別町新町二区', '01', '01648', '0894323', '北海道', 'ホッカイドウ', '足寄郡陸別町', 'アショログンリクベツチョウ', '新町二区', 'シンマチ02ク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道足寄郡陸別町旭町', '01', '01648', '0894324', '北海道', 'ホッカイドウ', '足寄郡陸別町', 'アショログンリクベツチョウ', '旭町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道足寄郡陸別町元町', '01', '01648', '0894325', '北海道', 'ホッカイドウ', '足寄郡陸別町', 'アショログンリクベツチョウ', '元町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道足寄郡陸別町緑町', '01', '01648', '0894326', '北海道', 'ホッカイドウ', '足寄郡陸別町', 'アショログンリクベツチョウ', '緑町', 'ミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡宇検村', '46', '46524', '8943300', '鹿児島県', 'カゴシマケン', '大島郡宇検村', 'オオシマグンウケンソン', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('117900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡宇検村湯湾', '46', '46524', '8943301', '鹿児島県', 'カゴシマケン', '大島郡宇検村', 'オオシマグンウケンソン', '湯湾', 'ユワン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡宇検村芦検', '46', '46524', '8943302', '鹿児島県', 'カゴシマケン', '大島郡宇検村', 'オオシマグンウケンソン', '芦検', 'アシケン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡宇検村田検', '46', '46524', '8943303', '鹿児島県', 'カゴシマケン', '大島郡宇検村', 'オオシマグンウケンソン', '田検', 'タケン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡宇検村須古', '46', '46524', '8943304', '鹿児島県', 'カゴシマケン', '大島郡宇検村', 'オオシマグンウケンソン', '須古', 'スコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡宇検村石良', '46', '46524', '8943305', '鹿児島県', 'カゴシマケン', '大島郡宇検村', 'オオシマグンウケンソン', '石良', 'イシラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道足寄郡陸別町川向', '01', '01648', '0894331', '北海道', 'ホッカイドウ', '足寄郡陸別町', 'アショログンリクベツチョウ', '川向', 'カワムカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道足寄郡陸別町関', '01', '01648', '0894332', '北海道', 'ホッカイドウ', '足寄郡陸別町', 'アショログンリクベツチョウ', '関', 'セキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道足寄郡陸別町殖産', '01', '01648', '0894333', '北海道', 'ホッカイドウ', '足寄郡陸別町', 'アショログンリクベツチョウ', '殖産', 'ショクサン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道足寄郡陸別町東斗満', '01', '01648', '0894334', '北海道', 'ホッカイドウ', '足寄郡陸別町', 'アショログンリクベツチョウ', '東斗満', 'ヒガシトマム', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道足寄郡陸別町中斗満', '01', '01648', '0894335', '北海道', 'ホッカイドウ', '足寄郡陸別町', 'アショログンリクベツチョウ', '中斗満', 'ナカトマム', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道足寄郡陸別町弥生', '01', '01648', '0894336', '北海道', 'ホッカイドウ', '足寄郡陸別町', 'アショログンリクベツチョウ', '弥生', 'ヤヨイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道足寄郡陸別町下斗満', '01', '01648', '0894337', '北海道', 'ホッカイドウ', '足寄郡陸別町', 'アショログンリクベツチョウ', '下斗満', 'シモトマム', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道足寄郡陸別町苫務', '01', '01648', '0894341', '北海道', 'ホッカイドウ', '足寄郡陸別町', 'アショログンリクベツチョウ', '苫務', 'トマム', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡宇検村宇検', '46', '46524', '8943411', '鹿児島県', 'カゴシマケン', '大島郡宇検村', 'オオシマグンウケンソン', '宇検', 'ウケン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡宇検村久志', '46', '46524', '8943412', '鹿児島県', 'カゴシマケン', '大島郡宇検村', 'オオシマグンウケンソン', '久志', 'クシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡宇検村生勝', '46', '46524', '8943413', '鹿児島県', 'カゴシマケン', '大島郡宇検村', 'オオシマグンウケンソン', '生勝', 'イケガチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道足寄郡陸別町上斗満', '01', '01648', '0894342', '北海道', 'ホッカイドウ', '足寄郡陸別町', 'アショログンリクベツチョウ', '上斗満', 'カミトマム', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道足寄郡陸別町南斗満', '01', '01648', '0894343', '北海道', 'ホッカイドウ', '足寄郡陸別町', 'アショログンリクベツチョウ', '南斗満', 'ミナミトマム', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道足寄郡陸別町西斗満', '01', '01648', '0894344', '北海道', 'ホッカイドウ', '足寄郡陸別町', 'アショログンリクベツチョウ', '西斗満', 'ニシトマム', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道足寄郡陸別町北斗満', '01', '01648', '0894345', '北海道', 'ホッカイドウ', '足寄郡陸別町', 'アショログンリクベツチョウ', '北斗満', 'キタトマム', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道足寄郡陸別町ポントマム', '01', '01648', '0894346', '北海道', 'ホッカイドウ', '足寄郡陸別町', 'アショログンリクベツチョウ', 'ポントマム', 'ポントマム', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道足寄郡陸別町勲祢別', '01', '01648', '0894351', '北海道', 'ホッカイドウ', '足寄郡陸別町', 'アショログンリクベツチョウ', '勲祢別', 'クンネベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道足寄郡陸別町分線', '01', '01648', '0894352', '北海道', 'ホッカイドウ', '足寄郡陸別町', 'アショログンリクベツチョウ', '分線', 'ブンセン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡宇検村名柄', '46', '46524', '8943521', '鹿児島県', 'カゴシマケン', '大島郡宇検村', 'オオシマグンウケンソン', '名柄', 'ナガラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡宇検村佐念', '46', '46524', '8943522', '鹿児島県', 'カゴシマケン', '大島郡宇検村', 'オオシマグンウケンソン', '佐念', 'サネン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡宇検村部連', '46', '46524', '8943523', '鹿児島県', 'カゴシマケン', '大島郡宇検村', 'オオシマグンウケンソン', '部連', 'ブレン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道足寄郡陸別町川上', '01', '01648', '0894353', '北海道', 'ホッカイドウ', '足寄郡陸別町', 'アショログンリクベツチョウ', '川上', 'カワカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道足寄郡陸別町日宗', '01', '01648', '0894354', '北海道', 'ホッカイドウ', '足寄郡陸別町', 'アショログンリクベツチョウ', '日宗', 'ニッシュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道足寄郡陸別町小利別', '01', '01648', '0894355', '北海道', 'ホッカイドウ', '足寄郡陸別町', 'アショログンリクベツチョウ', '小利別', 'ショウトシベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道足寄郡陸別町林内', '01', '01648', '0894356', '北海道', 'ホッカイドウ', '足寄郡陸別町', 'アショログンリクベツチョウ', '林内', 'リンナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道足寄郡陸別町利上', '01', '01648', '0894357', '北海道', 'ホッカイドウ', '足寄郡陸別町', 'アショログンリクベツチョウ', '利上', 'トシカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡宇検村平田', '46', '46524', '8943631', '鹿児島県', 'カゴシマケン', '大島郡宇検村', 'オオシマグンウケンソン', '平田', 'ヘダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡宇検村阿室', '46', '46524', '8943632', '鹿児島県', 'カゴシマケン', '大島郡宇検村', 'オオシマグンウケンソン', '阿室', 'アムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県大島郡宇検村屋鈍', '46', '46524', '8943633', '鹿児島県', 'カゴシマケン', '大島郡宇検村', 'オオシマグンウケンソン', '屋鈍', 'ヤドン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩川内市', '46', '46215', '8950000', '鹿児島県', 'カゴシマケン', '薩摩川内市', 'サツマセンダイシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('117950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩川内市白浜町', '46', '46215', '8950001', '鹿児島県', 'カゴシマケン', '薩摩川内市', 'サツマセンダイシ', '白浜町', 'シラハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩川内市楠元町', '46', '46215', '8950002', '鹿児島県', 'カゴシマケン', '薩摩川内市', 'サツマセンダイシ', '楠元町', 'クスモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩川内市中村町', '46', '46215', '8950003', '鹿児島県', 'カゴシマケン', '薩摩川内市', 'サツマセンダイシ', '中村町', 'ナカムラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩川内市久住町', '46', '46215', '8950004', '鹿児島県', 'カゴシマケン', '薩摩川内市', 'サツマセンダイシ', '久住町', 'クジュウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩川内市永利町', '46', '46215', '8950005', '鹿児島県', 'カゴシマケン', '薩摩川内市', 'サツマセンダイシ', '永利町', 'ナガトシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩川内市田崎町', '46', '46215', '8950006', '鹿児島県', 'カゴシマケン', '薩摩川内市', 'サツマセンダイシ', '田崎町', 'タサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩川内市百次町', '46', '46215', '8950007', '鹿児島県', 'カゴシマケン', '薩摩川内市', 'サツマセンダイシ', '百次町', 'モモツギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩川内市天辰町', '46', '46215', '8950011', '鹿児島県', 'カゴシマケン', '薩摩川内市', 'サツマセンダイシ', '天辰町', 'アマタツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩川内市平佐町', '46', '46215', '8950012', '鹿児島県', 'カゴシマケン', '薩摩川内市', 'サツマセンダイシ', '平佐町', 'ヒラサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩川内市宮崎町', '46', '46215', '8950013', '鹿児島県', 'カゴシマケン', '薩摩川内市', 'サツマセンダイシ', '宮崎町', 'ミヤザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩川内市向田本町', '46', '46215', '8950021', '鹿児島県', 'カゴシマケン', '薩摩川内市', 'サツマセンダイシ', '向田本町', 'ムコウダホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩川内市白和町', '46', '46215', '8950022', '鹿児島県', 'カゴシマケン', '薩摩川内市', 'サツマセンダイシ', '白和町', 'シラワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩川内市横馬場町', '46', '46215', '8950023', '鹿児島県', 'カゴシマケン', '薩摩川内市', 'サツマセンダイシ', '横馬場町', 'ヨコババチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩川内市鳥追町', '46', '46215', '8950024', '鹿児島県', 'カゴシマケン', '薩摩川内市', 'サツマセンダイシ', '鳥追町', 'トリオイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩川内市向田町', '46', '46215', '8950025', '鹿児島県', 'カゴシマケン', '薩摩川内市', 'サツマセンダイシ', '向田町', 'ムコウダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩川内市東向田町', '46', '46215', '8950026', '鹿児島県', 'カゴシマケン', '薩摩川内市', 'サツマセンダイシ', '東向田町', 'ヒガシムコウダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩川内市西向田町', '46', '46215', '8950027', '鹿児島県', 'カゴシマケン', '薩摩川内市', 'サツマセンダイシ', '西向田町', 'ニシムコウダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩川内市勝目町', '46', '46215', '8950031', '鹿児島県', 'カゴシマケン', '薩摩川内市', 'サツマセンダイシ', '勝目町', 'カチメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩川内市山之口町', '46', '46215', '8950032', '鹿児島県', 'カゴシマケン', '薩摩川内市', 'サツマセンダイシ', '山之口町', 'ヤマノクチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩川内市川永野町', '46', '46215', '8950033', '鹿児島県', 'カゴシマケン', '薩摩川内市', 'サツマセンダイシ', '川永野町', 'カワナガノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩川内市木場茶屋町', '46', '46215', '8950034', '鹿児島県', 'カゴシマケン', '薩摩川内市', 'サツマセンダイシ', '木場茶屋町', 'コバンチャヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩川内市尾白江町', '46', '46215', '8950035', '鹿児島県', 'カゴシマケン', '薩摩川内市', 'サツマセンダイシ', '尾白江町', 'オジロエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩川内市矢倉町', '46', '46215', '8950036', '鹿児島県', 'カゴシマケン', '薩摩川内市', 'サツマセンダイシ', '矢倉町', 'ヤグラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩川内市隈之城町', '46', '46215', '8950041', '鹿児島県', 'カゴシマケン', '薩摩川内市', 'サツマセンダイシ', '隈之城町', 'クマノジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩川内市中福良町', '46', '46215', '8950042', '鹿児島県', 'カゴシマケン', '薩摩川内市', 'サツマセンダイシ', '中福良町', 'ナカフクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩川内市都町', '46', '46215', '8950043', '鹿児島県', 'カゴシマケン', '薩摩川内市', 'サツマセンダイシ', '都町', 'ミヤコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩川内市青山町', '46', '46215', '8950044', '鹿児島県', 'カゴシマケン', '薩摩川内市', 'サツマセンダイシ', '青山町', 'アオヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩川内市東開聞町', '46', '46215', '8950051', '鹿児島県', 'カゴシマケン', '薩摩川内市', 'サツマセンダイシ', '東開聞町', 'ヒガシカイモンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩川内市神田町', '46', '46215', '8950052', '鹿児島県', 'カゴシマケン', '薩摩川内市', 'サツマセンダイシ', '神田町', 'カンダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩川内市冷水町', '46', '46215', '8950053', '鹿児島県', 'カゴシマケン', '薩摩川内市', 'サツマセンダイシ', '冷水町', 'ヒヤミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩川内市若松町', '46', '46215', '8950054', '鹿児島県', 'カゴシマケン', '薩摩川内市', 'サツマセンダイシ', '若松町', 'ワカマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩川内市西開聞町', '46', '46215', '8950055', '鹿児島県', 'カゴシマケン', '薩摩川内市', 'サツマセンダイシ', '西開聞町', 'ニシカイモンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩川内市宮里町', '46', '46215', '8950056', '鹿児島県', 'カゴシマケン', '薩摩川内市', 'サツマセンダイシ', '宮里町', 'ミヤザトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩川内市御陵下町', '46', '46215', '8950061', '鹿児島県', 'カゴシマケン', '薩摩川内市', 'サツマセンダイシ', '御陵下町', 'ゴリョウシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩川内市大王町', '46', '46215', '8950062', '鹿児島県', 'カゴシマケン', '薩摩川内市', 'サツマセンダイシ', '大王町', 'ダイオウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩川内市若葉町', '46', '46215', '8950063', '鹿児島県', 'カゴシマケン', '薩摩川内市', 'サツマセンダイシ', '若葉町', 'ワカバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩川内市花木町', '46', '46215', '8950064', '鹿児島県', 'カゴシマケン', '薩摩川内市', 'サツマセンダイシ', '花木町', 'ハナキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩川内市宮内町', '46', '46215', '8950065', '鹿児島県', 'カゴシマケン', '薩摩川内市', 'サツマセンダイシ', '宮内町', 'ミヤウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩川内市五代町', '46', '46215', '8950066', '鹿児島県', 'カゴシマケン', '薩摩川内市', 'サツマセンダイシ', '五代町', 'ゴダイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩川内市上川内町', '46', '46215', '8950067', '鹿児島県', 'カゴシマケン', '薩摩川内市', 'サツマセンダイシ', '上川内町', 'カミセンダイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩川内市田海町', '46', '46215', '8950071', '鹿児島県', 'カゴシマケン', '薩摩川内市', 'サツマセンダイシ', '田海町', 'タウミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩川内市中郷', '46', '46215', '8950072', '鹿児島県', 'カゴシマケン', '薩摩川内市', 'サツマセンダイシ', '中郷', 'チュウゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩川内市中郷町', '46', '46215', '8950072', '鹿児島県', 'カゴシマケン', '薩摩川内市', 'サツマセンダイシ', '中郷町', 'チュウゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩川内市国分寺町', '46', '46215', '8950073', '鹿児島県', 'カゴシマケン', '薩摩川内市', 'サツマセンダイシ', '国分寺町', 'コクブンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩川内市原田町', '46', '46215', '8950074', '鹿児島県', 'カゴシマケン', '薩摩川内市', 'サツマセンダイシ', '原田町', 'ハラダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩川内市東大小路町', '46', '46215', '8950075', '鹿児島県', 'カゴシマケン', '薩摩川内市', 'サツマセンダイシ', '東大小路町', 'ヒガシオオショウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩川内市大小路町', '46', '46215', '8950076', '鹿児島県', 'カゴシマケン', '薩摩川内市', 'サツマセンダイシ', '大小路町', 'オオショウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩川内市運動公園町', '46', '46215', '8950077', '鹿児島県', 'カゴシマケン', '薩摩川内市', 'サツマセンダイシ', '運動公園町', 'ウンドウコウエンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩川内市高江町', '46', '46215', '8950131', '鹿児島県', 'カゴシマケン', '薩摩川内市', 'サツマセンダイシ', '高江町', 'タカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('117999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩川内市久見崎町', '46', '46215', '8950132', '鹿児島県', 'カゴシマケン', '薩摩川内市', 'サツマセンダイシ', '久見崎町', 'グミサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩川内市寄田町', '46', '46215', '8950133', '鹿児島県', 'カゴシマケン', '薩摩川内市', 'サツマセンダイシ', '寄田町', 'ヨリタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩川内市高城町', '46', '46215', '8950211', '鹿児島県', 'カゴシマケン', '薩摩川内市', 'サツマセンダイシ', '高城町', 'タキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩川内市陽成町', '46', '46215', '8950212', '鹿児島県', 'カゴシマケン', '薩摩川内市', 'サツマセンダイシ', '陽成町', 'ヨウゼイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩川内市城上町', '46', '46215', '8950213', '鹿児島県', 'カゴシマケン', '薩摩川内市', 'サツマセンダイシ', '城上町', 'ジョウカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩川内市運動公園町', '46', '46215', '8950214', '鹿児島県', 'カゴシマケン', '薩摩川内市', 'サツマセンダイシ', '運動公園町', 'ウンドウコウエンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩川内市東郷町宍野', '46', '46215', '8951101', '鹿児島県', 'カゴシマケン', '薩摩川内市', 'サツマセンダイシ', '東郷町宍野', 'トウゴウチョウシシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩川内市東郷町藤川', '46', '46215', '8951102', '鹿児島県', 'カゴシマケン', '薩摩川内市', 'サツマセンダイシ', '東郷町藤川', 'トウゴウチョウフジカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩川内市東郷町鳥丸', '46', '46215', '8951103', '鹿児島県', 'カゴシマケン', '薩摩川内市', 'サツマセンダイシ', '東郷町鳥丸', 'トウゴウチョウトリマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩川内市東郷町山田', '46', '46215', '8951104', '鹿児島県', 'カゴシマケン', '薩摩川内市', 'サツマセンダイシ', '東郷町山田', 'トウゴウチョウヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩川内市東郷町南瀬', '46', '46215', '8951105', '鹿児島県', 'カゴシマケン', '薩摩川内市', 'サツマセンダイシ', '東郷町南瀬', 'トウゴウチョウノウゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩川内市東郷町斧渕', '46', '46215', '8951106', '鹿児島県', 'カゴシマケン', '薩摩川内市', 'サツマセンダイシ', '東郷町斧渕', 'トウゴウチョウオノブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩川内市樋脇町倉野', '46', '46215', '8951201', '鹿児島県', 'カゴシマケン', '薩摩川内市', 'サツマセンダイシ', '樋脇町倉野', 'ヒワキチョウクラノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩川内市樋脇町塔之原', '46', '46215', '8951202', '鹿児島県', 'カゴシマケン', '薩摩川内市', 'サツマセンダイシ', '樋脇町塔之原', 'ヒワキチョウトウノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩川内市樋脇町市比野', '46', '46215', '8951203', '鹿児島県', 'カゴシマケン', '薩摩川内市', 'サツマセンダイシ', '樋脇町市比野', 'ヒワキチョウイチヒノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩川内市入来町副田', '46', '46215', '8951401', '鹿児島県', 'カゴシマケン', '薩摩川内市', 'サツマセンダイシ', '入来町副田', 'イリキチョウソエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩川内市入来町浦之名', '46', '46215', '8951402', '鹿児島県', 'カゴシマケン', '薩摩川内市', 'サツマセンダイシ', '入来町浦之名', 'イリキチョウウラノミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩川内市祁答院町下手', '46', '46215', '8951501', '鹿児島県', 'カゴシマケン', '薩摩川内市', 'サツマセンダイシ', '祁答院町下手', 'ケドウインチョウシモデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩川内市祁答院町藺牟田', '46', '46215', '8951502', '鹿児島県', 'カゴシマケン', '薩摩川内市', 'サツマセンダイシ', '祁答院町藺牟田', 'ケドウインチョウイムタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩川内市祁答院町上手', '46', '46215', '8951503', '鹿児島県', 'カゴシマケン', '薩摩川内市', 'サツマセンダイシ', '祁答院町上手', 'ケドウインチョウカミデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩川内市祁答院町黒木', '46', '46215', '8951504', '鹿児島県', 'カゴシマケン', '薩摩川内市', 'サツマセンダイシ', '祁答院町黒木', 'ケドウインチョウクロキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩郡さつま町山崎', '46', '46392', '8951721', '鹿児島県', 'カゴシマケン', '薩摩郡さつま町', 'サツマグンサツマチョウ', '山崎', 'ヤマサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩郡さつま町久富木', '46', '46392', '8951722', '鹿児島県', 'カゴシマケン', '薩摩郡さつま町', 'サツマグンサツマチョウ', '久富木', 'クブキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩郡さつま町二渡', '46', '46392', '8951723', '鹿児島県', 'カゴシマケン', '薩摩郡さつま町', 'サツマグンサツマチョウ', '二渡', 'フタワタリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩郡さつま町', '46', '46392', '8951800', '鹿児島県', 'カゴシマケン', '薩摩郡さつま町', 'サツマグンサツマチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('118032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩郡さつま町広瀬', '46', '46392', '8951801', '鹿児島県', 'カゴシマケン', '薩摩郡さつま町', 'サツマグンサツマチョウ', '広瀬', 'ヒロセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩郡さつま町田原', '46', '46392', '8951802', '鹿児島県', 'カゴシマケン', '薩摩郡さつま町', 'サツマグンサツマチョウ', '田原', 'タバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩郡さつま町宮之城屋地', '46', '46392', '8951803', '鹿児島県', 'カゴシマケン', '薩摩郡さつま町', 'サツマグンサツマチョウ', '宮之城屋地', 'ミヤノジョウヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩郡さつま町船木', '46', '46392', '8951804', '鹿児島県', 'カゴシマケン', '薩摩郡さつま町', 'サツマグンサツマチョウ', '船木', 'フナキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩郡さつま町白男川', '46', '46392', '8951805', '鹿児島県', 'カゴシマケン', '薩摩郡さつま町', 'サツマグンサツマチョウ', '白男川', 'シラオガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩郡さつま町泊野', '46', '46392', '8951806', '鹿児島県', 'カゴシマケン', '薩摩郡さつま町', 'サツマグンサツマチョウ', '泊野', 'トマリノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩郡さつま町平川', '46', '46392', '8951807', '鹿児島県', 'カゴシマケン', '薩摩郡さつま町', 'サツマグンサツマチョウ', '平川', 'ヒラカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩郡さつま町虎居', '46', '46392', '8951811', '鹿児島県', 'カゴシマケン', '薩摩郡さつま町', 'サツマグンサツマチョウ', '虎居', 'トライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩郡さつま町虎居町', '46', '46392', '8951812', '鹿児島県', 'カゴシマケン', '薩摩郡さつま町', 'サツマグンサツマチョウ', '虎居町', 'トライマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩郡さつま町轟町', '46', '46392', '8951813', '鹿児島県', 'カゴシマケン', '薩摩郡さつま町', 'サツマグンサツマチョウ', '轟町', 'トドロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩郡さつま町旭町', '46', '46392', '8951814', '鹿児島県', 'カゴシマケン', '薩摩郡さつま町', 'サツマグンサツマチョウ', '旭町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩郡さつま町西新町', '46', '46392', '8951815', '鹿児島県', 'カゴシマケン', '薩摩郡さつま町', 'サツマグンサツマチョウ', '西新町', 'ニシシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩郡さつま町時吉', '46', '46392', '8951816', '鹿児島県', 'カゴシマケン', '薩摩郡さつま町', 'サツマグンサツマチョウ', '時吉', 'トキヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩郡さつま町湯田', '46', '46392', '8951817', '鹿児島県', 'カゴシマケン', '薩摩郡さつま町', 'サツマグンサツマチョウ', '湯田', 'ユダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩郡さつま町鶴田', '46', '46392', '8952101', '鹿児島県', 'カゴシマケン', '薩摩郡さつま町', 'サツマグンサツマチョウ', '鶴田', 'ツルダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩郡さつま町神子', '46', '46392', '8952102', '鹿児島県', 'カゴシマケン', '薩摩郡さつま町', 'サツマグンサツマチョウ', '神子', 'コウシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩郡さつま町紫尾', '46', '46392', '8952103', '鹿児島県', 'カゴシマケン', '薩摩郡さつま町', 'サツマグンサツマチョウ', '紫尾', 'シビ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩郡さつま町柏原', '46', '46392', '8952104', '鹿児島県', 'カゴシマケン', '薩摩郡さつま町', 'サツマグンサツマチョウ', '柏原', 'カシワバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩郡さつま町柊野', '46', '46392', '8952131', '鹿児島県', 'カゴシマケン', '薩摩郡さつま町', 'サツマグンサツマチョウ', '柊野', 'クキノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩郡さつま町求名', '46', '46392', '8952201', '鹿児島県', 'カゴシマケン', '薩摩郡さつま町', 'サツマグンサツマチョウ', '求名', 'グミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩郡さつま町中津川', '46', '46392', '8952202', '鹿児島県', 'カゴシマケン', '薩摩郡さつま町', 'サツマグンサツマチョウ', '中津川', 'ナカツガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩郡さつま町永野', '46', '46392', '8952203', '鹿児島県', 'カゴシマケン', '薩摩郡さつま町', 'サツマグンサツマチョウ', '永野', 'ナガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡豊頃町豊頃佐々田町', '01', '01645', '0895231', '北海道', 'ホッカイドウ', '中川郡豊頃町', 'ナカガワグントヨコロチョウ', '豊頃佐々田町', 'トヨコロササダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡豊頃町豊頃旭町', '01', '01645', '0895232', '北海道', 'ホッカイドウ', '中川郡豊頃町', 'ナカガワグントヨコロチョウ', '豊頃旭町', 'トヨコロアサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡豊頃町豊頃南町', '01', '01645', '0895233', '北海道', 'ホッカイドウ', '中川郡豊頃町', 'ナカガワグントヨコロチョウ', '豊頃南町', 'トヨコロミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡豊頃町中央新町', '01', '01645', '0895234', '北海道', 'ホッカイドウ', '中川郡豊頃町', 'ナカガワグントヨコロチョウ', '中央新町', 'チュウオウシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡豊頃町中央若葉町', '01', '01645', '0895235', '北海道', 'ホッカイドウ', '中川郡豊頃町', 'ナカガワグントヨコロチョウ', '中央若葉町', 'チュウオウワカバマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡豊頃町育素多', '01', '01645', '0895241', '北海道', 'ホッカイドウ', '中川郡豊頃町', 'ナカガワグントヨコロチョウ', '育素多', 'イクソタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡豊頃町北栄', '01', '01645', '0895242', '北海道', 'ホッカイドウ', '中川郡豊頃町', 'ナカガワグントヨコロチョウ', '北栄', 'ホクエイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡豊頃町十弗宝町', '01', '01645', '0895243', '北海道', 'ホッカイドウ', '中川郡豊頃町', 'ナカガワグントヨコロチョウ', '十弗宝町', 'トオフツタカラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡豊頃町十弗', '01', '01645', '0895244', '北海道', 'ホッカイドウ', '中川郡豊頃町', 'ナカガワグントヨコロチョウ', '十弗', 'トオフツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県伊佐市大口曽木', '46', '46224', '8952441', '鹿児島県', 'カゴシマケン', '伊佐市', 'イサシ', '大口曽木', 'オオクチソギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県伊佐市大口針持', '46', '46224', '8952442', '鹿児島県', 'カゴシマケン', '伊佐市', 'イサシ', '大口針持', 'オオクチハリモチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡豊頃町礼文内', '01', '01645', '0895245', '北海道', 'ホッカイドウ', '中川郡豊頃町', 'ナカガワグントヨコロチョウ', '礼文内', 'レブンナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡豊頃町豊頃', '01', '01645', '0895246', '北海道', 'ホッカイドウ', '中川郡豊頃町', 'ナカガワグントヨコロチョウ', '豊頃', 'トヨコロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡豊頃町幌岡', '01', '01645', '0895247', '北海道', 'ホッカイドウ', '中川郡豊頃町', 'ナカガワグントヨコロチョウ', '幌岡', 'ホロオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県伊佐市', '46', '46224', '8952500', '鹿児島県', 'カゴシマケン', '伊佐市', 'イサシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('118071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県伊佐市大口牛尾', '46', '46224', '8952501', '鹿児島県', 'カゴシマケン', '伊佐市', 'イサシ', '大口牛尾', 'オオクチウシオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県伊佐市大口木ノ氏', '46', '46224', '8952502', '鹿児島県', 'カゴシマケン', '伊佐市', 'イサシ', '大口木ノ氏', 'オオクチキノウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県伊佐市大口篠原', '46', '46224', '8952503', '鹿児島県', 'カゴシマケン', '伊佐市', 'イサシ', '大口篠原', 'オオクチシノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県伊佐市大口青木', '46', '46224', '8952504', '鹿児島県', 'カゴシマケン', '伊佐市', 'イサシ', '大口青木', 'オオクチアオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県伊佐市大口目丸', '46', '46224', '8952505', '鹿児島県', 'カゴシマケン', '伊佐市', 'イサシ', '大口目丸', 'オオクチメマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県伊佐市大口原田', '46', '46224', '8952506', '鹿児島県', 'カゴシマケン', '伊佐市', 'イサシ', '大口原田', 'オオクチハラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県伊佐市大口大田', '46', '46224', '8952507', '鹿児島県', 'カゴシマケン', '伊佐市', 'イサシ', '大口大田', 'オオクチオオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県伊佐市大口里', '46', '46224', '8952511', '鹿児島県', 'カゴシマケン', '伊佐市', 'イサシ', '大口里', 'オオクチサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県伊佐市大口元町', '46', '46224', '8952512', '鹿児島県', 'カゴシマケン', '伊佐市', 'イサシ', '大口元町', 'オオクチモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県伊佐市大口上町', '46', '46224', '8952513', '鹿児島県', 'カゴシマケン', '伊佐市', 'イサシ', '大口上町', 'オオクチカミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県伊佐市大口鳥巣', '46', '46224', '8952521', '鹿児島県', 'カゴシマケン', '伊佐市', 'イサシ', '大口鳥巣', 'オオクチトリス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県伊佐市大口大島', '46', '46224', '8952522', '鹿児島県', 'カゴシマケン', '伊佐市', 'イサシ', '大口大島', 'オオクチオオシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県伊佐市大口金波田', '46', '46224', '8952523', '鹿児島県', 'カゴシマケン', '伊佐市', 'イサシ', '大口金波田', 'オオクチカナハダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県伊佐市大口堂崎', '46', '46224', '8952524', '鹿児島県', 'カゴシマケン', '伊佐市', 'イサシ', '大口堂崎', 'オオクチドウザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県伊佐市大口下殿', '46', '46224', '8952525', '鹿児島県', 'カゴシマケン', '伊佐市', 'イサシ', '大口下殿', 'オオクチシモトノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県伊佐市大口宮人', '46', '46224', '8952526', '鹿児島県', 'カゴシマケン', '伊佐市', 'イサシ', '大口宮人', 'オオクチミヤヒト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県伊佐市大口田代', '46', '46224', '8952527', '鹿児島県', 'カゴシマケン', '伊佐市', 'イサシ', '大口田代', 'オオクチタシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県伊佐市大口川岩瀬', '46', '46224', '8952528', '鹿児島県', 'カゴシマケン', '伊佐市', 'イサシ', '大口川岩瀬', 'オオクチカワイワゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県伊佐市大口白木', '46', '46224', '8952529', '鹿児島県', 'カゴシマケン', '伊佐市', 'イサシ', '大口白木', 'オオクチシラキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県伊佐市大口小木原', '46', '46224', '8952631', '鹿児島県', 'カゴシマケン', '伊佐市', 'イサシ', '大口小木原', 'オオクチコギハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県伊佐市大口渕辺', '46', '46224', '8952632', '鹿児島県', 'カゴシマケン', '伊佐市', 'イサシ', '大口渕辺', 'オオクチフチベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県伊佐市大口平出水', '46', '46224', '8952633', '鹿児島県', 'カゴシマケン', '伊佐市', 'イサシ', '大口平出水', 'オオクチヒライズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県伊佐市大口小川内', '46', '46224', '8952634', '鹿児島県', 'カゴシマケン', '伊佐市', 'イサシ', '大口小川内', 'オオクチコガワウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県伊佐市大口山野', '46', '46224', '8952635', '鹿児島県', 'カゴシマケン', '伊佐市', 'イサシ', '大口山野', 'オオクチヤマノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県伊佐市菱刈前目', '46', '46224', '8952701', '鹿児島県', 'カゴシマケン', '伊佐市', 'イサシ', '菱刈前目', 'ヒシカリマエメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県伊佐市菱刈下手', '46', '46224', '8952702', '鹿児島県', 'カゴシマケン', '伊佐市', 'イサシ', '菱刈下手', 'ヒシカリシモデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県伊佐市菱刈花北', '46', '46224', '8952703', '鹿児島県', 'カゴシマケン', '伊佐市', 'イサシ', '菱刈花北', 'ヒシカリハナキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県伊佐市菱刈市山', '46', '46224', '8952704', '鹿児島県', 'カゴシマケン', '伊佐市', 'イサシ', '菱刈市山', 'ヒシカリイチヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県伊佐市菱刈重留', '46', '46224', '8952705', '鹿児島県', 'カゴシマケン', '伊佐市', 'イサシ', '菱刈重留', 'ヒシカリシゲトメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県伊佐市菱刈田中', '46', '46224', '8952706', '鹿児島県', 'カゴシマケン', '伊佐市', 'イサシ', '菱刈田中', 'ヒシカリタナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県伊佐市菱刈徳辺', '46', '46224', '8952707', '鹿児島県', 'カゴシマケン', '伊佐市', 'イサシ', '菱刈徳辺', 'ヒシカリトクベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県伊佐市菱刈川北', '46', '46224', '8952708', '鹿児島県', 'カゴシマケン', '伊佐市', 'イサシ', '菱刈川北', 'ヒシカリカワキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県伊佐市菱刈荒田', '46', '46224', '8952811', '鹿児島県', 'カゴシマケン', '伊佐市', 'イサシ', '菱刈荒田', 'ヒシカリアラタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県伊佐市菱刈川南', '46', '46224', '8952812', '鹿児島県', 'カゴシマケン', '伊佐市', 'イサシ', '菱刈川南', 'ヒシカリカワミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県伊佐市菱刈南浦', '46', '46224', '8952813', '鹿児島県', 'カゴシマケン', '伊佐市', 'イサシ', '菱刈南浦', 'ヒシカリミナミウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡豊頃町', '01', '01645', '0895300', '北海道', 'ホッカイドウ', '中川郡豊頃町', 'ナカガワグントヨコロチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('118108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡豊頃町統内', '01', '01645', '0895301', '北海道', 'ホッカイドウ', '中川郡豊頃町', 'ナカガワグントヨコロチョウ', '統内', 'トウナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡豊頃町礼作別', '01', '01645', '0895302', '北海道', 'ホッカイドウ', '中川郡豊頃町', 'ナカガワグントヨコロチョウ', '礼作別', 'レイサクベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡豊頃町農野牛', '01', '01645', '0895303', '北海道', 'ホッカイドウ', '中川郡豊頃町', 'ナカガワグントヨコロチョウ', '農野牛', 'ノヤウシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡豊頃町牛首別', '01', '01645', '0895304', '北海道', 'ホッカイドウ', '中川郡豊頃町', 'ナカガワグントヨコロチョウ', '牛首別', 'ウシシュベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡豊頃町背負', '01', '01645', '0895305', '北海道', 'ホッカイドウ', '中川郡豊頃町', 'ナカガワグントヨコロチョウ', '背負', 'セオイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡豊頃町安骨', '01', '01645', '0895306', '北海道', 'ホッカイドウ', '中川郡豊頃町', 'ナカガワグントヨコロチョウ', '安骨', 'アンコツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡豊頃町旅来', '01', '01645', '0895307', '北海道', 'ホッカイドウ', '中川郡豊頃町', 'ナカガワグントヨコロチョウ', '旅来', 'タビコライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡豊頃町湧洞', '01', '01645', '0895308', '北海道', 'ホッカイドウ', '中川郡豊頃町', 'ナカガワグントヨコロチョウ', '湧洞', 'ユウドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡豊頃町二宮', '01', '01645', '0895309', '北海道', 'ホッカイドウ', '中川郡豊頃町', 'ナカガワグントヨコロチョウ', '二宮', 'ニノミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡豊頃町茂岩新和町', '01', '01645', '0895311', '北海道', 'ホッカイドウ', '中川郡豊頃町', 'ナカガワグントヨコロチョウ', '茂岩新和町', 'モイワシンワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡豊頃町茂岩本町', '01', '01645', '0895312', '北海道', 'ホッカイドウ', '中川郡豊頃町', 'ナカガワグントヨコロチョウ', '茂岩本町', 'モイワホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡豊頃町茂岩栄町', '01', '01645', '0895313', '北海道', 'ホッカイドウ', '中川郡豊頃町', 'ナカガワグントヨコロチョウ', '茂岩栄町', 'モイワサカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡豊頃町茂岩末広町', '01', '01645', '0895314', '北海道', 'ホッカイドウ', '中川郡豊頃町', 'ナカガワグントヨコロチョウ', '茂岩末広町', 'モイワスエヒロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡豊頃町茂岩', '01', '01645', '0895315', '北海道', 'ホッカイドウ', '中川郡豊頃町', 'ナカガワグントヨコロチョウ', '茂岩', 'モイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡豊頃町大津元町', '01', '01645', '0895461', '北海道', 'ホッカイドウ', '中川郡豊頃町', 'ナカガワグントヨコロチョウ', '大津元町', 'オオツモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡豊頃町大津幸町', '01', '01645', '0895462', '北海道', 'ホッカイドウ', '中川郡豊頃町', 'ナカガワグントヨコロチョウ', '大津幸町', 'オオツサイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡豊頃町大津寿町', '01', '01645', '0895463', '北海道', 'ホッカイドウ', '中川郡豊頃町', 'ナカガワグントヨコロチョウ', '大津寿町', 'オオツコトブキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡豊頃町大津港町', '01', '01645', '0895464', '北海道', 'ホッカイドウ', '中川郡豊頃町', 'ナカガワグントヨコロチョウ', '大津港町', 'オオツミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡豊頃町大津', '01', '01645', '0895465', '北海道', 'ホッカイドウ', '中川郡豊頃町', 'ナカガワグントヨコロチョウ', '大津', 'オオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡豊頃町長節', '01', '01645', '0895466', '北海道', 'ホッカイドウ', '中川郡豊頃町', 'ナカガワグントヨコロチョウ', '長節', 'チョウブシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道十勝郡浦幌町吉野', '01', '01649', '0895541', '北海道', 'ホッカイドウ', '十勝郡浦幌町', 'トカチグンウラホロチョウ', '吉野', 'ヨシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道十勝郡浦幌町共栄', '01', '01649', '0895542', '北海道', 'ホッカイドウ', '十勝郡浦幌町', 'トカチグンウラホロチョウ', '共栄', 'キョウエイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道十勝郡浦幌町平和', '01', '01649', '0895543', '北海道', 'ホッカイドウ', '十勝郡浦幌町', 'トカチグンウラホロチョウ', '平和', 'ヘイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道十勝郡浦幌町統太', '01', '01649', '0895544', '北海道', 'ホッカイドウ', '十勝郡浦幌町', 'トカチグンウラホロチョウ', '統太', 'トウフト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道十勝郡浦幌町養老', '01', '01649', '0895545', '北海道', 'ホッカイドウ', '十勝郡浦幌町', 'トカチグンウラホロチョウ', '養老', 'ヨウロウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道十勝郡浦幌町朝日', '01', '01649', '0895546', '北海道', 'ホッカイドウ', '十勝郡浦幌町', 'トカチグンウラホロチョウ', '朝日', 'アサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道十勝郡浦幌町生剛', '01', '01649', '0895547', '北海道', 'ホッカイドウ', '十勝郡浦幌町', 'トカチグンウラホロチョウ', '生剛', 'セイゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道十勝郡浦幌町十勝太', '01', '01649', '0895548', '北海道', 'ホッカイドウ', '十勝郡浦幌町', 'トカチグンウラホロチョウ', '十勝太', 'トカチブト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道十勝郡浦幌町愛牛', '01', '01649', '0895551', '北海道', 'ホッカイドウ', '十勝郡浦幌町', 'トカチグンウラホロチョウ', '愛牛', 'アイウシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道十勝郡浦幌町豊北', '01', '01649', '0895552', '北海道', 'ホッカイドウ', '十勝郡浦幌町', 'トカチグンウラホロチョウ', '豊北', 'トヨキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道十勝郡浦幌町打内', '01', '01649', '0895553', '北海道', 'ホッカイドウ', '十勝郡浦幌町', 'トカチグンウラホロチョウ', '打内', 'ウツナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道十勝郡浦幌町大平', '01', '01649', '0895554', '北海道', 'ホッカイドウ', '十勝郡浦幌町', 'トカチグンウラホロチョウ', '大平', 'タイヘイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道十勝郡浦幌町トイトッキ', '01', '01649', '0895555', '北海道', 'ホッカイドウ', '十勝郡浦幌町', 'トカチグンウラホロチョウ', 'トイトッキ', 'トイトッキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道十勝郡浦幌町鼈奴', '01', '01649', '0895556', '北海道', 'ホッカイドウ', '十勝郡浦幌町', 'トカチグンウラホロチョウ', '鼈奴', 'ベッチャロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道十勝郡浦幌町ヌタベット', '01', '01649', '0895557', '北海道', 'ホッカイドウ', '十勝郡浦幌町', 'トカチグンウラホロチョウ', 'ヌタベット', 'ヌタベット', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道十勝郡浦幌町昆布刈石', '01', '01649', '0895558', '北海道', 'ホッカイドウ', '十勝郡浦幌町', 'トカチグンウラホロチョウ', '昆布刈石', 'コブカリイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道十勝郡浦幌町', '01', '01649', '0895600', '北海道', 'ホッカイドウ', '十勝郡浦幌町', 'トカチグンウラホロチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('118147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道十勝郡浦幌町宝町', '01', '01649', '0895601', '北海道', 'ホッカイドウ', '十勝郡浦幌町', 'トカチグンウラホロチョウ', '宝町', 'タカラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道十勝郡浦幌町末広町', '01', '01649', '0895602', '北海道', 'ホッカイドウ', '十勝郡浦幌町', 'トカチグンウラホロチョウ', '末広町', 'スエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道十勝郡浦幌町本町', '01', '01649', '0895603', '北海道', 'ホッカイドウ', '十勝郡浦幌町', 'トカチグンウラホロチョウ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道十勝郡浦幌町栄町', '01', '01649', '0895604', '北海道', 'ホッカイドウ', '十勝郡浦幌町', 'トカチグンウラホロチョウ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道十勝郡浦幌町緑町', '01', '01649', '0895605', '北海道', 'ホッカイドウ', '十勝郡浦幌町', 'トカチグンウラホロチョウ', '緑町', 'ミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道十勝郡浦幌町住吉町', '01', '01649', '0895606', '北海道', 'ホッカイドウ', '十勝郡浦幌町', 'トカチグンウラホロチョウ', '住吉町', 'スミヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道十勝郡浦幌町材木町', '01', '01649', '0895607', '北海道', 'ホッカイドウ', '十勝郡浦幌町', 'トカチグンウラホロチョウ', '材木町', 'ザイモクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道十勝郡浦幌町西町', '01', '01649', '0895608', '北海道', 'ホッカイドウ', '十勝郡浦幌町', 'トカチグンウラホロチョウ', '西町', 'ニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道十勝郡浦幌町寿町', '01', '01649', '0895611', '北海道', 'ホッカイドウ', '十勝郡浦幌町', 'トカチグンウラホロチョウ', '寿町', 'コトブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道十勝郡浦幌町東山町', '01', '01649', '0895612', '北海道', 'ホッカイドウ', '十勝郡浦幌町', 'トカチグンウラホロチョウ', '東山町', 'ヒガシヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道十勝郡浦幌町幸町', '01', '01649', '0895613', '北海道', 'ホッカイドウ', '十勝郡浦幌町', 'トカチグンウラホロチョウ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道十勝郡浦幌町桜町', '01', '01649', '0895614', '北海道', 'ホッカイドウ', '十勝郡浦幌町', 'トカチグンウラホロチョウ', '桜町', 'サクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道十勝郡浦幌町新町', '01', '01649', '0895615', '北海道', 'ホッカイドウ', '十勝郡浦幌町', 'トカチグンウラホロチョウ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道十勝郡浦幌町光南', '01', '01649', '0895617', '北海道', 'ホッカイドウ', '十勝郡浦幌町', 'トカチグンウラホロチョウ', '光南', 'コウナン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道十勝郡浦幌町南町', '01', '01649', '0895617', '北海道', 'ホッカイドウ', '十勝郡浦幌町', 'トカチグンウラホロチョウ', '南町', 'ミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道十勝郡浦幌町北町', '01', '01649', '0895621', '北海道', 'ホッカイドウ', '十勝郡浦幌町', 'トカチグンウラホロチョウ', '北町', 'キタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道十勝郡浦幌町北栄', '01', '01649', '0895622', '北海道', 'ホッカイドウ', '十勝郡浦幌町', 'トカチグンウラホロチョウ', '北栄', 'ホクエイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道十勝郡浦幌町瀬多来', '01', '01649', '0895631', '北海道', 'ホッカイドウ', '十勝郡浦幌町', 'トカチグンウラホロチョウ', '瀬多来', 'セタライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道十勝郡浦幌町留真', '01', '01649', '0895632', '北海道', 'ホッカイドウ', '十勝郡浦幌町', 'トカチグンウラホロチョウ', '留真', 'ルシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道十勝郡浦幌町常豊', '01', '01649', '0895633', '北海道', 'ホッカイドウ', '十勝郡浦幌町', 'トカチグンウラホロチョウ', '常豊', 'ツネトヨ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道十勝郡浦幌町常室', '01', '01649', '0895633', '北海道', 'ホッカイドウ', '十勝郡浦幌町', 'トカチグンウラホロチョウ', '常室', 'トコムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道十勝郡浦幌町福山', '01', '01649', '0895633', '北海道', 'ホッカイドウ', '十勝郡浦幌町', 'トカチグンウラホロチョウ', '福山', 'フクヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道十勝郡浦幌町円山', '01', '01649', '0895633', '北海道', 'ホッカイドウ', '十勝郡浦幌町', 'トカチグンウラホロチョウ', '円山', 'マルヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道十勝郡浦幌町帯富', '01', '01649', '0895634', '北海道', 'ホッカイドウ', '十勝郡浦幌町', 'トカチグンウラホロチョウ', '帯富', 'オビトミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道十勝郡浦幌町時和', '01', '01649', '0895634', '北海道', 'ホッカイドウ', '十勝郡浦幌町', 'トカチグンウラホロチョウ', '時和', 'トキワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道十勝郡浦幌町静内', '01', '01649', '0895635', '北海道', 'ホッカイドウ', '十勝郡浦幌町', 'トカチグンウラホロチョウ', '静内', 'シズナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道十勝郡浦幌町千歳町', '01', '01649', '0895636', '北海道', 'ホッカイドウ', '十勝郡浦幌町', 'トカチグンウラホロチョウ', '千歳町', 'チトセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道十勝郡浦幌町万年', '01', '01649', '0895636', '北海道', 'ホッカイドウ', '十勝郡浦幌町', 'トカチグンウラホロチョウ', '万年', 'マンネン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道十勝郡浦幌町稲穂', '01', '01649', '0895637', '北海道', 'ホッカイドウ', '十勝郡浦幌町', 'トカチグンウラホロチョウ', '稲穂', 'イナホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道十勝郡浦幌町幾栄', '01', '01649', '0895638', '北海道', 'ホッカイドウ', '十勝郡浦幌町', 'トカチグンウラホロチョウ', '幾栄', 'イクエイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道十勝郡浦幌町幾千世', '01', '01649', '0895638', '北海道', 'ホッカイドウ', '十勝郡浦幌町', 'トカチグンウラホロチョウ', '幾千世', 'イクチセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道十勝郡浦幌町厚内', '01', '01649', '0895865', '北海道', 'ホッカイドウ', '十勝郡浦幌町', 'トカチグンウラホロチョウ', '厚内', 'アツナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道十勝郡浦幌町上厚内', '01', '01649', '0895866', '北海道', 'ホッカイドウ', '十勝郡浦幌町', 'トカチグンウラホロチョウ', '上厚内', 'カミアツナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道十勝郡浦幌町オコッペ', '01', '01649', '0895867', '北海道', 'ホッカイドウ', '十勝郡浦幌町', 'トカチグンウラホロチョウ', 'オコッペ', 'オコッペ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道十勝郡浦幌町昆布刈石', '01', '01649', '0895868', '北海道', 'ホッカイドウ', '十勝郡浦幌町', 'トカチグンウラホロチョウ', '昆布刈石', 'コブカリイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道十勝郡浦幌町チプネオコッペ', '01', '01649', '0895869', '北海道', 'ホッカイドウ', '十勝郡浦幌町', 'トカチグンウラホロチョウ', 'チプネオコッペ', 'チプネオコッペ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県いちき串木野市', '46', '46219', '8960000', '鹿児島県', 'カゴシマケン', 'いちき串木野市', 'イチキクシキノシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('118200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県いちき串木野市曙町', '46', '46219', '8960001', '鹿児島県', 'カゴシマケン', 'いちき串木野市', 'イチキクシキノシ', '曙町', 'アケボノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県いちき串木野市春日町', '46', '46219', '8960002', '鹿児島県', 'カゴシマケン', 'いちき串木野市', 'イチキクシキノシ', '春日町', 'カスガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県いちき串木野市京町', '46', '46219', '8960003', '鹿児島県', 'カゴシマケン', 'いちき串木野市', 'イチキクシキノシ', '京町', 'キョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県いちき串木野市汐見町', '46', '46219', '8960004', '鹿児島県', 'カゴシマケン', 'いちき串木野市', 'イチキクシキノシ', '汐見町', 'シオミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県いちき串木野市西塩田町', '46', '46219', '8960005', '鹿児島県', 'カゴシマケン', 'いちき串木野市', 'イチキクシキノシ', '西塩田町', 'ニシエンデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県いちき串木野市東塩田町', '46', '46219', '8960006', '鹿児島県', 'カゴシマケン', 'いちき串木野市', 'イチキクシキノシ', '東塩田町', 'ヒガシエンデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県いちき串木野市大原町', '46', '46219', '8960011', '鹿児島県', 'カゴシマケン', 'いちき串木野市', 'イチキクシキノシ', '大原町', 'オオハルマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県いちき串木野市中尾町', '46', '46219', '8960012', '鹿児島県', 'カゴシマケン', 'いちき串木野市', 'イチキクシキノシ', '中尾町', 'ナカオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県いちき串木野市栄町', '46', '46219', '8960013', '鹿児島県', 'カゴシマケン', 'いちき串木野市', 'イチキクシキノシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県いちき串木野市元町', '46', '46219', '8960014', '鹿児島県', 'カゴシマケン', 'いちき串木野市', 'イチキクシキノシ', '元町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県いちき串木野市旭町', '46', '46219', '8960015', '鹿児島県', 'カゴシマケン', 'いちき串木野市', 'イチキクシキノシ', '旭町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県いちき串木野市桜町', '46', '46219', '8960016', '鹿児島県', 'カゴシマケン', 'いちき串木野市', 'イチキクシキノシ', '桜町', 'サクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県いちき串木野市高見町', '46', '46219', '8960017', '鹿児島県', 'カゴシマケン', 'いちき串木野市', 'イチキクシキノシ', '高見町', 'タカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県いちき串木野市住吉町', '46', '46219', '8960021', '鹿児島県', 'カゴシマケン', 'いちき串木野市', 'イチキクシキノシ', '住吉町', 'スミヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県いちき串木野市緑町', '46', '46219', '8960022', '鹿児島県', 'カゴシマケン', 'いちき串木野市', 'イチキクシキノシ', '緑町', 'ミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県いちき串木野市塩屋町', '46', '46219', '8960023', '鹿児島県', 'カゴシマケン', 'いちき串木野市', 'イチキクシキノシ', '塩屋町', 'シオヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県いちき串木野市美住町', '46', '46219', '8960024', '鹿児島県', 'カゴシマケン', 'いちき串木野市', 'イチキクシキノシ', '美住町', 'ミスミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県いちき串木野市御倉町', '46', '46219', '8960025', '鹿児島県', 'カゴシマケン', 'いちき串木野市', 'イチキクシキノシ', '御倉町', 'オクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県いちき串木野市昭和通', '46', '46219', '8960026', '鹿児島県', 'カゴシマケン', 'いちき串木野市', 'イチキクシキノシ', '昭和通', 'ショウワドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県いちき串木野市東島平町', '46', '46219', '8960031', '鹿児島県', 'カゴシマケン', 'いちき串木野市', 'イチキクシキノシ', '東島平町', 'ヒガシシマビラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県いちき串木野市西島平町', '46', '46219', '8960032', '鹿児島県', 'カゴシマケン', 'いちき串木野市', 'イチキクシキノシ', '西島平町', 'ニシシマビラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県いちき串木野市長崎町', '46', '46219', '8960033', '鹿児島県', 'カゴシマケン', 'いちき串木野市', 'イチキクシキノシ', '長崎町', 'ナガサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県いちき串木野市小瀬町', '46', '46219', '8960034', '鹿児島県', 'カゴシマケン', 'いちき串木野市', 'イチキクシキノシ', '小瀬町', 'コゼチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県いちき串木野市新生町', '46', '46219', '8960035', '鹿児島県', 'カゴシマケン', 'いちき串木野市', 'イチキクシキノシ', '新生町', 'シンセイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県いちき串木野市浦和町', '46', '46219', '8960036', '鹿児島県', 'カゴシマケン', 'いちき串木野市', 'イチキクシキノシ', '浦和町', 'ウラワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県いちき串木野市北浜町', '46', '46219', '8960041', '鹿児島県', 'カゴシマケン', 'いちき串木野市', 'イチキクシキノシ', '北浜町', 'キタハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県いちき串木野市本浜町', '46', '46219', '8960042', '鹿児島県', 'カゴシマケン', 'いちき串木野市', 'イチキクシキノシ', '本浜町', 'モトハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県いちき串木野市港町', '46', '46219', '8960043', '鹿児島県', 'カゴシマケン', 'いちき串木野市', 'イチキクシキノシ', '港町', 'ミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県いちき串木野市西浜町', '46', '46219', '8960044', '鹿児島県', 'カゴシマケン', 'いちき串木野市', 'イチキクシキノシ', '西浜町', 'ニシハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県いちき串木野市まぐろ本町', '46', '46219', '8960045', '鹿児島県', 'カゴシマケン', 'いちき串木野市', 'イチキクシキノシ', 'まぐろ本町', 'マグロホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県いちき串木野市西薩町', '46', '46219', '8960046', '鹿児島県', 'カゴシマケン', 'いちき串木野市', 'イチキクシキノシ', '西薩町', 'セイサツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県いちき串木野市冠嶽', '46', '46219', '8960051', '鹿児島県', 'カゴシマケン', 'いちき串木野市', 'イチキクシキノシ', '冠嶽', 'カンムリダケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県いちき串木野市上名', '46', '46219', '8960052', '鹿児島県', 'カゴシマケン', 'いちき串木野市', 'イチキクシキノシ', '上名', 'カンミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県いちき串木野市下名', '46', '46219', '8960053', '鹿児島県', 'カゴシマケン', 'いちき串木野市', 'イチキクシキノシ', '下名', 'シモンミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県いちき串木野市日出町', '46', '46219', '8960054', '鹿児島県', 'カゴシマケン', 'いちき串木野市', 'イチキクシキノシ', '日出町', 'ヒノデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県いちき串木野市愛木町', '46', '46219', '8960061', '鹿児島県', 'カゴシマケン', 'いちき串木野市', 'イチキクシキノシ', '愛木町', 'アイギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県いちき串木野市浜田町', '46', '46219', '8960062', '鹿児島県', 'カゴシマケン', 'いちき串木野市', 'イチキクシキノシ', '浜田町', 'ハマダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県いちき串木野市口之町', '46', '46219', '8960063', '鹿児島県', 'カゴシマケン', 'いちき串木野市', 'イチキクシキノシ', '口之町', 'クチノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県いちき串木野市羽島', '46', '46219', '8960064', '鹿児島県', 'カゴシマケン', 'いちき串木野市', 'イチキクシキノシ', '羽島', 'ハシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県いちき串木野市荒川', '46', '46219', '8960065', '鹿児島県', 'カゴシマケン', 'いちき串木野市', 'イチキクシキノシ', '荒川', 'アラカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩川内市里町里', '46', '46215', '8961101', '鹿児島県', 'カゴシマケン', '薩摩川内市', 'サツマセンダイシ', '里町里', 'サトチョウサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩川内市上甑町中甑', '46', '46215', '8961201', '鹿児島県', 'カゴシマケン', '薩摩川内市', 'サツマセンダイシ', '上甑町中甑', 'カミコシキチョウナカコシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩川内市上甑町中野', '46', '46215', '8961202', '鹿児島県', 'カゴシマケン', '薩摩川内市', 'サツマセンダイシ', '上甑町中野', 'カミコシキチョウナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩川内市上甑町江石', '46', '46215', '8961203', '鹿児島県', 'カゴシマケン', '薩摩川内市', 'サツマセンダイシ', '上甑町江石', 'カミコシキチョウエイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩川内市上甑町小島', '46', '46215', '8961204', '鹿児島県', 'カゴシマケン', '薩摩川内市', 'サツマセンダイシ', '上甑町小島', 'カミコシキチョウオシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩川内市上甑町瀬上', '46', '46215', '8961205', '鹿児島県', 'カゴシマケン', '薩摩川内市', 'サツマセンダイシ', '上甑町瀬上', 'カミコシキチョウセガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩川内市上甑町桑之浦', '46', '46215', '8961206', '鹿児島県', 'カゴシマケン', '薩摩川内市', 'サツマセンダイシ', '上甑町桑之浦', 'カミコシキチョウクワノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩川内市上甑町平良', '46', '46215', '8961281', '鹿児島県', 'カゴシマケン', '薩摩川内市', 'サツマセンダイシ', '上甑町平良', 'カミコシキチョウタイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩川内市鹿島町藺牟田', '46', '46215', '8961301', '鹿児島県', 'カゴシマケン', '薩摩川内市', 'サツマセンダイシ', '鹿島町藺牟田', 'カシマチョウイムタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩川内市下甑町長浜', '46', '46215', '8961411', '鹿児島県', 'カゴシマケン', '薩摩川内市', 'サツマセンダイシ', '下甑町長浜', 'シモコシキチョウナガハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩川内市下甑町瀬々野浦', '46', '46215', '8961412', '鹿児島県', 'カゴシマケン', '薩摩川内市', 'サツマセンダイシ', '下甑町瀬々野浦', 'シモコシキチョウセセノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩川内市下甑町瀬々野浦内川内', '46', '46215', '8961412', '鹿児島県', 'カゴシマケン', '薩摩川内市', 'サツマセンダイシ', '下甑町瀬々野浦', 'シモコシキチョウセセノウラ', null, null, '内川内', 'ウチカワウチ');
INSERT INTO `ms_addresses` VALUES ('118254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩川内市下甑町瀬々野浦', '46', '46215', '8961512', '鹿児島県', 'カゴシマケン', '薩摩川内市', 'サツマセンダイシ', '下甑町瀬々野浦', 'シモコシキチョウセセノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩川内市下甑町青瀬', '46', '46215', '8961521', '鹿児島県', 'カゴシマケン', '薩摩川内市', 'サツマセンダイシ', '下甑町青瀬', 'シモコシキチョウアオセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩川内市下甑町手打', '46', '46215', '8961601', '鹿児島県', 'カゴシマケン', '薩摩川内市', 'サツマセンダイシ', '下甑町手打', 'シモコシキチョウテウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩川内市下甑町片野浦', '46', '46215', '8961602', '鹿児島県', 'カゴシマケン', '薩摩川内市', 'サツマセンダイシ', '下甑町片野浦', 'シモコシキチョウカタノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県南さつま市', '46', '46220', '8970000', '鹿児島県', 'カゴシマケン', '南さつま市', 'ミナミサツマシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('118262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県南さつま市加世田村原', '46', '46220', '8970001', '鹿児島県', 'カゴシマケン', '南さつま市', 'ミナミサツマシ', '加世田村原', 'カセダムラハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県南さつま市加世田武田', '46', '46220', '8970002', '鹿児島県', 'カゴシマケン', '南さつま市', 'ミナミサツマシ', '加世田武田', 'カセダタケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県南さつま市加世田川畑', '46', '46220', '8970003', '鹿児島県', 'カゴシマケン', '南さつま市', 'ミナミサツマシ', '加世田川畑', 'カセダカワバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県南さつま市加世田内山田', '46', '46220', '8970004', '鹿児島県', 'カゴシマケン', '南さつま市', 'ミナミサツマシ', '加世田内山田', 'カセダウチヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県南さつま市加世田麓町', '46', '46220', '8970005', '鹿児島県', 'カゴシマケン', '南さつま市', 'ミナミサツマシ', '加世田麓町', 'カセダフモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県南さつま市加世田本町', '46', '46220', '8970006', '鹿児島県', 'カゴシマケン', '南さつま市', 'ミナミサツマシ', '加世田本町', 'カセダホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県南さつま市加世田白亀', '46', '46220', '8970007', '鹿児島県', 'カゴシマケン', '南さつま市', 'ミナミサツマシ', '加世田白亀', 'カセダシラカメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県南さつま市加世田地頭所', '46', '46220', '8970008', '鹿児島県', 'カゴシマケン', '南さつま市', 'ミナミサツマシ', '加世田地頭所', 'カセダジトウショ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県南さつま市加世田ハーモニー', '46', '46220', '8970009', '鹿児島県', 'カゴシマケン', '南さつま市', 'ミナミサツマシ', '加世田ハーモニー', 'カセダハーモニー', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県南さつま市加世田東本町', '46', '46220', '8970031', '鹿児島県', 'カゴシマケン', '南さつま市', 'ミナミサツマシ', '加世田東本町', 'カセダヒガシホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県南九州市川辺町上山田', '46', '46223', '8970131', '鹿児島県', 'カゴシマケン', '南九州市', 'ミナミキュウシュウシ', '川辺町上山田', 'カワナベチョウカミヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県南九州市川辺町中山田', '46', '46223', '8970132', '鹿児島県', 'カゴシマケン', '南九州市', 'ミナミキュウシュウシ', '川辺町中山田', 'カワナベチョウナカヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県南九州市川辺町下山田', '46', '46223', '8970133', '鹿児島県', 'カゴシマケン', '南九州市', 'ミナミキュウシュウシ', '川辺町下山田', 'カワナベチョウシモヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県南九州市', '46', '46223', '8970200', '鹿児島県', 'カゴシマケン', '南九州市', 'ミナミキュウシュウシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('118276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県南九州市川辺町神殿', '46', '46223', '8970201', '鹿児島県', 'カゴシマケン', '南九州市', 'ミナミキュウシュウシ', '川辺町神殿', 'カワナベチョウコウドノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県南九州市川辺町清水', '46', '46223', '8970202', '鹿児島県', 'カゴシマケン', '南九州市', 'ミナミキュウシュウシ', '川辺町清水', 'カワナベチョウキヨミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県南九州市川辺町野崎', '46', '46223', '8970203', '鹿児島県', 'カゴシマケン', '南九州市', 'ミナミキュウシュウシ', '川辺町野崎', 'カワナベチョウノサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県南九州市川辺町古殿', '46', '46223', '8970204', '鹿児島県', 'カゴシマケン', '南九州市', 'ミナミキュウシュウシ', '川辺町古殿', 'カワナベチョウフルトノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県南九州市川辺町野間', '46', '46223', '8970205', '鹿児島県', 'カゴシマケン', '南九州市', 'ミナミキュウシュウシ', '川辺町野間', 'カワナベチョウノマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県南九州市川辺町両添', '46', '46223', '8970211', '鹿児島県', 'カゴシマケン', '南九州市', 'ミナミキュウシュウシ', '川辺町両添', 'カワナベチョウリョウゾエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県南九州市川辺町今田', '46', '46223', '8970212', '鹿児島県', 'カゴシマケン', '南九州市', 'ミナミキュウシュウシ', '川辺町今田', 'カワナベチョウイマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県南九州市川辺町小野', '46', '46223', '8970213', '鹿児島県', 'カゴシマケン', '南九州市', 'ミナミキュウシュウシ', '川辺町小野', 'カワナベチョウオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県南九州市川辺町宮', '46', '46223', '8970214', '鹿児島県', 'カゴシマケン', '南九州市', 'ミナミキュウシュウシ', '川辺町宮', 'カワナベチョウミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県南九州市川辺町平山', '46', '46223', '8970215', '鹿児島県', 'カゴシマケン', '南九州市', 'ミナミキュウシュウシ', '川辺町平山', 'カワナベチョウヒラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県南九州市川辺町田部田', '46', '46223', '8970221', '鹿児島県', 'カゴシマケン', '南九州市', 'ミナミキュウシュウシ', '川辺町田部田', 'カワナベチョウタベタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県南九州市川辺町永田', '46', '46223', '8970222', '鹿児島県', 'カゴシマケン', '南九州市', 'ミナミキュウシュウシ', '川辺町永田', 'カワナベチョウナガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県南九州市川辺町高田', '46', '46223', '8970223', '鹿児島県', 'カゴシマケン', '南九州市', 'ミナミキュウシュウシ', '川辺町高田', 'カワナベチョウタカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県南九州市川辺町本別府', '46', '46223', '8970224', '鹿児島県', 'カゴシマケン', '南九州市', 'ミナミキュウシュウシ', '川辺町本別府', 'カワナベチョウモトベップ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県南九州市知覧町厚地', '46', '46223', '8970301', '鹿児島県', 'カゴシマケン', '南九州市', 'ミナミキュウシュウシ', '知覧町厚地', 'チランチョウアツチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県南九州市知覧町郡', '46', '46223', '8970302', '鹿児島県', 'カゴシマケン', '南九州市', 'ミナミキュウシュウシ', '知覧町郡', 'チランチョウコオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県南九州市知覧町永里', '46', '46223', '8970303', '鹿児島県', 'カゴシマケン', '南九州市', 'ミナミキュウシュウシ', '知覧町永里', 'チランチョウナガサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県南九州市知覧町東別府', '46', '46223', '8970304', '鹿児島県', 'カゴシマケン', '南九州市', 'ミナミキュウシュウシ', '知覧町東別府', 'チランチョウヒガシベップ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県南九州市知覧町瀬世', '46', '46223', '8970305', '鹿児島県', 'カゴシマケン', '南九州市', 'ミナミキュウシュウシ', '知覧町瀬世', 'チランチョウセセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県南九州市知覧町西元', '46', '46223', '8970306', '鹿児島県', 'カゴシマケン', '南九州市', 'ミナミキュウシュウシ', '知覧町西元', 'チランチョウニシモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県南さつま市加世田唐仁原', '46', '46220', '8971121', '鹿児島県', 'カゴシマケン', '南さつま市', 'ミナミサツマシ', '加世田唐仁原', 'カセダトウジンバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県南さつま市加世田小湊', '46', '46220', '8971122', '鹿児島県', 'カゴシマケン', '南さつま市', 'ミナミサツマシ', '加世田小湊', 'カセダコミナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県南さつま市加世田高橋', '46', '46220', '8971123', '鹿児島県', 'カゴシマケン', '南さつま市', 'ミナミサツマシ', '加世田高橋', 'カセダタカハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県南さつま市加世田宮原', '46', '46220', '8971124', '鹿児島県', 'カゴシマケン', '南さつま市', 'ミナミサツマシ', '加世田宮原', 'カセダミヤバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県南さつま市加世田益山', '46', '46220', '8971125', '鹿児島県', 'カゴシマケン', '南さつま市', 'ミナミサツマシ', '加世田益山', 'カセダマスヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県南さつま市大浦町', '46', '46220', '8971201', '鹿児島県', 'カゴシマケン', '南さつま市', 'ミナミサツマシ', '大浦町', 'オオウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県南さつま市笠沙町片浦', '46', '46220', '8971301', '鹿児島県', 'カゴシマケン', '南さつま市', 'ミナミサツマシ', '笠沙町片浦', 'カササチョウカタウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県南さつま市笠沙町赤生木', '46', '46220', '8971302', '鹿児島県', 'カゴシマケン', '南さつま市', 'ミナミサツマシ', '笠沙町赤生木', 'カササチョウアコウギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県枕崎市', '46', '46204', '8980000', '鹿児島県', 'カゴシマケン', '枕崎市', 'マクラザキシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('118308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県枕崎市松之尾町', '46', '46204', '8980001', '鹿児島県', 'カゴシマケン', '枕崎市', 'マクラザキシ', '松之尾町', 'マツノオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県枕崎市汐見町', '46', '46204', '8980002', '鹿児島県', 'カゴシマケン', '枕崎市', 'マクラザキシ', '汐見町', 'シオミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県枕崎市折口町', '46', '46204', '8980003', '鹿児島県', 'カゴシマケン', '枕崎市', 'マクラザキシ', '折口町', 'オリグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県枕崎市港町', '46', '46204', '8980004', '鹿児島県', 'カゴシマケン', '枕崎市', 'マクラザキシ', '港町', 'ミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県枕崎市中町', '46', '46204', '8980005', '鹿児島県', 'カゴシマケン', '枕崎市', 'マクラザキシ', '中町', 'ナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県枕崎市泉町', '46', '46204', '8980006', '鹿児島県', 'カゴシマケン', '枕崎市', 'マクラザキシ', '泉町', 'イズミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県枕崎市新町', '46', '46204', '8980007', '鹿児島県', 'カゴシマケン', '枕崎市', 'マクラザキシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県枕崎市旭町', '46', '46204', '8980008', '鹿児島県', 'カゴシマケン', '枕崎市', 'マクラザキシ', '旭町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県枕崎市恵比須町', '46', '46204', '8980009', '鹿児島県', 'カゴシマケン', '枕崎市', 'マクラザキシ', '恵比須町', 'エビスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県枕崎市緑町', '46', '46204', '8980011', '鹿児島県', 'カゴシマケン', '枕崎市', 'マクラザキシ', '緑町', 'ミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県枕崎市千代田町', '46', '46204', '8980012', '鹿児島県', 'カゴシマケン', '枕崎市', 'マクラザキシ', '千代田町', 'チヨダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県枕崎市山手町', '46', '46204', '8980013', '鹿児島県', 'カゴシマケン', '枕崎市', 'マクラザキシ', '山手町', 'ヤマテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県枕崎市東本町', '46', '46204', '8980014', '鹿児島県', 'カゴシマケン', '枕崎市', 'マクラザキシ', '東本町', 'ヒガシホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県枕崎市西本町', '46', '46204', '8980015', '鹿児島県', 'カゴシマケン', '枕崎市', 'マクラザキシ', '西本町', 'ニシホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県枕崎市高見町', '46', '46204', '8980016', '鹿児島県', 'カゴシマケン', '枕崎市', 'マクラザキシ', '高見町', 'タカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県枕崎市住吉町', '46', '46204', '8980017', '鹿児島県', 'カゴシマケン', '枕崎市', 'マクラザキシ', '住吉町', 'スミヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県枕崎市桜木町', '46', '46204', '8980018', '鹿児島県', 'カゴシマケン', '枕崎市', 'マクラザキシ', '桜木町', 'サクラギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県枕崎市東鹿篭', '46', '46204', '8980021', '鹿児島県', 'カゴシマケン', '枕崎市', 'マクラザキシ', '東鹿篭', 'ヒガシカゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県枕崎市宮田町', '46', '46204', '8980022', '鹿児島県', 'カゴシマケン', '枕崎市', 'マクラザキシ', '宮田町', 'ミヤタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県枕崎市若葉町', '46', '46204', '8980023', '鹿児島県', 'カゴシマケン', '枕崎市', 'マクラザキシ', '若葉町', 'ワカバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県枕崎市西鹿篭', '46', '46204', '8980024', '鹿児島県', 'カゴシマケン', '枕崎市', 'マクラザキシ', '西鹿篭', 'ニシカゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県枕崎市立神本町', '46', '46204', '8980025', '鹿児島県', 'カゴシマケン', '枕崎市', 'マクラザキシ', '立神本町', 'タチガミホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県枕崎市大塚北町', '46', '46204', '8980026', '鹿児島県', 'カゴシマケン', '枕崎市', 'マクラザキシ', '大塚北町', 'オオツカキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県枕崎市大塚西町', '46', '46204', '8980027', '鹿児島県', 'カゴシマケン', '枕崎市', 'マクラザキシ', '大塚西町', 'オオツカニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県枕崎市大塚中町', '46', '46204', '8980028', '鹿児島県', 'カゴシマケン', '枕崎市', 'マクラザキシ', '大塚中町', 'オオツカナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県枕崎市大塚南町', '46', '46204', '8980029', '鹿児島県', 'カゴシマケン', '枕崎市', 'マクラザキシ', '大塚南町', 'オオツカミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県枕崎市枕崎', '46', '46204', '8980031', '鹿児島県', 'カゴシマケン', '枕崎市', 'マクラザキシ', '枕崎', 'マクラザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県枕崎市別府', '46', '46204', '8980032', '鹿児島県', 'カゴシマケン', '枕崎市', 'マクラザキシ', '別府', 'ベップ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県枕崎市宮前町', '46', '46204', '8980033', '鹿児島県', 'カゴシマケン', '枕崎市', 'マクラザキシ', '宮前町', 'ミヤマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県枕崎市日之出町', '46', '46204', '8980034', '鹿児島県', 'カゴシマケン', '枕崎市', 'マクラザキシ', '日之出町', 'ヒノデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県枕崎市平田町', '46', '46204', '8980035', '鹿児島県', 'カゴシマケン', '枕崎市', 'マクラザキシ', '平田町', 'ヒラタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県枕崎市明和町', '46', '46204', '8980036', '鹿児島県', 'カゴシマケン', '枕崎市', 'マクラザキシ', '明和町', 'メイワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県枕崎市栄本町', '46', '46204', '8980037', '鹿児島県', 'カゴシマケン', '枕崎市', 'マクラザキシ', '栄本町', 'サカエホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県枕崎市栄中町', '46', '46204', '8980038', '鹿児島県', 'カゴシマケン', '枕崎市', 'マクラザキシ', '栄中町', 'サカエナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県枕崎市塩屋北町', '46', '46204', '8980041', '鹿児島県', 'カゴシマケン', '枕崎市', 'マクラザキシ', '塩屋北町', 'シオヤキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県枕崎市塩屋南町', '46', '46204', '8980042', '鹿児島県', 'カゴシマケン', '枕崎市', 'マクラザキシ', '塩屋南町', 'シオヤミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県枕崎市火之神北町', '46', '46204', '8980043', '鹿児島県', 'カゴシマケン', '枕崎市', 'マクラザキシ', '火之神北町', 'ヒノカミキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県枕崎市春日町', '46', '46204', '8980044', '鹿児島県', 'カゴシマケン', '枕崎市', 'マクラザキシ', '春日町', 'カスガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県枕崎市立神北町', '46', '46204', '8980045', '鹿児島県', 'カゴシマケン', '枕崎市', 'マクラザキシ', '立神北町', 'タテガミキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県枕崎市園見本町', '46', '46204', '8980046', '鹿児島県', 'カゴシマケン', '枕崎市', 'マクラザキシ', '園見本町', 'ソノミホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県枕崎市園見西町', '46', '46204', '8980047', '鹿児島県', 'カゴシマケン', '枕崎市', 'マクラザキシ', '園見西町', 'ソノミニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県枕崎市火之神町', '46', '46204', '8980048', '鹿児島県', 'カゴシマケン', '枕崎市', 'マクラザキシ', '火之神町', 'ヒノカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県枕崎市火之神岬町', '46', '46204', '8980049', '鹿児島県', 'カゴシマケン', '枕崎市', 'マクラザキシ', '火之神岬町', 'ヒノカミミサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県枕崎市中央町', '46', '46204', '8980051', '鹿児島県', 'カゴシマケン', '枕崎市', 'マクラザキシ', '中央町', 'チュウオウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県枕崎市岩崎町', '46', '46204', '8980052', '鹿児島県', 'カゴシマケン', '枕崎市', 'マクラザキシ', '岩崎町', 'イワサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県枕崎市木場町', '46', '46204', '8980053', '鹿児島県', 'カゴシマケン', '枕崎市', 'マクラザキシ', '木場町', 'コバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県枕崎市鹿篭麓町', '46', '46204', '8980054', '鹿児島県', 'カゴシマケン', '枕崎市', 'マクラザキシ', '鹿篭麓町', 'カゴフモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県枕崎市桜山西町', '46', '46204', '8980055', '鹿児島県', 'カゴシマケン', '枕崎市', 'マクラザキシ', '桜山西町', 'サクラヤマニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県枕崎市美原町', '46', '46204', '8980056', '鹿児島県', 'カゴシマケン', '枕崎市', 'マクラザキシ', '美原町', 'ミハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県枕崎市木原町', '46', '46204', '8980057', '鹿児島県', 'カゴシマケン', '枕崎市', 'マクラザキシ', '木原町', 'キハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県枕崎市岩戸町', '46', '46204', '8980058', '鹿児島県', 'カゴシマケン', '枕崎市', 'マクラザキシ', '岩戸町', 'イワドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県枕崎市桜山町', '46', '46204', '8980061', '鹿児島県', 'カゴシマケン', '枕崎市', 'マクラザキシ', '桜山町', 'サクラヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県枕崎市寿町', '46', '46204', '8980062', '鹿児島県', 'カゴシマケン', '枕崎市', 'マクラザキシ', '寿町', 'コトブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県枕崎市妙見町', '46', '46204', '8980063', '鹿児島県', 'カゴシマケン', '枕崎市', 'マクラザキシ', '妙見町', 'ミョウケンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県枕崎市桜山本町', '46', '46204', '8980064', '鹿児島県', 'カゴシマケン', '枕崎市', 'マクラザキシ', '桜山本町', 'サクラヤマホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県枕崎市桜山東町', '46', '46204', '8980065', '鹿児島県', 'カゴシマケン', '枕崎市', 'マクラザキシ', '桜山東町', 'サクラヤマヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県枕崎市清水町', '46', '46204', '8980066', '鹿児島県', 'カゴシマケン', '枕崎市', 'マクラザキシ', '清水町', 'キヨミズマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県枕崎市美山町', '46', '46204', '8980071', '鹿児島県', 'カゴシマケン', '枕崎市', 'マクラザキシ', '美山町', 'ミヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県枕崎市道野町', '46', '46204', '8980072', '鹿児島県', 'カゴシマケン', '枕崎市', 'マクラザキシ', '道野町', 'ミチノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県枕崎市桜山上町', '46', '46204', '8980073', '鹿児島県', 'カゴシマケン', '枕崎市', 'マクラザキシ', '桜山上町', 'サクラヤマカミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県枕崎市金山西町', '46', '46204', '8980074', '鹿児島県', 'カゴシマケン', '枕崎市', 'マクラザキシ', '金山西町', 'キンザンニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県枕崎市田布川町', '46', '46204', '8980075', '鹿児島県', 'カゴシマケン', '枕崎市', 'マクラザキシ', '田布川町', 'タブガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県枕崎市金山町', '46', '46204', '8980076', '鹿児島県', 'カゴシマケン', '枕崎市', 'マクラザキシ', '金山町', 'キンザンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県枕崎市あけぼの町', '46', '46204', '8980080', '鹿児島県', 'カゴシマケン', '枕崎市', 'マクラザキシ', 'あけぼの町', 'アケボノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県枕崎市豊留町', '46', '46204', '8980081', '鹿児島県', 'カゴシマケン', '枕崎市', 'マクラザキシ', '豊留町', 'トヨトメマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県枕崎市板敷本町', '46', '46204', '8980082', '鹿児島県', 'カゴシマケン', '枕崎市', 'マクラザキシ', '板敷本町', 'イタシキホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県枕崎市板敷南町', '46', '46204', '8980083', '鹿児島県', 'カゴシマケン', '枕崎市', 'マクラザキシ', '板敷南町', 'イタシキミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県枕崎市板敷西町', '46', '46204', '8980084', '鹿児島県', 'カゴシマケン', '枕崎市', 'マクラザキシ', '板敷西町', 'イタシキニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県枕崎市別府東町', '46', '46204', '8980085', '鹿児島県', 'カゴシマケン', '枕崎市', 'マクラザキシ', '別府東町', 'ベップヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県枕崎市別府西町', '46', '46204', '8980086', '鹿児島県', 'カゴシマケン', '枕崎市', 'マクラザキシ', '別府西町', 'ベップニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県枕崎市瀬戸町', '46', '46204', '8980087', '鹿児島県', 'カゴシマケン', '枕崎市', 'マクラザキシ', '瀬戸町', 'セトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県枕崎市国見町', '46', '46204', '8980088', '鹿児島県', 'カゴシマケン', '枕崎市', 'マクラザキシ', '国見町', 'クニミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県枕崎市白沢北町', '46', '46204', '8980089', '鹿児島県', 'カゴシマケン', '枕崎市', 'マクラザキシ', '白沢北町', 'シラサワキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県枕崎市白沢東町', '46', '46204', '8980091', '鹿児島県', 'カゴシマケン', '枕崎市', 'マクラザキシ', '白沢東町', 'シラサワヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県枕崎市白沢西町', '46', '46204', '8980092', '鹿児島県', 'カゴシマケン', '枕崎市', 'マクラザキシ', '白沢西町', 'シラサワニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県枕崎市仁田浦町', '46', '46204', '8980093', '鹿児島県', 'カゴシマケン', '枕崎市', 'マクラザキシ', '仁田浦町', 'ニタウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県枕崎市駒水町', '46', '46204', '8980094', '鹿児島県', 'カゴシマケン', '枕崎市', 'マクラザキシ', '駒水町', 'コマミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県枕崎市下松町', '46', '46204', '8980095', '鹿児島県', 'カゴシマケン', '枕崎市', 'マクラザキシ', '下松町', 'シモマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県枕崎市まかや町', '46', '46204', '8980096', '鹿児島県', 'カゴシマケン', '枕崎市', 'マクラザキシ', 'まかや町', 'マカヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県枕崎市里町', '46', '46204', '8980097', '鹿児島県', 'カゴシマケン', '枕崎市', 'マクラザキシ', '里町', 'サトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県枕崎市茅野町', '46', '46204', '8980098', '鹿児島県', 'カゴシマケン', '枕崎市', 'マクラザキシ', '茅野町', 'カヤノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県枕崎市小塚町', '46', '46204', '8980099', '鹿児島県', 'カゴシマケン', '枕崎市', 'マクラザキシ', '小塚町', 'コツカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県南さつま市坊津町坊', '46', '46220', '8980101', '鹿児島県', 'カゴシマケン', '南さつま市', 'ミナミサツマシ', '坊津町坊', 'ボウノツチョウボウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県南さつま市坊津町泊', '46', '46220', '8980102', '鹿児島県', 'カゴシマケン', '南さつま市', 'ミナミサツマシ', '坊津町泊', 'ボウノツチョウトマリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県南さつま市坊津町久志', '46', '46220', '8980211', '鹿児島県', 'カゴシマケン', '南さつま市', 'ミナミサツマシ', '坊津町久志', 'ボウノツチョウクシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県南さつま市坊津町秋目', '46', '46220', '8980212', '鹿児島県', 'カゴシマケン', '南さつま市', 'ミナミサツマシ', '坊津町秋目', 'ボウノツチョウアキメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県南さつま市大浦町', '46', '46220', '8980221', '鹿児島県', 'カゴシマケン', '南さつま市', 'ミナミサツマシ', '大浦町', 'オオウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県出水市米ノ津町', '46', '46208', '8990121', '鹿児島県', 'カゴシマケン', '出水市', 'イズミシ', '米ノ津町', 'コメノツマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県出水市境町', '46', '46208', '8990122', '鹿児島県', 'カゴシマケン', '出水市', 'イズミシ', '境町', 'サカイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県出水市下鯖町', '46', '46208', '8990123', '鹿児島県', 'カゴシマケン', '出水市', 'イズミシ', '下鯖町', 'シモサバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県出水市美原町', '46', '46208', '8990124', '鹿児島県', 'カゴシマケン', '出水市', 'イズミシ', '美原町', 'ミハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県出水市黄金町', '46', '46208', '8990125', '鹿児島県', 'カゴシマケン', '出水市', 'イズミシ', '黄金町', 'コガネマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県出水市六月田町', '46', '46208', '8990126', '鹿児島県', 'カゴシマケン', '出水市', 'イズミシ', '六月田町', 'ロクガツダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県出水市明神町', '46', '46208', '8990131', '鹿児島県', 'カゴシマケン', '出水市', 'イズミシ', '明神町', 'ミョウジンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県出水市下知識町', '46', '46208', '8990132', '鹿児島県', 'カゴシマケン', '出水市', 'イズミシ', '下知識町', 'シモチシキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県出水市福ノ江町', '46', '46208', '8990133', '鹿児島県', 'カゴシマケン', '出水市', 'イズミシ', '福ノ江町', 'フクノエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県出水市浦田町', '46', '46208', '8990134', '鹿児島県', 'カゴシマケン', '出水市', 'イズミシ', '浦田町', 'ウラタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県出水市汐見町', '46', '46208', '8990136', '鹿児島県', 'カゴシマケン', '出水市', 'イズミシ', '汐見町', 'シオミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県出水市今釜町', '46', '46208', '8990137', '鹿児島県', 'カゴシマケン', '出水市', 'イズミシ', '今釜町', 'イマガマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県出水市住吉町', '46', '46208', '8990138', '鹿児島県', 'カゴシマケン', '出水市', 'イズミシ', '住吉町', 'スミヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県出水市', '46', '46208', '8990200', '鹿児島県', 'カゴシマケン', '出水市', 'イズミシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('118410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県出水市緑町', '46', '46208', '8990201', '鹿児島県', 'カゴシマケン', '出水市', 'イズミシ', '緑町', 'ミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県出水市昭和町', '46', '46208', '8990202', '鹿児島県', 'カゴシマケン', '出水市', 'イズミシ', '昭和町', 'ショウワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県出水市上鯖渕', '46', '46208', '8990203', '鹿児島県', 'カゴシマケン', '出水市', 'イズミシ', '上鯖渕', 'カミサバブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県出水市麓町', '46', '46208', '8990204', '鹿児島県', 'カゴシマケン', '出水市', 'イズミシ', '麓町', 'フモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県出水市本町', '46', '46208', '8990205', '鹿児島県', 'カゴシマケン', '出水市', 'イズミシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県出水市向江町', '46', '46208', '8990206', '鹿児島県', 'カゴシマケン', '出水市', 'イズミシ', '向江町', 'ムカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県出水市中央町', '46', '46208', '8990207', '鹿児島県', 'カゴシマケン', '出水市', 'イズミシ', '中央町', 'チュウオウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県出水市文化町', '46', '46208', '8990208', '鹿児島県', 'カゴシマケン', '出水市', 'イズミシ', '文化町', 'ブンカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県出水市知識町', '46', '46208', '8990211', '鹿児島県', 'カゴシマケン', '出水市', 'イズミシ', '知識町', 'チシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県出水市上知識町', '46', '46208', '8990212', '鹿児島県', 'カゴシマケン', '出水市', 'イズミシ', '上知識町', 'カミチシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県出水市西出水町', '46', '46208', '8990213', '鹿児島県', 'カゴシマケン', '出水市', 'イズミシ', '西出水町', 'ニシイズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県出水市五万石町', '46', '46208', '8990214', '鹿児島県', 'カゴシマケン', '出水市', 'イズミシ', '五万石町', 'ゴマンゴクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県出水市武本', '46', '46208', '8990215', '鹿児島県', 'カゴシマケン', '出水市', 'イズミシ', '武本', 'タケモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県出水市大野原町', '46', '46208', '8990216', '鹿児島県', 'カゴシマケン', '出水市', 'イズミシ', '大野原町', 'オオノハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県出水市平和町', '46', '46208', '8990217', '鹿児島県', 'カゴシマケン', '出水市', 'イズミシ', '平和町', 'ヘイワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県出水市上大川内', '46', '46208', '8990341', '鹿児島県', 'カゴシマケン', '出水市', 'イズミシ', '上大川内', 'カミオオカワウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県出水市下大川内', '46', '46208', '8990342', '鹿児島県', 'カゴシマケン', '出水市', 'イズミシ', '下大川内', 'シモオオカワウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県出水市高尾野町大久保', '46', '46208', '8990401', '鹿児島県', 'カゴシマケン', '出水市', 'イズミシ', '高尾野町大久保', 'タカオノマチオオクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県出水市高尾野町柴引', '46', '46208', '8990402', '鹿児島県', 'カゴシマケン', '出水市', 'イズミシ', '高尾野町柴引', 'タカオノマチシバヒキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県出水市高尾野町唐笠木', '46', '46208', '8990403', '鹿児島県', 'カゴシマケン', '出水市', 'イズミシ', '高尾野町唐笠木', 'タカオノマチカラガサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県出水市高尾野町下高尾野', '46', '46208', '8990404', '鹿児島県', 'カゴシマケン', '出水市', 'イズミシ', '高尾野町下高尾野', 'タカオノマチシモタカオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県出水市高尾野町下水流', '46', '46208', '8990405', '鹿児島県', 'カゴシマケン', '出水市', 'イズミシ', '高尾野町下水流', 'タカオノマチシモズル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県出水市高尾野町上水流', '46', '46208', '8990406', '鹿児島県', 'カゴシマケン', '出水市', 'イズミシ', '高尾野町上水流', 'タカオノマチカミズル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県出水市高尾野町江内', '46', '46208', '8990407', '鹿児島県', 'カゴシマケン', '出水市', 'イズミシ', '高尾野町江内', 'タカオノマチエウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県出水市荘', '46', '46208', '8990435', '鹿児島県', 'カゴシマケン', '出水市', 'イズミシ', '荘', 'ショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県出水市野田町上名', '46', '46208', '8990501', '鹿児島県', 'カゴシマケン', '出水市', 'イズミシ', '野田町上名', 'ノダチョウカミミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県出水市野田町下名', '46', '46208', '8990502', '鹿児島県', 'カゴシマケン', '出水市', 'イズミシ', '野田町下名', 'ノダチョウシモミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県阿久根市脇本', '46', '46206', '8991131', '鹿児島県', 'カゴシマケン', '阿久根市', 'アクネシ', '脇本', 'ワキモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県出水郡長島町山門野', '46', '46404', '8991211', '鹿児島県', 'カゴシマケン', '出水郡長島町', 'イズミグンナガシマチョウ', '山門野', 'ヤマドノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県出水郡長島町川床', '46', '46404', '8991212', '鹿児島県', 'カゴシマケン', '出水郡長島町', 'イズミグンナガシマチョウ', '川床', 'カワトコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県出水郡長島町蔵之元', '46', '46404', '8991301', '鹿児島県', 'カゴシマケン', '出水郡長島町', 'イズミグンナガシマチョウ', '蔵之元', 'クラノモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県出水郡長島町平尾', '46', '46404', '8991302', '鹿児島県', 'カゴシマケン', '出水郡長島町', 'イズミグンナガシマチョウ', '平尾', 'ヒラオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県出水郡長島町指江', '46', '46404', '8991303', '鹿児島県', 'カゴシマケン', '出水郡長島町', 'イズミグンナガシマチョウ', '指江', 'サスエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県出水郡長島町城川内', '46', '46404', '8991304', '鹿児島県', 'カゴシマケン', '出水郡長島町', 'イズミグンナガシマチョウ', '城川内', 'ジョウカワウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県出水郡長島町下山門野', '46', '46404', '8991321', '鹿児島県', 'カゴシマケン', '出水郡長島町', 'イズミグンナガシマチョウ', '下山門野', 'シモヤマドノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県出水郡長島町', '46', '46404', '8991400', '鹿児島県', 'カゴシマケン', '出水郡長島町', 'イズミグンナガシマチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('118453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県出水郡長島町鷹巣', '46', '46404', '8991401', '鹿児島県', 'カゴシマケン', '出水郡長島町', 'イズミグンナガシマチョウ', '鷹巣', 'タカノス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県出水郡長島町浦底', '46', '46404', '8991402', '鹿児島県', 'カゴシマケン', '出水郡長島町', 'イズミグンナガシマチョウ', '浦底', 'ウラソコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県出水郡長島町諸浦', '46', '46404', '8991403', '鹿児島県', 'カゴシマケン', '出水郡長島町', 'イズミグンナガシマチョウ', '諸浦', 'ショウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県出水郡長島町獅子島', '46', '46404', '8991501', '鹿児島県', 'カゴシマケン', '出水郡長島町', 'イズミグンナガシマチョウ', '獅子島', 'シシジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県阿久根市', '46', '46206', '8991600', '鹿児島県', 'カゴシマケン', '阿久根市', 'アクネシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('118459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県阿久根市折口', '46', '46206', '8991601', '鹿児島県', 'カゴシマケン', '阿久根市', 'アクネシ', '折口', 'オリグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県阿久根市多田', '46', '46206', '8991602', '鹿児島県', 'カゴシマケン', '阿久根市', 'アクネシ', '多田', 'タダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県阿久根市鶴川内', '46', '46206', '8991603', '鹿児島県', 'カゴシマケン', '阿久根市', 'アクネシ', '鶴川内', 'ツルガワウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県阿久根市山下', '46', '46206', '8991604', '鹿児島県', 'カゴシマケン', '阿久根市', 'アクネシ', '山下', 'ヤマシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県阿久根市赤瀬川', '46', '46206', '8991611', '鹿児島県', 'カゴシマケン', '阿久根市', 'アクネシ', '赤瀬川', 'アカセガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県阿久根市丸尾町', '46', '46206', '8991612', '鹿児島県', 'カゴシマケン', '阿久根市', 'アクネシ', '丸尾町', 'マルオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県阿久根市新町', '46', '46206', '8991613', '鹿児島県', 'カゴシマケン', '阿久根市', 'アクネシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県阿久根市晴海町', '46', '46206', '8991614', '鹿児島県', 'カゴシマケン', '阿久根市', 'アクネシ', '晴海町', 'ハルミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県阿久根市琴平町', '46', '46206', '8991615', '鹿児島県', 'カゴシマケン', '阿久根市', 'アクネシ', '琴平町', 'コトヒラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県阿久根市栄町', '46', '46206', '8991616', '鹿児島県', 'カゴシマケン', '阿久根市', 'アクネシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県阿久根市浜町', '46', '46206', '8991617', '鹿児島県', 'カゴシマケン', '阿久根市', 'アクネシ', '浜町', 'ハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県阿久根市本町', '46', '46206', '8991621', '鹿児島県', 'カゴシマケン', '阿久根市', 'アクネシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県阿久根市高松町', '46', '46206', '8991622', '鹿児島県', 'カゴシマケン', '阿久根市', 'アクネシ', '高松町', 'タカマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県阿久根市港町', '46', '46206', '8991623', '鹿児島県', 'カゴシマケン', '阿久根市', 'アクネシ', '港町', 'ミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県阿久根市大丸町', '46', '46206', '8991624', '鹿児島県', 'カゴシマケン', '阿久根市', 'アクネシ', '大丸町', 'オオマルチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県阿久根市波留', '46', '46206', '8991625', '鹿児島県', 'カゴシマケン', '阿久根市', 'アクネシ', '波留', 'ハル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県阿久根市鶴見町', '46', '46206', '8991626', '鹿児島県', 'カゴシマケン', '阿久根市', 'アクネシ', '鶴見町', 'ツルミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県阿久根市西目', '46', '46206', '8991627', '鹿児島県', 'カゴシマケン', '阿久根市', 'アクネシ', '西目', 'ニシメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県阿久根市塩鶴町', '46', '46206', '8991628', '鹿児島県', 'カゴシマケン', '阿久根市', 'アクネシ', '塩鶴町', 'シオツルチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県阿久根市塩浜町', '46', '46206', '8991629', '鹿児島県', 'カゴシマケン', '阿久根市', 'アクネシ', '塩浜町', 'シオハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県阿久根市大川', '46', '46206', '8991741', '鹿児島県', 'カゴシマケン', '阿久根市', 'アクネシ', '大川', 'オオカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩川内市西方町', '46', '46215', '8991801', '鹿児島県', 'カゴシマケン', '薩摩川内市', 'サツマセンダイシ', '西方町', 'ニシカタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩川内市湯田町', '46', '46215', '8991802', '鹿児島県', 'カゴシマケン', '薩摩川内市', 'サツマセンダイシ', '湯田町', 'ユダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩川内市水引町', '46', '46215', '8991921', '鹿児島県', 'カゴシマケン', '薩摩川内市', 'サツマセンダイシ', '水引町', 'ミズヒキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩川内市小倉町', '46', '46215', '8991922', '鹿児島県', 'カゴシマケン', '薩摩川内市', 'サツマセンダイシ', '小倉町', 'コクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩川内市湯島町', '46', '46215', '8991923', '鹿児島県', 'カゴシマケン', '薩摩川内市', 'サツマセンダイシ', '湯島町', 'ユシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩川内市港町', '46', '46215', '8991924', '鹿児島県', 'カゴシマケン', '薩摩川内市', 'サツマセンダイシ', '港町', 'ミナトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県薩摩川内市網津町', '46', '46215', '8991925', '鹿児島県', 'カゴシマケン', '薩摩川内市', 'サツマセンダイシ', '網津町', 'オウヅチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県いちき串木野市湊町', '46', '46219', '8992101', '鹿児島県', 'カゴシマケン', 'いちき串木野市', 'イチキクシキノシ', '湊町', 'ミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県いちき串木野市川上', '46', '46219', '8992102', '鹿児島県', 'カゴシマケン', 'いちき串木野市', 'イチキクシキノシ', '川上', 'カワカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県いちき串木野市大里', '46', '46219', '8992103', '鹿児島県', 'カゴシマケン', 'いちき串木野市', 'イチキクシキノシ', '大里', 'オオザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県日置市東市来町湯田', '46', '46216', '8992201', '鹿児島県', 'カゴシマケン', '日置市', 'ヒオキシ', '東市来町湯田', 'ヒガシイチキチョウユダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県日置市東市来町長里', '46', '46216', '8992202', '鹿児島県', 'カゴシマケン', '日置市', 'ヒオキシ', '東市来町長里', 'ヒガシイチキチョウナガサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県日置市東市来町伊作田', '46', '46216', '8992203', '鹿児島県', 'カゴシマケン', '日置市', 'ヒオキシ', '東市来町伊作田', 'ヒガシイチキチョウイザクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県日置市東市来町神之川', '46', '46216', '8992204', '鹿児島県', 'カゴシマケン', '日置市', 'ヒオキシ', '東市来町神之川', 'ヒガシイチキチョウカミノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県日置市東市来町養母', '46', '46216', '8992311', '鹿児島県', 'カゴシマケン', '日置市', 'ヒオキシ', '東市来町養母', 'ヒガシイチキチョウヨウボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県日置市日吉町神之川', '46', '46216', '8992421', '鹿児島県', 'カゴシマケン', '日置市', 'ヒオキシ', '日吉町神之川', 'ヒヨシチョウカミノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県日置市東市来町美山', '46', '46216', '8992431', '鹿児島県', 'カゴシマケン', '日置市', 'ヒオキシ', '東市来町美山', 'ヒガシイチキチョウミヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県日置市東市来町寺脇', '46', '46216', '8992432', '鹿児島県', 'カゴシマケン', '日置市', 'ヒオキシ', '東市来町寺脇', 'ヒガシイチキチョウテラワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県日置市東市来町宮田', '46', '46216', '8992433', '鹿児島県', 'カゴシマケン', '日置市', 'ヒオキシ', '東市来町宮田', 'ヒガシイチキチョウミヤタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県日置市東市来町南神之川', '46', '46216', '8992434', '鹿児島県', 'カゴシマケン', '日置市', 'ヒオキシ', '東市来町南神之川', 'ヒガシイチキチョウミナミカミノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県日置市伊集院町桑畑', '46', '46216', '8992441', '鹿児島県', 'カゴシマケン', '日置市', 'ヒオキシ', '伊集院町桑畑', 'イジュウインチョウクワバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県日置市伊集院町野田', '46', '46216', '8992442', '鹿児島県', 'カゴシマケン', '日置市', 'ヒオキシ', '伊集院町野田', 'イジュウインチョウノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県日置市伊集院町寺脇', '46', '46216', '8992443', '鹿児島県', 'カゴシマケン', '日置市', 'ヒオキシ', '伊集院町寺脇', 'イジュウインチョウテラワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県日置市', '46', '46216', '8992500', '鹿児島県', 'カゴシマケン', '日置市', 'ヒオキシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('118507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県日置市伊集院町下谷口', '46', '46216', '8992501', '鹿児島県', 'カゴシマケン', '日置市', 'ヒオキシ', '伊集院町下谷口', 'イジュウインチョウシモタニグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県日置市伊集院町徳重', '46', '46216', '8992502', '鹿児島県', 'カゴシマケン', '日置市', 'ヒオキシ', '伊集院町徳重', 'イジュウインチョウトクシゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県日置市伊集院町妙円寺', '46', '46216', '8992503', '鹿児島県', 'カゴシマケン', '日置市', 'ヒオキシ', '伊集院町妙円寺', 'イジュウインチョウミョウエンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県日置市伊集院町郡', '46', '46216', '8992504', '鹿児島県', 'カゴシマケン', '日置市', 'ヒオキシ', '伊集院町郡', 'イジュウインチョウコオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県日置市伊集院町猪鹿倉', '46', '46216', '8992505', '鹿児島県', 'カゴシマケン', '日置市', 'ヒオキシ', '伊集院町猪鹿倉', 'イジュウインチョウイガクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県日置市伊集院町清藤', '46', '46216', '8992506', '鹿児島県', 'カゴシマケン', '日置市', 'ヒオキシ', '伊集院町清藤', 'イジュウインチョウキヨフジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県日置市伊集院町下神殿', '46', '46216', '8992511', '鹿児島県', 'カゴシマケン', '日置市', 'ヒオキシ', '伊集院町下神殿', 'イジュウインチョウシモコウドノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県日置市伊集院町上神殿', '46', '46216', '8992512', '鹿児島県', 'カゴシマケン', '日置市', 'ヒオキシ', '伊集院町上神殿', 'イジュウインチョウカミコウドノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県日置市伊集院町麦生田', '46', '46216', '8992513', '鹿児島県', 'カゴシマケン', '日置市', 'ヒオキシ', '伊集院町麦生田', 'イジュウインチョウムギウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県日置市伊集院町中川', '46', '46216', '8992514', '鹿児島県', 'カゴシマケン', '日置市', 'ヒオキシ', '伊集院町中川', 'イジュウインチョウナカガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県日置市伊集院町竹之山', '46', '46216', '8992515', '鹿児島県', 'カゴシマケン', '日置市', 'ヒオキシ', '伊集院町竹之山', 'イジュウインチョウタケノヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県日置市伊集院町土橋', '46', '46216', '8992516', '鹿児島県', 'カゴシマケン', '日置市', 'ヒオキシ', '伊集院町土橋', 'イジュウインチョウツチバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県日置市伊集院町大田', '46', '46216', '8992521', '鹿児島県', 'カゴシマケン', '日置市', 'ヒオキシ', '伊集院町大田', 'イジュウインチョウオオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県日置市伊集院町飯牟礼', '46', '46216', '8992522', '鹿児島県', 'カゴシマケン', '日置市', 'ヒオキシ', '伊集院町飯牟礼', 'イジュウインチョウイイムレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県日置市伊集院町古城', '46', '46216', '8992523', '鹿児島県', 'カゴシマケン', '日置市', 'ヒオキシ', '伊集院町古城', 'イジュウインチョウフルジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県日置市伊集院町恋之原', '46', '46216', '8992524', '鹿児島県', 'カゴシマケン', '日置市', 'ヒオキシ', '伊集院町恋之原', 'イジュウインチョウコイノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市小山田町', '46', '46201', '8992531', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '小山田町', 'コヤマダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市石谷町', '46', '46201', '8992701', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '石谷町', 'イシダニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市福山町', '46', '46201', '8992702', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '福山町', 'フクヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市上谷口町', '46', '46201', '8992703', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '上谷口町', 'カミタニグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市春山町', '46', '46201', '8992704', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '春山町', 'ハルヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市直木町', '46', '46201', '8992705', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '直木町', 'ナオキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市入佐町', '46', '46201', '8992706', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '入佐町', 'イリサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市松陽台町', '46', '46201', '8992707', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '松陽台町', 'ショウヨウダイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市四元町', '46', '46201', '8992708', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '四元町', 'ヨツモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市平田町', '46', '46201', '8992709', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '平田町', 'ヒラタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県日置市日吉町日置', '46', '46216', '8993101', '鹿児島県', 'カゴシマケン', '日置市', 'ヒオキシ', '日吉町日置', 'ヒヨシチョウヒオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県日置市日吉町山田', '46', '46216', '8993102', '鹿児島県', 'カゴシマケン', '日置市', 'ヒオキシ', '日吉町山田', 'ヒヨシチョウヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県日置市日吉町吉利', '46', '46216', '8993103', '鹿児島県', 'カゴシマケン', '日置市', 'ヒオキシ', '日吉町吉利', 'ヒヨシチョウヨシトシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県日置市伊集院町大田久木野々石塚', '46', '46216', '8993121', '鹿児島県', 'カゴシマケン', '日置市', 'ヒオキシ', '伊集院町大田', 'イジュウインチョウオオタ', null, null, '久木野々石塚', 'クキノノイシヅカ');
INSERT INTO `ms_addresses` VALUES ('118544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県日置市日吉町吉利', '46', '46216', '8993203', '鹿児島県', 'カゴシマケン', '日置市', 'ヒオキシ', '日吉町吉利', 'ヒヨシチョウヨシトシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿児島市入佐町', '46', '46201', '8993206', '鹿児島県', 'カゴシマケン', '鹿児島市', 'カゴシマシ', '入佐町', 'イリサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県日置市吹上町永吉', '46', '46216', '8993221', '鹿児島県', 'カゴシマケン', '日置市', 'ヒオキシ', '吹上町永吉', 'フキアゲチョウナガヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県日置市吹上町中原', '46', '46216', '8993301', '鹿児島県', 'カゴシマケン', '日置市', 'ヒオキシ', '吹上町中原', 'フキアゲチョウナカハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県日置市吹上町中之里', '46', '46216', '8993302', '鹿児島県', 'カゴシマケン', '日置市', 'ヒオキシ', '吹上町中之里', 'フキアゲチョウナカノサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県日置市吹上町湯之浦', '46', '46216', '8993303', '鹿児島県', 'カゴシマケン', '日置市', 'ヒオキシ', '吹上町湯之浦', 'フキアゲチョウユノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県日置市吹上町入来', '46', '46216', '8993304', '鹿児島県', 'カゴシマケン', '日置市', 'ヒオキシ', '吹上町入来', 'フキアゲチョウイリキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県日置市吹上町今田', '46', '46216', '8993305', '鹿児島県', 'カゴシマケン', '日置市', 'ヒオキシ', '吹上町今田', 'フキアゲチョウイマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県日置市吹上町小野', '46', '46216', '8993306', '鹿児島県', 'カゴシマケン', '日置市', 'ヒオキシ', '吹上町小野', 'フキアゲチョウオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県日置市吹上町花熟里', '46', '46216', '8993307', '鹿児島県', 'カゴシマケン', '日置市', 'ヒオキシ', '吹上町花熟里', 'フキアゲチョウケジュクリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県日置市吹上町田尻', '46', '46216', '8993308', '鹿児島県', 'カゴシマケン', '日置市', 'ヒオキシ', '吹上町田尻', 'フキアゲチョウタジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県日置市吹上町与倉', '46', '46216', '8993309', '鹿児島県', 'カゴシマケン', '日置市', 'ヒオキシ', '吹上町与倉', 'フキアゲチョウヨクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県日置市吹上町和田', '46', '46216', '8993311', '鹿児島県', 'カゴシマケン', '日置市', 'ヒオキシ', '吹上町和田', 'フキアゲチョウワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県南さつま市金峰町大野', '46', '46220', '8993401', '鹿児島県', 'カゴシマケン', '南さつま市', 'ミナミサツマシ', '金峰町大野', 'キンポウチョウオオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県南さつま市金峰町大坂', '46', '46220', '8993402', '鹿児島県', 'カゴシマケン', '南さつま市', 'ミナミサツマシ', '金峰町大坂', 'キンポウチョウダイザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県南さつま市金峰町尾下', '46', '46220', '8993403', '鹿児島県', 'カゴシマケン', '南さつま市', 'ミナミサツマシ', '金峰町尾下', 'キンポウチョウオクダリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県南さつま市金峰町高橋', '46', '46220', '8993404', '鹿児島県', 'カゴシマケン', '南さつま市', 'ミナミサツマシ', '金峰町高橋', 'キンポウチョウタカハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県南さつま市金峰町池辺', '46', '46220', '8993405', '鹿児島県', 'カゴシマケン', '南さつま市', 'ミナミサツマシ', '金峰町池辺', 'キンポウチョウイケベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県南さつま市金峰町宮崎', '46', '46220', '8993511', '鹿児島県', 'カゴシマケン', '南さつま市', 'ミナミサツマシ', '金峰町宮崎', 'キンポウチョウミヤザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県南さつま市金峰町花瀬', '46', '46220', '8993512', '鹿児島県', 'カゴシマケン', '南さつま市', 'ミナミサツマシ', '金峰町花瀬', 'キンポウチョウハナゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県南さつま市金峰町白川', '46', '46220', '8993513', '鹿児島県', 'カゴシマケン', '南さつま市', 'ミナミサツマシ', '金峰町白川', 'キンポウチョウシラカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県南さつま市金峰町新山', '46', '46220', '8993514', '鹿児島県', 'カゴシマケン', '南さつま市', 'ミナミサツマシ', '金峰町新山', 'キンポウチョウニイヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県南さつま市金峰町中津野', '46', '46220', '8993515', '鹿児島県', 'カゴシマケン', '南さつま市', 'ミナミサツマシ', '金峰町中津野', 'キンポウチョウナカツノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県南さつま市金峰町浦之名', '46', '46220', '8993516', '鹿児島県', 'カゴシマケン', '南さつま市', 'ミナミサツマシ', '金峰町浦之名', 'キンポウチョウウラノミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県南さつま市加世田津貫', '46', '46220', '8993611', '鹿児島県', 'カゴシマケン', '南さつま市', 'ミナミサツマシ', '加世田津貫', 'カセダツヌキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県曽於市財部町南俣', '46', '46217', '8994101', '鹿児島県', 'カゴシマケン', '曽於市', 'ソオシ', '財部町南俣', 'タカラベチョウミナミマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県曽於市財部町北俣', '46', '46217', '8994102', '鹿児島県', 'カゴシマケン', '曽於市', 'ソオシ', '財部町北俣', 'タカラベチョウキタマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県曽於市財部町下財部', '46', '46217', '8994103', '鹿児島県', 'カゴシマケン', '曽於市', 'ソオシ', '財部町下財部', 'タカラベチョウシモタカラベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県霧島市霧島田口', '46', '46218', '8994201', '鹿児島県', 'カゴシマケン', '霧島市', 'キリシマシ', '霧島田口', 'キリシマタグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県霧島市霧島永水', '46', '46218', '8994202', '鹿児島県', 'カゴシマケン', '霧島市', 'キリシマシ', '霧島永水', 'キリシマナガミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県霧島市霧島大窪', '46', '46218', '8994203', '鹿児島県', 'カゴシマケン', '霧島市', 'キリシマシ', '霧島大窪', 'キリシマオオクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県霧島市霧島川北', '46', '46218', '8994204', '鹿児島県', 'カゴシマケン', '霧島市', 'キリシマシ', '霧島川北', 'キリシマカワキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県霧島市', '46', '46218', '8994300', '鹿児島県', 'カゴシマケン', '霧島市', 'キリシマシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('118580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県霧島市国分重久', '46', '46218', '8994301', '鹿児島県', 'カゴシマケン', '霧島市', 'キリシマシ', '国分重久', 'コクブシゲヒサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県霧島市国分台明寺', '46', '46218', '8994302', '鹿児島県', 'カゴシマケン', '霧島市', 'キリシマシ', '国分台明寺', 'コクブダイミョウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県霧島市国分川原', '46', '46218', '8994303', '鹿児島県', 'カゴシマケン', '霧島市', 'キリシマシ', '国分川原', 'コクブカワハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県霧島市国分清水', '46', '46218', '8994304', '鹿児島県', 'カゴシマケン', '霧島市', 'キリシマシ', '国分清水', 'コクブキヨミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県霧島市国分郡田', '46', '46218', '8994305', '鹿児島県', 'カゴシマケン', '霧島市', 'キリシマシ', '国分郡田', 'コクブコオリダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県霧島市国分名波町', '46', '46218', '8994311', '鹿児島県', 'カゴシマケン', '霧島市', 'キリシマシ', '国分名波町', 'コクブナバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県霧島市国分山下町', '46', '46218', '8994312', '鹿児島県', 'カゴシマケン', '霧島市', 'キリシマシ', '国分山下町', 'コクブヤマシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県霧島市国分上井', '46', '46218', '8994313', '鹿児島県', 'カゴシマケン', '霧島市', 'キリシマシ', '国分上井', 'コクブウワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県霧島市国分川内', '46', '46218', '8994314', '鹿児島県', 'カゴシマケン', '霧島市', 'キリシマシ', '国分川内', 'コクブカワウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県霧島市国分湊', '46', '46218', '8994315', '鹿児島県', 'カゴシマケン', '霧島市', 'キリシマシ', '国分湊', 'コクブミナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県霧島市国分上小川', '46', '46218', '8994316', '鹿児島県', 'カゴシマケン', '霧島市', 'キリシマシ', '国分上小川', 'コクブカミコガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県霧島市国分上野原テクノパーク', '46', '46218', '8994317', '鹿児島県', 'カゴシマケン', '霧島市', 'キリシマシ', '国分上野原テクノパーク', 'コクブウエノハラテクノパーク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県霧島市国分上野原縄文の森', '46', '46218', '8994318', '鹿児島県', 'カゴシマケン', '霧島市', 'キリシマシ', '国分上野原縄文の森', 'コクブウエノハラジョウモンノモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県霧島市国分広瀬', '46', '46218', '8994321', '鹿児島県', 'カゴシマケン', '霧島市', 'キリシマシ', '国分広瀬', 'コクブヒロセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県霧島市国分福島', '46', '46218', '8994322', '鹿児島県', 'カゴシマケン', '霧島市', 'キリシマシ', '国分福島', 'コクブフクシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県霧島市国分松木', '46', '46218', '8994323', '鹿児島県', 'カゴシマケン', '霧島市', 'キリシマシ', '国分松木', 'コクブマツキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県霧島市国分松木東', '46', '46218', '8994324', '鹿児島県', 'カゴシマケン', '霧島市', 'キリシマシ', '国分松木東', 'コクブマツキヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県霧島市国分松木町', '46', '46218', '8994325', '鹿児島県', 'カゴシマケン', '霧島市', 'キリシマシ', '国分松木町', 'コクブマツキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県霧島市国分城山町', '46', '46218', '8994331', '鹿児島県', 'カゴシマケン', '霧島市', 'キリシマシ', '国分城山町', 'コクブシロヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県霧島市国分中央', '46', '46218', '8994332', '鹿児島県', 'カゴシマケン', '霧島市', 'キリシマシ', '国分中央', 'コクブチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県霧島市国分野口東', '46', '46218', '8994341', '鹿児島県', 'カゴシマケン', '霧島市', 'キリシマシ', '国分野口東', 'コクブノグチヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県霧島市国分野口町', '46', '46218', '8994342', '鹿児島県', 'カゴシマケン', '霧島市', 'キリシマシ', '国分野口町', 'コクブノグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県霧島市国分野口西', '46', '46218', '8994343', '鹿児島県', 'カゴシマケン', '霧島市', 'キリシマシ', '国分野口西', 'コクブノグチニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県霧島市国分野口北', '46', '46218', '8994344', '鹿児島県', 'カゴシマケン', '霧島市', 'キリシマシ', '国分野口北', 'コクブノグチキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県霧島市国分府中', '46', '46218', '8994345', '鹿児島県', 'カゴシマケン', '霧島市', 'キリシマシ', '国分府中', 'コクブフチュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県霧島市国分府中町', '46', '46218', '8994346', '鹿児島県', 'カゴシマケン', '霧島市', 'キリシマシ', '国分府中町', 'コクブフチュウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県霧島市国分新町', '46', '46218', '8994351', '鹿児島県', 'カゴシマケン', '霧島市', 'キリシマシ', '国分新町', 'コクブシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県霧島市国分向花', '46', '46218', '8994352', '鹿児島県', 'カゴシマケン', '霧島市', 'キリシマシ', '国分向花', 'コクブムケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県霧島市国分向花町', '46', '46218', '8994353', '鹿児島県', 'カゴシマケン', '霧島市', 'キリシマシ', '国分向花町', 'コクブムケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県霧島市国分姫城', '46', '46218', '8994354', '鹿児島県', 'カゴシマケン', '霧島市', 'キリシマシ', '国分姫城', 'コクブヒメギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県霧島市国分剣之宇都町', '46', '46218', '8994355', '鹿児島県', 'カゴシマケン', '霧島市', 'キリシマシ', '国分剣之宇都町', 'コクブケンノウトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県霧島市国分姫城南', '46', '46218', '8994356', '鹿児島県', 'カゴシマケン', '霧島市', 'キリシマシ', '国分姫城南', 'コクブヒメギミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県霧島市国分上之段', '46', '46218', '8994461', '鹿児島県', 'カゴシマケン', '霧島市', 'キリシマシ', '国分上之段', 'コクブウエノダン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県霧島市国分敷根', '46', '46218', '8994462', '鹿児島県', 'カゴシマケン', '霧島市', 'キリシマシ', '国分敷根', 'コクブシキネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県霧島市国分下井', '46', '46218', '8994463', '鹿児島県', 'カゴシマケン', '霧島市', 'キリシマシ', '国分下井', 'コクブシタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県霧島市福山町福山', '46', '46218', '8994501', '鹿児島県', 'カゴシマケン', '霧島市', 'キリシマシ', '福山町福山', 'フクヤマチョウフクヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県霧島市福山町福地', '46', '46218', '8994502', '鹿児島県', 'カゴシマケン', '霧島市', 'キリシマシ', '福山町福地', 'フクヤマチョウフクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県霧島市福山町福沢', '46', '46218', '8994503', '鹿児島県', 'カゴシマケン', '霧島市', 'キリシマシ', '福山町福沢', 'フクヤマチョウフクザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県霧島市福山町佳例川', '46', '46218', '8994504', '鹿児島県', 'カゴシマケン', '霧島市', 'キリシマシ', '福山町佳例川', 'フクヤマチョウカレイガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県垂水市牛根境', '46', '46214', '8994631', '鹿児島県', 'カゴシマケン', '垂水市', 'タルミズシ', '牛根境', 'ウシネサカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県垂水市牛根麓', '46', '46214', '8994632', '鹿児島県', 'カゴシマケン', '垂水市', 'タルミズシ', '牛根麓', 'ウシネフモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県垂水市二川', '46', '46214', '8994633', '鹿児島県', 'カゴシマケン', '垂水市', 'タルミズシ', '二川', 'フタガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県霧島市隼人町住吉', '46', '46218', '8995101', '鹿児島県', 'カゴシマケン', '霧島市', 'キリシマシ', '隼人町住吉', 'ハヤトチョウスミヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県霧島市隼人町真孝', '46', '46218', '8995102', '鹿児島県', 'カゴシマケン', '霧島市', 'キリシマシ', '隼人町真孝', 'ハヤトチョウシンコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県霧島市隼人町小浜', '46', '46218', '8995103', '鹿児島県', 'カゴシマケン', '霧島市', 'キリシマシ', '隼人町小浜', 'ハヤトチョウオハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県霧島市隼人町野久美田', '46', '46218', '8995104', '鹿児島県', 'カゴシマケン', '霧島市', 'キリシマシ', '隼人町野久美田', 'ハヤトチョウノクミダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県霧島市隼人町小田', '46', '46218', '8995105', '鹿児島県', 'カゴシマケン', '霧島市', 'キリシマシ', '隼人町小田', 'ハヤトチョウオダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県霧島市隼人町内山田', '46', '46218', '8995106', '鹿児島県', 'カゴシマケン', '霧島市', 'キリシマシ', '隼人町内山田', 'ハヤトチョウウチヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県霧島市隼人町姫城', '46', '46218', '8995111', '鹿児島県', 'カゴシマケン', '霧島市', 'キリシマシ', '隼人町姫城', 'ハヤトチョウヒメギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県霧島市隼人町松永', '46', '46218', '8995112', '鹿児島県', 'カゴシマケン', '霧島市', 'キリシマシ', '隼人町松永', 'ハヤトチョウマツナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県霧島市隼人町嘉例川', '46', '46218', '8995113', '鹿児島県', 'カゴシマケン', '霧島市', 'キリシマシ', '隼人町嘉例川', 'ハヤトチョウカレイガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県霧島市隼人町西光寺', '46', '46218', '8995114', '鹿児島県', 'カゴシマケン', '霧島市', 'キリシマシ', '隼人町西光寺', 'ハヤトチョウサイコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県霧島市隼人町東郷', '46', '46218', '8995115', '鹿児島県', 'カゴシマケン', '霧島市', 'キリシマシ', '隼人町東郷', 'ハヤトチョウトウゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県霧島市隼人町内', '46', '46218', '8995116', '鹿児島県', 'カゴシマケン', '霧島市', 'キリシマシ', '隼人町内', 'ハヤトチョウウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県霧島市隼人町見次', '46', '46218', '8995117', '鹿児島県', 'カゴシマケン', '霧島市', 'キリシマシ', '隼人町見次', 'ハヤトチョウミツギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県霧島市隼人町朝日', '46', '46218', '8995118', '鹿児島県', 'カゴシマケン', '霧島市', 'キリシマシ', '隼人町朝日', 'ハヤトチョウアサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県霧島市隼人町神宮', '46', '46218', '8995121', '鹿児島県', 'カゴシマケン', '霧島市', 'キリシマシ', '隼人町神宮', 'ハヤトチョウジングウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県姶良郡加治木町', '46', '46441', '8995200', '鹿児島県', 'カゴシマケン', '姶良郡加治木町', 'アイラグンカジキチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('118646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県姶良郡加治木町西別府', '46', '46441', '8995201', '鹿児島県', 'カゴシマケン', '姶良郡加治木町', 'アイラグンカジキチョウ', '西別府', 'ニシベップ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県姶良郡加治木町辺川', '46', '46441', '8995202', '鹿児島県', 'カゴシマケン', '姶良郡加治木町', 'アイラグンカジキチョウ', '辺川', 'ヘガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県姶良郡加治木町小山田', '46', '46441', '8995203', '鹿児島県', 'カゴシマケン', '姶良郡加治木町', 'アイラグンカジキチョウ', '小山田', 'コヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県姶良郡加治木町日木山', '46', '46441', '8995204', '鹿児島県', 'カゴシマケン', '姶良郡加治木町', 'アイラグンカジキチョウ', '日木山', 'ヒキヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県姶良郡加治木町新富町', '46', '46441', '8995211', '鹿児島県', 'カゴシマケン', '姶良郡加治木町', 'アイラグンカジキチョウ', '新富町', 'シントミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県姶良郡加治木町諏訪町', '46', '46441', '8995212', '鹿児島県', 'カゴシマケン', '姶良郡加治木町', 'アイラグンカジキチョウ', '諏訪町', 'スワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県姶良郡加治木町朝日町', '46', '46441', '8995213', '鹿児島県', 'カゴシマケン', '姶良郡加治木町', 'アイラグンカジキチョウ', '朝日町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県姶良郡加治木町仮屋町', '46', '46441', '8995214', '鹿児島県', 'カゴシマケン', '姶良郡加治木町', 'アイラグンカジキチョウ', '仮屋町', 'カリヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県姶良郡加治木町本町', '46', '46441', '8995215', '鹿児島県', 'カゴシマケン', '姶良郡加治木町', 'アイラグンカジキチョウ', '本町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県姶良郡加治木町港町', '46', '46441', '8995221', '鹿児島県', 'カゴシマケン', '姶良郡加治木町', 'アイラグンカジキチョウ', '港町', 'ミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県姶良郡加治木町錦江町', '46', '46441', '8995222', '鹿児島県', 'カゴシマケン', '姶良郡加治木町', 'アイラグンカジキチョウ', '錦江町', 'キンコウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県姶良郡加治木町新生町', '46', '46441', '8995223', '鹿児島県', 'カゴシマケン', '姶良郡加治木町', 'アイラグンカジキチョウ', '新生町', 'シンセイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県姶良郡加治木町反土', '46', '46441', '8995231', '鹿児島県', 'カゴシマケン', '姶良郡加治木町', 'アイラグンカジキチョウ', '反土', 'タンド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県姶良郡加治木町木田', '46', '46441', '8995241', '鹿児島県', 'カゴシマケン', '姶良郡加治木町', 'アイラグンカジキチョウ', '木田', 'キダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県姶良郡蒲生町', '46', '46443', '8995300', '鹿児島県', 'カゴシマケン', '姶良郡蒲生町', 'アイラグンカモウチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('118664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県姶良郡蒲生町漆', '46', '46443', '8995301', '鹿児島県', 'カゴシマケン', '姶良郡蒲生町', 'アイラグンカモウチョウ', '漆', 'ウルシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県姶良郡蒲生町上久徳', '46', '46443', '8995302', '鹿児島県', 'カゴシマケン', '姶良郡蒲生町', 'アイラグンカモウチョウ', '上久徳', 'カミギュウトク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県姶良郡蒲生町北', '46', '46443', '8995303', '鹿児島県', 'カゴシマケン', '姶良郡蒲生町', 'アイラグンカモウチョウ', '北', 'キタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県姶良郡蒲生町下久徳', '46', '46443', '8995304', '鹿児島県', 'カゴシマケン', '姶良郡蒲生町', 'アイラグンカモウチョウ', '下久徳', 'シモギュウトク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県姶良郡蒲生町白男', '46', '46443', '8995305', '鹿児島県', 'カゴシマケン', '姶良郡蒲生町', 'アイラグンカモウチョウ', '白男', 'シラオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県姶良郡蒲生町西浦', '46', '46443', '8995306', '鹿児島県', 'カゴシマケン', '姶良郡蒲生町', 'アイラグンカモウチョウ', '西浦', 'ニシウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県姶良郡蒲生町久末', '46', '46443', '8995307', '鹿児島県', 'カゴシマケン', '姶良郡蒲生町', 'アイラグンカモウチョウ', '久末', 'ヒサスエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県姶良郡蒲生町米丸', '46', '46443', '8995308', '鹿児島県', 'カゴシマケン', '姶良郡蒲生町', 'アイラグンカモウチョウ', '米丸', 'ヨネマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県姶良郡姶良町', '46', '46442', '8995400', '鹿児島県', 'カゴシマケン', '姶良郡姶良町', 'アイラグンアイラチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('118674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県姶良郡姶良町寺師', '46', '46442', '8995401', '鹿児島県', 'カゴシマケン', '姶良郡姶良町', 'アイラグンアイラチョウ', '寺師', 'テラシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県姶良郡姶良町中津野', '46', '46442', '8995402', '鹿児島県', 'カゴシマケン', '姶良郡姶良町', 'アイラグンアイラチョウ', '中津野', 'ナカツノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県姶良郡姶良町増田', '46', '46442', '8995403', '鹿児島県', 'カゴシマケン', '姶良郡姶良町', 'アイラグンアイラチョウ', '増田', 'マスダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県姶良郡姶良町永瀬', '46', '46442', '8995404', '鹿児島県', 'カゴシマケン', '姶良郡姶良町', 'アイラグンアイラチョウ', '永瀬', 'ナガセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県姶良郡姶良町住吉', '46', '46442', '8995405', '鹿児島県', 'カゴシマケン', '姶良郡姶良町', 'アイラグンアイラチョウ', '住吉', 'スミヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県姶良郡姶良町鍋倉', '46', '46442', '8995411', '鹿児島県', 'カゴシマケン', '姶良郡姶良町', 'アイラグンアイラチョウ', '鍋倉', 'ナベクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県姶良郡姶良町三拾町', '46', '46442', '8995412', '鹿児島県', 'カゴシマケン', '姶良郡姶良町', 'アイラグンアイラチョウ', '三拾町', 'サンジュッチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県姶良郡姶良町豊留', '46', '46442', '8995413', '鹿児島県', 'カゴシマケン', '姶良郡姶良町', 'アイラグンアイラチョウ', '豊留', 'トヨドメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県姶良郡姶良町深水', '46', '46442', '8995414', '鹿児島県', 'カゴシマケン', '姶良郡姶良町', 'アイラグンアイラチョウ', '深水', 'フカミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県姶良郡姶良町東餠田', '46', '46442', '8995421', '鹿児島県', 'カゴシマケン', '姶良郡姶良町', 'アイラグンアイラチョウ', '東餠田', 'ヒガシモチダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県姶良郡姶良町西餠田', '46', '46442', '8995431', '鹿児島県', 'カゴシマケン', '姶良郡姶良町', 'アイラグンアイラチョウ', '西餠田', 'ニシモチダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県姶良郡姶良町宮島町', '46', '46442', '8995432', '鹿児島県', 'カゴシマケン', '姶良郡姶良町', 'アイラグンアイラチョウ', '宮島町', 'ミヤジママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県姶良郡姶良町西宮島町', '46', '46442', '8995433', '鹿児島県', 'カゴシマケン', '姶良郡姶良町', 'アイラグンアイラチョウ', '西宮島町', 'ニシミヤジママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県姶良郡姶良町北山', '46', '46442', '8995541', '鹿児島県', 'カゴシマケン', '姶良郡姶良町', 'アイラグンアイラチョウ', '北山', 'キタヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県姶良郡姶良町上名', '46', '46442', '8995542', '鹿児島県', 'カゴシマケン', '姶良郡姶良町', 'アイラグンアイラチョウ', '上名', 'カミミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県姶良郡姶良町下名', '46', '46442', '8995543', '鹿児島県', 'カゴシマケン', '姶良郡姶良町', 'アイラグンアイラチョウ', '下名', 'シモミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県姶良郡姶良町大山', '46', '46442', '8995544', '鹿児島県', 'カゴシマケン', '姶良郡姶良町', 'アイラグンアイラチョウ', '大山', 'オオヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県姶良郡姶良町木津志', '46', '46442', '8995545', '鹿児島県', 'カゴシマケン', '姶良郡姶良町', 'アイラグンアイラチョウ', '木津志', 'キヅシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県姶良郡姶良町脇元', '46', '46442', '8995651', '鹿児島県', 'カゴシマケン', '姶良郡姶良町', 'アイラグンアイラチョウ', '脇元', 'ワキモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県姶良郡姶良町平松', '46', '46442', '8995652', '鹿児島県', 'カゴシマケン', '姶良郡姶良町', 'アイラグンアイラチョウ', '平松', 'ヒラマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県姶良郡姶良町池島町', '46', '46442', '8995653', '鹿児島県', 'カゴシマケン', '姶良郡姶良町', 'アイラグンアイラチョウ', '池島町', 'イケジママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県姶良郡姶良町永池町', '46', '46442', '8995654', '鹿児島県', 'カゴシマケン', '姶良郡姶良町', 'アイラグンアイラチョウ', '永池町', 'ナガイケマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県姶良郡姶良町船津', '46', '46442', '8995655', '鹿児島県', 'カゴシマケン', '姶良郡姶良町', 'アイラグンアイラチョウ', '船津', 'フナツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県姶良郡姶良町西姶良', '46', '46442', '8995656', '鹿児島県', 'カゴシマケン', '姶良郡姶良町', 'アイラグンアイラチョウ', '西姶良', 'ニシアイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県姶良郡湧水町鶴丸', '46', '46452', '8996101', '鹿児島県', 'カゴシマケン', '姶良郡湧水町', 'アイラグンユウスイチョウ', '鶴丸', 'ツルマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県姶良郡湧水町中津川', '46', '46452', '8996102', '鹿児島県', 'カゴシマケン', '姶良郡湧水町', 'アイラグンユウスイチョウ', '中津川', 'ナカツガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県姶良郡湧水町川添', '46', '46452', '8996103', '鹿児島県', 'カゴシマケン', '姶良郡湧水町', 'アイラグンユウスイチョウ', '川添', 'カワソエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県姶良郡湧水町川西', '46', '46452', '8996104', '鹿児島県', 'カゴシマケン', '姶良郡湧水町', 'アイラグンユウスイチョウ', '川西', 'カワニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県姶良郡湧水町般若寺', '46', '46452', '8996105', '鹿児島県', 'カゴシマケン', '姶良郡湧水町', 'アイラグンユウスイチョウ', '般若寺', 'ハンニャジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県姶良郡湧水町', '46', '46452', '8996200', '鹿児島県', 'カゴシマケン', '姶良郡湧水町', 'アイラグンユウスイチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('118711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県姶良郡湧水町木場', '46', '46452', '8996201', '鹿児島県', 'カゴシマケン', '姶良郡湧水町', 'アイラグンユウスイチョウ', '木場', 'コバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県姶良郡湧水町北方', '46', '46452', '8996202', '鹿児島県', 'カゴシマケン', '姶良郡湧水町', 'アイラグンユウスイチョウ', '北方', 'キタカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県姶良郡湧水町田尾原', '46', '46452', '8996203', '鹿児島県', 'カゴシマケン', '姶良郡湧水町', 'アイラグンユウスイチョウ', '田尾原', 'タオバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県姶良郡湧水町稲葉崎', '46', '46452', '8996204', '鹿児島県', 'カゴシマケン', '姶良郡湧水町', 'アイラグンユウスイチョウ', '稲葉崎', 'イナバサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県姶良郡湧水町幸田', '46', '46452', '8996205', '鹿児島県', 'カゴシマケン', '姶良郡湧水町', 'アイラグンユウスイチョウ', '幸田', 'コウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県姶良郡湧水町恒次', '46', '46452', '8996206', '鹿児島県', 'カゴシマケン', '姶良郡湧水町', 'アイラグンユウスイチョウ', '恒次', 'ツネツグ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県姶良郡湧水町米永', '46', '46452', '8996207', '鹿児島県', 'カゴシマケン', '姶良郡湧水町', 'アイラグンユウスイチョウ', '米永', 'ヨネナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県霧島市横川町上ノ', '46', '46218', '8996301', '鹿児島県', 'カゴシマケン', '霧島市', 'キリシマシ', '横川町上ノ', 'ヨコガワチョウカミノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県霧島市横川町下ノ', '46', '46218', '8996302', '鹿児島県', 'カゴシマケン', '霧島市', 'キリシマシ', '横川町下ノ', 'ヨコガワチョウシモノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県霧島市横川町中ノ', '46', '46218', '8996303', '鹿児島県', 'カゴシマケン', '霧島市', 'キリシマシ', '横川町中ノ', 'ヨコガワチョウナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県霧島市溝辺町有川', '46', '46218', '8996401', '鹿児島県', 'カゴシマケン', '霧島市', 'キリシマシ', '溝辺町有川', 'ミゾベチョウアリカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県霧島市溝辺町竹子', '46', '46218', '8996402', '鹿児島県', 'カゴシマケン', '霧島市', 'キリシマシ', '溝辺町竹子', 'ミゾベチョウタカゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県霧島市溝辺町三縄', '46', '46218', '8996403', '鹿児島県', 'カゴシマケン', '霧島市', 'キリシマシ', '溝辺町三縄', 'ミゾベチョウミナワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県霧島市溝辺町麓', '46', '46218', '8996404', '鹿児島県', 'カゴシマケン', '霧島市', 'キリシマシ', '溝辺町麓', 'ミゾベチョウフモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県霧島市溝辺町崎森', '46', '46218', '8996405', '鹿児島県', 'カゴシマケン', '霧島市', 'キリシマシ', '溝辺町崎森', 'ミゾベチョウサキモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県霧島市牧園町万膳', '46', '46218', '8996501', '鹿児島県', 'カゴシマケン', '霧島市', 'キリシマシ', '牧園町万膳', 'マキゾノチョウマンゼン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県霧島市牧園町三体堂', '46', '46218', '8996502', '鹿児島県', 'カゴシマケン', '霧島市', 'キリシマシ', '牧園町三体堂', 'マキゾノチョウサンタイドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県霧島市牧園町高千穂', '46', '46218', '8996503', '鹿児島県', 'カゴシマケン', '霧島市', 'キリシマシ', '牧園町高千穂', 'マキゾノチョウタカチホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県霧島市牧園町上中津川', '46', '46218', '8996504', '鹿児島県', 'カゴシマケン', '霧島市', 'キリシマシ', '牧園町上中津川', 'マキゾノチョウカミナカツガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県霧島市牧園町持松', '46', '46218', '8996505', '鹿児島県', 'カゴシマケン', '霧島市', 'キリシマシ', '牧園町持松', 'マキゾノチョウモチマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県霧島市牧園町下中津川', '46', '46218', '8996506', '鹿児島県', 'カゴシマケン', '霧島市', 'キリシマシ', '牧園町下中津川', 'マキゾノチョウシモナカツガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県霧島市牧園町宿窪田', '46', '46218', '8996507', '鹿児島県', 'カゴシマケン', '霧島市', 'キリシマシ', '牧園町宿窪田', 'マキゾノチョウシュククボタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県霧島市牧園町万膳', '46', '46218', '8996601', '鹿児島県', 'カゴシマケン', '霧島市', 'キリシマシ', '牧園町万膳', 'マキゾノチョウマンゼン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県霧島市牧園町三体堂', '46', '46218', '8996602', '鹿児島県', 'カゴシマケン', '霧島市', 'キリシマシ', '牧園町三体堂', 'マキゾノチョウサンタイドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県霧島市牧園町高千穂', '46', '46218', '8996603', '鹿児島県', 'カゴシマケン', '霧島市', 'キリシマシ', '牧園町高千穂', 'マキゾノチョウタカチホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県霧島市牧園町上中津川', '46', '46218', '8996604', '鹿児島県', 'カゴシマケン', '霧島市', 'キリシマシ', '牧園町上中津川', 'マキゾノチョウカミナカツガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県志布志市', '46', '46221', '8997100', '鹿児島県', 'カゴシマケン', '志布志市', 'シブシシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('118745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県志布志市志布志町夏井', '46', '46221', '8997101', '鹿児島県', 'カゴシマケン', '志布志市', 'シブシシ', '志布志町夏井', 'シブシチョウナツイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県志布志市志布志町帖', '46', '46221', '8997102', '鹿児島県', 'カゴシマケン', '志布志市', 'シブシシ', '志布志町帖', 'シブシチョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県志布志市志布志町志布志', '46', '46221', '8997103', '鹿児島県', 'カゴシマケン', '志布志市', 'シブシシ', '志布志町志布志', 'シブシチョウシブシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県志布志市志布志町安楽', '46', '46221', '8997104', '鹿児島県', 'カゴシマケン', '志布志市', 'シブシシ', '志布志町安楽', 'シブシチョウアンラク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県志布志市志布志町内之倉', '46', '46221', '8997211', '鹿児島県', 'カゴシマケン', '志布志市', 'シブシシ', '志布志町内之倉', 'シブシチョウウチノクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県志布志市志布志町田之浦', '46', '46221', '8997212', '鹿児島県', 'カゴシマケン', '志布志市', 'シブシシ', '志布志町田之浦', 'シブシチョウタノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県曽於郡大崎町', '46', '46468', '8997300', '鹿児島県', 'カゴシマケン', '曽於郡大崎町', 'ソオグンオオサキチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('118753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県曽於郡大崎町菱田', '46', '46468', '8997301', '鹿児島県', 'カゴシマケン', '曽於郡大崎町', 'ソオグンオオサキチョウ', '菱田', 'ヒシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県曽於郡大崎町神領', '46', '46468', '8997302', '鹿児島県', 'カゴシマケン', '曽於郡大崎町', 'ソオグンオオサキチョウ', '神領', 'ジンリョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県曽於郡大崎町益丸', '46', '46468', '8997303', '鹿児島県', 'カゴシマケン', '曽於郡大崎町', 'ソオグンオオサキチョウ', '益丸', 'マスマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県曽於郡大崎町横瀬', '46', '46468', '8997304', '鹿児島県', 'カゴシマケン', '曽於郡大崎町', 'ソオグンオオサキチョウ', '横瀬', 'ヨコセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県曽於郡大崎町假宿', '46', '46468', '8997305', '鹿児島県', 'カゴシマケン', '曽於郡大崎町', 'ソオグンオオサキチョウ', '假宿', 'カリジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県曽於郡大崎町永吉', '46', '46468', '8997306', '鹿児島県', 'カゴシマケン', '曽於郡大崎町', 'ソオグンオオサキチョウ', '永吉', 'ナガヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県曽於郡大崎町持留', '46', '46468', '8997307', '鹿児島県', 'カゴシマケン', '曽於郡大崎町', 'ソオグンオオサキチョウ', '持留', 'モチドメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県曽於郡大崎町岡別府', '46', '46468', '8997308', '鹿児島県', 'カゴシマケン', '曽於郡大崎町', 'ソオグンオオサキチョウ', '岡別府', 'オカベップ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県曽於郡大崎町井俣', '46', '46468', '8997309', '鹿児島県', 'カゴシマケン', '曽於郡大崎町', 'ソオグンオオサキチョウ', '井俣', 'イマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県志布志市有明町伊崎田', '46', '46221', '8997401', '鹿児島県', 'カゴシマケン', '志布志市', 'シブシシ', '有明町伊崎田', 'アリアケチョウイサキダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県志布志市有明町野井倉', '46', '46221', '8997402', '鹿児島県', 'カゴシマケン', '志布志市', 'シブシシ', '有明町野井倉', 'アリアケチョウノイクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県志布志市有明町蓬原春日', '46', '46221', '8997403', '鹿児島県', 'カゴシマケン', '志布志市', 'シブシシ', '有明町蓬原', 'アリアケチョウフツハラ', null, null, '春日', 'カスガ');
INSERT INTO `ms_addresses` VALUES ('118766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県志布志市有明町蓬原', '46', '46221', '8997503', '鹿児島県', 'カゴシマケン', '志布志市', 'シブシシ', '有明町蓬原', 'アリアケチョウフツハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県志布志市有明町原田', '46', '46221', '8997511', '鹿児島県', 'カゴシマケン', '志布志市', 'シブシシ', '有明町原田', 'アリアケチョウハラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県志布志市有明町野神', '46', '46221', '8997512', '鹿児島県', 'カゴシマケン', '志布志市', 'シブシシ', '有明町野神', 'アリアケチョウノガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県志布志市有明町山重', '46', '46221', '8997513', '鹿児島県', 'カゴシマケン', '志布志市', 'シブシシ', '有明町山重', 'アリアケチョウヤマシゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県志布志市松山町新橋', '46', '46221', '8997601', '鹿児島県', 'カゴシマケン', '志布志市', 'シブシシ', '松山町新橋', 'マツヤマチョウシンバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県志布志市松山町泰野', '46', '46221', '8997602', '鹿児島県', 'カゴシマケン', '志布志市', 'シブシシ', '松山町泰野', 'マツヤマチョウタイノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県志布志市松山町尾野見', '46', '46221', '8997603', '鹿児島県', 'カゴシマケン', '志布志市', 'シブシシ', '松山町尾野見', 'マツヤマチョウオノミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県曽於市末吉町岩崎池原', '46', '46217', '8998101', '鹿児島県', 'カゴシマケン', '曽於市', 'ソオシ', '末吉町岩崎', 'スエヨシチョウイワサキ', null, null, '池原', 'イケハラ');
INSERT INTO `ms_addresses` VALUES ('118775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県曽於市末吉町岩崎岩之上', '46', '46217', '8998101', '鹿児島県', 'カゴシマケン', '曽於市', 'ソオシ', '末吉町岩崎', 'スエヨシチョウイワサキ', null, null, '岩之上', 'イワノウエ');
INSERT INTO `ms_addresses` VALUES ('118776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県曽於市末吉町岩崎岩南', '46', '46217', '8998101', '鹿児島県', 'カゴシマケン', '曽於市', 'ソオシ', '末吉町岩崎', 'スエヨシチョウイワサキ', null, null, '岩南', 'イワミナミ');
INSERT INTO `ms_addresses` VALUES ('118777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県曽於市末吉町岩崎前田', '46', '46217', '8998101', '鹿児島県', 'カゴシマケン', '曽於市', 'ソオシ', '末吉町岩崎', 'スエヨシチョウイワサキ', null, null, '前田', 'マエダ');
INSERT INTO `ms_addresses` VALUES ('118778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県曽於市末吉町岩崎牧原', '46', '46217', '8998101', '鹿児島県', 'カゴシマケン', '曽於市', 'ソオシ', '末吉町岩崎', 'スエヨシチョウイワサキ', null, null, '牧原', 'マキハラ');
INSERT INTO `ms_addresses` VALUES ('118779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県曽於市末吉町岩崎道添', '46', '46217', '8998101', '鹿児島県', 'カゴシマケン', '曽於市', 'ソオシ', '末吉町岩崎', 'スエヨシチョウイワサキ', null, null, '道添', 'ミチゾイ');
INSERT INTO `ms_addresses` VALUES ('118780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県曽於市末吉町岩崎宮原', '46', '46217', '8998101', '鹿児島県', 'カゴシマケン', '曽於市', 'ソオシ', '末吉町岩崎', 'スエヨシチョウイワサキ', null, null, '宮原', 'ミヤバル');
INSERT INTO `ms_addresses` VALUES ('118781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県曽於市大隅町岩川', '46', '46217', '8998102', '鹿児島県', 'カゴシマケン', '曽於市', 'ソオシ', '大隅町岩川', 'オオスミチョウイワガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県曽於市大隅町中之内', '46', '46217', '8998103', '鹿児島県', 'カゴシマケン', '曽於市', 'ソオシ', '大隅町中之内', 'オオスミチョウナカノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県曽於市大隅町鳴神町', '46', '46217', '8998104', '鹿児島県', 'カゴシマケン', '曽於市', 'ソオシ', '大隅町鳴神町', 'オオスミチョウナルガミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県曽於市大隅町段中町', '46', '46217', '8998105', '鹿児島県', 'カゴシマケン', '曽於市', 'ソオシ', '大隅町段中町', 'オオスミチョウダンナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県曽於市大隅町下窪町', '46', '46217', '8998106', '鹿児島県', 'カゴシマケン', '曽於市', 'ソオシ', '大隅町下窪町', 'オオスミチョウシモクボマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県曽於市大隅町荒谷荒谷', '46', '46217', '8998211', '鹿児島県', 'カゴシマケン', '曽於市', 'ソオシ', '大隅町荒谷', 'オオスミチョウアラタニ', null, null, '荒谷', 'アラタニ');
INSERT INTO `ms_addresses` VALUES ('118788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県曽於市大隅町荒谷大迫', '46', '46217', '8998211', '鹿児島県', 'カゴシマケン', '曽於市', 'ソオシ', '大隅町荒谷', 'オオスミチョウアラタニ', null, null, '大迫', 'オオサコ');
INSERT INTO `ms_addresses` VALUES ('118789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県曽於市大隅町荒谷中大迫', '46', '46217', '8998211', '鹿児島県', 'カゴシマケン', '曽於市', 'ソオシ', '大隅町荒谷', 'オオスミチョウアラタニ', null, null, '中大迫', 'ナカオオサコ');
INSERT INTO `ms_addresses` VALUES ('118790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県曽於市大隅町月野', '46', '46217', '8998212', '鹿児島県', 'カゴシマケン', '曽於市', 'ソオシ', '大隅町月野', 'オオスミチョウツキノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県曽於市大隅町境木町', '46', '46217', '8998213', '鹿児島県', 'カゴシマケン', '曽於市', 'ソオシ', '大隅町境木町', 'オオスミチョウサカイギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県曽於市大隅町荒谷', '46', '46217', '8998311', '鹿児島県', 'カゴシマケン', '曽於市', 'ソオシ', '大隅町荒谷', 'オオスミチョウアラタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県志布志市有明町野神抜谷', '46', '46221', '8998312', '鹿児島県', 'カゴシマケン', '志布志市', 'シブシシ', '有明町野神', 'アリアケチョウノガミ', null, null, '抜谷', 'ヌキダニ');
INSERT INTO `ms_addresses` VALUES ('118794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県志布志市有明町野神塗木', '46', '46221', '8998312', '鹿児島県', 'カゴシマケン', '志布志市', 'シブシシ', '有明町野神', 'アリアケチョウノガミ', null, null, '塗木', 'ヌルキ');
INSERT INTO `ms_addresses` VALUES ('118795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県志布志市有明町野神本地', '46', '46221', '8998312', '鹿児島県', 'カゴシマケン', '志布志市', 'シブシシ', '有明町野神', 'アリアケチョウノガミ', null, null, '本地', 'ホンジ');
INSERT INTO `ms_addresses` VALUES ('118796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県志布志市有明町野神曲', '46', '46221', '8998312', '鹿児島県', 'カゴシマケン', '志布志市', 'シブシシ', '有明町野神', 'アリアケチョウノガミ', null, null, '曲', 'マガリ');
INSERT INTO `ms_addresses` VALUES ('118797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県志布志市有明町野神水ノ谷', '46', '46221', '8998312', '鹿児島県', 'カゴシマケン', '志布志市', 'シブシシ', '有明町野神', 'アリアケチョウノガミ', null, null, '水ノ谷', 'ミズノタニ');
INSERT INTO `ms_addresses` VALUES ('118798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県曽於郡大崎町野方', '46', '46468', '8998313', '鹿児島県', 'カゴシマケン', '曽於郡大崎町', 'ソオグンオオサキチョウ', '野方', 'ノガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県曽於市大隅町大谷', '46', '46217', '8998421', '鹿児島県', 'カゴシマケン', '曽於市', 'ソオシ', '大隅町大谷', 'オオスミチョウオオタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県曽於市大隅町坂元', '46', '46217', '8998422', '鹿児島県', 'カゴシマケン', '曽於市', 'ソオシ', '大隅町坂元', 'オオスミチョウサカモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県曽於市大隅町須田木', '46', '46217', '8998423', '鹿児島県', 'カゴシマケン', '曽於市', 'ソオシ', '大隅町須田木', 'オオスミチョウスダキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県曽於市大隅町恒吉', '46', '46217', '8998424', '鹿児島県', 'カゴシマケン', '曽於市', 'ソオシ', '大隅町恒吉', 'オオスミチョウツネヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿屋市輝北町市成', '46', '46203', '8998511', '鹿児島県', 'カゴシマケン', '鹿屋市', 'カノヤシ', '輝北町市成', 'キホクチョウイチナリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県鹿屋市輝北町諏訪原', '46', '46203', '8998512', '鹿児島県', 'カゴシマケン', '鹿屋市', 'カノヤシ', '輝北町諏訪原', 'キホクチョウスワバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県曽於市', '46', '46217', '8998600', '鹿児島県', 'カゴシマケン', '曽於市', 'ソオシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('118806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県曽於市末吉町岩崎', '46', '46217', '8998601', '鹿児島県', 'カゴシマケン', '曽於市', 'ソオシ', '末吉町岩崎', 'スエヨシチョウイワサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県曽於市末吉町栄町', '46', '46217', '8998602', '鹿児島県', 'カゴシマケン', '曽於市', 'ソオシ', '末吉町栄町', 'スエヨシチョウサカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県曽於市末吉町新町', '46', '46217', '8998603', '鹿児島県', 'カゴシマケン', '曽於市', 'ソオシ', '末吉町新町', 'スエヨシチョウシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県曽於市末吉町諏訪方', '46', '46217', '8998604', '鹿児島県', 'カゴシマケン', '曽於市', 'ソオシ', '末吉町諏訪方', 'スエヨシチョウスワカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県曽於市末吉町二之方', '46', '46217', '8998605', '鹿児島県', 'カゴシマケン', '曽於市', 'ソオシ', '末吉町二之方', 'スエヨシチョウニノカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県曽於市末吉町深川', '46', '46217', '8998606', '鹿児島県', 'カゴシマケン', '曽於市', 'ソオシ', '末吉町深川', 'スエヨシチョウフカガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県曽於市末吉町本町', '46', '46217', '8998607', '鹿児島県', 'カゴシマケン', '曽於市', 'ソオシ', '末吉町本町', 'スエヨシチョウホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '鹿児島県曽於市末吉町南之郷', '46', '46217', '8998608', '鹿児島県', 'カゴシマケン', '曽於市', 'ソオシ', '末吉町南之郷', 'スエヨシチョウミナミノゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市', '01', '01208', '0900000', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('118816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県那覇市', '47', '47201', '9000000', '沖縄県', 'オキナワケン', '那覇市', 'ナハシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('118817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県那覇市港町', '47', '47201', '9000001', '沖縄県', 'オキナワケン', '那覇市', 'ナハシ', '港町', 'ミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県那覇市曙', '47', '47201', '9000002', '沖縄県', 'オキナワケン', '那覇市', 'ナハシ', '曙', 'アケボノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県那覇市安謝', '47', '47201', '9000003', '沖縄県', 'オキナワケン', '那覇市', 'ナハシ', '安謝', 'アジャ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県那覇市銘苅', '47', '47201', '9000004', '沖縄県', 'オキナワケン', '那覇市', 'ナハシ', '銘苅', 'メカル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県那覇市天久', '47', '47201', '9000005', '沖縄県', 'オキナワケン', '那覇市', 'ナハシ', '天久', 'アメク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県那覇市おもろまち', '47', '47201', '9000006', '沖縄県', 'オキナワケン', '那覇市', 'ナハシ', 'おもろまち', 'オモロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市小泉', '01', '01208', '0900001', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '小泉', 'コイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県那覇市上之屋', '47', '47201', '9000011', '沖縄県', 'オキナワケン', '那覇市', 'ナハシ', '上之屋', 'ウエノヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県那覇市泊', '47', '47201', '9000012', '沖縄県', 'オキナワケン', '那覇市', 'ナハシ', '泊', 'トマリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県那覇市牧志', '47', '47201', '9000013', '沖縄県', 'オキナワケン', '那覇市', 'ナハシ', '牧志', 'マキシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県那覇市松尾', '47', '47201', '9000014', '沖縄県', 'オキナワケン', '那覇市', 'ナハシ', '松尾', 'マツオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県那覇市久茂地', '47', '47201', '9000015', '沖縄県', 'オキナワケン', '那覇市', 'ナハシ', '久茂地', 'クモジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県那覇市前島', '47', '47201', '9000016', '沖縄県', 'オキナワケン', '那覇市', 'ナハシ', '前島', 'マエジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市昭和', '01', '01208', '0900002', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '昭和', 'ショウワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県那覇市泉崎', '47', '47201', '9000021', '沖縄県', 'オキナワケン', '那覇市', 'ナハシ', '泉崎', 'イズミザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県那覇市樋川', '47', '47201', '9000022', '沖縄県', 'オキナワケン', '那覇市', 'ナハシ', '樋川', 'ヒガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県那覇市楚辺', '47', '47201', '9000023', '沖縄県', 'オキナワケン', '那覇市', 'ナハシ', '楚辺', 'ソベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県那覇市古波蔵', '47', '47201', '9000024', '沖縄県', 'オキナワケン', '那覇市', 'ナハシ', '古波蔵', 'コハグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県那覇市壺川', '47', '47201', '9000025', '沖縄県', 'オキナワケン', '那覇市', 'ナハシ', '壺川', 'ツボガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県那覇市奥武山町', '47', '47201', '9000026', '沖縄県', 'オキナワケン', '那覇市', 'ナハシ', '奥武山町', 'オオノヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県那覇市山下町', '47', '47201', '9000027', '沖縄県', 'オキナワケン', '那覇市', 'ナハシ', '山下町', 'ヤマシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県那覇市垣花町', '47', '47201', '9000028', '沖縄県', 'オキナワケン', '那覇市', 'ナハシ', '垣花町', 'カキノハナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県那覇市旭町', '47', '47201', '9000029', '沖縄県', 'オキナワケン', '那覇市', 'ナハシ', '旭町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市仁頃町', '01', '01208', '0900003', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '仁頃町', 'ニコロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県那覇市若狭', '47', '47201', '9000031', '沖縄県', 'オキナワケン', '那覇市', 'ナハシ', '若狭', 'ワカサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県那覇市松山', '47', '47201', '9000032', '沖縄県', 'オキナワケン', '那覇市', 'ナハシ', '松山', 'マツヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県那覇市久米', '47', '47201', '9000033', '沖縄県', 'オキナワケン', '那覇市', 'ナハシ', '久米', 'クメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県那覇市東町', '47', '47201', '9000034', '沖縄県', 'オキナワケン', '那覇市', 'ナハシ', '東町', 'ヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県那覇市通堂町', '47', '47201', '9000035', '沖縄県', 'オキナワケン', '那覇市', 'ナハシ', '通堂町', 'トンドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県那覇市西', '47', '47201', '9000036', '沖縄県', 'オキナワケン', '那覇市', 'ナハシ', '西', 'ニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県那覇市辻', '47', '47201', '9000037', '沖縄県', 'オキナワケン', '那覇市', 'ナハシ', '辻', 'ツジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市北陽', '01', '01208', '0900004', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '北陽', 'ホクヨウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市大和', '01', '01208', '0900005', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '大和', 'ヤマト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市上仁頃', '01', '01208', '0900006', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '上仁頃', 'カミニコロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市美里', '01', '01208', '0900007', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '美里', 'ミサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市大正', '01', '01208', '0900008', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '大正', 'タイショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市曙町', '01', '01208', '0900011', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '曙町', 'アケボノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市並木町', '01', '01208', '0900012', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '並木町', 'ナミキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市柏陽町', '01', '01208', '0900013', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '柏陽町', 'ハクヨウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市文京町', '01', '01208', '0900014', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '文京町', 'ブンキョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市公園町', '01', '01208', '0900015', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '公園町', 'コウエンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市大町', '01', '01208', '0900016', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '大町', 'オオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市高砂町', '01', '01208', '0900017', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '高砂町', 'タカサゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市青葉町', '01', '01208', '0900018', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '青葉町', 'アオバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市三楽町', '01', '01208', '0900019', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '三楽町', 'サンラクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市大通東', '01', '01208', '0900020', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '大通東', 'オオドオリヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市北1条東', '01', '01208', '0900021', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '北1条東', 'キタ01ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市北2条東', '01', '01208', '0900022', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '北2条東', 'キタ02ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市北3条東', '01', '01208', '0900023', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '北3条東', 'キタ03ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市北4条東', '01', '01208', '0900024', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '北4条東', 'キタ04ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市北5条東', '01', '01208', '0900025', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '北5条東', 'キタ05ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市北6条東', '01', '01208', '0900026', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '北6条東', 'キタ06ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市北7条東', '01', '01208', '0900027', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '北7条東', 'キタ07ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市北8条東', '01', '01208', '0900028', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '北8条東', 'キタ08ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市北9条東', '01', '01208', '0900029', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '北9条東', 'キタ09ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市北10条東', '01', '01208', '0900030', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '北10条東', 'キタ10ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市北11条東', '01', '01208', '0900031', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '北11条東', 'キタ11ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市三住町', '01', '01208', '0900032', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '三住町', 'ミスミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市番場町', '01', '01208', '0900033', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '番場町', 'バンバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市中央町', '01', '01208', '0900034', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '中央町', 'チュウオウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市北斗町', '01', '01208', '0900035', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '北斗町', 'ホクトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市幸町', '01', '01208', '0900036', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市山下町', '01', '01208', '0900037', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '山下町', 'ヤマシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市大通西', '01', '01208', '0900040', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '大通西', 'オオドオリニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市北1条西', '01', '01208', '0900041', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '北1条西', 'キタ01ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市北2条西', '01', '01208', '0900042', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '北2条西', 'キタ02ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市北3条西', '01', '01208', '0900043', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '北3条西', 'キタ03ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市北4条西', '01', '01208', '0900044', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '北4条西', 'キタ04ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市北5条西', '01', '01208', '0900045', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '北5条西', 'キタ05ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市北6条西', '01', '01208', '0900046', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '北6条西', 'キタ06ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市北7条西', '01', '01208', '0900047', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '北7条西', 'キタ07ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市北8条西', '01', '01208', '0900048', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '北8条西', 'キタ08ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市高栄東町', '01', '01208', '0900051', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '高栄東町', 'コウエイヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市北進町', '01', '01208', '0900052', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '北進町', 'ホクシンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市桂町', '01', '01208', '0900053', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '桂町', 'カツラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市双葉町', '01', '01208', '0900054', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '双葉町', 'フタバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市緑町', '01', '01208', '0900055', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '緑町', 'ミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市卸町', '01', '01208', '0900056', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '卸町', 'オロシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市若葉', '01', '01208', '0900057', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '若葉', 'ワカバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市高栄西町', '01', '01208', '0900058', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '高栄西町', 'コウエイニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市東陵町', '01', '01208', '0900061', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '東陵町', 'トウリョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市美山町', '01', '01208', '0900062', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '美山町', 'ミヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市清見町', '01', '01208', '0900063', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '清見町', 'キヨミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市美芳町', '01', '01208', '0900064', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '美芳町', 'ミヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市寿町', '01', '01208', '0900065', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '寿町', 'コトブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市花月町', '01', '01208', '0900066', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '花月町', 'カゲツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市緑ケ丘', '01', '01208', '0900067', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '緑ケ丘', 'ミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市春光町', '01', '01208', '0900801', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '春光町', 'シュンコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市田端町', '01', '01208', '0900802', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '田端町', 'タバタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市朝日町', '01', '01208', '0900803', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '朝日町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市桜町', '01', '01208', '0900804', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '桜町', 'サクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市清月町', '01', '01208', '0900805', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '清月町', 'セイゲツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市南町', '01', '01208', '0900806', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '南町', 'ミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市川東', '01', '01208', '0900807', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '川東', 'カワヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市若松', '01', '01208', '0900808', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '若松', 'ワカマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市ひかり野', '01', '01208', '0900810', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', 'ひかり野', 'ヒカリノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市泉町', '01', '01208', '0900811', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '泉町', 'イズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市南仲町', '01', '01208', '0900812', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '南仲町', 'ミナミナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市中ノ島町', '01', '01208', '0900813', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '中ノ島町', 'ナカノシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市光葉町', '01', '01208', '0900814', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '光葉町', 'コウヨウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市新生町', '01', '01208', '0900815', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '新生町', 'シンセイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市花園町', '01', '01208', '0900816', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '花園町', 'ハナゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市常盤町', '01', '01208', '0900817', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '常盤町', 'トキワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市本町', '01', '01208', '0900818', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '本町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市川沿町', '01', '01208', '0900821', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '川沿町', 'カワゾエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市北央町', '01', '01208', '0900822', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '北央町', 'ホクオウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市広明町', '01', '01208', '0900823', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '広明町', 'コウメイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市北光', '01', '01208', '0900824', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '北光', 'ホッコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市無加川町', '01', '01208', '0900825', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '無加川町', 'ムカガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市末広町', '01', '01208', '0900826', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '末広町', 'スエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市錦町', '01', '01208', '0900827', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '錦町', 'ニシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市西富町', '01', '01208', '0900831', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '西富町', 'ニシトミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市栄町', '01', '01208', '0900832', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市とん田東町', '01', '01208', '0900833', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', 'とん田東町', 'トンデンヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市とん田西町', '01', '01208', '0900834', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', 'とん田西町', 'トンデンニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市光西町', '01', '01208', '0900835', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '光西町', 'コウセイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市東三輪', '01', '01208', '0900836', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '東三輪', 'ヒガシミワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市中央三輪', '01', '01208', '0900837', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '中央三輪', 'チュウオウミワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('118935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市西三輪', '01', '01208', '0900838', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '西三輪', 'ニシミワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県那覇市住吉町', '47', '47201', '9010141', '沖縄県', 'オキナワケン', '那覇市', 'ナハシ', '住吉町', 'スミヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県那覇市鏡水', '47', '47201', '9010142', '沖縄県', 'オキナワケン', '那覇市', 'ナハシ', '鏡水', 'カガミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県那覇市安次嶺', '47', '47201', '9010143', '沖縄県', 'オキナワケン', '那覇市', 'ナハシ', '安次嶺', 'アシミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県那覇市当間', '47', '47201', '9010144', '沖縄県', 'オキナワケン', '那覇市', 'ナハシ', '当間', 'トウマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県那覇市高良', '47', '47201', '9010145', '沖縄県', 'オキナワケン', '那覇市', 'ナハシ', '高良', 'タカラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県那覇市具志', '47', '47201', '9010146', '沖縄県', 'オキナワケン', '那覇市', 'ナハシ', '具志', 'グシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県那覇市宮城', '47', '47201', '9010147', '沖縄県', 'オキナワケン', '那覇市', 'ナハシ', '宮城', 'ミヤグスク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県那覇市大嶺', '47', '47201', '9010148', '沖縄県', 'オキナワケン', '那覇市', 'ナハシ', '大嶺', 'オオミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県那覇市鏡原町', '47', '47201', '9010151', '沖縄県', 'オキナワケン', '那覇市', 'ナハシ', '鏡原町', 'キョウハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県那覇市小禄', '47', '47201', '9010152', '沖縄県', 'オキナワケン', '那覇市', 'ナハシ', '小禄', 'オロク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県那覇市宇栄原', '47', '47201', '9010153', '沖縄県', 'オキナワケン', '那覇市', 'ナハシ', '宇栄原', 'ウエバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県那覇市赤嶺', '47', '47201', '9010154', '沖縄県', 'オキナワケン', '那覇市', 'ナハシ', '赤嶺', 'アカミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県那覇市金城', '47', '47201', '9010155', '沖縄県', 'オキナワケン', '那覇市', 'ナハシ', '金城', 'カナグスク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県那覇市田原', '47', '47201', '9010156', '沖縄県', 'オキナワケン', '那覇市', 'ナハシ', '田原', 'タバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県豊見城市', '47', '47212', '9010200', '沖縄県', 'オキナワケン', '豊見城市', 'トミグスクシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('119022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県豊見城市真玉橋', '47', '47212', '9010201', '沖縄県', 'オキナワケン', '豊見城市', 'トミグスクシ', '真玉橋', 'マダンバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県豊見城市嘉数', '47', '47212', '9010202', '沖縄県', 'オキナワケン', '豊見城市', 'トミグスクシ', '嘉数', 'カカズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県豊見城市長堂', '47', '47212', '9010203', '沖縄県', 'オキナワケン', '豊見城市', 'トミグスクシ', '長堂', 'ナガドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県豊見城市金良', '47', '47212', '9010204', '沖縄県', 'オキナワケン', '豊見城市', 'トミグスクシ', '金良', 'カネラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県豊見城市根差部', '47', '47212', '9010205', '沖縄県', 'オキナワケン', '豊見城市', 'トミグスクシ', '根差部', 'ネサブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県豊見城市饒波', '47', '47212', '9010211', '沖縄県', 'オキナワケン', '豊見城市', 'トミグスクシ', '饒波', 'ノハ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県豊見城市平良', '47', '47212', '9010212', '沖縄県', 'オキナワケン', '豊見城市', 'トミグスクシ', '平良', 'タイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県豊見城市高嶺', '47', '47212', '9010213', '沖縄県', 'オキナワケン', '豊見城市', 'トミグスクシ', '高嶺', 'タカミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県豊見城市保栄茂', '47', '47212', '9010214', '沖縄県', 'オキナワケン', '豊見城市', 'トミグスクシ', '保栄茂', 'ビン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県豊見城市渡嘉敷', '47', '47212', '9010215', '沖縄県', 'オキナワケン', '豊見城市', 'トミグスクシ', '渡嘉敷', 'トカシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県豊見城市座安', '47', '47212', '9010221', '沖縄県', 'オキナワケン', '豊見城市', 'トミグスクシ', '座安', 'ザヤス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県豊見城市渡橋名', '47', '47212', '9010222', '沖縄県', 'オキナワケン', '豊見城市', 'トミグスクシ', '渡橋名', 'トハシナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県豊見城市翁長', '47', '47212', '9010223', '沖縄県', 'オキナワケン', '豊見城市', 'トミグスクシ', '翁長', 'オナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県豊見城市与根', '47', '47212', '9010224', '沖縄県', 'オキナワケン', '豊見城市', 'トミグスクシ', '与根', 'ヨネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県豊見城市豊崎', '47', '47212', '9010225', '沖縄県', 'オキナワケン', '豊見城市', 'トミグスクシ', '豊崎', 'トヨサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県豊見城市我那覇', '47', '47212', '9010231', '沖縄県', 'オキナワケン', '豊見城市', 'トミグスクシ', '我那覇', 'ガナハ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県豊見城市伊良波', '47', '47212', '9010232', '沖縄県', 'オキナワケン', '豊見城市', 'トミグスクシ', '伊良波', 'イラハ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県豊見城市瀬長', '47', '47212', '9010233', '沖縄県', 'オキナワケン', '豊見城市', 'トミグスクシ', '瀬長', 'セナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県豊見城市田頭', '47', '47212', '9010234', '沖縄県', 'オキナワケン', '豊見城市', 'トミグスクシ', '田頭', 'タガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県豊見城市名嘉地', '47', '47212', '9010235', '沖縄県', 'オキナワケン', '豊見城市', 'トミグスクシ', '名嘉地', 'ナカチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県豊見城市豊見城', '47', '47212', '9010241', '沖縄県', 'オキナワケン', '豊見城市', 'トミグスクシ', '豊見城', 'トミグスク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県豊見城市高安', '47', '47212', '9010242', '沖縄県', 'オキナワケン', '豊見城市', 'トミグスクシ', '高安', 'タカヤス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県豊見城市上田', '47', '47212', '9010243', '沖縄県', 'オキナワケン', '豊見城市', 'トミグスクシ', '上田', 'ウエタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県豊見城市宜保', '47', '47212', '9010244', '沖縄県', 'オキナワケン', '豊見城市', 'トミグスクシ', '宜保', 'ギボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県糸満市', '47', '47210', '9010300', '沖縄県', 'オキナワケン', '糸満市', 'イトマンシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('119050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県糸満市阿波根', '47', '47210', '9010301', '沖縄県', 'オキナワケン', '糸満市', 'イトマンシ', '阿波根', 'アハゴン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県糸満市潮平', '47', '47210', '9010302', '沖縄県', 'オキナワケン', '糸満市', 'イトマンシ', '潮平', 'シオヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県糸満市兼城', '47', '47210', '9010303', '沖縄県', 'オキナワケン', '糸満市', 'イトマンシ', '兼城', 'カネグスク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県糸満市西川町', '47', '47210', '9010304', '沖縄県', 'オキナワケン', '糸満市', 'イトマンシ', '西川町', 'ニシカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県糸満市西崎', '47', '47210', '9010305', '沖縄県', 'オキナワケン', '糸満市', 'イトマンシ', '西崎', 'ニシザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県糸満市武富', '47', '47210', '9010311', '沖縄県', 'オキナワケン', '糸満市', 'イトマンシ', '武富', 'タケトミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県糸満市北波平', '47', '47210', '9010312', '沖縄県', 'オキナワケン', '糸満市', 'イトマンシ', '北波平', 'キタナミヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県糸満市賀数', '47', '47210', '9010313', '沖縄県', 'オキナワケン', '糸満市', 'イトマンシ', '賀数', 'カカズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県糸満市座波', '47', '47210', '9010314', '沖縄県', 'オキナワケン', '糸満市', 'イトマンシ', '座波', 'ザハ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県糸満市照屋', '47', '47210', '9010315', '沖縄県', 'オキナワケン', '糸満市', 'イトマンシ', '照屋', 'テルヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県糸満市豊原', '47', '47210', '9010321', '沖縄県', 'オキナワケン', '糸満市', 'イトマンシ', '豊原', 'トヨハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県糸満市与座', '47', '47210', '9010322', '沖縄県', 'オキナワケン', '糸満市', 'イトマンシ', '与座', 'ヨザ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県糸満市新垣', '47', '47210', '9010323', '沖縄県', 'オキナワケン', '糸満市', 'イトマンシ', '新垣', 'アラカキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県糸満市国吉', '47', '47210', '9010324', '沖縄県', 'オキナワケン', '糸満市', 'イトマンシ', '国吉', 'クニヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県糸満市大里', '47', '47210', '9010325', '沖縄県', 'オキナワケン', '糸満市', 'イトマンシ', '大里', 'オオザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県糸満市真栄平', '47', '47210', '9010331', '沖縄県', 'オキナワケン', '糸満市', 'イトマンシ', '真栄平', 'マエヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県糸満市宇江城', '47', '47210', '9010332', '沖縄県', 'オキナワケン', '糸満市', 'イトマンシ', '宇江城', 'ウエグスク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県糸満市摩文仁', '47', '47210', '9010333', '沖縄県', 'オキナワケン', '糸満市', 'イトマンシ', '摩文仁', 'マブニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県糸満市大度', '47', '47210', '9010334', '沖縄県', 'オキナワケン', '糸満市', 'イトマンシ', '大度', 'オオド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県糸満市米須', '47', '47210', '9010335', '沖縄県', 'オキナワケン', '糸満市', 'イトマンシ', '米須', 'コメス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県糸満市真壁', '47', '47210', '9010336', '沖縄県', 'オキナワケン', '糸満市', 'イトマンシ', '真壁', 'マカベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県糸満市小波蔵', '47', '47210', '9010341', '沖縄県', 'オキナワケン', '糸満市', 'イトマンシ', '小波蔵', 'コハグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県糸満市糸洲', '47', '47210', '9010342', '沖縄県', 'オキナワケン', '糸満市', 'イトマンシ', '糸洲', 'イトス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県糸満市南波平', '47', '47210', '9010343', '沖縄県', 'オキナワケン', '糸満市', 'イトマンシ', '南波平', 'ミナミナミヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県糸満市伊原', '47', '47210', '9010344', '沖縄県', 'オキナワケン', '糸満市', 'イトマンシ', '伊原', 'イハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県糸満市福地', '47', '47210', '9010345', '沖縄県', 'オキナワケン', '糸満市', 'イトマンシ', '福地', 'フクジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県糸満市名城', '47', '47210', '9010351', '沖縄県', 'オキナワケン', '糸満市', 'イトマンシ', '名城', 'ナシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県糸満市山城', '47', '47210', '9010352', '沖縄県', 'オキナワケン', '糸満市', 'イトマンシ', '山城', 'ヤマグスク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県糸満市束里', '47', '47210', '9010353', '沖縄県', 'オキナワケン', '糸満市', 'イトマンシ', '束里', 'ツカザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県糸満市喜屋武', '47', '47210', '9010354', '沖縄県', 'オキナワケン', '糸満市', 'イトマンシ', '喜屋武', 'キャン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県糸満市糸満', '47', '47210', '9010361', '沖縄県', 'オキナワケン', '糸満市', 'イトマンシ', '糸満', 'イトマン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県糸満市真栄里', '47', '47210', '9010362', '沖縄県', 'オキナワケン', '糸満市', 'イトマンシ', '真栄里', 'マエザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県糸満市伊敷', '47', '47210', '9010363', '沖縄県', 'オキナワケン', '糸満市', 'イトマンシ', '伊敷', 'イシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県糸満市潮崎町', '47', '47210', '9010364', '沖縄県', 'オキナワケン', '糸満市', 'イトマンシ', '潮崎町', 'シオザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡八重瀬町', '47', '47362', '9010400', '沖縄県', 'オキナワケン', '島尻郡八重瀬町', 'シマジリグンヤエセチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('119087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡八重瀬町東風平', '47', '47362', '9010401', '沖縄県', 'オキナワケン', '島尻郡八重瀬町', 'シマジリグンヤエセチョウ', '東風平', 'コチンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡八重瀬町富盛', '47', '47362', '9010402', '沖縄県', 'オキナワケン', '島尻郡八重瀬町', 'シマジリグンヤエセチョウ', '富盛', 'トモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡八重瀬町世名城', '47', '47362', '9010403', '沖縄県', 'オキナワケン', '島尻郡八重瀬町', 'シマジリグンヤエセチョウ', '世名城', 'ヨナグスク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡八重瀬町高良', '47', '47362', '9010404', '沖縄県', 'オキナワケン', '島尻郡八重瀬町', 'シマジリグンヤエセチョウ', '高良', 'タカラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡八重瀬町伊覇', '47', '47362', '9010405', '沖縄県', 'オキナワケン', '島尻郡八重瀬町', 'シマジリグンヤエセチョウ', '伊覇', 'イハ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡八重瀬町屋宜原', '47', '47362', '9010406', '沖縄県', 'オキナワケン', '島尻郡八重瀬町', 'シマジリグンヤエセチョウ', '屋宜原', 'ヤギバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡八重瀬町友寄', '47', '47362', '9010411', '沖縄県', 'オキナワケン', '島尻郡八重瀬町', 'シマジリグンヤエセチョウ', '友寄', 'トモヨセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡八重瀬町上田原', '47', '47362', '9010412', '沖縄県', 'オキナワケン', '島尻郡八重瀬町', 'シマジリグンヤエセチョウ', '上田原', 'ウエタバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡八重瀬町志多伯', '47', '47362', '9010413', '沖縄県', 'オキナワケン', '島尻郡八重瀬町', 'シマジリグンヤエセチョウ', '志多伯', 'シタハク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡八重瀬町当銘', '47', '47362', '9010414', '沖縄県', 'オキナワケン', '島尻郡八重瀬町', 'シマジリグンヤエセチョウ', '当銘', 'トウメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡八重瀬町小城', '47', '47362', '9010415', '沖縄県', 'オキナワケン', '島尻郡八重瀬町', 'シマジリグンヤエセチョウ', '小城', 'コグスク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡八重瀬町宜次', '47', '47362', '9010416', '沖縄県', 'オキナワケン', '島尻郡八重瀬町', 'シマジリグンヤエセチョウ', '宜次', 'ギシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡八重瀬町外間', '47', '47362', '9010417', '沖縄県', 'オキナワケン', '島尻郡八重瀬町', 'シマジリグンヤエセチョウ', '外間', 'ホカマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡八重瀬町長毛', '47', '47362', '9010501', '沖縄県', 'オキナワケン', '島尻郡八重瀬町', 'シマジリグンヤエセチョウ', '長毛', 'ナガモウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡八重瀬町大頓', '47', '47362', '9010502', '沖縄県', 'オキナワケン', '島尻郡八重瀬町', 'シマジリグンヤエセチョウ', '大頓', 'オオトン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡八重瀬町新城', '47', '47362', '9010503', '沖縄県', 'オキナワケン', '島尻郡八重瀬町', 'シマジリグンヤエセチョウ', '新城', 'アラグスク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡八重瀬町後原', '47', '47362', '9010504', '沖縄県', 'オキナワケン', '島尻郡八重瀬町', 'シマジリグンヤエセチョウ', '後原', 'コシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡八重瀬町港川', '47', '47362', '9010511', '沖縄県', 'オキナワケン', '島尻郡八重瀬町', 'シマジリグンヤエセチョウ', '港川', 'ミナトガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡八重瀬町具志頭', '47', '47362', '9010512', '沖縄県', 'オキナワケン', '島尻郡八重瀬町', 'シマジリグンヤエセチョウ', '具志頭', 'グシチャン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡八重瀬町玻名城', '47', '47362', '9010513', '沖縄県', 'オキナワケン', '島尻郡八重瀬町', 'シマジリグンヤエセチョウ', '玻名城', 'ハナシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡八重瀬町安里', '47', '47362', '9010514', '沖縄県', 'オキナワケン', '島尻郡八重瀬町', 'シマジリグンヤエセチョウ', '安里', 'アサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡八重瀬町与座', '47', '47362', '9010515', '沖縄県', 'オキナワケン', '島尻郡八重瀬町', 'シマジリグンヤエセチョウ', '与座', 'ヨザ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡八重瀬町仲座', '47', '47362', '9010516', '沖縄県', 'オキナワケン', '島尻郡八重瀬町', 'シマジリグンヤエセチョウ', '仲座', 'ナカザ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県南城市玉城垣花', '47', '47215', '9010601', '沖縄県', 'オキナワケン', '南城市', 'ナンジョウシ', '玉城垣花', 'タマグスクカキノハナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県南城市玉城仲村渠', '47', '47215', '9010602', '沖縄県', 'オキナワケン', '南城市', 'ナンジョウシ', '玉城仲村渠', 'タマグスクナカンダカリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県南城市玉城百名', '47', '47215', '9010603', '沖縄県', 'オキナワケン', '南城市', 'ナンジョウシ', '玉城百名', 'タマグスクヒャクナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県南城市玉城玉城', '47', '47215', '9010604', '沖縄県', 'オキナワケン', '南城市', 'ナンジョウシ', '玉城玉城', 'タマグスクタマグスク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県南城市玉城中山', '47', '47215', '9010605', '沖縄県', 'オキナワケン', '南城市', 'ナンジョウシ', '玉城中山', 'タマグスクナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県南城市玉城糸数', '47', '47215', '9010606', '沖縄県', 'オキナワケン', '南城市', 'ナンジョウシ', '玉城糸数', 'タマグスクイトカズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県南城市玉城喜良原', '47', '47215', '9010607', '沖縄県', 'オキナワケン', '南城市', 'ナンジョウシ', '玉城喜良原', 'タマグスクキラバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県南城市玉城親慶原', '47', '47215', '9010608', '沖縄県', 'オキナワケン', '南城市', 'ナンジョウシ', '玉城親慶原', 'タマグスクオヤケバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県南城市玉城富里', '47', '47215', '9010611', '沖縄県', 'オキナワケン', '南城市', 'ナンジョウシ', '玉城富里', 'タマグスクフサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県南城市玉城當山', '47', '47215', '9010612', '沖縄県', 'オキナワケン', '南城市', 'ナンジョウシ', '玉城當山', 'タマグスクトウヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県南城市玉城志堅原', '47', '47215', '9010613', '沖縄県', 'オキナワケン', '南城市', 'ナンジョウシ', '玉城志堅原', 'タマグスクシケンバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県南城市玉城奥武', '47', '47215', '9010614', '沖縄県', 'オキナワケン', '南城市', 'ナンジョウシ', '玉城奥武', 'タマグスクオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県南城市玉城堀川', '47', '47215', '9010615', '沖縄県', 'オキナワケン', '南城市', 'ナンジョウシ', '玉城堀川', 'タマグスクホリカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県南城市玉城前川', '47', '47215', '9010616', '沖縄県', 'オキナワケン', '南城市', 'ナンジョウシ', '玉城前川', 'タマグスクマエカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県南城市玉城愛地', '47', '47215', '9010617', '沖縄県', 'オキナワケン', '南城市', 'ナンジョウシ', '玉城愛地', 'タマグスクアイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県南城市玉城船越', '47', '47215', '9010618', '沖縄県', 'オキナワケン', '南城市', 'ナンジョウシ', '玉城船越', 'タマグスクフナコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県南城市玉城屋嘉部', '47', '47215', '9010619', '沖縄県', 'オキナワケン', '南城市', 'ナンジョウシ', '玉城屋嘉部', 'タマグスクヤカブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡南風原町', '47', '47350', '9011100', '沖縄県', 'オキナワケン', '島尻郡南風原町', 'シマジリグンハエバルチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('119135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡南風原町大名', '47', '47350', '9011101', '沖縄県', 'オキナワケン', '島尻郡南風原町', 'シマジリグンハエバルチョウ', '大名', 'オオナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡南風原町宮城', '47', '47350', '9011102', '沖縄県', 'オキナワケン', '島尻郡南風原町', 'シマジリグンハエバルチョウ', '宮城', 'ミヤグスク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡南風原町与那覇', '47', '47350', '9011103', '沖縄県', 'オキナワケン', '島尻郡南風原町', 'シマジリグンハエバルチョウ', '与那覇', 'ヨナハ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡南風原町宮平', '47', '47350', '9011104', '沖縄県', 'オキナワケン', '島尻郡南風原町', 'シマジリグンハエバルチョウ', '宮平', 'ミヤヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡南風原町新川', '47', '47350', '9011105', '沖縄県', 'オキナワケン', '島尻郡南風原町', 'シマジリグンハエバルチョウ', '新川', 'アラカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡南風原町兼城', '47', '47350', '9011111', '沖縄県', 'オキナワケン', '島尻郡南風原町', 'シマジリグンハエバルチョウ', '兼城', 'カネグスク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡南風原町本部', '47', '47350', '9011112', '沖縄県', 'オキナワケン', '島尻郡南風原町', 'シマジリグンハエバルチョウ', '本部', 'モトブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡南風原町喜屋武', '47', '47350', '9011113', '沖縄県', 'オキナワケン', '島尻郡南風原町', 'シマジリグンハエバルチョウ', '喜屋武', 'キャン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡南風原町神里', '47', '47350', '9011114', '沖縄県', 'オキナワケン', '島尻郡南風原町', 'シマジリグンハエバルチョウ', '神里', 'カミザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡南風原町山川', '47', '47350', '9011115', '沖縄県', 'オキナワケン', '島尻郡南風原町', 'シマジリグンハエバルチョウ', '山川', 'ヤマカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡南風原町照屋', '47', '47350', '9011116', '沖縄県', 'オキナワケン', '島尻郡南風原町', 'シマジリグンハエバルチョウ', '照屋', 'テルヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡南風原町津嘉山', '47', '47350', '9011117', '沖縄県', 'オキナワケン', '島尻郡南風原町', 'シマジリグンハエバルチョウ', '津嘉山', 'ツカザン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県南城市大里嶺井', '47', '47215', '9011201', '沖縄県', 'オキナワケン', '南城市', 'ナンジョウシ', '大里嶺井', 'オオザトミネイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県南城市大里大里', '47', '47215', '9011202', '沖縄県', 'オキナワケン', '南城市', 'ナンジョウシ', '大里大里', 'オオザトオオザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県南城市大里大城', '47', '47215', '9011203', '沖縄県', 'オキナワケン', '南城市', 'ナンジョウシ', '大里大城', 'オオザトオオシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県南城市大里稲嶺', '47', '47215', '9011204', '沖縄県', 'オキナワケン', '南城市', 'ナンジョウシ', '大里稲嶺', 'オオザトイナミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県南城市大里高平', '47', '47215', '9011205', '沖縄県', 'オキナワケン', '南城市', 'ナンジョウシ', '大里高平', 'オオザトタカヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県南城市大里仲間', '47', '47215', '9011206', '沖縄県', 'オキナワケン', '南城市', 'ナンジョウシ', '大里仲間', 'オオザトナカマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県南城市大里古堅', '47', '47215', '9011207', '沖縄県', 'オキナワケン', '南城市', 'ナンジョウシ', '大里古堅', 'オオザトフルゲン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡与那原町', '47', '47348', '9011300', '沖縄県', 'オキナワケン', '島尻郡与那原町', 'シマジリグンヨナバルチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('119160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡与那原町板良敷', '47', '47348', '9011301', '沖縄県', 'オキナワケン', '島尻郡与那原町', 'シマジリグンヨナバルチョウ', '板良敷', 'イタラシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡与那原町上与那原', '47', '47348', '9011302', '沖縄県', 'オキナワケン', '島尻郡与那原町', 'シマジリグンヨナバルチョウ', '上与那原', 'ウエヨナバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡与那原町与那原', '47', '47348', '9011303', '沖縄県', 'オキナワケン', '島尻郡与那原町', 'シマジリグンヨナバルチョウ', '与那原', 'ヨナバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡与那原町東浜', '47', '47348', '9011304', '沖縄県', 'オキナワケン', '島尻郡与那原町', 'シマジリグンヨナバルチョウ', '東浜', 'アガリハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県南城市', '47', '47215', '9011400', '沖縄県', 'オキナワケン', '南城市', 'ナンジョウシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('119167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県南城市佐敷伊原', '47', '47215', '9011401', '沖縄県', 'オキナワケン', '南城市', 'ナンジョウシ', '佐敷伊原', 'サシキイバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県南城市佐敷手登根', '47', '47215', '9011402', '沖縄県', 'オキナワケン', '南城市', 'ナンジョウシ', '佐敷手登根', 'サシキテドコン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県南城市佐敷佐敷', '47', '47215', '9011403', '沖縄県', 'オキナワケン', '南城市', 'ナンジョウシ', '佐敷佐敷', 'サシキサシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県南城市佐敷冨祖崎', '47', '47215', '9011404', '沖縄県', 'オキナワケン', '南城市', 'ナンジョウシ', '佐敷冨祖崎', 'サシキフソザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県南城市佐敷仲伊保', '47', '47215', '9011405', '沖縄県', 'オキナワケン', '南城市', 'ナンジョウシ', '佐敷仲伊保', 'サシキナカイホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県南城市佐敷屋比久', '47', '47215', '9011406', '沖縄県', 'オキナワケン', '南城市', 'ナンジョウシ', '佐敷屋比久', 'サシキヤビク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県南城市佐敷兼久', '47', '47215', '9011411', '沖縄県', 'オキナワケン', '南城市', 'ナンジョウシ', '佐敷兼久', 'サシキカネク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県南城市佐敷新里', '47', '47215', '9011412', '沖縄県', 'オキナワケン', '南城市', 'ナンジョウシ', '佐敷新里', 'サシキシンザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県南城市佐敷小谷', '47', '47215', '9011413', '沖縄県', 'オキナワケン', '南城市', 'ナンジョウシ', '佐敷小谷', 'サシキオコク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県南城市佐敷津波古', '47', '47215', '9011414', '沖縄県', 'オキナワケン', '南城市', 'ナンジョウシ', '佐敷津波古', 'サシキツハコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県南城市佐敷新開', '47', '47215', '9011415', '沖縄県', 'オキナワケン', '南城市', 'ナンジョウシ', '佐敷新開', 'サシキシンカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県南城市知念久高', '47', '47215', '9011501', '沖縄県', 'オキナワケン', '南城市', 'ナンジョウシ', '知念久高', 'チネンクダカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県南城市知念安座真', '47', '47215', '9011502', '沖縄県', 'オキナワケン', '南城市', 'ナンジョウシ', '知念安座真', 'チネンアザマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県南城市知念知名', '47', '47215', '9011503', '沖縄県', 'オキナワケン', '南城市', 'ナンジョウシ', '知念知名', 'チネンチナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県南城市知念海野', '47', '47215', '9011504', '沖縄県', 'オキナワケン', '南城市', 'ナンジョウシ', '知念海野', 'チネンウミノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県南城市知念久原', '47', '47215', '9011505', '沖縄県', 'オキナワケン', '南城市', 'ナンジョウシ', '知念久原', 'チネンクハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県南城市知念久手堅', '47', '47215', '9011511', '沖縄県', 'オキナワケン', '南城市', 'ナンジョウシ', '知念久手堅', 'チネンクデケン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県南城市知念吉富', '47', '47215', '9011512', '沖縄県', 'オキナワケン', '南城市', 'ナンジョウシ', '知念吉富', 'チネンヨシトミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県南城市知念知念', '47', '47215', '9011513', '沖縄県', 'オキナワケン', '南城市', 'ナンジョウシ', '知念知念', 'チネンチネン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県南城市知念具志堅', '47', '47215', '9011514', '沖縄県', 'オキナワケン', '南城市', 'ナンジョウシ', '知念具志堅', 'チネングシケン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県南城市知念山里', '47', '47215', '9011515', '沖縄県', 'オキナワケン', '南城市', 'ナンジョウシ', '知念山里', 'チネンヤマザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県南城市知念志喜屋', '47', '47215', '9011516', '沖縄県', 'オキナワケン', '南城市', 'ナンジョウシ', '知念志喜屋', 'チネンシキヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県浦添市', '47', '47208', '9012100', '沖縄県', 'オキナワケン', '浦添市', 'ウラソエシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('119192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県浦添市西原', '47', '47208', '9012101', '沖縄県', 'オキナワケン', '浦添市', 'ウラソエシ', '西原', 'ニシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県浦添市前田', '47', '47208', '9012102', '沖縄県', 'オキナワケン', '浦添市', 'ウラソエシ', '前田', 'マエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県浦添市仲間', '47', '47208', '9012103', '沖縄県', 'オキナワケン', '浦添市', 'ウラソエシ', '仲間', 'ナカマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県浦添市当山', '47', '47208', '9012104', '沖縄県', 'オキナワケン', '浦添市', 'ウラソエシ', '当山', 'トウヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県浦添市経塚', '47', '47208', '9012111', '沖縄県', 'オキナワケン', '浦添市', 'ウラソエシ', '経塚', 'キョウヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県浦添市沢岻', '47', '47208', '9012112', '沖縄県', 'オキナワケン', '浦添市', 'ウラソエシ', '沢岻', 'タクシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県浦添市大平', '47', '47208', '9012113', '沖縄県', 'オキナワケン', '浦添市', 'ウラソエシ', '大平', 'オオヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県浦添市安波茶', '47', '47208', '9012114', '沖縄県', 'オキナワケン', '浦添市', 'ウラソエシ', '安波茶', 'アハチャ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県浦添市内間', '47', '47208', '9012121', '沖縄県', 'オキナワケン', '浦添市', 'ウラソエシ', '内間', 'ウチマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県浦添市勢理客', '47', '47208', '9012122', '沖縄県', 'オキナワケン', '浦添市', 'ウラソエシ', '勢理客', 'ジッチャク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県浦添市西洲', '47', '47208', '9012123', '沖縄県', 'オキナワケン', '浦添市', 'ウラソエシ', '西洲', 'イリジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県浦添市小湾', '47', '47208', '9012124', '沖縄県', 'オキナワケン', '浦添市', 'ウラソエシ', '小湾', 'コワン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県浦添市仲西', '47', '47208', '9012125', '沖縄県', 'オキナワケン', '浦添市', 'ウラソエシ', '仲西', 'ナカニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県浦添市宮城', '47', '47208', '9012126', '沖縄県', 'オキナワケン', '浦添市', 'ウラソエシ', '宮城', 'ミヤギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県浦添市屋富祖', '47', '47208', '9012127', '沖縄県', 'オキナワケン', '浦添市', 'ウラソエシ', '屋富祖', 'ヤフソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県浦添市伊奈武瀬', '47', '47208', '9012128', '沖縄県', 'オキナワケン', '浦添市', 'ウラソエシ', '伊奈武瀬', 'イナンセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県浦添市牧港', '47', '47208', '9012131', '沖縄県', 'オキナワケン', '浦添市', 'ウラソエシ', '牧港', 'マキミナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県浦添市伊祖', '47', '47208', '9012132', '沖縄県', 'オキナワケン', '浦添市', 'ウラソエシ', '伊祖', 'イソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県浦添市城間', '47', '47208', '9012133', '沖縄県', 'オキナワケン', '浦添市', 'ウラソエシ', '城間', 'グスクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県浦添市港川', '47', '47208', '9012134', '沖縄県', 'オキナワケン', '浦添市', 'ウラソエシ', '港川', 'ミナトガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県宜野湾市', '47', '47205', '9012200', '沖縄県', 'オキナワケン', '宜野湾市', 'ギノワンシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('119213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県宜野湾市新城', '47', '47205', '9012201', '沖縄県', 'オキナワケン', '宜野湾市', 'ギノワンシ', '新城', 'アラグスク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県宜野湾市普天間', '47', '47205', '9012202', '沖縄県', 'オキナワケン', '宜野湾市', 'ギノワンシ', '普天間', 'フテンマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県宜野湾市野嵩', '47', '47205', '9012203', '沖縄県', 'オキナワケン', '宜野湾市', 'ギノワンシ', '野嵩', 'ノダケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県宜野湾市上原', '47', '47205', '9012204', '沖縄県', 'オキナワケン', '宜野湾市', 'ギノワンシ', '上原', 'ウエハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県宜野湾市赤道', '47', '47205', '9012205', '沖縄県', 'オキナワケン', '宜野湾市', 'ギノワンシ', '赤道', 'アカミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県宜野湾市愛知', '47', '47205', '9012206', '沖縄県', 'オキナワケン', '宜野湾市', 'ギノワンシ', '愛知', 'アイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県宜野湾市神山', '47', '47205', '9012207', '沖縄県', 'オキナワケン', '宜野湾市', 'ギノワンシ', '神山', 'カミヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県宜野湾市宜野湾', '47', '47205', '9012211', '沖縄県', 'オキナワケン', '宜野湾市', 'ギノワンシ', '宜野湾', 'ギノワン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県宜野湾市長田', '47', '47205', '9012212', '沖縄県', 'オキナワケン', '宜野湾市', 'ギノワンシ', '長田', 'ナガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県宜野湾市志真志', '47', '47205', '9012213', '沖縄県', 'オキナワケン', '宜野湾市', 'ギノワンシ', '志真志', 'シマシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県宜野湾市我如古', '47', '47205', '9012214', '沖縄県', 'オキナワケン', '宜野湾市', 'ギノワンシ', '我如古', 'ガネコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県宜野湾市真栄原', '47', '47205', '9012215', '沖縄県', 'オキナワケン', '宜野湾市', 'ギノワンシ', '真栄原', 'マエハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県宜野湾市佐真下', '47', '47205', '9012216', '沖縄県', 'オキナワケン', '宜野湾市', 'ギノワンシ', '佐真下', 'サマシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県宜野湾市伊佐', '47', '47205', '9012221', '沖縄県', 'オキナワケン', '宜野湾市', 'ギノワンシ', '伊佐', 'イサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県宜野湾市喜友名', '47', '47205', '9012222', '沖縄県', 'オキナワケン', '宜野湾市', 'ギノワンシ', '喜友名', 'キュウナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県宜野湾市大山', '47', '47205', '9012223', '沖縄県', 'オキナワケン', '宜野湾市', 'ギノワンシ', '大山', 'オオヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県宜野湾市真志喜', '47', '47205', '9012224', '沖縄県', 'オキナワケン', '宜野湾市', 'ギノワンシ', '真志喜', 'マシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県宜野湾市大謝名', '47', '47205', '9012225', '沖縄県', 'オキナワケン', '宜野湾市', 'ギノワンシ', '大謝名', 'オオジャナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県宜野湾市嘉数', '47', '47205', '9012226', '沖縄県', 'オキナワケン', '宜野湾市', 'ギノワンシ', '嘉数', 'カカズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県宜野湾市宇地泊', '47', '47205', '9012227', '沖縄県', 'オキナワケン', '宜野湾市', 'ギノワンシ', '宇地泊', 'ウチドマリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県中頭郡北中城村', '47', '47327', '9012300', '沖縄県', 'オキナワケン', '中頭郡北中城村', 'ナカガミグンキタナカグスクソン', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('119234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県中頭郡北中城村島袋', '47', '47327', '9012301', '沖縄県', 'オキナワケン', '中頭郡北中城村', 'ナカガミグンキタナカグスクソン', '島袋', 'シマブク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県中頭郡北中城村渡口', '47', '47327', '9012302', '沖縄県', 'オキナワケン', '中頭郡北中城村', 'ナカガミグンキタナカグスクソン', '渡口', 'トグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県中頭郡北中城村仲順', '47', '47327', '9012303', '沖縄県', 'オキナワケン', '中頭郡北中城村', 'ナカガミグンキタナカグスクソン', '仲順', 'チュンジュン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県中頭郡北中城村屋宜原', '47', '47327', '9012304', '沖縄県', 'オキナワケン', '中頭郡北中城村', 'ナカガミグンキタナカグスクソン', '屋宜原', 'ヤギバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県中頭郡北中城村比嘉', '47', '47327', '9012305', '沖縄県', 'オキナワケン', '中頭郡北中城村', 'ナカガミグンキタナカグスクソン', '比嘉', 'ヒガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県中頭郡北中城村喜舎場', '47', '47327', '9012311', '沖縄県', 'オキナワケン', '中頭郡北中城村', 'ナカガミグンキタナカグスクソン', '喜舎場', 'キシャバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県中頭郡北中城村和仁屋', '47', '47327', '9012312', '沖縄県', 'オキナワケン', '中頭郡北中城村', 'ナカガミグンキタナカグスクソン', '和仁屋', 'ワニヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県中頭郡北中城村熱田', '47', '47327', '9012313', '沖縄県', 'オキナワケン', '中頭郡北中城村', 'ナカガミグンキタナカグスクソン', '熱田', 'アツタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県中頭郡北中城村大城', '47', '47327', '9012314', '沖縄県', 'オキナワケン', '中頭郡北中城村', 'ナカガミグンキタナカグスクソン', '大城', 'オオグスク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県中頭郡北中城村荻道', '47', '47327', '9012315', '沖縄県', 'オキナワケン', '中頭郡北中城村', 'ナカガミグンキタナカグスクソン', '荻道', 'オギドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県中頭郡北中城村安谷屋', '47', '47327', '9012316', '沖縄県', 'オキナワケン', '中頭郡北中城村', 'ナカガミグンキタナカグスクソン', '安谷屋', 'アダニヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県中頭郡北中城村瑞慶覧', '47', '47327', '9012317', '沖縄県', 'オキナワケン', '中頭郡北中城村', 'ナカガミグンキタナカグスクソン', '瑞慶覧', 'ズケラン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県中頭郡北中城村美崎', '47', '47327', '9012321', '沖縄県', 'オキナワケン', '中頭郡北中城村', 'ナカガミグンキタナカグスクソン', '美崎', 'ミサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県中頭郡中城村', '47', '47328', '9012400', '沖縄県', 'オキナワケン', '中頭郡中城村', 'ナカガミグンナカグスクソン', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('119250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県中頭郡中城村久場', '47', '47328', '9012401', '沖縄県', 'オキナワケン', '中頭郡中城村', 'ナカガミグンナカグスクソン', '久場', 'クバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県中頭郡中城村泊', '47', '47328', '9012402', '沖縄県', 'オキナワケン', '中頭郡中城村', 'ナカガミグンナカグスクソン', '泊', 'トマリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県中頭郡中城村伊舎堂', '47', '47328', '9012403', '沖縄県', 'オキナワケン', '中頭郡中城村', 'ナカガミグンナカグスクソン', '伊舎堂', 'イシャドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県中頭郡中城村添石', '47', '47328', '9012404', '沖縄県', 'オキナワケン', '中頭郡中城村', 'ナカガミグンナカグスクソン', '添石', 'ソエシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県中頭郡中城村屋宜', '47', '47328', '9012405', '沖縄県', 'オキナワケン', '中頭郡中城村', 'ナカガミグンナカグスクソン', '屋宜', 'ヤギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県中頭郡中城村当間', '47', '47328', '9012406', '沖縄県', 'オキナワケン', '中頭郡中城村', 'ナカガミグンナカグスクソン', '当間', 'トウマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県中頭郡中城村安里', '47', '47328', '9012407', '沖縄県', 'オキナワケン', '中頭郡中城村', 'ナカガミグンナカグスクソン', '安里', 'アサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県中頭郡中城村浜', '47', '47328', '9012411', '沖縄県', 'オキナワケン', '中頭郡中城村', 'ナカガミグンナカグスクソン', '浜', 'ハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県中頭郡中城村奥間', '47', '47328', '9012412', '沖縄県', 'オキナワケン', '中頭郡中城村', 'ナカガミグンナカグスクソン', '奥間', 'オクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県中頭郡中城村津覇', '47', '47328', '9012413', '沖縄県', 'オキナワケン', '中頭郡中城村', 'ナカガミグンナカグスクソン', '津覇', 'ツハ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県中頭郡中城村北浜', '47', '47328', '9012414', '沖縄県', 'オキナワケン', '中頭郡中城村', 'ナカガミグンナカグスクソン', '北浜', 'キタハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県中頭郡中城村南浜', '47', '47328', '9012415', '沖縄県', 'オキナワケン', '中頭郡中城村', 'ナカガミグンナカグスクソン', '南浜', 'ミナミハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県中頭郡中城村和宇慶', '47', '47328', '9012416', '沖縄県', 'オキナワケン', '中頭郡中城村', 'ナカガミグンナカグスクソン', '和宇慶', 'ワウケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県中頭郡中城村伊集', '47', '47328', '9012417', '沖縄県', 'オキナワケン', '中頭郡中城村', 'ナカガミグンナカグスクソン', '伊集', 'イジュ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県中頭郡中城村登又', '47', '47328', '9012421', '沖縄県', 'オキナワケン', '中頭郡中城村', 'ナカガミグンナカグスクソン', '登又', 'ノボリマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県中頭郡中城村新垣', '47', '47328', '9012422', '沖縄県', 'オキナワケン', '中頭郡中城村', 'ナカガミグンナカグスクソン', '新垣', 'アラカキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県中頭郡中城村北上原', '47', '47328', '9012423', '沖縄県', 'オキナワケン', '中頭郡中城村', 'ナカガミグンナカグスクソン', '北上原', 'キタウエバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県中頭郡中城村南上原', '47', '47328', '9012424', '沖縄県', 'オキナワケン', '中頭郡中城村', 'ナカガミグンナカグスクソン', '南上原', 'ミナミウエバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡久米島町', '47', '47361', '9013100', '沖縄県', 'オキナワケン', '島尻郡久米島町', 'シマジリグンクメジマチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('119311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡久米島町宇江城', '47', '47361', '9013101', '沖縄県', 'オキナワケン', '島尻郡久米島町', 'シマジリグンクメジマチョウ', '宇江城', 'ウエグスク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡久米島町比屋定', '47', '47361', '9013102', '沖縄県', 'オキナワケン', '島尻郡久米島町', 'シマジリグンクメジマチョウ', '比屋定', 'ヒヤジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡久米島町阿嘉', '47', '47361', '9013103', '沖縄県', 'オキナワケン', '島尻郡久米島町', 'シマジリグンクメジマチョウ', '阿嘉', 'アカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡久米島町真謝', '47', '47361', '9013104', '沖縄県', 'オキナワケン', '島尻郡久米島町', 'シマジリグンクメジマチョウ', '真謝', 'マジャ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡久米島町宇根', '47', '47361', '9013105', '沖縄県', 'オキナワケン', '島尻郡久米島町', 'シマジリグンクメジマチョウ', '宇根', 'ウネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡久米島町奥武', '47', '47361', '9013106', '沖縄県', 'オキナワケン', '島尻郡久米島町', 'シマジリグンクメジマチョウ', '奥武', 'オウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡久米島町謝名堂', '47', '47361', '9013107', '沖縄県', 'オキナワケン', '島尻郡久米島町', 'シマジリグンクメジマチョウ', '謝名堂', 'ジャナドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡久米島町比嘉', '47', '47361', '9013108', '沖縄県', 'オキナワケン', '島尻郡久米島町', 'シマジリグンクメジマチョウ', '比嘉', 'ヒガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡久米島町山城', '47', '47361', '9013111', '沖縄県', 'オキナワケン', '島尻郡久米島町', 'シマジリグンクメジマチョウ', '山城', 'ヤマグスク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡久米島町真我里', '47', '47361', '9013112', '沖縄県', 'オキナワケン', '島尻郡久米島町', 'シマジリグンクメジマチョウ', '真我里', 'マガリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡久米島町銭田', '47', '47361', '9013113', '沖縄県', 'オキナワケン', '島尻郡久米島町', 'シマジリグンクメジマチョウ', '銭田', 'ゼンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡久米島町島尻', '47', '47361', '9013114', '沖縄県', 'オキナワケン', '島尻郡久米島町', 'シマジリグンクメジマチョウ', '島尻', 'シマジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡久米島町儀間', '47', '47361', '9013115', '沖縄県', 'オキナワケン', '島尻郡久米島町', 'シマジリグンクメジマチョウ', '儀間', 'ギマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡久米島町嘉手苅', '47', '47361', '9013121', '沖縄県', 'オキナワケン', '島尻郡久米島町', 'シマジリグンクメジマチョウ', '嘉手苅', 'カデカル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡久米島町兼城', '47', '47361', '9013122', '沖縄県', 'オキナワケン', '島尻郡久米島町', 'シマジリグンクメジマチョウ', '兼城', 'カネグスク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡久米島町大田', '47', '47361', '9013123', '沖縄県', 'オキナワケン', '島尻郡久米島町', 'シマジリグンクメジマチョウ', '大田', 'オオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡久米島町仲泊', '47', '47361', '9013124', '沖縄県', 'オキナワケン', '島尻郡久米島町', 'シマジリグンクメジマチョウ', '仲泊', 'ナカドマリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡久米島町鳥島', '47', '47361', '9013125', '沖縄県', 'オキナワケン', '島尻郡久米島町', 'シマジリグンクメジマチョウ', '鳥島', 'トリシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡久米島町西銘', '47', '47361', '9013131', '沖縄県', 'オキナワケン', '島尻郡久米島町', 'シマジリグンクメジマチョウ', '西銘', 'ニシメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡久米島町大原', '47', '47361', '9013132', '沖縄県', 'オキナワケン', '島尻郡久米島町', 'シマジリグンクメジマチョウ', '大原', 'オオハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡久米島町北原', '47', '47361', '9013133', '沖縄県', 'オキナワケン', '島尻郡久米島町', 'シマジリグンクメジマチョウ', '北原', 'キタハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡久米島町具志川', '47', '47361', '9013134', '沖縄県', 'オキナワケン', '島尻郡久米島町', 'シマジリグンクメジマチョウ', '具志川', 'グシカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡久米島町仲村渠', '47', '47361', '9013135', '沖縄県', 'オキナワケン', '島尻郡久米島町', 'シマジリグンクメジマチョウ', '仲村渠', 'ナカンダカリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡久米島町仲地', '47', '47361', '9013136', '沖縄県', 'オキナワケン', '島尻郡久米島町', 'シマジリグンクメジマチョウ', '仲地', 'ナカチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡久米島町山里', '47', '47361', '9013137', '沖縄県', 'オキナワケン', '島尻郡久米島町', 'シマジリグンクメジマチョウ', '山里', 'ヤマザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡久米島町上江洲', '47', '47361', '9013138', '沖縄県', 'オキナワケン', '島尻郡久米島町', 'シマジリグンクメジマチョウ', '上江洲', 'ウエズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡座間味村阿嘉', '47', '47354', '9013311', '沖縄県', 'オキナワケン', '島尻郡座間味村', 'シマジリグンザマミソン', '阿嘉', 'アカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡座間味村慶留間', '47', '47354', '9013312', '沖縄県', 'オキナワケン', '島尻郡座間味村', 'シマジリグンザマミソン', '慶留間', 'ゲルマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡座間味村', '47', '47354', '9013400', '沖縄県', 'オキナワケン', '島尻郡座間味村', 'シマジリグンザマミソン', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('119342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡座間味村阿佐', '47', '47354', '9013401', '沖縄県', 'オキナワケン', '島尻郡座間味村', 'シマジリグンザマミソン', '阿佐', 'アサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡座間味村座間味', '47', '47354', '9013402', '沖縄県', 'オキナワケン', '島尻郡座間味村', 'シマジリグンザマミソン', '座間味', 'ザマミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡座間味村阿真', '47', '47354', '9013403', '沖縄県', 'オキナワケン', '島尻郡座間味村', 'シマジリグンザマミソン', '阿真', 'アマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡渡嘉敷村', '47', '47353', '9013500', '沖縄県', 'オキナワケン', '島尻郡渡嘉敷村', 'シマジリグントカシキソン', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('119347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡渡嘉敷村渡嘉敷', '47', '47353', '9013501', '沖縄県', 'オキナワケン', '島尻郡渡嘉敷村', 'シマジリグントカシキソン', '渡嘉敷', 'トカシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡渡嘉敷村阿波連', '47', '47353', '9013502', '沖縄県', 'オキナワケン', '島尻郡渡嘉敷村', 'シマジリグントカシキソン', '阿波連', 'アハレン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡渡名喜村', '47', '47356', '9013601', '沖縄県', 'オキナワケン', '島尻郡渡名喜村', 'シマジリグントナキソン', null, '　', '（全域）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('119353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡粟国村', '47', '47355', '9013700', '沖縄県', 'オキナワケン', '島尻郡粟国村', 'シマジリグンアグニソン', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('119354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡粟国村浜', '47', '47355', '9013701', '沖縄県', 'オキナワケン', '島尻郡粟国村', 'シマジリグンアグニソン', '浜', 'ハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡粟国村東', '47', '47355', '9013702', '沖縄県', 'オキナワケン', '島尻郡粟国村', 'シマジリグンアグニソン', '東', 'ヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡粟国村西', '47', '47355', '9013703', '沖縄県', 'オキナワケン', '島尻郡粟国村', 'シマジリグンアグニソン', '西', 'ニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡南大東村', '47', '47357', '9013800', '沖縄県', 'オキナワケン', '島尻郡南大東村', 'シマジリグンミナミダイトウソン', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('119359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡南大東村北', '47', '47357', '9013801', '沖縄県', 'オキナワケン', '島尻郡南大東村', 'シマジリグンミナミダイトウソン', '北', 'キタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡南大東村新東', '47', '47357', '9013802', '沖縄県', 'オキナワケン', '島尻郡南大東村', 'シマジリグンミナミダイトウソン', '新東', 'シントウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡南大東村旧東', '47', '47357', '9013803', '沖縄県', 'オキナワケン', '島尻郡南大東村', 'シマジリグンミナミダイトウソン', '旧東', 'キュウトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡南大東村南', '47', '47357', '9013804', '沖縄県', 'オキナワケン', '島尻郡南大東村', 'シマジリグンミナミダイトウソン', '南', 'ミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡南大東村在所', '47', '47357', '9013805', '沖縄県', 'オキナワケン', '島尻郡南大東村', 'シマジリグンミナミダイトウソン', '在所', 'ザイショ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡南大東村池之沢', '47', '47357', '9013806', '沖縄県', 'オキナワケン', '島尻郡南大東村', 'シマジリグンミナミダイトウソン', '池之沢', 'イケノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡北大東村', '47', '47358', '9013900', '沖縄県', 'オキナワケン', '島尻郡北大東村', 'シマジリグンキタダイトウソン', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('119367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡北大東村南', '47', '47358', '9013901', '沖縄県', 'オキナワケン', '島尻郡北大東村', 'シマジリグンキタダイトウソン', '南', 'ミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡北大東村中野', '47', '47358', '9013902', '沖縄県', 'オキナワケン', '島尻郡北大東村', 'シマジリグンキタダイトウソン', '中野', 'ナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡北大東村港', '47', '47358', '9013903', '沖縄県', 'オキナワケン', '島尻郡北大東村', 'シマジリグンキタダイトウソン', '港', 'ミナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県那覇市古島', '47', '47201', '9020061', '沖縄県', 'オキナワケン', '那覇市', 'ナハシ', '古島', 'フルジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県那覇市松川', '47', '47201', '9020062', '沖縄県', 'オキナワケン', '那覇市', 'ナハシ', '松川', 'マツガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県那覇市三原', '47', '47201', '9020063', '沖縄県', 'オキナワケン', '那覇市', 'ナハシ', '三原', 'ミハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県那覇市寄宮', '47', '47201', '9020064', '沖縄県', 'オキナワケン', '那覇市', 'ナハシ', '寄宮', 'ヨリミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県那覇市壺屋', '47', '47201', '9020065', '沖縄県', 'オキナワケン', '那覇市', 'ナハシ', '壺屋', 'ツボヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県那覇市大道', '47', '47201', '9020066', '沖縄県', 'オキナワケン', '那覇市', 'ナハシ', '大道', 'ダイドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県那覇市安里', '47', '47201', '9020067', '沖縄県', 'オキナワケン', '那覇市', 'ナハシ', '安里', 'アサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県那覇市真嘉比', '47', '47201', '9020068', '沖縄県', 'オキナワケン', '那覇市', 'ナハシ', '真嘉比', 'マカビ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県那覇市松島', '47', '47201', '9020069', '沖縄県', 'オキナワケン', '那覇市', 'ナハシ', '松島', 'マツシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県那覇市繁多川', '47', '47201', '9020071', '沖縄県', 'オキナワケン', '那覇市', 'ナハシ', '繁多川', 'ハンタガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県那覇市真地', '47', '47201', '9020072', '沖縄県', 'オキナワケン', '那覇市', 'ナハシ', '真地', 'マアジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県那覇市上間', '47', '47201', '9020073', '沖縄県', 'オキナワケン', '那覇市', 'ナハシ', '上間', 'ウエマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県那覇市仲井真', '47', '47201', '9020074', '沖縄県', 'オキナワケン', '那覇市', 'ナハシ', '仲井真', 'ナカイマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県那覇市国場', '47', '47201', '9020075', '沖縄県', 'オキナワケン', '那覇市', 'ナハシ', '国場', 'コクバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県那覇市与儀', '47', '47201', '9020076', '沖縄県', 'オキナワケン', '那覇市', 'ナハシ', '与儀', 'ヨギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県那覇市長田', '47', '47201', '9020077', '沖縄県', 'オキナワケン', '那覇市', 'ナハシ', '長田', 'ナガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県那覇市識名', '47', '47201', '9020078', '沖縄県', 'オキナワケン', '那覇市', 'ナハシ', '識名', 'シキナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県中頭郡西原町', '47', '47329', '9030100', '沖縄県', 'オキナワケン', '中頭郡西原町', 'ナカガミグンニシハラチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('119397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県中頭郡西原町掛保久', '47', '47329', '9030101', '沖縄県', 'オキナワケン', '中頭郡西原町', 'ナカガミグンニシハラチョウ', '掛保久', 'カケボク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県中頭郡西原町嘉手苅', '47', '47329', '9030102', '沖縄県', 'オキナワケン', '中頭郡西原町', 'ナカガミグンニシハラチョウ', '嘉手苅', 'カデカル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県中頭郡西原町小那覇', '47', '47329', '9030103', '沖縄県', 'オキナワケン', '中頭郡西原町', 'ナカガミグンニシハラチョウ', '小那覇', 'オナハ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県中頭郡西原町兼久', '47', '47329', '9030104', '沖縄県', 'オキナワケン', '中頭郡西原町', 'ナカガミグンニシハラチョウ', '兼久', 'カネク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県中頭郡西原町東崎', '47', '47329', '9030105', '沖縄県', 'オキナワケン', '中頭郡西原町', 'ナカガミグンニシハラチョウ', '東崎', 'アガリザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県中頭郡西原町与那城', '47', '47329', '9030111', '沖縄県', 'オキナワケン', '中頭郡西原町', 'ナカガミグンニシハラチョウ', '与那城', 'ヨナグスク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県中頭郡西原町我謝', '47', '47329', '9030112', '沖縄県', 'オキナワケン', '中頭郡西原町', 'ナカガミグンニシハラチョウ', '我謝', 'ガジャ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県中頭郡西原町安室', '47', '47329', '9030113', '沖縄県', 'オキナワケン', '中頭郡西原町', 'ナカガミグンニシハラチョウ', '安室', 'アムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県中頭郡西原町桃原', '47', '47329', '9030114', '沖縄県', 'オキナワケン', '中頭郡西原町', 'ナカガミグンニシハラチョウ', '桃原', 'トウバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県中頭郡西原町池田', '47', '47329', '9030115', '沖縄県', 'オキナワケン', '中頭郡西原町', 'ナカガミグンニシハラチョウ', '池田', 'イケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県中頭郡西原町幸地', '47', '47329', '9030116', '沖縄県', 'オキナワケン', '中頭郡西原町', 'ナカガミグンニシハラチョウ', '幸地', 'コウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県中頭郡西原町翁長', '47', '47329', '9030117', '沖縄県', 'オキナワケン', '中頭郡西原町', 'ナカガミグンニシハラチョウ', '翁長', 'オナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県中頭郡西原町小波津', '47', '47329', '9030118', '沖縄県', 'オキナワケン', '中頭郡西原町', 'ナカガミグンニシハラチョウ', '小波津', 'コハツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県中頭郡西原町内間', '47', '47329', '9030121', '沖縄県', 'オキナワケン', '中頭郡西原町', 'ナカガミグンニシハラチョウ', '内間', 'ウチマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県中頭郡西原町小橋川', '47', '47329', '9030122', '沖縄県', 'オキナワケン', '中頭郡西原町', 'ナカガミグンニシハラチョウ', '小橋川', 'コバシガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県中頭郡西原町津花波', '47', '47329', '9030123', '沖縄県', 'オキナワケン', '中頭郡西原町', 'ナカガミグンニシハラチョウ', '津花波', 'ツハナハ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県中頭郡西原町呉屋', '47', '47329', '9030124', '沖縄県', 'オキナワケン', '中頭郡西原町', 'ナカガミグンニシハラチョウ', '呉屋', 'ゴヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県中頭郡西原町上原', '47', '47329', '9030125', '沖縄県', 'オキナワケン', '中頭郡西原町', 'ナカガミグンニシハラチョウ', '上原', 'ウエハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県中頭郡西原町棚原', '47', '47329', '9030126', '沖縄県', 'オキナワケン', '中頭郡西原町', 'ナカガミグンニシハラチョウ', '棚原', 'タナバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県中頭郡西原町徳佐田', '47', '47329', '9030127', '沖縄県', 'オキナワケン', '中頭郡西原町', 'ナカガミグンニシハラチョウ', '徳佐田', 'トクサダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県中頭郡西原町森川', '47', '47329', '9030128', '沖縄県', 'オキナワケン', '中頭郡西原町', 'ナカガミグンニシハラチョウ', '森川', 'モリカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県中頭郡西原町千原', '47', '47329', '9030129', '沖縄県', 'オキナワケン', '中頭郡西原町', 'ナカガミグンニシハラチョウ', '千原', 'センバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県那覇市首里末吉町', '47', '47201', '9030801', '沖縄県', 'オキナワケン', '那覇市', 'ナハシ', '首里末吉町', 'シュリスエヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県那覇市首里大名町', '47', '47201', '9030802', '沖縄県', 'オキナワケン', '那覇市', 'ナハシ', '首里大名町', 'シュリオオナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県那覇市首里平良町', '47', '47201', '9030803', '沖縄県', 'オキナワケン', '那覇市', 'ナハシ', '首里平良町', 'シュリタイラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県那覇市首里石嶺町', '47', '47201', '9030804', '沖縄県', 'オキナワケン', '那覇市', 'ナハシ', '首里石嶺町', 'シュリイシミネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県那覇市首里鳥堀町', '47', '47201', '9030805', '沖縄県', 'オキナワケン', '那覇市', 'ナハシ', '首里鳥堀町', 'シュリトリホリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県那覇市首里汀良町', '47', '47201', '9030806', '沖縄県', 'オキナワケン', '那覇市', 'ナハシ', '首里汀良町', 'シュリテラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県那覇市首里久場川町', '47', '47201', '9030807', '沖縄県', 'オキナワケン', '那覇市', 'ナハシ', '首里久場川町', 'シュリクバガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県那覇市首里赤平町', '47', '47201', '9030811', '沖縄県', 'オキナワケン', '那覇市', 'ナハシ', '首里赤平町', 'シュリアカヒラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県那覇市首里当蔵町', '47', '47201', '9030812', '沖縄県', 'オキナワケン', '那覇市', 'ナハシ', '首里当蔵町', 'シュリトウノクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県那覇市首里赤田町', '47', '47201', '9030813', '沖縄県', 'オキナワケン', '那覇市', 'ナハシ', '首里赤田町', 'シュリアカタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県那覇市首里崎山町', '47', '47201', '9030814', '沖縄県', 'オキナワケン', '那覇市', 'ナハシ', '首里崎山町', 'シュリサキヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県那覇市首里金城町', '47', '47201', '9030815', '沖縄県', 'オキナワケン', '那覇市', 'ナハシ', '首里金城町', 'シュリキンジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県那覇市首里真和志町', '47', '47201', '9030816', '沖縄県', 'オキナワケン', '那覇市', 'ナハシ', '首里真和志町', 'シュリマワシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県那覇市首里儀保町', '47', '47201', '9030821', '沖縄県', 'オキナワケン', '那覇市', 'ナハシ', '首里儀保町', 'シュリギボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県那覇市首里桃原町', '47', '47201', '9030822', '沖縄県', 'オキナワケン', '那覇市', 'ナハシ', '首里桃原町', 'シュリトウバルチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県那覇市首里大中町', '47', '47201', '9030823', '沖縄県', 'オキナワケン', '那覇市', 'ナハシ', '首里大中町', 'シュリオオナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県那覇市首里池端町', '47', '47201', '9030824', '沖縄県', 'オキナワケン', '那覇市', 'ナハシ', '首里池端町', 'シュリイケハタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県那覇市首里山川町', '47', '47201', '9030825', '沖縄県', 'オキナワケン', '那覇市', 'ナハシ', '首里山川町', 'シュリヤマガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県那覇市首里寒川町', '47', '47201', '9030826', '沖縄県', 'オキナワケン', '那覇市', 'ナハシ', '首里寒川町', 'シュリサムカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県沖縄市', '47', '47211', '9040000', '沖縄県', 'オキナワケン', '沖縄市', 'オキナワシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('119456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県沖縄市越来', '47', '47211', '9040001', '沖縄県', 'オキナワケン', '沖縄市', 'オキナワシ', '越来', 'ゴエク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県沖縄市城前町', '47', '47211', '9040002', '沖縄県', 'オキナワケン', '沖縄市', 'オキナワシ', '城前町', 'シロマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県沖縄市住吉', '47', '47211', '9040003', '沖縄県', 'オキナワケン', '沖縄市', 'オキナワシ', '住吉', 'スミヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県沖縄市中央', '47', '47211', '9040004', '沖縄県', 'オキナワケン', '沖縄市', 'オキナワシ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県沖縄市嘉間良', '47', '47211', '9040005', '沖縄県', 'オキナワケン', '沖縄市', 'オキナワシ', '嘉間良', 'カマラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県沖縄市八重島', '47', '47211', '9040006', '沖縄県', 'オキナワケン', '沖縄市', 'オキナワシ', '八重島', 'ヤエシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県沖縄市照屋', '47', '47211', '9040011', '沖縄県', 'オキナワケン', '沖縄市', 'オキナワシ', '照屋', 'テルヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県沖縄市安慶田', '47', '47211', '9040012', '沖縄県', 'オキナワケン', '沖縄市', 'オキナワシ', '安慶田', 'アゲダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県沖縄市室川', '47', '47211', '9040013', '沖縄県', 'オキナワケン', '沖縄市', 'オキナワシ', '室川', 'ムロカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県沖縄市仲宗根町', '47', '47211', '9040014', '沖縄県', 'オキナワケン', '沖縄市', 'オキナワシ', '仲宗根町', 'ナカソネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県沖縄市胡屋', '47', '47211', '9040021', '沖縄県', 'オキナワケン', '沖縄市', 'オキナワシ', '胡屋', 'ゴヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県沖縄市園田', '47', '47211', '9040022', '沖縄県', 'オキナワケン', '沖縄市', 'オキナワシ', '園田', 'ソノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県沖縄市久保田', '47', '47211', '9040023', '沖縄県', 'オキナワケン', '沖縄市', 'オキナワシ', '久保田', 'クボタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県沖縄市上地', '47', '47211', '9040031', '沖縄県', 'オキナワケン', '沖縄市', 'オキナワシ', '上地', 'ウエチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県沖縄市諸見里', '47', '47211', '9040032', '沖縄県', 'オキナワケン', '沖縄市', 'オキナワシ', '諸見里', 'モロミザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県沖縄市山里', '47', '47211', '9040033', '沖縄県', 'オキナワケン', '沖縄市', 'オキナワシ', '山里', 'ヤマザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県沖縄市山内', '47', '47211', '9040034', '沖縄県', 'オキナワケン', '沖縄市', 'オキナワシ', '山内', 'ヤマウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県沖縄市南桃原', '47', '47211', '9040035', '沖縄県', 'オキナワケン', '沖縄市', 'オキナワシ', '南桃原', 'ミナミトウバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県中頭郡北谷町', '47', '47326', '9040100', '沖縄県', 'オキナワケン', '中頭郡北谷町', 'ナカガミグンチャタンチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('119475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県中頭郡北谷町上勢頭', '47', '47326', '9040101', '沖縄県', 'オキナワケン', '中頭郡北谷町', 'ナカガミグンチャタンチョウ', '上勢頭', 'カミセイド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県中頭郡北谷町伊平', '47', '47326', '9040102', '沖縄県', 'オキナワケン', '中頭郡北谷町', 'ナカガミグンチャタンチョウ', '伊平', 'イヘイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県中頭郡北谷町桑江', '47', '47326', '9040103', '沖縄県', 'オキナワケン', '中頭郡北谷町', 'ナカガミグンチャタンチョウ', '桑江', 'クワエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県中頭郡北谷町桃原', '47', '47326', '9040104', '沖縄県', 'オキナワケン', '中頭郡北谷町', 'ナカガミグンチャタンチョウ', '桃原', 'トウバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県中頭郡北谷町吉原', '47', '47326', '9040105', '沖縄県', 'オキナワケン', '中頭郡北谷町', 'ナカガミグンチャタンチョウ', '吉原', 'ヨシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県中頭郡北谷町玉上', '47', '47326', '9040106', '沖縄県', 'オキナワケン', '中頭郡北谷町', 'ナカガミグンチャタンチョウ', '玉上', 'タマガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県中頭郡北谷町大村', '47', '47326', '9040107', '沖縄県', 'オキナワケン', '中頭郡北谷町', 'ナカガミグンチャタンチョウ', '大村', 'オオムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県中頭郡北谷町砂辺', '47', '47326', '9040111', '沖縄県', 'オキナワケン', '中頭郡北谷町', 'ナカガミグンチャタンチョウ', '砂辺', 'スナベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県中頭郡北谷町浜川', '47', '47326', '9040112', '沖縄県', 'オキナワケン', '中頭郡北谷町', 'ナカガミグンチャタンチョウ', '浜川', 'ハマガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県中頭郡北谷町宮城', '47', '47326', '9040113', '沖縄県', 'オキナワケン', '中頭郡北谷町', 'ナカガミグンチャタンチョウ', '宮城', 'ミヤギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県中頭郡北谷町港', '47', '47326', '9040114', '沖縄県', 'オキナワケン', '中頭郡北谷町', 'ナカガミグンチャタンチョウ', '港', 'ミナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県中頭郡北谷町美浜', '47', '47326', '9040115', '沖縄県', 'オキナワケン', '中頭郡北谷町', 'ナカガミグンチャタンチョウ', '美浜', 'ミハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県中頭郡北谷町北谷', '47', '47326', '9040116', '沖縄県', 'オキナワケン', '中頭郡北谷町', 'ナカガミグンチャタンチョウ', '北谷', 'チャタン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県中頭郡北谷町北前', '47', '47326', '9040117', '沖縄県', 'オキナワケン', '中頭郡北谷町', 'ナカガミグンチャタンチョウ', '北前', 'キタマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県中頭郡嘉手納町', '47', '47325', '9040200', '沖縄県', 'オキナワケン', '中頭郡嘉手納町', 'ナカガミグンカデナチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('119494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県中頭郡嘉手納町久得', '47', '47325', '9040201', '沖縄県', 'オキナワケン', '中頭郡嘉手納町', 'ナカガミグンカデナチョウ', '久得', 'クドク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県中頭郡嘉手納町屋良', '47', '47325', '9040202', '沖縄県', 'オキナワケン', '中頭郡嘉手納町', 'ナカガミグンカデナチョウ', '屋良', 'ヤラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県中頭郡嘉手納町嘉手納', '47', '47325', '9040203', '沖縄県', 'オキナワケン', '中頭郡嘉手納町', 'ナカガミグンカデナチョウ', '嘉手納', 'カデナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県中頭郡嘉手納町水釜', '47', '47325', '9040204', '沖縄県', 'オキナワケン', '中頭郡嘉手納町', 'ナカガミグンカデナチョウ', '水釜', 'ミズガマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県中頭郡嘉手納町兼久', '47', '47325', '9040205', '沖縄県', 'オキナワケン', '中頭郡嘉手納町', 'ナカガミグンカデナチョウ', '兼久', 'カネク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県中頭郡読谷村', '47', '47324', '9040300', '沖縄県', 'オキナワケン', '中頭郡読谷村', 'ナカガミグンヨミタンソン', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('119502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県中頭郡読谷村座喜味', '47', '47324', '9040301', '沖縄県', 'オキナワケン', '中頭郡読谷村', 'ナカガミグンヨミタンソン', '座喜味', 'ザキミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県中頭郡読谷村喜名', '47', '47324', '9040302', '沖縄県', 'オキナワケン', '中頭郡読谷村', 'ナカガミグンヨミタンソン', '喜名', 'キナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県中頭郡読谷村伊良皆', '47', '47324', '9040303', '沖縄県', 'オキナワケン', '中頭郡読谷村', 'ナカガミグンヨミタンソン', '伊良皆', 'イラミナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県中頭郡読谷村楚辺', '47', '47324', '9040304', '沖縄県', 'オキナワケン', '中頭郡読谷村', 'ナカガミグンヨミタンソン', '楚辺', 'ソベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県中頭郡読谷村都屋', '47', '47324', '9040305', '沖縄県', 'オキナワケン', '中頭郡読谷村', 'ナカガミグンヨミタンソン', '都屋', 'トヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県中頭郡読谷村比謝', '47', '47324', '9040311', '沖縄県', 'オキナワケン', '中頭郡読谷村', 'ナカガミグンヨミタンソン', '比謝', 'ヒジャ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県中頭郡読谷村比謝矼', '47', '47324', '9040312', '沖縄県', 'オキナワケン', '中頭郡読谷村', 'ナカガミグンヨミタンソン', '比謝矼', 'ヒジャバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県中頭郡読谷村大湾', '47', '47324', '9040313', '沖縄県', 'オキナワケン', '中頭郡読谷村', 'ナカガミグンヨミタンソン', '大湾', 'オオワン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県中頭郡読谷村古堅', '47', '47324', '9040314', '沖縄県', 'オキナワケン', '中頭郡読谷村', 'ナカガミグンヨミタンソン', '古堅', 'フルゲン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県中頭郡読谷村渡具知', '47', '47324', '9040315', '沖縄県', 'オキナワケン', '中頭郡読谷村', 'ナカガミグンヨミタンソン', '渡具知', 'トグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県中頭郡読谷村大木', '47', '47324', '9040316', '沖縄県', 'オキナワケン', '中頭郡読谷村', 'ナカガミグンヨミタンソン', '大木', 'オオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県中頭郡読谷村上地', '47', '47324', '9040321', '沖縄県', 'オキナワケン', '中頭郡読谷村', 'ナカガミグンヨミタンソン', '上地', 'ウエチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県中頭郡読谷村波平', '47', '47324', '9040322', '沖縄県', 'オキナワケン', '中頭郡読谷村', 'ナカガミグンヨミタンソン', '波平', 'ナミヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県中頭郡読谷村高志保', '47', '47324', '9040323', '沖縄県', 'オキナワケン', '中頭郡読谷村', 'ナカガミグンヨミタンソン', '高志保', 'タカシホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県中頭郡読谷村長浜', '47', '47324', '9040324', '沖縄県', 'オキナワケン', '中頭郡読谷村', 'ナカガミグンヨミタンソン', '長浜', 'ナガハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県中頭郡読谷村瀬名波', '47', '47324', '9040325', '沖縄県', 'オキナワケン', '中頭郡読谷村', 'ナカガミグンヨミタンソン', '瀬名波', 'セナハ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県中頭郡読谷村渡慶次', '47', '47324', '9040326', '沖縄県', 'オキナワケン', '中頭郡読谷村', 'ナカガミグンヨミタンソン', '渡慶次', 'トケシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県中頭郡読谷村儀間', '47', '47324', '9040327', '沖縄県', 'オキナワケン', '中頭郡読谷村', 'ナカガミグンヨミタンソン', '儀間', 'ギマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県中頭郡読谷村宇座', '47', '47324', '9040328', '沖縄県', 'オキナワケン', '中頭郡読谷村', 'ナカガミグンヨミタンソン', '宇座', 'ウザ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡恩納村', '47', '47311', '9040400', '沖縄県', 'オキナワケン', '国頭郡恩納村', 'クニガミグンオンナソン', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('119526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡恩納村名嘉真', '47', '47311', '9040401', '沖縄県', 'オキナワケン', '国頭郡恩納村', 'クニガミグンオンナソン', '名嘉真', 'ナカマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡恩納村安富祖', '47', '47311', '9040402', '沖縄県', 'オキナワケン', '国頭郡恩納村', 'クニガミグンオンナソン', '安富祖', 'アフソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡恩納村喜瀬武原', '47', '47311', '9040403', '沖縄県', 'オキナワケン', '国頭郡恩納村', 'クニガミグンオンナソン', '喜瀬武原', 'キセンバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡恩納村瀬良垣', '47', '47311', '9040404', '沖縄県', 'オキナワケン', '国頭郡恩納村', 'クニガミグンオンナソン', '瀬良垣', 'セラカキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡恩納村恩納', '47', '47311', '9040411', '沖縄県', 'オキナワケン', '国頭郡恩納村', 'クニガミグンオンナソン', '恩納', 'オンナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡恩納村谷茶', '47', '47311', '9040412', '沖縄県', 'オキナワケン', '国頭郡恩納村', 'クニガミグンオンナソン', '谷茶', 'タンチャ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡恩納村冨着', '47', '47311', '9040413', '沖縄県', 'オキナワケン', '国頭郡恩納村', 'クニガミグンオンナソン', '冨着', 'フチャク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡恩納村前兼久', '47', '47311', '9040414', '沖縄県', 'オキナワケン', '国頭郡恩納村', 'クニガミグンオンナソン', '前兼久', 'マエガネク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡恩納村仲泊', '47', '47311', '9040415', '沖縄県', 'オキナワケン', '国頭郡恩納村', 'クニガミグンオンナソン', '仲泊', 'ナカドマリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡恩納村山田', '47', '47311', '9040416', '沖縄県', 'オキナワケン', '国頭郡恩納村', 'クニガミグンオンナソン', '山田', 'ヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡恩納村真栄田', '47', '47311', '9040417', '沖縄県', 'オキナワケン', '国頭郡恩納村', 'クニガミグンオンナソン', '真栄田', 'マエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県うるま市石川東山本町', '47', '47213', '9041101', '沖縄県', 'オキナワケン', 'うるま市', 'ウルマシ', '石川東山本町', 'イシカワアガリヤマモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県うるま市石川東山', '47', '47213', '9041102', '沖縄県', 'オキナワケン', 'うるま市', 'ウルマシ', '石川東山', 'イシカワアガリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県うるま市石川赤崎', '47', '47213', '9041103', '沖縄県', 'オキナワケン', 'うるま市', 'ウルマシ', '石川赤崎', 'イシカワアカサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県うるま市石川石崎', '47', '47213', '9041104', '沖縄県', 'オキナワケン', 'うるま市', 'ウルマシ', '石川石崎', 'イシカワイシザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県うるま市石川白浜', '47', '47213', '9041105', '沖縄県', 'オキナワケン', 'うるま市', 'ウルマシ', '石川白浜', 'イシカワシラハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県うるま市石川', '47', '47213', '9041106', '沖縄県', 'オキナワケン', 'うるま市', 'ウルマシ', '石川', 'イシカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県うるま市石川曙', '47', '47213', '9041107', '沖縄県', 'オキナワケン', 'うるま市', 'ウルマシ', '石川曙', 'イシカワアケボノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県うるま市石川東恩納', '47', '47213', '9041111', '沖縄県', 'オキナワケン', 'うるま市', 'ウルマシ', '石川東恩納', 'イシカワヒガシオンナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県うるま市石川楚南', '47', '47213', '9041112', '沖縄県', 'オキナワケン', 'うるま市', 'ウルマシ', '石川楚南', 'イシカワソナン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県うるま市石川山城', '47', '47213', '9041113', '沖縄県', 'オキナワケン', 'うるま市', 'ウルマシ', '石川山城', 'イシカワヤマシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県うるま市石川嘉手苅', '47', '47213', '9041114', '沖縄県', 'オキナワケン', 'うるま市', 'ウルマシ', '石川嘉手苅', 'イシカワカデカル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県うるま市石川伊波', '47', '47213', '9041115', '沖縄県', 'オキナワケン', 'うるま市', 'ウルマシ', '石川伊波', 'イシカワイハ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡金武町', '47', '47314', '9041200', '沖縄県', 'オキナワケン', '国頭郡金武町', 'クニガミグンキンチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('119555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡金武町金武', '47', '47314', '9041201', '沖縄県', 'オキナワケン', '国頭郡金武町', 'クニガミグンキンチョウ', '金武', 'キン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡金武町伊芸', '47', '47314', '9041202', '沖縄県', 'オキナワケン', '国頭郡金武町', 'クニガミグンキンチョウ', '伊芸', 'イゲイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡金武町屋嘉', '47', '47314', '9041203', '沖縄県', 'オキナワケン', '国頭郡金武町', 'クニガミグンキンチョウ', '屋嘉', 'ヤカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡宜野座村', '47', '47313', '9041300', '沖縄県', 'オキナワケン', '国頭郡宜野座村', 'クニガミグンギノザソン', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('119562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡宜野座村松田', '47', '47313', '9041301', '沖縄県', 'オキナワケン', '国頭郡宜野座村', 'クニガミグンギノザソン', '松田', 'マツダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡宜野座村宜野座', '47', '47313', '9041302', '沖縄県', 'オキナワケン', '国頭郡宜野座村', 'クニガミグンギノザソン', '宜野座', 'ギノザ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡宜野座村惣慶', '47', '47313', '9041303', '沖縄県', 'オキナワケン', '国頭郡宜野座村', 'クニガミグンギノザソン', '惣慶', 'ソケイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡宜野座村漢那', '47', '47313', '9041304', '沖縄県', 'オキナワケン', '国頭郡宜野座村', 'クニガミグンギノザソン', '漢那', 'カンナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県沖縄市池原', '47', '47211', '9042141', '沖縄県', 'オキナワケン', '沖縄市', 'オキナワシ', '池原', 'イケハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県沖縄市登川', '47', '47211', '9042142', '沖縄県', 'オキナワケン', '沖縄市', 'オキナワシ', '登川', 'ノボリカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県沖縄市知花', '47', '47211', '9042143', '沖縄県', 'オキナワケン', '沖縄市', 'オキナワシ', '知花', 'チバナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県沖縄市白川', '47', '47211', '9042144', '沖縄県', 'オキナワケン', '沖縄市', 'オキナワシ', '白川', 'シラカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県沖縄市倉敷', '47', '47211', '9042145', '沖縄県', 'オキナワケン', '沖縄市', 'オキナワシ', '倉敷', 'クラシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県沖縄市松本', '47', '47211', '9042151', '沖縄県', 'オキナワケン', '沖縄市', 'オキナワシ', '松本', 'マツモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県沖縄市明道', '47', '47211', '9042152', '沖縄県', 'オキナワケン', '沖縄市', 'オキナワシ', '明道', 'アケミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県沖縄市美里', '47', '47211', '9042153', '沖縄県', 'オキナワケン', '沖縄市', 'オキナワシ', '美里', 'ミサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県沖縄市東', '47', '47211', '9042154', '沖縄県', 'オキナワケン', '沖縄市', 'オキナワシ', '東', 'ヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県沖縄市美原', '47', '47211', '9042155', '沖縄県', 'オキナワケン', '沖縄市', 'オキナワシ', '美原', 'ミハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県沖縄市古謝', '47', '47211', '9042161', '沖縄県', 'オキナワケン', '沖縄市', 'オキナワシ', '古謝', 'コジャ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県沖縄市海邦', '47', '47211', '9042162', '沖縄県', 'オキナワケン', '沖縄市', 'オキナワシ', '海邦', 'カイホウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県沖縄市海邦町', '47', '47211', '9042162', '沖縄県', 'オキナワケン', '沖縄市', 'オキナワシ', '海邦町', 'カイホウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県沖縄市大里', '47', '47211', '9042163', '沖縄県', 'オキナワケン', '沖縄市', 'オキナワシ', '大里', 'オオザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県沖縄市桃原', '47', '47211', '9042164', '沖縄県', 'オキナワケン', '沖縄市', 'オキナワシ', '桃原', 'トウバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県沖縄市宮里', '47', '47211', '9042165', '沖縄県', 'オキナワケン', '沖縄市', 'オキナワシ', '宮里', 'ミヤザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県沖縄市高原', '47', '47211', '9042171', '沖縄県', 'オキナワケン', '沖縄市', 'オキナワシ', '高原', 'タカハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県沖縄市泡瀬', '47', '47211', '9042172', '沖縄県', 'オキナワケン', '沖縄市', 'オキナワシ', '泡瀬', 'アワセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県沖縄市比屋根', '47', '47211', '9042173', '沖縄県', 'オキナワケン', '沖縄市', 'オキナワシ', '比屋根', 'ヒヤゴン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県沖縄市与儀', '47', '47211', '9042174', '沖縄県', 'オキナワケン', '沖縄市', 'オキナワシ', '与儀', 'ヨギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県うるま市', '47', '47213', '9042200', '沖縄県', 'オキナワケン', 'うるま市', 'ウルマシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('119593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県うるま市昆布', '47', '47213', '9042201', '沖縄県', 'オキナワケン', 'うるま市', 'ウルマシ', '昆布', 'コンブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県うるま市天願', '47', '47213', '9042202', '沖縄県', 'オキナワケン', 'うるま市', 'ウルマシ', '天願', 'テンガン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県うるま市川崎', '47', '47213', '9042203', '沖縄県', 'オキナワケン', 'うるま市', 'ウルマシ', '川崎', 'カワサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県うるま市西原', '47', '47213', '9042204', '沖縄県', 'オキナワケン', 'うるま市', 'ウルマシ', '西原', 'イリバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県うるま市栄野比', '47', '47213', '9042205', '沖縄県', 'オキナワケン', 'うるま市', 'ウルマシ', '栄野比', 'エノビ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県うるま市宇堅', '47', '47213', '9042211', '沖縄県', 'オキナワケン', 'うるま市', 'ウルマシ', '宇堅', 'ウケン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県うるま市赤野', '47', '47213', '9042212', '沖縄県', 'オキナワケン', 'うるま市', 'ウルマシ', '赤野', 'アカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県うるま市田場', '47', '47213', '9042213', '沖縄県', 'オキナワケン', 'うるま市', 'ウルマシ', '田場', 'タバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県うるま市安慶名', '47', '47213', '9042214', '沖縄県', 'オキナワケン', 'うるま市', 'ウルマシ', '安慶名', 'アゲナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県うるま市みどり町', '47', '47213', '9042215', '沖縄県', 'オキナワケン', 'うるま市', 'ウルマシ', 'みどり町', 'ミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県うるま市平良川', '47', '47213', '9042221', '沖縄県', 'オキナワケン', 'うるま市', 'ウルマシ', '平良川', 'タイラガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県うるま市上江洲', '47', '47213', '9042222', '沖縄県', 'オキナワケン', 'うるま市', 'ウルマシ', '上江洲', 'ウエズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県うるま市具志川', '47', '47213', '9042223', '沖縄県', 'オキナワケン', 'うるま市', 'ウルマシ', '具志川', 'グシカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県うるま市大田', '47', '47213', '9042224', '沖縄県', 'オキナワケン', 'うるま市', 'ウルマシ', '大田', 'オオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県うるま市喜屋武', '47', '47213', '9042225', '沖縄県', 'オキナワケン', 'うるま市', 'ウルマシ', '喜屋武', 'キャン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県うるま市仲嶺', '47', '47213', '9042226', '沖縄県', 'オキナワケン', 'うるま市', 'ウルマシ', '仲嶺', 'ナカミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県うるま市塩屋', '47', '47213', '9042231', '沖縄県', 'オキナワケン', 'うるま市', 'ウルマシ', '塩屋', 'シオヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県うるま市川田', '47', '47213', '9042232', '沖縄県', 'オキナワケン', 'うるま市', 'ウルマシ', '川田', 'カワタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県うるま市豊原', '47', '47213', '9042233', '沖縄県', 'オキナワケン', 'うるま市', 'ウルマシ', '豊原', 'トヨハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県うるま市州崎', '47', '47213', '9042234', '沖縄県', 'オキナワケン', 'うるま市', 'ウルマシ', '州崎', 'スザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県うるま市前原', '47', '47213', '9042235', '沖縄県', 'オキナワケン', 'うるま市', 'ウルマシ', '前原', 'マエハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県うるま市喜仲', '47', '47213', '9042236', '沖縄県', 'オキナワケン', 'うるま市', 'ウルマシ', '喜仲', 'キナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県うるま市兼箇段', '47', '47213', '9042241', '沖縄県', 'オキナワケン', 'うるま市', 'ウルマシ', '兼箇段', 'カネカダン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県うるま市高江洲', '47', '47213', '9042242', '沖縄県', 'オキナワケン', 'うるま市', 'ウルマシ', '高江洲', 'タカエス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県うるま市宮里', '47', '47213', '9042243', '沖縄県', 'オキナワケン', 'うるま市', 'ウルマシ', '宮里', 'ミヤザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県うるま市江洲', '47', '47213', '9042244', '沖縄県', 'オキナワケン', 'うるま市', 'ウルマシ', '江洲', 'エス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県うるま市赤道', '47', '47213', '9042245', '沖縄県', 'オキナワケン', 'うるま市', 'ウルマシ', '赤道', 'アカミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県うるま市与那城照間', '47', '47213', '9042301', '沖縄県', 'オキナワケン', 'うるま市', 'ウルマシ', '与那城照間', 'ヨナシロテルマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県うるま市与那城西原', '47', '47213', '9042302', '沖縄県', 'オキナワケン', 'うるま市', 'ウルマシ', '与那城西原', 'ヨナシロニシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県うるま市与那城', '47', '47213', '9042303', '沖縄県', 'オキナワケン', 'うるま市', 'ウルマシ', '与那城', 'ヨナシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県うるま市与那城屋慶名', '47', '47213', '9042304', '沖縄県', 'オキナワケン', 'うるま市', 'ウルマシ', '与那城屋慶名', 'ヨナシロヤケナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県うるま市与那城中央', '47', '47213', '9042305', '沖縄県', 'オキナワケン', 'うるま市', 'ウルマシ', '与那城中央', 'ヨナシロチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県うるま市与那城安勢理', '47', '47213', '9042306', '沖縄県', 'オキナワケン', 'うるま市', 'ウルマシ', '与那城安勢理', 'ヨナシロアセリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県うるま市与那城饒辺', '47', '47213', '9042307', '沖縄県', 'オキナワケン', 'うるま市', 'ウルマシ', '与那城饒辺', 'ヨナシロノヘン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県うるま市勝連南風原', '47', '47213', '9042311', '沖縄県', 'オキナワケン', 'うるま市', 'ウルマシ', '勝連南風原', 'カツレンハエバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県うるま市勝連平安名', '47', '47213', '9042312', '沖縄県', 'オキナワケン', 'うるま市', 'ウルマシ', '勝連平安名', 'カツレンヘンナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県うるま市勝連内間', '47', '47213', '9042313', '沖縄県', 'オキナワケン', 'うるま市', 'ウルマシ', '勝連内間', 'カツレンウチマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県うるま市勝連平敷屋', '47', '47213', '9042314', '沖縄県', 'オキナワケン', 'うるま市', 'ウルマシ', '勝連平敷屋', 'カツレンヘシキヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県うるま市勝連浜', '47', '47213', '9042315', '沖縄県', 'オキナワケン', 'うるま市', 'ウルマシ', '勝連浜', 'カツレンハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県うるま市勝連比嘉', '47', '47213', '9042316', '沖縄県', 'オキナワケン', 'うるま市', 'ウルマシ', '勝連比嘉', 'カツレンヒガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県うるま市勝連津堅', '47', '47213', '9042317', '沖縄県', 'オキナワケン', 'うるま市', 'ウルマシ', '勝連津堅', 'カツレンツケン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県うるま市与那城伊計', '47', '47213', '9042421', '沖縄県', 'オキナワケン', 'うるま市', 'ウルマシ', '与那城伊計', 'ヨナシロイケイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県うるま市与那城池味', '47', '47213', '9042422', '沖縄県', 'オキナワケン', 'うるま市', 'ウルマシ', '与那城池味', 'ヨナシロイケミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県うるま市与那城宮城', '47', '47213', '9042423', '沖縄県', 'オキナワケン', 'うるま市', 'ウルマシ', '与那城宮城', 'ヨナシロミヤギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県うるま市与那城上原', '47', '47213', '9042424', '沖縄県', 'オキナワケン', 'うるま市', 'ウルマシ', '与那城上原', 'ヨナシロウエハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県うるま市与那城桃原', '47', '47213', '9042425', '沖縄県', 'オキナワケン', 'うるま市', 'ウルマシ', '与那城桃原', 'ヨナシロトウバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県うるま市与那城平安座', '47', '47213', '9042426', '沖縄県', 'オキナワケン', 'うるま市', 'ウルマシ', '与那城平安座', 'ヨナシロヘンザ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県うるま市与那城屋平', '47', '47213', '9042427', '沖縄県', 'オキナワケン', 'うるま市', 'ウルマシ', '与那城屋平', 'ヨナシロヤヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県うるま市与那城平宮', '47', '47213', '9042428', '沖縄県', 'オキナワケン', 'うるま市', 'ウルマシ', '与那城平宮', 'ヨナシロヒラミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県名護市', '47', '47209', '9050000', '沖縄県', 'オキナワケン', '名護市', 'ナゴシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('119651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県名護市安和', '47', '47209', '9050001', '沖縄県', 'オキナワケン', '名護市', 'ナゴシ', '安和', 'アワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県名護市勝山', '47', '47209', '9050002', '沖縄県', 'オキナワケン', '名護市', 'ナゴシ', '勝山', 'カツヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県名護市旭川', '47', '47209', '9050003', '沖縄県', 'オキナワケン', '名護市', 'ナゴシ', '旭川', 'アサヒカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県名護市中山', '47', '47209', '9050004', '沖縄県', 'オキナワケン', '名護市', 'ナゴシ', '中山', 'ナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県名護市為又', '47', '47209', '9050005', '沖縄県', 'オキナワケン', '名護市', 'ナゴシ', '為又', 'ビイマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県名護市宇茂佐', '47', '47209', '9050006', '沖縄県', 'オキナワケン', '名護市', 'ナゴシ', '宇茂佐', 'ウムサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県名護市屋部', '47', '47209', '9050007', '沖縄県', 'オキナワケン', '名護市', 'ナゴシ', '屋部', 'ヤブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県名護市山入端', '47', '47209', '9050008', '沖縄県', 'オキナワケン', '名護市', 'ナゴシ', '山入端', 'ヤマノハ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県名護市宮里', '47', '47209', '9050011', '沖縄県', 'オキナワケン', '名護市', 'ナゴシ', '宮里', 'ミヤザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県名護市名護', '47', '47209', '9050012', '沖縄県', 'オキナワケン', '名護市', 'ナゴシ', '名護', 'ナゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県名護市城', '47', '47209', '9050013', '沖縄県', 'オキナワケン', '名護市', 'ナゴシ', '城', 'グスク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県名護市港', '47', '47209', '9050014', '沖縄県', 'オキナワケン', '名護市', 'ナゴシ', '港', 'ミナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県名護市大南', '47', '47209', '9050015', '沖縄県', 'オキナワケン', '名護市', 'ナゴシ', '大南', 'オオミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県名護市大東', '47', '47209', '9050016', '沖縄県', 'オキナワケン', '名護市', 'ナゴシ', '大東', 'オオヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県名護市大中', '47', '47209', '9050017', '沖縄県', 'オキナワケン', '名護市', 'ナゴシ', '大中', 'オオナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県名護市大西', '47', '47209', '9050018', '沖縄県', 'オキナワケン', '名護市', 'ナゴシ', '大西', 'オオニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県名護市大北', '47', '47209', '9050019', '沖縄県', 'オキナワケン', '名護市', 'ナゴシ', '大北', 'オオキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県名護市東江', '47', '47209', '9050021', '沖縄県', 'オキナワケン', '名護市', 'ナゴシ', '東江', 'アガリエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県名護市世冨慶', '47', '47209', '9050022', '沖縄県', 'オキナワケン', '名護市', 'ナゴシ', '世冨慶', 'ヨフケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県名護市数久田', '47', '47209', '9050023', '沖縄県', 'オキナワケン', '名護市', 'ナゴシ', '数久田', 'スクタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県名護市許田', '47', '47209', '9050024', '沖縄県', 'オキナワケン', '名護市', 'ナゴシ', '許田', 'キョダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県名護市幸喜', '47', '47209', '9050025', '沖縄県', 'オキナワケン', '名護市', 'ナゴシ', '幸喜', 'コウキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県名護市喜瀬', '47', '47209', '9050026', '沖縄県', 'オキナワケン', '名護市', 'ナゴシ', '喜瀬', 'キセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡本部町', '47', '47308', '9050200', '沖縄県', 'オキナワケン', '国頭郡本部町', 'クニガミグンモトブチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('119675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡本部町具志堅', '47', '47308', '9050201', '沖縄県', 'オキナワケン', '国頭郡本部町', 'クニガミグンモトブチョウ', '具志堅', 'グシケン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡本部町嘉津宇', '47', '47308', '9050202', '沖縄県', 'オキナワケン', '国頭郡本部町', 'クニガミグンモトブチョウ', '嘉津宇', 'カツウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡本部町謝花', '47', '47308', '9050203', '沖縄県', 'オキナワケン', '国頭郡本部町', 'クニガミグンモトブチョウ', '謝花', 'ジャハナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡本部町豊原', '47', '47308', '9050204', '沖縄県', 'オキナワケン', '国頭郡本部町', 'クニガミグンモトブチョウ', '豊原', 'トヨハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡本部町山川', '47', '47308', '9050205', '沖縄県', 'オキナワケン', '国頭郡本部町', 'クニガミグンモトブチョウ', '山川', 'ヤマカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡本部町石川', '47', '47308', '9050206', '沖縄県', 'オキナワケン', '国頭郡本部町', 'クニガミグンモトブチョウ', '石川', 'イシカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡本部町備瀬', '47', '47308', '9050207', '沖縄県', 'オキナワケン', '国頭郡本部町', 'クニガミグンモトブチョウ', '備瀬', 'ビセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡本部町新里', '47', '47308', '9050208', '沖縄県', 'オキナワケン', '国頭郡本部町', 'クニガミグンモトブチョウ', '新里', 'シンザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡本部町北里', '47', '47308', '9050209', '沖縄県', 'オキナワケン', '国頭郡本部町', 'クニガミグンモトブチョウ', '北里', 'キタザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡本部町東', '47', '47308', '9050211', '沖縄県', 'オキナワケン', '国頭郡本部町', 'クニガミグンモトブチョウ', '東', 'ヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡本部町大浜', '47', '47308', '9050212', '沖縄県', 'オキナワケン', '国頭郡本部町', 'クニガミグンモトブチョウ', '大浜', 'オオハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡本部町谷茶', '47', '47308', '9050213', '沖縄県', 'オキナワケン', '国頭郡本部町', 'クニガミグンモトブチョウ', '谷茶', 'タンチャ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡本部町渡久地', '47', '47308', '9050214', '沖縄県', 'オキナワケン', '国頭郡本部町', 'クニガミグンモトブチョウ', '渡久地', 'トグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡本部町野原', '47', '47308', '9050215', '沖縄県', 'オキナワケン', '国頭郡本部町', 'クニガミグンモトブチョウ', '野原', 'ノバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡本部町浜元', '47', '47308', '9050216', '沖縄県', 'オキナワケン', '国頭郡本部町', 'クニガミグンモトブチョウ', '浜元', 'ハマモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡本部町浦崎', '47', '47308', '9050217', '沖縄県', 'オキナワケン', '国頭郡本部町', 'クニガミグンモトブチョウ', '浦崎', 'ウラサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡本部町古島', '47', '47308', '9050218', '沖縄県', 'オキナワケン', '国頭郡本部町', 'クニガミグンモトブチョウ', '古島', 'フルジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡本部町山里', '47', '47308', '9050219', '沖縄県', 'オキナワケン', '国頭郡本部町', 'クニガミグンモトブチョウ', '山里', 'ヤマザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡本部町伊豆味', '47', '47308', '9050221', '沖縄県', 'オキナワケン', '国頭郡本部町', 'クニガミグンモトブチョウ', '伊豆味', 'イズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡本部町並里', '47', '47308', '9050222', '沖縄県', 'オキナワケン', '国頭郡本部町', 'クニガミグンモトブチョウ', '並里', 'ナミザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡本部町大嘉陽', '47', '47308', '9050223', '沖縄県', 'オキナワケン', '国頭郡本部町', 'クニガミグンモトブチョウ', '大嘉陽', 'オオカヨウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡本部町辺名地', '47', '47308', '9050224', '沖縄県', 'オキナワケン', '国頭郡本部町', 'クニガミグンモトブチョウ', '辺名地', 'ヘナジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡本部町崎本部', '47', '47308', '9050225', '沖縄県', 'オキナワケン', '国頭郡本部町', 'クニガミグンモトブチョウ', '崎本部', 'サキモトブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡本部町健堅', '47', '47308', '9050226', '沖縄県', 'オキナワケン', '国頭郡本部町', 'クニガミグンモトブチョウ', '健堅', 'ケンケン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡本部町瀬底', '47', '47308', '9050227', '沖縄県', 'オキナワケン', '国頭郡本部町', 'クニガミグンモトブチョウ', '瀬底', 'セソコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡本部町伊野波', '47', '47308', '9050228', '沖縄県', 'オキナワケン', '国頭郡本部町', 'クニガミグンモトブチョウ', '伊野波', 'イノハ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡本部町大堂', '47', '47308', '9050229', '沖縄県', 'オキナワケン', '国頭郡本部町', 'クニガミグンモトブチョウ', '大堂', 'ウフドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡今帰仁村', '47', '47306', '9050400', '沖縄県', 'オキナワケン', '国頭郡今帰仁村', 'クニガミグンナキジンソン', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('119704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡今帰仁村仲宗根', '47', '47306', '9050401', '沖縄県', 'オキナワケン', '国頭郡今帰仁村', 'クニガミグンナキジンソン', '仲宗根', 'ナカソネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡今帰仁村渡喜仁', '47', '47306', '9050402', '沖縄県', 'オキナワケン', '国頭郡今帰仁村', 'クニガミグンナキジンソン', '渡喜仁', 'トキジン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡今帰仁村運天', '47', '47306', '9050403', '沖縄県', 'オキナワケン', '国頭郡今帰仁村', 'クニガミグンナキジンソン', '運天', 'ウンテン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡今帰仁村上運天', '47', '47306', '9050404', '沖縄県', 'オキナワケン', '国頭郡今帰仁村', 'クニガミグンナキジンソン', '上運天', 'カミウンテン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡今帰仁村勢理客', '47', '47306', '9050405', '沖縄県', 'オキナワケン', '国頭郡今帰仁村', 'クニガミグンナキジンソン', '勢理客', 'セリキャク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡今帰仁村古宇利', '47', '47306', '9050406', '沖縄県', 'オキナワケン', '国頭郡今帰仁村', 'クニガミグンナキジンソン', '古宇利', 'コウリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡今帰仁村天底', '47', '47306', '9050411', '沖縄県', 'オキナワケン', '国頭郡今帰仁村', 'クニガミグンナキジンソン', '天底', 'アメソコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡今帰仁村湧川', '47', '47306', '9050412', '沖縄県', 'オキナワケン', '国頭郡今帰仁村', 'クニガミグンナキジンソン', '湧川', 'ワクガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡今帰仁村呉我山', '47', '47306', '9050413', '沖縄県', 'オキナワケン', '国頭郡今帰仁村', 'クニガミグンナキジンソン', '呉我山', 'ゴガヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡今帰仁村謝名', '47', '47306', '9050414', '沖縄県', 'オキナワケン', '国頭郡今帰仁村', 'クニガミグンナキジンソン', '謝名', 'ジャナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡今帰仁村玉城', '47', '47306', '9050415', '沖縄県', 'オキナワケン', '国頭郡今帰仁村', 'クニガミグンナキジンソン', '玉城', 'タマシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡今帰仁村越地', '47', '47306', '9050421', '沖縄県', 'オキナワケン', '国頭郡今帰仁村', 'クニガミグンナキジンソン', '越地', 'コエチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡今帰仁村崎山', '47', '47306', '9050422', '沖縄県', 'オキナワケン', '国頭郡今帰仁村', 'クニガミグンナキジンソン', '崎山', 'サキヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡今帰仁村平敷', '47', '47306', '9050423', '沖縄県', 'オキナワケン', '国頭郡今帰仁村', 'クニガミグンナキジンソン', '平敷', 'ヘシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡今帰仁村仲尾次', '47', '47306', '9050424', '沖縄県', 'オキナワケン', '国頭郡今帰仁村', 'クニガミグンナキジンソン', '仲尾次', 'ナカオシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡今帰仁村与那嶺', '47', '47306', '9050425', '沖縄県', 'オキナワケン', '国頭郡今帰仁村', 'クニガミグンナキジンソン', '与那嶺', 'ヨナミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡今帰仁村諸志', '47', '47306', '9050426', '沖縄県', 'オキナワケン', '国頭郡今帰仁村', 'クニガミグンナキジンソン', '諸志', 'ショシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡今帰仁村兼次', '47', '47306', '9050427', '沖縄県', 'オキナワケン', '国頭郡今帰仁村', 'クニガミグンナキジンソン', '兼次', 'カネシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡今帰仁村今泊', '47', '47306', '9050428', '沖縄県', 'オキナワケン', '国頭郡今帰仁村', 'クニガミグンナキジンソン', '今泊', 'イマドマリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡伊江村', '47', '47315', '9050500', '沖縄県', 'オキナワケン', '国頭郡伊江村', 'クニガミグンイエソン', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('119725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡伊江村東江上', '47', '47315', '9050501', '沖縄県', 'オキナワケン', '国頭郡伊江村', 'クニガミグンイエソン', '東江上', 'ヒガシエウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡伊江村東江前', '47', '47315', '9050502', '沖縄県', 'オキナワケン', '国頭郡伊江村', 'クニガミグンイエソン', '東江前', 'ヒガシエマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡伊江村川平', '47', '47315', '9050503', '沖縄県', 'オキナワケン', '国頭郡伊江村', 'クニガミグンイエソン', '川平', 'カワヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡伊江村西江前', '47', '47315', '9050504', '沖縄県', 'オキナワケン', '国頭郡伊江村', 'クニガミグンイエソン', '西江前', 'ニシエマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡伊江村西江上', '47', '47315', '9050505', '沖縄県', 'オキナワケン', '国頭郡伊江村', 'クニガミグンイエソン', '西江上', 'ニシエウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡伊是名村', '47', '47360', '9050600', '沖縄県', 'オキナワケン', '島尻郡伊是名村', 'シマジリグンイゼナソン', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('119736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡伊是名村内花', '47', '47360', '9050601', '沖縄県', 'オキナワケン', '島尻郡伊是名村', 'シマジリグンイゼナソン', '内花', 'ウチハナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡伊是名村諸見', '47', '47360', '9050602', '沖縄県', 'オキナワケン', '島尻郡伊是名村', 'シマジリグンイゼナソン', '諸見', 'ショミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡伊是名村仲田', '47', '47360', '9050603', '沖縄県', 'オキナワケン', '島尻郡伊是名村', 'シマジリグンイゼナソン', '仲田', 'ナカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡伊是名村伊是名', '47', '47360', '9050604', '沖縄県', 'オキナワケン', '島尻郡伊是名村', 'シマジリグンイゼナソン', '伊是名', 'イゼナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡伊是名村勢理客', '47', '47360', '9050605', '沖縄県', 'オキナワケン', '島尻郡伊是名村', 'シマジリグンイゼナソン', '勢理客', 'セリキャク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡伊平屋村', '47', '47359', '9050700', '沖縄県', 'オキナワケン', '島尻郡伊平屋村', 'シマジリグンイヘヤソン', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('119743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡伊平屋村田名', '47', '47359', '9050701', '沖縄県', 'オキナワケン', '島尻郡伊平屋村', 'シマジリグンイヘヤソン', '田名', 'ダナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡伊平屋村前泊', '47', '47359', '9050702', '沖縄県', 'オキナワケン', '島尻郡伊平屋村', 'シマジリグンイヘヤソン', '前泊', 'マエドマリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡伊平屋村我喜屋', '47', '47359', '9050703', '沖縄県', 'オキナワケン', '島尻郡伊平屋村', 'シマジリグンイヘヤソン', '我喜屋', 'ガキヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡伊平屋村島尻', '47', '47359', '9050704', '沖縄県', 'オキナワケン', '島尻郡伊平屋村', 'シマジリグンイヘヤソン', '島尻', 'シマジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県島尻郡伊平屋村野甫', '47', '47359', '9050705', '沖縄県', 'オキナワケン', '島尻郡伊平屋村', 'シマジリグンイヘヤソン', '野甫', 'ノホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県名護市源河', '47', '47209', '9051141', '沖縄県', 'オキナワケン', '名護市', 'ナゴシ', '源河', 'ゲンカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県名護市稲嶺', '47', '47209', '9051142', '沖縄県', 'オキナワケン', '名護市', 'ナゴシ', '稲嶺', 'イナミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県名護市真喜屋', '47', '47209', '9051143', '沖縄県', 'オキナワケン', '名護市', 'ナゴシ', '真喜屋', 'マキヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県名護市仲尾次', '47', '47209', '9051144', '沖縄県', 'オキナワケン', '名護市', 'ナゴシ', '仲尾次', 'ナカオシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県名護市川上', '47', '47209', '9051145', '沖縄県', 'オキナワケン', '名護市', 'ナゴシ', '川上', 'カワカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県名護市親川', '47', '47209', '9051146', '沖縄県', 'オキナワケン', '名護市', 'ナゴシ', '親川', 'オヤカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県名護市田井等', '47', '47209', '9051147', '沖縄県', 'オキナワケン', '名護市', 'ナゴシ', '田井等', 'タイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県名護市振慶名', '47', '47209', '9051151', '沖縄県', 'オキナワケン', '名護市', 'ナゴシ', '振慶名', 'ブリケナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県名護市伊差川', '47', '47209', '9051152', '沖縄県', 'オキナワケン', '名護市', 'ナゴシ', '伊差川', 'イサガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県名護市仲尾', '47', '47209', '9051153', '沖縄県', 'オキナワケン', '名護市', 'ナゴシ', '仲尾', 'ナカオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県名護市呉我', '47', '47209', '9051154', '沖縄県', 'オキナワケン', '名護市', 'ナゴシ', '呉我', 'ゴガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県名護市我部祖河', '47', '47209', '9051155', '沖縄県', 'オキナワケン', '名護市', 'ナゴシ', '我部祖河', 'ガブソカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県名護市古我知', '47', '47209', '9051156', '沖縄県', 'オキナワケン', '名護市', 'ナゴシ', '古我知', 'コガチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡東村', '47', '47303', '9051200', '沖縄県', 'オキナワケン', '国頭郡東村', 'クニガミグンヒガシソン', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('119767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡東村高江', '47', '47303', '9051201', '沖縄県', 'オキナワケン', '国頭郡東村', 'クニガミグンヒガシソン', '高江', 'タカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡東村宮城', '47', '47303', '9051202', '沖縄県', 'オキナワケン', '国頭郡東村', 'クニガミグンヒガシソン', '宮城', 'ミヤギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡東村川田', '47', '47303', '9051203', '沖縄県', 'オキナワケン', '国頭郡東村', 'クニガミグンヒガシソン', '川田', 'カワタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡東村平良', '47', '47303', '9051204', '沖縄県', 'オキナワケン', '国頭郡東村', 'クニガミグンヒガシソン', '平良', 'タイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡東村慶佐次', '47', '47303', '9051205', '沖縄県', 'オキナワケン', '国頭郡東村', 'クニガミグンヒガシソン', '慶佐次', 'ゲサシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡東村有銘', '47', '47303', '9051206', '沖縄県', 'オキナワケン', '国頭郡東村', 'クニガミグンヒガシソン', '有銘', 'アルメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡大宜味村', '47', '47302', '9051300', '沖縄県', 'オキナワケン', '国頭郡大宜味村', 'クニガミグンオオギミソン', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('119775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡大宜味村田嘉里', '47', '47302', '9051301', '沖縄県', 'オキナワケン', '国頭郡大宜味村', 'クニガミグンオオギミソン', '田嘉里', 'タカザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡大宜味村謝名城', '47', '47302', '9051302', '沖縄県', 'オキナワケン', '国頭郡大宜味村', 'クニガミグンオオギミソン', '謝名城', 'ジャナグスク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡大宜味村喜如嘉', '47', '47302', '9051303', '沖縄県', 'オキナワケン', '国頭郡大宜味村', 'クニガミグンオオギミソン', '喜如嘉', 'キジョカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡大宜味村饒波', '47', '47302', '9051304', '沖縄県', 'オキナワケン', '国頭郡大宜味村', 'クニガミグンオオギミソン', '饒波', 'ヌウハ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡大宜味村大兼久', '47', '47302', '9051305', '沖縄県', 'オキナワケン', '国頭郡大宜味村', 'クニガミグンオオギミソン', '大兼久', 'オオガネク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡大宜味村大宜味', '47', '47302', '9051306', '沖縄県', 'オキナワケン', '国頭郡大宜味村', 'クニガミグンオオギミソン', '大宜味', 'オオギミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡大宜味村根路銘', '47', '47302', '9051307', '沖縄県', 'オキナワケン', '国頭郡大宜味村', 'クニガミグンオオギミソン', '根路銘', 'ネロメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡大宜味村上原', '47', '47302', '9051308', '沖縄県', 'オキナワケン', '国頭郡大宜味村', 'クニガミグンオオギミソン', '上原', 'ウエハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡大宜味村塩屋', '47', '47302', '9051311', '沖縄県', 'オキナワケン', '国頭郡大宜味村', 'クニガミグンオオギミソン', '塩屋', 'シオヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡大宜味村屋古', '47', '47302', '9051312', '沖縄県', 'オキナワケン', '国頭郡大宜味村', 'クニガミグンオオギミソン', '屋古', 'ヤコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡大宜味村押川', '47', '47302', '9051313', '沖縄県', 'オキナワケン', '国頭郡大宜味村', 'クニガミグンオオギミソン', '押川', 'オシカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡大宜味村田港', '47', '47302', '9051314', '沖縄県', 'オキナワケン', '国頭郡大宜味村', 'クニガミグンオオギミソン', '田港', 'タミナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡大宜味村大保', '47', '47302', '9051315', '沖縄県', 'オキナワケン', '国頭郡大宜味村', 'クニガミグンオオギミソン', '大保', 'タイホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡大宜味村白浜', '47', '47302', '9051316', '沖縄県', 'オキナワケン', '国頭郡大宜味村', 'クニガミグンオオギミソン', '白浜', 'シラハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡大宜味村江洲', '47', '47302', '9051317', '沖縄県', 'オキナワケン', '国頭郡大宜味村', 'クニガミグンオオギミソン', '江洲', 'エス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡大宜味村津波', '47', '47302', '9051318', '沖縄県', 'オキナワケン', '国頭郡大宜味村', 'クニガミグンオオギミソン', '津波', 'ツハ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡大宜味村宮城', '47', '47302', '9051319', '沖縄県', 'オキナワケン', '国頭郡大宜味村', 'クニガミグンオオギミソン', '宮城', 'ミヤギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡国頭村', '47', '47301', '9051400', '沖縄県', 'オキナワケン', '国頭郡国頭村', 'クニガミグンクニガミソン', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('119794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡国頭村辺土名', '47', '47301', '9051411', '沖縄県', 'オキナワケン', '国頭郡国頭村', 'クニガミグンクニガミソン', '辺土名', 'ヘントナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡国頭村奥間', '47', '47301', '9051412', '沖縄県', 'オキナワケン', '国頭郡国頭村', 'クニガミグンクニガミソン', '奥間', 'オクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡国頭村比地', '47', '47301', '9051413', '沖縄県', 'オキナワケン', '国頭郡国頭村', 'クニガミグンクニガミソン', '比地', 'ヒジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡国頭村半地', '47', '47301', '9051414', '沖縄県', 'オキナワケン', '国頭郡国頭村', 'クニガミグンクニガミソン', '半地', 'ハンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡国頭村浜', '47', '47301', '9051415', '沖縄県', 'オキナワケン', '国頭郡国頭村', 'クニガミグンクニガミソン', '浜', 'ハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡国頭村鏡地', '47', '47301', '9051416', '沖縄県', 'オキナワケン', '国頭郡国頭村', 'クニガミグンクニガミソン', '鏡地', 'カガンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡国頭村桃原', '47', '47301', '9051417', '沖縄県', 'オキナワケン', '国頭郡国頭村', 'クニガミグンクニガミソン', '桃原', 'トウバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡国頭村辺戸', '47', '47301', '9051421', '沖縄県', 'オキナワケン', '国頭郡国頭村', 'クニガミグンクニガミソン', '辺戸', 'ヘド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡国頭村宜名真', '47', '47301', '9051422', '沖縄県', 'オキナワケン', '国頭郡国頭村', 'クニガミグンクニガミソン', '宜名真', 'ギナマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡国頭村宇嘉', '47', '47301', '9051423', '沖縄県', 'オキナワケン', '国頭郡国頭村', 'クニガミグンクニガミソン', '宇嘉', 'ウカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡国頭村辺野喜', '47', '47301', '9051424', '沖縄県', 'オキナワケン', '国頭郡国頭村', 'クニガミグンクニガミソン', '辺野喜', 'ベノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡国頭村佐手', '47', '47301', '9051425', '沖縄県', 'オキナワケン', '国頭郡国頭村', 'クニガミグンクニガミソン', '佐手', 'サテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡国頭村謝敷', '47', '47301', '9051426', '沖縄県', 'オキナワケン', '国頭郡国頭村', 'クニガミグンクニガミソン', '謝敷', 'ジャシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡国頭村与那', '47', '47301', '9051427', '沖縄県', 'オキナワケン', '国頭郡国頭村', 'クニガミグンクニガミソン', '与那', 'ヨナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡国頭村伊地', '47', '47301', '9051428', '沖縄県', 'オキナワケン', '国頭郡国頭村', 'クニガミグンクニガミソン', '伊地', 'イジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡国頭村宇良', '47', '47301', '9051429', '沖縄県', 'オキナワケン', '国頭郡国頭村', 'クニガミグンクニガミソン', '宇良', 'ウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡国頭村奥', '47', '47301', '9051501', '沖縄県', 'オキナワケン', '国頭郡国頭村', 'クニガミグンクニガミソン', '奥', 'オク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡国頭村楚洲', '47', '47301', '9051502', '沖縄県', 'オキナワケン', '国頭郡国頭村', 'クニガミグンクニガミソン', '楚洲', 'ソス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡国頭村安田', '47', '47301', '9051503', '沖縄県', 'オキナワケン', '国頭郡国頭村', 'クニガミグンクニガミソン', '安田', 'アダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県国頭郡国頭村安波', '47', '47301', '9051504', '沖縄県', 'オキナワケン', '国頭郡国頭村', 'クニガミグンクニガミソン', '安波', 'アハ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県名護市屋我', '47', '47209', '9051631', '沖縄県', 'オキナワケン', '名護市', 'ナゴシ', '屋我', 'ヤガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県名護市饒平名', '47', '47209', '9051632', '沖縄県', 'オキナワケン', '名護市', 'ナゴシ', '饒平名', 'ヨヘナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県名護市我部', '47', '47209', '9051633', '沖縄県', 'オキナワケン', '名護市', 'ナゴシ', '我部', 'ガブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県名護市運天原', '47', '47209', '9051634', '沖縄県', 'オキナワケン', '名護市', 'ナゴシ', '運天原', 'ウンテンバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県名護市済井出', '47', '47209', '9051635', '沖縄県', 'オキナワケン', '名護市', 'ナゴシ', '済井出', 'スムイデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県名護市辺野古', '47', '47209', '9052171', '沖縄県', 'オキナワケン', '名護市', 'ナゴシ', '辺野古', 'ヘノコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県名護市豊原', '47', '47209', '9052172', '沖縄県', 'オキナワケン', '名護市', 'ナゴシ', '豊原', 'トヨハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県名護市久志', '47', '47209', '9052173', '沖縄県', 'オキナワケン', '名護市', 'ナゴシ', '久志', 'クシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県名護市天仁屋', '47', '47209', '9052261', '沖縄県', 'オキナワケン', '名護市', 'ナゴシ', '天仁屋', 'テニヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県名護市嘉陽', '47', '47209', '9052262', '沖縄県', 'オキナワケン', '名護市', 'ナゴシ', '嘉陽', 'カヨウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県名護市安部', '47', '47209', '9052263', '沖縄県', 'オキナワケン', '名護市', 'ナゴシ', '安部', 'アブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県名護市三原', '47', '47209', '9052264', '沖縄県', 'オキナワケン', '名護市', 'ナゴシ', '三原', 'ミハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県名護市汀間', '47', '47209', '9052265', '沖縄県', 'オキナワケン', '名護市', 'ナゴシ', '汀間', 'テイマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県名護市瀬嵩', '47', '47209', '9052266', '沖縄県', 'オキナワケン', '名護市', 'ナゴシ', '瀬嵩', 'セダケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県名護市大浦', '47', '47209', '9052267', '沖縄県', 'オキナワケン', '名護市', 'ナゴシ', '大浦', 'オオウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県名護市大川', '47', '47209', '9052268', '沖縄県', 'オキナワケン', '名護市', 'ナゴシ', '大川', 'オオカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県名護市二見', '47', '47209', '9052269', '沖縄県', 'オキナワケン', '名護市', 'ナゴシ', '二見', 'フタミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県宮古島市', '47', '47214', '9060000', '沖縄県', 'オキナワケン', '宮古島市', 'ミヤコジマシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('119840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県宮古島市平良大神', '47', '47214', '9060001', '沖縄県', 'オキナワケン', '宮古島市', 'ミヤコジマシ', '平良大神', 'ヒララオオガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県宮古島市平良狩俣', '47', '47214', '9060002', '沖縄県', 'オキナワケン', '宮古島市', 'ミヤコジマシ', '平良狩俣', 'ヒララカリマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県宮古島市平良島尻', '47', '47214', '9060003', '沖縄県', 'オキナワケン', '宮古島市', 'ミヤコジマシ', '平良島尻', 'ヒララシマジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県宮古島市平良大浦', '47', '47214', '9060004', '沖縄県', 'オキナワケン', '宮古島市', 'ミヤコジマシ', '平良大浦', 'ヒララオオウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県宮古島市平良西原', '47', '47214', '9060005', '沖縄県', 'オキナワケン', '宮古島市', 'ミヤコジマシ', '平良西原', 'ヒララニシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県宮古島市平良西仲宗根', '47', '47214', '9060006', '沖縄県', 'オキナワケン', '宮古島市', 'ミヤコジマシ', '平良西仲宗根', 'ヒララニシナカソネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県宮古島市平良東仲宗根', '47', '47214', '9060007', '沖縄県', 'オキナワケン', '宮古島市', 'ミヤコジマシ', '平良東仲宗根', 'ヒララヒガシナカソネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県宮古島市平良荷川取', '47', '47214', '9060008', '沖縄県', 'オキナワケン', '宮古島市', 'ミヤコジマシ', '平良荷川取', 'ヒララニカドリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県宮古島市平良東仲宗根添', '47', '47214', '9060011', '沖縄県', 'オキナワケン', '宮古島市', 'ミヤコジマシ', '平良東仲宗根添', 'ヒララヒガシナカソネゾエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県宮古島市平良西里', '47', '47214', '9060012', '沖縄県', 'オキナワケン', '宮古島市', 'ミヤコジマシ', '平良西里', 'ヒララニシザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県宮古島市平良下里', '47', '47214', '9060013', '沖縄県', 'オキナワケン', '宮古島市', 'ミヤコジマシ', '平良下里', 'ヒララシモザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県宮古島市平良松原', '47', '47214', '9060014', '沖縄県', 'オキナワケン', '宮古島市', 'ミヤコジマシ', '平良松原', 'ヒララマツバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県宮古島市平良久貝', '47', '47214', '9060015', '沖縄県', 'オキナワケン', '宮古島市', 'ミヤコジマシ', '平良久貝', 'ヒララクガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県宮古島市城辺保良', '47', '47214', '9060101', '沖縄県', 'オキナワケン', '宮古島市', 'ミヤコジマシ', '城辺保良', 'グスクベボラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県宮古島市城辺新城', '47', '47214', '9060102', '沖縄県', 'オキナワケン', '宮古島市', 'ミヤコジマシ', '城辺新城', 'グスクベアラグスク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県宮古島市城辺福里', '47', '47214', '9060103', '沖縄県', 'オキナワケン', '宮古島市', 'ミヤコジマシ', '城辺福里', 'グスクベフクザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県宮古島市城辺比嘉', '47', '47214', '9060104', '沖縄県', 'オキナワケン', '宮古島市', 'ミヤコジマシ', '城辺比嘉', 'グスクベヒガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県宮古島市城辺長間', '47', '47214', '9060105', '沖縄県', 'オキナワケン', '宮古島市', 'ミヤコジマシ', '城辺長間', 'グスクベナガマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県宮古島市城辺西里添', '47', '47214', '9060106', '沖縄県', 'オキナワケン', '宮古島市', 'ミヤコジマシ', '城辺西里添', 'グスクベニシザトソエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県宮古島市城辺友利', '47', '47214', '9060107', '沖縄県', 'オキナワケン', '宮古島市', 'ミヤコジマシ', '城辺友利', 'グスクベトモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県宮古島市城辺砂川', '47', '47214', '9060108', '沖縄県', 'オキナワケン', '宮古島市', 'ミヤコジマシ', '城辺砂川', 'グスクベウルカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県宮古島市城辺下里添', '47', '47214', '9060109', '沖縄県', 'オキナワケン', '宮古島市', 'ミヤコジマシ', '城辺下里添', 'グスクベシモザトソエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県宮古島市上野野原', '47', '47214', '9060201', '沖縄県', 'オキナワケン', '宮古島市', 'ミヤコジマシ', '上野野原', 'ウエノノバル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県宮古島市上野新里', '47', '47214', '9060202', '沖縄県', 'オキナワケン', '宮古島市', 'ミヤコジマシ', '上野新里', 'ウエノアラザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県宮古島市上野宮国', '47', '47214', '9060203', '沖縄県', 'オキナワケン', '宮古島市', 'ミヤコジマシ', '上野宮国', 'ウエノミヤグニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県宮古島市上野上野', '47', '47214', '9060204', '沖縄県', 'オキナワケン', '宮古島市', 'ミヤコジマシ', '上野上野', 'ウエノウエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県宮古島市下地川満', '47', '47214', '9060301', '沖縄県', 'オキナワケン', '宮古島市', 'ミヤコジマシ', '下地川満', 'シモジカワミツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県宮古島市下地嘉手苅', '47', '47214', '9060302', '沖縄県', 'オキナワケン', '宮古島市', 'ミヤコジマシ', '下地嘉手苅', 'シモジカデカリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県宮古島市下地洲鎌', '47', '47214', '9060303', '沖縄県', 'オキナワケン', '宮古島市', 'ミヤコジマシ', '下地洲鎌', 'シモジスガマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県宮古島市下地上地', '47', '47214', '9060304', '沖縄県', 'オキナワケン', '宮古島市', 'ミヤコジマシ', '下地上地', 'シモジウエチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県宮古島市下地与那覇', '47', '47214', '9060305', '沖縄県', 'オキナワケン', '宮古島市', 'ミヤコジマシ', '下地与那覇', 'シモジヨナハ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県宮古島市下地来間', '47', '47214', '9060306', '沖縄県', 'オキナワケン', '宮古島市', 'ミヤコジマシ', '下地来間', 'シモジクリマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県宮古島市平良池間', '47', '47214', '9060421', '沖縄県', 'オキナワケン', '宮古島市', 'ミヤコジマシ', '平良池間', 'ヒラライケマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県宮古島市平良前里', '47', '47214', '9060422', '沖縄県', 'オキナワケン', '宮古島市', 'ミヤコジマシ', '平良前里', 'ヒララマエザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県宮古島市伊良部前里添', '47', '47214', '9060501', '沖縄県', 'オキナワケン', '宮古島市', 'ミヤコジマシ', '伊良部前里添', 'イラブマエサトソエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県宮古島市伊良部池間添', '47', '47214', '9060502', '沖縄県', 'オキナワケン', '宮古島市', 'ミヤコジマシ', '伊良部池間添', 'イラブイケマソエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県宮古島市伊良部伊良部', '47', '47214', '9060503', '沖縄県', 'オキナワケン', '宮古島市', 'ミヤコジマシ', '伊良部伊良部', 'イラブイラブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県宮古島市伊良部仲地', '47', '47214', '9060504', '沖縄県', 'オキナワケン', '宮古島市', 'ミヤコジマシ', '伊良部仲地', 'イラブナカチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県宮古島市伊良部国仲', '47', '47214', '9060505', '沖縄県', 'オキナワケン', '宮古島市', 'ミヤコジマシ', '伊良部国仲', 'イラブクニナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県宮古島市伊良部長浜', '47', '47214', '9060506', '沖縄県', 'オキナワケン', '宮古島市', 'ミヤコジマシ', '伊良部長浜', 'イラブナガハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県宮古島市伊良部佐和田', '47', '47214', '9060507', '沖縄県', 'オキナワケン', '宮古島市', 'ミヤコジマシ', '伊良部佐和田', 'イラブサワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県宮古郡多良間村', '47', '47375', '9060600', '沖縄県', 'オキナワケン', '宮古郡多良間村', 'ミヤコグンタラマソン', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('119884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県宮古郡多良間村塩川', '47', '47375', '9060601', '沖縄県', 'オキナワケン', '宮古郡多良間村', 'ミヤコグンタラマソン', '塩川', 'シオカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県宮古郡多良間村仲筋', '47', '47375', '9060602', '沖縄県', 'オキナワケン', '宮古郡多良間村', 'ミヤコグンタラマソン', '仲筋', 'ナカスジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県宮古郡多良間村水納', '47', '47375', '9060603', '沖縄県', 'オキナワケン', '宮古郡多良間村', 'ミヤコグンタラマソン', '水納', 'ミンナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県石垣市', '47', '47207', '9070000', '沖縄県', 'オキナワケン', '石垣市', 'イシガキシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('119891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県八重山郡竹富町', '47', '47381', '9070000', '沖縄県', 'オキナワケン', '八重山郡竹富町', 'ヤエヤマグンタケトミチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('119892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県石垣市大浜', '47', '47207', '9070001', '沖縄県', 'オキナワケン', '石垣市', 'イシガキシ', '大浜', 'オオハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県石垣市真栄里', '47', '47207', '9070002', '沖縄県', 'オキナワケン', '石垣市', 'イシガキシ', '真栄里', 'マエザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県石垣市平得', '47', '47207', '9070003', '沖縄県', 'オキナワケン', '石垣市', 'イシガキシ', '平得', 'ヒラエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県石垣市登野城', '47', '47207', '9070004', '沖縄県', 'オキナワケン', '石垣市', 'イシガキシ', '登野城', 'トノシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県石垣市八島町', '47', '47207', '9070011', '沖縄県', 'オキナワケン', '石垣市', 'イシガキシ', '八島町', 'ヤシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県石垣市美崎町', '47', '47207', '9070012', '沖縄県', 'オキナワケン', '石垣市', 'イシガキシ', '美崎町', 'ミサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県石垣市浜崎町', '47', '47207', '9070013', '沖縄県', 'オキナワケン', '石垣市', 'イシガキシ', '浜崎町', 'ハマサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県石垣市新栄町', '47', '47207', '9070014', '沖縄県', 'オキナワケン', '石垣市', 'イシガキシ', '新栄町', 'シンエイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県石垣市名蔵', '47', '47207', '9070021', '沖縄県', 'オキナワケン', '石垣市', 'イシガキシ', '名蔵', 'ナグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県石垣市大川', '47', '47207', '9070022', '沖縄県', 'オキナワケン', '石垣市', 'イシガキシ', '大川', 'オオカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県石垣市石垣', '47', '47207', '9070023', '沖縄県', 'オキナワケン', '石垣市', 'イシガキシ', '石垣', 'イシガキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県石垣市新川', '47', '47207', '9070024', '沖縄県', 'オキナワケン', '石垣市', 'イシガキシ', '新川', 'アラカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県石垣市桃里', '47', '47207', '9070241', '沖縄県', 'オキナワケン', '石垣市', 'イシガキシ', '桃里', 'トウザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県石垣市白保', '47', '47207', '9070242', '沖縄県', 'オキナワケン', '石垣市', 'イシガキシ', '白保', 'シラホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県石垣市宮良', '47', '47207', '9070243', '沖縄県', 'オキナワケン', '石垣市', 'イシガキシ', '宮良', 'ミヤラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県石垣市平久保', '47', '47207', '9070331', '沖縄県', 'オキナワケン', '石垣市', 'イシガキシ', '平久保', 'ヒラクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県石垣市伊原間', '47', '47207', '9070332', '沖縄県', 'オキナワケン', '石垣市', 'イシガキシ', '伊原間', 'イバルマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県石垣市野底', '47', '47207', '9070333', '沖縄県', 'オキナワケン', '石垣市', 'イシガキシ', '野底', 'ノソコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県石垣市桴海', '47', '47207', '9070451', '沖縄県', 'オキナワケン', '石垣市', 'イシガキシ', '桴海', 'フカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県石垣市崎枝', '47', '47207', '9070452', '沖縄県', 'オキナワケン', '石垣市', 'イシガキシ', '崎枝', 'サキエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県石垣市川平', '47', '47207', '9070453', '沖縄県', 'オキナワケン', '石垣市', 'イシガキシ', '川平', 'カビラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県八重山郡竹富町竹富', '47', '47381', '9071101', '沖縄県', 'オキナワケン', '八重山郡竹富町', 'ヤエヤマグンタケトミチョウ', '竹富', 'タケトミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県八重山郡竹富町小浜', '47', '47381', '9071221', '沖縄県', 'オキナワケン', '八重山郡竹富町', 'ヤエヤマグンタケトミチョウ', '小浜', 'コハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県八重山郡竹富町黒島', '47', '47381', '9071311', '沖縄県', 'オキナワケン', '八重山郡竹富町', 'ヤエヤマグンタケトミチョウ', '黒島', 'クロシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県八重山郡竹富町高那', '47', '47381', '9071431', '沖縄県', 'オキナワケン', '八重山郡竹富町', 'ヤエヤマグンタケトミチョウ', '高那', 'タカナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県八重山郡竹富町古見', '47', '47381', '9071432', '沖縄県', 'オキナワケン', '八重山郡竹富町', 'ヤエヤマグンタケトミチョウ', '古見', 'コミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県八重山郡竹富町南風見仲', '47', '47381', '9071433', '沖縄県', 'オキナワケン', '八重山郡竹富町', 'ヤエヤマグンタケトミチョウ', '南風見仲', 'ハイミナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県八重山郡竹富町南風見', '47', '47381', '9071434', '沖縄県', 'オキナワケン', '八重山郡竹富町', 'ヤエヤマグンタケトミチョウ', '南風見', 'ハイミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県八重山郡竹富町新城', '47', '47381', '9071435', '沖縄県', 'オキナワケン', '八重山郡竹富町', 'ヤエヤマグンタケトミチョウ', '新城', 'アラグスク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県八重山郡竹富町上原', '47', '47381', '9071541', '沖縄県', 'オキナワケン', '八重山郡竹富町', 'ヤエヤマグンタケトミチョウ', '上原', 'ウエハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県八重山郡竹富町西表', '47', '47381', '9071542', '沖縄県', 'オキナワケン', '八重山郡竹富町', 'ヤエヤマグンタケトミチョウ', '西表', 'イリオモテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県八重山郡竹富町崎山', '47', '47381', '9071543', '沖縄県', 'オキナワケン', '八重山郡竹富町', 'ヤエヤマグンタケトミチョウ', '崎山', 'サキヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県八重山郡竹富町鳩間', '47', '47381', '9071544', '沖縄県', 'オキナワケン', '八重山郡竹富町', 'ヤエヤマグンタケトミチョウ', '鳩間', 'ハトマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県八重山郡竹富町波照間', '47', '47381', '9071751', '沖縄県', 'オキナワケン', '八重山郡竹富町', 'ヤエヤマグンタケトミチョウ', '波照間', 'ハテルマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県八重山郡与那国町', '47', '47382', '9071800', '沖縄県', 'オキナワケン', '八重山郡与那国町', 'ヤエヤマグンヨナグニチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('119928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '沖縄県八重山郡与那国町与那国', '47', '47382', '9071801', '沖縄県', 'オキナワケン', '八重山郡与那国町', 'ヤエヤマグンヨナグニチョウ', '与那国', 'ヨナグニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市大願寺', '18', '18201', '9100001', '福井県', 'フクイケン', '福井市', 'フクイシ', '大願寺', 'ダイガンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市町屋', '18', '18201', '9100002', '福井県', 'フクイケン', '福井市', 'フクイシ', '町屋', 'マチヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市松本', '18', '18201', '9100003', '福井県', 'フクイケン', '福井市', 'フクイシ', '松本', 'マツモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市宝永', '18', '18201', '9100004', '福井県', 'フクイケン', '福井市', 'フクイシ', '宝永', 'ホウエイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市大手', '18', '18201', '9100005', '福井県', 'フクイケン', '福井市', 'フクイシ', '大手', 'オオテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市中央', '18', '18201', '9100006', '福井県', 'フクイケン', '福井市', 'フクイシ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市留辺蘂町元町', '01', '01208', '0910001', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '留辺蘂町元町', 'ルベシベチョウモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市経田', '18', '18201', '9100011', '福井県', 'フクイケン', '福井市', 'フクイシ', '経田', 'キョウデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市経栄', '18', '18201', '9100012', '福井県', 'フクイケン', '福井市', 'フクイシ', '経栄', 'キョウエイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市幾代', '18', '18201', '9100013', '福井県', 'フクイケン', '福井市', 'フクイシ', '幾代', 'イクヨ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市幾久町', '18', '18201', '9100014', '福井県', 'フクイケン', '福井市', 'フクイシ', '幾久町', 'イクヒサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市二の宮', '18', '18201', '9100015', '福井県', 'フクイケン', '福井市', 'フクイシ', '二の宮', 'ニノミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市大宮', '18', '18201', '9100016', '福井県', 'フクイケン', '福井市', 'フクイシ', '大宮', 'オオミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市文京', '18', '18201', '9100017', '福井県', 'フクイケン', '福井市', 'フクイシ', '文京', 'ブンキョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市田原', '18', '18201', '9100018', '福井県', 'フクイケン', '福井市', 'フクイシ', '田原', 'タワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市春山', '18', '18201', '9100019', '福井県', 'フクイケン', '福井市', 'フクイシ', '春山', 'ハルヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市留辺蘂町東町', '01', '01208', '0910002', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '留辺蘂町東町', 'ルベシベチョウアズマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市乾徳', '18', '18201', '9100021', '福井県', 'フクイケン', '福井市', 'フクイシ', '乾徳', 'ケントク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市花月', '18', '18201', '9100022', '福井県', 'フクイケン', '福井市', 'フクイシ', '花月', 'カゲツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市順化', '18', '18201', '9100023', '福井県', 'フクイケン', '福井市', 'フクイシ', '順化', 'ジュンカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市照手', '18', '18201', '9100024', '福井県', 'フクイケン', '福井市', 'フクイシ', '照手', 'テルテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市照手町', '18', '18201', '9100025', '福井県', 'フクイケン', '福井市', 'フクイシ', '照手町', 'テルテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市光陽', '18', '18201', '9100026', '福井県', 'フクイケン', '福井市', 'フクイシ', '光陽', 'コウヨウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市豊岡', '18', '18201', '9100027', '福井県', 'フクイケン', '福井市', 'フクイシ', '豊岡', 'トヨオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市学園', '18', '18201', '9100028', '福井県', 'フクイケン', '福井市', 'フクイシ', '学園', 'ガクエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市日光', '18', '18201', '9100029', '福井県', 'フクイケン', '福井市', 'フクイシ', '日光', 'ニッコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市留辺蘂町仲町', '01', '01208', '0910003', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '留辺蘂町仲町', 'ルベシベチョウナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市堀ノ宮町', '18', '18201', '9100031', '福井県', 'フクイケン', '福井市', 'フクイシ', '堀ノ宮町', 'ホリノミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市堀ノ宮', '18', '18201', '9100032', '福井県', 'フクイケン', '福井市', 'フクイシ', '堀ノ宮', 'ホリノミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市三郎丸', '18', '18201', '9100033', '福井県', 'フクイケン', '福井市', 'フクイシ', '三郎丸', 'サブロウマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市菅谷', '18', '18201', '9100034', '福井県', 'フクイケン', '福井市', 'フクイシ', '菅谷', 'スガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市菅谷町', '18', '18201', '9100035', '福井県', 'フクイケン', '福井市', 'フクイシ', '菅谷町', 'スガヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市三郎丸町', '18', '18201', '9100036', '福井県', 'フクイケン', '福井市', 'フクイシ', '三郎丸町', 'サブロウマルチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市西堀町', '18', '18201', '9100037', '福井県', 'フクイケン', '福井市', 'フクイシ', '西堀町', 'ニシボリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市三ツ屋', '18', '18201', '9100038', '福井県', 'フクイケン', '福井市', 'フクイシ', '三ツ屋', 'ミツヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('119999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市三ツ屋町', '18', '18201', '9100039', '福井県', 'フクイケン', '福井市', 'フクイシ', '三ツ屋町', 'ミツヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市留辺蘂町上町', '01', '01208', '0910004', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '留辺蘂町上町', 'ルベシベチョウカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市天菅生町', '18', '18201', '9100041', '福井県', 'フクイケン', '福井市', 'フクイシ', '天菅生町', 'アマスゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市岸水町', '18', '18201', '9100042', '福井県', 'フクイケン', '福井市', 'フクイシ', '岸水町', 'キシミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市四十谷町', '18', '18201', '9100043', '福井県', 'フクイケン', '福井市', 'フクイシ', '四十谷町', 'シジュウタニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市田ノ谷町', '18', '18201', '9100044', '福井県', 'フクイケン', '福井市', 'フクイシ', '田ノ谷町', 'タノタニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市北楢原町', '18', '18201', '9100045', '福井県', 'フクイケン', '福井市', 'フクイシ', '北楢原町', 'キタナラハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市南楢原町', '18', '18201', '9100046', '福井県', 'フクイケン', '福井市', 'フクイシ', '南楢原町', 'ミナミナラハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市海老助町', '18', '18201', '9100047', '福井県', 'フクイケン', '福井市', 'フクイシ', '海老助町', 'エビスケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市地蔵堂町', '18', '18201', '9100048', '福井県', 'フクイケン', '福井市', 'フクイシ', '地蔵堂町', 'ジゾウドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市深谷町', '18', '18201', '9100049', '福井県', 'フクイケン', '福井市', 'フクイシ', '深谷町', 'フカダニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市郡町', '18', '18201', '9100051', '福井県', 'フクイケン', '福井市', 'フクイシ', '郡町', 'コオリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市黒丸町', '18', '18201', '9100052', '福井県', 'フクイケン', '福井市', 'フクイシ', '黒丸町', 'クロマルチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市土橋町', '18', '18201', '9100053', '福井県', 'フクイケン', '福井市', 'フクイシ', '土橋町', 'ツチハシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市安竹町', '18', '18201', '9100054', '福井県', 'フクイケン', '福井市', 'フクイシ', '安竹町', 'ヤスタケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市上伏町', '18', '18201', '9100055', '福井県', 'フクイケン', '福井市', 'フクイシ', '上伏町', 'ウエブセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市里別所新町', '18', '18201', '9100056', '福井県', 'フクイケン', '福井市', 'フクイシ', '里別所新町', 'サトベッショシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市里別所町', '18', '18201', '9100057', '福井県', 'フクイケン', '福井市', 'フクイシ', '里別所町', 'サトベッショチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市舟橋新町', '18', '18201', '9100061', '福井県', 'フクイケン', '福井市', 'フクイシ', '舟橋新町', 'フナバシシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市灯明寺町', '18', '18201', '9100062', '福井県', 'フクイケン', '福井市', 'フクイシ', '灯明寺町', 'トウミョウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市灯明寺', '18', '18201', '9100063', '福井県', 'フクイケン', '福井市', 'フクイシ', '灯明寺', 'トウミョウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市新田塚町', '18', '18201', '9100064', '福井県', 'フクイケン', '福井市', 'フクイシ', '新田塚町', 'ニツタヅカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市八ツ島町', '18', '18201', '9100065', '福井県', 'フクイケン', '福井市', 'フクイシ', '八ツ島町', 'ヤツシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市八ツ島', '18', '18201', '9100066', '福井県', 'フクイケン', '福井市', 'フクイシ', '八ツ島', 'ヤツシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市新田塚', '18', '18201', '9100067', '福井県', 'フクイケン', '福井市', 'フクイシ', '新田塚', 'ニッタヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市留辺蘂町富岡', '01', '01208', '0910007', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '留辺蘂町富岡', 'ルベシベチョウトミオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市留辺蘂町宮下町', '01', '01208', '0910008', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '留辺蘂町宮下町', 'ルベシベチョウミヤシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市つくし野', '18', '18201', '9100101', '福井県', 'フクイケン', '福井市', 'フクイシ', 'つくし野', 'ツクシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市川合鷲塚町', '18', '18201', '9100102', '福井県', 'フクイケン', '福井市', 'フクイシ', '川合鷲塚町', 'カワイワシヅカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市中角町', '18', '18201', '9100103', '福井県', 'フクイケン', '福井市', 'フクイシ', '中角町', 'ナカツノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市網戸瀬町', '18', '18201', '9100104', '福井県', 'フクイケン', '福井市', 'フクイシ', '網戸瀬町', 'アドセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市河合勝見町', '18', '18201', '9100105', '福井県', 'フクイケン', '福井市', 'フクイシ', '河合勝見町', 'カワイカツミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市六日市町', '18', '18201', '9100106', '福井県', 'フクイケン', '福井市', 'フクイシ', '六日市町', 'ムイカイチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市高屋町', '18', '18201', '9100107', '福井県', 'フクイケン', '福井市', 'フクイシ', '高屋町', 'タカヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市山室町', '18', '18201', '9100108', '福井県', 'フクイケン', '福井市', 'フクイシ', '山室町', 'ヤマムロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市二日市町', '18', '18201', '9100109', '福井県', 'フクイケン', '福井市', 'フクイシ', '二日市町', 'フツカイチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市留辺蘂町泉', '01', '01208', '0910011', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '留辺蘂町泉', 'ルベシベチョウイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市定正町', '18', '18201', '9100121', '福井県', 'フクイケン', '福井市', 'フクイシ', '定正町', 'サダマサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市石盛町', '18', '18201', '9100122', '福井県', 'フクイケン', '福井市', 'フクイシ', '石盛町', 'イシモリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市八重巻町', '18', '18201', '9100123', '福井県', 'フクイケン', '福井市', 'フクイシ', '八重巻町', 'ヤエマキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市天池町', '18', '18201', '9100124', '福井県', 'フクイケン', '福井市', 'フクイシ', '天池町', 'アマイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市漆原町', '18', '18201', '9100131', '福井県', 'フクイケン', '福井市', 'フクイシ', '漆原町', 'ウルシハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市河合寄安町', '18', '18201', '9100132', '福井県', 'フクイケン', '福井市', 'フクイシ', '河合寄安町', 'カワイヨリヤスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市森田新保町', '18', '18201', '9100133', '福井県', 'フクイケン', '福井市', 'フクイシ', '森田新保町', 'モリタシンボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市上野本町', '18', '18201', '9100134', '福井県', 'フクイケン', '福井市', 'フクイシ', '上野本町', 'ウエノホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市上野本町新', '18', '18201', '9100135', '福井県', 'フクイケン', '福井市', 'フクイシ', '上野本町新', 'ウエノホンマチシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市栗森町浜', '18', '18201', '9100136', '福井県', 'フクイケン', '福井市', 'フクイシ', '栗森町浜', 'クリモリチョウハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市栗森町', '18', '18201', '9100137', '福井県', 'フクイケン', '福井市', 'フクイシ', '栗森町', 'クリモリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市上森田町', '18', '18201', '9100141', '福井県', 'フクイケン', '福井市', 'フクイシ', '上森田町', 'カミモリダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市上森田', '18', '18201', '9100142', '福井県', 'フクイケン', '福井市', 'フクイシ', '上森田', 'カミモリダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市下森田新町', '18', '18201', '9100143', '福井県', 'フクイケン', '福井市', 'フクイシ', '下森田新町', 'シモモリダシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市下森田本町', '18', '18201', '9100144', '福井県', 'フクイケン', '福井市', 'フクイシ', '下森田本町', 'シモモリダホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市下森田藤巻町', '18', '18201', '9100145', '福井県', 'フクイケン', '福井市', 'フクイシ', '下森田藤巻町', 'シモモリダフジマキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市下森田桜町', '18', '18201', '9100146', '福井県', 'フクイケン', '福井市', 'フクイシ', '下森田桜町', 'シモモリダサクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市下森田町', '18', '18201', '9100147', '福井県', 'フクイケン', '福井市', 'フクイシ', '下森田町', 'シモモリダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市栄町', '18', '18201', '9100151', '福井県', 'フクイケン', '福井市', 'フクイシ', '栄町', 'サカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市古市', '18', '18201', '9100152', '福井県', 'フクイケン', '福井市', 'フクイシ', '古市', 'フルイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市古市町', '18', '18201', '9100153', '福井県', 'フクイケン', '福井市', 'フクイシ', '古市町', 'フルイチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市稲多元町', '18', '18201', '9100154', '福井県', 'フクイケン', '福井市', 'フクイシ', '稲多元町', 'イナダモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市稲多浜町', '18', '18201', '9100155', '福井県', 'フクイケン', '福井市', 'フクイシ', '稲多浜町', 'イナダハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市稲多新町', '18', '18201', '9100156', '福井県', 'フクイケン', '福井市', 'フクイシ', '稲多新町', 'イナダシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市八重巻東町', '18', '18201', '9100157', '福井県', 'フクイケン', '福井市', 'フクイシ', '八重巻東町', 'ヤエマキヒガシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市八重巻中町', '18', '18201', '9100158', '福井県', 'フクイケン', '福井市', 'フクイシ', '八重巻中町', 'ヤエマキナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市留辺蘂町丸山', '01', '01208', '0910016', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '留辺蘂町丸山', 'ルベシベチョウマルヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市留辺蘂町瑞穂', '01', '01208', '0910017', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '留辺蘂町瑞穂', 'ルベシベチョウミズホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市留辺蘂町花園', '01', '01208', '0910018', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '留辺蘂町花園', 'ルベシベチョウハナゾノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市', '18', '18210', '9100200', '福井県', 'フクイケン', '坂井市', 'サカイシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('120066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町上竹田曽谷', '18', '18210', '9100201', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町上竹田', 'マルオカチョウカミタケダ', null, null, '曽谷', 'ソタニ');
INSERT INTO `ms_addresses` VALUES ('120067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町上竹田岡', '18', '18210', '9100202', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町上竹田', 'マルオカチョウカミタケダ', null, null, '岡', 'オカ');
INSERT INTO `ms_addresses` VALUES ('120068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町山口', '18', '18210', '9100203', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町山口', 'マルオカチョウヤマグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町山竹田', '18', '18210', '9100204', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町山竹田', 'マルオカチョウヤマタケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町上竹田', '18', '18210', '9100205', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町上竹田', 'マルオカチョウカミタケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町川上', '18', '18210', '9100206', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町川上', 'マルオカチョウカワカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町山久保', '18', '18210', '9100207', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町山久保', 'マルオカチョウヤマクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町坪江', '18', '18210', '9100208', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町坪江', 'マルオカチョウツボエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市留辺蘂町金華', '01', '01208', '0910021', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '留辺蘂町金華', 'ルベシベチョウカネハナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町女形谷', '18', '18210', '9100211', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町女形谷', 'マルオカチョウオナガタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町赤坂', '18', '18210', '9100212', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町赤坂', 'マルオカチョウアカサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町田屋', '18', '18210', '9100213', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町田屋', 'マルオカチョウタヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町畑中', '18', '18210', '9100214', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町畑中', 'マルオカチョウハタケナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町与河', '18', '18210', '9100215', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町与河', 'マルオカチョウヨカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市留辺蘂町旭東', '01', '01208', '0910022', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '留辺蘂町旭東', 'ルベシベチョウアサヒヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町城北', '18', '18210', '9100221', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町城北', 'マルオカチョウジョウホク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町伏屋', '18', '18210', '9100222', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町伏屋', 'マルオカチョウフセヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町三本木', '18', '18210', '9100223', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町三本木', 'マルオカチョウサンボンギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町八ケ郷', '18', '18210', '9100224', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町八ケ郷', 'マルオカチョウハッカゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町松川', '18', '18210', '9100225', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町松川', 'マルオカチョウマツカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町松川町', '18', '18210', '9100226', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町松川町', 'マルオカチョウマツカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町荒町', '18', '18210', '9100227', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町荒町', 'マルオカチョウアラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市留辺蘂町旭中央', '01', '01208', '0910023', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '留辺蘂町旭中央', 'ルベシベチョウアサヒチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町霞町', '18', '18210', '9100231', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町霞町', 'マルオカチョウカスミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町霞ケ丘', '18', '18210', '9100232', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町霞ケ丘', 'マルオカチョウカスミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町東陽', '18', '18210', '9100233', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町東陽', 'マルオカチョウトウヨウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町今市', '18', '18210', '9100234', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町今市', 'マルオカチョウイマイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町巽町', '18', '18210', '9100235', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町巽町', 'マルオカチョウタツミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町本町', '18', '18210', '9100236', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町本町', 'マルオカチョウホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町乾', '18', '18210', '9100237', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町乾', 'マルオカチョウイヌイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市留辺蘂町旭南', '01', '01208', '0910024', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '留辺蘂町旭南', 'ルベシベチョウアサヒミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町柳町', '18', '18210', '9100241', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町柳町', 'マルオカチョウヤナギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町西里丸岡', '18', '18210', '9100242', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町西里丸岡', 'マルオカチョウニシサトマルオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町石城戸町', '18', '18210', '9100243', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町石城戸町', 'マルオカチョウイシキドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町富田町', '18', '18210', '9100244', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町富田町', 'マルオカチョウトミタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町谷町', '18', '18210', '9100245', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町谷町', 'マルオカチョウタニマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町西瓜屋', '18', '18210', '9100246', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町西瓜屋', 'マルオカチョウニシウリヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市留辺蘂町旭北', '01', '01208', '0910025', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '留辺蘂町旭北', 'ルベシベチョウアサヒキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町一本田福所', '18', '18210', '9100251', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町一本田福所', 'マルオカチョウイッポンデンフクショ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町御幸', '18', '18210', '9100252', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町御幸', 'マルオカチョウミユキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町一本田中', '18', '18210', '9100253', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町一本田中', 'マルオカチョウイッポンデンナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町一本田', '18', '18210', '9100254', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町一本田', 'マルオカチョウイッポンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市留辺蘂町旭公園', '01', '01208', '0910026', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '留辺蘂町旭公園', 'ルベシベチョウアサヒコウエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町針ノ木', '18', '18210', '9100261', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町針ノ木', 'マルオカチョウハリノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町栄', '18', '18210', '9100262', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町栄', 'マルオカチョウサカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町上田町', '18', '18210', '9100263', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町上田町', 'マルオカチョウウエダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町乾下田', '18', '18210', '9100264', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町乾下田', 'マルオカチョウイヌイシモダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町朝陽', '18', '18210', '9100265', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町朝陽', 'マルオカチョウアサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市留辺蘂町旭西', '01', '01208', '0910027', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '留辺蘂町旭西', 'ルベシベチョウアサヒニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町堀水', '18', '18210', '9100271', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町堀水', 'マルオカチョウホリミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町乗兼', '18', '18210', '9100272', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町乗兼', 'マルオカチョウノリカネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町長畝', '18', '18210', '9100273', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町長畝', 'マルオカチョウノウネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町千田', '18', '18210', '9100274', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町千田', 'マルオカチョウセンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町宇田', '18', '18210', '9100275', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町宇田', 'マルオカチョウウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町玄女', '18', '18210', '9100276', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町玄女', 'マルオカチョウゲンニョ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町里竹田', '18', '18210', '9100277', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町里竹田', 'マルオカチョウサトタケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市留辺蘂町旭3区', '01', '01208', '0910028', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '留辺蘂町旭3区', 'ルベシベチョウアサヒ03ク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市留辺蘂町旭1区', '01', '01208', '0910029', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '留辺蘂町旭1区', 'ルベシベチョウアサヒ01ク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町愛宕', '18', '18210', '9100301', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町愛宕', 'マルオカチョウアタゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町里丸岡', '18', '18210', '9100302', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町里丸岡', 'マルオカチョウサトマルオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町猪爪', '18', '18210', '9100303', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町猪爪', 'マルオカチョウイノツメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町今福', '18', '18210', '9100304', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町今福', 'マルオカチョウイマフク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町八幡町', '18', '18210', '9100305', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町八幡町', 'マルオカチョウハチマンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市留辺蘂町大富', '01', '01208', '0910031', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '留辺蘂町大富', 'ルベシベチョウオオトミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町豊原', '18', '18210', '9100311', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町豊原', 'マルオカチョウトヨハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町曽々木', '18', '18210', '9100312', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町曽々木', 'マルオカチョウソソキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町内田', '18', '18210', '9100313', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町内田', 'マルオカチョウウチダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町舛田', '18', '18210', '9100314', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町舛田', 'マルオカチョウマスタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町小黒', '18', '18210', '9100315', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町小黒', 'マルオカチョウオグロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町篠岡', '18', '18210', '9100316', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町篠岡', 'マルオカチョウシノオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市留辺蘂町豊金', '01', '01208', '0910032', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '留辺蘂町豊金', 'ルベシベチョウトヨガネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町山崎三ケ', '18', '18210', '9100321', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町山崎三ケ', 'マルオカチョウヤマサキサンガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町大森', '18', '18210', '9100322', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町大森', 'マルオカチョウオオモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町野中山王', '18', '18210', '9100323', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町野中山王', 'マルオカチョウノナカサンノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町油為頭', '18', '18210', '9100324', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町油為頭', 'マルオカチョウアブラタメトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町板倉', '18', '18210', '9100325', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町板倉', 'マルオカチョウイタクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町末政', '18', '18210', '9100326', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町末政', 'マルオカチョウスエマサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市留辺蘂町栄町', '01', '01208', '0910033', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '留辺蘂町栄町', 'ルベシベチョウサカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町上久米田', '18', '18210', '9100331', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町上久米田', 'マルオカチョウカミクメダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町下久米田', '18', '18210', '9100332', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町下久米田', 'マルオカチョウシモクメダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町金元', '18', '18210', '9100333', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町金元', 'マルオカチョウカネモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町東二ツ屋', '18', '18210', '9100334', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町東二ツ屋', 'マルオカチョウヒガシフタツヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町上金屋', '18', '18210', '9100335', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町上金屋', 'マルオカチョウカミカナヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町楽間', '18', '18210', '9100336', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町楽間', 'マルオカチョウラクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町新鳴鹿', '18', '18210', '9100337', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町新鳴鹿', 'マルオカチョウシンナルカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町為安', '18', '18210', '9100338', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町為安', 'マルオカチョウタメヤス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町寄永', '18', '18210', '9100339', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町寄永', 'マルオカチョウヨリナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町四ツ柳', '18', '18210', '9100341', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町四ツ柳', 'マルオカチョウヨツヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町高田', '18', '18210', '9100342', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町高田', 'マルオカチョウタカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町坪ノ内', '18', '18210', '9100343', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町坪ノ内', 'マルオカチョウツボノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町友末', '18', '18210', '9100344', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町友末', 'マルオカチョウトモスエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町四郎丸', '18', '18210', '9100345', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町四郎丸', 'マルオカチョウシロウマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町磯部島', '18', '18210', '9100346', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町磯部島', 'マルオカチョウイソベシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町熊堂', '18', '18210', '9100347', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町熊堂', 'マルオカチョウクマンドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町今町', '18', '18210', '9100348', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町今町', 'マルオカチョウイママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町反保', '18', '18210', '9100349', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町反保', 'マルオカチョウタンボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町南今市', '18', '18210', '9100350', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町南今市', 'マルオカチョウミナミイマイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町寅国', '18', '18210', '9100351', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町寅国', 'マルオカチョウトラクニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町新間', '18', '18210', '9100352', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町新間', 'マルオカチョウシンマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町筑後清水', '18', '18210', '9100353', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町筑後清水', 'マルオカチョウチクゴショウズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町豊原高瀬', '18', '18210', '9100354', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町豊原高瀬', 'マルオカチョウトヨハラタカセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町高瀬', '18', '18210', '9100355', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町高瀬', 'マルオカチョウタカセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町牛ケ島', '18', '18210', '9100356', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町牛ケ島', 'マルオカチョウウシガシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町儀間', '18', '18210', '9100357', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町儀間', 'マルオカチョウギマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町安田新', '18', '18210', '9100361', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町安田新', 'マルオカチョウヤスタシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町上安田', '18', '18210', '9100362', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町上安田', 'マルオカチョウカミヤスタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町下安田', '18', '18210', '9100363', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町下安田', 'マルオカチョウシモヤスタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町八丁', '18', '18210', '9100364', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町八丁', 'マルオカチョウハッチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町磯部福庄', '18', '18210', '9100365', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町磯部福庄', 'マルオカチョウイソベフクショ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町宇随', '18', '18210', '9100366', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町宇随', 'マルオカチョウウズイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町羽崎', '18', '18210', '9100367', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町羽崎', 'マルオカチョウハサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町磯部新保', '18', '18210', '9100368', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町磯部新保', 'マルオカチョウイソベシンボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町新九頭竜', '18', '18210', '9100369', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町新九頭竜', 'マルオカチョウシンクズリュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町八ツ口', '18', '18210', '9100371', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町八ツ口', 'マルオカチョウヤツクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町吉政', '18', '18210', '9100372', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町吉政', 'マルオカチョウヨシマサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町高柳', '18', '18210', '9100373', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町高柳', 'マルオカチョウタカヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町北横地', '18', '18210', '9100374', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町北横地', 'マルオカチョウキタヨコジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町南横地', '18', '18210', '9100375', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町南横地', 'マルオカチョウミナミヨコジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町舟寄', '18', '18210', '9100381', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町舟寄', 'マルオカチョウフナヨセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町笹和田', '18', '18210', '9100382', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町笹和田', 'マルオカチョウササワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町長崎', '18', '18210', '9100383', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町長崎', 'マルオカチョウナガサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市丸岡町四ツ屋', '18', '18210', '9100384', '福井県', 'フクイケン', '坂井市', 'サカイシ', '丸岡町四ツ屋', 'マルオカチョウヨツヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市寺前町', '18', '18201', '9100801', '福井県', 'フクイケン', '福井市', 'フクイシ', '寺前町', 'テラマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市大和田町', '18', '18201', '9100802', '福井県', 'フクイケン', '福井市', 'フクイシ', '大和田町', 'オオワダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市高柳町', '18', '18201', '9100803', '福井県', 'フクイケン', '福井市', 'フクイシ', '高柳町', 'タカヤナギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市高木中央', '18', '18201', '9100804', '福井県', 'フクイケン', '福井市', 'フクイシ', '高木中央', 'タカギチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市高木', '18', '18201', '9100805', '福井県', 'フクイケン', '福井市', 'フクイシ', '高木', 'タカギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市高木町', '18', '18201', '9100806', '福井県', 'フクイケン', '福井市', 'フクイシ', '高木町', 'タカギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市高木北', '18', '18201', '9100807', '福井県', 'フクイケン', '福井市', 'フクイシ', '高木北', 'タカギキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市舟橋', '18', '18201', '9100808', '福井県', 'フクイケン', '福井市', 'フクイシ', '舟橋', 'フナバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市舟橋町', '18', '18201', '9100809', '福井県', 'フクイケン', '福井市', 'フクイシ', '舟橋町', 'フナバシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市中藤新保町', '18', '18201', '9100811', '福井県', 'フクイケン', '福井市', 'フクイシ', '中藤新保町', 'ナカフジシンボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市新田本町', '18', '18201', '9100812', '福井県', 'フクイケン', '福井市', 'フクイシ', '新田本町', 'シンデンホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市中新田町', '18', '18201', '9100813', '福井県', 'フクイケン', '福井市', 'フクイシ', '中新田町', 'ナカシンデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市北野下町', '18', '18201', '9100814', '福井県', 'フクイケン', '福井市', 'フクイシ', '北野下町', 'キタノシモチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市北野上町', '18', '18201', '9100815', '福井県', 'フクイケン', '福井市', 'フクイシ', '北野上町', 'キタノカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市中ノ郷町', '18', '18201', '9100816', '福井県', 'フクイケン', '福井市', 'フクイシ', '中ノ郷町', 'ナカノゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市泉田町', '18', '18201', '9100817', '福井県', 'フクイケン', '福井市', 'フクイシ', '泉田町', 'イズミダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市堂島町', '18', '18201', '9100818', '福井県', 'フクイケン', '福井市', 'フクイシ', '堂島町', 'ドウジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市島橋町', '18', '18201', '9100821', '福井県', 'フクイケン', '福井市', 'フクイシ', '島橋町', 'シマバシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市玄正島町', '18', '18201', '9100822', '福井県', 'フクイケン', '福井市', 'フクイシ', '玄正島町', 'ゲンショウジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市重立町', '18', '18201', '9100823', '福井県', 'フクイケン', '福井市', 'フクイシ', '重立町', 'シゲタテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市間山町', '18', '18201', '9100824', '福井県', 'フクイケン', '福井市', 'フクイシ', '間山町', 'マヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市原目町', '18', '18201', '9100825', '福井県', 'フクイケン', '福井市', 'フクイシ', '原目町', 'ハラメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市上中町', '18', '18201', '9100826', '福井県', 'フクイケン', '福井市', 'フクイシ', '上中町', 'カミナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市藤島町', '18', '18201', '9100827', '福井県', 'フクイケン', '福井市', 'フクイシ', '藤島町', 'フジシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市林町', '18', '18201', '9100828', '福井県', 'フクイケン', '福井市', 'フクイシ', '林町', 'ハヤシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市林藤島町', '18', '18201', '9100829', '福井県', 'フクイケン', '福井市', 'フクイシ', '林藤島町', 'ハヤシフジシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市若栄町', '18', '18201', '9100831', '福井県', 'フクイケン', '福井市', 'フクイシ', '若栄町', 'ワカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市新保町', '18', '18201', '9100832', '福井県', 'フクイケン', '福井市', 'フクイシ', '新保町', 'シンボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市新保', '18', '18201', '9100833', '福井県', 'フクイケン', '福井市', 'フクイシ', '新保', 'シンボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市丸山', '18', '18201', '9100834', '福井県', 'フクイケン', '福井市', 'フクイシ', '丸山', 'マルヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市丸山町', '18', '18201', '9100835', '福井県', 'フクイケン', '福井市', 'フクイシ', '丸山町', 'マルヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市開発町', '18', '18201', '9100841', '福井県', 'フクイケン', '福井市', 'フクイシ', '開発町', 'カイホツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市開発', '18', '18201', '9100842', '福井県', 'フクイケン', '福井市', 'フクイシ', '開発', 'カイホツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市西開発', '18', '18201', '9100843', '福井県', 'フクイケン', '福井市', 'フクイシ', '西開発', 'ニシカイホツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市長本町', '18', '18201', '9100844', '福井県', 'フクイケン', '福井市', 'フクイシ', '長本町', 'ナガモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市志比口', '18', '18201', '9100845', '福井県', 'フクイケン', '福井市', 'フクイシ', '志比口', 'シヒグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市四ツ井', '18', '18201', '9100846', '福井県', 'フクイケン', '福井市', 'フクイシ', '四ツ井', 'ヨツイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市米松', '18', '18201', '9100851', '福井県', 'フクイケン', '福井市', 'フクイシ', '米松', 'ヨネマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市松城町', '18', '18201', '9100852', '福井県', 'フクイケン', '福井市', 'フクイシ', '松城町', 'マツシロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市城東', '18', '18201', '9100853', '福井県', 'フクイケン', '福井市', 'フクイシ', '城東', 'ジョウトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市御幸', '18', '18201', '9100854', '福井県', 'フクイケン', '福井市', 'フクイシ', '御幸', 'ミユキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市西方', '18', '18201', '9100855', '福井県', 'フクイケン', '福井市', 'フクイシ', '西方', 'ニシカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市勝見', '18', '18201', '9100856', '福井県', 'フクイケン', '福井市', 'フクイシ', '勝見', 'カツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市豊島', '18', '18201', '9100857', '福井県', 'フクイケン', '福井市', 'フクイシ', '豊島', 'トヨシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市手寄', '18', '18201', '9100858', '福井県', 'フクイケン', '福井市', 'フクイシ', '手寄', 'テヨセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市日之出', '18', '18201', '9100859', '福井県', 'フクイケン', '福井市', 'フクイシ', '日之出', 'ヒノデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県吉田郡永平寺町', '18', '18322', '9101100', '福井県', 'フクイケン', '吉田郡永平寺町', 'ヨシダグンエイヘイジチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('120242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県吉田郡永平寺町松岡樋爪', '18', '18322', '9101101', '福井県', 'フクイケン', '吉田郡永平寺町', 'ヨシダグンエイヘイジチョウ', '松岡樋爪', 'マツオカヒヅメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県吉田郡永平寺町松岡学園', '18', '18322', '9101102', '福井県', 'フクイケン', '吉田郡永平寺町', 'ヨシダグンエイヘイジチョウ', '松岡学園', 'マツオカガクエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県吉田郡永平寺町松岡上合月', '18', '18322', '9101103', '福井県', 'フクイケン', '吉田郡永平寺町', 'ヨシダグンエイヘイジチョウ', '松岡上合月', 'マツオカカミアイヅキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県吉田郡永平寺町松岡下合月', '18', '18322', '9101104', '福井県', 'フクイケン', '吉田郡永平寺町', 'ヨシダグンエイヘイジチョウ', '松岡下合月', 'マツオカシモアイヅキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県吉田郡永平寺町松岡末政', '18', '18322', '9101105', '福井県', 'フクイケン', '吉田郡永平寺町', 'ヨシダグンエイヘイジチョウ', '松岡末政', 'マツオカスエマサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県吉田郡永平寺町松岡御公領', '18', '18322', '9101106', '福井県', 'フクイケン', '吉田郡永平寺町', 'ヨシダグンエイヘイジチョウ', '松岡御公領', 'マツオカゴクリョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県吉田郡永平寺町松岡志比堺', '18', '18322', '9101111', '福井県', 'フクイケン', '吉田郡永平寺町', 'ヨシダグンエイヘイジチョウ', '松岡志比堺', 'マツオカシヒザカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県吉田郡永平寺町松岡越坂', '18', '18322', '9101112', '福井県', 'フクイケン', '吉田郡永平寺町', 'ヨシダグンエイヘイジチョウ', '松岡越坂', 'マツオカコイサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県吉田郡永平寺町松岡松ケ丘', '18', '18322', '9101113', '福井県', 'フクイケン', '吉田郡永平寺町', 'ヨシダグンエイヘイジチョウ', '松岡松ケ丘', 'マツオカマツガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県吉田郡永平寺町松岡城東', '18', '18322', '9101114', '福井県', 'フクイケン', '吉田郡永平寺町', 'ヨシダグンエイヘイジチョウ', '松岡城東', 'マツオカジョウトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県吉田郡永平寺町松岡石舟', '18', '18322', '9101115', '福井県', 'フクイケン', '吉田郡永平寺町', 'ヨシダグンエイヘイジチョウ', '松岡石舟', 'マツオカイシフネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県吉田郡永平寺町松岡清水', '18', '18322', '9101116', '福井県', 'フクイケン', '吉田郡永平寺町', 'ヨシダグンエイヘイジチョウ', '松岡清水', 'マツオカシミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県吉田郡永平寺町松岡神明', '18', '18322', '9101117', '福井県', 'フクイケン', '吉田郡永平寺町', 'ヨシダグンエイヘイジチョウ', '松岡神明', 'マツオカシンメイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県吉田郡永平寺町松岡薬師', '18', '18322', '9101118', '福井県', 'フクイケン', '吉田郡永平寺町', 'ヨシダグンエイヘイジチョウ', '松岡薬師', 'マツオカヤクシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県吉田郡永平寺町松岡吉野', '18', '18322', '9101121', '福井県', 'フクイケン', '吉田郡永平寺町', 'ヨシダグンエイヘイジチョウ', '松岡吉野', 'マツオカヨシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県吉田郡永平寺町松岡宮重', '18', '18322', '9101122', '福井県', 'フクイケン', '吉田郡永平寺町', 'ヨシダグンエイヘイジチョウ', '松岡宮重', 'マツオカミヤシゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県吉田郡永平寺町松岡湯谷', '18', '18322', '9101123', '福井県', 'フクイケン', '吉田郡永平寺町', 'ヨシダグンエイヘイジチョウ', '松岡湯谷', 'マツオカユダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県吉田郡永平寺町松岡上吉野', '18', '18322', '9101124', '福井県', 'フクイケン', '吉田郡永平寺町', 'ヨシダグンエイヘイジチョウ', '松岡上吉野', 'マツオカカミヨシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県吉田郡永平寺町松岡西野中', '18', '18322', '9101125', '福井県', 'フクイケン', '吉田郡永平寺町', 'ヨシダグンエイヘイジチョウ', '松岡西野中', 'マツオカニシノナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県吉田郡永平寺町松岡小畑', '18', '18322', '9101126', '福井県', 'フクイケン', '吉田郡永平寺町', 'ヨシダグンエイヘイジチョウ', '松岡小畑', 'マツオカオバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県吉田郡永平寺町松岡吉野堺', '18', '18322', '9101127', '福井県', 'フクイケン', '吉田郡永平寺町', 'ヨシダグンエイヘイジチョウ', '松岡吉野堺', 'マツオカヨシノザカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県吉田郡永平寺町松岡椚', '18', '18322', '9101131', '福井県', 'フクイケン', '吉田郡永平寺町', 'ヨシダグンエイヘイジチョウ', '松岡椚', 'マツオカクヌギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県吉田郡永平寺町松岡葵', '18', '18322', '9101132', '福井県', 'フクイケン', '吉田郡永平寺町', 'ヨシダグンエイヘイジチョウ', '松岡葵', 'マツオカアオイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県吉田郡永平寺町松岡春日', '18', '18322', '9101133', '福井県', 'フクイケン', '吉田郡永平寺町', 'ヨシダグンエイヘイジチョウ', '松岡春日', 'マツオカカスガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県吉田郡永平寺町松岡芝原', '18', '18322', '9101134', '福井県', 'フクイケン', '吉田郡永平寺町', 'ヨシダグンエイヘイジチョウ', '松岡芝原', 'マツオカシバハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県吉田郡永平寺町松岡室', '18', '18322', '9101135', '福井県', 'フクイケン', '吉田郡永平寺町', 'ヨシダグンエイヘイジチョウ', '松岡室', 'マツオカムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県吉田郡永平寺町松岡窪', '18', '18322', '9101136', '福井県', 'フクイケン', '吉田郡永平寺町', 'ヨシダグンエイヘイジチョウ', '松岡窪', 'マツオカクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県吉田郡永平寺町松岡観音', '18', '18322', '9101137', '福井県', 'フクイケン', '吉田郡永平寺町', 'ヨシダグンエイヘイジチョウ', '松岡観音', 'マツオカカンノン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県吉田郡永平寺町松岡松ケ原', '18', '18322', '9101138', '福井県', 'フクイケン', '吉田郡永平寺町', 'ヨシダグンエイヘイジチョウ', '松岡松ケ原', 'マツオカマツガハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県吉田郡永平寺町松岡木ノ下', '18', '18322', '9101139', '福井県', 'フクイケン', '吉田郡永平寺町', 'ヨシダグンエイヘイジチョウ', '松岡木ノ下', 'マツオカコノシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県吉田郡永平寺町松岡領家', '18', '18322', '9101141', '福井県', 'フクイケン', '吉田郡永平寺町', 'ヨシダグンエイヘイジチョウ', '松岡領家', 'マツオカリョウケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県吉田郡永平寺町松岡兼定島', '18', '18322', '9101142', '福井県', 'フクイケン', '吉田郡永平寺町', 'ヨシダグンエイヘイジチョウ', '松岡兼定島', 'マツオカケンジョウジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県吉田郡永平寺町松岡渡新田', '18', '18322', '9101143', '福井県', 'フクイケン', '吉田郡永平寺町', 'ヨシダグンエイヘイジチョウ', '松岡渡新田', 'マツオカワタリシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県吉田郡永平寺町松岡平成', '18', '18322', '9101144', '福井県', 'フクイケン', '吉田郡永平寺町', 'ヨシダグンエイヘイジチョウ', '松岡平成', 'マツオカヘイセイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県吉田郡永平寺町鳴鹿山鹿', '18', '18322', '9101201', '福井県', 'フクイケン', '吉田郡永平寺町', 'ヨシダグンエイヘイジチョウ', '鳴鹿山鹿', 'ナルカサンガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県吉田郡永平寺町下浄法寺', '18', '18322', '9101202', '福井県', 'フクイケン', '吉田郡永平寺町', 'ヨシダグンエイヘイジチョウ', '下浄法寺', 'シモジョホウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県吉田郡永平寺町上浄法寺', '18', '18322', '9101203', '福井県', 'フクイケン', '吉田郡永平寺町', 'ヨシダグンエイヘイジチョウ', '上浄法寺', 'カミジョホウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県吉田郡永平寺町岩野', '18', '18322', '9101204', '福井県', 'フクイケン', '吉田郡永平寺町', 'ヨシダグンエイヘイジチョウ', '岩野', 'イワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県吉田郡永平寺町吉波', '18', '18322', '9101205', '福井県', 'フクイケン', '吉田郡永平寺町', 'ヨシダグンエイヘイジチョウ', '吉波', 'ヨシナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県吉田郡永平寺町栃原', '18', '18322', '9101206', '福井県', 'フクイケン', '吉田郡永平寺町', 'ヨシダグンエイヘイジチョウ', '栃原', 'トチハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県吉田郡永平寺町法寺岡', '18', '18322', '9101211', '福井県', 'フクイケン', '吉田郡永平寺町', 'ヨシダグンエイヘイジチョウ', '法寺岡', 'ホウジオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県吉田郡永平寺町東古市', '18', '18322', '9101212', '福井県', 'フクイケン', '吉田郡永平寺町', 'ヨシダグンエイヘイジチョウ', '東古市', 'ヒガシフルイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県吉田郡永平寺町高橋', '18', '18322', '9101213', '福井県', 'フクイケン', '吉田郡永平寺町', 'ヨシダグンエイヘイジチョウ', '高橋', 'タカハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県吉田郡永平寺町谷口', '18', '18322', '9101214', '福井県', 'フクイケン', '吉田郡永平寺町', 'ヨシダグンエイヘイジチョウ', '谷口', 'タニグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県吉田郡永平寺町花谷', '18', '18322', '9101215', '福井県', 'フクイケン', '吉田郡永平寺町', 'ヨシダグンエイヘイジチョウ', '花谷', 'ハナタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県吉田郡永平寺町光明寺', '18', '18322', '9101216', '福井県', 'フクイケン', '吉田郡永平寺町', 'ヨシダグンエイヘイジチョウ', '光明寺', 'コウミョウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県吉田郡永平寺町飯島', '18', '18322', '9101217', '福井県', 'フクイケン', '吉田郡永平寺町', 'ヨシダグンエイヘイジチョウ', '飯島', 'イイジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県吉田郡永平寺町轟', '18', '18322', '9101218', '福井県', 'フクイケン', '吉田郡永平寺町', 'ヨシダグンエイヘイジチョウ', '轟', 'ドメキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県吉田郡永平寺町山', '18', '18322', '9101221', '福井県', 'フクイケン', '吉田郡永平寺町', 'ヨシダグンエイヘイジチョウ', '山', 'ヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県吉田郡永平寺町諏訪間', '18', '18322', '9101222', '福井県', 'フクイケン', '吉田郡永平寺町', 'ヨシダグンエイヘイジチョウ', '諏訪間', 'スワマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県吉田郡永平寺町けやき台', '18', '18322', '9101223', '福井県', 'フクイケン', '吉田郡永平寺町', 'ヨシダグンエイヘイジチョウ', 'けやき台', 'ケヤキダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県吉田郡永平寺町寺本', '18', '18322', '9101224', '福井県', 'フクイケン', '吉田郡永平寺町', 'ヨシダグンエイヘイジチョウ', '寺本', 'テラモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県吉田郡永平寺町京善', '18', '18322', '9101225', '福井県', 'フクイケン', '吉田郡永平寺町', 'ヨシダグンエイヘイジチョウ', '京善', 'キョウゼン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県吉田郡永平寺町市野々', '18', '18322', '9101226', '福井県', 'フクイケン', '吉田郡永平寺町', 'ヨシダグンエイヘイジチョウ', '市野々', 'イチノノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県吉田郡永平寺町荒谷', '18', '18322', '9101227', '福井県', 'フクイケン', '吉田郡永平寺町', 'ヨシダグンエイヘイジチョウ', '荒谷', 'アラタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県吉田郡永平寺町志比', '18', '18322', '9101228', '福井県', 'フクイケン', '吉田郡永平寺町', 'ヨシダグンエイヘイジチョウ', '志比', 'シヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県吉田郡永平寺町中島', '18', '18322', '9101301', '福井県', 'フクイケン', '吉田郡永平寺町', 'ヨシダグンエイヘイジチョウ', '中島', 'ナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県吉田郡永平寺町市荒川', '18', '18322', '9101302', '福井県', 'フクイケン', '吉田郡永平寺町', 'ヨシダグンエイヘイジチョウ', '市荒川', 'イチアラカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県吉田郡永平寺町藤巻', '18', '18322', '9101303', '福井県', 'フクイケン', '吉田郡永平寺町', 'ヨシダグンエイヘイジチョウ', '藤巻', 'フジマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県吉田郡永平寺町吉峰', '18', '18322', '9101304', '福井県', 'フクイケン', '吉田郡永平寺町', 'ヨシダグンエイヘイジチョウ', '吉峰', 'ヨシミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県吉田郡永平寺町竹原', '18', '18322', '9101305', '福井県', 'フクイケン', '吉田郡永平寺町', 'ヨシダグンエイヘイジチョウ', '竹原', 'タケハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県吉田郡永平寺町大野島', '18', '18322', '9101311', '福井県', 'フクイケン', '吉田郡永平寺町', 'ヨシダグンエイヘイジチョウ', '大野島', 'オオノジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県吉田郡永平寺町清水', '18', '18322', '9101312', '福井県', 'フクイケン', '吉田郡永平寺町', 'ヨシダグンエイヘイジチョウ', '清水', 'シミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県吉田郡永平寺町石上', '18', '18322', '9101313', '福井県', 'フクイケン', '吉田郡永平寺町', 'ヨシダグンエイヘイジチョウ', '石上', 'イシガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県吉田郡永平寺町栗住波', '18', '18322', '9101314', '福井県', 'フクイケン', '吉田郡永平寺町', 'ヨシダグンエイヘイジチョウ', '栗住波', 'クリスナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県吉田郡永平寺町せせらぎ', '18', '18322', '9101315', '福井県', 'フクイケン', '吉田郡永平寺町', 'ヨシダグンエイヘイジチョウ', 'せせらぎ', 'セセラギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県吉田郡永平寺町市右エ門島', '18', '18322', '9101316', '福井県', 'フクイケン', '吉田郡永平寺町', 'ヨシダグンエイヘイジチョウ', '市右エ門島', 'イチウエモンジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県吉田郡永平寺町山王', '18', '18322', '9101321', '福井県', 'フクイケン', '吉田郡永平寺町', 'ヨシダグンエイヘイジチョウ', '山王', 'サンノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県吉田郡永平寺町大月', '18', '18322', '9101322', '福井県', 'フクイケン', '吉田郡永平寺町', 'ヨシダグンエイヘイジチョウ', '大月', 'オオツキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県吉田郡永平寺町浅見', '18', '18322', '9101323', '福井県', 'フクイケン', '吉田郡永平寺町', 'ヨシダグンエイヘイジチョウ', '浅見', 'アザミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県吉田郡永平寺町野中', '18', '18322', '9101324', '福井県', 'フクイケン', '吉田郡永平寺町', 'ヨシダグンエイヘイジチョウ', '野中', 'ノナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県吉田郡永平寺町北島', '18', '18322', '9101325', '福井県', 'フクイケン', '吉田郡永平寺町', 'ヨシダグンエイヘイジチョウ', '北島', 'キタジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県吉田郡永平寺町牧福島', '18', '18322', '9101326', '福井県', 'フクイケン', '吉田郡永平寺町', 'ヨシダグンエイヘイジチョウ', '牧福島', 'マキフクシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市留辺蘂町昭栄', '01', '01208', '0910151', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '留辺蘂町昭栄', 'ルベシベチョウショウエイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市留辺蘂町松山', '01', '01208', '0910153', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '留辺蘂町松山', 'ルベシベチョウマツヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市留辺蘂町平里', '01', '01208', '0910154', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '留辺蘂町平里', 'ルベシベチョウヒラサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市留辺蘂町大和', '01', '01208', '0910155', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '留辺蘂町大和', 'ルベシベチョウヤマト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市留辺蘂町川北', '01', '01208', '0910156', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '留辺蘂町川北', 'ルベシベチョウカワキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市留辺蘂町花丘', '01', '01208', '0910157', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '留辺蘂町花丘', 'ルベシベチョウハナオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市留辺蘂町厚和', '01', '01208', '0910161', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '留辺蘂町厚和', 'ルベシベチョウコウワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市留辺蘂町富士見', '01', '01208', '0910162', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '留辺蘂町富士見', 'ルベシベチョウフジミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市留辺蘂町滝の湯', '01', '01208', '0910163', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '留辺蘂町滝の湯', 'ルベシベチョウタキノユ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市留辺蘂町温根湯温泉', '01', '01208', '0910170', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '留辺蘂町温根湯温泉', 'ルベシベチョウオンネユオンセン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市高尾町', '18', '18201', '9102141', '福井県', 'フクイケン', '福井市', 'フクイシ', '高尾町', 'タカオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市前波町', '18', '18201', '9102142', '福井県', 'フクイケン', '福井市', 'フクイシ', '前波町', 'マエバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市宿布町', '18', '18201', '9102143', '福井県', 'フクイケン', '福井市', 'フクイシ', '宿布町', 'シクヌノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市上毘沙門町', '18', '18201', '9102144', '福井県', 'フクイケン', '福井市', 'フクイシ', '上毘沙門町', 'カミビシャモンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市中毘沙門町', '18', '18201', '9102145', '福井県', 'フクイケン', '福井市', 'フクイシ', '中毘沙門町', 'ナカビシャモンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市下毘沙門町', '18', '18201', '9102146', '福井県', 'フクイケン', '福井市', 'フクイシ', '下毘沙門町', 'シモビシャモンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市成願寺町', '18', '18201', '9102147', '福井県', 'フクイケン', '福井市', 'フクイシ', '成願寺町', 'ジョウガンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市篠尾町', '18', '18201', '9102148', '福井県', 'フクイケン', '福井市', 'フクイシ', '篠尾町', 'シノオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市安波賀中島町', '18', '18201', '9102151', '福井県', 'フクイケン', '福井市', 'フクイシ', '安波賀中島町', 'アバカナカジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市安波賀町', '18', '18201', '9102152', '福井県', 'フクイケン', '福井市', 'フクイシ', '安波賀町', 'アバカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市城戸ノ内町', '18', '18201', '9102153', '福井県', 'フクイケン', '福井市', 'フクイシ', '城戸ノ内町', 'キドノウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市東新町', '18', '18201', '9102154', '福井県', 'フクイケン', '福井市', 'フクイシ', '東新町', 'ヒガシシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市浄教寺町', '18', '18201', '9102155', '福井県', 'フクイケン', '福井市', 'フクイシ', '浄教寺町', 'ジョウキョウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市鹿俣町', '18', '18201', '9102156', '福井県', 'フクイケン', '福井市', 'フクイシ', '鹿俣町', 'カナマタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市西新町', '18', '18201', '9102157', '福井県', 'フクイケン', '福井市', 'フクイシ', '西新町', 'ニシシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市脇三ケ町', '18', '18201', '9102161', '福井県', 'フクイケン', '福井市', 'フクイシ', '脇三ケ町', 'ワキサンガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市南山町', '18', '18201', '9102162', '福井県', 'フクイケン', '福井市', 'フクイシ', '南山町', 'ミナミヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市栃泉町', '18', '18201', '9102163', '福井県', 'フクイケン', '福井市', 'フクイシ', '栃泉町', 'トチイズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市深見町', '18', '18201', '9102164', '福井県', 'フクイケン', '福井市', 'フクイシ', '深見町', 'フカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市東郷二ケ町', '18', '18201', '9102165', '福井県', 'フクイケン', '福井市', 'フクイシ', '東郷二ケ町', 'トウゴウニカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市小路町', '18', '18201', '9102166', '福井県', 'フクイケン', '福井市', 'フクイシ', '小路町', 'ショウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市安原町', '18', '18201', '9102167', '福井県', 'フクイケン', '福井市', 'フクイシ', '安原町', 'ヤスハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市荒木町', '18', '18201', '9102171', '福井県', 'フクイケン', '福井市', 'フクイシ', '荒木町', 'アラキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市荒木新保町', '18', '18201', '9102172', '福井県', 'フクイケン', '福井市', 'フクイシ', '荒木新保町', 'アラキシンボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市下東郷町', '18', '18201', '9102173', '福井県', 'フクイケン', '福井市', 'フクイシ', '下東郷町', 'シモトウゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市上東郷町', '18', '18201', '9102174', '福井県', 'フクイケン', '福井市', 'フクイシ', '上東郷町', 'カミトウゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市円成寺町', '18', '18201', '9102175', '福井県', 'フクイケン', '福井市', 'フクイシ', '円成寺町', 'エンジョウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市東郷中島町', '18', '18201', '9102176', '福井県', 'フクイケン', '福井市', 'フクイシ', '東郷中島町', 'トウゴウナカジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市稲津町', '18', '18201', '9102177', '福井県', 'フクイケン', '福井市', 'フクイシ', '稲津町', 'イナヅチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市栂野町', '18', '18201', '9102178', '福井県', 'フクイケン', '福井市', 'フクイシ', '栂野町', 'トガノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市皿谷町', '18', '18201', '9102201', '福井県', 'フクイケン', '福井市', 'フクイシ', '皿谷町', 'サラダニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市所谷町', '18', '18201', '9102202', '福井県', 'フクイケン', '福井市', 'フクイシ', '所谷町', 'トコロダニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市西中町', '18', '18201', '9102203', '福井県', 'フクイケン', '福井市', 'フクイシ', '西中町', 'ニシナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市美山大谷町', '18', '18201', '9102204', '福井県', 'フクイケン', '福井市', 'フクイシ', '美山大谷町', 'ミヤマオオタニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市篭谷町', '18', '18201', '9102205', '福井県', 'フクイケン', '福井市', 'フクイシ', '篭谷町', 'カゴヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市吉山町上吉山', '18', '18201', '9102206', '福井県', 'フクイケン', '福井市', 'フクイシ', '吉山町', 'ヨシヤマチョウ', null, null, '上吉山', 'カミヨシヤマ');
INSERT INTO `ms_addresses` VALUES ('120373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市吉山町下吉山', '18', '18201', '9102207', '福井県', 'フクイケン', '福井市', 'フクイシ', '吉山町', 'ヨシヤマチョウ', null, null, '下吉山', 'シモヨシヤマ');
INSERT INTO `ms_addresses` VALUES ('120374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市吉山町', '18', '18201', '9102208', '福井県', 'フクイケン', '福井市', 'フクイシ', '吉山町', 'ヨシヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市獺ケ口町', '18', '18201', '9102211', '福井県', 'フクイケン', '福井市', 'フクイシ', '獺ケ口町', 'ウソガグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市小和清水町', '18', '18201', '9102212', '福井県', 'フクイケン', '福井市', 'フクイシ', '小和清水町', 'コワショウズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市大久保町', '18', '18201', '9102213', '福井県', 'フクイケン', '福井市', 'フクイシ', '大久保町', 'オオクボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市福島町', '18', '18201', '9102214', '福井県', 'フクイケン', '福井市', 'フクイシ', '福島町', 'フクシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市奈良瀬町', '18', '18201', '9102221', '福井県', 'フクイケン', '福井市', 'フクイシ', '奈良瀬町', 'ナラセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市市波町', '18', '18201', '9102222', '福井県', 'フクイケン', '福井市', 'フクイシ', '市波町', 'イチナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市宇坂別所町', '18', '18201', '9102223', '福井県', 'フクイケン', '福井市', 'フクイシ', '宇坂別所町', 'ウサカベッショチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市三万谷町', '18', '18201', '9102224', '福井県', 'フクイケン', '福井市', 'フクイシ', '三万谷町', 'サンマンダニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市田尻町', '18', '18201', '9102225', '福井県', 'フクイケン', '福井市', 'フクイシ', '田尻町', 'タジリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市高田町', '18', '18201', '9102226', '福井県', 'フクイケン', '福井市', 'フクイシ', '高田町', 'タカタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市宇坂大谷町', '18', '18201', '9102227', '福井県', 'フクイケン', '福井市', 'フクイシ', '宇坂大谷町', 'ウサカオオタニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市計石町', '18', '18201', '9102331', '福井県', 'フクイケン', '福井市', 'フクイシ', '計石町', 'ハカリイシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市野波町', '18', '18201', '9102332', '福井県', 'フクイケン', '福井市', 'フクイシ', '野波町', 'ノナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市野波町追分', '18', '18201', '9102333', '福井県', 'フクイケン', '福井市', 'フクイシ', '野波町', 'ノナミチョウ', null, null, '追分', 'オイワケ');
INSERT INTO `ms_addresses` VALUES ('120389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市大宮町', '18', '18201', '9102334', '福井県', 'フクイケン', '福井市', 'フクイシ', '大宮町', 'オオミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市縫原町', '18', '18201', '9102335', '福井県', 'フクイケン', '福井市', 'フクイシ', '縫原町', 'ヌイバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市仁位町', '18', '18201', '9102336', '福井県', 'フクイケン', '福井市', 'フクイシ', '仁位町', 'ニイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市薬師町上薬師', '18', '18201', '9102337', '福井県', 'フクイケン', '福井市', 'フクイシ', '薬師町', 'ヤクシチョウ', null, null, '上薬師', 'カミヤクシ');
INSERT INTO `ms_addresses` VALUES ('120393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市薬師町下薬師', '18', '18201', '9102338', '福井県', 'フクイケン', '福井市', 'フクイシ', '薬師町', 'ヤクシチョウ', null, null, '下薬師', 'シモヤクシ');
INSERT INTO `ms_addresses` VALUES ('120394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市薬師町', '18', '18201', '9102339', '福井県', 'フクイケン', '福井市', 'フクイシ', '薬師町', 'ヤクシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市東川上町', '18', '18201', '9102341', '福井県', 'フクイケン', '福井市', 'フクイシ', '東川上町', 'ヒガシカワカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市東俣町', '18', '18201', '9102342', '福井県', 'フクイケン', '福井市', 'フクイシ', '東俣町', 'ヒガシマタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市南西俣町', '18', '18201', '9102343', '福井県', 'フクイケン', '福井市', 'フクイシ', '南西俣町', 'ミナミニシマタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市南宮地町', '18', '18201', '9102344', '福井県', 'フクイケン', '福井市', 'フクイシ', '南宮地町', 'ミナミミヤジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市間戸町', '18', '18201', '9102345', '福井県', 'フクイケン', '福井市', 'フクイシ', '間戸町', 'マトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市椙谷町', '18', '18201', '9102346', '福井県', 'フクイケン', '福井市', 'フクイシ', '椙谷町', 'スイダニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市境寺町', '18', '18201', '9102347', '福井県', 'フクイケン', '福井市', 'フクイシ', '境寺町', 'サカイデラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市品ケ瀬町', '18', '18201', '9102348', '福井県', 'フクイケン', '福井市', 'フクイシ', '品ケ瀬町', 'シナガセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市美山町', '18', '18201', '9102351', '福井県', 'フクイケン', '福井市', 'フクイシ', '美山町', 'ミヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市小宇坂町', '18', '18201', '9102352', '福井県', 'フクイケン', '福井市', 'フクイシ', '小宇坂町', 'コウサカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市小宇坂島町', '18', '18201', '9102353', '福井県', 'フクイケン', '福井市', 'フクイシ', '小宇坂島町', 'コウサカジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市東天田町', '18', '18201', '9102354', '福井県', 'フクイケン', '福井市', 'フクイシ', '東天田町', 'ヒガシアマダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市西天田町', '18', '18201', '9102355', '福井県', 'フクイケン', '福井市', 'フクイシ', '西天田町', 'ニシアマダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市蔵作町', '18', '18201', '9102356', '福井県', 'フクイケン', '福井市', 'フクイシ', '蔵作町', 'クラツクリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市朝谷町', '18', '18201', '9102357', '福井県', 'フクイケン', '福井市', 'フクイシ', '朝谷町', 'アサダニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市南野津又町', '18', '18201', '9102461', '福井県', 'フクイケン', '福井市', 'フクイシ', '南野津又町', 'ミナミノツマタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市神当部町', '18', '18201', '9102462', '福井県', 'フクイケン', '福井市', 'フクイシ', '神当部町', 'カントベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市味見河内町', '18', '18201', '9102463', '福井県', 'フクイケン', '福井市', 'フクイシ', '味見河内町', 'アジミコウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市中手町', '18', '18201', '9102464', '福井県', 'フクイケン', '福井市', 'フクイシ', '中手町', 'ナカンテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市小当見町', '18', '18201', '9102465', '福井県', 'フクイケン', '福井市', 'フクイシ', '小当見町', 'オトミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市西市布町', '18', '18201', '9102466', '福井県', 'フクイケン', '福井市', 'フクイシ', '西市布町', 'ニシイチヌノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市西河原町', '18', '18201', '9102471', '福井県', 'フクイケン', '福井市', 'フクイシ', '西河原町', 'ニシコウバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市東河原町', '18', '18201', '9102472', '福井県', 'フクイケン', '福井市', 'フクイシ', '東河原町', 'ヒガシコウバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市横越町', '18', '18201', '9102473', '福井県', 'フクイケン', '福井市', 'フクイシ', '横越町', 'ヨコゴシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市折立町', '18', '18201', '9102474', '福井県', 'フクイケン', '福井市', 'フクイシ', '折立町', 'オリタテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市赤谷町', '18', '18201', '9102475', '福井県', 'フクイケン', '福井市', 'フクイシ', '赤谷町', 'アカダニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県今立郡池田町', '18', '18382', '9102500', '福井県', 'フクイケン', '今立郡池田町', 'イマダテグンイケダチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('120423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県今立郡池田町持越', '18', '18382', '9102501', '福井県', 'フクイケン', '今立郡池田町', 'イマダテグンイケダチョウ', '持越', 'モチコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県今立郡池田町野尻', '18', '18382', '9102502', '福井県', 'フクイケン', '今立郡池田町', 'イマダテグンイケダチョウ', '野尻', 'ノジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県今立郡池田町谷口', '18', '18382', '9102503', '福井県', 'フクイケン', '今立郡池田町', 'イマダテグンイケダチョウ', '谷口', 'タニグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県今立郡池田町安善寺', '18', '18382', '9102504', '福井県', 'フクイケン', '今立郡池田町', 'イマダテグンイケダチョウ', '安善寺', 'アンゼンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県今立郡池田町水海', '18', '18382', '9102505', '福井県', 'フクイケン', '今立郡池田町', 'イマダテグンイケダチョウ', '水海', 'ミズウミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県今立郡池田町広瀬', '18', '18382', '9102506', '福井県', 'フクイケン', '今立郡池田町', 'イマダテグンイケダチョウ', '広瀬', 'ヒロセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県今立郡池田町清水谷', '18', '18382', '9102507', '福井県', 'フクイケン', '今立郡池田町', 'イマダテグンイケダチョウ', '清水谷', 'シミズタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県今立郡池田町柿ケ原', '18', '18382', '9102508', '福井県', 'フクイケン', '今立郡池田町', 'イマダテグンイケダチョウ', '柿ケ原', 'カキガハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県今立郡池田町薮田', '18', '18382', '9102511', '福井県', 'フクイケン', '今立郡池田町', 'イマダテグンイケダチョウ', '薮田', 'ヤブタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県今立郡池田町稲荷', '18', '18382', '9102512', '福井県', 'フクイケン', '今立郡池田町', 'イマダテグンイケダチョウ', '稲荷', 'イナリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県今立郡池田町寺島', '18', '18382', '9102513', '福井県', 'フクイケン', '今立郡池田町', 'イマダテグンイケダチョウ', '寺島', 'テラジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県今立郡池田町学園', '18', '18382', '9102514', '福井県', 'フクイケン', '今立郡池田町', 'イマダテグンイケダチョウ', '学園', 'ガクエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県今立郡池田町池田', '18', '18382', '9102515', '福井県', 'フクイケン', '今立郡池田町', 'イマダテグンイケダチョウ', '池田', 'イケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県今立郡池田町山田', '18', '18382', '9102516', '福井県', 'フクイケン', '今立郡池田町', 'イマダテグンイケダチョウ', '山田', 'ヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県今立郡池田町寺谷', '18', '18382', '9102517', '福井県', 'フクイケン', '今立郡池田町', 'イマダテグンイケダチョウ', '寺谷', 'テラダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県今立郡池田町常安', '18', '18382', '9102521', '福井県', 'フクイケン', '今立郡池田町', 'イマダテグンイケダチョウ', '常安', 'ツネヤス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県今立郡池田町月ケ瀬', '18', '18382', '9102522', '福井県', 'フクイケン', '今立郡池田町', 'イマダテグンイケダチョウ', '月ケ瀬', 'ツキガセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県今立郡池田町河内', '18', '18382', '9102523', '福井県', 'フクイケン', '今立郡池田町', 'イマダテグンイケダチョウ', '河内', 'コウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県今立郡池田町志津原', '18', '18382', '9102523', '福井県', 'フクイケン', '今立郡池田町', 'イマダテグンイケダチョウ', '志津原', 'シヅハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県今立郡池田町土合皿尾', '18', '18382', '9102524', '福井県', 'フクイケン', '今立郡池田町', 'イマダテグンイケダチョウ', '土合皿尾', 'ドアイサラオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県今立郡池田町市', '18', '18382', '9102525', '福井県', 'フクイケン', '今立郡池田町', 'イマダテグンイケダチョウ', '市', 'イチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県今立郡池田町上荒谷', '18', '18382', '9102526', '福井県', 'フクイケン', '今立郡池田町', 'イマダテグンイケダチョウ', '上荒谷', 'カミアラタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県今立郡池田町板垣', '18', '18382', '9102527', '福井県', 'フクイケン', '今立郡池田町', 'イマダテグンイケダチョウ', '板垣', 'イタガキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県今立郡池田町東角間', '18', '18382', '9102531', '福井県', 'フクイケン', '今立郡池田町', 'イマダテグンイケダチョウ', '東角間', 'ヒガシカクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県今立郡池田町新保', '18', '18382', '9102532', '福井県', 'フクイケン', '今立郡池田町', 'イマダテグンイケダチョウ', '新保', 'シンボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県今立郡池田町東俣', '18', '18382', '9102533', '福井県', 'フクイケン', '今立郡池田町', 'イマダテグンイケダチョウ', '東俣', 'ヒガシマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県今立郡池田町魚見', '18', '18382', '9102534', '福井県', 'フクイケン', '今立郡池田町', 'イマダテグンイケダチョウ', '魚見', 'ウオミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県今立郡池田町菅生', '18', '18382', '9102535', '福井県', 'フクイケン', '今立郡池田町', 'イマダテグンイケダチョウ', '菅生', 'スゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県今立郡池田町西角間', '18', '18382', '9102536', '福井県', 'フクイケン', '今立郡池田町', 'イマダテグンイケダチョウ', '西角間', 'ニシカクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県今立郡池田町定方', '18', '18382', '9102537', '福井県', 'フクイケン', '今立郡池田町', 'イマダテグンイケダチョウ', '定方', 'サダカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県今立郡池田町尾緩', '18', '18382', '9102551', '福井県', 'フクイケン', '今立郡池田町', 'イマダテグンイケダチョウ', '尾緩', 'オダルミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県今立郡池田町大本', '18', '18382', '9102552', '福井県', 'フクイケン', '今立郡池田町', 'イマダテグンイケダチョウ', '大本', 'オオモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県今立郡池田町籠掛', '18', '18382', '9102553', '福井県', 'フクイケン', '今立郡池田町', 'イマダテグンイケダチョウ', '籠掛', 'カゴカケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県今立郡池田町金見谷', '18', '18382', '9102554', '福井県', 'フクイケン', '今立郡池田町', 'イマダテグンイケダチョウ', '金見谷', 'カナミダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県今立郡池田町千代谷', '18', '18382', '9102555', '福井県', 'フクイケン', '今立郡池田町', 'イマダテグンイケダチョウ', '千代谷', 'チヨダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県今立郡池田町白粟', '18', '18382', '9102556', '福井県', 'フクイケン', '今立郡池田町', 'イマダテグンイケダチョウ', '白粟', 'シラワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県今立郡池田町松ケ谷', '18', '18382', '9102556', '福井県', 'フクイケン', '今立郡池田町', 'イマダテグンイケダチョウ', '松ケ谷', 'マツガタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県今立郡池田町小畑', '18', '18382', '9102557', '福井県', 'フクイケン', '今立郡池田町', 'イマダテグンイケダチョウ', '小畑', 'オバタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市昭和新町', '18', '18201', '9103101', '福井県', 'フクイケン', '福井市', 'フクイシ', '昭和新町', 'ショウワシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市小尉町', '18', '18201', '9103102', '福井県', 'フクイケン', '福井市', 'フクイシ', '小尉町', 'コジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市三宅町', '18', '18201', '9103103', '福井県', 'フクイケン', '福井市', 'フクイシ', '三宅町', 'ミヤケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市布施田町', '18', '18201', '9103104', '福井県', 'フクイケン', '福井市', 'フクイシ', '布施田町', 'フセダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市西中野町', '18', '18201', '9103105', '福井県', 'フクイケン', '福井市', 'フクイシ', '西中野町', 'ニシナカノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市池尻町', '18', '18201', '9103106', '福井県', 'フクイケン', '福井市', 'フクイシ', '池尻町', 'イケノシリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市黒丸城町', '18', '18201', '9103107', '福井県', 'フクイケン', '福井市', 'フクイシ', '黒丸城町', 'クロマルジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市島山梨子町', '18', '18201', '9103111', '福井県', 'フクイケン', '福井市', 'フクイシ', '島山梨子町', 'シマヤマナシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市御所垣内町', '18', '18201', '9103112', '福井県', 'フクイケン', '福井市', 'フクイシ', '御所垣内町', 'ゴショガイチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市江上町', '18', '18201', '9103113', '福井県', 'フクイケン', '福井市', 'フクイシ', '江上町', 'エガミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市剣大谷町', '18', '18201', '9103114', '福井県', 'フクイケン', '福井市', 'フクイシ', '剣大谷町', 'ツルギオオタニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市仙町', '18', '18201', '9103115', '福井県', 'フクイケン', '福井市', 'フクイシ', '仙町', 'センチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市内山梨子町', '18', '18201', '9103116', '福井県', 'フクイケン', '福井市', 'フクイシ', '内山梨子町', 'ウチヤマナシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市浄土寺町', '18', '18201', '9103117', '福井県', 'フクイケン', '福井市', 'フクイシ', '浄土寺町', 'ジョウドジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市上野町', '18', '18201', '9103118', '福井県', 'フクイケン', '福井市', 'フクイシ', '上野町', 'ウエノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市佐野町', '18', '18201', '9103121', '福井県', 'フクイケン', '福井市', 'フクイシ', '佐野町', 'サノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市小野町', '18', '18201', '9103122', '福井県', 'フクイケン', '福井市', 'フクイシ', '小野町', 'コノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市石畠町', '18', '18201', '9103123', '福井県', 'フクイケン', '福井市', 'フクイシ', '石畠町', 'イシバタケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市田ノ頭町', '18', '18201', '9103124', '福井県', 'フクイケン', '福井市', 'フクイシ', '田ノ頭町', 'タノカシラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市市ノ瀬町', '18', '18201', '9103125', '福井県', 'フクイケン', '福井市', 'フクイシ', '市ノ瀬町', 'イチノセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市深坂町', '18', '18201', '9103126', '福井県', 'フクイケン', '福井市', 'フクイシ', '深坂町', 'フカサカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市中山町', '18', '18201', '9103127', '福井県', 'フクイケン', '福井市', 'フクイシ', '中山町', 'ナカヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市為寄町', '18', '18201', '9103128', '福井県', 'フクイケン', '福井市', 'フクイシ', '為寄町', 'タメヨリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市白方町', '18', '18201', '9103131', '福井県', 'フクイケン', '福井市', 'フクイシ', '白方町', 'シラカタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市浜島町', '18', '18201', '9103132', '福井県', 'フクイケン', '福井市', 'フクイシ', '浜島町', 'ハマシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市石新保町', '18', '18201', '9103133', '福井県', 'フクイケン', '福井市', 'フクイシ', '石新保町', 'イシシンボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市浜別所町', '18', '18201', '9103134', '福井県', 'フクイケン', '福井市', 'フクイシ', '浜別所町', 'ハマベッショチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市両橋屋町', '18', '18201', '9103135', '福井県', 'フクイケン', '福井市', 'フクイシ', '両橋屋町', 'リョウハシヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市川尻町', '18', '18201', '9103136', '福井県', 'フクイケン', '福井市', 'フクイシ', '川尻町', 'カワシリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市石橋町', '18', '18201', '9103137', '福井県', 'フクイケン', '福井市', 'フクイシ', '石橋町', 'イシバシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市テクノポート', '18', '18201', '9103138', '福井県', 'フクイケン', '福井市', 'フクイシ', 'テクノポート', 'テクノポート', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市砂子田町', '18', '18201', '9103141', '福井県', 'フクイケン', '福井市', 'フクイシ', '砂子田町', 'スナゴダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市波寄町', '18', '18201', '9103142', '福井県', 'フクイケン', '福井市', 'フクイシ', '波寄町', 'ナミヨセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市砂子坂町', '18', '18201', '9103143', '福井県', 'フクイケン', '福井市', 'フクイシ', '砂子坂町', 'スナゴサカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市水切町', '18', '18201', '9103144', '福井県', 'フクイケン', '福井市', 'フクイシ', '水切町', 'ミズキリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市串野町', '18', '18201', '9103145', '福井県', 'フクイケン', '福井市', 'フクイシ', '串野町', 'クシノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市小幡町', '18', '18201', '9103146', '福井県', 'フクイケン', '福井市', 'フクイシ', '小幡町', 'コワタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市木下町', '18', '18201', '9103147', '福井県', 'フクイケン', '福井市', 'フクイシ', '木下町', 'キノシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市菖蒲谷町', '18', '18201', '9103148', '福井県', 'フクイケン', '福井市', 'フクイシ', '菖蒲谷町', 'ショウブダニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市荒谷町', '18', '18201', '9103251', '福井県', 'フクイケン', '福井市', 'フクイシ', '荒谷町', 'アラタニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市燈豊町', '18', '18201', '9103252', '福井県', 'フクイケン', '福井市', 'フクイシ', '燈豊町', 'トウブチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市大谷町', '18', '18201', '9103253', '福井県', 'フクイケン', '福井市', 'フクイシ', '大谷町', 'オオタニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市八幡町', '18', '18201', '9103254', '福井県', 'フクイケン', '福井市', 'フクイシ', '八幡町', 'ヤワタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市大年町', '18', '18201', '9103255', '福井県', 'フクイケン', '福井市', 'フクイシ', '大年町', 'オオトシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市中町', '18', '18201', '9103256', '福井県', 'フクイケン', '福井市', 'フクイシ', '中町', 'ナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市西荒井町', '18', '18201', '9103261', '福井県', 'フクイケン', '福井市', 'フクイシ', '西荒井町', 'ニシアライチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市一王寺町', '18', '18201', '9103262', '福井県', 'フクイケン', '福井市', 'フクイシ', '一王寺町', 'イチオウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市中河内町', '18', '18201', '9103263', '福井県', 'フクイケン', '福井市', 'フクイシ', '中河内町', 'ナカコウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市木米町', '18', '18201', '9103264', '福井県', 'フクイケン', '福井市', 'フクイシ', '木米町', 'キヨネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市柿谷町', '18', '18201', '9103265', '福井県', 'フクイケン', '福井市', 'フクイシ', '柿谷町', 'カキダニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市足谷町', '18', '18201', '9103266', '福井県', 'フクイケン', '福井市', 'フクイシ', '足谷町', 'アシタニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市猫瀬町', '18', '18201', '9103266', '福井県', 'フクイケン', '福井市', 'フクイシ', '猫瀬町', 'ネコセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市東平町', '18', '18201', '9103266', '福井県', 'フクイケン', '福井市', 'フクイシ', '東平町', 'ヒガシダイラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市河内町', '18', '18201', '9103267', '福井県', 'フクイケン', '福井市', 'フクイシ', '河内町', 'コウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市奥平町', '18', '18201', '9103268', '福井県', 'フクイケン', '福井市', 'フクイシ', '奥平町', 'オクダイラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市清水平町', '18', '18201', '9103268', '福井県', 'フクイケン', '福井市', 'フクイシ', '清水平町', 'シミズダイラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市中平町', '18', '18201', '9103268', '福井県', 'フクイケン', '福井市', 'フクイシ', '中平町', 'ナカダイラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市大窪町', '18', '18201', '9103371', '福井県', 'フクイケン', '福井市', 'フクイシ', '大窪町', 'オオクボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市西二ツ屋町', '18', '18201', '9103372', '福井県', 'フクイケン', '福井市', 'フクイシ', '西二ツ屋町', 'ニシフタツヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市西畑町', '18', '18201', '9103373', '福井県', 'フクイケン', '福井市', 'フクイシ', '西畑町', 'ニシハタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市高須町', '18', '18201', '9103374', '福井県', 'フクイケン', '福井市', 'フクイシ', '高須町', 'タカスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市宮郷町', '18', '18201', '9103375', '福井県', 'フクイケン', '福井市', 'フクイシ', '宮郷町', 'ミヤゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市和布町', '18', '18201', '9103376', '福井県', 'フクイケン', '福井市', 'フクイシ', '和布町', 'メラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市浜住町', '18', '18201', '9103377', '福井県', 'フクイケン', '福井市', 'フクイシ', '浜住町', 'ハマジュウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市免鳥町', '18', '18201', '9103378', '福井県', 'フクイケン', '福井市', 'フクイシ', '免鳥町', 'メンドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市蓑町', '18', '18201', '9103381', '福井県', 'フクイケン', '福井市', 'フクイシ', '蓑町', 'ミノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市松蔭町', '18', '18201', '9103382', '福井県', 'フクイケン', '福井市', 'フクイシ', '松蔭町', 'マツカゲチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市糸崎町', '18', '18201', '9103383', '福井県', 'フクイケン', '福井市', 'フクイシ', '糸崎町', 'イトサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市長橋町', '18', '18201', '9103384', '福井県', 'フクイケン', '福井市', 'フクイシ', '長橋町', 'ナガハシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市北菅生町', '18', '18201', '9103385', '福井県', 'フクイケン', '福井市', 'フクイシ', '北菅生町', 'キタスゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市南菅生町', '18', '18201', '9103386', '福井県', 'フクイケン', '福井市', 'フクイシ', '南菅生町', 'ミナミスゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市国見町', '18', '18201', '9103401', '福井県', 'フクイケン', '福井市', 'フクイシ', '国見町', 'クニミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市鮎川町', '18', '18201', '9103402', '福井県', 'フクイケン', '福井市', 'フクイシ', '鮎川町', 'アユカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市白浜町', '18', '18201', '9103403', '福井県', 'フクイケン', '福井市', 'フクイシ', '白浜町', 'シラハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市大丹生町', '18', '18201', '9103404', '福井県', 'フクイケン', '福井市', 'フクイシ', '大丹生町', 'オニュウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市小丹生町', '18', '18201', '9103405', '福井県', 'フクイケン', '福井市', 'フクイシ', '小丹生町', 'コニュウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市白滝町', '18', '18201', '9103511', '福井県', 'フクイケン', '福井市', 'フクイシ', '白滝町', 'シラタキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市西別所町', '18', '18201', '9103512', '福井県', 'フクイケン', '福井市', 'フクイシ', '西別所町', 'ニシベッショチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市宿堂町', '18', '18201', '9103513', '福井県', 'フクイケン', '福井市', 'フクイシ', '宿堂町', 'シュクドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市水谷町', '18', '18201', '9103514', '福井県', 'フクイケン', '福井市', 'フクイシ', '水谷町', 'ミズタニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市大矢町', '18', '18201', '9103515', '福井県', 'フクイケン', '福井市', 'フクイシ', '大矢町', 'オオヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市風尾町', '18', '18201', '9103516', '福井県', 'フクイケン', '福井市', 'フクイシ', '風尾町', 'カザオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市畠中町', '18', '18201', '9103517', '福井県', 'フクイケン', '福井市', 'フクイシ', '畠中町', 'ハタケナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市国山町', '18', '18201', '9103518', '福井県', 'フクイケン', '福井市', 'フクイシ', '国山町', 'クニヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市千合町', '18', '18201', '9103521', '福井県', 'フクイケン', '福井市', 'フクイシ', '千合町', 'チゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市謡谷町', '18', '18201', '9103522', '福井県', 'フクイケン', '福井市', 'フクイシ', '謡谷町', 'ウタイダニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市武周町', '18', '18201', '9103523', '福井県', 'フクイケン', '福井市', 'フクイシ', '武周町', 'ブシュウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市別畑町', '18', '18201', '9103524', '福井県', 'フクイケン', '福井市', 'フクイシ', '別畑町', 'ベツバタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市尼ケ谷町', '18', '18201', '9103525', '福井県', 'フクイケン', '福井市', 'フクイシ', '尼ケ谷町', 'アマガタニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市二ツ屋町', '18', '18201', '9103526', '福井県', 'フクイケン', '福井市', 'フクイシ', '二ツ屋町', 'フタツヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市大味町', '18', '18201', '9103551', '福井県', 'フクイケン', '福井市', 'フクイシ', '大味町', 'オオミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市茱崎町', '18', '18201', '9103552', '福井県', 'フクイケン', '福井市', 'フクイシ', '茱崎町', 'グミザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市蒲生町', '18', '18201', '9103553', '福井県', 'フクイケン', '福井市', 'フクイシ', '蒲生町', 'ガモウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市浜北山町', '18', '18201', '9103554', '福井県', 'フクイケン', '福井市', 'フクイシ', '浜北山町', 'ハマキタヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市居倉町', '18', '18201', '9103555', '福井県', 'フクイケン', '福井市', 'フクイシ', '居倉町', 'イクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市赤坂町', '18', '18201', '9103556', '福井県', 'フクイケン', '福井市', 'フクイシ', '赤坂町', 'アカサカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市城有町', '18', '18201', '9103557', '福井県', 'フクイケン', '福井市', 'フクイシ', '城有町', 'シロアリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市八ツ俣町', '18', '18201', '9103558', '福井県', 'フクイケン', '福井市', 'フクイシ', '八ツ俣町', 'ヤツマタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市清水町', '18', '18201', '9103601', '福井県', 'フクイケン', '福井市', 'フクイシ', '清水町', 'シミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市竹生町', '18', '18201', '9103602', '福井県', 'フクイケン', '福井市', 'フクイシ', '竹生町', 'タコオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市片粕町', '18', '18201', '9103603', '福井県', 'フクイケン', '福井市', 'フクイシ', '片粕町', 'カタカスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市グリーンハイツ', '18', '18201', '9103604', '福井県', 'フクイケン', '福井市', 'フクイシ', 'グリーンハイツ', 'グリーンハイツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市朝宮町', '18', '18201', '9103605', '福井県', 'フクイケン', '福井市', 'フクイシ', '朝宮町', 'アサミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市田尻栃谷町', '18', '18201', '9103606', '福井県', 'フクイケン', '福井市', 'フクイシ', '田尻栃谷町', 'タジリトチタニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市清水杉谷町', '18', '18201', '9103607', '福井県', 'フクイケン', '福井市', 'フクイシ', '清水杉谷町', 'シミズスギタニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市三留町', '18', '18201', '9103608', '福井県', 'フクイケン', '福井市', 'フクイシ', '三留町', 'ミトメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市片山町', '18', '18201', '9103611', '福井県', 'フクイケン', '福井市', 'フクイシ', '片山町', 'カタヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市清水山町', '18', '18201', '9103612', '福井県', 'フクイケン', '福井市', 'フクイシ', '清水山町', 'シミズヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市甑谷町', '18', '18201', '9103613', '福井県', 'フクイケン', '福井市', 'フクイシ', '甑谷町', 'コシキダニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市在田町', '18', '18201', '9103614', '福井県', 'フクイケン', '福井市', 'フクイシ', '在田町', 'アイダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市坪谷町', '18', '18201', '9103615', '福井県', 'フクイケン', '福井市', 'フクイシ', '坪谷町', 'ツボタニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市真栗町', '18', '18201', '9103616', '福井県', 'フクイケン', '福井市', 'フクイシ', '真栗町', 'マクリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市御油町', '18', '18201', '9103617', '福井県', 'フクイケン', '福井市', 'フクイシ', '御油町', 'ゴユチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市小羽町', '18', '18201', '9103621', '福井県', 'フクイケン', '福井市', 'フクイシ', '小羽町', 'オバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市風巻町', '18', '18201', '9103622', '福井県', 'フクイケン', '福井市', 'フクイシ', '風巻町', 'カザマキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市島寺町', '18', '18201', '9103623', '福井県', 'フクイケン', '福井市', 'フクイシ', '島寺町', 'シマデラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市和田町', '18', '18201', '9103631', '福井県', 'フクイケン', '福井市', 'フクイシ', '和田町', 'ワダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市下天下町', '18', '18201', '9103632', '福井県', 'フクイケン', '福井市', 'フクイシ', '下天下町', 'シモテガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市上天下町', '18', '18201', '9103633', '福井県', 'フクイケン', '福井市', 'フクイシ', '上天下町', 'カミテガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市大森町', '18', '18201', '9103634', '福井県', 'フクイケン', '福井市', 'フクイシ', '大森町', 'オオモリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市志津が丘', '18', '18201', '9103635', '福井県', 'フクイケン', '福井市', 'フクイシ', '志津が丘', 'シヅガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市山内町', '18', '18201', '9103636', '福井県', 'フクイケン', '福井市', 'フクイシ', '山内町', 'ヤマウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市平尾町', '18', '18201', '9103641', '福井県', 'フクイケン', '福井市', 'フクイシ', '平尾町', 'ヒラオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市本折町', '18', '18201', '9103642', '福井県', 'フクイケン', '福井市', 'フクイシ', '本折町', 'モトオリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市滝波町', '18', '18201', '9103643', '福井県', 'フクイケン', '福井市', 'フクイシ', '滝波町', 'タキナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市加茂内町', '18', '18201', '9103644', '福井県', 'フクイケン', '福井市', 'フクイシ', '加茂内町', 'カモウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市加茂町', '18', '18201', '9103644', '福井県', 'フクイケン', '福井市', 'フクイシ', '加茂町', 'カモチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市笹谷町', '18', '18201', '9103645', '福井県', 'フクイケン', '福井市', 'フクイシ', '笹谷町', 'ササダニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市清水畑町', '18', '18201', '9103646', '福井県', 'フクイケン', '福井市', 'フクイシ', '清水畑町', 'シミズバタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県あわら市芦鶴', '18', '18208', '9104102', '福井県', 'フクイケン', 'あわら市', 'アワラシ', '芦鶴', 'アシヅル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県あわら市二面', '18', '18208', '9104103', '福井県', 'フクイケン', 'あわら市', 'アワラシ', '二面', 'フタオモテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県あわら市温泉', '18', '18208', '9104104', '福井県', 'フクイケン', 'あわら市', 'アワラシ', '温泉', 'オンセン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県あわら市舟津', '18', '18208', '9104105', '福井県', 'フクイケン', 'あわら市', 'アワラシ', '舟津', 'フナツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県あわら市牛山', '18', '18208', '9104111', '福井県', 'フクイケン', 'あわら市', 'アワラシ', '牛山', 'ウシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県あわら市井江葭', '18', '18208', '9104112', '福井県', 'フクイケン', 'あわら市', 'アワラシ', '井江葭', 'イエヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県あわら市横垣', '18', '18208', '9104113', '福井県', 'フクイケン', 'あわら市', 'アワラシ', '横垣', 'ヨコガキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県あわら市国影', '18', '18208', '9104115', '福井県', 'フクイケン', 'あわら市', 'アワラシ', '国影', 'クニカゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県あわら市東温泉', '18', '18208', '9104121', '福井県', 'フクイケン', 'あわら市', 'アワラシ', '東温泉', 'ヒガシオンセン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県あわら市重義', '18', '18208', '9104122', '福井県', 'フクイケン', 'あわら市', 'アワラシ', '重義', 'シゲヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県あわら市番田', '18', '18208', '9104123', '福井県', 'フクイケン', 'あわら市', 'アワラシ', '番田', 'バンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県あわら市田中々', '18', '18208', '9104124', '福井県', 'フクイケン', 'あわら市', 'アワラシ', '田中々', 'タナカナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県あわら市堀江十楽', '18', '18208', '9104125', '福井県', 'フクイケン', 'あわら市', 'アワラシ', '堀江十楽', 'ホリエジュウラク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県あわら市布目', '18', '18208', '9104126', '福井県', 'フクイケン', 'あわら市', 'アワラシ', '布目', 'ヌノメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県あわら市西温泉', '18', '18208', '9104127', '福井県', 'フクイケン', 'あわら市', 'アワラシ', '西温泉', 'ニシオンセン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県あわら市東善寺', '18', '18208', '9104131', '福井県', 'フクイケン', 'あわら市', 'アワラシ', '東善寺', 'トウゼンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県あわら市谷畠', '18', '18208', '9104132', '福井県', 'フクイケン', 'あわら市', 'アワラシ', '谷畠', 'タンバク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県あわら市轟木', '18', '18208', '9104133', '福井県', 'フクイケン', 'あわら市', 'アワラシ', '轟木', 'トドロキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県あわら市上番', '18', '18208', '9104134', '福井県', 'フクイケン', 'あわら市', 'アワラシ', '上番', 'カミバン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県あわら市中番', '18', '18208', '9104137', '福井県', 'フクイケン', 'あわら市', 'アワラシ', '中番', 'ナカバン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県あわら市下番', '18', '18208', '9104138', '福井県', 'フクイケン', 'あわら市', 'アワラシ', '下番', 'シモバン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県あわら市玉木', '18', '18208', '9104141', '福井県', 'フクイケン', 'あわら市', 'アワラシ', '玉木', 'タマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県あわら市河間', '18', '18208', '9104142', '福井県', 'フクイケン', 'あわら市', 'アワラシ', '河間', 'コウマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県あわら市中浜', '18', '18208', '9104144', '福井県', 'フクイケン', 'あわら市', 'アワラシ', '中浜', 'ナカノハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県あわら市角屋', '18', '18208', '9104145', '福井県', 'フクイケン', 'あわら市', 'アワラシ', '角屋', 'スミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県あわら市北本堂', '18', '18208', '9104146', '福井県', 'フクイケン', 'あわら市', 'アワラシ', '北本堂', 'キタホンドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県あわら市公文', '18', '18208', '9104147', '福井県', 'フクイケン', 'あわら市', 'アワラシ', '公文', 'クモン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県あわら市宮前', '18', '18208', '9104147', '福井県', 'フクイケン', 'あわら市', 'アワラシ', '宮前', 'ミヤマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県あわら市浜坂', '18', '18208', '9104271', '福井県', 'フクイケン', 'あわら市', 'アワラシ', '浜坂', 'ハマサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県あわら市北潟', '18', '18208', '9104272', '福井県', 'フクイケン', 'あわら市', 'アワラシ', '北潟', 'キタガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県あわら市富津北潟', '18', '18208', '9104272', '福井県', 'フクイケン', 'あわら市', 'アワラシ', '富津', 'トミツ', null, null, '北潟', 'キタガタ');
INSERT INTO `ms_addresses` VALUES ('120628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県あわら市赤尾', '18', '18208', '9104273', '福井県', 'フクイケン', 'あわら市', 'アワラシ', '赤尾', 'アカオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県あわら市番堂野', '18', '18208', '9104274', '福井県', 'フクイケン', 'あわら市', 'アワラシ', '番堂野', 'バンドノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県あわら市城新田', '18', '18208', '9104275', '福井県', 'フクイケン', 'あわら市', 'アワラシ', '城新田', 'ジョウシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県あわら市十三城', '18', '18208', '9104276', '福井県', 'フクイケン', 'あわら市', 'アワラシ', '十三', 'ジュウソウ', null, null, '城', 'ジョウ');
INSERT INTO `ms_addresses` VALUES ('120632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県あわら市城', '18', '18208', '9104276', '福井県', 'フクイケン', 'あわら市', 'アワラシ', '城', 'ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県あわら市波松', '18', '18208', '9104277', '福井県', 'フクイケン', 'あわら市', 'アワラシ', '波松', 'ナミマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道常呂郡佐呂間町大成', '01', '01552', '0910471', '北海道', 'ホッカイドウ', '常呂郡佐呂間町', 'トコログンサロマチョウ', '大成', 'タイセイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道常呂郡佐呂間町栄', '01', '01552', '0910472', '北海道', 'ホッカイドウ', '常呂郡佐呂間町', 'トコログンサロマチョウ', '栄', 'サカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道常呂郡佐呂間町共立', '01', '01552', '0910473', '北海道', 'ホッカイドウ', '常呂郡佐呂間町', 'トコログンサロマチョウ', '共立', 'キョウリツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道常呂郡佐呂間町若佐', '01', '01552', '0910551', '北海道', 'ホッカイドウ', '常呂郡佐呂間町', 'トコログンサロマチョウ', '若佐', 'ワカサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道常呂郡佐呂間町富丘', '01', '01552', '0910552', '北海道', 'ホッカイドウ', '常呂郡佐呂間町', 'トコログンサロマチョウ', '富丘', 'トミオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道常呂郡佐呂間町朝日', '01', '01552', '0910553', '北海道', 'ホッカイドウ', '常呂郡佐呂間町', 'トコログンサロマチョウ', '朝日', 'アサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道常呂郡佐呂間町武士', '01', '01552', '0910554', '北海道', 'ホッカイドウ', '常呂郡佐呂間町', 'トコログンサロマチョウ', '武士', 'ブシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道常呂郡佐呂間町中園', '01', '01552', '0910555', '北海道', 'ホッカイドウ', '常呂郡佐呂間町', 'トコログンサロマチョウ', '中園', 'ナカゾノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道常呂郡佐呂間町啓生', '01', '01552', '0910556', '北海道', 'ホッカイドウ', '常呂郡佐呂間町', 'トコログンサロマチョウ', '啓生', 'ケイセイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道常呂郡佐呂間町川西', '01', '01552', '0910557', '北海道', 'ホッカイドウ', '常呂郡佐呂間町', 'トコログンサロマチョウ', '川西', 'カワニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道常呂郡佐呂間町栃木', '01', '01552', '0910558', '北海道', 'ホッカイドウ', '常呂郡佐呂間町', 'トコログンサロマチョウ', '栃木', 'トチギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市', '18', '18206', '9110000', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('120737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市北谷町小原', '18', '18206', '9110001', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '北谷町小原', 'キタダニチョウオハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市北谷町木根橋', '18', '18206', '9110002', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '北谷町木根橋', 'キタダニチョウキネハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市北谷町河合', '18', '18206', '9110003', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '北谷町河合', 'キタダニチョウコウゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市北谷町北六呂師', '18', '18206', '9110004', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '北谷町北六呂師', 'キタダニチョウキタロクロシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市北谷町中尾', '18', '18206', '9110004', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '北谷町中尾', 'キタダニチョウナカオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市北谷町杉山', '18', '18206', '9110005', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '北谷町杉山', 'キタダニチョウスギヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市北谷町谷', '18', '18206', '9110006', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '北谷町谷', 'キタダニチョウタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市野向町牛ケ谷', '18', '18206', '9110011', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '野向町牛ケ谷', 'ノムキチョウウシガタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市野向町薬師神谷', '18', '18206', '9110012', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '野向町薬師神谷', 'ノムキチョウヤクシガミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市野向町深谷', '18', '18206', '9110013', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '野向町深谷', 'ノムキチョウフカダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市野向町聖丸', '18', '18206', '9110014', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '野向町聖丸', 'ノムキチョウヒジリマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市野向町竹林', '18', '18206', '9110015', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '野向町竹林', 'ノムキチョウタケバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市野向町竜谷', '18', '18206', '9110016', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '野向町竜谷', 'ノムキチョウリュウダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市野向町北野津又', '18', '18206', '9110017', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '野向町北野津又', 'ノムキチョウキタノツマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市野向町横倉', '18', '18206', '9110017', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '野向町横倉', 'ノムキチョウヨコクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市村岡町栃神谷', '18', '18206', '9110021', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '村岡町栃神谷', 'ムロコチョウトチガミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市村岡町暮見', '18', '18206', '9110022', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '村岡町暮見', 'ムロコチョウクレミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市芳野ケ原', '18', '18206', '9110022', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '芳野ケ原', 'ヨシノガハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市村岡町寺尾', '18', '18206', '9110023', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '村岡町寺尾', 'ムロコチョウテラオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市村岡町浄土寺', '18', '18206', '9110024', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '村岡町浄土寺', 'ムロコチョウジョウドジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市村岡町五本寺', '18', '18206', '9110025', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '村岡町五本寺', 'ムロコチョウゴホンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市村岡町黒原', '18', '18206', '9110026', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '村岡町黒原', 'ムロコチョウクロハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市長山町', '18', '18206', '9110031', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '長山町', 'ナガヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市芳野町', '18', '18206', '9110032', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '芳野町', 'ヨシノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市栄町', '18', '18206', '9110033', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市滝波町', '18', '18206', '9110034', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '滝波町', 'タキナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市郡町', '18', '18206', '9110035', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '郡町', 'コオリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市荒土町北新在家', '18', '18206', '9110041', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '荒土町北新在家', 'アラドチョウキタシンザイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市荒土町清水島', '18', '18206', '9110041', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '荒土町清水島', 'アラドチョウシミズシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市荒土町布市', '18', '18206', '9110041', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '荒土町布市', 'アラドチョウヌノイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市荒土町田名部', '18', '18206', '9110042', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '荒土町田名部', 'アラドチョウタナベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市荒土町松田', '18', '18206', '9110042', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '荒土町松田', 'アラドチョウマツタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市荒土町新保', '18', '18206', '9110043', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '荒土町新保', 'アラドチョウシンボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市荒土町松ケ崎', '18', '18206', '9110044', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '荒土町松ケ崎', 'アラドチョウマツガサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市荒土町伊波', '18', '18206', '9110045', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '荒土町伊波', 'アラドチョウイナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市荒土町妙金島', '18', '18206', '9110045', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '荒土町妙金島', 'アラドチョウミョウキンジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市荒土町中清水', '18', '18206', '9110046', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '荒土町中清水', 'アラドチョウナカシミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市荒土町堀名', '18', '18206', '9110046', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '荒土町堀名', 'アラドチョウホリメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市荒土町堀名中清水', '18', '18206', '9110046', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '荒土町堀名中清水', 'アラドチョウホリメナカシミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市荒土町北宮地', '18', '18206', '9110047', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '荒土町北宮地', 'アラドチョウキタミヤジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市荒土町境', '18', '18206', '9110048', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '荒土町境', 'アラドチョウサカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市荒土町新道', '18', '18206', '9110048', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '荒土町新道', 'アラドチョウシンドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市荒土町戸倉', '18', '18206', '9110048', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '荒土町戸倉', 'アラドチョウトクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市荒土町西ケ原', '18', '18206', '9110048', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '荒土町西ケ原', 'アラドチョウニシガハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市荒土町別所', '18', '18206', '9110048', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '荒土町別所', 'アラドチョウベッショ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市荒土町細野', '18', '18206', '9110048', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '荒土町細野', 'アラドチョウホソノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市荒土町細野口', '18', '18206', '9110048', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '荒土町細野口', 'アラドチョウホソノグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市北郷町新町', '18', '18206', '9110051', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '北郷町新町', 'キタゴウチョウアラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市北郷町志比原', '18', '18206', '9110051', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '北郷町志比原', 'キタゴウチョウシイワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市北郷町檜曽谷', '18', '18206', '9110051', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '北郷町檜曽谷', 'キタゴウチョウヒソダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市北郷町西妙金島', '18', '18206', '9110052', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '北郷町西妙金島', 'キタゴウチョウニシミョウキンジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市北郷町上森川', '18', '18206', '9110053', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '北郷町上森川', 'キタゴウチョウカミモリカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市北郷町下森川', '18', '18206', '9110053', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '北郷町下森川', 'キタゴウチョウシモモリカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市北郷町森川', '18', '18206', '9110053', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '北郷町森川', 'キタゴウチョウモリカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市北郷町東野', '18', '18206', '9110054', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '北郷町東野', 'キタゴウチョウヒガシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市北郷町伊知地', '18', '18206', '9110055', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '北郷町伊知地', 'キタゴウチョウイジチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市北郷町岩屋', '18', '18206', '9110055', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '北郷町岩屋', 'キタゴウチョウイワヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市北郷町上野', '18', '18206', '9110055', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '北郷町上野', 'キタゴウチョウウワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市北郷町坂東島', '18', '18206', '9110056', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '北郷町坂東島', 'キタゴウチョウバンドウジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市沢町', '18', '18206', '9110801', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '沢町', 'サワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市昭和町', '18', '18206', '9110802', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '昭和町', 'ショウワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市旭町', '18', '18206', '9110803', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '旭町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市元町', '18', '18206', '9110804', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '元町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市立川町', '18', '18206', '9110805', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '立川町', 'タテカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市本町', '18', '18206', '9110806', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市片瀬', '18', '18206', '9110811', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '片瀬', 'カタセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市片瀬町', '18', '18206', '9110811', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '片瀬町', 'カタセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市猪野', '18', '18206', '9110812', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '猪野', 'イノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市猪野口', '18', '18206', '9110813', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '猪野口', 'イノクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市若猪野', '18', '18206', '9110814', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '若猪野', 'ワカイノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市上高島', '18', '18206', '9110815', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '上高島', 'カミタカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市北市', '18', '18206', '9110815', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '北市', 'キタイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市下高島', '18', '18206', '9110815', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '下高島', 'シモタカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市高島', '18', '18206', '9110815', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '高島', 'タカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市西高島', '18', '18206', '9110815', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '西高島', 'ニシタカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市猪野毛屋', '18', '18206', '9110816', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '猪野毛屋', 'イノケヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市毛屋', '18', '18206', '9110816', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '毛屋', 'ケヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市毛屋町', '18', '18206', '9110816', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '毛屋町', 'ケヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市下毛屋', '18', '18206', '9110816', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '下毛屋', 'シモケヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市旭毛屋町', '18', '18206', '9110817', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '旭毛屋町', 'アサヒケヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市平泉寺町岡横江', '18', '18206', '9110821', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '平泉寺町岡横江', 'ヘイセンジチョウオカヨコエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市平泉寺町神野', '18', '18206', '9110822', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '平泉寺町神野', 'ヘイセンジチョウシンノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市平泉寺町平泉寺', '18', '18206', '9110822', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '平泉寺町平泉寺', 'ヘイセンジチョウヘイセンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市平泉寺町赤尾', '18', '18206', '9110823', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '平泉寺町赤尾', 'ヘイセンジチョウアカオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市平泉寺町池ケ原', '18', '18206', '9110824', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '平泉寺町池ケ原', 'ヘイセンジチョウイケガハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市平泉寺町大矢谷', '18', '18206', '9110824', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '平泉寺町大矢谷', 'ヘイセンジチョウオオヤダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市平泉寺町小矢谷', '18', '18206', '9110824', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '平泉寺町小矢谷', 'ヘイセンジチョウコヤダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市平泉寺町岩ケ野', '18', '18206', '9110825', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '平泉寺町岩ケ野', 'ヘイセンジチョウイワガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市平泉寺町上野', '18', '18206', '9110825', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '平泉寺町上野', 'ヘイセンジチョウウエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市平泉寺町壁倉', '18', '18206', '9110826', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '平泉寺町壁倉', 'ヘイセンジチョウカベクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市平泉寺町笹尾', '18', '18206', '9110827', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '平泉寺町笹尾', 'ヘイセンジチョウササオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市平泉寺町大渡', '18', '18206', '9110828', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '平泉寺町大渡', 'ヘイセンジチョウオオワタリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市平泉寺町経塚', '18', '18206', '9110828', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '平泉寺町経塚', 'ヘイセンジチョウキョウヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市遅羽町千代田', '18', '18206', '9110831', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '遅羽町千代田', 'オソワチョウチヨダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市遅羽町中島', '18', '18206', '9110831', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '遅羽町中島', 'オソワチョウナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市遅羽町比島', '18', '18206', '9110831', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '遅羽町比島', 'オソワチョウヒシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市遅羽町蓬生', '18', '18206', '9110832', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '遅羽町蓬生', 'オソワチョウヨモギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市遅羽町北山', '18', '18206', '9110833', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '遅羽町北山', 'オソワチョウキタヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市遅羽町大袋', '18', '18206', '9110834', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '遅羽町大袋', 'オソワチョウオオブクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市遅羽町新道', '18', '18206', '9110834', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '遅羽町新道', 'オソワチョウシンドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市遅羽町ほう崎', '18', '18206', '9110835', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '遅羽町ほう崎', 'オソワチョウホウキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市遅羽町下荒井', '18', '18206', '9110836', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '遅羽町下荒井', 'オソワチョウシモアライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市鹿谷町発坂', '18', '18206', '9110841', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '鹿谷町発坂', 'シカダニチョウホッサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市鹿谷町志田', '18', '18206', '9110842', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '鹿谷町志田', 'シカダニチョウシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市鹿谷町杉俣', '18', '18206', '9110843', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '鹿谷町杉俣', 'シカダニチョウスギマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市鹿谷町本郷', '18', '18206', '9110843', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '鹿谷町本郷', 'シカダニチョウホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市鹿谷町西遅羽口', '18', '18206', '9110844', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '鹿谷町西遅羽口', 'シカダニチョウニシオソワグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市鹿谷町東遅羽口', '18', '18206', '9110844', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '鹿谷町東遅羽口', 'シカダニチョウヒガシオソワグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市鹿谷町矢戸口', '18', '18206', '9110845', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '鹿谷町矢戸口', 'シカダニチョウヤトグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市鹿谷町北西俣', '18', '18206', '9110846', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '鹿谷町北西俣', 'シカダニチョウキタニシマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市鹿谷町西光寺', '18', '18206', '9110847', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '鹿谷町西光寺', 'シカダニチョウサイコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市鹿谷町出村', '18', '18206', '9110848', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '鹿谷町出村', 'シカダニチョウデムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市鹿谷町保田', '18', '18206', '9110848', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '鹿谷町保田', 'シカダニチョウホタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県勝山市鹿谷町保田出村', '18', '18206', '9110848', '福井県', 'フクイケン', '勝山市', 'カツヤマシ', '鹿谷町保田出村', 'シカダニチョウホタデムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市', '18', '18205', '9120000', '福井県', 'フクイケン', '大野市', 'オオノシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('120860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市大矢戸', '18', '18205', '9120001', '福井県', 'フクイケン', '大野市', 'オオノシ', '大矢戸', 'オオヤト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市小矢戸', '18', '18205', '9120002', '福井県', 'フクイケン', '大野市', 'オオノシ', '小矢戸', 'コヤト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市西大月', '18', '18205', '9120003', '福井県', 'フクイケン', '大野市', 'オオノシ', '西大月', 'ニシオオツキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市東大月', '18', '18205', '9120003', '福井県', 'フクイケン', '大野市', 'オオノシ', '東大月', 'ヒガシオオツキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市中津川', '18', '18205', '9120004', '福井県', 'フクイケン', '大野市', 'オオノシ', '中津川', 'ナカツガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市太田', '18', '18205', '9120005', '福井県', 'フクイケン', '大野市', 'オオノシ', '太田', 'オオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市庄林', '18', '18205', '9120006', '福井県', 'フクイケン', '大野市', 'オオノシ', '庄林', 'ショウバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市西市', '18', '18205', '9120007', '福井県', 'フクイケン', '大野市', 'オオノシ', '西市', 'ニシイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市矢', '18', '18205', '9120008', '福井県', 'フクイケン', '大野市', 'オオノシ', '矢', 'ヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市南新在家', '18', '18205', '9120011', '福井県', 'フクイケン', '大野市', 'オオノシ', '南新在家', 'ミナミシンザイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市横枕', '18', '18205', '9120012', '福井県', 'フクイケン', '大野市', 'オオノシ', '横枕', 'ヨコマクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市堂本', '18', '18205', '9120013', '福井県', 'フクイケン', '大野市', 'オオノシ', '堂本', 'ドウモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市中保', '18', '18205', '9120014', '福井県', 'フクイケン', '大野市', 'オオノシ', '中保', 'ナカホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市中挾', '18', '18205', '9120015', '福井県', 'フクイケン', '大野市', 'オオノシ', '中挾', 'ナカバサミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市友江', '18', '18205', '9120016', '福井県', 'フクイケン', '大野市', 'オオノシ', '友江', 'トモエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市東中野', '18', '18205', '9120017', '福井県', 'フクイケン', '大野市', 'オオノシ', '東中野', 'ヒガシナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市中野', '18', '18205', '9120021', '福井県', 'フクイケン', '大野市', 'オオノシ', '中野', 'ナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市中野町', '18', '18205', '9120021', '福井県', 'フクイケン', '大野市', 'オオノシ', '中野町', 'ナカノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市陽明町', '18', '18205', '9120022', '福井県', 'フクイケン', '大野市', 'オオノシ', '陽明町', 'ヨウメイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市中荒井', '18', '18205', '9120023', '福井県', 'フクイケン', '大野市', 'オオノシ', '中荒井', 'ナカアライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市中荒井町', '18', '18205', '9120023', '福井県', 'フクイケン', '大野市', 'オオノシ', '中荒井町', 'ナカアライチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市錦町', '18', '18205', '9120024', '福井県', 'フクイケン', '大野市', 'オオノシ', '錦町', 'ニシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市本町', '18', '18205', '9120025', '福井県', 'フクイケン', '大野市', 'オオノシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市要町', '18', '18205', '9120026', '福井県', 'フクイケン', '大野市', 'オオノシ', '要町', 'カナメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市新町', '18', '18205', '9120027', '福井県', 'フクイケン', '大野市', 'オオノシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市月美町', '18', '18205', '9120031', '福井県', 'フクイケン', '大野市', 'オオノシ', '月美町', 'ツキミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市清和町', '18', '18205', '9120032', '福井県', 'フクイケン', '大野市', 'オオノシ', '清和町', 'セイワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市美里町', '18', '18205', '9120033', '福井県', 'フクイケン', '大野市', 'オオノシ', '美里町', 'ミサトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市吉野町', '18', '18205', '9120034', '福井県', 'フクイケン', '大野市', 'オオノシ', '吉野町', 'ヨシノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市有明町', '18', '18205', '9120035', '福井県', 'フクイケン', '大野市', 'オオノシ', '有明町', 'アリアケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市美川町', '18', '18205', '9120036', '福井県', 'フクイケン', '大野市', 'オオノシ', '美川町', 'ミカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市菖蒲池', '18', '18205', '9120041', '福井県', 'フクイケン', '大野市', 'オオノシ', '菖蒲池', 'ショウブイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市東中', '18', '18205', '9120042', '福井県', 'フクイケン', '大野市', 'オオノシ', '東中', 'ヒガシナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市東中町', '18', '18205', '9120042', '福井県', 'フクイケン', '大野市', 'オオノシ', '東中町', 'ヒガシナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市国時町', '18', '18205', '9120043', '福井県', 'フクイケン', '大野市', 'オオノシ', '国時町', 'クニトキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市桜塚町', '18', '18205', '9120044', '福井県', 'フクイケン', '大野市', 'オオノシ', '桜塚町', 'サクラヅカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市若杉町', '18', '18205', '9120045', '福井県', 'フクイケン', '大野市', 'オオノシ', '若杉町', 'ワカスギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市神明', '18', '18205', '9120046', '福井県', 'フクイケン', '大野市', 'オオノシ', '神明', 'シンメイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市神明町', '18', '18205', '9120046', '福井県', 'フクイケン', '大野市', 'オオノシ', '神明町', 'シンメイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市幸町', '18', '18205', '9120047', '福井県', 'フクイケン', '大野市', 'オオノシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市日吉町', '18', '18205', '9120051', '福井県', 'フクイケン', '大野市', 'オオノシ', '日吉町', 'ヒヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市弥生町', '18', '18205', '9120052', '福井県', 'フクイケン', '大野市', 'オオノシ', '弥生町', 'ヤヨイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市春日', '18', '18205', '9120053', '福井県', 'フクイケン', '大野市', 'オオノシ', '春日', 'カスガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市糸魚町', '18', '18205', '9120054', '福井県', 'フクイケン', '大野市', 'オオノシ', '糸魚町', 'イトヨチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市高砂町', '18', '18205', '9120055', '福井県', 'フクイケン', '大野市', 'オオノシ', '高砂町', 'タカサゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市篠座', '18', '18205', '9120061', '福井県', 'フクイケン', '大野市', 'オオノシ', '篠座', 'シノクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市篠座町', '18', '18205', '9120061', '福井県', 'フクイケン', '大野市', 'オオノシ', '篠座町', 'シノクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市千歳', '18', '18205', '9120062', '福井県', 'フクイケン', '大野市', 'オオノシ', '千歳', 'チトセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市阿難祖地頭方', '18', '18205', '9120063', '福井県', 'フクイケン', '大野市', 'オオノシ', '阿難祖地頭方', 'アドソジトウホウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市阿難祖領家', '18', '18205', '9120063', '福井県', 'フクイケン', '大野市', 'オオノシ', '阿難祖領家', 'アドソリョウケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市上舌', '18', '18205', '9120064', '福井県', 'フクイケン', '大野市', 'オオノシ', '上舌', 'カミシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市下舌', '18', '18205', '9120065', '福井県', 'フクイケン', '大野市', 'オオノシ', '下舌', 'シモシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市南春日野', '18', '18205', '9120066', '福井県', 'フクイケン', '大野市', 'オオノシ', '南春日野', 'ミナミカスガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市右近次郎', '18', '18205', '9120067', '福井県', 'フクイケン', '大野市', 'オオノシ', '右近次郎', 'ウコンジロウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市茜町', '18', '18205', '9120068', '福井県', 'フクイケン', '大野市', 'オオノシ', '茜町', 'アカネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市鍬掛', '18', '18205', '9120071', '福井県', 'フクイケン', '大野市', 'オオノシ', '鍬掛', 'クワカケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市飯降', '18', '18205', '9120072', '福井県', 'フクイケン', '大野市', 'オオノシ', '飯降', 'イフリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市深井', '18', '18205', '9120073', '福井県', 'フクイケン', '大野市', 'オオノシ', '深井', 'フカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市上荒井', '18', '18205', '9120074', '福井県', 'フクイケン', '大野市', 'オオノシ', '上荒井', 'カミアライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市下黒谷', '18', '18205', '9120075', '福井県', 'フクイケン', '大野市', 'オオノシ', '下黒谷', 'シモクロダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市上黒谷', '18', '18205', '9120076', '福井県', 'フクイケン', '大野市', 'オオノシ', '上黒谷', 'カミクロダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市元町', '18', '18205', '9120081', '福井県', 'フクイケン', '大野市', 'オオノシ', '元町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市大和町', '18', '18205', '9120082', '福井県', 'フクイケン', '大野市', 'オオノシ', '大和町', 'ヤマトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市明倫町', '18', '18205', '9120083', '福井県', 'フクイケン', '大野市', 'オオノシ', '明倫町', 'メイリンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市天神町', '18', '18205', '9120084', '福井県', 'フクイケン', '大野市', 'オオノシ', '天神町', 'テンジンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市新庄', '18', '18205', '9120085', '福井県', 'フクイケン', '大野市', 'オオノシ', '新庄', 'シンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市泉町', '18', '18205', '9120086', '福井県', 'フクイケン', '大野市', 'オオノシ', '泉町', 'イズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市清水', '18', '18205', '9120086', '福井県', 'フクイケン', '大野市', 'オオノシ', '清水', 'ショウズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市亀山', '18', '18205', '9120087', '福井県', 'フクイケン', '大野市', 'オオノシ', '亀山', 'カメヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市城町', '18', '18205', '9120087', '福井県', 'フクイケン', '大野市', 'オオノシ', '城町', 'シロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市水落', '18', '18205', '9120088', '福井県', 'フクイケン', '大野市', 'オオノシ', '水落', 'ミズオトシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市水落町', '18', '18205', '9120088', '福井県', 'フクイケン', '大野市', 'オオノシ', '水落町', 'ミズオトシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市犬山', '18', '18205', '9120091', '福井県', 'フクイケン', '大野市', 'オオノシ', '犬山', 'イヌヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市牛ケ原', '18', '18205', '9120091', '福井県', 'フクイケン', '大野市', 'オオノシ', '牛ケ原', 'ウシガハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市清瀧', '18', '18205', '9120092', '福井県', 'フクイケン', '大野市', 'オオノシ', '清瀧', 'セイリュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市中丁', '18', '18205', '9120093', '福井県', 'フクイケン', '大野市', 'オオノシ', '中丁', 'ナカヨウロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市上丁', '18', '18205', '9120094', '福井県', 'フクイケン', '大野市', 'オオノシ', '上丁', 'カミヨウロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市下丁', '18', '18205', '9120095', '福井県', 'フクイケン', '大野市', 'オオノシ', '下丁', 'シモヨウロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市南六呂師', '18', '18205', '9120131', '福井県', 'フクイケン', '大野市', 'オオノシ', '南六呂師', 'ミナミロクロシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市大月', '18', '18205', '9120132', '福井県', 'フクイケン', '大野市', 'オオノシ', '大月', 'オオツキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市御領', '18', '18205', '9120133', '福井県', 'フクイケン', '大野市', 'オオノシ', '御領', 'ゴリョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市石谷', '18', '18205', '9120134', '福井県', 'フクイケン', '大野市', 'オオノシ', '石谷', 'イシタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市森本', '18', '18205', '9120135', '福井県', 'フクイケン', '大野市', 'オオノシ', '森本', 'モリモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市松丸', '18', '18205', '9120136', '福井県', 'フクイケン', '大野市', 'オオノシ', '松丸', 'マツマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市萩ケ野', '18', '18205', '9120137', '福井県', 'フクイケン', '大野市', 'オオノシ', '萩ケ野', 'ハンガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市花房', '18', '18205', '9120138', '福井県', 'フクイケン', '大野市', 'オオノシ', '花房', 'ハナブサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市不動堂', '18', '18205', '9120139', '福井県', 'フクイケン', '大野市', 'オオノシ', '不動堂', 'フドウドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市橋爪', '18', '18205', '9120141', '福井県', 'フクイケン', '大野市', 'オオノシ', '橋爪', 'ハシヅメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市蓑道', '18', '18205', '9120142', '福井県', 'フクイケン', '大野市', 'オオノシ', '蓑道', 'ミノミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市金山', '18', '18205', '9120143', '福井県', 'フクイケン', '大野市', 'オオノシ', '金山', 'キンザン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市小黒見', '18', '18205', '9120144', '福井県', 'フクイケン', '大野市', 'オオノシ', '小黒見', 'オグロミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市堂嶋', '18', '18205', '9120145', '福井県', 'フクイケン', '大野市', 'オオノシ', '堂嶋', 'ドウジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市落合', '18', '18205', '9120146', '福井県', 'フクイケン', '大野市', 'オオノシ', '落合', 'オチアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市柿ケ嶋', '18', '18205', '9120147', '福井県', 'フクイケン', '大野市', 'オオノシ', '柿ケ嶋', 'カキガシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市八町', '18', '18205', '9120148', '福井県', 'フクイケン', '大野市', 'オオノシ', '八町', 'ヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市伏石', '18', '18205', '9120149', '福井県', 'フクイケン', '大野市', 'オオノシ', '伏石', 'ブクイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市上打波', '18', '18205', '9120151', '福井県', 'フクイケン', '大野市', 'オオノシ', '上打波', 'カミウチナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市下打波', '18', '18205', '9120152', '福井県', 'フクイケン', '大野市', 'オオノシ', '下打波', 'シモウチナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市仏原', '18', '18205', '9120153', '福井県', 'フクイケン', '大野市', 'オオノシ', '仏原', 'ホトケバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市東勝原', '18', '18205', '9120154', '福井県', 'フクイケン', '大野市', 'オオノシ', '東勝原', 'ヒガシカドハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市西勝原', '18', '18205', '9120155', '福井県', 'フクイケン', '大野市', 'オオノシ', '西勝原', 'ニシカドハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市朝日前坂', '18', '18205', '9120201', '福井県', 'フクイケン', '大野市', 'オオノシ', '朝日前坂', 'アサヒマエサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市角野前坂', '18', '18205', '9120202', '福井県', 'フクイケン', '大野市', 'オオノシ', '角野前坂', 'カクノマエサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市後野', '18', '18205', '9120203', '福井県', 'フクイケン', '大野市', 'オオノシ', '後野', 'ノチノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市貝皿', '18', '18205', '9120204', '福井県', 'フクイケン', '大野市', 'オオノシ', '貝皿', 'カイザラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市朝日', '18', '18205', '9120205', '福井県', 'フクイケン', '大野市', 'オオノシ', '朝日', 'アサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市板倉', '18', '18205', '9120206', '福井県', 'フクイケン', '大野市', 'オオノシ', '板倉', 'イタクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市下山', '18', '18205', '9120207', '福井県', 'フクイケン', '大野市', 'オオノシ', '下山', 'シモヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市下半原', '18', '18205', '9120211', '福井県', 'フクイケン', '大野市', 'オオノシ', '下半原', 'シモハンバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市箱ケ瀬', '18', '18205', '9120212', '福井県', 'フクイケン', '大野市', 'オオノシ', '箱ケ瀬', 'ハコガセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市野尻', '18', '18205', '9120213', '福井県', 'フクイケン', '大野市', 'オオノシ', '野尻', 'ノジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市長野', '18', '18205', '9120214', '福井県', 'フクイケン', '大野市', 'オオノシ', '長野', 'ナガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市下大納', '18', '18205', '9120215', '福井県', 'フクイケン', '大野市', 'オオノシ', '下大納', 'シモオオノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市上大納', '18', '18205', '9120216', '福井県', 'フクイケン', '大野市', 'オオノシ', '上大納', 'カミオオノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市角野', '18', '18205', '9120217', '福井県', 'フクイケン', '大野市', 'オオノシ', '角野', 'カクノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市川合', '18', '18205', '9120218', '福井県', 'フクイケン', '大野市', 'オオノシ', '川合', 'カワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市上半原', '18', '18205', '9120221', '福井県', 'フクイケン', '大野市', 'オオノシ', '上半原', 'カミハンバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市東市布', '18', '18205', '9120222', '福井県', 'フクイケン', '大野市', 'オオノシ', '東市布', 'ヒガシイチヌノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市吉', '18', '18205', '9120401', '福井県', 'フクイケン', '大野市', 'オオノシ', '吉', 'ヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市北御門', '18', '18205', '9120402', '福井県', 'フクイケン', '大野市', 'オオノシ', '北御門', 'キタミカド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市森政領家', '18', '18205', '9120403', '福井県', 'フクイケン', '大野市', 'オオノシ', '森政領家', 'モリマサリョウケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市猪島', '18', '18205', '9120404', '福井県', 'フクイケン', '大野市', 'オオノシ', '猪島', 'イノシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市森政地頭', '18', '18205', '9120405', '福井県', 'フクイケン', '大野市', 'オオノシ', '森政地頭', 'モリマサジトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市友兼', '18', '18205', '9120411', '福井県', 'フクイケン', '大野市', 'オオノシ', '友兼', 'トモカネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市御給', '18', '18205', '9120412', '福井県', 'フクイケン', '大野市', 'オオノシ', '御給', 'ゴキュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市東山', '18', '18205', '9120413', '福井県', 'フクイケン', '大野市', 'オオノシ', '東山', 'ヒガシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市野中', '18', '18205', '9120414', '福井県', 'フクイケン', '大野市', 'オオノシ', '野中', 'ノナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市稲郷', '18', '18205', '9120415', '福井県', 'フクイケン', '大野市', 'オオノシ', '稲郷', 'トウゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市開発', '18', '18205', '9120416', '福井県', 'フクイケン', '大野市', 'オオノシ', '開発', 'カイホツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市五条方', '18', '18205', '9120421', '福井県', 'フクイケン', '大野市', 'オオノシ', '五条方', 'ゴジョウホウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市佐開', '18', '18205', '9120422', '福井県', 'フクイケン', '大野市', 'オオノシ', '佐開', 'サビラキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市下若生子', '18', '18205', '9120423', '福井県', 'フクイケン', '大野市', 'オオノシ', '下若生子', 'シモワカゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市今井', '18', '18205', '9120424', '福井県', 'フクイケン', '大野市', 'オオノシ', '今井', 'イマイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市平沢', '18', '18205', '9120425', '福井県', 'フクイケン', '大野市', 'オオノシ', '平沢', 'ヒラサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市西山', '18', '18205', '9120426', '福井県', 'フクイケン', '大野市', 'オオノシ', '西山', 'ニシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市森山', '18', '18205', '9120427', '福井県', 'フクイケン', '大野市', 'オオノシ', '森山', 'モリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市下据', '18', '18205', '9120431', '福井県', 'フクイケン', '大野市', 'オオノシ', '下据', 'シモシガラミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市西里', '18', '18205', '9120431', '福井県', 'フクイケン', '大野市', 'オオノシ', '西里', 'ニシサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('120999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市下郷', '18', '18205', '9120432', '福井県', 'フクイケン', '大野市', 'オオノシ', '下郷', 'シモゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市木本', '18', '18205', '9120433', '福井県', 'フクイケン', '大野市', 'オオノシ', '木本', 'コノモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市宝慶寺', '18', '18205', '9120434', '福井県', 'フクイケン', '大野市', 'オオノシ', '宝慶寺', 'ホウキョウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市榎', '18', '18205', '9120435', '福井県', 'フクイケン', '大野市', 'オオノシ', '榎', 'エノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市西据', '18', '18205', '9120436', '福井県', 'フクイケン', '大野市', 'オオノシ', '西据', 'ニシシガラミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市中据', '18', '18205', '9120437', '福井県', 'フクイケン', '大野市', 'オオノシ', '中据', 'ナカシガラミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市新河原', '18', '18205', '9120801', '福井県', 'フクイケン', '大野市', 'オオノシ', '新河原', 'シンカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市新田', '18', '18205', '9120802', '福井県', 'フクイケン', '大野市', 'オオノシ', '新田', 'シンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市富嶋', '18', '18205', '9120803', '福井県', 'フクイケン', '大野市', 'オオノシ', '富嶋', 'トビシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市森目', '18', '18205', '9120804', '福井県', 'フクイケン', '大野市', 'オオノシ', '森目', 'モリメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市土布子', '18', '18205', '9120805', '福井県', 'フクイケン', '大野市', 'オオノシ', '土布子', 'ツチフゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市土打', '18', '18205', '9120811', '福井県', 'フクイケン', '大野市', 'オオノシ', '土打', 'ツチウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市富塚', '18', '18205', '9120812', '福井県', 'フクイケン', '大野市', 'オオノシ', '富塚', 'トミヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市上野', '18', '18205', '9120813', '福井県', 'フクイケン', '大野市', 'オオノシ', '上野', 'ウワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市上麻生嶋', '18', '18205', '9120814', '福井県', 'フクイケン', '大野市', 'オオノシ', '上麻生嶋', 'カミアソウジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市川嶋', '18', '18205', '9120814', '福井県', 'フクイケン', '大野市', 'オオノシ', '川嶋', 'カワシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市下麻生嶋', '18', '18205', '9120815', '福井県', 'フクイケン', '大野市', 'オオノシ', '下麻生嶋', 'シモアソウジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市七板', '18', '18205', '9120821', '福井県', 'フクイケン', '大野市', 'オオノシ', '七板', 'ナナイタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市下唯野', '18', '18205', '9120822', '福井県', 'フクイケン', '大野市', 'オオノシ', '下唯野', 'シモユイノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市蕨生', '18', '18205', '9120823', '福井県', 'フクイケン', '大野市', 'オオノシ', '蕨生', 'ワラビョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市木落', '18', '18205', '9120824', '福井県', 'フクイケン', '大野市', 'オオノシ', '木落', 'キオトシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市新塚原', '18', '18205', '9120825', '福井県', 'フクイケン', '大野市', 'オオノシ', '新塚原', 'シンツカバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市塚原', '18', '18205', '9120825', '福井県', 'フクイケン', '大野市', 'オオノシ', '塚原', 'ツカバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市井ノ口', '18', '18205', '9120826', '福井県', 'フクイケン', '大野市', 'オオノシ', '井ノ口', 'イノクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大野市田野', '18', '18205', '9120827', '福井県', 'フクイケン', '大野市', 'オオノシ', '田野', 'タノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市三国町池上', '18', '18210', '9130001', '福井県', 'フクイケン', '坂井市', 'サカイシ', '三国町池上', 'ミクニチョウイケガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市三国町加戸', '18', '18210', '9130002', '福井県', 'フクイケン', '坂井市', 'サカイシ', '三国町加戸', 'ミクニチョウカド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市三国町西谷', '18', '18210', '9130003', '福井県', 'フクイケン', '坂井市', 'サカイシ', '三国町西谷', 'ミクニチョウニシタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市三国町平山', '18', '18210', '9130004', '福井県', 'フクイケン', '坂井市', 'サカイシ', '三国町平山', 'ミクニチョウヒラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市三国町浜地', '18', '18210', '9130005', '福井県', 'フクイケン', '坂井市', 'サカイシ', '三国町浜地', 'ミクニチョウハマジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市三国町水居', '18', '18210', '9130011', '福井県', 'フクイケン', '坂井市', 'サカイシ', '三国町水居', 'ミクニチョウミズイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市三国町西今市', '18', '18210', '9130012', '福井県', 'フクイケン', '坂井市', 'サカイシ', '三国町西今市', 'ミクニチョウニシイマイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市三国町藤沢', '18', '18210', '9130013', '福井県', 'フクイケン', '坂井市', 'サカイシ', '三国町藤沢', 'ミクニチョウフジサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市三国町玉江', '18', '18210', '9130014', '福井県', 'フクイケン', '坂井市', 'サカイシ', '三国町玉江', 'ミクニチョウトウノエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市三国町野中', '18', '18210', '9130015', '福井県', 'フクイケン', '坂井市', 'サカイシ', '三国町野中', 'ミクニチョウノナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市三国町三国東', '18', '18210', '9130016', '福井県', 'フクイケン', '坂井市', 'サカイシ', '三国町三国東', 'ミクニチョウミクニヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市三国町竹松', '18', '18210', '9130017', '福井県', 'フクイケン', '坂井市', 'サカイシ', '三国町竹松', 'ミクニチョウタケマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市三国町楽円', '18', '18210', '9130021', '福井県', 'フクイケン', '坂井市', 'サカイシ', '三国町楽円', 'ミクニチョウラクエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市三国町油屋', '18', '18210', '9130022', '福井県', 'フクイケン', '坂井市', 'サカイシ', '三国町油屋', 'ミクニチョウアブラヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市三国町石丸', '18', '18210', '9130023', '福井県', 'フクイケン', '坂井市', 'サカイシ', '三国町石丸', 'ミクニチョウイシマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市三国町池見', '18', '18210', '9130024', '福井県', 'フクイケン', '坂井市', 'サカイシ', '三国町池見', 'ミクニチョウイケミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市三国町川崎', '18', '18210', '9130025', '福井県', 'フクイケン', '坂井市', 'サカイシ', '三国町川崎', 'ミクニチョウカワサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市三国町殿島', '18', '18210', '9130026', '福井県', 'フクイケン', '坂井市', 'サカイシ', '三国町殿島', 'ミクニチョウトノシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市三国町汐見', '18', '18210', '9130027', '福井県', 'フクイケン', '坂井市', 'サカイシ', '三国町汐見', 'ミクニチョウシオミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市三国町新保', '18', '18210', '9130031', '福井県', 'フクイケン', '坂井市', 'サカイシ', '三国町新保', 'ミクニチョウシンボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市三国町山岸', '18', '18210', '9130032', '福井県', 'フクイケン', '坂井市', 'サカイシ', '三国町山岸', 'ミクニチョウヤマギシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市三国町下野', '18', '18210', '9130033', '福井県', 'フクイケン', '坂井市', 'サカイシ', '三国町下野', 'ミクニチョウシモノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市三国町西野中', '18', '18210', '9130034', '福井県', 'フクイケン', '坂井市', 'サカイシ', '三国町西野中', 'ミクニチョウニシノナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市三国町沖野々', '18', '18210', '9130035', '福井県', 'フクイケン', '坂井市', 'サカイシ', '三国町沖野々', 'ミクニチョウオキノノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市三国町横越', '18', '18210', '9130035', '福井県', 'フクイケン', '坂井市', 'サカイシ', '三国町横越', 'ミクニチョウヨコゴシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市三国町米納津', '18', '18210', '9130036', '福井県', 'フクイケン', '坂井市', 'サカイシ', '三国町米納津', 'ミクニチョウヨノヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市三国町黒目', '18', '18210', '9130037', '福井県', 'フクイケン', '坂井市', 'サカイシ', '三国町黒目', 'ミクニチョウクロメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市三国町黒目テクノポート', '18', '18210', '9130038', '福井県', 'フクイケン', '坂井市', 'サカイシ', '三国町黒目', 'ミクニチョウクロメ', null, null, 'テクノポート', 'テクノポート');
INSERT INTO `ms_addresses` VALUES ('121059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市三国町新保テクノポート', '18', '18210', '9130038', '福井県', 'フクイケン', '坂井市', 'サカイシ', '三国町新保', 'ミクニチョウシンボ', null, null, 'テクノポート', 'テクノポート');
INSERT INTO `ms_addresses` VALUES ('121060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市三国町山岸テクノポート', '18', '18210', '9130038', '福井県', 'フクイケン', '坂井市', 'サカイシ', '三国町山岸', 'ミクニチョウヤマギシ', null, null, 'テクノポート', 'テクノポート');
INSERT INTO `ms_addresses` VALUES ('121061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市三国町米納津テクノポート', '18', '18210', '9130038', '福井県', 'フクイケン', '坂井市', 'サカイシ', '三国町米納津', 'ミクニチョウヨノヅ', null, null, 'テクノポート', 'テクノポート');
INSERT INTO `ms_addresses` VALUES ('121062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市三国町覚善', '18', '18210', '9130041', '福井県', 'フクイケン', '坂井市', 'サカイシ', '三国町覚善', 'ミクニチョウカクゼン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市三国町中央', '18', '18210', '9130042', '福井県', 'フクイケン', '坂井市', 'サカイシ', '三国町中央', 'ミクニチョウチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市三国町錦', '18', '18210', '9130043', '福井県', 'フクイケン', '坂井市', 'サカイシ', '三国町錦', 'ミクニチョウニシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市三国町山王', '18', '18210', '9130044', '福井県', 'フクイケン', '坂井市', 'サカイシ', '三国町山王', 'ミクニチョウサンノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市三国町南本町', '18', '18210', '9130045', '福井県', 'フクイケン', '坂井市', 'サカイシ', '三国町南本町', 'ミクニチョウミナミホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市三国町北本町', '18', '18210', '9130046', '福井県', 'フクイケン', '坂井市', 'サカイシ', '三国町北本町', 'ミクニチョウキタホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市三国町神明', '18', '18210', '9130047', '福井県', 'フクイケン', '坂井市', 'サカイシ', '三国町神明', 'ミクニチョウシンメイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市三国町緑ケ丘', '18', '18210', '9130048', '福井県', 'フクイケン', '坂井市', 'サカイシ', '三国町緑ケ丘', 'ミクニチョウミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市三国町嵩', '18', '18210', '9130051', '福井県', 'フクイケン', '坂井市', 'サカイシ', '三国町嵩', 'ミクニチョウダケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市三国町運動公園', '18', '18210', '9130052', '福井県', 'フクイケン', '坂井市', 'サカイシ', '三国町運動公園', 'ミクニチョウウンドウコウエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市三国町青葉台', '18', '18210', '9130053', '福井県', 'フクイケン', '坂井市', 'サカイシ', '三国町青葉台', 'ミクニチョウアオバダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市三国町滝谷', '18', '18210', '9130054', '福井県', 'フクイケン', '坂井市', 'サカイシ', '三国町滝谷', 'ミクニチョウタキダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市三国町つつじが丘', '18', '18210', '9130055', '福井県', 'フクイケン', '坂井市', 'サカイシ', '三国町つつじが丘', 'ミクニチョウツツジガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市三国町宿', '18', '18210', '9130056', '福井県', 'フクイケン', '坂井市', 'サカイシ', '三国町宿', 'ミクニチョウシュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市三国町米ケ脇', '18', '18210', '9130057', '福井県', 'フクイケン', '坂井市', 'サカイシ', '三国町米ケ脇', 'ミクニチョウコメガワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市三国町新宿', '18', '18210', '9130058', '福井県', 'フクイケン', '坂井市', 'サカイシ', '三国町新宿', 'ミクニチョウシンシュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市三国町梶', '18', '18210', '9130061', '福井県', 'フクイケン', '坂井市', 'サカイシ', '三国町梶', 'ミクニチョウカジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市三国町陣ケ岡', '18', '18210', '9130062', '福井県', 'フクイケン', '坂井市', 'サカイシ', '三国町陣ケ岡', 'ミクニチョウジンガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市三国町安島東尋坊', '18', '18210', '9130063', '福井県', 'フクイケン', '坂井市', 'サカイシ', '三国町安島', 'ミクニチョウアントウ', null, null, '東尋坊', 'トウジンボウ');
INSERT INTO `ms_addresses` VALUES ('121081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市三国町安島', '18', '18210', '9130064', '福井県', 'フクイケン', '坂井市', 'サカイシ', '三国町安島', 'ミクニチョウアントウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市三国町崎', '18', '18210', '9130065', '福井県', 'フクイケン', '坂井市', 'サカイシ', '三国町崎', 'ミクニチョウサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市', '18', '18202', '9140000', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('121092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市新保', '18', '18202', '9140001', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '新保', 'シンボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市葉原', '18', '18202', '9140002', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '葉原', 'ハバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市獺河内', '18', '18202', '9140003', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '獺河内', 'ウソゴウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市池河内', '18', '18202', '9140004', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '池河内', 'イケノコウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市樫曲', '18', '18202', '9140005', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '樫曲', 'カシマガリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市越坂', '18', '18202', '9140006', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '越坂', 'オッサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市田尻', '18', '18202', '9140007', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '田尻', 'タジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市深山寺', '18', '18202', '9140011', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '深山寺', 'ミヤマデラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市川北', '18', '18202', '9140012', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '川北', 'カワキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市谷口', '18', '18202', '9140013', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '谷口', 'タニグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市井川', '18', '18202', '9140014', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '井川', 'イガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市河原町', '18', '18202', '9140015', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '河原町', 'カワハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市余座', '18', '18202', '9140016', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '余座', 'ヨザ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市藤ケ丘町', '18', '18202', '9140017', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '藤ケ丘町', 'フジガオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市大蔵', '18', '18202', '9140018', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '大蔵', 'オオクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市泉ケ丘町', '18', '18202', '9140021', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '泉ケ丘町', 'イズミガオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市高野', '18', '18202', '9140022', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '高野', 'タカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市深川町', '18', '18202', '9140023', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '深川町', 'フカガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市吉河', '18', '18202', '9140024', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '吉河', 'ヨシコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市樋ノ水町', '18', '18202', '9140025', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '樋ノ水町', 'ヒノミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市木ノ芽町', '18', '18202', '9140026', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '木ノ芽町', 'キノメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市若泉町', '18', '18202', '9140027', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '若泉町', 'ワカイズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市中', '18', '18202', '9140028', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '中', 'ナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市谷', '18', '18202', '9140031', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '谷', 'タニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市小河', '18', '18202', '9140032', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '小河', 'オゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市鳩原', '18', '18202', '9140033', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '鳩原', 'ハトハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市小河口', '18', '18202', '9140034', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '小河口', 'オゴグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市山泉', '18', '18202', '9140035', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '山泉', 'ヤマシミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市堂', '18', '18202', '9140036', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '堂', 'ドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市道口', '18', '18202', '9140037', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '道口', 'ミチノクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市坂下', '18', '18202', '9140038', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '坂下', 'サカノシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市観音町', '18', '18202', '9140039', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '観音町', 'カンノンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市羽織町', '18', '18202', '9140039', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '羽織町', 'ハオリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市布田町', '18', '18202', '9140041', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '布田町', 'ヌノダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市石ケ町', '18', '18202', '9140042', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '石ケ町', 'イシガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市衣掛町', '18', '18202', '9140043', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '衣掛町', 'キヌカケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市岡山町', '18', '18202', '9140044', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '岡山町', 'オカヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市古田刈', '18', '18202', '9140045', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '古田刈', 'コタカリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市長沢', '18', '18202', '9140046', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '長沢', 'ナガソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市東洋町', '18', '18202', '9140047', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '東洋町', 'トウヨウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市本町', '18', '18202', '9140051', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市清水町', '18', '18202', '9140052', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '清水町', 'キヨミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市舞崎町', '18', '18202', '9140053', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '舞崎町', 'マイザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市白銀町', '18', '18202', '9140054', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '白銀町', 'シロガネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市鉄輪町', '18', '18202', '9140055', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '鉄輪町', 'カナワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市津内町', '18', '18202', '9140056', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '津内町', 'ツナイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市開町', '18', '18202', '9140057', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '開町', 'ヒラキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市三島町', '18', '18202', '9140058', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '三島町', 'ミシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市国広町', '18', '18202', '9140059', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '国広町', 'クニヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市蓬莱町', '18', '18202', '9140061', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '蓬莱町', 'ホウライチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市相生町', '18', '18202', '9140062', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '相生町', 'アイオイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市神楽町', '18', '18202', '9140063', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '神楽町', 'カグラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市結城町', '18', '18202', '9140064', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '結城町', 'ユウキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市松栄町', '18', '18202', '9140065', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '松栄町', 'マツエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市川崎町', '18', '18202', '9140066', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '川崎町', 'カワサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市泉', '18', '18202', '9140071', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '泉', 'シミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市金ケ崎町', '18', '18202', '9140072', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '金ケ崎町', 'カネガサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市天筒町', '18', '18202', '9140073', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '天筒町', 'テヅツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市角鹿町', '18', '18202', '9140074', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '角鹿町', 'ツノガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市曙町', '18', '18202', '9140075', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '曙町', 'アケボノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市元町', '18', '18202', '9140076', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '元町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市栄新町', '18', '18202', '9140077', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '栄新町', 'サカエシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市桜町', '18', '18202', '9140078', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '桜町', 'サクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市港町', '18', '18202', '9140079', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '港町', 'ミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市野神', '18', '18202', '9140121', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '野神', 'ノガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市新和町', '18', '18202', '9140122', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '新和町', 'シンワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市和久野', '18', '18202', '9140123', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '和久野', 'ワクノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市市野々', '18', '18202', '9140124', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '市野々', 'イチノノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市市野々町', '18', '18202', '9140124', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '市野々町', 'イチノノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市若葉町', '18', '18202', '9140125', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '若葉町', 'ワカバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市公文名', '18', '18202', '9140131', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '公文名', 'クモンミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市御名', '18', '18202', '9140132', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '御名', 'ゴミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市みどりケ丘町', '18', '18202', '9140133', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', 'みどりケ丘町', 'ミドリガオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市山', '18', '18202', '9140134', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '山', 'ヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市長谷', '18', '18202', '9140135', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '長谷', 'ナガタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市砂流', '18', '18202', '9140136', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '砂流', 'スナガレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市ひばりケ丘町', '18', '18202', '9140137', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', 'ひばりケ丘町', 'ヒバリガオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市櫛林', '18', '18202', '9140138', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '櫛林', 'クシバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市莇生野', '18', '18202', '9140141', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '莇生野', 'アゾノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市萩野町', '18', '18202', '9140142', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '萩野町', 'ハギノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市沢', '18', '18202', '9140143', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '沢', 'サワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市桜ケ丘町', '18', '18202', '9140144', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '桜ケ丘町', 'サクラガオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市野坂', '18', '18202', '9140145', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '野坂', 'ノサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市金山', '18', '18202', '9140146', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '金山', 'カナヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市関', '18', '18202', '9140147', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '関', 'セキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市元比田', '18', '18202', '9140261', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '元比田', 'モトヒダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市大比田', '18', '18202', '9140262', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '大比田', 'オオヒダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市横浜', '18', '18202', '9140263', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '横浜', 'ヨコハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市杉津', '18', '18202', '9140264', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '杉津', 'スイヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市阿曽', '18', '18202', '9140265', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '阿曽', 'アゾ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市挙野', '18', '18202', '9140266', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '挙野', 'アゲノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市五幡', '18', '18202', '9140267', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '五幡', 'イツハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市江良', '18', '18202', '9140268', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '江良', 'エラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市泉東浦', '18', '18202', '9140271', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '泉', 'シミズ', null, null, '東浦', 'ヒガシウラ');
INSERT INTO `ms_addresses` VALUES ('121189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市赤崎', '18', '18202', '9140272', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '赤崎', 'アカサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市田結', '18', '18202', '9140273', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '田結', 'タイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市鞠山', '18', '18202', '9140274', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '鞠山', 'マルヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市市橋', '18', '18202', '9140301', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '市橋', 'イチハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市疋田', '18', '18202', '9140302', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '疋田', 'ヒキダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市追分', '18', '18202', '9140303', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '追分', 'オイワケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市深坂', '18', '18202', '9140304', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '深坂', 'フカサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市駄口', '18', '18202', '9140305', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '駄口', 'ダグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市山中', '18', '18202', '9140306', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '山中', 'ヤマナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市奥野', '18', '18202', '9140311', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '奥野', 'オクノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市曽々木', '18', '18202', '9140312', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '曽々木', 'ソソギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市刀根', '18', '18202', '9140313', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '刀根', 'トネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市杉箸', '18', '18202', '9140314', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '杉箸', 'スギハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市麻生口', '18', '18202', '9140315', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '麻生口', 'アソウグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市奥麻生', '18', '18202', '9140316', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '奥麻生', 'オクアソウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市新道', '18', '18202', '9140317', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '新道', 'シンドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市松島町', '18', '18202', '9140801', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '松島町', 'マツシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市呉竹町', '18', '18202', '9140802', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '呉竹町', 'クレタケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市新松島町', '18', '18202', '9140803', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '新松島町', 'シンマツシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市鋳物師町', '18', '18202', '9140805', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '鋳物師町', 'イモジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市松原町', '18', '18202', '9140806', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '松原町', 'マツバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市松葉町', '18', '18202', '9140807', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '松葉町', 'マツバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市中央町', '18', '18202', '9140811', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '中央町', 'チュウオウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市昭和町', '18', '18202', '9140812', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '昭和町', 'ショウワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市呉羽町', '18', '18202', '9140813', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '呉羽町', 'クレハチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市木崎', '18', '18202', '9140814', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '木崎', 'キザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市平和町', '18', '18202', '9140815', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '平和町', 'ヘイワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市櫛川', '18', '18202', '9140821', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '櫛川', 'クシカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市櫛川町', '18', '18202', '9140822', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '櫛川町', 'クシカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市沓見', '18', '18202', '9140823', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '沓見', 'クツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市原', '18', '18202', '9140824', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '原', 'ハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市永大町', '18', '18202', '9140825', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '永大町', 'エイダイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市沓', '18', '18202', '9140831', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '沓', 'クツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市常宮', '18', '18202', '9140832', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '常宮', 'ジョウグウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市縄間', '18', '18202', '9140833', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '縄間', 'ノウマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市名子', '18', '18202', '9140834', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '名子', 'ナゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市二村', '18', '18202', '9140835', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '二村', 'フタムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市立石', '18', '18202', '9140841', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '立石', 'タテイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市明神町', '18', '18202', '9140842', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '明神町', 'ミョウジンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市浦底', '18', '18202', '9140843', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '浦底', 'ウラソコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市色浜', '18', '18202', '9140844', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '色浜', 'イロハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市手', '18', '18202', '9140845', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '手', 'テ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市', '18', '18209', '9150000', '福井県', 'フクイケン', '越前市', 'エチゼンシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('121247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市中新庄町', '18', '18209', '9150001', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '中新庄町', 'ナカシンジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市長尾町', '18', '18209', '9150002', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '長尾町', 'ナガオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市戸谷町', '18', '18209', '9150003', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '戸谷町', 'トタニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市北町', '18', '18209', '9150004', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '北町', 'キタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市真柄町', '18', '18209', '9150005', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '真柄町', 'マカラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市杉崎町', '18', '18209', '9150006', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '杉崎町', 'スギサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市三ツ屋町', '18', '18209', '9150007', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '三ツ屋町', 'ミツヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市金屋町', '18', '18209', '9150011', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '金屋町', 'カナヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市上真柄町', '18', '18209', '9150011', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '上真柄町', 'カミマカラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市清水頭町', '18', '18209', '9150012', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '清水頭町', 'シミズガシラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市上真柄宮谷入会地', '18', '18209', '9150013', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '上真柄宮谷入会地', 'カミマカラミヤダニイリアイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市宮谷町', '18', '18209', '9150013', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '宮谷町', 'ミヤダニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市西尾町', '18', '18209', '9150014', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '西尾町', 'ニシオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市大手町', '18', '18209', '9150015', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '大手町', 'オオデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市岩内町', '18', '18209', '9150016', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '岩内町', 'イワウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市北小山町', '18', '18209', '9150021', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '北小山町', 'キタオヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市南小山町', '18', '18209', '9150022', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '南小山町', 'ミナミオヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市池泉町', '18', '18209', '9150023', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '池泉町', 'イケイズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市上大坪町', '18', '18209', '9150024', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '上大坪町', 'カミオオツボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市味真野町', '18', '18209', '9150025', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '味真野町', 'アジマノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市五分市町', '18', '18209', '9150026', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '五分市町', 'ゴブイチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市余川町', '18', '18209', '9150031', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '余川町', 'ヨカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市檜尾谷町', '18', '18209', '9150032', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '檜尾谷町', 'ヒオダニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市蓑脇町', '18', '18209', '9150033', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '蓑脇町', 'ミノワキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市中居町', '18', '18209', '9150034', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '中居町', 'ナカイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市入谷町', '18', '18209', '9150035', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '入谷町', 'イリタニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市文室町', '18', '18209', '9150036', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '文室町', 'フムロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市萱谷町', '18', '18209', '9150037', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '萱谷町', 'カヤダニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市葛岡町', '18', '18209', '9150041', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '葛岡町', 'クズオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市大屋町', '18', '18209', '9150042', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '大屋町', 'オオヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市庄田町', '18', '18209', '9150043', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '庄田町', 'ショウデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市平林町', '18', '18209', '9150044', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '平林町', 'ヒラバヤシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市荒谷町', '18', '18209', '9150045', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '荒谷町', 'アラタニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市西谷町', '18', '18209', '9150046', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '西谷町', 'ニシタニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市帆山町', '18', '18209', '9150051', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '帆山町', 'ホヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市矢放町', '18', '18209', '9150052', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '矢放町', 'ヤハナシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市問屋町', '18', '18209', '9150053', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '問屋町', 'トンヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市小野谷町', '18', '18209', '9150054', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '小野谷町', 'オノダニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市畑町', '18', '18209', '9150055', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '畑町', 'ハタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市向新保町', '18', '18209', '9150056', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '向新保町', 'ムカイシンボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市矢船町', '18', '18209', '9150057', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '矢船町', 'ヤフネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市堀川町', '18', '18209', '9150061', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '堀川町', 'ホリカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市姫川', '18', '18209', '9150062', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '姫川', 'ヒメカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市若竹町', '18', '18209', '9150063', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '若竹町', 'ワカタケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市あおば町', '18', '18209', '9150064', '福井県', 'フクイケン', '越前市', 'エチゼンシ', 'あおば町', 'アオバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市豊町', '18', '18209', '9150065', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '豊町', 'ユタカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市神明町', '18', '18209', '9150066', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '神明町', 'シンメイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市住吉町', '18', '18209', '9150067', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '住吉町', 'スミヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市天王町', '18', '18209', '9150068', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '天王町', 'テンノウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市吾妻町', '18', '18209', '9150069', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '吾妻町', 'アヅマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市府中', '18', '18209', '9150071', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '府中', 'フチュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市万代町', '18', '18209', '9150072', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '万代町', 'バンダイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市錦町', '18', '18209', '9150073', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '錦町', 'ニシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市蓬莱町', '18', '18209', '9150074', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '蓬莱町', 'ホウライチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市幸町', '18', '18209', '9150075', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市国府', '18', '18209', '9150076', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '国府', 'コクフ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市馬上免町', '18', '18209', '9150081', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '馬上免町', 'バジョウメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市国高', '18', '18209', '9150082', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '国高', 'クニタカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市押田', '18', '18209', '9150083', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '押田', 'オシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市村国', '18', '18209', '9150084', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '村国', 'ムラクニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市八幡', '18', '18209', '9150085', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '八幡', 'ハチマン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市高木町', '18', '18209', '9150091', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '高木町', 'タカギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市塚町', '18', '18209', '9150092', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '塚町', 'ツカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市庄町', '18', '18209', '9150093', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '庄町', 'ショウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市横市町', '18', '18209', '9150094', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '横市町', 'ヨコイチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市稲寄町', '18', '18209', '9150095', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '稲寄町', 'イナヨセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市瓜生町', '18', '18209', '9150096', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '瓜生町', 'ウリュウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市長土呂町', '18', '18209', '9150097', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '長土呂町', 'ナガトロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市西河内町', '18', '18209', '9150201', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '西河内町', 'ニシコウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市相木町', '18', '18209', '9150202', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '相木町', 'アイノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市清根町', '18', '18209', '9150203', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '清根町', 'キヨネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市横住町', '18', '18209', '9150203', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '横住町', 'ヨコズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市寺地町', '18', '18209', '9150204', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '寺地町', 'テラジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市波垣町', '18', '18209', '9150205', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '波垣町', 'ナミガキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市春山町', '18', '18209', '9150206', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '春山町', 'ハルヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市東樫尾町', '18', '18209', '9150207', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '東樫尾町', 'ヒガシカシオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市領家町', '18', '18209', '9150208', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '領家町', 'リョウケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市藤木町', '18', '18209', '9150209', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '藤木町', 'フジノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市室谷町', '18', '18209', '9150211', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '室谷町', 'ムロタニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市長谷町', '18', '18209', '9150212', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '長谷町', 'ナガタニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市南中町', '18', '18209', '9150213', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '南中町', 'ミナミナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市赤谷町', '18', '18209', '9150214', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '赤谷町', 'アカタニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市柳元町', '18', '18209', '9150215', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '柳元町', 'ヤナギモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市市野々町', '18', '18209', '9150216', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '市野々町', 'イチノノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市水間町', '18', '18209', '9150217', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '水間町', 'ミズマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市大谷町', '18', '18209', '9150218', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '大谷町', 'オオタニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市北坂下町', '18', '18209', '9150219', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '北坂下町', 'キタサカシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市殿町', '18', '18209', '9150219', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '殿町', 'トノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市杉尾町', '18', '18209', '9150221', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '杉尾町', 'スギオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市轟井町', '18', '18209', '9150222', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '轟井町', 'トドロイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市島町', '18', '18209', '9150223', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '島町', 'シマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市長五町', '18', '18209', '9150223', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '長五町', 'チョウゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市八石町', '18', '18209', '9150224', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '八石町', 'ハチコクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市別印町', '18', '18209', '9150225', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '別印町', 'ベツインチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市南坂下町', '18', '18209', '9150226', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '南坂下町', 'ミナミサカシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市中印町', '18', '18209', '9150227', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '中印町', 'ナカインチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市大平町', '18', '18209', '9150228', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '大平町', 'オオヒラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市定友町', '18', '18209', '9150231', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '定友町', 'サダトモチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市新在家町', '18', '18209', '9150232', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '新在家町', 'シンザイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市岩本町', '18', '18209', '9150233', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '岩本町', 'イワモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市大滝町', '18', '18209', '9150234', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '大滝町', 'オオタキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市不老町', '18', '18209', '9150235', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '不老町', 'オイズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市粟田部町中央', '18', '18209', '9150241', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '粟田部町中央', 'アワタベチョウチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市粟田部町', '18', '18209', '9150242', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '粟田部町', 'アワタベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市千原町', '18', '18209', '9150243', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '千原町', 'チハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市西樫尾町', '18', '18209', '9150244', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '西樫尾町', 'ニシカシオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市東庄境町', '18', '18209', '9150251', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '東庄境町', 'ヒガシショウザカイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市西庄境町', '18', '18209', '9150252', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '西庄境町', 'ニシショウザカイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市中津山町', '18', '18209', '9150253', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '中津山町', 'ナカツヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市国中町', '18', '18209', '9150254', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '国中町', 'クニナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市新堂町', '18', '18209', '9150255', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '新堂町', 'シンドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市赤坂町', '18', '18209', '9150256', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '赤坂町', 'アカサカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市朽飯町', '18', '18209', '9150261', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '朽飯町', 'クダシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市高岡町', '18', '18209', '9150262', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '高岡町', 'タカオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市山室町', '18', '18209', '9150263', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '山室町', 'ヤマムロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市野岡町', '18', '18209', '9150264', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '野岡町', 'ノオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市仲山', '18', '18209', '9150265', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '仲山', 'ナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市家久町', '18', '18209', '9150801', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '家久町', 'イエヒサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市北府', '18', '18209', '9150802', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '北府', 'キタゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市北府本町', '18', '18209', '9150802', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '北府本町', 'キタゴホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市平出', '18', '18209', '9150803', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '平出', 'ヒライデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市新保', '18', '18209', '9150804', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '新保', 'シンボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市新保町', '18', '18209', '9150804', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '新保町', 'シンボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市芝原', '18', '18209', '9150805', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '芝原', 'シバハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市本保町', '18', '18209', '9150806', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '本保町', 'ホンボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市本多', '18', '18209', '9150811', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '本多', 'ホンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市桂町', '18', '18209', '9150812', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '桂町', 'カツラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市京町', '18', '18209', '9150813', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '京町', 'キョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市中央', '18', '18209', '9150814', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市深草', '18', '18209', '9150815', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '深草', 'フカクサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市小松', '18', '18209', '9150816', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '小松', 'コマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市若松町', '18', '18209', '9150821', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '若松町', 'ワカマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市元町', '18', '18209', '9150822', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '元町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市本町', '18', '18209', '9150823', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市武生柳町', '18', '18209', '9150824', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '武生柳町', 'タケフヤナギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市南', '18', '18209', '9150825', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '南', 'ミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市御幸町', '18', '18209', '9150826', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '御幸町', 'ミユキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市平和町', '18', '18209', '9150827', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '平和町', 'ヘイワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市日野美', '18', '18209', '9150831', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '日野美', 'ヒノミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市高瀬', '18', '18209', '9150832', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '高瀬', 'タカセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市沢町', '18', '18209', '9150833', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '沢町', 'サワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市北千福町', '18', '18209', '9150834', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '北千福町', 'キタセンプクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市岡本町', '18', '18209', '9150835', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '岡本町', 'オカモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市野上町', '18', '18209', '9150836', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '野上町', 'ノガミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市文京', '18', '18209', '9150841', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '文京', 'ブンキョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市常久町', '18', '18209', '9150842', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '常久町', 'ツネヒサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市月見町', '18', '18209', '9150843', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '月見町', 'ツキミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市妙法寺町', '18', '18209', '9150844', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '妙法寺町', 'ミョウホウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市三ツ口町', '18', '18209', '9150845', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '三ツ口町', 'ミツクチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市千福町', '18', '18209', '9150846', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '千福町', 'センプクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市東千福町', '18', '18209', '9150847', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '東千福町', 'ヒガシセンプクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市畷町', '18', '18209', '9150851', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '畷町', 'ナワテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市松森町', '18', '18209', '9150852', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '松森町', 'マツモリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市行松町', '18', '18209', '9150853', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '行松町', 'ユキマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市富士見が丘', '18', '18209', '9150854', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '富士見が丘', 'フジミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市下平吹町', '18', '18209', '9150855', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '下平吹町', 'シモヒラブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市中平吹町', '18', '18209', '9150856', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '中平吹町', 'ナカヒラブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市四郎丸町', '18', '18209', '9150857', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '四郎丸町', 'シロウマルチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市今宿町', '18', '18209', '9150861', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '今宿町', 'イマジュクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市国兼町', '18', '18209', '9150862', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '国兼町', 'クニカネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市大塩町', '18', '18209', '9150863', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '大塩町', 'オオシオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市上小松町', '18', '18209', '9150864', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '上小松町', 'カミコマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市瓜生野町', '18', '18209', '9150865', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '瓜生野町', 'ウリュウノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市森久町', '18', '18209', '9150865', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '森久町', 'モリヒサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市向が丘町', '18', '18209', '9150871', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '向が丘町', 'ムカイガオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市広瀬町', '18', '18209', '9150872', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '広瀬町', 'ヒロセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市池ノ上町', '18', '18209', '9150873', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '池ノ上町', 'イケノカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市向陽町', '18', '18209', '9150874', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '向陽町', 'コウヨウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市塚原町', '18', '18209', '9150875', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '塚原町', 'ツカバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市白崎町', '18', '18209', '9150876', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '白崎町', 'シロサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市春日野町', '18', '18209', '9150877', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '春日野町', 'カスガノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市下太田町', '18', '18209', '9150881', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '下太田町', 'シモオオダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市上太田町', '18', '18209', '9150882', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '上太田町', 'カミオオダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市新町', '18', '18209', '9150883', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '新町', 'シンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市大虫本町', '18', '18209', '9150884', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '大虫本町', 'オオムシホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市大虫町', '18', '18209', '9150885', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '大虫町', 'オオムシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市上四目町', '18', '18209', '9150886', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '上四目町', 'カミシメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市下四目町', '18', '18209', '9150887', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '下四目町', 'シモシメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市高森町', '18', '18209', '9150888', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '高森町', 'タカモリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市余田町', '18', '18209', '9150891', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '余田町', 'ハグリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市氷坂町', '18', '18209', '9150892', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '氷坂町', 'ヒサカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市片屋町', '18', '18209', '9150893', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '片屋町', 'カタヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市丹生郷町', '18', '18209', '9150894', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '丹生郷町', 'ニュウノゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市三ツ俣町', '18', '18209', '9150895', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '三ツ俣町', 'ミツマタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市横根町', '18', '18209', '9150896', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '横根町', 'ヨコネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市北山町', '18', '18209', '9150897', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '北山町', 'キタヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県南条郡南越前町具谷', '18', '18404', '9151101', '福井県', 'フクイケン', '南条郡南越前町', 'ナンジョウグンミナミエチゼンチョウ', '具谷', 'グダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県南条郡南越前町菅谷', '18', '18404', '9151102', '福井県', 'フクイケン', '南条郡南越前町', 'ナンジョウグンミナミエチゼンチョウ', '菅谷', 'スゲノタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県南条郡南越前町大谷', '18', '18404', '9151103', '福井県', 'フクイケン', '南条郡南越前町', 'ナンジョウグンミナミエチゼンチョウ', '大谷', 'オオタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県南条郡南越前町大良', '18', '18404', '9151104', '福井県', 'フクイケン', '南条郡南越前町', 'ナンジョウグンミナミエチゼンチョウ', '大良', 'ダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県南条郡南越前町赤萩', '18', '18404', '9151105', '福井県', 'フクイケン', '南条郡南越前町', 'ナンジョウグンミナミエチゼンチョウ', '赤萩', 'アカハギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県南条郡南越前町河内', '18', '18404', '9151106', '福井県', 'フクイケン', '南条郡南越前町', 'ナンジョウグンミナミエチゼンチョウ', '河内', 'コウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県南条郡南越前町河野', '18', '18404', '9151111', '福井県', 'フクイケン', '南条郡南越前町', 'ナンジョウグンミナミエチゼンチョウ', '河野', 'コウノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県南条郡南越前町今泉', '18', '18404', '9151112', '福井県', 'フクイケン', '南条郡南越前町', 'ナンジョウグンミナミエチゼンチョウ', '今泉', 'イマイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県南条郡南越前町甲楽城', '18', '18404', '9151113', '福井県', 'フクイケン', '南条郡南越前町', 'ナンジョウグンミナミエチゼンチョウ', '甲楽城', 'カブラキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県南条郡南越前町糠', '18', '18404', '9151114', '福井県', 'フクイケン', '南条郡南越前町', 'ナンジョウグンミナミエチゼンチョウ', '糠', 'ヌカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県南条郡南越前町糠神土', '18', '18404', '9151114', '福井県', 'フクイケン', '南条郡南越前町', 'ナンジョウグンミナミエチゼンチョウ', '糠', 'ヌカ', null, null, '神土', 'ジンド');
INSERT INTO `ms_addresses` VALUES ('121445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県南条郡南越前町糠杉山', '18', '18404', '9151114', '福井県', 'フクイケン', '南条郡南越前町', 'ナンジョウグンミナミエチゼンチョウ', '糠', 'ヌカ', null, null, '杉山', 'スギヤマ');
INSERT INTO `ms_addresses` VALUES ('121446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県南条郡南越前町八田', '18', '18404', '9151114', '福井県', 'フクイケン', '南条郡南越前町', 'ナンジョウグンミナミエチゼンチョウ', '八田', 'ハッタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市安養寺町', '18', '18209', '9151201', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '安養寺町', 'アンヨウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市黒川町', '18', '18209', '9151202', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '黒川町', 'クロカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市上杉本町', '18', '18209', '9151203', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '上杉本町', 'カミスギモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市都辺町', '18', '18209', '9151204', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '都辺町', 'トベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市萩原町', '18', '18209', '9151205', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '萩原町', 'ハギワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市堀町', '18', '18209', '9151211', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '堀町', 'ホリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市米口町', '18', '18209', '9151212', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '米口町', 'コメグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市仏谷町', '18', '18209', '9151212', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '仏谷町', 'ホトケダニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市丸岡町', '18', '18209', '9151213', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '丸岡町', 'マルカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市勝蓮花町', '18', '18209', '9151214', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '勝蓮花町', 'ショウレンゲチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市小野町', '18', '18209', '9151215', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '小野町', 'コノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市勾当原町', '18', '18209', '9151221', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '勾当原町', 'コウトウガハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市下中津原町', '18', '18209', '9151222', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '下中津原町', 'シモナカツハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市中津原町', '18', '18209', '9151223', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '中津原町', 'ナカツハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市下別所町', '18', '18209', '9151224', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '下別所町', 'シモベッシヨチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市湯谷町', '18', '18209', '9151225', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '湯谷町', 'ユヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市中山町', '18', '18209', '9151226', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '中山町', 'ナカヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市千合谷町', '18', '18209', '9151231', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '千合谷町', 'センゴウダニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市二階堂町', '18', '18209', '9151232', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '二階堂町', 'ニカイドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市菖蒲谷町', '18', '18209', '9151233', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '菖蒲谷町', 'ショウブダニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市小谷町', '18', '18209', '9151234', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '小谷町', 'コダニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市土山町', '18', '18209', '9151234', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '土山町', 'ツチヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市菅町', '18', '18209', '9151235', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '菅町', 'スゲチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市安戸町', '18', '18209', '9151235', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '安戸町', 'ヤスドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市曽原町', '18', '18209', '9151241', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '曽原町', 'ソハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市粟野町', '18', '18209', '9151242', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '粟野町', 'アワノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市小杉町', '18', '18209', '9151243', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '小杉町', 'コスギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市牧町', '18', '18209', '9151244', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '牧町', 'マキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市若須町', '18', '18209', '9151245', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '若須町', 'ワガスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県越前市中野町', '18', '18209', '9151246', '福井県', 'フクイケン', '越前市', 'エチゼンシ', '中野町', 'ナカノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県鯖江市', '18', '18207', '9160000', '福井県', 'フクイケン', '鯖江市', 'サバエシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('121487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県鯖江市吉江町', '18', '18207', '9160001', '福井県', 'フクイケン', '鯖江市', 'サバエシ', '吉江町', 'ヨシエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県鯖江市米岡町', '18', '18207', '9160002', '福井県', 'フクイケン', '鯖江市', 'サバエシ', '米岡町', 'ヨネオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県鯖江市田所町', '18', '18207', '9160003', '福井県', 'フクイケン', '鯖江市', 'サバエシ', '田所町', 'タドコロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県鯖江市糺町', '18', '18207', '9160004', '福井県', 'フクイケン', '鯖江市', 'サバエシ', '糺町', 'タダスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県鯖江市杉本町', '18', '18207', '9160005', '福井県', 'フクイケン', '鯖江市', 'サバエシ', '杉本町', 'スギモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県鯖江市西番町', '18', '18207', '9160006', '福井県', 'フクイケン', '鯖江市', 'サバエシ', '西番町', 'ニシバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県鯖江市三尾野出作町', '18', '18207', '9160007', '福井県', 'フクイケン', '鯖江市', 'サバエシ', '三尾野出作町', 'ミオノシュツサクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県鯖江市入町', '18', '18207', '9160008', '福井県', 'フクイケン', '鯖江市', 'サバエシ', '入町', 'イリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県鯖江市つつじケ丘町', '18', '18207', '9160011', '福井県', 'フクイケン', '鯖江市', 'サバエシ', 'つつじケ丘町', 'ツツジガオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県鯖江市東米岡', '18', '18207', '9160012', '福井県', 'フクイケン', '鯖江市', 'サバエシ', '東米岡', 'ヒガシヨネオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県鯖江市鳥羽', '18', '18207', '9160013', '福井県', 'フクイケン', '鯖江市', 'サバエシ', '鳥羽', 'トバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県鯖江市鳥羽町', '18', '18207', '9160014', '福井県', 'フクイケン', '鯖江市', 'サバエシ', '鳥羽町', 'トバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県鯖江市御幸町', '18', '18207', '9160015', '福井県', 'フクイケン', '鯖江市', 'サバエシ', '御幸町', 'ミユキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県鯖江市神中町', '18', '18207', '9160016', '福井県', 'フクイケン', '鯖江市', 'サバエシ', '神中町', 'カミナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県鯖江市神明町', '18', '18207', '9160017', '福井県', 'フクイケン', '鯖江市', 'サバエシ', '神明町', 'シンメイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県鯖江市幸町', '18', '18207', '9160018', '福井県', 'フクイケン', '鯖江市', 'サバエシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県鯖江市丸山町', '18', '18207', '9160019', '福井県', 'フクイケン', '鯖江市', 'サバエシ', '丸山町', 'マルヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県鯖江市三六町', '18', '18207', '9160021', '福井県', 'フクイケン', '鯖江市', 'サバエシ', '三六町', 'サンロクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県鯖江市水落町', '18', '18207', '9160022', '福井県', 'フクイケン', '鯖江市', 'サバエシ', '水落町', 'ミズオチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県鯖江市西山町', '18', '18207', '9160023', '福井県', 'フクイケン', '鯖江市', 'サバエシ', '西山町', 'ニシヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県鯖江市長泉寺町', '18', '18207', '9160024', '福井県', 'フクイケン', '鯖江市', 'サバエシ', '長泉寺町', 'チョウセンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県鯖江市旭町', '18', '18207', '9160025', '福井県', 'フクイケン', '鯖江市', 'サバエシ', '旭町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県鯖江市本町', '18', '18207', '9160026', '福井県', 'フクイケン', '鯖江市', 'サバエシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県鯖江市桜町', '18', '18207', '9160027', '福井県', 'フクイケン', '鯖江市', 'サバエシ', '桜町', 'サクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県鯖江市小黒町', '18', '18207', '9160028', '福井県', 'フクイケン', '鯖江市', 'サバエシ', '小黒町', 'コグロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県鯖江市北野町', '18', '18207', '9160029', '福井県', 'フクイケン', '鯖江市', 'サバエシ', '北野町', 'キタノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県鯖江市橋立町', '18', '18207', '9160031', '福井県', 'フクイケン', '鯖江市', 'サバエシ', '橋立町', 'ハシタテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県鯖江市舟枝町', '18', '18207', '9160032', '福井県', 'フクイケン', '鯖江市', 'サバエシ', '舟枝町', 'フナエダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県鯖江市中野町', '18', '18207', '9160033', '福井県', 'フクイケン', '鯖江市', 'サバエシ', '中野町', 'ナカノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県鯖江市下新庄町', '18', '18207', '9160034', '福井県', 'フクイケン', '鯖江市', 'サバエシ', '下新庄町', 'シモシンジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県鯖江市新町', '18', '18207', '9160035', '福井県', 'フクイケン', '鯖江市', 'サバエシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県鯖江市横越町', '18', '18207', '9160036', '福井県', 'フクイケン', '鯖江市', 'サバエシ', '横越町', 'ヨコゴシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県鯖江市上河端町', '18', '18207', '9160037', '福井県', 'フクイケン', '鯖江市', 'サバエシ', '上河端町', 'カミコウバタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県鯖江市下河端町', '18', '18207', '9160038', '福井県', 'フクイケン', '鯖江市', 'サバエシ', '下河端町', 'シモコウバタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県鯖江市東鯖江', '18', '18207', '9160041', '福井県', 'フクイケン', '鯖江市', 'サバエシ', '東鯖江', 'ヒガシサバエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県鯖江市新横江', '18', '18207', '9160042', '福井県', 'フクイケン', '鯖江市', 'サバエシ', '新横江', 'シンヨコエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県鯖江市定次町', '18', '18207', '9160043', '福井県', 'フクイケン', '鯖江市', 'サバエシ', '定次町', 'サダツギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県鯖江市五郎丸町', '18', '18207', '9160044', '福井県', 'フクイケン', '鯖江市', 'サバエシ', '五郎丸町', 'ゴロウマルチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県鯖江市宮前', '18', '18207', '9160045', '福井県', 'フクイケン', '鯖江市', 'サバエシ', '宮前', 'ミヤマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県鯖江市横江町', '18', '18207', '9160046', '福井県', 'フクイケン', '鯖江市', 'サバエシ', '横江町', 'ヨコエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県鯖江市柳町', '18', '18207', '9160047', '福井県', 'フクイケン', '鯖江市', 'サバエシ', '柳町', 'ヤナギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県鯖江市屋形町', '18', '18207', '9160051', '福井県', 'フクイケン', '鯖江市', 'サバエシ', '屋形町', 'ヤカタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県鯖江市深江町', '18', '18207', '9160052', '福井県', 'フクイケン', '鯖江市', 'サバエシ', '深江町', 'フカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県鯖江市日の出町', '18', '18207', '9160053', '福井県', 'フクイケン', '鯖江市', 'サバエシ', '日の出町', 'ヒノデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県鯖江市舟津町', '18', '18207', '9160054', '福井県', 'フクイケン', '鯖江市', 'サバエシ', '舟津町', 'フナツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県鯖江市上鯖江', '18', '18207', '9160055', '福井県', 'フクイケン', '鯖江市', 'サバエシ', '上鯖江', 'カミサバエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県鯖江市上鯖江町', '18', '18207', '9160055', '福井県', 'フクイケン', '鯖江市', 'サバエシ', '上鯖江町', 'カミサバエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県鯖江市住吉町', '18', '18207', '9160056', '福井県', 'フクイケン', '鯖江市', 'サバエシ', '住吉町', 'スミヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県鯖江市有定町', '18', '18207', '9160057', '福井県', 'フクイケン', '鯖江市', 'サバエシ', '有定町', 'アリサダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県鯖江市平井町', '18', '18207', '9160061', '福井県', 'フクイケン', '鯖江市', 'サバエシ', '平井町', 'ヒライチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県鯖江市熊田町', '18', '18207', '9160062', '福井県', 'フクイケン', '鯖江市', 'サバエシ', '熊田町', 'クマダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県鯖江市鳥井町', '18', '18207', '9160063', '福井県', 'フクイケン', '鯖江市', 'サバエシ', '鳥井町', 'トリイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県鯖江市下司町', '18', '18207', '9160064', '福井県', 'フクイケン', '鯖江市', 'サバエシ', '下司町', 'ゲシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県鯖江市当田町', '18', '18207', '9160065', '福井県', 'フクイケン', '鯖江市', 'サバエシ', '当田町', 'トウデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県鯖江市上氏家町', '18', '18207', '9160066', '福井県', 'フクイケン', '鯖江市', 'サバエシ', '上氏家町', 'カミウズエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県鯖江市下氏家町', '18', '18207', '9160067', '福井県', 'フクイケン', '鯖江市', 'サバエシ', '下氏家町', 'シモウズエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県鯖江市二丁掛町', '18', '18207', '9160068', '福井県', 'フクイケン', '鯖江市', 'サバエシ', '二丁掛町', 'ニチョガケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県鯖江市持明寺町', '18', '18207', '9160071', '福井県', 'フクイケン', '鯖江市', 'サバエシ', '持明寺町', 'ジミョウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県鯖江市冬島町', '18', '18207', '9160072', '福井県', 'フクイケン', '鯖江市', 'サバエシ', '冬島町', 'フジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県鯖江市下野田町', '18', '18207', '9160073', '福井県', 'フクイケン', '鯖江市', 'サバエシ', '下野田町', 'シモノダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県鯖江市上野田町', '18', '18207', '9160074', '福井県', 'フクイケン', '鯖江市', 'サバエシ', '上野田町', 'カミノダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県鯖江市漆原町', '18', '18207', '9160075', '福井県', 'フクイケン', '鯖江市', 'サバエシ', '漆原町', 'ウルシハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県鯖江市石生谷町', '18', '18207', '9160076', '福井県', 'フクイケン', '鯖江市', 'サバエシ', '石生谷町', 'イショウダニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県鯖江市和田町', '18', '18207', '9160077', '福井県', 'フクイケン', '鯖江市', 'サバエシ', '和田町', 'ワダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県鯖江市西大井町', '18', '18207', '9160078', '福井県', 'フクイケン', '鯖江市', 'サバエシ', '西大井町', 'ニシオオイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県鯖江市石田下町', '18', '18207', '9160081', '福井県', 'フクイケン', '鯖江市', 'サバエシ', '石田下町', 'イシダシモチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県鯖江市石田中町', '18', '18207', '9160082', '福井県', 'フクイケン', '鯖江市', 'サバエシ', '石田中町', 'イシダナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県鯖江市石田上町', '18', '18207', '9160083', '福井県', 'フクイケン', '鯖江市', 'サバエシ', '石田上町', 'イシダカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県鯖江市小泉町', '18', '18207', '9160084', '福井県', 'フクイケン', '鯖江市', 'サバエシ', '小泉町', 'コイズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県鯖江市大倉町', '18', '18207', '9160085', '福井県', 'フクイケン', '鯖江市', 'サバエシ', '大倉町', 'オオクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県鯖江市吉田町', '18', '18207', '9160086', '福井県', 'フクイケン', '鯖江市', 'サバエシ', '吉田町', 'ヨシダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県鯖江市田村町', '18', '18207', '9160087', '福井県', 'フクイケン', '鯖江市', 'サバエシ', '田村町', 'タムラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県鯖江市川去町', '18', '18207', '9160088', '福井県', 'フクイケン', '鯖江市', 'サバエシ', '川去町', 'カワサリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県丹生郡越前町天谷', '18', '18423', '9160101', '福井県', 'フクイケン', '丹生郡越前町', 'ニュウグンエチゼンチョウ', '天谷', 'アマダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県丹生郡越前町真木', '18', '18423', '9160102', '福井県', 'フクイケン', '丹生郡越前町', 'ニュウグンエチゼンチョウ', '真木', 'マキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県丹生郡越前町杖立', '18', '18423', '9160103', '福井県', 'フクイケン', '丹生郡越前町', 'ニュウグンエチゼンチョウ', '杖立', 'ツエタテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県丹生郡越前町森', '18', '18423', '9160104', '福井県', 'フクイケン', '丹生郡越前町', 'ニュウグンエチゼンチョウ', '森', 'モリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県丹生郡越前町清水', '18', '18423', '9160105', '福井県', 'フクイケン', '丹生郡越前町', 'ニュウグンエチゼンチョウ', '清水', 'ショウズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県丹生郡越前町大玉', '18', '18423', '9160106', '福井県', 'フクイケン', '丹生郡越前町', 'ニュウグンエチゼンチョウ', '大玉', 'イカダマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県丹生郡越前町上糸生', '18', '18423', '9160107', '福井県', 'フクイケン', '丹生郡越前町', 'ニュウグンエチゼンチョウ', '上糸生', 'カミイトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県丹生郡越前町小川', '18', '18423', '9160108', '福井県', 'フクイケン', '丹生郡越前町', 'ニュウグンエチゼンチョウ', '小川', 'オガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県丹生郡越前町小倉', '18', '18423', '9160111', '福井県', 'フクイケン', '丹生郡越前町', 'ニュウグンエチゼンチョウ', '小倉', 'オグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県丹生郡越前町葛野', '18', '18423', '9160112', '福井県', 'フクイケン', '丹生郡越前町', 'ニュウグンエチゼンチョウ', '葛野', 'カズラノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県丹生郡越前町野田', '18', '18423', '9160113', '福井県', 'フクイケン', '丹生郡越前町', 'ニュウグンエチゼンチョウ', '野田', 'ノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県丹生郡越前町下糸生', '18', '18423', '9160114', '福井県', 'フクイケン', '丹生郡越前町', 'ニュウグンエチゼンチョウ', '下糸生', 'シモイトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県丹生郡越前町脇', '18', '18423', '9160115', '福井県', 'フクイケン', '丹生郡越前町', 'ニュウグンエチゼンチョウ', '脇', 'ワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県丹生郡越前町中野', '18', '18423', '9160116', '福井県', 'フクイケン', '丹生郡越前町', 'ニュウグンエチゼンチョウ', '中野', 'ナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県丹生郡越前町大谷寺', '18', '18423', '9160117', '福井県', 'フクイケン', '丹生郡越前町', 'ニュウグンエチゼンチョウ', '大谷寺', 'オオタンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県丹生郡越前町大畑', '18', '18423', '9160121', '福井県', 'フクイケン', '丹生郡越前町', 'ニュウグンエチゼンチョウ', '大畑', 'オオバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県丹生郡越前町天王', '18', '18423', '9160122', '福井県', 'フクイケン', '丹生郡越前町', 'ニュウグンエチゼンチョウ', '天王', 'テンノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県丹生郡越前町天宝', '18', '18423', '9160123', '福井県', 'フクイケン', '丹生郡越前町', 'ニュウグンエチゼンチョウ', '天宝', 'テンポウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県丹生郡越前町宝泉寺', '18', '18423', '9160124', '福井県', 'フクイケン', '丹生郡越前町', 'ニュウグンエチゼンチョウ', '宝泉寺', 'ホウセンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県丹生郡越前町横山', '18', '18423', '9160125', '福井県', 'フクイケン', '丹生郡越前町', 'ニュウグンエチゼンチョウ', '横山', 'ヨコヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県丹生郡越前町牛越', '18', '18423', '9160126', '福井県', 'フクイケン', '丹生郡越前町', 'ニュウグンエチゼンチョウ', '牛越', 'ウシゴエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県丹生郡越前町野末', '18', '18423', '9160127', '福井県', 'フクイケン', '丹生郡越前町', 'ニュウグンエチゼンチョウ', '野末', 'ノズエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県丹生郡越前町乙坂', '18', '18423', '9160131', '福井県', 'フクイケン', '丹生郡越前町', 'ニュウグンエチゼンチョウ', '乙坂', 'オツサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県丹生郡越前町田中', '18', '18423', '9160132', '福井県', 'フクイケン', '丹生郡越前町', 'ニュウグンエチゼンチョウ', '田中', 'タナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県丹生郡越前町気比庄', '18', '18423', '9160133', '福井県', 'フクイケン', '丹生郡越前町', 'ニュウグンエチゼンチョウ', '気比庄', 'キヒショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県丹生郡越前町新庄', '18', '18423', '9160134', '福井県', 'フクイケン', '丹生郡越前町', 'ニュウグンエチゼンチョウ', '新庄', 'シンショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県丹生郡越前町市', '18', '18423', '9160135', '福井県', 'フクイケン', '丹生郡越前町', 'ニュウグンエチゼンチョウ', '市', 'イチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県丹生郡越前町栃川', '18', '18423', '9160136', '福井県', 'フクイケン', '丹生郡越前町', 'ニュウグンエチゼンチョウ', '栃川', 'トチカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県丹生郡越前町宮の西団地', '18', '18423', '9160137', '福井県', 'フクイケン', '丹生郡越前町', 'ニュウグンエチゼンチョウ', '宮の西団地', 'ミヤノニシダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県丹生郡越前町西田中', '18', '18423', '9160141', '福井県', 'フクイケン', '丹生郡越前町', 'ニュウグンエチゼンチョウ', '西田中', 'ニシタナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県丹生郡越前町上川去', '18', '18423', '9160142', '福井県', 'フクイケン', '丹生郡越前町', 'ニュウグンエチゼンチョウ', '上川去', 'カミカワサリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県丹生郡越前町宇田', '18', '18423', '9160143', '福井県', 'フクイケン', '丹生郡越前町', 'ニュウグンエチゼンチョウ', '宇田', 'ウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県丹生郡越前町漆本', '18', '18423', '9160143', '福井県', 'フクイケン', '丹生郡越前町', 'ニュウグンエチゼンチョウ', '漆本', 'ウルシモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県丹生郡越前町佐々生', '18', '18423', '9160144', '福井県', 'フクイケン', '丹生郡越前町', 'ニュウグンエチゼンチョウ', '佐々生', 'サソウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県丹生郡越前町岩開', '18', '18423', '9160145', '福井県', 'フクイケン', '丹生郡越前町', 'ニュウグンエチゼンチョウ', '岩開', 'イワカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県丹生郡越前町朝日', '18', '18423', '9160146', '福井県', 'フクイケン', '丹生郡越前町', 'ニュウグンエチゼンチョウ', '朝日', 'アサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県丹生郡越前町内郡', '18', '18423', '9160147', '福井県', 'フクイケン', '丹生郡越前町', 'ニュウグンエチゼンチョウ', '内郡', 'ウチゴオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県丹生郡越前町金谷', '18', '18423', '9160151', '福井県', 'フクイケン', '丹生郡越前町', 'ニュウグンエチゼンチョウ', '金谷', 'カナヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県丹生郡越前町青野', '18', '18423', '9160152', '福井県', 'フクイケン', '丹生郡越前町', 'ニュウグンエチゼンチョウ', '青野', 'アオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県丹生郡越前町頭谷', '18', '18423', '9160153', '福井県', 'フクイケン', '丹生郡越前町', 'ニュウグンエチゼンチョウ', '頭谷', 'カシラダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県丹生郡越前町境野', '18', '18423', '9160154', '福井県', 'フクイケン', '丹生郡越前町', 'ニュウグンエチゼンチョウ', '境野', 'サカイノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県丹生郡越前町茱原', '18', '18423', '9160155', '福井県', 'フクイケン', '丹生郡越前町', 'ニュウグンエチゼンチョウ', '茱原', 'グミワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県丹生郡越前町東内郡', '18', '18423', '9160156', '福井県', 'フクイケン', '丹生郡越前町', 'ニュウグンエチゼンチョウ', '東内郡', 'ヒガシウチゴオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県丹生郡越前町', '18', '18423', '9160200', '福井県', 'フクイケン', '丹生郡越前町', 'ニュウグンエチゼンチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('121605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県丹生郡越前町入尾', '18', '18423', '9160201', '福井県', 'フクイケン', '丹生郡越前町', 'ニュウグンエチゼンチョウ', '入尾', 'イリオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県丹生郡越前町細野', '18', '18423', '9160202', '福井県', 'フクイケン', '丹生郡越前町', 'ニュウグンエチゼンチョウ', '細野', 'ホソノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県丹生郡越前町山田', '18', '18423', '9160203', '福井県', 'フクイケン', '丹生郡越前町', 'ニュウグンエチゼンチョウ', '山田', 'ヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県丹生郡越前町中', '18', '18423', '9160204', '福井県', 'フクイケン', '丹生郡越前町', 'ニュウグンエチゼンチョウ', '中', 'ナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県丹生郡越前町赤井谷', '18', '18423', '9160205', '福井県', 'フクイケン', '丹生郡越前町', 'ニュウグンエチゼンチョウ', '赤井谷', 'アカイダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県丹生郡越前町笈松', '18', '18423', '9160206', '福井県', 'フクイケン', '丹生郡越前町', 'ニュウグンエチゼンチョウ', '笈松', 'オイマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県丹生郡越前町笹川', '18', '18423', '9160211', '福井県', 'フクイケン', '丹生郡越前町', 'ニュウグンエチゼンチョウ', '笹川', 'ササガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県丹生郡越前町岩倉', '18', '18423', '9160212', '福井県', 'フクイケン', '丹生郡越前町', 'ニュウグンエチゼンチョウ', '岩倉', 'イワクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県丹生郡越前町桜谷', '18', '18423', '9160213', '福井県', 'フクイケン', '丹生郡越前町', 'ニュウグンエチゼンチョウ', '桜谷', 'サクラダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県丹生郡越前町上戸', '18', '18423', '9160214', '福井県', 'フクイケン', '丹生郡越前町', 'ニュウグンエチゼンチョウ', '上戸', 'ウワド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県丹生郡越前町織田', '18', '18423', '9160215', '福井県', 'フクイケン', '丹生郡越前町', 'ニュウグンエチゼンチョウ', '織田', 'オタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県丹生郡越前町打越', '18', '18423', '9160216', '福井県', 'フクイケン', '丹生郡越前町', 'ニュウグンエチゼンチョウ', '打越', 'ウチコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県丹生郡越前町丸山', '18', '18423', '9160217', '福井県', 'フクイケン', '丹生郡越前町', 'ニュウグンエチゼンチョウ', '丸山', 'マルヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県丹生郡越前町萩野', '18', '18423', '9160218', '福井県', 'フクイケン', '丹生郡越前町', 'ニュウグンエチゼンチョウ', '萩野', 'ハギノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県丹生郡越前町西ケ丘', '18', '18423', '9160219', '福井県', 'フクイケン', '丹生郡越前町', 'ニュウグンエチゼンチョウ', '西ケ丘', 'ニシガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県丹生郡越前町三崎', '18', '18423', '9160221', '福井県', 'フクイケン', '丹生郡越前町', 'ニュウグンエチゼンチョウ', '三崎', 'ミサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県丹生郡越前町大王丸', '18', '18423', '9160222', '福井県', 'フクイケン', '丹生郡越前町', 'ニュウグンエチゼンチョウ', '大王丸', 'ダイオウマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県丹生郡越前町下河原', '18', '18423', '9160223', '福井県', 'フクイケン', '丹生郡越前町', 'ニュウグンエチゼンチョウ', '下河原', 'シモガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県丹生郡越前町平等', '18', '18423', '9160224', '福井県', 'フクイケン', '丹生郡越前町', 'ニュウグンエチゼンチョウ', '平等', 'タイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県丹生郡越前町上山中', '18', '18423', '9160225', '福井県', 'フクイケン', '丹生郡越前町', 'ニュウグンエチゼンチョウ', '上山中', 'カミヤマナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県丹生郡越前町下山中', '18', '18423', '9160226', '福井県', 'フクイケン', '丹生郡越前町', 'ニュウグンエチゼンチョウ', '下山中', 'シモヤマナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県丹生郡越前町四ツ杉', '18', '18423', '9160227', '福井県', 'フクイケン', '丹生郡越前町', 'ニュウグンエチゼンチョウ', '四ツ杉', 'ヨツスギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県丹生郡越前町大谷', '18', '18423', '9160251', '福井県', 'フクイケン', '丹生郡越前町', 'ニュウグンエチゼンチョウ', '大谷', 'オオタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県丹生郡越前町蝉口', '18', '18423', '9160252', '福井県', 'フクイケン', '丹生郡越前町', 'ニュウグンエチゼンチョウ', '蝉口', 'セミグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県丹生郡越前町蚊谷寺', '18', '18423', '9160253', '福井県', 'フクイケン', '丹生郡越前町', 'ニュウグンエチゼンチョウ', '蚊谷寺', 'カダンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県丹生郡越前町広野', '18', '18423', '9160254', '福井県', 'フクイケン', '丹生郡越前町', 'ニュウグンエチゼンチョウ', '広野', 'ヒロノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県丹生郡越前町江波', '18', '18423', '9160255', '福井県', 'フクイケン', '丹生郡越前町', 'ニュウグンエチゼンチョウ', '江波', 'エナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県丹生郡越前町野', '18', '18423', '9160261', '福井県', 'フクイケン', '丹生郡越前町', 'ニュウグンエチゼンチョウ', '野', 'ノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県丹生郡越前町宇須尾', '18', '18423', '9160262', '福井県', 'フクイケン', '丹生郡越前町', 'ニュウグンエチゼンチョウ', '宇須尾', 'ウスオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県丹生郡越前町円満', '18', '18423', '9160263', '福井県', 'フクイケン', '丹生郡越前町', 'ニュウグンエチゼンチョウ', '円満', 'エンマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県丹生郡越前町八田', '18', '18423', '9160264', '福井県', 'フクイケン', '丹生郡越前町', 'ニュウグンエチゼンチョウ', '八田', 'ハッタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県丹生郡越前町八田新保', '18', '18423', '9160265', '福井県', 'フクイケン', '丹生郡越前町', 'ニュウグンエチゼンチョウ', '八田新保', 'ハッタシンボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県丹生郡越前町寺', '18', '18423', '9160266', '福井県', 'フクイケン', '丹生郡越前町', 'ニュウグンエチゼンチョウ', '寺', 'テラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県丹生郡越前町上野', '18', '18423', '9160267', '福井県', 'フクイケン', '丹生郡越前町', 'ニュウグンエチゼンチョウ', '上野', 'ウワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県丹生郡越前町陶の谷', '18', '18423', '9160268', '福井県', 'フクイケン', '丹生郡越前町', 'ニュウグンエチゼンチョウ', '陶の谷', 'スエノタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県丹生郡越前町舟場', '18', '18423', '9160271', '福井県', 'フクイケン', '丹生郡越前町', 'ニュウグンエチゼンチョウ', '舟場', 'フナバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県丹生郡越前町樫津', '18', '18423', '9160272', '福井県', 'フクイケン', '丹生郡越前町', 'ニュウグンエチゼンチョウ', '樫津', 'カシヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県丹生郡越前町小曽原', '18', '18423', '9160273', '福井県', 'フクイケン', '丹生郡越前町', 'ニュウグンエチゼンチョウ', '小曽原', 'オゾワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県丹生郡越前町増谷', '18', '18423', '9160274', '福井県', 'フクイケン', '丹生郡越前町', 'ニュウグンエチゼンチョウ', '増谷', 'マスタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県丹生郡越前町熊谷', '18', '18423', '9160275', '福井県', 'フクイケン', '丹生郡越前町', 'ニュウグンエチゼンチョウ', '熊谷', 'クマダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県丹生郡越前町古屋', '18', '18423', '9160276', '福井県', 'フクイケン', '丹生郡越前町', 'ニュウグンエチゼンチョウ', '古屋', 'フルヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県丹生郡越前町梨子ケ平', '18', '18423', '9160301', '福井県', 'フクイケン', '丹生郡越前町', 'ニュウグンエチゼンチョウ', '梨子ケ平', 'ナシガダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県丹生郡越前町左右', '18', '18423', '9160302', '福井県', 'フクイケン', '丹生郡越前町', 'ニュウグンエチゼンチョウ', '左右', 'ソウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県丹生郡越前町血ケ平', '18', '18423', '9160303', '福井県', 'フクイケン', '丹生郡越前町', 'ニュウグンエチゼンチョウ', '血ケ平', 'チガダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県丹生郡越前町玉川', '18', '18423', '9160304', '福井県', 'フクイケン', '丹生郡越前町', 'ニュウグンエチゼンチョウ', '玉川', 'タマガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県丹生郡越前町梅浦', '18', '18423', '9160311', '福井県', 'フクイケン', '丹生郡越前町', 'ニュウグンエチゼンチョウ', '梅浦', 'ウメウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県丹生郡越前町宿', '18', '18423', '9160312', '福井県', 'フクイケン', '丹生郡越前町', 'ニュウグンエチゼンチョウ', '宿', 'シュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県丹生郡越前町新保', '18', '18423', '9160313', '福井県', 'フクイケン', '丹生郡越前町', 'ニュウグンエチゼンチョウ', '新保', 'シンボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県丹生郡越前町城ケ谷', '18', '18423', '9160314', '福井県', 'フクイケン', '丹生郡越前町', 'ニュウグンエチゼンチョウ', '城ケ谷', 'ジョウガタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県丹生郡越前町小樟', '18', '18423', '9160315', '福井県', 'フクイケン', '丹生郡越前町', 'ニュウグンエチゼンチョウ', '小樟', 'ココノギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県丹生郡越前町大樟', '18', '18423', '9160316', '福井県', 'フクイケン', '丹生郡越前町', 'ニュウグンエチゼンチョウ', '大樟', 'オコノギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県丹生郡越前町道口', '18', '18423', '9160421', '福井県', 'フクイケン', '丹生郡越前町', 'ニュウグンエチゼンチョウ', '道口', 'ミチグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県丹生郡越前町厨', '18', '18423', '9160422', '福井県', 'フクイケン', '丹生郡越前町', 'ニュウグンエチゼンチョウ', '厨', 'クリヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県丹生郡越前町茂原', '18', '18423', '9160423', '福井県', 'フクイケン', '丹生郡越前町', 'ニュウグンエチゼンチョウ', '茂原', 'モハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県丹生郡越前町白浜', '18', '18423', '9160424', '福井県', 'フクイケン', '丹生郡越前町', 'ニュウグンエチゼンチョウ', '白浜', 'シラハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県丹生郡越前町高佐', '18', '18423', '9160425', '福井県', 'フクイケン', '丹生郡越前町', 'ニュウグンエチゼンチョウ', '高佐', 'タカサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県丹生郡越前町米ノ', '18', '18423', '9160426', '福井県', 'フクイケン', '丹生郡越前町', 'ニュウグンエチゼンチョウ', '米ノ', 'コメノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県丹生郡越前町六呂師', '18', '18423', '9160427', '福井県', 'フクイケン', '丹生郡越前町', 'ニュウグンエチゼンチョウ', '六呂師', 'ロクロシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県丹生郡越前町午房ケ平', '18', '18423', '9160428', '福井県', 'フクイケン', '丹生郡越前町', 'ニュウグンエチゼンチョウ', '午房ケ平', 'ゴボウガダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県鯖江市大正寺町', '18', '18207', '9161101', '福井県', 'フクイケン', '鯖江市', 'サバエシ', '大正寺町', 'ダイショウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県鯖江市大野町', '18', '18207', '9161102', '福井県', 'フクイケン', '鯖江市', 'サバエシ', '大野町', 'オオノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県鯖江市別所町', '18', '18207', '9161103', '福井県', 'フクイケン', '鯖江市', 'サバエシ', '別所町', 'ベッショチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県鯖江市乙坂今北町', '18', '18207', '9161104', '福井県', 'フクイケン', '鯖江市', 'サバエシ', '乙坂今北町', 'オツサカコンボクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県鯖江市吉谷町', '18', '18207', '9161105', '福井県', 'フクイケン', '鯖江市', 'サバエシ', '吉谷町', 'ヨシタニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県鯖江市四方谷町', '18', '18207', '9161106', '福井県', 'フクイケン', '鯖江市', 'サバエシ', '四方谷町', 'シホウダニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県鯖江市南井町', '18', '18207', '9161107', '福井県', 'フクイケン', '鯖江市', 'サバエシ', '南井町', 'ナオイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県鯖江市上戸口町', '18', '18207', '9161111', '福井県', 'フクイケン', '鯖江市', 'サバエシ', '上戸口町', 'カミトノクチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県鯖江市中戸口町', '18', '18207', '9161112', '福井県', 'フクイケン', '鯖江市', 'サバエシ', '中戸口町', 'ナカトノクチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県鯖江市戸口町', '18', '18207', '9161113', '福井県', 'フクイケン', '鯖江市', 'サバエシ', '戸口町', 'トノクチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県鯖江市磯部町', '18', '18207', '9161114', '福井県', 'フクイケン', '鯖江市', 'サバエシ', '磯部町', 'イソベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県鯖江市落井町', '18', '18207', '9161115', '福井県', 'フクイケン', '鯖江市', 'サバエシ', '落井町', 'オチイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県鯖江市川島町', '18', '18207', '9161116', '福井県', 'フクイケン', '鯖江市', 'サバエシ', '川島町', 'カワシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県鯖江市松成町', '18', '18207', '9161118', '福井県', 'フクイケン', '鯖江市', 'サバエシ', '松成町', 'マツナリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県鯖江市中野松成', '18', '18207', '9161133', '福井県', 'フクイケン', '鯖江市', 'サバエシ', '中野松成', 'ナカノマツナリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県鯖江市西袋町', '18', '18207', '9161221', '福井県', 'フクイケン', '鯖江市', 'サバエシ', '西袋町', 'ニシブクロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県鯖江市河和田町', '18', '18207', '9161222', '福井県', 'フクイケン', '鯖江市', 'サバエシ', '河和田町', 'カワダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県鯖江市片山町', '18', '18207', '9161223', '福井県', 'フクイケン', '鯖江市', 'サバエシ', '片山町', 'カタヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県鯖江市莇生田町', '18', '18207', '9161224', '福井県', 'フクイケン', '鯖江市', 'サバエシ', '莇生田町', 'アゾウダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県鯖江市別司町', '18', '18207', '9161225', '福井県', 'フクイケン', '鯖江市', 'サバエシ', '別司町', 'ベッシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県鯖江市金谷町', '18', '18207', '9161231', '福井県', 'フクイケン', '鯖江市', 'サバエシ', '金谷町', 'カナダニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県鯖江市寺中町', '18', '18207', '9161232', '福井県', 'フクイケン', '鯖江市', 'サバエシ', '寺中町', 'ジチュウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県鯖江市尾花町', '18', '18207', '9161233', '福井県', 'フクイケン', '鯖江市', 'サバエシ', '尾花町', 'オバナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県鯖江市沢町', '18', '18207', '9161234', '福井県', 'フクイケン', '鯖江市', 'サバエシ', '沢町', 'サワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県鯖江市上河内町', '18', '18207', '9161235', '福井県', 'フクイケン', '鯖江市', 'サバエシ', '上河内町', 'カミコウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県鯖江市東清水町', '18', '18207', '9161236', '福井県', 'フクイケン', '鯖江市', 'サバエシ', '東清水町', 'ヒガシシミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県鯖江市北中町', '18', '18207', '9161237', '福井県', 'フクイケン', '鯖江市', 'サバエシ', '北中町', 'キタナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市', '18', '18204', '9170000', '福井県', 'フクイケン', '小浜市', 'オバマシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('121713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市福谷', '18', '18204', '9170001', '福井県', 'フクイケン', '小浜市', 'オバマシ', '福谷', 'フクタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市北塩屋', '18', '18204', '9170002', '福井県', 'フクイケン', '小浜市', 'オバマシ', '北塩屋', 'キタシオヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市北長町', '18', '18204', '9170002', '福井県', 'フクイケン', '小浜市', 'オバマシ', '北長町', 'キタナガマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市学園町', '18', '18204', '9170003', '福井県', 'フクイケン', '小浜市', 'オバマシ', '学園町', 'ガクエンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市大湊', '18', '18204', '9170004', '福井県', 'フクイケン', '小浜市', 'オバマシ', '大湊', 'オオミナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市小湊', '18', '18204', '9170004', '福井県', 'フクイケン', '小浜市', 'オバマシ', '小湊', 'コミナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市湊', '18', '18204', '9170004', '福井県', 'フクイケン', '小浜市', 'オバマシ', '湊', 'ミナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市板屋町', '18', '18204', '9170005', '福井県', 'フクイケン', '小浜市', 'オバマシ', '板屋町', 'イタヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市小松原', '18', '18204', '9170006', '福井県', 'フクイケン', '小浜市', 'オバマシ', '小松原', 'コマツバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市下竹原', '18', '18204', '9170007', '福井県', 'フクイケン', '小浜市', 'オバマシ', '下竹原', 'シモダワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市西長町', '18', '18204', '9170007', '福井県', 'フクイケン', '小浜市', 'オバマシ', '西長町', 'ニシナガマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市新小松原', '18', '18204', '9170008', '福井県', 'フクイケン', '小浜市', 'オバマシ', '新小松原', 'シンコマツバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市奈胡', '18', '18204', '9170011', '福井県', 'フクイケン', '小浜市', 'オバマシ', '奈胡', 'ナゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市熊野', '18', '18204', '9170012', '福井県', 'フクイケン', '小浜市', 'オバマシ', '熊野', 'クマノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市太良庄', '18', '18204', '9170013', '福井県', 'フクイケン', '小浜市', 'オバマシ', '太良庄', 'タラノショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市北川', '18', '18204', '9170014', '福井県', 'フクイケン', '小浜市', 'オバマシ', '北川', 'キタガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市高塚', '18', '18204', '9170014', '福井県', 'フクイケン', '小浜市', 'オバマシ', '高塚', 'タカツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市栗田', '18', '18204', '9170015', '福井県', 'フクイケン', '小浜市', 'オバマシ', '栗田', 'クリタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市次吉', '18', '18204', '9170016', '福井県', 'フクイケン', '小浜市', 'オバマシ', '次吉', 'ツギヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市江古川', '18', '18204', '9170017', '福井県', 'フクイケン', '小浜市', 'オバマシ', '江古川', 'エゴガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市羽賀', '18', '18204', '9170017', '福井県', 'フクイケン', '小浜市', 'オバマシ', '羽賀', 'ハガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市松ケ崎', '18', '18204', '9170018', '福井県', 'フクイケン', '小浜市', 'オバマシ', '松ケ崎', 'マツガサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市山王前', '18', '18204', '9170019', '福井県', 'フクイケン', '小浜市', 'オバマシ', '山王前', 'サンノウマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市関', '18', '18204', '9170021', '福井県', 'フクイケン', '小浜市', 'オバマシ', '関', 'セキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市竹原', '18', '18204', '9170021', '福井県', 'フクイケン', '小浜市', 'オバマシ', '竹原', 'タワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市上竹原', '18', '18204', '9170022', '福井県', 'フクイケン', '小浜市', 'オバマシ', '上竹原', 'カミタワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市府中', '18', '18204', '9170023', '福井県', 'フクイケン', '小浜市', 'オバマシ', '府中', 'フチュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市和久里', '18', '18204', '9170024', '福井県', 'フクイケン', '小浜市', 'オバマシ', '和久里', 'ワクリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市木崎', '18', '18204', '9170025', '福井県', 'フクイケン', '小浜市', 'オバマシ', '木崎', 'キザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市多田', '18', '18204', '9170026', '福井県', 'フクイケン', '小浜市', 'オバマシ', '多田', 'タダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市生守', '18', '18204', '9170027', '福井県', 'フクイケン', '小浜市', 'オバマシ', '生守', 'イゴモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市生守団地', '18', '18204', '9170027', '福井県', 'フクイケン', '小浜市', 'オバマシ', '生守団地', 'イゴモリダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市野代', '18', '18204', '9170028', '福井県', 'フクイケン', '小浜市', 'オバマシ', '野代', 'ノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市谷田部', '18', '18204', '9170031', '福井県', 'フクイケン', '小浜市', 'オバマシ', '谷田部', 'ヤタベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市尾崎', '18', '18204', '9170032', '福井県', 'フクイケン', '小浜市', 'オバマシ', '尾崎', 'オザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市須縄', '18', '18204', '9170033', '福井県', 'フクイケン', '小浜市', 'オバマシ', '須縄', 'スノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市奥田縄', '18', '18204', '9170034', '福井県', 'フクイケン', '小浜市', 'オバマシ', '奥田縄', 'オクダノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市口田縄', '18', '18204', '9170035', '福井県', 'フクイケン', '小浜市', 'オバマシ', '口田縄', 'クチダノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市上中井', '18', '18204', '9170036', '福井県', 'フクイケン', '小浜市', 'オバマシ', '上中井', 'カミナカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市下中井', '18', '18204', '9170036', '福井県', 'フクイケン', '小浜市', 'オバマシ', '下中井', 'シモナカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市新滝', '18', '18204', '9170036', '福井県', 'フクイケン', '小浜市', 'オバマシ', '新滝', 'シンタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市滝谷', '18', '18204', '9170036', '福井県', 'フクイケン', '小浜市', 'オバマシ', '滝谷', 'タキダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市中井', '18', '18204', '9170036', '福井県', 'フクイケン', '小浜市', 'オバマシ', '中井', 'ナカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市相生', '18', '18204', '9170037', '福井県', 'フクイケン', '小浜市', 'オバマシ', '相生', 'アイオイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市西相生', '18', '18204', '9170037', '福井県', 'フクイケン', '小浜市', 'オバマシ', '西相生', 'ニシアイオイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市東相生', '18', '18204', '9170037', '福井県', 'フクイケン', '小浜市', 'オバマシ', '東相生', 'ヒガシアイオイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市青井', '18', '18204', '9170041', '福井県', 'フクイケン', '小浜市', 'オバマシ', '青井', 'アオイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市東勢', '18', '18204', '9170042', '福井県', 'フクイケン', '小浜市', 'オバマシ', '東勢', 'ヒガシセイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市西勢', '18', '18204', '9170043', '福井県', 'フクイケン', '小浜市', 'オバマシ', '西勢', 'ニシセイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市荒木', '18', '18204', '9170044', '福井県', 'フクイケン', '小浜市', 'オバマシ', '荒木', 'アラキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市黒駒', '18', '18204', '9170044', '福井県', 'フクイケン', '小浜市', 'オバマシ', '黒駒', 'クロコマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市法海', '18', '18204', '9170044', '福井県', 'フクイケン', '小浜市', 'オバマシ', '法海', 'ノリカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市飯盛', '18', '18204', '9170044', '福井県', 'フクイケン', '小浜市', 'オバマシ', '飯盛', 'ハンセイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市加斗', '18', '18204', '9170045', '福井県', 'フクイケン', '小浜市', 'オバマシ', '加斗', 'カド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市上加斗', '18', '18204', '9170045', '福井県', 'フクイケン', '小浜市', 'オバマシ', '上加斗', 'カミカド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市下加斗', '18', '18204', '9170045', '福井県', 'フクイケン', '小浜市', 'オバマシ', '下加斗', 'シモカド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市岡津', '18', '18204', '9170046', '福井県', 'フクイケン', '小浜市', 'オバマシ', '岡津', 'オコヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市鯉川', '18', '18204', '9170047', '福井県', 'フクイケン', '小浜市', 'オバマシ', '鯉川', 'コイガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市小浜白鳥', '18', '18204', '9170051', '福井県', 'フクイケン', '小浜市', 'オバマシ', '小浜白鳥', 'オバマシラトリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市小浜男山', '18', '18204', '9170052', '福井県', 'フクイケン', '小浜市', 'オバマシ', '小浜男山', 'オバマオトコヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市小浜大宮', '18', '18204', '9170053', '福井県', 'フクイケン', '小浜市', 'オバマシ', '小浜大宮', 'オバマオオミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市伏原', '18', '18204', '9170054', '福井県', 'フクイケン', '小浜市', 'オバマシ', '伏原', 'フシワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市小浜浅間', '18', '18204', '9170055', '福井県', 'フクイケン', '小浜市', 'オバマシ', '小浜浅間', 'オバマアサマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市小浜大原', '18', '18204', '9170056', '福井県', 'フクイケン', '小浜市', 'オバマシ', '小浜大原', 'オバマオオハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市小浜飛鳥', '18', '18204', '9170057', '福井県', 'フクイケン', '小浜市', 'オバマシ', '小浜飛鳥', 'オバマアスカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市小浜香取', '18', '18204', '9170058', '福井県', 'フクイケン', '小浜市', 'オバマシ', '小浜香取', 'オバマカトリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市小浜貴船', '18', '18204', '9170059', '福井県', 'フクイケン', '小浜市', 'オバマシ', '小浜貴船', 'オバマキフネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市小浜玉前', '18', '18204', '9170061', '福井県', 'フクイケン', '小浜市', 'オバマシ', '小浜玉前', 'オバマタママエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市小浜今宮', '18', '18204', '9170062', '福井県', 'フクイケン', '小浜市', 'オバマシ', '小浜今宮', 'オバマイマミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市小浜酒井', '18', '18204', '9170063', '福井県', 'フクイケン', '小浜市', 'オバマシ', '小浜酒井', 'オバマサカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市小浜竜田', '18', '18204', '9170064', '福井県', 'フクイケン', '小浜市', 'オバマシ', '小浜竜田', 'オバマタツタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市小浜住吉', '18', '18204', '9170065', '福井県', 'フクイケン', '小浜市', 'オバマシ', '小浜住吉', 'オバマスミヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市小浜神田', '18', '18204', '9170066', '福井県', 'フクイケン', '小浜市', 'オバマシ', '小浜神田', 'オバマカンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市小浜鹿島', '18', '18204', '9170067', '福井県', 'フクイケン', '小浜市', 'オバマシ', '小浜鹿島', 'オバマカシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市小浜日吉', '18', '18204', '9170068', '福井県', 'フクイケン', '小浜市', 'オバマシ', '小浜日吉', 'オバマヒヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市小浜白鬚', '18', '18204', '9170069', '福井県', 'フクイケン', '小浜市', 'オバマシ', '小浜白鬚', 'オバマシラヒゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市一番町', '18', '18204', '9170071', '福井県', 'フクイケン', '小浜市', 'オバマシ', '一番町', 'イチバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市千種', '18', '18204', '9170072', '福井県', 'フクイケン', '小浜市', 'オバマシ', '千種', 'チグサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市四谷町', '18', '18204', '9170073', '福井県', 'フクイケン', '小浜市', 'オバマシ', '四谷町', 'ヨツヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市後瀬町', '18', '18204', '9170074', '福井県', 'フクイケン', '小浜市', 'オバマシ', '後瀬町', 'ノチセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市南川町', '18', '18204', '9170075', '福井県', 'フクイケン', '小浜市', 'オバマシ', '南川町', 'ミナミガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市湯岡', '18', '18204', '9170076', '福井県', 'フクイケン', '小浜市', 'オバマシ', '湯岡', 'ユノオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市駅前町', '18', '18204', '9170077', '福井県', 'フクイケン', '小浜市', 'オバマシ', '駅前町', 'エキマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市大手町', '18', '18204', '9170078', '福井県', 'フクイケン', '小浜市', 'オバマシ', '大手町', 'オオテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市川崎', '18', '18204', '9170081', '福井県', 'フクイケン', '小浜市', 'オバマシ', '川崎', 'カワサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市小浜津島', '18', '18204', '9170082', '福井県', 'フクイケン', '小浜市', 'オバマシ', '小浜津島', 'オバマツシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市小浜清滝', '18', '18204', '9170083', '福井県', 'フクイケン', '小浜市', 'オバマシ', '小浜清滝', 'オバマキヨタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市小浜広峰', '18', '18204', '9170084', '福井県', 'フクイケン', '小浜市', 'オバマシ', '小浜広峰', 'オバマヒロミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市小浜生玉', '18', '18204', '9170085', '福井県', 'フクイケン', '小浜市', 'オバマシ', '小浜生玉', 'オバマイクダマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市小浜塩竈', '18', '18204', '9170086', '福井県', 'フクイケン', '小浜市', 'オバマシ', '小浜塩竈', 'オバマシオガマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市小浜鈴鹿', '18', '18204', '9170087', '福井県', 'フクイケン', '小浜市', 'オバマシ', '小浜鈴鹿', 'オバマスズカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市小浜多賀', '18', '18204', '9170088', '福井県', 'フクイケン', '小浜市', 'オバマシ', '小浜多賀', 'オバマタガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市西津', '18', '18204', '9170091', '福井県', 'フクイケン', '小浜市', 'オバマシ', '西津', 'ニシヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市山手', '18', '18204', '9170092', '福井県', 'フクイケン', '小浜市', 'オバマシ', '山手', 'ヤマテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市水取', '18', '18204', '9170093', '福井県', 'フクイケン', '小浜市', 'オバマシ', '水取', 'ミズトリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市丸山', '18', '18204', '9170094', '福井県', 'フクイケン', '小浜市', 'オバマシ', '丸山', 'マルヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市城内', '18', '18204', '9170095', '福井県', 'フクイケン', '小浜市', 'オバマシ', '城内', 'ジョウナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市雲浜', '18', '18204', '9170096', '福井県', 'フクイケン', '小浜市', 'オバマシ', '雲浜', 'ウンピン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市堀屋敷', '18', '18204', '9170097', '福井県', 'フクイケン', '小浜市', 'オバマシ', '堀屋敷', 'ホリヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市田烏', '18', '18204', '9170101', '福井県', 'フクイケン', '小浜市', 'オバマシ', '田烏', 'タガラス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市矢代', '18', '18204', '9170102', '福井県', 'フクイケン', '小浜市', 'オバマシ', '矢代', 'ヤシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市志積', '18', '18204', '9170103', '福井県', 'フクイケン', '小浜市', 'オバマシ', '志積', 'シツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市犬熊', '18', '18204', '9170104', '福井県', 'フクイケン', '小浜市', 'オバマシ', '犬熊', 'イノクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市阿納', '18', '18204', '9170105', '福井県', 'フクイケン', '小浜市', 'オバマシ', '阿納', 'アノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市阿納尻', '18', '18204', '9170106', '福井県', 'フクイケン', '小浜市', 'オバマシ', '阿納尻', 'アノジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市甲ケ崎', '18', '18204', '9170107', '福井県', 'フクイケン', '小浜市', 'オバマシ', '甲ケ崎', 'コガサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市西小川', '18', '18204', '9170111', '福井県', 'フクイケン', '小浜市', 'オバマシ', '西小川', 'ニシオガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市加尾', '18', '18204', '9170112', '福井県', 'フクイケン', '小浜市', 'オバマシ', '加尾', 'カオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市宇久', '18', '18204', '9170113', '福井県', 'フクイケン', '小浜市', 'オバマシ', '宇久', 'ウグ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市若狭', '18', '18204', '9170114', '福井県', 'フクイケン', '小浜市', 'オバマシ', '若狭', 'ワカサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市仏谷', '18', '18204', '9170115', '福井県', 'フクイケン', '小浜市', 'オバマシ', '仏谷', 'ホトケダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市堅海', '18', '18204', '9170116', '福井県', 'フクイケン', '小浜市', 'オバマシ', '堅海', 'カツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市泊', '18', '18204', '9170117', '福井県', 'フクイケン', '小浜市', 'オバマシ', '泊', 'トマリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市大谷', '18', '18204', '9170221', '福井県', 'フクイケン', '小浜市', 'オバマシ', '大谷', 'オオタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市新保', '18', '18204', '9170222', '福井県', 'フクイケン', '小浜市', 'オバマシ', '新保', 'シンボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市大戸', '18', '18204', '9170223', '福井県', 'フクイケン', '小浜市', 'オバマシ', '大戸', 'オオド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市加茂', '18', '18204', '9170223', '福井県', 'フクイケン', '小浜市', 'オバマシ', '加茂', 'カモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市竹長', '18', '18204', '9170224', '福井県', 'フクイケン', '小浜市', 'オバマシ', '竹長', 'タケナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市本保', '18', '18204', '9170225', '福井県', 'フクイケン', '小浜市', 'オバマシ', '本保', 'ホンボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市平野', '18', '18204', '9170226', '福井県', 'フクイケン', '小浜市', 'オバマシ', '平野', 'ヒラノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市国分', '18', '18204', '9170231', '福井県', 'フクイケン', '小浜市', 'オバマシ', '国分', 'コクブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市東市場', '18', '18204', '9170232', '福井県', 'フクイケン', '小浜市', 'オバマシ', '東市場', 'トイチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市太興寺', '18', '18204', '9170233', '福井県', 'フクイケン', '小浜市', 'オバマシ', '太興寺', 'タイコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市上野', '18', '18204', '9170234', '福井県', 'フクイケン', '小浜市', 'オバマシ', '上野', 'ウエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市四分一', '18', '18204', '9170235', '福井県', 'フクイケン', '小浜市', 'オバマシ', '四分一', 'シブイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市三分一', '18', '18204', '9170236', '福井県', 'フクイケン', '小浜市', 'オバマシ', '三分一', 'サンブイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市門前', '18', '18204', '9170237', '福井県', 'フクイケン', '小浜市', 'オバマシ', '門前', 'モンゼン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市池河内', '18', '18204', '9170238', '福井県', 'フクイケン', '小浜市', 'オバマシ', '池河内', 'イケノコウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市池田', '18', '18204', '9170241', '福井県', 'フクイケン', '小浜市', 'オバマシ', '池田', 'イケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市市場', '18', '18204', '9170241', '福井県', 'フクイケン', '小浜市', 'オバマシ', '市場', 'イチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市遠敷', '18', '18204', '9170241', '福井県', 'フクイケン', '小浜市', 'オバマシ', '遠敷', 'オニュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市検見坂', '18', '18204', '9170241', '福井県', 'フクイケン', '小浜市', 'オバマシ', '検見坂', 'ケンミザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市島', '18', '18204', '9170241', '福井県', 'フクイケン', '小浜市', 'オバマシ', '島', 'シマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市中村', '18', '18204', '9170241', '福井県', 'フクイケン', '小浜市', 'オバマシ', '中村', 'ナカムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市金屋', '18', '18204', '9170242', '福井県', 'フクイケン', '小浜市', 'オバマシ', '金屋', 'カナヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市中の宮', '18', '18204', '9170242', '福井県', 'フクイケン', '小浜市', 'オバマシ', '中の宮', 'ナカノミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市竜前', '18', '18204', '9170243', '福井県', 'フクイケン', '小浜市', 'オバマシ', '竜前', 'リュウゼン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市神宮寺', '18', '18204', '9170244', '福井県', 'フクイケン', '小浜市', 'オバマシ', '神宮寺', 'ジングウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市忠野', '18', '18204', '9170245', '福井県', 'フクイケン', '小浜市', 'オバマシ', '忠野', 'チュウノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市下根来', '18', '18204', '9170246', '福井県', 'フクイケン', '小浜市', 'オバマシ', '下根来', 'シモネゴリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市中ノ畑', '18', '18204', '9170247', '福井県', 'フクイケン', '小浜市', 'オバマシ', '中ノ畑', 'ナカノハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市上根来', '18', '18204', '9170248', '福井県', 'フクイケン', '小浜市', 'オバマシ', '上根来', 'カミネゴリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市宮の前', '18', '18204', '9170249', '福井県', 'フクイケン', '小浜市', 'オバマシ', '宮の前', 'ミヤノマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市田茂谷', '18', '18204', '9170351', '福井県', 'フクイケン', '小浜市', 'オバマシ', '田茂谷', 'タモタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市深谷', '18', '18204', '9170352', '福井県', 'フクイケン', '小浜市', 'オバマシ', '深谷', 'フカタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市深野', '18', '18204', '9170353', '福井県', 'フクイケン', '小浜市', 'オバマシ', '深野', 'フカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市和多田', '18', '18204', '9170354', '福井県', 'フクイケン', '小浜市', 'オバマシ', '和多田', 'ワダタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市下田', '18', '18204', '9170355', '福井県', 'フクイケン', '小浜市', 'オバマシ', '下田', 'シモタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市上田', '18', '18204', '9170356', '福井県', 'フクイケン', '小浜市', 'オバマシ', '上田', 'カミタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県小浜市小屋', '18', '18204', '9170357', '福井県', 'フクイケン', '小浜市', 'オバマシ', '小屋', 'オヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大飯郡おおい町名田庄挙原', '18', '18483', '9170361', '福井県', 'フクイケン', '大飯郡おおい町', 'オオイグンオオイチョウ', '名田庄挙原', 'ナタショウアゲハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大飯郡おおい町名田庄木谷', '18', '18483', '9170361', '福井県', 'フクイケン', '大飯郡おおい町', 'オオイグンオオイチョウ', '名田庄木谷', 'ナタショウキダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大飯郡おおい町名田庄出合', '18', '18483', '9170361', '福井県', 'フクイケン', '大飯郡おおい町', 'オオイグンオオイチョウ', '名田庄出合', 'ナタショウデアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大飯郡おおい町名田庄虫谷', '18', '18483', '9170361', '福井県', 'フクイケン', '大飯郡おおい町', 'オオイグンオオイチョウ', '名田庄虫谷', 'ナタショウムシダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大飯郡おおい町名田庄永谷', '18', '18483', '9170362', '福井県', 'フクイケン', '大飯郡おおい町', 'オオイグンオオイチョウ', '名田庄永谷', 'ナタショウナガタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大飯郡おおい町名田庄挙野', '18', '18483', '9170363', '福井県', 'フクイケン', '大飯郡おおい町', 'オオイグンオオイチョウ', '名田庄挙野', 'ナタショウアゲノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大飯郡おおい町名田庄虫鹿野', '18', '18483', '9170364', '福井県', 'フクイケン', '大飯郡おおい町', 'オオイグンオオイチョウ', '名田庄虫鹿野', 'ナタショウムシガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大飯郡おおい町名田庄小倉畑', '18', '18483', '9170365', '福井県', 'フクイケン', '大飯郡おおい町', 'オオイグンオオイチョウ', '名田庄小倉畑', 'ナタショウオグラハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大飯郡おおい町名田庄小倉', '18', '18483', '9170371', '福井県', 'フクイケン', '大飯郡おおい町', 'オオイグンオオイチョウ', '名田庄小倉', 'ナタショウオグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大飯郡おおい町名田庄堂本', '18', '18483', '9170372', '福井県', 'フクイケン', '大飯郡おおい町', 'オオイグンオオイチョウ', '名田庄堂本', 'ナタショウドウモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大飯郡おおい町名田庄染ケ谷', '18', '18483', '9170373', '福井県', 'フクイケン', '大飯郡おおい町', 'オオイグンオオイチョウ', '名田庄染ケ谷', 'ナタショウソメガタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大飯郡おおい町名田庄槇谷', '18', '18483', '9170373', '福井県', 'フクイケン', '大飯郡おおい町', 'オオイグンオオイチョウ', '名田庄槇谷', 'ナタショウマキダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大飯郡おおい町名田庄中', '18', '18483', '9170374', '福井県', 'フクイケン', '大飯郡おおい町', 'オオイグンオオイチョウ', '名田庄中', 'ナタショウナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大飯郡おおい町名田庄納田終', '18', '18483', '9170375', '福井県', 'フクイケン', '大飯郡おおい町', 'オオイグンオオイチョウ', '名田庄納田終', 'ナタショウノタオイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大飯郡おおい町名田庄三重', '18', '18483', '9170381', '福井県', 'フクイケン', '大飯郡おおい町', 'オオイグンオオイチョウ', '名田庄三重', 'ナタショウミエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大飯郡おおい町名田庄久坂', '18', '18483', '9170382', '福井県', 'フクイケン', '大飯郡おおい町', 'オオイグンオオイチョウ', '名田庄久坂', 'ナタショウヒササカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大飯郡おおい町名田庄下', '18', '18483', '9170383', '福井県', 'フクイケン', '大飯郡おおい町', 'オオイグンオオイチョウ', '名田庄下', 'ナタショウシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大飯郡おおい町名田庄西谷', '18', '18483', '9170384', '福井県', 'フクイケン', '大飯郡おおい町', 'オオイグンオオイチョウ', '名田庄西谷', 'ナタショウニシダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大飯郡おおい町名田庄井上', '18', '18483', '9170385', '福井県', 'フクイケン', '大飯郡おおい町', 'オオイグンオオイチョウ', '名田庄井上', 'ナタショウイガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大飯郡おおい町名田庄口坂本', '18', '18483', '9170386', '福井県', 'フクイケン', '大飯郡おおい町', 'オオイグンオオイチョウ', '名田庄口坂本', 'ナタショウクチサカモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大飯郡おおい町名田庄奥坂本', '18', '18483', '9170387', '福井県', 'フクイケン', '大飯郡おおい町', 'オオイグンオオイチョウ', '名田庄奥坂本', 'ナタショウオクサカモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市', '18', '18201', '9180000', '福井県', 'フクイケン', '福井市', 'フクイシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('121912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市つくも', '18', '18201', '9188001', '福井県', 'フクイケン', '福井市', 'フクイシ', 'つくも', 'ツクモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市左内町', '18', '18201', '9188002', '福井県', 'フクイケン', '福井市', 'フクイシ', '左内町', 'サナイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市毛矢', '18', '18201', '9188003', '福井県', 'フクイケン', '福井市', 'フクイシ', '毛矢', 'ケヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市西木田', '18', '18201', '9188004', '福井県', 'フクイケン', '福井市', 'フクイシ', '西木田', 'ニシキダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市みのり', '18', '18201', '9188005', '福井県', 'フクイケン', '福井市', 'フクイシ', 'みのり', 'ミノリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市足羽上町', '18', '18201', '9188006', '福井県', 'フクイケン', '福井市', 'フクイシ', '足羽上町', 'アスワカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市足羽', '18', '18201', '9188007', '福井県', 'フクイケン', '福井市', 'フクイシ', '足羽', 'アスワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市有楽町', '18', '18201', '9188008', '福井県', 'フクイケン', '福井市', 'フクイシ', '有楽町', 'ユウラクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市山奥町', '18', '18201', '9188009', '福井県', 'フクイケン', '福井市', 'フクイシ', '山奥町', 'ヤマオクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市月見', '18', '18201', '9188011', '福井県', 'フクイケン', '福井市', 'フクイシ', '月見', 'ツキミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市花堂北', '18', '18201', '9188012', '福井県', 'フクイケン', '福井市', 'フクイシ', '花堂北', 'ハナンドウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市花堂東', '18', '18201', '9188013', '福井県', 'フクイケン', '福井市', 'フクイシ', '花堂東', 'ハナンドウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市花堂中', '18', '18201', '9188014', '福井県', 'フクイケン', '福井市', 'フクイシ', '花堂中', 'ハナンドウナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市花堂南', '18', '18201', '9188015', '福井県', 'フクイケン', '福井市', 'フクイシ', '花堂南', 'ハナンドウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市江端町', '18', '18201', '9188016', '福井県', 'フクイケン', '福井市', 'フクイシ', '江端町', 'エバタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市下荒井町', '18', '18201', '9188017', '福井県', 'フクイケン', '福井市', 'フクイシ', '下荒井町', 'シモアライチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市大島町', '18', '18201', '9188018', '福井県', 'フクイケン', '福井市', 'フクイシ', '大島町', 'オオシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市門前', '18', '18201', '9188021', '福井県', 'フクイケン', '福井市', 'フクイシ', '門前', 'モンゼン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市門前町', '18', '18201', '9188021', '福井県', 'フクイケン', '福井市', 'フクイシ', '門前町', 'モンゼンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市西谷町', '18', '18201', '9188022', '福井県', 'フクイケン', '福井市', 'フクイシ', '西谷町', 'ニシタニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市西谷', '18', '18201', '9188023', '福井県', 'フクイケン', '福井市', 'フクイシ', '西谷', 'ニシタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市舞屋町', '18', '18201', '9188024', '福井県', 'フクイケン', '福井市', 'フクイシ', '舞屋町', 'マイヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市江守中', '18', '18201', '9188025', '福井県', 'フクイケン', '福井市', 'フクイシ', '江守中', 'エモリナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市江守中町', '18', '18201', '9188025', '福井県', 'フクイケン', '福井市', 'フクイシ', '江守中町', 'エモリナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市渕', '18', '18201', '9188026', '福井県', 'フクイケン', '福井市', 'フクイシ', '渕', 'フチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市渕町', '18', '18201', '9188026', '福井県', 'フクイケン', '福井市', 'フクイシ', '渕町', 'フチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市福', '18', '18201', '9188027', '福井県', 'フクイケン', '福井市', 'フクイシ', '福', 'フク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市福町', '18', '18201', '9188027', '福井県', 'フクイケン', '福井市', 'フクイシ', '福町', 'フクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市種池', '18', '18201', '9188031', '福井県', 'フクイケン', '福井市', 'フクイシ', '種池', 'タナイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市種池町', '18', '18201', '9188031', '福井県', 'フクイケン', '福井市', 'フクイシ', '種池町', 'タナイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市南江守町', '18', '18201', '9188032', '福井県', 'フクイケン', '福井市', 'フクイシ', '南江守町', 'ミナミエモリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市合谷町', '18', '18201', '9188033', '福井県', 'フクイケン', '福井市', 'フクイシ', '合谷町', 'ゴウダニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市南居町', '18', '18201', '9188034', '福井県', 'フクイケン', '福井市', 'フクイシ', '南居町', 'ナゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市江守の里', '18', '18201', '9188035', '福井県', 'フクイケン', '福井市', 'フクイシ', '江守の里', 'エモリノサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市新下江守町', '18', '18201', '9188036', '福井県', 'フクイケン', '福井市', 'フクイシ', '新下江守町', 'シンシモエモリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市下江守町', '18', '18201', '9188037', '福井県', 'フクイケン', '福井市', 'フクイシ', '下江守町', 'シモエモリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市西下野町', '18', '18201', '9188041', '福井県', 'フクイケン', '福井市', 'フクイシ', '西下野町', 'ニシシモノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市東下野町', '18', '18201', '9188042', '福井県', 'フクイケン', '福井市', 'フクイシ', '東下野町', 'ヒガシシモノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市狐橋', '18', '18201', '9188043', '福井県', 'フクイケン', '福井市', 'フクイシ', '狐橋', 'キツネバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市高塚町', '18', '18201', '9188044', '福井県', 'フクイケン', '福井市', 'フクイシ', '高塚町', 'タカツカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市福新町', '18', '18201', '9188045', '福井県', 'フクイケン', '福井市', 'フクイシ', '福新町', 'フクシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市運動公園', '18', '18201', '9188046', '福井県', 'フクイケン', '福井市', 'フクイシ', '運動公園', 'ウンドウコウエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市久喜津町', '18', '18201', '9188047', '福井県', 'フクイケン', '福井市', 'フクイシ', '久喜津町', 'クキヅチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市桃園', '18', '18201', '9188051', '福井県', 'フクイケン', '福井市', 'フクイシ', '桃園', 'モモゾノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市明里町', '18', '18201', '9188052', '福井県', 'フクイケン', '福井市', 'フクイシ', '明里町', 'アカリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市小山谷町', '18', '18201', '9188053', '福井県', 'フクイケン', '福井市', 'フクイシ', '小山谷町', 'オヤマダニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市加茂河原町', '18', '18201', '9188054', '福井県', 'フクイケン', '福井市', 'フクイシ', '加茂河原町', 'カモガワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市若杉', '18', '18201', '9188055', '福井県', 'フクイケン', '福井市', 'フクイシ', '若杉', 'ワカスギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市若杉町', '18', '18201', '9188055', '福井県', 'フクイケン', '福井市', 'フクイシ', '若杉町', 'ワカスギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市若杉浜', '18', '18201', '9188056', '福井県', 'フクイケン', '福井市', 'フクイシ', '若杉浜', 'ワカスギハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市加茂河原', '18', '18201', '9188057', '福井県', 'フクイケン', '福井市', 'フクイシ', '加茂河原', 'カモガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市加茂緑苑町', '18', '18201', '9188058', '福井県', 'フクイケン', '福井市', 'フクイシ', '加茂緑苑町', 'カモリョクエンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市金屋町', '18', '18201', '9188061', '福井県', 'フクイケン', '福井市', 'フクイシ', '金屋町', 'カナヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市下市町', '18', '18201', '9188062', '福井県', 'フクイケン', '福井市', 'フクイシ', '下市町', 'シモイチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市大瀬町', '18', '18201', '9188063', '福井県', 'フクイケン', '福井市', 'フクイシ', '大瀬町', 'オオセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市西学園', '18', '18201', '9188064', '福井県', 'フクイケン', '福井市', 'フクイシ', '西学園', 'ニシガクエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市水越', '18', '18201', '9188065', '福井県', 'フクイケン', '福井市', 'フクイシ', '水越', 'ミズコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市渡町', '18', '18201', '9188066', '福井県', 'フクイケン', '福井市', 'フクイシ', '渡町', 'ワタリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市飯塚町', '18', '18201', '9188067', '福井県', 'フクイケン', '福井市', 'フクイシ', '飯塚町', 'イイヅカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市角折町', '18', '18201', '9188068', '福井県', 'フクイケン', '福井市', 'フクイシ', '角折町', 'ツノオリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市恐神町', '18', '18201', '9188071', '福井県', 'フクイケン', '福井市', 'フクイシ', '恐神町', 'オソガミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市北堀町', '18', '18201', '9188072', '福井県', 'フクイケン', '福井市', 'フクイシ', '北堀町', 'キタホリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市安田町', '18', '18201', '9188073', '福井県', 'フクイケン', '福井市', 'フクイシ', '安田町', 'ヤスダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市細坂町', '18', '18201', '9188074', '福井県', 'フクイケン', '福井市', 'フクイシ', '細坂町', 'ホソサカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市羽坂町', '18', '18201', '9188075', '福井県', 'フクイケン', '福井市', 'フクイシ', '羽坂町', 'ハザカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市本堂町', '18', '18201', '9188076', '福井県', 'フクイケン', '福井市', 'フクイシ', '本堂町', 'ホンドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市末町', '18', '18201', '9188077', '福井県', 'フクイケン', '福井市', 'フクイシ', '末町', 'スエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市更毛町', '18', '18201', '9188078', '福井県', 'フクイケン', '福井市', 'フクイシ', '更毛町', 'サラゲチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市上一光町', '18', '18201', '9188081', '福井県', 'フクイケン', '福井市', 'フクイシ', '上一光町', 'カミイカリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市下一光町', '18', '18201', '9188082', '福井県', 'フクイケン', '福井市', 'フクイシ', '下一光町', 'シモイカリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市五太子町', '18', '18201', '9188083', '福井県', 'フクイケン', '福井市', 'フクイシ', '五太子町', 'ゴタイシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市一本木町', '18', '18201', '9188101', '福井県', 'フクイケン', '福井市', 'フクイシ', '一本木町', 'イッポンギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市西板垣町', '18', '18201', '9188102', '福井県', 'フクイケン', '福井市', 'フクイシ', '西板垣町', 'ニシイタガキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市板垣町', '18', '18201', '9188103', '福井県', 'フクイケン', '福井市', 'フクイシ', '板垣町', 'イタガキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市板垣', '18', '18201', '9188104', '福井県', 'フクイケン', '福井市', 'フクイシ', '板垣', 'イタガキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市木田', '18', '18201', '9188105', '福井県', 'フクイケン', '福井市', 'フクイシ', '木田', 'キダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市木田町', '18', '18201', '9188106', '福井県', 'フクイケン', '福井市', 'フクイシ', '木田町', 'キダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市春日町', '18', '18201', '9188107', '福井県', 'フクイケン', '福井市', 'フクイシ', '春日町', 'カスガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市春日', '18', '18201', '9188108', '福井県', 'フクイケン', '福井市', 'フクイシ', '春日', 'カスガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市馬垣町', '18', '18201', '9188111', '福井県', 'フクイケン', '福井市', 'フクイシ', '馬垣町', 'ウマガキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市下馬', '18', '18201', '9188112', '福井県', 'フクイケン', '福井市', 'フクイシ', '下馬', 'ゲバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市下馬町', '18', '18201', '9188113', '福井県', 'フクイケン', '福井市', 'フクイシ', '下馬町', 'ゲバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市羽水', '18', '18201', '9188114', '福井県', 'フクイケン', '福井市', 'フクイシ', '羽水', 'ウスイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市別所町', '18', '18201', '9188115', '福井県', 'フクイケン', '福井市', 'フクイシ', '別所町', 'ベッショチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市大町', '18', '18201', '9188116', '福井県', 'フクイケン', '福井市', 'フクイシ', '大町', 'オオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市小稲津町', '18', '18201', '9188131', '福井県', 'フクイケン', '福井市', 'フクイシ', '小稲津町', 'コイナヅチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市上六条町', '18', '18201', '9188132', '福井県', 'フクイケン', '福井市', 'フクイシ', '上六条町', 'カミロクジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('121999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市上莇生田町', '18', '18201', '9188133', '福井県', 'フクイケン', '福井市', 'フクイシ', '上莇生田町', 'カミアゾウダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市下莇生田町', '18', '18201', '9188134', '福井県', 'フクイケン', '福井市', 'フクイシ', '下莇生田町', 'シモアゾウダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市下六条町', '18', '18201', '9188135', '福井県', 'フクイケン', '福井市', 'フクイシ', '下六条町', 'シモロクジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市天王町', '18', '18201', '9188136', '福井県', 'フクイケン', '福井市', 'フクイシ', '天王町', 'テンノウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市中荒井町', '18', '18201', '9188151', '福井県', 'フクイケン', '福井市', 'フクイシ', '中荒井町', 'ナカアライマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市今市町', '18', '18201', '9188152', '福井県', 'フクイケン', '福井市', 'フクイシ', '今市町', 'イマイチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市安保町', '18', '18201', '9188153', '福井県', 'フクイケン', '福井市', 'フクイシ', '安保町', 'アボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市冬野町', '18', '18201', '9188154', '福井県', 'フクイケン', '福井市', 'フクイシ', '冬野町', 'フユノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市杉谷町', '18', '18201', '9188155', '福井県', 'フクイケン', '福井市', 'フクイシ', '杉谷町', 'スギタニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市引目町', '18', '18201', '9188156', '福井県', 'フクイケン', '福井市', 'フクイシ', '引目町', 'ヒキメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市鉾ケ崎町', '18', '18201', '9188161', '福井県', 'フクイケン', '福井市', 'フクイシ', '鉾ケ崎町', 'ホコガサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市角原町', '18', '18201', '9188162', '福井県', 'フクイケン', '福井市', 'フクイシ', '角原町', 'ツノハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市生野町', '18', '18201', '9188163', '福井県', 'フクイケン', '福井市', 'フクイシ', '生野町', 'ショウノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市三本木町', '18', '18201', '9188164', '福井県', 'フクイケン', '福井市', 'フクイシ', '三本木町', 'サンボンギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市徳尾町', '18', '18201', '9188165', '福井県', 'フクイケン', '福井市', 'フクイシ', '徳尾町', 'トクオチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市主計中町', '18', '18201', '9188166', '福井県', 'フクイケン', '福井市', 'フクイシ', '主計中町', 'カズエナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市森行町', '18', '18201', '9188171', '福井県', 'フクイケン', '福井市', 'フクイシ', '森行町', 'モリユキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市末広町', '18', '18201', '9188172', '福井県', 'フクイケン', '福井市', 'フクイシ', '末広町', 'スエヒロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市下江尻町', '18', '18201', '9188173', '福井県', 'フクイケン', '福井市', 'フクイシ', '下江尻町', 'シモエジリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市上江尻町', '18', '18201', '9188174', '福井県', 'フクイケン', '福井市', 'フクイシ', '上江尻町', 'カミエジリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市江尻ケ丘町', '18', '18201', '9188175', '福井県', 'フクイケン', '福井市', 'フクイシ', '江尻ケ丘町', 'エジリガオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市三十八社町', '18', '18201', '9188176', '福井県', 'フクイケン', '福井市', 'フクイシ', '三十八社町', 'サンジュウハッシャチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市浅水町', '18', '18201', '9188181', '福井県', 'フクイケン', '福井市', 'フクイシ', '浅水町', 'アソウズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市浅水二日町', '18', '18201', '9188182', '福井県', 'フクイケン', '福井市', 'フクイシ', '浅水二日町', 'アソウズフツカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市浅水三ケ町', '18', '18201', '9188183', '福井県', 'フクイケン', '福井市', 'フクイシ', '浅水三ケ町', 'アソウズサンガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市真木町', '18', '18201', '9188184', '福井県', 'フクイケン', '福井市', 'フクイシ', '真木町', 'マキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市中野町', '18', '18201', '9188185', '福井県', 'フクイケン', '福井市', 'フクイシ', '中野町', 'ナカノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市中野', '18', '18201', '9188186', '福井県', 'フクイケン', '福井市', 'フクイシ', '中野', 'ナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市花守町', '18', '18201', '9188187', '福井県', 'フクイケン', '福井市', 'フクイシ', '花守町', 'ハナモリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市三尾野町', '18', '18201', '9188188', '福井県', 'フクイケン', '福井市', 'フクイシ', '三尾野町', 'ミオノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市南四ツ居町', '18', '18201', '9188201', '福井県', 'フクイケン', '福井市', 'フクイシ', '南四ツ居町', 'ミナミヨツイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市大東', '18', '18201', '9188202', '福井県', 'フクイケン', '福井市', 'フクイシ', '大東', 'ダイトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市上北野', '18', '18201', '9188203', '福井県', 'フクイケン', '福井市', 'フクイシ', '上北野', 'カミキタノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市南四ツ居', '18', '18201', '9188204', '福井県', 'フクイケン', '福井市', 'フクイシ', '南四ツ居', 'ミナミヨツイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市北四ツ居', '18', '18201', '9188205', '福井県', 'フクイケン', '福井市', 'フクイシ', '北四ツ居', 'キタヨツイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市北四ツ居町', '18', '18201', '9188206', '福井県', 'フクイケン', '福井市', 'フクイシ', '北四ツ居町', 'キタヨツイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市円山', '18', '18201', '9188207', '福井県', 'フクイケン', '福井市', 'フクイシ', '円山', 'エンザン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市下中町', '18', '18201', '9188211', '福井県', 'フクイケン', '福井市', 'フクイシ', '下中町', 'シモナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市北今泉町', '18', '18201', '9188212', '福井県', 'フクイケン', '福井市', 'フクイシ', '北今泉町', 'キタイマイズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市今泉町', '18', '18201', '9188213', '福井県', 'フクイケン', '福井市', 'フクイシ', '今泉町', 'イマイズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市東今泉町', '18', '18201', '9188214', '福井県', 'フクイケン', '福井市', 'フクイシ', '東今泉町', 'ヒガシイマイズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市寮町', '18', '18201', '9188215', '福井県', 'フクイケン', '福井市', 'フクイシ', '寮町', 'リョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市殿下町', '18', '18201', '9188216', '福井県', 'フクイケン', '福井市', 'フクイシ', '殿下町', 'テンガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市印田町', '18', '18201', '9188217', '福井県', 'フクイケン', '福井市', 'フクイシ', '印田町', 'インデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市河増町', '18', '18201', '9188218', '福井県', 'フクイケン', '福井市', 'フクイシ', '河増町', 'コウマスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市堅達町', '18', '18201', '9188221', '福井県', 'フクイケン', '福井市', 'フクイシ', '堅達町', 'ゲンダツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市坂下町', '18', '18201', '9188222', '福井県', 'フクイケン', '福井市', 'フクイシ', '坂下町', 'サカシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市河水町', '18', '18201', '9188223', '福井県', 'フクイケン', '福井市', 'フクイシ', '河水町', 'コウスイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市花野谷町', '18', '18201', '9188224', '福井県', 'フクイケン', '福井市', 'フクイシ', '花野谷町', 'ハナノタニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市宮地町', '18', '18201', '9188225', '福井県', 'フクイケン', '福井市', 'フクイシ', '宮地町', 'ミヤジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市大畑町', '18', '18201', '9188226', '福井県', 'フクイケン', '福井市', 'フクイシ', '大畑町', 'オバタケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市次郎丸町', '18', '18201', '9188227', '福井県', 'フクイケン', '福井市', 'フクイシ', '次郎丸町', 'ジロウマルチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市岡西谷町', '18', '18201', '9188228', '福井県', 'フクイケン', '福井市', 'フクイシ', '岡西谷町', 'オカニシタニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市問屋町', '18', '18201', '9188231', '福井県', 'フクイケン', '福井市', 'フクイシ', '問屋町', 'トイヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市荒木別所町', '18', '18201', '9188232', '福井県', 'フクイケン', '福井市', 'フクイシ', '荒木別所町', 'アラキベッシヨチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市合島町', '18', '18201', '9188233', '福井県', 'フクイケン', '福井市', 'フクイシ', '合島町', 'ゴウシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市曽万布町', '18', '18201', '9188234', '福井県', 'フクイケン', '福井市', 'フクイシ', '曽万布町', 'ソンボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市和田中町', '18', '18201', '9188235', '福井県', 'フクイケン', '福井市', 'フクイシ', '和田中町', 'ワダナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市和田中', '18', '18201', '9188236', '福井県', 'フクイケン', '福井市', 'フクイシ', '和田中', 'ワダナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市和田東', '18', '18201', '9188237', '福井県', 'フクイケン', '福井市', 'フクイシ', '和田東', 'ワダヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市和田', '18', '18201', '9188238', '福井県', 'フクイケン', '福井市', 'フクイシ', '和田', 'ワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市成和', '18', '18201', '9188239', '福井県', 'フクイケン', '福井市', 'フクイシ', '成和', 'セイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県南条郡南越前町湯尾', '18', '18404', '9190101', '福井県', 'フクイケン', '南条郡南越前町', 'ナンジョウグンミナミエチゼンチョウ', '湯尾', 'ユノオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県南条郡南越前町八乙女', '18', '18404', '9190102', '福井県', 'フクイケン', '南条郡南越前町', 'ナンジョウグンミナミエチゼンチョウ', '八乙女', 'ヤオトメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県南条郡南越前町社谷', '18', '18404', '9190103', '福井県', 'フクイケン', '南条郡南越前町', 'ナンジョウグンミナミエチゼンチョウ', '社谷', 'ヤシロダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県南条郡南越前町燧', '18', '18404', '9190104', '福井県', 'フクイケン', '南条郡南越前町', 'ナンジョウグンミナミエチゼンチョウ', '燧', 'ヒウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県南条郡南越前町杉谷', '18', '18404', '9190111', '福井県', 'フクイケン', '南条郡南越前町', 'ナンジョウグンミナミエチゼンチョウ', '杉谷', 'スギタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県南条郡南越前町杣木俣', '18', '18404', '9190112', '福井県', 'フクイケン', '南条郡南越前町', 'ナンジョウグンミナミエチゼンチョウ', '杣木俣', 'ソマキマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県南条郡南越前町瀬戸', '18', '18404', '9190113', '福井県', 'フクイケン', '南条郡南越前町', 'ナンジョウグンミナミエチゼンチョウ', '瀬戸', 'セト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県南条郡南越前町小倉谷', '18', '18404', '9190114', '福井県', 'フクイケン', '南条郡南越前町', 'ナンジョウグンミナミエチゼンチョウ', '小倉谷', 'オグラタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県南条郡南越前町上温谷', '18', '18404', '9190115', '福井県', 'フクイケン', '南条郡南越前町', 'ナンジョウグンミナミエチゼンチョウ', '上温谷', 'カミヌクダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県南条郡南越前町古木', '18', '18404', '9190116', '福井県', 'フクイケン', '南条郡南越前町', 'ナンジョウグンミナミエチゼンチョウ', '古木', 'フルキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県南条郡南越前町馬上免', '18', '18404', '9190117', '福井県', 'フクイケン', '南条郡南越前町', 'ナンジョウグンミナミエチゼンチョウ', '馬上免', 'バジョウメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県南条郡南越前町長沢', '18', '18404', '9190118', '福井県', 'フクイケン', '南条郡南越前町', 'ナンジョウグンミナミエチゼンチョウ', '長沢', 'ナガサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県南条郡南越前町久喜', '18', '18404', '9190119', '福井県', 'フクイケン', '南条郡南越前町', 'ナンジョウグンミナミエチゼンチョウ', '久喜', 'クキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県南条郡南越前町合波', '18', '18404', '9190121', '福井県', 'フクイケン', '南条郡南越前町', 'ナンジョウグンミナミエチゼンチョウ', '合波', 'アイバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県南条郡南越前町大門', '18', '18404', '9190122', '福井県', 'フクイケン', '南条郡南越前町', 'ナンジョウグンミナミエチゼンチョウ', '大門', 'ダイモン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県南条郡南越前町荒井', '18', '18404', '9190123', '福井県', 'フクイケン', '南条郡南越前町', 'ナンジョウグンミナミエチゼンチョウ', '荒井', 'アライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県南条郡南越前町八飯', '18', '18404', '9190124', '福井県', 'フクイケン', '南条郡南越前町', 'ナンジョウグンミナミエチゼンチョウ', '八飯', 'ヤイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県南条郡南越前町宇津尾', '18', '18404', '9190125', '福井県', 'フクイケン', '南条郡南越前町', 'ナンジョウグンミナミエチゼンチョウ', '宇津尾', 'ウツオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県南条郡南越前町橋立', '18', '18404', '9190126', '福井県', 'フクイケン', '南条郡南越前町', 'ナンジョウグンミナミエチゼンチョウ', '橋立', 'ハシタテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県南条郡南越前町広野', '18', '18404', '9190127', '福井県', 'フクイケン', '南条郡南越前町', 'ナンジョウグンミナミエチゼンチョウ', '広野', 'ヒロノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県南条郡南越前町板取', '18', '18404', '9190128', '福井県', 'フクイケン', '南条郡南越前町', 'ナンジョウグンミナミエチゼンチョウ', '板取', 'イタドリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県南条郡南越前町孫谷', '18', '18404', '9190129', '福井県', 'フクイケン', '南条郡南越前町', 'ナンジョウグンミナミエチゼンチョウ', '孫谷', 'マゴタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県南条郡南越前町今庄', '18', '18404', '9190131', '福井県', 'フクイケン', '南条郡南越前町', 'ナンジョウグンミナミエチゼンチョウ', '今庄', 'イマジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県南条郡南越前町南今庄', '18', '18404', '9190132', '福井県', 'フクイケン', '南条郡南越前町', 'ナンジョウグンミナミエチゼンチョウ', '南今庄', 'ミナミイマジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県南条郡南越前町新道', '18', '18404', '9190133', '福井県', 'フクイケン', '南条郡南越前町', 'ナンジョウグンミナミエチゼンチョウ', '新道', 'シンドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県南条郡南越前町二ツ屋', '18', '18404', '9190135', '福井県', 'フクイケン', '南条郡南越前町', 'ナンジョウグンミナミエチゼンチョウ', '二ツ屋', 'フタツヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県南条郡南越前町大桐', '18', '18404', '9190136', '福井県', 'フクイケン', '南条郡南越前町', 'ナンジョウグンミナミエチゼンチョウ', '大桐', 'オオギリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県南条郡南越前町', '18', '18404', '9190200', '福井県', 'フクイケン', '南条郡南越前町', 'ナンジョウグンミナミエチゼンチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('122128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県南条郡南越前町上平吹', '18', '18404', '9190201', '福井県', 'フクイケン', '南条郡南越前町', 'ナンジョウグンミナミエチゼンチョウ', '上平吹', 'カミヒラブキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県南条郡南越前町鋳物師', '18', '18404', '9190202', '福井県', 'フクイケン', '南条郡南越前町', 'ナンジョウグンミナミエチゼンチョウ', '鋳物師', 'イモノシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県南条郡南越前町牧谷', '18', '18404', '9190203', '福井県', 'フクイケン', '南条郡南越前町', 'ナンジョウグンミナミエチゼンチョウ', '牧谷', 'マキダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県南条郡南越前町上野', '18', '18404', '9190204', '福井県', 'フクイケン', '南条郡南越前町', 'ナンジョウグンミナミエチゼンチョウ', '上野', 'ウエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県南条郡南越前町堂宮', '18', '18404', '9190205', '福井県', 'フクイケン', '南条郡南越前町', 'ナンジョウグンミナミエチゼンチョウ', '堂宮', 'ドウミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県南条郡南越前町金粕', '18', '18404', '9190206', '福井県', 'フクイケン', '南条郡南越前町', 'ナンジョウグンミナミエチゼンチョウ', '金粕', 'カネガス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県南条郡南越前町関ケ鼻', '18', '18404', '9190211', '福井県', 'フクイケン', '南条郡南越前町', 'ナンジョウグンミナミエチゼンチョウ', '関ケ鼻', 'セキガハナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県南条郡南越前町鯖波', '18', '18404', '9190212', '福井県', 'フクイケン', '南条郡南越前町', 'ナンジョウグンミナミエチゼンチョウ', '鯖波', 'サバナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県南条郡南越前町阿久和', '18', '18404', '9190213', '福井県', 'フクイケン', '南条郡南越前町', 'ナンジョウグンミナミエチゼンチョウ', '阿久和', 'アクワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県南条郡南越前町中小屋', '18', '18404', '9190214', '福井県', 'フクイケン', '南条郡南越前町', 'ナンジョウグンミナミエチゼンチョウ', '中小屋', 'ナカゴヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県南条郡南越前町奥野々', '18', '18404', '9190215', '福井県', 'フクイケン', '南条郡南越前町', 'ナンジョウグンミナミエチゼンチョウ', '奥野々', 'オクノノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県南条郡南越前町上別所', '18', '18404', '9190216', '福井県', 'フクイケン', '南条郡南越前町', 'ナンジョウグンミナミエチゼンチョウ', '上別所', 'カミベッショ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県南条郡南越前町杣山', '18', '18404', '9190217', '福井県', 'フクイケン', '南条郡南越前町', 'ナンジョウグンミナミエチゼンチョウ', '杣山', 'ソマヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県南条郡南越前町島', '18', '18404', '9190221', '福井県', 'フクイケン', '南条郡南越前町', 'ナンジョウグンミナミエチゼンチョウ', '島', 'シマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県南条郡南越前町日野', '18', '18404', '9190222', '福井県', 'フクイケン', '南条郡南越前町', 'ナンジョウグンミナミエチゼンチョウ', '日野', 'ヒノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県南条郡南越前町東大道', '18', '18404', '9190223', '福井県', 'フクイケン', '南条郡南越前町', 'ナンジョウグンミナミエチゼンチョウ', '東大道', 'ヒガシダイドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県南条郡南越前町西大道', '18', '18404', '9190224', '福井県', 'フクイケン', '南条郡南越前町', 'ナンジョウグンミナミエチゼンチョウ', '西大道', 'ニシダイドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県南条郡南越前町東谷', '18', '18404', '9190225', '福井県', 'フクイケン', '南条郡南越前町', 'ナンジョウグンミナミエチゼンチョウ', '東谷', 'ヒガシダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県南条郡南越前町清水', '18', '18404', '9190226', '福井県', 'フクイケン', '南条郡南越前町', 'ナンジョウグンミナミエチゼンチョウ', '清水', 'シミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県南条郡南越前町脇本', '18', '18404', '9190227', '福井県', 'フクイケン', '南条郡南越前町', 'ナンジョウグンミナミエチゼンチョウ', '脇本', 'ワキモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市下細江町', '18', '18201', '9190301', '福井県', 'フクイケン', '福井市', 'フクイシ', '下細江町', 'シモホソエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市上細江町', '18', '18201', '9190302', '福井県', 'フクイケン', '福井市', 'フクイシ', '上細江町', 'カミホソエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市岩倉町', '18', '18201', '9190303', '福井県', 'フクイケン', '福井市', 'フクイシ', '岩倉町', 'イワクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市田中町', '18', '18201', '9190304', '福井県', 'フクイケン', '福井市', 'フクイシ', '田中町', 'タナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市徳光町', '18', '18201', '9190305', '福井県', 'フクイケン', '福井市', 'フクイシ', '徳光町', 'トクミツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市田治島町', '18', '18201', '9190311', '福井県', 'フクイケン', '福井市', 'フクイシ', '田治島町', 'タジシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市東大味町', '18', '18201', '9190312', '福井県', 'フクイケン', '福井市', 'フクイシ', '東大味町', 'ヒガシオオミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市西大味町', '18', '18201', '9190313', '福井県', 'フクイケン', '福井市', 'フクイシ', '西大味町', 'ニシオオミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市生部町', '18', '18201', '9190314', '福井県', 'フクイケン', '福井市', 'フクイシ', '生部町', 'イケブチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市西袋町', '18', '18201', '9190315', '福井県', 'フクイケン', '福井市', 'フクイシ', '西袋町', 'ニシブクロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市大村町', '18', '18201', '9190316', '福井県', 'フクイケン', '福井市', 'フクイシ', '大村町', 'オオムラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市北山町', '18', '18201', '9190317', '福井県', 'フクイケン', '福井市', 'フクイシ', '北山町', 'キタヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市北山新保町', '18', '18201', '9190318', '福井県', 'フクイケン', '福井市', 'フクイシ', '北山新保町', 'キタヤマシンボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市下河北町', '18', '18201', '9190321', '福井県', 'フクイケン', '福井市', 'フクイシ', '下河北町', 'シモコギタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市上河北町', '18', '18201', '9190322', '福井県', 'フクイケン', '福井市', 'フクイシ', '上河北町', 'カミコギタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市太田町', '18', '18201', '9190323', '福井県', 'フクイケン', '福井市', 'フクイシ', '太田町', 'オオタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市帆谷町', '18', '18201', '9190324', '福井県', 'フクイケン', '福井市', 'フクイシ', '帆谷町', 'ホダニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市二上町', '18', '18201', '9190325', '福井県', 'フクイケン', '福井市', 'フクイシ', '二上町', 'フタガミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市半田町', '18', '18201', '9190326', '福井県', 'フクイケン', '福井市', 'フクイシ', '半田町', 'ハンダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市大土呂町', '18', '18201', '9190327', '福井県', 'フクイケン', '福井市', 'フクイシ', '大土呂町', 'オオドロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市新開町', '18', '18201', '9190328', '福井県', 'フクイケン', '福井市', 'フクイシ', '新開町', 'シンビラキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県福井市下東郷町新村', '18', '18201', '9190373', '福井県', 'フクイケン', '福井市', 'フクイシ', '下東郷町', 'シモトウゴウチョウ', null, null, '新村', 'シンムラ');
INSERT INTO `ms_addresses` VALUES ('122171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市春江町堀越', '18', '18210', '9190401', '福井県', 'フクイケン', '坂井市', 'サカイシ', '春江町堀越', 'ハルエチョウホリコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市春江町大牧', '18', '18210', '9190402', '福井県', 'フクイケン', '坂井市', 'サカイシ', '春江町大牧', 'ハルエチョウオオマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市春江町井向', '18', '18210', '9190403', '福井県', 'フクイケン', '坂井市', 'サカイシ', '春江町井向', 'ハルエチョウイノムカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市春江町西長田', '18', '18210', '9190404', '福井県', 'フクイケン', '坂井市', 'サカイシ', '春江町西長田', 'ハルエチョウニシナガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市春江町上小森', '18', '18210', '9190405', '福井県', 'フクイケン', '坂井市', 'サカイシ', '春江町上小森', 'ハルエチョウカミコモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市春江町下小森', '18', '18210', '9190406', '福井県', 'フクイケン', '坂井市', 'サカイシ', '春江町下小森', 'ハルエチョウシモコモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市春江町辻', '18', '18210', '9190407', '福井県', 'フクイケン', '坂井市', 'サカイシ', '春江町辻', 'ハルエチョウツジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市春江町木部西方寺', '18', '18210', '9190408', '福井県', 'フクイケン', '坂井市', 'サカイシ', '春江町木部西方寺', 'ハルエチョウキベサイホウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市春江町定広', '18', '18210', '9190409', '福井県', 'フクイケン', '坂井市', 'サカイシ', '春江町定広', 'ハルエチョウサダヒロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市春江町藤鷲塚', '18', '18210', '9190411', '福井県', 'フクイケン', '坂井市', 'サカイシ', '春江町藤鷲塚', 'ハルエチョウフジワシヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市春江町江留中', '18', '18210', '9190412', '福井県', 'フクイケン', '坂井市', 'サカイシ', '春江町江留中', 'ハルエチョウエドメナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市春江町随応寺', '18', '18210', '9190413', '福井県', 'フクイケン', '坂井市', 'サカイシ', '春江町随応寺', 'ハルエチョウズイオウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市春江町江留下屋敷', '18', '18210', '9190414', '福井県', 'フクイケン', '坂井市', 'サカイシ', '春江町江留下屋敷', 'ハルエチョウエドメシモヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市春江町江留下', '18', '18210', '9190415', '福井県', 'フクイケン', '坂井市', 'サカイシ', '春江町江留下', 'ハルエチョウエドメシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市春江町江留下宇和江', '18', '18210', '9190416', '福井県', 'フクイケン', '坂井市', 'サカイシ', '春江町江留下宇和江', 'ハルエチョウエドメシモウワエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市春江町江留下相田', '18', '18210', '9190417', '福井県', 'フクイケン', '坂井市', 'サカイシ', '春江町江留下相田', 'ハルエチョウエドメシモアイデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市春江町江留下高道', '18', '18210', '9190418', '福井県', 'フクイケン', '坂井市', 'サカイシ', '春江町江留下高道', 'ハルエチョウエドメシモタカミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市春江町大針', '18', '18210', '9190421', '福井県', 'フクイケン', '坂井市', 'サカイシ', '春江町大針', 'ハルエチョウオオバリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市春江町沖布目', '18', '18210', '9190422', '福井県', 'フクイケン', '坂井市', 'サカイシ', '春江町沖布目', 'ハルエチョウオキヌノメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市春江町石仏', '18', '18210', '9190423', '福井県', 'フクイケン', '坂井市', 'サカイシ', '春江町石仏', 'ハルエチョウイシボトケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市春江町いちい野', '18', '18210', '9190424', '福井県', 'フクイケン', '坂井市', 'サカイシ', '春江町いちい野', 'ハルエチョウイチイノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市春江町いちい野北', '18', '18210', '9190425', '福井県', 'フクイケン', '坂井市', 'サカイシ', '春江町いちい野北', 'ハルエチョウイチイノキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市春江町いちい野中央', '18', '18210', '9190426', '福井県', 'フクイケン', '坂井市', 'サカイシ', '春江町いちい野中央', 'ハルエチョウイチイノチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市春江町為国', '18', '18210', '9190431', '福井県', 'フクイケン', '坂井市', 'サカイシ', '春江町為国', 'ハルエチョウタメクニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市春江町為国亀ケ久保', '18', '18210', '9190432', '福井県', 'フクイケン', '坂井市', 'サカイシ', '春江町為国亀ケ久保', 'ハルエチョウタメクニカメガクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市春江町為国平成', '18', '18210', '9190433', '福井県', 'フクイケン', '坂井市', 'サカイシ', '春江町為国平成', 'ハルエチョウタメクニヘイセイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市春江町境', '18', '18210', '9190434', '福井県', 'フクイケン', '坂井市', 'サカイシ', '春江町境', 'ハルエチョウサカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市春江町境上町', '18', '18210', '9190434', '福井県', 'フクイケン', '坂井市', 'サカイシ', '春江町境上町', 'ハルエチョウサカイカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市春江町境元町', '18', '18210', '9190434', '福井県', 'フクイケン', '坂井市', 'サカイシ', '春江町境元町', 'ハルエチョウサカイモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市春江町為国幸', '18', '18210', '9190435', '福井県', 'フクイケン', '坂井市', 'サカイシ', '春江町為国幸', 'ハルエチョウタメクニサイワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市春江町為国中区', '18', '18210', '9190436', '福井県', 'フクイケン', '坂井市', 'サカイシ', '春江町為国中区', 'ハルエチョウタメクニナカク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市春江町為国西の宮', '18', '18210', '9190437', '福井県', 'フクイケン', '坂井市', 'サカイシ', '春江町為国西の宮', 'ハルエチョウタメクニニシノミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市春江町定重', '18', '18210', '9190441', '福井県', 'フクイケン', '坂井市', 'サカイシ', '春江町定重', 'ハルエチョウサダシゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市春江町寄安', '18', '18210', '9190442', '福井県', 'フクイケン', '坂井市', 'サカイシ', '春江町寄安', 'ハルエチョウヨリヤス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市春江町正蓮花', '18', '18210', '9190443', '福井県', 'フクイケン', '坂井市', 'サカイシ', '春江町正蓮花', 'ハルエチョウショウレンゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市春江町中筋三ツ屋', '18', '18210', '9190444', '福井県', 'フクイケン', '坂井市', 'サカイシ', '春江町中筋三ツ屋', 'ハルエチョウナカスジミツヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市春江町中筋高田', '18', '18210', '9190445', '福井県', 'フクイケン', '坂井市', 'サカイシ', '春江町中筋高田', 'ハルエチョウナカスジタカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市春江町中筋春日', '18', '18210', '9190446', '福井県', 'フクイケン', '坂井市', 'サカイシ', '春江町中筋春日', 'ハルエチョウナカスジカスガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市春江町中筋大手', '18', '18210', '9190447', '福井県', 'フクイケン', '坂井市', 'サカイシ', '春江町中筋大手', 'ハルエチョウナカスジオオテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市春江町中筋北浦', '18', '18210', '9190448', '福井県', 'フクイケン', '坂井市', 'サカイシ', '春江町中筋北浦', 'ハルエチョウナカスジキタウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市春江町中筋', '18', '18210', '9190449', '福井県', 'フクイケン', '坂井市', 'サカイシ', '春江町中筋', 'ハルエチョウナカスジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市春江町江留上旭', '18', '18210', '9190451', '福井県', 'フクイケン', '坂井市', 'サカイシ', '春江町江留上旭', 'ハルエチョウエドメカミアサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市春江町江留上本町', '18', '18210', '9190452', '福井県', 'フクイケン', '坂井市', 'サカイシ', '春江町江留上本町', 'ハルエチョウエドメカミホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市春江町江留上中央', '18', '18210', '9190453', '福井県', 'フクイケン', '坂井市', 'サカイシ', '春江町江留上中央', 'ハルエチョウエドメカミチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市春江町江留上日の出', '18', '18210', '9190454', '福井県', 'フクイケン', '坂井市', 'サカイシ', '春江町江留上日の出', 'ハルエチョウエドメカミヒノデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市春江町江留上', '18', '18210', '9190455', '福井県', 'フクイケン', '坂井市', 'サカイシ', '春江町江留上', 'ハルエチョウエドメカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市春江町江留上緑', '18', '18210', '9190461', '福井県', 'フクイケン', '坂井市', 'サカイシ', '春江町江留上緑', 'ハルエチョウエドメカミミドリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市春江町江留上大和', '18', '18210', '9190462', '福井県', 'フクイケン', '坂井市', 'サカイシ', '春江町江留上大和', 'ハルエチョウエドメカミヤマト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市春江町江留上昭和', '18', '18210', '9190463', '福井県', 'フクイケン', '坂井市', 'サカイシ', '春江町江留上昭和', 'ハルエチョウエドメカミショウワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市春江町江留上錦', '18', '18210', '9190464', '福井県', 'フクイケン', '坂井市', 'サカイシ', '春江町江留上錦', 'ハルエチョウエドメカミニシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市春江町江留上新町', '18', '18210', '9190465', '福井県', 'フクイケン', '坂井市', 'サカイシ', '春江町江留上新町', 'ハルエチョウエドメカミシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市春江町金剛寺', '18', '18210', '9190471', '福井県', 'フクイケン', '坂井市', 'サカイシ', '春江町金剛寺', 'ハルエチョウコンゴウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市春江町松木', '18', '18210', '9190472', '福井県', 'フクイケン', '坂井市', 'サカイシ', '春江町松木', 'ハルエチョウマツキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市春江町本堂', '18', '18210', '9190473', '福井県', 'フクイケン', '坂井市', 'サカイシ', '春江町本堂', 'ハルエチョウホンドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市春江町西太郎丸', '18', '18210', '9190474', '福井県', 'フクイケン', '坂井市', 'サカイシ', '春江町西太郎丸', 'ハルエチョウニシタロウマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市春江町東太郎丸', '18', '18210', '9190475', '福井県', 'フクイケン', '坂井市', 'サカイシ', '春江町東太郎丸', 'ハルエチョウヒガシタロウマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市春江町針原', '18', '18210', '9190476', '福井県', 'フクイケン', '坂井市', 'サカイシ', '春江町針原', 'ハルエチョウハリバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市春江町田端', '18', '18210', '9190477', '福井県', 'フクイケン', '坂井市', 'サカイシ', '春江町田端', 'ハルエチョウタバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市春江町高江', '18', '18210', '9190479', '福井県', 'フクイケン', '坂井市', 'サカイシ', '春江町高江', 'ハルエチョウタカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市春江町千歩寺', '18', '18210', '9190481', '福井県', 'フクイケン', '坂井市', 'サカイシ', '春江町千歩寺', 'ハルエチョウセンボウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市春江町中庄', '18', '18210', '9190482', '福井県', 'フクイケン', '坂井市', 'サカイシ', '春江町中庄', 'ハルエチョウナカノショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市春江町石塚', '18', '18210', '9190483', '福井県', 'フクイケン', '坂井市', 'サカイシ', '春江町石塚', 'ハルエチョウイシヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市春江町安沢', '18', '18210', '9190484', '福井県', 'フクイケン', '坂井市', 'サカイシ', '春江町安沢', 'ハルエチョウヤスザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市春江町取次', '18', '18210', '9190485', '福井県', 'フクイケン', '坂井市', 'サカイシ', '春江町取次', 'ハルエチョウトリツギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市春江町布施田新', '18', '18210', '9190486', '福井県', 'フクイケン', '坂井市', 'サカイシ', '春江町布施田新', 'ハルエチョウフセダシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市春江町正善', '18', '18210', '9190487', '福井県', 'フクイケン', '坂井市', 'サカイシ', '春江町正善', 'ハルエチョウショウゼン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市春江町姫王', '18', '18210', '9190488', '福井県', 'フクイケン', '坂井市', 'サカイシ', '春江町姫王', 'ハルエチョウヒメオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市坂井町下関', '18', '18210', '9190501', '福井県', 'フクイケン', '坂井市', 'サカイシ', '坂井町下関', 'サカイチョウシモゼキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市坂井町上関', '18', '18210', '9190502', '福井県', 'フクイケン', '坂井市', 'サカイシ', '坂井町上関', 'サカイチョウカミゼキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市坂井町長屋', '18', '18210', '9190503', '福井県', 'フクイケン', '坂井市', 'サカイシ', '坂井町長屋', 'サカイチョウナガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市坂井町御油田', '18', '18210', '9190504', '福井県', 'フクイケン', '坂井市', 'サカイシ', '坂井町御油田', 'サカイチョウゴユウデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市坂井町河和田', '18', '18210', '9190505', '福井県', 'フクイケン', '坂井市', 'サカイシ', '坂井町河和田', 'サカイチョウカワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市坂井町定旨', '18', '18210', '9190506', '福井県', 'フクイケン', '坂井市', 'サカイシ', '坂井町定旨', 'サカイチョウサダムネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市坂井町五本', '18', '18210', '9190507', '福井県', 'フクイケン', '坂井市', 'サカイシ', '坂井町五本', 'サカイチョウゴホン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市坂井町長畑', '18', '18210', '9190511', '福井県', 'フクイケン', '坂井市', 'サカイシ', '坂井町長畑', 'サカイチョウナガバタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市坂井町宮領', '18', '18210', '9190512', '福井県', 'フクイケン', '坂井市', 'サカイシ', '坂井町宮領', 'サカイチョウミヤリョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市坂井町田島', '18', '18210', '9190513', '福井県', 'フクイケン', '坂井市', 'サカイシ', '坂井町田島', 'サカイチョウタジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市坂井町田島窪', '18', '18210', '9190514', '福井県', 'フクイケン', '坂井市', 'サカイシ', '坂井町田島窪', 'サカイチョウタジマクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市坂井町若宮', '18', '18210', '9190515', '福井県', 'フクイケン', '坂井市', 'サカイシ', '坂井町若宮', 'サカイチョウワカミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市坂井町福島', '18', '18210', '9190516', '福井県', 'フクイケン', '坂井市', 'サカイシ', '坂井町福島', 'サカイチョウフクシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市坂井町朝日', '18', '18210', '9190517', '福井県', 'フクイケン', '坂井市', 'サカイシ', '坂井町朝日', 'サカイチョウアサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市坂井町下新庄', '18', '18210', '9190521', '福井県', 'フクイケン', '坂井市', 'サカイシ', '坂井町下新庄', 'サカイチョウシモシンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市坂井町上新庄', '18', '18210', '9190522', '福井県', 'フクイケン', '坂井市', 'サカイシ', '坂井町上新庄', 'サカイチョウカミシンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市坂井町新庄', '18', '18210', '9190523', '福井県', 'フクイケン', '坂井市', 'サカイシ', '坂井町新庄', 'サカイチョウシンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市坂井町東長田', '18', '18210', '9190524', '福井県', 'フクイケン', '坂井市', 'サカイシ', '坂井町東長田', 'サカイチョウヒガシナガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市坂井町徳分田', '18', '18210', '9190525', '福井県', 'フクイケン', '坂井市', 'サカイシ', '坂井町徳分田', 'サカイチョウトクブンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市坂井町上兵庫', '18', '18210', '9190526', '福井県', 'フクイケン', '坂井市', 'サカイシ', '坂井町上兵庫', 'サカイチョウカミヒョウゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市坂井町下兵庫', '18', '18210', '9190527', '福井県', 'フクイケン', '坂井市', 'サカイシ', '坂井町下兵庫', 'サカイチョウシモヒョウゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市坂井町今井', '18', '18210', '9190531', '福井県', 'フクイケン', '坂井市', 'サカイシ', '坂井町今井', 'サカイチョウイマイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市坂井町高柳', '18', '18210', '9190532', '福井県', 'フクイケン', '坂井市', 'サカイシ', '坂井町高柳', 'サカイチョウタカヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市坂井町木部東', '18', '18210', '9190533', '福井県', 'フクイケン', '坂井市', 'サカイシ', '坂井町木部東', 'サカイチョウキベヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市坂井町清永', '18', '18210', '9190534', '福井県', 'フクイケン', '坂井市', 'サカイシ', '坂井町清永', 'サカイチョウキヨナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市坂井町島', '18', '18210', '9190535', '福井県', 'フクイケン', '坂井市', 'サカイシ', '坂井町島', 'サカイチョウシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市坂井町木部新保', '18', '18210', '9190536', '福井県', 'フクイケン', '坂井市', 'サカイシ', '坂井町木部新保', 'サカイチョウキベシンボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市坂井町折戸', '18', '18210', '9190537', '福井県', 'フクイケン', '坂井市', 'サカイシ', '坂井町折戸', 'サカイチョウオリト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市坂井町東', '18', '18210', '9190541', '福井県', 'フクイケン', '坂井市', 'サカイシ', '坂井町東', 'サカイチョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市坂井町蔵垣内', '18', '18210', '9190542', '福井県', 'フクイケン', '坂井市', 'サカイシ', '坂井町蔵垣内', 'サカイチョウクラガイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市坂井町西', '18', '18210', '9190543', '福井県', 'フクイケン', '坂井市', 'サカイシ', '坂井町西', 'サカイチョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市坂井町東中野', '18', '18210', '9190544', '福井県', 'フクイケン', '坂井市', 'サカイシ', '坂井町東中野', 'サカイチョウヒガシナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市坂井町東荒井', '18', '18210', '9190545', '福井県', 'フクイケン', '坂井市', 'サカイシ', '坂井町東荒井', 'サカイチョウヒガシアライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市坂井町蛸', '18', '18210', '9190546', '福井県', 'フクイケン', '坂井市', 'サカイシ', '坂井町蛸', 'サカイチョウタコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県坂井市坂井町大味', '18', '18210', '9190547', '福井県', 'フクイケン', '坂井市', 'サカイシ', '坂井町大味', 'サカイチョウオオミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県あわら市', '18', '18208', '9190600', '福井県', 'フクイケン', 'あわら市', 'アワラシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('122280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県あわら市山室', '18', '18208', '9190601', '福井県', 'フクイケン', 'あわら市', 'アワラシ', '山室', 'ヤマムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県あわら市菅野', '18', '18208', '9190602', '福井県', 'フクイケン', 'あわら市', 'アワラシ', '菅野', 'スガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県あわら市矢地', '18', '18208', '9190603', '福井県', 'フクイケン', 'あわら市', 'アワラシ', '矢地', 'ヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県あわら市自由ケ丘', '18', '18208', '9190604', '福井県', 'フクイケン', 'あわら市', 'アワラシ', '自由ケ丘', 'ジユウガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県あわら市清間', '18', '18208', '9190611', '福井県', 'フクイケン', 'あわら市', 'アワラシ', '清間', 'セイマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県あわら市桑原', '18', '18208', '9190612', '福井県', 'フクイケン', 'あわら市', 'アワラシ', '桑原', 'クワバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県あわら市古屋石塚', '18', '18208', '9190613', '福井県', 'フクイケン', 'あわら市', 'アワラシ', '古屋石塚', 'フルヤイシヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県あわら市伊井', '18', '18208', '9190614', '福井県', 'フクイケン', 'あわら市', 'アワラシ', '伊井', 'イイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県あわら市池口', '18', '18208', '9190615', '福井県', 'フクイケン', 'あわら市', 'アワラシ', '池口', 'イケグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県あわら市河原井手', '18', '18208', '9190616', '福井県', 'フクイケン', 'あわら市', 'アワラシ', '河原井手', 'カワライデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県あわら市市姫', '18', '18208', '9190621', '福井県', 'フクイケン', 'あわら市', 'アワラシ', '市姫', 'イチヒメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県あわら市稲越', '18', '18208', '9190623', '福井県', 'フクイケン', 'あわら市', 'アワラシ', '稲越', 'イナゴエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県あわら市大溝', '18', '18208', '9190628', '福井県', 'フクイケン', 'あわら市', 'アワラシ', '大溝', 'オオミゾ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県あわら市高塚', '18', '18208', '9190631', '福井県', 'フクイケン', 'あわら市', 'アワラシ', '高塚', 'タカツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県あわら市春宮', '18', '18208', '9190632', '福井県', 'フクイケン', 'あわら市', 'アワラシ', '春宮', 'ハルミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県あわら市花乃杜', '18', '18208', '9190633', '福井県', 'フクイケン', 'あわら市', 'アワラシ', '花乃杜', 'ハナノモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県あわら市北金津', '18', '18208', '9190634', '福井県', 'フクイケン', 'あわら市', 'アワラシ', '北金津', 'キタカナヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県あわら市牛ノ谷', '18', '18208', '9190721', '福井県', 'フクイケン', 'あわら市', 'アワラシ', '牛ノ谷', 'ウシノヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県あわら市畝市野々', '18', '18208', '9190722', '福井県', 'フクイケン', 'あわら市', 'アワラシ', '畝市野々', 'ウネイチノノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県あわら市熊坂', '18', '18208', '9190723', '福井県', 'フクイケン', 'あわら市', 'アワラシ', '熊坂', 'クマサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県あわら市上野', '18', '18208', '9190724', '福井県', 'フクイケン', 'あわら市', 'アワラシ', '上野', 'ウワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県あわら市前谷', '18', '18208', '9190725', '福井県', 'フクイケン', 'あわら市', 'アワラシ', '前谷', 'マエダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県あわら市笹岡', '18', '18208', '9190726', '福井県', 'フクイケン', 'あわら市', 'アワラシ', '笹岡', 'ササオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県あわら市下金屋', '18', '18208', '9190727', '福井県', 'フクイケン', 'あわら市', 'アワラシ', '下金屋', 'シモカナヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県あわら市権世市野々', '18', '18208', '9190731', '福井県', 'フクイケン', 'あわら市', 'アワラシ', '権世市野々', 'ゴンゼイチノノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県あわら市鎌谷', '18', '18208', '9190732', '福井県', 'フクイケン', 'あわら市', 'アワラシ', '鎌谷', 'カマダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県あわら市清滝', '18', '18208', '9190733', '福井県', 'フクイケン', 'あわら市', 'アワラシ', '清滝', 'キヨタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県あわら市東山', '18', '18208', '9190734', '福井県', 'フクイケン', 'あわら市', 'アワラシ', '東山', 'ヒガシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県あわら市後山', '18', '18208', '9190735', '福井県', 'フクイケン', 'あわら市', 'アワラシ', '後山', 'ウシロヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県あわら市椚', '18', '18208', '9190736', '福井県', 'フクイケン', 'あわら市', 'アワラシ', '椚', 'クヌギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県あわら市権世', '18', '18208', '9190737', '福井県', 'フクイケン', 'あわら市', 'アワラシ', '権世', 'ゴンゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県あわら市中川', '18', '18208', '9190741', '福井県', 'フクイケン', 'あわら市', 'アワラシ', '中川', 'ナカガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県あわら市瓜生', '18', '18208', '9190742', '福井県', 'フクイケン', 'あわら市', 'アワラシ', '瓜生', 'ウリュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県あわら市南疋田', '18', '18208', '9190743', '福井県', 'フクイケン', 'あわら市', 'アワラシ', '南疋田', 'ミナミヒキダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県あわら市北疋田', '18', '18208', '9190744', '福井県', 'フクイケン', 'あわら市', 'アワラシ', '北疋田', 'キタヒキダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県あわら市次郎丸', '18', '18208', '9190745', '福井県', 'フクイケン', 'あわら市', 'アワラシ', '次郎丸', 'ジロウマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県あわら市東田中', '18', '18208', '9190746', '福井県', 'フクイケン', 'あわら市', 'アワラシ', '東田中', 'ヒガシタナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県あわら市御簾尾', '18', '18208', '9190747', '福井県', 'フクイケン', 'あわら市', 'アワラシ', '御簾尾', 'ミスノオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県あわら市北野', '18', '18208', '9190748', '福井県', 'フクイケン', 'あわら市', 'アワラシ', '北野', 'キタノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県あわら市北', '18', '18208', '9190749', '福井県', 'フクイケン', 'あわら市', 'アワラシ', '北', 'キタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県あわら市細呂木', '18', '18208', '9190801', '福井県', 'フクイケン', 'あわら市', 'アワラシ', '細呂木', 'ホソロギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県あわら市橋屋', '18', '18208', '9190802', '福井県', 'フクイケン', 'あわら市', 'アワラシ', '橋屋', 'ハシヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県あわら市樋山', '18', '18208', '9190803', '福井県', 'フクイケン', 'あわら市', 'アワラシ', '樋山', 'ヒヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県あわら市沢', '18', '18208', '9190804', '福井県', 'フクイケン', 'あわら市', 'アワラシ', '沢', 'サワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県あわら市滝', '18', '18208', '9190805', '福井県', 'フクイケン', 'あわら市', 'アワラシ', '滝', 'タキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県あわら市宮谷', '18', '18208', '9190806', '福井県', 'フクイケン', 'あわら市', 'アワラシ', '宮谷', 'ミヤダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県あわら市指中', '18', '18208', '9190807', '福井県', 'フクイケン', 'あわら市', 'アワラシ', '指中', 'ユビナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県あわら市蓮ケ浦', '18', '18208', '9190811', '福井県', 'フクイケン', 'あわら市', 'アワラシ', '蓮ケ浦', 'ハスガウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県あわら市柿原', '18', '18208', '9190812', '福井県', 'フクイケン', 'あわら市', 'アワラシ', '柿原', 'カキバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県あわら市山西方寺', '18', '18208', '9190813', '福井県', 'フクイケン', 'あわら市', 'アワラシ', '山西方寺', 'ヤマサイホウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県あわら市青ノ木', '18', '18208', '9190814', '福井県', 'フクイケン', 'あわら市', 'アワラシ', '青ノ木', 'アオノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県あわら市清王', '18', '18208', '9190815', '福井県', 'フクイケン', 'あわら市', 'アワラシ', '清王', 'セイオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県あわら市山十楽', '18', '18208', '9190816', '福井県', 'フクイケン', 'あわら市', 'アワラシ', '山十楽', 'ヤマジュウラク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県あわら市坂口', '18', '18208', '9190817', '福井県', 'フクイケン', 'あわら市', 'アワラシ', '坂口', 'サカグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方郡美浜町', '18', '18442', '9191100', '福井県', 'フクイケン', '三方郡美浜町', 'ミカタグンミハマチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('122340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方郡美浜町和田', '18', '18442', '9191121', '福井県', 'フクイケン', '三方郡美浜町', 'ミカタグンミハマチョウ', '和田', 'ワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方郡美浜町松原', '18', '18442', '9191122', '福井県', 'フクイケン', '三方郡美浜町', 'ミカタグンミハマチョウ', '松原', 'マツバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方郡美浜町久々子', '18', '18442', '9191123', '福井県', 'フクイケン', '三方郡美浜町', 'ミカタグンミハマチョウ', '久々子', 'クグシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方郡美浜町早瀬', '18', '18442', '9191124', '福井県', 'フクイケン', '三方郡美浜町', 'ミカタグンミハマチョウ', '早瀬', 'ハヤセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方郡美浜町笹田', '18', '18442', '9191125', '福井県', 'フクイケン', '三方郡美浜町', 'ミカタグンミハマチョウ', '笹田', 'ササダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方郡美浜町日向', '18', '18442', '9191126', '福井県', 'フクイケン', '三方郡美浜町', 'ミカタグンミハマチョウ', '日向', 'ヒルガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方郡美浜町木野', '18', '18442', '9191131', '福井県', 'フクイケン', '三方郡美浜町', 'ミカタグンミハマチョウ', '木野', 'キノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方郡美浜町佐柿', '18', '18442', '9191132', '福井県', 'フクイケン', '三方郡美浜町', 'ミカタグンミハマチョウ', '佐柿', 'サガキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方郡美浜町麻生', '18', '18442', '9191133', '福井県', 'フクイケン', '三方郡美浜町', 'ミカタグンミハマチョウ', '麻生', 'アソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方郡美浜町宮代', '18', '18442', '9191134', '福井県', 'フクイケン', '三方郡美浜町', 'ミカタグンミハマチョウ', '宮代', 'ミヤシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方郡美浜町五十谷', '18', '18442', '9191135', '福井県', 'フクイケン', '三方郡美浜町', 'ミカタグンミハマチョウ', '五十谷', 'イサダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方郡美浜町安江', '18', '18442', '9191135', '福井県', 'フクイケン', '三方郡美浜町', 'ミカタグンミハマチョウ', '安江', 'ヤスエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方郡美浜町寄戸', '18', '18442', '9191135', '福井県', 'フクイケン', '三方郡美浜町', 'ミカタグンミハマチョウ', '寄戸', 'ヨリト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方郡美浜町中寺', '18', '18442', '9191136', '福井県', 'フクイケン', '三方郡美浜町', 'ミカタグンミハマチョウ', '中寺', 'ナカデラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方郡美浜町南市', '18', '18442', '9191137', '福井県', 'フクイケン', '三方郡美浜町', 'ミカタグンミハマチョウ', '南市', 'ミナミイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方郡美浜町河原市', '18', '18442', '9191138', '福井県', 'フクイケン', '三方郡美浜町', 'ミカタグンミハマチョウ', '河原市', 'カワライチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方郡美浜町郷市', '18', '18442', '9191141', '福井県', 'フクイケン', '三方郡美浜町', 'ミカタグンミハマチョウ', '郷市', 'ゴイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方郡美浜町興道寺', '18', '18442', '9191142', '福井県', 'フクイケン', '三方郡美浜町', 'ミカタグンミハマチョウ', '興道寺', 'コウドウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方郡美浜町佐野', '18', '18442', '9191143', '福井県', 'フクイケン', '三方郡美浜町', 'ミカタグンミハマチョウ', '佐野', 'サノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方郡美浜町新庄', '18', '18442', '9191144', '福井県', 'フクイケン', '三方郡美浜町', 'ミカタグンミハマチョウ', '新庄', 'シンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方郡美浜町金山', '18', '18442', '9191145', '福井県', 'フクイケン', '三方郡美浜町', 'ミカタグンミハマチョウ', '金山', 'カナヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方郡美浜町大薮', '18', '18442', '9191146', '福井県', 'フクイケン', '三方郡美浜町', 'ミカタグンミハマチョウ', '大薮', 'オオヤブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方郡美浜町気山', '18', '18442', '9191147', '福井県', 'フクイケン', '三方郡美浜町', 'ミカタグンミハマチョウ', '気山', 'キヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方郡美浜町丹生', '18', '18442', '9191201', '福井県', 'フクイケン', '三方郡美浜町', 'ミカタグンミハマチョウ', '丹生', 'ニュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方郡美浜町竹波', '18', '18442', '9191202', '福井県', 'フクイケン', '三方郡美浜町', 'ミカタグンミハマチョウ', '竹波', 'タケナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方郡美浜町菅浜', '18', '18442', '9191203', '福井県', 'フクイケン', '三方郡美浜町', 'ミカタグンミハマチョウ', '菅浜', 'スガハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方郡美浜町北田', '18', '18442', '9191204', '福井県', 'フクイケン', '三方郡美浜町', 'ミカタグンミハマチョウ', '北田', 'キタダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方郡美浜町佐田', '18', '18442', '9191205', '福井県', 'フクイケン', '三方郡美浜町', 'ミカタグンミハマチョウ', '佐田', 'サタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方郡美浜町太田', '18', '18442', '9191206', '福井県', 'フクイケン', '三方郡美浜町', 'ミカタグンミハマチョウ', '太田', 'オオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方郡美浜町山上', '18', '18442', '9191207', '福井県', 'フクイケン', '三方郡美浜町', 'ミカタグンミハマチョウ', '山上', 'ヤマガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方郡美浜町坂尻', '18', '18442', '9191208', '福井県', 'フクイケン', '三方郡美浜町', 'ミカタグンミハマチョウ', '坂尻', 'サカジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県敦賀市白木', '18', '18202', '9191279', '福井県', 'フクイケン', '敦賀市', 'ツルガシ', '白木', 'シラキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方上中郡若狭町', '18', '18501', '9191300', '福井県', 'フクイケン', '三方上中郡若狭町', 'ミカタカミナカグンワカサチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('122374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方上中郡若狭町気山', '18', '18501', '9191301', '福井県', 'フクイケン', '三方上中郡若狭町', 'ミカタカミナカグンワカサチョウ', '気山', 'キヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方上中郡若狭町上瀬', '18', '18501', '9191302', '福井県', 'フクイケン', '三方上中郡若狭町', 'ミカタカミナカグンワカサチョウ', '上瀬', 'ウワセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方上中郡若狭町三方', '18', '18501', '9191303', '福井県', 'フクイケン', '三方上中郡若狭町', 'ミカタカミナカグンワカサチョウ', '三方', 'ミカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方上中郡若狭町生倉', '18', '18501', '9191304', '福井県', 'フクイケン', '三方上中郡若狭町', 'ミカタカミナカグンワカサチョウ', '生倉', 'イクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方上中郡若狭町北前川', '18', '18501', '9191305', '福井県', 'フクイケン', '三方上中郡若狭町', 'ミカタカミナカグンワカサチョウ', '北前川', 'キタマエガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方上中郡若狭町南前川', '18', '18501', '9191306', '福井県', 'フクイケン', '三方上中郡若狭町', 'ミカタカミナカグンワカサチョウ', '南前川', 'ミナミマエガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方上中郡若狭町藤井', '18', '18501', '9191311', '福井県', 'フクイケン', '三方上中郡若狭町', 'ミカタカミナカグンワカサチョウ', '藤井', 'フジイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方上中郡若狭町相田', '18', '18501', '9191312', '福井県', 'フクイケン', '三方上中郡若狭町', 'ミカタカミナカグンワカサチョウ', '相田', 'アイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方上中郡若狭町横渡', '18', '18501', '9191313', '福井県', 'フクイケン', '三方上中郡若狭町', 'ミカタカミナカグンワカサチョウ', '横渡', 'ヨコワタリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方上中郡若狭町能登野', '18', '18501', '9191314', '福井県', 'フクイケン', '三方上中郡若狭町', 'ミカタカミナカグンワカサチョウ', '能登野', 'ノトノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方上中郡若狭町高岸', '18', '18501', '9191315', '福井県', 'フクイケン', '三方上中郡若狭町', 'ミカタカミナカグンワカサチョウ', '高岸', 'タカギシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方上中郡若狭町井崎', '18', '18501', '9191316', '福井県', 'フクイケン', '三方上中郡若狭町', 'ミカタカミナカグンワカサチョウ', '井崎', 'イザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方上中郡若狭町上野', '18', '18501', '9191321', '福井県', 'フクイケン', '三方上中郡若狭町', 'ミカタカミナカグンワカサチョウ', '上野', 'ウエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方上中郡若狭町成願寺', '18', '18501', '9191322', '福井県', 'フクイケン', '三方上中郡若狭町', 'ミカタカミナカグンワカサチョウ', '成願寺', 'ジョウガンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方上中郡若狭町倉見', '18', '18501', '9191323', '福井県', 'フクイケン', '三方上中郡若狭町', 'ミカタカミナカグンワカサチョウ', '倉見', 'クラミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方上中郡若狭町白屋', '18', '18501', '9191324', '福井県', 'フクイケン', '三方上中郡若狭町', 'ミカタカミナカグンワカサチョウ', '白屋', 'シロヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方上中郡若狭町岩屋', '18', '18501', '9191325', '福井県', 'フクイケン', '三方上中郡若狭町', 'ミカタカミナカグンワカサチョウ', '岩屋', 'イワヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方上中郡若狭町田上', '18', '18501', '9191326', '福井県', 'フクイケン', '三方上中郡若狭町', 'ミカタカミナカグンワカサチョウ', '田上', 'タガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方上中郡若狭町東黒田', '18', '18501', '9191327', '福井県', 'フクイケン', '三方上中郡若狭町', 'ミカタカミナカグンワカサチョウ', '東黒田', 'ヒガシクロタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方上中郡若狭町三十三団地', '18', '18501', '9191328', '福井県', 'フクイケン', '三方上中郡若狭町', 'ミカタカミナカグンワカサチョウ', '三十三団地', 'ミソミダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方上中郡若狭町鳥浜', '18', '18501', '9191331', '福井県', 'フクイケン', '三方上中郡若狭町', 'ミカタカミナカグンワカサチョウ', '鳥浜', 'トリハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方上中郡若狭町館川', '18', '18501', '9191332', '福井県', 'フクイケン', '三方上中郡若狭町', 'ミカタカミナカグンワカサチョウ', '館川', 'タチカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方上中郡若狭町中央', '18', '18501', '9191333', '福井県', 'フクイケン', '三方上中郡若狭町', 'ミカタカミナカグンワカサチョウ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方上中郡若狭町田名', '18', '18501', '9191334', '福井県', 'フクイケン', '三方上中郡若狭町', 'ミカタカミナカグンワカサチョウ', '田名', 'タナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方上中郡若狭町佐古', '18', '18501', '9191335', '福井県', 'フクイケン', '三方上中郡若狭町', 'ミカタカミナカグンワカサチョウ', '佐古', 'サコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方上中郡若狭町向笠', '18', '18501', '9191336', '福井県', 'フクイケン', '三方上中郡若狭町', 'ミカタカミナカグンワカサチョウ', '向笠', 'ムカサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方上中郡若狭町常神', '18', '18501', '9191451', '福井県', 'フクイケン', '三方上中郡若狭町', 'ミカタカミナカグンワカサチョウ', '常神', 'ツネカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方上中郡若狭町神子', '18', '18501', '9191452', '福井県', 'フクイケン', '三方上中郡若狭町', 'ミカタカミナカグンワカサチョウ', '神子', 'ミコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方上中郡若狭町小川', '18', '18501', '9191453', '福井県', 'フクイケン', '三方上中郡若狭町', 'ミカタカミナカグンワカサチョウ', '小川', 'オガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方上中郡若狭町遊子', '18', '18501', '9191454', '福井県', 'フクイケン', '三方上中郡若狭町', 'ミカタカミナカグンワカサチョウ', '遊子', 'ユウシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方上中郡若狭町塩坂越', '18', '18501', '9191455', '福井県', 'フクイケン', '三方上中郡若狭町', 'ミカタカミナカグンワカサチョウ', '塩坂越', 'シャクシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方上中郡若狭町海山', '18', '18501', '9191461', '福井県', 'フクイケン', '三方上中郡若狭町', 'ミカタカミナカグンワカサチョウ', '海山', 'ウミヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方上中郡若狭町島の内', '18', '18501', '9191462', '福井県', 'フクイケン', '三方上中郡若狭町', 'ミカタカミナカグンワカサチョウ', '島の内', 'シマノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方上中郡若狭町田井', '18', '18501', '9191462', '福井県', 'フクイケン', '三方上中郡若狭町', 'ミカタカミナカグンワカサチョウ', '田井', 'タイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方上中郡若狭町成出', '18', '18501', '9191463', '福井県', 'フクイケン', '三方上中郡若狭町', 'ミカタカミナカグンワカサチョウ', '成出', 'ナルデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方上中郡若狭町世久見', '18', '18501', '9191464', '福井県', 'フクイケン', '三方上中郡若狭町', 'ミカタカミナカグンワカサチョウ', '世久見', 'セクミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方上中郡若狭町海士坂', '18', '18501', '9191501', '福井県', 'フクイケン', '三方上中郡若狭町', 'ミカタカミナカグンワカサチョウ', '海士坂', 'アマサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方上中郡若狭町麻生野', '18', '18501', '9191502', '福井県', 'フクイケン', '三方上中郡若狭町', 'ミカタカミナカグンワカサチョウ', '麻生野', 'アソノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方上中郡若狭町上黒田', '18', '18501', '9191503', '福井県', 'フクイケン', '三方上中郡若狭町', 'ミカタカミナカグンワカサチョウ', '上黒田', 'カミクロダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方上中郡若狭町大鳥羽', '18', '18501', '9191504', '福井県', 'フクイケン', '三方上中郡若狭町', 'ミカタカミナカグンワカサチョウ', '大鳥羽', 'オオトバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方上中郡若狭町長江', '18', '18501', '9191505', '福井県', 'フクイケン', '三方上中郡若狭町', 'ミカタカミナカグンワカサチョウ', '長江', 'ナガエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方上中郡若狭町持田', '18', '18501', '9191506', '福井県', 'フクイケン', '三方上中郡若狭町', 'ミカタカミナカグンワカサチョウ', '持田', 'モチダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方上中郡若狭町有田', '18', '18501', '9191507', '福井県', 'フクイケン', '三方上中郡若狭町', 'ミカタカミナカグンワカサチョウ', '有田', 'アリダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方上中郡若狭町三生野', '18', '18501', '9191511', '福井県', 'フクイケン', '三方上中郡若狭町', 'ミカタカミナカグンワカサチョウ', '三生野', 'ミショウノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方上中郡若狭町無悪', '18', '18501', '9191512', '福井県', 'フクイケン', '三方上中郡若狭町', 'ミカタカミナカグンワカサチョウ', '無悪', 'サカナシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方上中郡若狭町三田', '18', '18501', '9191513', '福井県', 'フクイケン', '三方上中郡若狭町', 'ミカタカミナカグンワカサチョウ', '三田', 'ミタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方上中郡若狭町小原', '18', '18501', '9191514', '福井県', 'フクイケン', '三方上中郡若狭町', 'ミカタカミナカグンワカサチョウ', '小原', 'オハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方上中郡若狭町南', '18', '18501', '9191515', '福井県', 'フクイケン', '三方上中郡若狭町', 'ミカタカミナカグンワカサチョウ', '南', 'ミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方上中郡若狭町山内', '18', '18501', '9191516', '福井県', 'フクイケン', '三方上中郡若狭町', 'ミカタカミナカグンワカサチョウ', '山内', 'ヤマウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方上中郡若狭町下タ中', '18', '18501', '9191521', '福井県', 'フクイケン', '三方上中郡若狭町', 'ミカタカミナカグンワカサチョウ', '下タ中', 'シタナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方上中郡若狭町末野', '18', '18501', '9191522', '福井県', 'フクイケン', '三方上中郡若狭町', 'ミカタカミナカグンワカサチョウ', '末野', 'スエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方上中郡若狭町安賀里', '18', '18501', '9191523', '福井県', 'フクイケン', '三方上中郡若狭町', 'ミカタカミナカグンワカサチョウ', '安賀里', 'アガリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方上中郡若狭町脇袋', '18', '18501', '9191524', '福井県', 'フクイケン', '三方上中郡若狭町', 'ミカタカミナカグンワカサチョウ', '脇袋', 'ワキブクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方上中郡若狭町瓜生', '18', '18501', '9191525', '福井県', 'フクイケン', '三方上中郡若狭町', 'ミカタカミナカグンワカサチョウ', '瓜生', 'ウリュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方上中郡若狭町関', '18', '18501', '9191526', '福井県', 'フクイケン', '三方上中郡若狭町', 'ミカタカミナカグンワカサチョウ', '関', 'セキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方上中郡若狭町上吉田', '18', '18501', '9191527', '福井県', 'フクイケン', '三方上中郡若狭町', 'ミカタカミナカグンワカサチョウ', '上吉田', 'カミヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方上中郡若狭町下吉田', '18', '18501', '9191528', '福井県', 'フクイケン', '三方上中郡若狭町', 'ミカタカミナカグンワカサチョウ', '下吉田', 'シモヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方上中郡若狭町新道', '18', '18501', '9191531', '福井県', 'フクイケン', '三方上中郡若狭町', 'ミカタカミナカグンワカサチョウ', '新道', 'シンドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方上中郡若狭町熊川', '18', '18501', '9191532', '福井県', 'フクイケン', '三方上中郡若狭町', 'ミカタカミナカグンワカサチョウ', '熊川', 'クマガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方上中郡若狭町河内', '18', '18501', '9191533', '福井県', 'フクイケン', '三方上中郡若狭町', 'ミカタカミナカグンワカサチョウ', '河内', 'コウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方上中郡若狭町仮屋', '18', '18501', '9191534', '福井県', 'フクイケン', '三方上中郡若狭町', 'ミカタカミナカグンワカサチョウ', '仮屋', 'カリヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方上中郡若狭町若王子', '18', '18501', '9191535', '福井県', 'フクイケン', '三方上中郡若狭町', 'ミカタカミナカグンワカサチョウ', '若王子', 'ワカオウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方上中郡若狭町三宅', '18', '18501', '9191536', '福井県', 'フクイケン', '三方上中郡若狭町', 'ミカタカミナカグンワカサチョウ', '三宅', 'ミヤケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方上中郡若狭町市場', '18', '18501', '9191541', '福井県', 'フクイケン', '三方上中郡若狭町', 'ミカタカミナカグンワカサチョウ', '市場', 'イチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方上中郡若狭町井ノ口', '18', '18501', '9191542', '福井県', 'フクイケン', '三方上中郡若狭町', 'ミカタカミナカグンワカサチョウ', '井ノ口', 'イノクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方上中郡若狭町天徳寺', '18', '18501', '9191543', '福井県', 'フクイケン', '三方上中郡若狭町', 'ミカタカミナカグンワカサチョウ', '天徳寺', 'テントクジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方上中郡若狭町神谷', '18', '18501', '9191544', '福井県', 'フクイケン', '三方上中郡若狭町', 'ミカタカミナカグンワカサチョウ', '神谷', 'コウダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方上中郡若狭町日笠', '18', '18501', '9191545', '福井県', 'フクイケン', '三方上中郡若狭町', 'ミカタカミナカグンワカサチョウ', '日笠', 'ヒカサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方上中郡若狭町杉山', '18', '18501', '9191551', '福井県', 'フクイケン', '三方上中郡若狭町', 'ミカタカミナカグンワカサチョウ', '杉山', 'スギヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方上中郡若狭町若狭テクノバレー', '18', '18501', '9191552', '福井県', 'フクイケン', '三方上中郡若狭町', 'ミカタカミナカグンワカサチョウ', '若狭テクノバレー', 'ワカサテクノバレー', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方上中郡若狭町堤', '18', '18501', '9191553', '福井県', 'フクイケン', '三方上中郡若狭町', 'ミカタカミナカグンワカサチョウ', '堤', 'ツツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方上中郡若狭町兼田', '18', '18501', '9191554', '福井県', 'フクイケン', '三方上中郡若狭町', 'ミカタカミナカグンワカサチョウ', '兼田', 'カネダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方上中郡若狭町武生', '18', '18501', '9191555', '福井県', 'フクイケン', '三方上中郡若狭町', 'ミカタカミナカグンワカサチョウ', '武生', 'ムシュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方上中郡若狭町玉置', '18', '18501', '9191556', '福井県', 'フクイケン', '三方上中郡若狭町', 'ミカタカミナカグンワカサチョウ', '玉置', 'タマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方上中郡若狭町上野木', '18', '18501', '9191557', '福井県', 'フクイケン', '三方上中郡若狭町', 'ミカタカミナカグンワカサチョウ', '上野木', 'カミノギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方上中郡若狭町中野木', '18', '18501', '9191558', '福井県', 'フクイケン', '三方上中郡若狭町', 'ミカタカミナカグンワカサチョウ', '中野木', 'ナカノギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県三方上中郡若狭町下野木', '18', '18501', '9191559', '福井県', 'フクイケン', '三方上中郡若狭町', 'ミカタカミナカグンワカサチョウ', '下野木', 'シモノギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大飯郡おおい町', '18', '18483', '9192100', '福井県', 'フクイケン', '大飯郡おおい町', 'オオイグンオオイチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('122458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大飯郡おおい町大島', '18', '18483', '9192101', '福井県', 'フクイケン', '大飯郡おおい町', 'オオイグンオオイチョウ', '大島', 'オオシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大飯郡おおい町長井', '18', '18483', '9192102', '福井県', 'フクイケン', '大飯郡おおい町', 'オオイグンオオイチョウ', '長井', 'ナガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大飯郡おおい町尾内', '18', '18483', '9192103', '福井県', 'フクイケン', '大飯郡おおい町', 'オオイグンオオイチョウ', '尾内', 'オナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大飯郡おおい町成和', '18', '18483', '9192104', '福井県', 'フクイケン', '大飯郡おおい町', 'オオイグンオオイチョウ', '成和', 'セイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大飯郡おおい町小堀', '18', '18483', '9192105', '福井県', 'フクイケン', '大飯郡おおい町', 'オオイグンオオイチョウ', '小堀', 'コホリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大飯郡おおい町犬見', '18', '18483', '9192106', '福井県', 'フクイケン', '大飯郡おおい町', 'オオイグンオオイチョウ', '犬見', 'イヌミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大飯郡おおい町成海', '18', '18483', '9192107', '福井県', 'フクイケン', '大飯郡おおい町', 'オオイグンオオイチョウ', '成海', 'ナルミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大飯郡おおい町本郷', '18', '18483', '9192111', '福井県', 'フクイケン', '大飯郡おおい町', 'オオイグンオオイチョウ', '本郷', 'ホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大飯郡おおい町山田', '18', '18483', '9192112', '福井県', 'フクイケン', '大飯郡おおい町', 'オオイグンオオイチョウ', '山田', 'ヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大飯郡おおい町芝崎', '18', '18483', '9192113', '福井県', 'フクイケン', '大飯郡おおい町', 'オオイグンオオイチョウ', '芝崎', 'シバサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大飯郡おおい町野尻', '18', '18483', '9192114', '福井県', 'フクイケン', '大飯郡おおい町', 'オオイグンオオイチョウ', '野尻', 'ノジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大飯郡おおい町父子', '18', '18483', '9192115', '福井県', 'フクイケン', '大飯郡おおい町', 'オオイグンオオイチョウ', '父子', 'チチシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大飯郡おおい町岡田', '18', '18483', '9192116', '福井県', 'フクイケン', '大飯郡おおい町', 'オオイグンオオイチョウ', '岡田', 'オカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大飯郡おおい町万願寺', '18', '18483', '9192121', '福井県', 'フクイケン', '大飯郡おおい町', 'オオイグンオオイチョウ', '万願寺', 'マンガンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大飯郡おおい町神崎', '18', '18483', '9192122', '福井県', 'フクイケン', '大飯郡おおい町', 'オオイグンオオイチョウ', '神崎', 'コウザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大飯郡おおい町鹿野', '18', '18483', '9192123', '福井県', 'フクイケン', '大飯郡おおい町', 'オオイグンオオイチョウ', '鹿野', 'シカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大飯郡おおい町小車田', '18', '18483', '9192124', '福井県', 'フクイケン', '大飯郡おおい町', 'オオイグンオオイチョウ', '小車田', 'コシヤタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大飯郡おおい町石山', '18', '18483', '9192125', '福井県', 'フクイケン', '大飯郡おおい町', 'オオイグンオオイチョウ', '石山', 'イシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大飯郡おおい町佐畑', '18', '18483', '9192126', '福井県', 'フクイケン', '大飯郡おおい町', 'オオイグンオオイチョウ', '佐畑', 'サバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大飯郡おおい町笹谷', '18', '18483', '9192127', '福井県', 'フクイケン', '大飯郡おおい町', 'オオイグンオオイチョウ', '笹谷', 'ササダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大飯郡おおい町岡安', '18', '18483', '9192128', '福井県', 'フクイケン', '大飯郡おおい町', 'オオイグンオオイチョウ', '岡安', 'オカヤス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大飯郡おおい町広岡', '18', '18483', '9192129', '福井県', 'フクイケン', '大飯郡おおい町', 'オオイグンオオイチョウ', '広岡', 'ヒロオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大飯郡おおい町福谷', '18', '18483', '9192131', '福井県', 'フクイケン', '大飯郡おおい町', 'オオイグンオオイチョウ', '福谷', 'フクタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大飯郡おおい町安川', '18', '18483', '9192132', '福井県', 'フクイケン', '大飯郡おおい町', 'オオイグンオオイチョウ', '安川', 'ヤスカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大飯郡おおい町久保', '18', '18483', '9192133', '福井県', 'フクイケン', '大飯郡おおい町', 'オオイグンオオイチョウ', '久保', 'クボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大飯郡おおい町川上', '18', '18483', '9192134', '福井県', 'フクイケン', '大飯郡おおい町', 'オオイグンオオイチョウ', '川上', 'カワカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大飯郡おおい町三森', '18', '18483', '9192135', '福井県', 'フクイケン', '大飯郡おおい町', 'オオイグンオオイチョウ', '三森', 'ミツモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大飯郡高浜町', '18', '18481', '9192200', '福井県', 'フクイケン', '大飯郡高浜町', 'オオイグンタカハマチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('122486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大飯郡高浜町和田', '18', '18481', '9192201', '福井県', 'フクイケン', '大飯郡高浜町', 'オオイグンタカハマチョウ', '和田', 'ワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大飯郡高浜町安土', '18', '18481', '9192202', '福井県', 'フクイケン', '大飯郡高浜町', 'オオイグンタカハマチョウ', '安土', 'アヅチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大飯郡高浜町水明', '18', '18481', '9192203', '福井県', 'フクイケン', '大飯郡高浜町', 'オオイグンタカハマチョウ', '水明', 'スイメイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大飯郡高浜町青戸', '18', '18481', '9192204', '福井県', 'フクイケン', '大飯郡高浜町', 'オオイグンタカハマチョウ', '青戸', 'アオト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大飯郡高浜町下車持', '18', '18481', '9192205', '福井県', 'フクイケン', '大飯郡高浜町', 'オオイグンタカハマチョウ', '下車持', 'シモクラモチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大飯郡高浜町上車持', '18', '18481', '9192206', '福井県', 'フクイケン', '大飯郡高浜町', 'オオイグンタカハマチョウ', '上車持', 'カミクラモチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大飯郡高浜町馬居寺', '18', '18481', '9192207', '福井県', 'フクイケン', '大飯郡高浜町', 'オオイグンタカハマチョウ', '馬居寺', 'マゴジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大飯郡高浜町中津海', '18', '18481', '9192211', '福井県', 'フクイケン', '大飯郡高浜町', 'オオイグンタカハマチョウ', '中津海', 'ナカツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大飯郡高浜町鐘寄', '18', '18481', '9192212', '福井県', 'フクイケン', '大飯郡高浜町', 'オオイグンタカハマチョウ', '鐘寄', 'カネヨリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大飯郡高浜町畑', '18', '18481', '9192213', '福井県', 'フクイケン', '大飯郡高浜町', 'オオイグンタカハマチョウ', '畑', 'ハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大飯郡高浜町湯谷', '18', '18481', '9192214', '福井県', 'フクイケン', '大飯郡高浜町', 'オオイグンタカハマチョウ', '湯谷', 'ユタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大飯郡高浜町南団地', '18', '18481', '9192215', '福井県', 'フクイケン', '大飯郡高浜町', 'オオイグンタカハマチョウ', '南団地', 'ミナミダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大飯郡高浜町笠原', '18', '18481', '9192216', '福井県', 'フクイケン', '大飯郡高浜町', 'オオイグンタカハマチョウ', '笠原', 'カサハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大飯郡高浜町子生', '18', '18481', '9192216', '福井県', 'フクイケン', '大飯郡高浜町', 'オオイグンタカハマチョウ', '子生', 'コビ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大飯郡高浜町坂田', '18', '18481', '9192216', '福井県', 'フクイケン', '大飯郡高浜町', 'オオイグンタカハマチョウ', '坂田', 'サカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大飯郡高浜町事代', '18', '18481', '9192221', '福井県', 'フクイケン', '大飯郡高浜町', 'オオイグンタカハマチョウ', '事代', 'コトシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大飯郡高浜町岩神', '18', '18481', '9192222', '福井県', 'フクイケン', '大飯郡高浜町', 'オオイグンタカハマチョウ', '岩神', 'イワガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大飯郡高浜町紫水ケ丘', '18', '18481', '9192223', '福井県', 'フクイケン', '大飯郡高浜町', 'オオイグンタカハマチョウ', '紫水ケ丘', 'シスイガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大飯郡高浜町薗部', '18', '18481', '9192224', '福井県', 'フクイケン', '大飯郡高浜町', 'オオイグンタカハマチョウ', '薗部', 'ソノベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大飯郡高浜町宮崎', '18', '18481', '9192225', '福井県', 'フクイケン', '大飯郡高浜町', 'オオイグンタカハマチョウ', '宮崎', 'ミヤザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大飯郡高浜町立石', '18', '18481', '9192226', '福井県', 'フクイケン', '大飯郡高浜町', 'オオイグンタカハマチョウ', '立石', 'タテイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大飯郡高浜町若宮', '18', '18481', '9192227', '福井県', 'フクイケン', '大飯郡高浜町', 'オオイグンタカハマチョウ', '若宮', 'ワカミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大飯郡高浜町塩土', '18', '18481', '9192228', '福井県', 'フクイケン', '大飯郡高浜町', 'オオイグンタカハマチョウ', '塩土', 'シオド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大飯郡高浜町三明', '18', '18481', '9192229', '福井県', 'フクイケン', '大飯郡高浜町', 'オオイグンタカハマチョウ', '三明', 'サンメイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大飯郡高浜町山中', '18', '18481', '9192351', '福井県', 'フクイケン', '大飯郡高浜町', 'オオイグンタカハマチョウ', '山中', 'ヤマナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大飯郡高浜町鎌倉', '18', '18481', '9192352', '福井県', 'フクイケン', '大飯郡高浜町', 'オオイグンタカハマチョウ', '鎌倉', 'カマクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大飯郡高浜町下', '18', '18481', '9192353', '福井県', 'フクイケン', '大飯郡高浜町', 'オオイグンタカハマチョウ', '下', 'シモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大飯郡高浜町宮尾', '18', '18481', '9192354', '福井県', 'フクイケン', '大飯郡高浜町', 'オオイグンタカハマチョウ', '宮尾', 'ミヤオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大飯郡高浜町日引', '18', '18481', '9192355', '福井県', 'フクイケン', '大飯郡高浜町', 'オオイグンタカハマチョウ', '日引', 'ヒビキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大飯郡高浜町上瀬', '18', '18481', '9192356', '福井県', 'フクイケン', '大飯郡高浜町', 'オオイグンタカハマチョウ', '上瀬', 'ウワセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大飯郡高浜町音海', '18', '18481', '9192361', '福井県', 'フクイケン', '大飯郡高浜町', 'オオイグンタカハマチョウ', '音海', 'オトミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大飯郡高浜町田ノ浦', '18', '18481', '9192362', '福井県', 'フクイケン', '大飯郡高浜町', 'オオイグンタカハマチョウ', '田ノ浦', 'タノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大飯郡高浜町小黒飯', '18', '18481', '9192363', '福井県', 'フクイケン', '大飯郡高浜町', 'オオイグンタカハマチョウ', '小黒飯', 'オグルイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大飯郡高浜町難波江', '18', '18481', '9192364', '福井県', 'フクイケン', '大飯郡高浜町', 'オオイグンタカハマチョウ', '難波江', 'ナバエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大飯郡高浜町神野', '18', '18481', '9192365', '福井県', 'フクイケン', '大飯郡高浜町', 'オオイグンタカハマチョウ', '神野', 'コウノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大飯郡高浜町神野浦', '18', '18481', '9192366', '福井県', 'フクイケン', '大飯郡高浜町', 'オオイグンタカハマチョウ', '神野浦', 'コウノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大飯郡高浜町中山', '18', '18481', '9192371', '福井県', 'フクイケン', '大飯郡高浜町', 'オオイグンタカハマチョウ', '中山', 'ナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大飯郡高浜町高屋', '18', '18481', '9192372', '福井県', 'フクイケン', '大飯郡高浜町', 'オオイグンタカハマチョウ', '高屋', 'タカヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大飯郡高浜町緑ケ丘', '18', '18481', '9192372', '福井県', 'フクイケン', '大飯郡高浜町', 'オオイグンタカハマチョウ', '緑ケ丘', 'ミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大飯郡高浜町小和田', '18', '18481', '9192373', '福井県', 'フクイケン', '大飯郡高浜町', 'オオイグンタカハマチョウ', '小和田', 'コワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大飯郡高浜町高野', '18', '18481', '9192374', '福井県', 'フクイケン', '大飯郡高浜町', 'オオイグンタカハマチョウ', '高野', 'タカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大飯郡高浜町旭ケ丘', '18', '18481', '9192375', '福井県', 'フクイケン', '大飯郡高浜町', 'オオイグンタカハマチョウ', '旭ケ丘', 'アサヒガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大飯郡高浜町蒜畠', '18', '18481', '9192375', '福井県', 'フクイケン', '大飯郡高浜町', 'オオイグンタカハマチョウ', '蒜畠', 'ヒルバタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大飯郡高浜町今寺', '18', '18481', '9192376', '福井県', 'フクイケン', '大飯郡高浜町', 'オオイグンタカハマチョウ', '今寺', 'イマデラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大飯郡高浜町西三松', '18', '18481', '9192381', '福井県', 'フクイケン', '大飯郡高浜町', 'オオイグンタカハマチョウ', '西三松', 'ニシミツマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大飯郡高浜町東三松', '18', '18481', '9192382', '福井県', 'フクイケン', '大飯郡高浜町', 'オオイグンタカハマチョウ', '東三松', 'ヒガシミツマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大飯郡高浜町日置', '18', '18481', '9192383', '福井県', 'フクイケン', '大飯郡高浜町', 'オオイグンタカハマチョウ', '日置', 'ヒキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大飯郡高浜町青', '18', '18481', '9192384', '福井県', 'フクイケン', '大飯郡高浜町', 'オオイグンタカハマチョウ', '青', 'アオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大飯郡高浜町横津海', '18', '18481', '9192385', '福井県', 'フクイケン', '大飯郡高浜町', 'オオイグンタカハマチョウ', '横津海', 'ヨコツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大飯郡高浜町関屋', '18', '18481', '9192386', '福井県', 'フクイケン', '大飯郡高浜町', 'オオイグンタカハマチョウ', '関屋', 'セキヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県大飯郡高浜町六路谷', '18', '18481', '9192387', '福井県', 'フクイケン', '大飯郡高浜町', 'オオイグンタカハマチョウ', '六路谷', 'ロクロダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡美幌町', '01', '01543', '0920000', '北海道', 'ホッカイドウ', '網走郡美幌町', 'アバシリグンビホロチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('122540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市', '17', '17201', '9200000', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('122541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市千木町', '17', '17201', '9200001', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '千木町', 'セギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市千木', '17', '17201', '9200002', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '千木', 'セギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市疋田', '17', '17201', '9200003', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '疋田', 'ヒキダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市疋田町', '17', '17201', '9200004', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '疋田町', 'ヒキダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市高柳町', '17', '17201', '9200005', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '高柳町', 'タカヤナギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市宮保町', '17', '17201', '9200006', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '宮保町', 'ミヤボマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市田中町', '17', '17201', '9200007', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '田中町', 'タナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市今昭町', '17', '17201', '9200008', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '今昭町', 'イマショウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡美幌町高野', '01', '01543', '0920001', '北海道', 'ホッカイドウ', '網走郡美幌町', 'アバシリグンビホロチョウ', '高野', 'タカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市松寺町', '17', '17201', '9200011', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '松寺町', 'マツデラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市磯部町', '17', '17201', '9200012', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '磯部町', 'イソベマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市沖町', '17', '17201', '9200013', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '沖町', 'オキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市諸江町', '17', '17201', '9200014', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '諸江町', 'モロエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市諸江町上丁', '17', '17201', '9200015', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '諸江町', 'モロエマチ', null, null, '上丁', 'カミチョウ');
INSERT INTO `ms_addresses` VALUES ('122555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市諸江町中丁', '17', '17201', '9200016', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '諸江町', 'モロエマチ', null, null, '中丁', 'ナカチョウ');
INSERT INTO `ms_addresses` VALUES ('122556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市諸江町下丁', '17', '17201', '9200017', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '諸江町', 'モロエマチ', null, null, '下丁', 'シモチョウ');
INSERT INTO `ms_addresses` VALUES ('122557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市三口町', '17', '17201', '9200018', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '三口町', 'ミツクチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡美幌町美禽', '01', '01543', '0920002', '北海道', 'ホッカイドウ', '網走郡美幌町', 'アバシリグンビホロチョウ', '美禽', 'ミドリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市七ツ屋町', '17', '17201', '9200021', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '七ツ屋町', 'ナナツヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市北安江', '17', '17201', '9200022', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '北安江', 'キタヤスエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市北安江町', '17', '17201', '9200023', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '北安江町', 'キタヤスエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市西念', '17', '17201', '9200024', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '西念', 'サイネン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市駅西本町', '17', '17201', '9200025', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '駅西本町', 'エキニシホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市西念町', '17', '17201', '9200026', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '西念町', 'サイネンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市駅西新町', '17', '17201', '9200027', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '駅西新町', 'エキニシシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡美幌町鳥里', '01', '01543', '0920003', '北海道', 'ホッカイドウ', '網走郡美幌町', 'アバシリグンビホロチョウ', '鳥里', 'トリサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市広岡', '17', '17201', '9200031', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '広岡', 'ヒロオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市広岡町', '17', '17201', '9200032', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '広岡町', 'ヒロオカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市日吉町', '17', '17201', '9200033', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '日吉町', 'ヒヨシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市醒ケ井町', '17', '17201', '9200034', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '醒ケ井町', 'サメガイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市中橋町', '17', '17201', '9200035', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '中橋町', 'ナカバシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市元菊町', '17', '17201', '9200036', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '元菊町', 'モトギクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡美幌町仲町', '01', '01543', '0920004', '北海道', 'ホッカイドウ', '網走郡美幌町', 'アバシリグンビホロチョウ', '仲町', 'ナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市長田本町', '17', '17201', '9200041', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '長田本町', 'ナガタホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市長田町', '17', '17201', '9200042', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '長田町', 'ナガタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市長田', '17', '17201', '9200043', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '長田', 'ナガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市南広岡町', '17', '17201', '9200044', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '南広岡町', 'ミナミヒロオカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市向中町', '17', '17201', '9200045', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '向中町', 'ムコウナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市大和町', '17', '17201', '9200046', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '大和町', 'ダイワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市大豆田本町', '17', '17201', '9200047', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '大豆田本町', 'マメダホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡美幌町野崎', '01', '01543', '0920005', '北海道', 'ホッカイドウ', '網走郡美幌町', 'アバシリグンビホロチョウ', '野崎', 'ノザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市二口町', '17', '17201', '9200051', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '二口町', 'フタクチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市薬師堂町', '17', '17201', '9200052', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '薬師堂町', 'ヤクシドウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市若宮町', '17', '17201', '9200053', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '若宮町', 'ワカミヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市若宮', '17', '17201', '9200054', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '若宮', 'ワカミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市北町', '17', '17201', '9200055', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '北町', 'キタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市出雲町', '17', '17201', '9200056', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '出雲町', 'イズモマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市桜田町', '17', '17201', '9200057', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '桜田町', 'サクラダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市示野中町', '17', '17201', '9200058', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '示野中町', 'シメノナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市示野町', '17', '17201', '9200059', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '示野町', 'シメノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡美幌町昭野', '01', '01543', '0920006', '北海道', 'ホッカイドウ', '網走郡美幌町', 'アバシリグンビホロチョウ', '昭野', 'アキノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市問屋町', '17', '17201', '9200061', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '問屋町', 'トイヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市割出町', '17', '17201', '9200062', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '割出町', 'ワリダシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市三浦町', '17', '17201', '9200063', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '三浦町', 'ミウラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市南新保町', '17', '17201', '9200064', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '南新保町', 'ミナミシンボマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市二ツ屋町', '17', '17201', '9200065', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '二ツ屋町', 'フタツヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市二宮町', '17', '17201', '9200067', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '二宮町', 'ニノミヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡美幌町豊岡', '01', '01543', '0920007', '北海道', 'ホッカイドウ', '網走郡美幌町', 'アバシリグンビホロチョウ', '豊岡', 'トヨオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市利屋町', '17', '17201', '9200101', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '利屋町', 'トギヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市岸川町', '17', '17201', '9200102', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '岸川町', 'キシガワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市花園八幡町', '17', '17201', '9200103', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '花園八幡町', 'ハナゾノヤワタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市四坊高坂町', '17', '17201', '9200104', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '四坊高坂町', 'シボウタカサカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市四坊町', '17', '17201', '9200104', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '四坊町', 'シボウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市月影町', '17', '17201', '9200105', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '月影町', 'ツキカゲマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市今町', '17', '17201', '9200106', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '今町', 'イママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市二日市町', '17', '17201', '9200107', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '二日市町', 'フツカイチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡美幌町東町', '01', '01543', '0920011', '北海道', 'ホッカイドウ', '網走郡美幌町', 'アバシリグンビホロチョウ', '東町', 'ヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市浅丘町', '17', '17201', '9200111', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '浅丘町', 'アサオカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市榎尾町', '17', '17201', '9200112', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '榎尾町', 'エノキオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市俵原町', '17', '17201', '9200113', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '俵原町', 'タラワラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市加賀朝日町', '17', '17201', '9200114', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '加賀朝日町', 'カガアサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市千杉町', '17', '17201', '9200115', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '千杉町', 'センノスギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市地代町', '17', '17201', '9200116', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '地代町', 'ジダイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡美幌町栄町', '01', '01543', '0920012', '北海道', 'ホッカイドウ', '網走郡美幌町', 'アバシリグンビホロチョウ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市琴町', '17', '17201', '9200121', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '琴町', 'コトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市上平町', '17', '17201', '9200122', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '上平町', 'ウワダイラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市滝下町', '17', '17201', '9200123', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '滝下町', 'タキシタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市中尾町', '17', '17201', '9200124', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '中尾町', 'ナカオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市今泉町', '17', '17201', '9200125', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '今泉町', 'イマイズミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市朝日牧町', '17', '17201', '9200126', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '朝日牧町', 'アサヒマキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市南千谷町', '17', '17201', '9200127', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '南千谷町', 'ミナミセンゴクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市北千石町', '17', '17201', '9200128', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '北千石町', 'キタセンゴクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市琴坂町', '17', '17201', '9200129', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '琴坂町', 'コトサカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡美幌町美芳', '01', '01543', '0920013', '北海道', 'ホッカイドウ', '網走郡美幌町', 'アバシリグンビホロチョウ', '美芳', 'ミヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市東原町', '17', '17201', '9200131', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '東原町', 'ヒガシハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市清水谷町', '17', '17201', '9200132', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '清水谷町', 'シミズダニマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市堀切町', '17', '17201', '9200133', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '堀切町', 'ホリキリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市曲子原町', '17', '17201', '9200134', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '曲子原町', 'マゲシハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市土子原町', '17', '17201', '9200135', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '土子原町', 'ツチコハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市松根町', '17', '17201', '9200136', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '松根町', 'マツネマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市竹又町', '17', '17201', '9200137', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '竹又町', 'タケマタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡美幌町美里', '01', '01543', '0920014', '北海道', 'ホッカイドウ', '網走郡美幌町', 'アバシリグンビホロチョウ', '美里', 'ミサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市直江野町', '17', '17201', '9200141', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '直江野町', 'ナオエノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市納年町', '17', '17201', '9200142', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '納年町', 'ノウネンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市北方町', '17', '17201', '9200143', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '北方町', 'キタガタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市小嶺町', '17', '17201', '9200144', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '小嶺町', 'コミネマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市市瀬町', '17', '17201', '9200145', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '市瀬町', 'イチノセマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市柚木町', '17', '17201', '9200146', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '柚木町', 'ユノキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市不室町', '17', '17201', '9200147', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '不室町', 'フムロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市牧山町', '17', '17201', '9200148', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '牧山町', 'マキヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡美幌町新町', '01', '01543', '0920015', '北海道', 'ホッカイドウ', '網走郡美幌町', 'アバシリグンビホロチョウ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市梨木町', '17', '17201', '9200151', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '梨木町', 'ナシノキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市鳴瀬元町', '17', '17201', '9200152', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '鳴瀬元町', 'ナラセモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市宮野町', '17', '17201', '9200153', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '宮野町', 'ミヤノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市正部町', '17', '17201', '9200154', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '正部町', 'ショウブマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市高坂町', '17', '17201', '9200155', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '高坂町', 'タカサカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市古屋谷町', '17', '17201', '9200156', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '古屋谷町', 'フルヤダニマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市車町', '17', '17201', '9200157', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '車町', 'クルママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡美幌町瑞治', '01', '01543', '0920016', '北海道', 'ホッカイドウ', '網走郡美幌町', 'アバシリグンビホロチョウ', '瑞治', 'ミズハル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市鞁筒町', '17', '17201', '9200161', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '鞁筒町', 'ツヅミドウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市小池町', '17', '17201', '9200162', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '小池町', 'オイケマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市桐山町', '17', '17201', '9200163', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '桐山町', 'キリヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市堅田町', '17', '17201', '9200164', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '堅田町', 'カタタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市深谷町', '17', '17201', '9200165', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '深谷町', 'フカタニマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市四王寺町', '17', '17201', '9200166', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '四王寺町', 'シオウジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市福畠町', '17', '17201', '9200167', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '福畠町', 'フクバタケマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市小野町', '17', '17201', '9200168', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '小野町', 'コノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡美幌町報徳', '01', '01543', '0920017', '北海道', 'ホッカイドウ', '網走郡美幌町', 'アバシリグンビホロチョウ', '報徳', 'ホウトク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市岩出町', '17', '17201', '9200171', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '岩出町', 'イワデマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市河原市町', '17', '17201', '9200172', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '河原市町', 'カワライチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市不動寺町', '17', '17201', '9200173', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '不動寺町', 'フドウジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市薬師町', '17', '17201', '9200174', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '薬師町', 'ヤクシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市上涌波町', '17', '17201', '9200175', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '上涌波町', 'カミワクナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市下涌波町', '17', '17201', '9200176', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '下涌波町', 'シモワクナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市北陽台', '17', '17201', '9200177', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '北陽台', 'ホクヨウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市月浦町', '17', '17201', '9200178', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '月浦町', 'ツキウラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡美幌町田中', '01', '01543', '0920018', '北海道', 'ホッカイドウ', '網走郡美幌町', 'アバシリグンビホロチョウ', '田中', 'タナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡内灘町', '17', '17365', '9200200', '石川県', 'イシカワケン', '河北郡内灘町', 'カホクグンウチナダマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('122670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市木越町瑞樹団地', '17', '17201', '9200201', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '木越町', 'キゴシマチ', null, null, '瑞樹団地', 'ミズキダンチ');
INSERT INTO `ms_addresses` VALUES ('122671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市みずき', '17', '17201', '9200201', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', 'みずき', 'ミズキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市木越', '17', '17201', '9200202', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '木越', 'キゴシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市木越町', '17', '17201', '9200203', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '木越町', 'キゴシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市千田町', '17', '17201', '9200204', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '千田町', 'センダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市大浦町', '17', '17201', '9200205', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '大浦町', 'オオウラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市北寺町', '17', '17201', '9200206', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '北寺町', 'キタデラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市須崎町', '17', '17201', '9200207', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '須崎町', 'スザキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市蚊爪町', '17', '17201', '9200208', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '蚊爪町', 'カガツメマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市東蚊爪町', '17', '17201', '9200209', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '東蚊爪町', 'ヒガシカガツメマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡美幌町日並', '01', '01543', '0920021', '北海道', 'ホッカイドウ', '網走郡美幌町', 'アバシリグンビホロチョウ', '日並', 'ヒナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市湊', '17', '17201', '9200211', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '湊', 'ミナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市北間町', '17', '17201', '9200212', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '北間町', 'キタママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市大河端町', '17', '17201', '9200213', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '大河端町', 'オコバタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市三ツ屋町', '17', '17201', '9200214', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '三ツ屋町', 'ミツヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市弓取町', '17', '17201', '9200215', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '弓取町', 'ユミトリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市かたつ', '17', '17201', '9200219', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', 'かたつ', 'カタツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡美幌町古梅', '01', '01543', '0920022', '北海道', 'ホッカイドウ', '網走郡美幌町', 'アバシリグンビホロチョウ', '古梅', 'フルウメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市戸水町', '17', '17201', '9200223', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '戸水町', 'トミズマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市五郎島町', '17', '17201', '9200224', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '五郎島町', 'ゴロジママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市大野町新町', '17', '17201', '9200225', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '大野町新町', 'オオノマチシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市粟崎町', '17', '17201', '9200226', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '粟崎町', 'アワガサキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市粟崎浜町', '17', '17201', '9200227', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '粟崎浜町', 'アワガサキハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡美幌町豊富', '01', '01543', '0920023', '北海道', 'ホッカイドウ', '網走郡美幌町', 'アバシリグンビホロチョウ', '豊富', 'トヨトミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市大野町ソ', '17', '17201', '9200231', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '大野町', 'オオノマチ', null, null, 'ソ', 'ソ');
INSERT INTO `ms_addresses` VALUES ('122695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市大野町タ', '17', '17201', '9200231', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '大野町', 'オオノマチ', null, null, 'タ', 'タ');
INSERT INTO `ms_addresses` VALUES ('122696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市大野町ヌ', '17', '17201', '9200231', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '大野町', 'オオノマチ', null, null, 'ヌ', 'ヌ');
INSERT INTO `ms_addresses` VALUES ('122697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市大野町ヨ', '17', '17201', '9200231', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '大野町', 'オオノマチ', null, null, 'ヨ', 'ヨ');
INSERT INTO `ms_addresses` VALUES ('122698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市大野町レ', '17', '17201', '9200231', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '大野町', 'オオノマチ', null, null, 'レ', 'レ');
INSERT INTO `ms_addresses` VALUES ('122699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡美幌町福住', '01', '01543', '0920024', '北海道', 'ホッカイドウ', '網走郡美幌町', 'アバシリグンビホロチョウ', '福住', 'フクズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡美幌町駒生', '01', '01543', '0920025', '北海道', 'ホッカイドウ', '網走郡美幌町', 'アバシリグンビホロチョウ', '駒生', 'コマオイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡美幌町都橋', '01', '01543', '0920026', '北海道', 'ホッカイドウ', '網走郡美幌町', 'アバシリグンビホロチョウ', '都橋', 'ミヤコバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡内灘町室', '17', '17365', '9200261', '石川県', 'イシカワケン', '河北郡内灘町', 'カホクグンウチナダマチ', '室', 'ムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡内灘町西荒屋', '17', '17365', '9200262', '石川県', 'イシカワケン', '河北郡内灘町', 'カホクグンウチナダマチ', '西荒屋', 'ニシアラヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡内灘町湖西', '17', '17365', '9200263', '石川県', 'イシカワケン', '河北郡内灘町', 'カホクグンウチナダマチ', '湖西', 'コセイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡内灘町宮坂', '17', '17365', '9200264', '石川県', 'イシカワケン', '河北郡内灘町', 'カホクグンウチナダマチ', '宮坂', 'ミヤサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡内灘町大学', '17', '17365', '9200265', '石川県', 'イシカワケン', '河北郡内灘町', 'カホクグンウチナダマチ', '大学', 'ダイガク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡内灘町大根布', '17', '17365', '9200266', '石川県', 'イシカワケン', '河北郡内灘町', 'カホクグンウチナダマチ', '大根布', 'オオネブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡内灘町大清台', '17', '17365', '9200267', '石川県', 'イシカワケン', '河北郡内灘町', 'カホクグンウチナダマチ', '大清台', 'タイセイダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡内灘町ハマナス', '17', '17365', '9200268', '石川県', 'イシカワケン', '河北郡内灘町', 'カホクグンウチナダマチ', 'ハマナス', 'ハマナス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡内灘町白帆台', '17', '17365', '9200269', '石川県', 'イシカワケン', '河北郡内灘町', 'カホクグンウチナダマチ', '白帆台', 'シラホダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡美幌町稲美', '01', '01543', '0920027', '北海道', 'ホッカイドウ', '網走郡美幌町', 'アバシリグンビホロチョウ', '稲美', 'イナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡内灘町鶴ケ丘', '17', '17365', '9200271', '石川県', 'イシカワケン', '河北郡内灘町', 'カホクグンウチナダマチ', '鶴ケ丘', 'ツルガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡内灘町向陽台', '17', '17365', '9200272', '石川県', 'イシカワケン', '河北郡内灘町', 'カホクグンウチナダマチ', '向陽台', 'コウヨウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡内灘町アカシア', '17', '17365', '9200273', '石川県', 'イシカワケン', '河北郡内灘町', 'カホクグンウチナダマチ', 'アカシア', 'アカシア', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡内灘町向粟崎', '17', '17365', '9200274', '石川県', 'イシカワケン', '河北郡内灘町', 'カホクグンウチナダマチ', '向粟崎', 'ムカイアワガサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡内灘町旭ケ丘', '17', '17365', '9200275', '石川県', 'イシカワケン', '河北郡内灘町', 'カホクグンウチナダマチ', '旭ケ丘', 'アサヒガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡内灘町緑台', '17', '17365', '9200276', '石川県', 'イシカワケン', '河北郡内灘町', 'カホクグンウチナダマチ', '緑台', 'ミドリダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡内灘町千鳥台', '17', '17365', '9200277', '石川県', 'イシカワケン', '河北郡内灘町', 'カホクグンウチナダマチ', '千鳥台', 'チドリダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡美幌町美富', '01', '01543', '0920030', '北海道', 'ホッカイドウ', '網走郡美幌町', 'アバシリグンビホロチョウ', '美富', 'ミトミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡美幌町大通南', '01', '01543', '0920031', '北海道', 'ホッカイドウ', '網走郡美幌町', 'アバシリグンビホロチョウ', '大通南', 'オオドオリミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡美幌町西1条南', '01', '01543', '0920032', '北海道', 'ホッカイドウ', '網走郡美幌町', 'アバシリグンビホロチョウ', '西1条南', 'ニシ01ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡美幌町西2条南', '01', '01543', '0920033', '北海道', 'ホッカイドウ', '網走郡美幌町', 'アバシリグンビホロチョウ', '西2条南', 'ニシ02ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市大野町', '17', '17201', '9200331', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '大野町', 'オオノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市無量寺町', '17', '17201', '9200332', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '無量寺町', 'ムリョウジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市無量寺', '17', '17201', '9200333', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '無量寺', 'ムリョウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市桂町', '17', '17201', '9200334', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '桂町', 'カツラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市金石東', '17', '17201', '9200335', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '金石東', 'カナイワヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市金石本町', '17', '17201', '9200336', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '金石本町', 'カナイワホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市金石西', '17', '17201', '9200337', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '金石西', 'カナイワニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市金石北', '17', '17201', '9200338', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '金石北', 'カナイワキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市寺中町', '17', '17201', '9200341', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '寺中町', 'ジチュウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市畝田西', '17', '17201', '9200342', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '畝田西', 'ウネダニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市畝田町', '17', '17201', '9200342', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '畝田町', 'ウネダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市畝田中', '17', '17201', '9200343', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '畝田中', 'ウネダナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市畝田東', '17', '17201', '9200344', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '畝田東', 'ウネダヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市藤江北', '17', '17201', '9200345', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '藤江北', 'フジエキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市藤江南', '17', '17201', '9200346', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '藤江南', 'フジエミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市松村町', '17', '17201', '9200347', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '松村町', 'マツムラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市松村', '17', '17201', '9200348', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '松村', 'マツムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市普正寺町', '17', '17201', '9200351', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '普正寺町', 'フショウジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市観音堂町', '17', '17201', '9200352', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '観音堂町', 'カンノンドウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市赤土町', '17', '17201', '9200353', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '赤土町', 'アカツチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市二ツ寺町', '17', '17201', '9200354', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '二ツ寺町', 'フタツデラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市稚日野町', '17', '17201', '9200355', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '稚日野町', 'ワカヒノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市専光寺町', '17', '17201', '9200356', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '専光寺町', 'センコウジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市佐奇森町', '17', '17201', '9200357', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '佐奇森町', 'サキモリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市袋畠町', '17', '17201', '9200361', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '袋畠町', 'フクロバタケマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市古府', '17', '17201', '9200362', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '古府', 'コブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市古府町', '17', '17201', '9200362', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '古府町', 'コブマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市古府町西', '17', '17201', '9200362', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '古府町', 'コブマチ', null, null, '西', 'ニシ');
INSERT INTO `ms_addresses` VALUES ('122754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市古府町南', '17', '17201', '9200363', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '古府町', 'コブマチ', null, null, '南', 'ミナミ');
INSERT INTO `ms_addresses` VALUES ('122755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市松島', '17', '17201', '9200364', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '松島', 'マツシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市松島町', '17', '17201', '9200364', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '松島町', 'マツシママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市神野町', '17', '17201', '9200365', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '神野町', 'カミノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市南塚町', '17', '17201', '9200366', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '南塚町', 'ミナミヅカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市北塚町', '17', '17201', '9200367', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '北塚町', 'キタヅカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市神野', '17', '17201', '9200368', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '神野', 'カミノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市下安原町', '17', '17201', '9200371', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '下安原町', 'シモヤスハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市豊穂町', '17', '17201', '9200372', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '豊穂町', 'トヨホマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市みどり', '17', '17201', '9200373', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', 'みどり', 'ミドリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市上安原町', '17', '17201', '9200374', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '上安原町', 'カミヤスハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市上安原南', '17', '17201', '9200374', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '上安原南', 'カミヤスハラミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市中屋町', '17', '17201', '9200375', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '中屋町', 'ナカヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市福増町', '17', '17201', '9200376', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '福増町', 'フクマスマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市打木町', '17', '17201', '9200377', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '打木町', 'ウツギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市いなほ', '17', '17201', '9200378', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', 'いなほ', 'イナホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市中屋南', '17', '17201', '9200379', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '中屋南', 'ナカヤミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡美幌町東1条南', '01', '01543', '0920041', '北海道', 'ホッカイドウ', '網走郡美幌町', 'アバシリグンビホロチョウ', '東1条南', 'ヒガシ01ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡美幌町東2条南', '01', '01543', '0920042', '北海道', 'ホッカイドウ', '網走郡美幌町', 'アバシリグンビホロチョウ', '東2条南', 'ヒガシ02ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡美幌町東3条南', '01', '01543', '0920043', '北海道', 'ホッカイドウ', '網走郡美幌町', 'アバシリグンビホロチョウ', '東3条南', 'ヒガシ03ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡美幌町東4条南', '01', '01543', '0920044', '北海道', 'ホッカイドウ', '網走郡美幌町', 'アバシリグンビホロチョウ', '東4条南', 'ヒガシ04ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡美幌町大通北', '01', '01543', '0920050', '北海道', 'ホッカイドウ', '網走郡美幌町', 'アバシリグンビホロチョウ', '大通北', 'オオドオリキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡美幌町東1条北', '01', '01543', '0920051', '北海道', 'ホッカイドウ', '網走郡美幌町', 'アバシリグンビホロチョウ', '東1条北', 'ヒガシ01ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡美幌町東2条北', '01', '01543', '0920052', '北海道', 'ホッカイドウ', '網走郡美幌町', 'アバシリグンビホロチョウ', '東2条北', 'ヒガシ02ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡美幌町東3条北', '01', '01543', '0920053', '北海道', 'ホッカイドウ', '網走郡美幌町', 'アバシリグンビホロチョウ', '東3条北', 'ヒガシ03ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡美幌町西1条北', '01', '01543', '0920061', '北海道', 'ホッカイドウ', '網走郡美幌町', 'アバシリグンビホロチョウ', '西1条北', 'ニシ01ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡美幌町西2条北', '01', '01543', '0920062', '北海道', 'ホッカイドウ', '網走郡美幌町', 'アバシリグンビホロチョウ', '西2条北', 'ニシ02ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡美幌町元町', '01', '01543', '0920063', '北海道', 'ホッカイドウ', '網走郡美幌町', 'アバシリグンビホロチョウ', '元町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡美幌町青葉', '01', '01543', '0920064', '北海道', 'ホッカイドウ', '網走郡美幌町', 'アバシリグンビホロチョウ', '青葉', 'アオバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡美幌町青山南', '01', '01543', '0920065', '北海道', 'ホッカイドウ', '網走郡美幌町', 'アバシリグンビホロチョウ', '青山南', 'アオヤマミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡美幌町青山北', '01', '01543', '0920066', '北海道', 'ホッカイドウ', '網走郡美幌町', 'アバシリグンビホロチョウ', '青山北', 'アオヤマキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡美幌町三橋南', '01', '01543', '0920067', '北海道', 'ホッカイドウ', '網走郡美幌町', 'アバシリグンビホロチョウ', '三橋南', 'ミツハシミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡美幌町三橋町', '01', '01543', '0920068', '北海道', 'ホッカイドウ', '網走郡美幌町', 'アバシリグンビホロチョウ', '三橋町', 'ミツハシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡美幌町日の出', '01', '01543', '0920069', '北海道', 'ホッカイドウ', '網走郡美幌町', 'アバシリグンビホロチョウ', '日の出', 'ヒノデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市神谷内町', '17', '17201', '9200801', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '神谷内町', 'カミヤチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市三池町', '17', '17201', '9200802', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '三池町', 'ミイケマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市神宮寺町', '17', '17201', '9200803', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '神宮寺町', 'ジングウジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市鳴和', '17', '17201', '9200804', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '鳴和', 'ナルワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市小金町', '17', '17201', '9200805', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '小金町', 'コガネマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市神宮寺', '17', '17201', '9200806', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '神宮寺', 'ジングウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市乙丸町', '17', '17201', '9200807', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '乙丸町', 'オトマルマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市三池新町', '17', '17201', '9200808', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '三池新町', 'ミイケシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市小坂町', '17', '17201', '9200811', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '小坂町', 'コサカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市南御所町', '17', '17201', '9200812', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '南御所町', 'ミナミゴショマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市御所町', '17', '17201', '9200813', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '御所町', 'ゴショマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市鳴和町', '17', '17201', '9200814', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '鳴和町', 'ナルワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市鳴和台', '17', '17201', '9200815', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '鳴和台', 'ナルワダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市山の上町', '17', '17201', '9200816', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '山の上町', 'ヤマノウエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市春日町', '17', '17201', '9200817', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '春日町', 'カスガマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市大樋町', '17', '17201', '9200818', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '大樋町', 'オオヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市山王町', '17', '17201', '9200821', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '山王町', 'サンノウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市東長江町', '17', '17201', '9200822', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '東長江町', 'ヒガシナガエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市夕日寺町', '17', '17201', '9200823', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '夕日寺町', 'ユウヒデラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市伝燈寺町', '17', '17201', '9200824', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '伝燈寺町', 'デンドウジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市釣部町', '17', '17201', '9200825', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '釣部町', 'ツルベマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市小二又町', '17', '17201', '9200826', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '小二又町', 'コフタマタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市牧町', '17', '17201', '9200827', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '牧町', 'マキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市東山', '17', '17201', '9200831', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '東山', 'ヒガシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市卯辰町', '17', '17201', '9200832', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '卯辰町', 'ウタツマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市末広町', '17', '17201', '9200833', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '末広町', 'スエヒロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市常盤町', '17', '17201', '9200834', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '常盤町', 'トキワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市東御影町', '17', '17201', '9200835', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '東御影町', 'ヒガシミカゲマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市子来町', '17', '17201', '9200836', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '子来町', 'コライマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市鶯町', '17', '17201', '9200837', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '鶯町', 'ウグイスマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市観音町', '17', '17201', '9200838', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '観音町', 'カンノンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市浅野本町', '17', '17201', '9200841', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '浅野本町', 'アサノホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市元町', '17', '17201', '9200842', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '元町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市森山', '17', '17201', '9200843', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '森山', 'モリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市小橋町', '17', '17201', '9200844', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '小橋町', 'コバシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市瓢箪町', '17', '17201', '9200845', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '瓢箪町', 'ヒョウタンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市昌永町', '17', '17201', '9200846', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '昌永町', 'ショウエイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市堀川町', '17', '17201', '9200847', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '堀川町', 'ホリカワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市京町', '17', '17201', '9200848', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '京町', 'キョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市堀川新町', '17', '17201', '9200849', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '堀川新町', 'ホリカワシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市笠市町', '17', '17201', '9200851', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '笠市町', 'カサイチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市此花町', '17', '17201', '9200852', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '此花町', 'コノハナマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市本町', '17', '17201', '9200853', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市安江町', '17', '17201', '9200854', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '安江町', 'ヤスエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市武蔵町', '17', '17201', '9200855', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '武蔵町', 'ムサシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市昭和町', '17', '17201', '9200856', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '昭和町', 'ショウワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市折違町', '17', '17201', '9200857', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '折違町', 'スジカイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市木ノ新保町', '17', '17201', '9200858', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '木ノ新保町', 'キノシンボマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市三社町', '17', '17201', '9200861', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '三社町', 'サンジャマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市芳斉', '17', '17201', '9200862', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '芳斉', 'ホウサイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市玉川町', '17', '17201', '9200863', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '玉川町', 'タマガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市高岡町', '17', '17201', '9200864', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '高岡町', 'タカオカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市長町', '17', '17201', '9200865', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '長町', 'ナガマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市中央通町', '17', '17201', '9200866', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '中央通町', 'チュウオウドオリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市長土塀', '17', '17201', '9200867', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '長土塀', 'ナガドヘ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市六枚町', '17', '17201', '9200868', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '六枚町', 'ロクマイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市彦三町', '17', '17201', '9200901', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '彦三町', 'ヒコソマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市尾張町', '17', '17201', '9200902', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '尾張町', 'オワリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市博労町', '17', '17201', '9200903', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '博労町', 'バクロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市下近江町', '17', '17201', '9200904', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '下近江町', 'シモオウミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市上近江町', '17', '17201', '9200905', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '上近江町', 'カミオウミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市十間町', '17', '17201', '9200906', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '十間町', 'ジツケンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市青草町', '17', '17201', '9200907', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '青草町', 'アオクサマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市主計町', '17', '17201', '9200908', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '主計町', 'カズエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市袋町', '17', '17201', '9200909', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '袋町', 'フクロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市橋場町', '17', '17201', '9200911', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '橋場町', 'ハシバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市大手町', '17', '17201', '9200912', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '大手町', 'オオテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市西町三番丁', '17', '17201', '9200913', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '西町三番丁', 'ニシチョウ03バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市西町四番丁', '17', '17201', '9200914', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '西町四番丁', 'ニシチョウ04バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市西町藪ノ内通', '17', '17201', '9200915', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '西町藪ノ内通', 'ニシチョウヤブノウチドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市下松原町', '17', '17201', '9200916', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '下松原町', 'シモマツバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市下堤町', '17', '17201', '9200917', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '下堤町', 'シモツツミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市尾山町', '17', '17201', '9200918', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '尾山町', 'オヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市南町', '17', '17201', '9200919', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '南町', 'ミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市材木町', '17', '17201', '9200921', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '材木町', 'ザイモクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市横山町', '17', '17201', '9200922', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '横山町', 'ヨコヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市桜町', '17', '17201', '9200923', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '桜町', 'サクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市田井町', '17', '17201', '9200924', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '田井町', 'タイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市天神町', '17', '17201', '9200925', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '天神町', 'テンジンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市暁町', '17', '17201', '9200926', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '暁町', 'アカツキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市扇町', '17', '17201', '9200927', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '扇町', 'オウギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市並木町', '17', '17201', '9200928', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '並木町', 'ナミキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市兼六元町', '17', '17201', '9200931', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '兼六元町', 'ケンロクモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市小将町', '17', '17201', '9200932', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '小将町', 'コショウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市東兼六町', '17', '17201', '9200933', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '東兼六町', 'ヒガシケンロクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市宝町', '17', '17201', '9200934', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '宝町', 'タカラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市石引', '17', '17201', '9200935', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '石引', 'イシビキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市兼六町', '17', '17201', '9200936', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '兼六町', 'ケンロクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市丸の内', '17', '17201', '9200937', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '丸の内', 'マルノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市飛梅町', '17', '17201', '9200938', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '飛梅町', 'トビウメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市下石引町', '17', '17201', '9200939', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '下石引町', 'シモイシビキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市旭町', '17', '17201', '9200941', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '旭町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市小立野', '17', '17201', '9200942', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '小立野', 'コダツノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市上野本町', '17', '17201', '9200943', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '上野本町', 'ウエノホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市三口新町', '17', '17201', '9200944', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '三口新町', 'ミツクチシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市大桑新町', '17', '17201', '9200945', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '大桑新町', 'オオクワシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市大桑町穴欠', '17', '17201', '9200946', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '大桑町', 'オオクワマチ', null, null, '穴欠', 'アナガケ');
INSERT INTO `ms_addresses` VALUES ('122896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市大桑町穴淵欠', '17', '17201', '9200946', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '大桑町', 'オオクワマチ', null, null, '穴淵欠', 'アナブチガケ');
INSERT INTO `ms_addresses` VALUES ('122897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市大桑町カ', '17', '17201', '9200946', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '大桑町', 'オオクワマチ', null, null, 'カ', 'カ');
INSERT INTO `ms_addresses` VALUES ('122898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市大桑町コ', '17', '17201', '9200946', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '大桑町', 'オオクワマチ', null, null, 'コ', 'コ');
INSERT INTO `ms_addresses` VALUES ('122899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市大桑町庚', '17', '17201', '9200946', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '大桑町', 'オオクワマチ', null, null, '庚', 'コウ');
INSERT INTO `ms_addresses` VALUES ('122900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市大桑町サ乙', '17', '17201', '9200946', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '大桑町', 'オオクワマチ', null, null, 'サ乙', 'サオツ');
INSERT INTO `ms_addresses` VALUES ('122901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市大桑町サ甲', '17', '17201', '9200946', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '大桑町', 'オオクワマチ', null, null, 'サ甲', 'サコウ');
INSERT INTO `ms_addresses` VALUES ('122902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市大桑町下葭島欠', '17', '17201', '9200946', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '大桑町', 'オオクワマチ', null, null, '下葭島欠', 'シモヨシジマガケ');
INSERT INTO `ms_addresses` VALUES ('122903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市大桑町ソ', '17', '17201', '9200946', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '大桑町', 'オオクワマチ', null, null, 'ソ', 'ソ');
INSERT INTO `ms_addresses` VALUES ('122904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市大桑町タ', '17', '17201', '9200946', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '大桑町', 'オオクワマチ', null, null, 'タ', 'タ');
INSERT INTO `ms_addresses` VALUES ('122905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市大桑町ツ甲', '17', '17201', '9200946', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '大桑町', 'オオクワマチ', null, null, 'ツ甲', 'ツコウ');
INSERT INTO `ms_addresses` VALUES ('122906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市大桑町ナ', '17', '17201', '9200946', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '大桑町', 'オオクワマチ', null, null, 'ナ', 'ナ');
INSERT INTO `ms_addresses` VALUES ('122907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市大桑町子', '17', '17201', '9200946', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '大桑町', 'オオクワマチ', null, null, '子', 'ネ');
INSERT INTO `ms_addresses` VALUES ('122908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市大桑町メ', '17', '17201', '9200946', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '大桑町', 'オオクワマチ', null, null, 'メ', 'メ');
INSERT INTO `ms_addresses` VALUES ('122909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市大桑町ユ', '17', '17201', '9200946', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '大桑町', 'オオクワマチ', null, null, 'ユ', 'ユ');
INSERT INTO `ms_addresses` VALUES ('122910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市大桑町ヨ', '17', '17201', '9200946', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '大桑町', 'オオクワマチ', null, null, 'ヨ', 'ヨ');
INSERT INTO `ms_addresses` VALUES ('122911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市大桑町葭島', '17', '17201', '9200946', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '大桑町', 'オオクワマチ', null, null, '葭島', 'ヨシジマ');
INSERT INTO `ms_addresses` VALUES ('122912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市大桑町ラ', '17', '17201', '9200946', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '大桑町', 'オオクワマチ', null, null, 'ラ', 'ラ');
INSERT INTO `ms_addresses` VALUES ('122913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市大桑町ワ', '17', '17201', '9200946', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '大桑町', 'オオクワマチ', null, null, 'ワ', 'ワ');
INSERT INTO `ms_addresses` VALUES ('122914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市笠舞本町', '17', '17201', '9200947', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '笠舞本町', 'カサマイホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市花里町', '17', '17201', '9200951', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '花里町', 'ハナザトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市錦町', '17', '17201', '9200952', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '錦町', 'ニシキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市涌波', '17', '17201', '9200953', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '涌波', 'ワクナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市涌波町', '17', '17201', '9200954', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '涌波町', 'ワクナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市土清水', '17', '17201', '9200955', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '土清水', 'ツチシミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市舘山町', '17', '17201', '9200956', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '舘山町', 'タチヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市舘町', '17', '17201', '9200957', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '舘町', 'タチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市香林坊', '17', '17201', '9200961', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '香林坊', 'コウリンボウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市広坂', '17', '17201', '9200962', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '広坂', 'ヒロサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市出羽町', '17', '17201', '9200963', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '出羽町', 'デワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市本多町', '17', '17201', '9200964', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '本多町', 'ホンダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市笠舞', '17', '17201', '9200965', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '笠舞', 'カサマイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市城南', '17', '17201', '9200966', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '城南', 'ジョウナン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市菊川', '17', '17201', '9200967', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '菊川', 'キクガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市幸町', '17', '17201', '9200968', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '幸町', 'サイワイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市鱗町', '17', '17201', '9200971', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '鱗町', 'ウロコマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市杉浦町', '17', '17201', '9200972', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '杉浦町', 'スギウラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市枝町', '17', '17201', '9200973', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '枝町', 'エダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市川岸町', '17', '17201', '9200974', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '川岸町', 'カワギシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市中川除町', '17', '17201', '9200975', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '中川除町', 'ナカカワヨケマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市十三間町', '17', '17201', '9200976', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '十三間町', 'ジュウサンゲンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市十三間町中丁', '17', '17201', '9200977', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '十三間町中丁', 'ジュウサンゲンマチナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市水溜町', '17', '17201', '9200978', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '水溜町', 'ミズタメマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市片町', '17', '17201', '9200981', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '片町', 'カタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市大工町', '17', '17201', '9200982', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '大工町', 'ダイクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市池田町一番丁', '17', '17201', '9200983', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '池田町一番丁', 'イケダマチ01バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市池田町二番丁', '17', '17201', '9200984', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '池田町二番丁', 'イケダマチ02バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市池田町三番丁', '17', '17201', '9200985', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '池田町三番丁', 'イケダマチ03バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市池田町四番丁', '17', '17201', '9200986', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '池田町四番丁', 'イケダマチ04バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市池田町立丁', '17', '17201', '9200987', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '池田町立丁', 'イケダマチタテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市木倉町', '17', '17201', '9200988', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '木倉町', 'キグラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市下柿木畠', '17', '17201', '9200991', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '下柿木畠', 'シモカキノキバタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市上柿木畠', '17', '17201', '9200992', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '上柿木畠', 'カミカキノキバタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市下本多町', '17', '17201', '9200993', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '下本多町', 'シモホンダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市茨木町', '17', '17201', '9200994', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '茨木町', 'イバラギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市新竪町', '17', '17201', '9200995', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '新竪町', 'シンタテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市油車', '17', '17201', '9200996', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '油車', 'アブラグルマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市竪町', '17', '17201', '9200997', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '竪町', 'タテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市里見町', '17', '17201', '9200998', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '里見町', 'サトミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市柿木畠', '17', '17201', '9200999', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '柿木畠', 'カキノキバタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市荒山町', '17', '17201', '9201101', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '荒山町', 'アラヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市奥新保町', '17', '17201', '9201101', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '奥新保町', 'オクシンボマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市砂子坂町', '17', '17201', '9201101', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '砂子坂町', 'スナゴザカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市二俣町', '17', '17201', '9201102', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '二俣町', 'フタマタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市田島町', '17', '17201', '9201103', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '田島町', 'タノシママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市清水町', '17', '17201', '9201104', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '清水町', 'シミズマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市戸室新保', '17', '17201', '9201105', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '戸室新保', 'トムロシンボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市戸室別所', '17', '17201', '9201106', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '戸室別所', 'トムロベッショ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市湯谷原町', '17', '17201', '9201106', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '湯谷原町', 'ユヤガハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市小豆沢町', '17', '17201', '9201107', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '小豆沢町', 'アズキザワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市俵町', '17', '17201', '9201108', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '俵町', 'タワラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市中山町', '17', '17201', '9201109', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '中山町', 'ナカヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市魚帰町', '17', '17201', '9201111', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '魚帰町', 'ウオガエリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市大菱池町', '17', '17201', '9201111', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '大菱池町', 'オビシケマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市小菱池町', '17', '17201', '9201111', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '小菱池町', 'コビシケマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市菱池小原町', '17', '17201', '9201111', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '菱池小原町', 'ヒシイケオハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市折谷町', '17', '17201', '9201112', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '折谷町', 'オリタニマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市上山町', '17', '17201', '9201113', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '上山町', 'ウエヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市古郷町', '17', '17201', '9201114', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '古郷町', 'コキョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市石黒町', '17', '17201', '9201115', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '石黒町', 'イシグロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市板ケ谷町', '17', '17201', '9201116', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '板ケ谷町', 'イタガヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市横谷町', '17', '17201', '9201117', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '横谷町', 'ヨコタニマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市湯涌河内町', '17', '17201', '9201118', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '湯涌河内町', 'ユワクカワチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市湯涌曲町', '17', '17201', '9201119', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '湯涌曲町', 'ユワクマガリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市東町', '17', '17201', '9201121', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '東町', 'ヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市湯涌荒屋町', '17', '17201', '9201122', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '湯涌荒屋町', 'ユワクアラヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市湯涌町', '17', '17201', '9201123', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '湯涌町', 'ユワクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市湯涌田子島町', '17', '17201', '9201124', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '湯涌田子島町', 'ユワクタゴジママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市上原町', '17', '17201', '9201125', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '上原町', 'カンバラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市白見町', '17', '17201', '9201126', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '白見町', 'シロミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市下谷町', '17', '17201', '9201127', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '下谷町', 'シモダニマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市羽場町', '17', '17201', '9201128', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '羽場町', 'ハバマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市芝原町', '17', '17201', '9201129', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '芝原町', 'シバハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市東荒屋町', '17', '17201', '9201131', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '東荒屋町', 'ヒガシアラヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市朝加屋町', '17', '17201', '9201132', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '朝加屋町', 'アサカヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市藤六町', '17', '17201', '9201133', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '藤六町', 'トウロクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市東市瀬町', '17', '17201', '9201134', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '東市瀬町', 'ヒガシイチノセマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市北袋町', '17', '17201', '9201135', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '北袋町', 'キタブクロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市西市瀬町', '17', '17201', '9201136', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '西市瀬町', 'ニシイチノセマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市七曲町', '17', '17201', '9201137', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '七曲町', 'ナナマガリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市茅原町', '17', '17201', '9201138', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '茅原町', 'チハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市平等本町', '17', '17201', '9201141', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '平等本町', 'ダイラホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市蓮如町', '17', '17201', '9201142', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '蓮如町', 'レンニョマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市高池町', '17', '17201', '9201143', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '高池町', 'タカイケマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('122999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市袋板屋町', '17', '17201', '9201144', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '袋板屋町', 'フクロイタヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市浅川町', '17', '17201', '9201145', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '浅川町', 'アサカワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市上中町', '17', '17201', '9201146', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '上中町', 'カミナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市銚子町', '17', '17201', '9201147', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '銚子町', 'チョウシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市金川町', '17', '17201', '9201148', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '金川町', 'カナガワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市打尾町', '17', '17201', '9201149', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '打尾町', 'ウチオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市田上町', '17', '17201', '9201151', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '田上町', 'タガミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市田上', '17', '17201', '9201152', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '田上', 'タガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市田上新町', '17', '17201', '9201153', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '田上新町', 'タガミシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市太陽が丘', '17', '17201', '9201154', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '太陽が丘', 'タイヨウガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市田上本町', '17', '17201', '9201155', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '田上本町', 'タガミホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市鈴見台', '17', '17201', '9201161', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '鈴見台', 'スズミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市鈴見町', '17', '17201', '9201162', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '鈴見町', 'スズミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市角間新町', '17', '17201', '9201163', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '角間新町', 'カクマシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市角間町', '17', '17201', '9201164', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '角間町', 'カクママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市若松町', '17', '17201', '9201165', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '若松町', 'ワカマツマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市上若松町', '17', '17201', '9201166', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '上若松町', 'カミワカマツマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市もりの里', '17', '17201', '9201167', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', 'もりの里', 'モリノサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市永安町', '17', '17201', '9201301', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '永安町', 'エイアンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市末町', '17', '17201', '9201302', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '末町', 'スエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市辰巳町', '17', '17201', '9201303', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '辰巳町', 'タツミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市上辰巳町', '17', '17201', '9201304', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '上辰巳町', 'カミタツミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市菅池町', '17', '17201', '9201311', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '菅池町', 'スガイケマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市瀬領町', '17', '17201', '9201312', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '瀬領町', 'セリョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市駒帰町', '17', '17201', '9201313', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '駒帰町', 'コマガエリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市娚杉町', '17', '17201', '9201314', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '娚杉町', 'メオトスギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市寺津町', '17', '17201', '9201315', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '寺津町', 'テラヅマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市二又新町', '17', '17201', '9201316', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '二又新町', 'フタマタシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市水淵町', '17', '17201', '9201321', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '水淵町', 'ミズブチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市相合谷町', '17', '17201', '9201322', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '相合谷町', 'アオダニマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市下鴛原町', '17', '17201', '9201323', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '下鴛原町', 'シモオシハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市鴛原町', '17', '17201', '9201324', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '鴛原町', 'オシハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市城力町', '17', '17201', '9201325', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '城力町', 'ジョウリキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市熊走町', '17', '17201', '9201326', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '熊走町', 'クマバシリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市天池町', '17', '17201', '9201331', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '天池町', 'アマイケマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市樫見町', '17', '17201', '9201332', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '樫見町', 'カシミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市国見町', '17', '17201', '9201333', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '国見町', 'クニミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市平町', '17', '17201', '9201334', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '平町', 'タイラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市大平沢町', '17', '17201', '9201335', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '大平沢町', 'オオヒラソウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市中戸町', '17', '17201', '9201336', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '中戸町', 'ナカトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市山川町', '17', '17201', '9201337', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '山川町', 'ヤマゴマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市別所町', '17', '17201', '9201341', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '別所町', 'ベッショマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市蓮花町', '17', '17201', '9201342', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '蓮花町', 'レンゲマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市小原町', '17', '17201', '9201343', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '小原町', 'オハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市住吉町', '17', '17201', '9201344', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '住吉町', 'スミヨシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市新保町', '17', '17201', '9201345', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '新保町', 'シンボマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市三小牛町', '17', '17201', '9201346', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '三小牛町', 'ミツコウジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡美幌町美富', '01', '01543', '0920171', '北海道', 'ホッカイドウ', '網走郡美幌町', 'アバシリグンビホロチョウ', '美富', 'ミトミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡美幌町美和', '01', '01543', '0920173', '北海道', 'ホッカイドウ', '網走郡美幌町', 'アバシリグンビホロチョウ', '美和', 'ビワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡美幌町栄森', '01', '01543', '0920174', '北海道', 'ホッカイドウ', '網走郡美幌町', 'アバシリグンビホロチョウ', '栄森', 'サカエモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡美幌町駒生', '01', '01543', '0920175', '北海道', 'ホッカイドウ', '網走郡美幌町', 'アバシリグンビホロチョウ', '駒生', 'コマオイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡美幌町野崎', '01', '01543', '0920176', '北海道', 'ホッカイドウ', '網走郡美幌町', 'アバシリグンビホロチョウ', '野崎', 'ノザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡美幌町上町', '01', '01543', '0920181', '北海道', 'ホッカイドウ', '網走郡美幌町', 'アバシリグンビホロチョウ', '上町', 'カミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡美幌町豊幌', '01', '01543', '0920183', '北海道', 'ホッカイドウ', '網走郡美幌町', 'アバシリグンビホロチョウ', '豊幌', 'トヨホロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡美幌町登栄', '01', '01543', '0920184', '北海道', 'ホッカイドウ', '網走郡美幌町', 'アバシリグンビホロチョウ', '登栄', 'トイエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡津別町', '01', '01544', '0920200', '北海道', 'ホッカイドウ', '網走郡津別町', 'アバシリグンツベツチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('123065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡津別町最上', '01', '01544', '0920201', '北海道', 'ホッカイドウ', '網走郡津別町', 'アバシリグンツベツチョウ', '最上', 'モガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡津別町達美', '01', '01544', '0920203', '北海道', 'ホッカイドウ', '網走郡津別町', 'アバシリグンツベツチョウ', '達美', 'タツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡津別町岩富', '01', '01544', '0920205', '北海道', 'ホッカイドウ', '網走郡津別町', 'アバシリグンツベツチョウ', '岩富', 'イワトミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡津別町活汲', '01', '01544', '0920206', '北海道', 'ホッカイドウ', '網走郡津別町', 'アバシリグンツベツチョウ', '活汲', 'カツクミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡津別町東岡', '01', '01544', '0920207', '北海道', 'ホッカイドウ', '網走郡津別町', 'アバシリグンツベツチョウ', '東岡', 'ヒガシオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市曽谷町', '17', '17210', '9202101', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '曽谷町', 'ソダニマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市坂尻町', '17', '17210', '9202102', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '坂尻町', 'サカジリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市小柳町', '17', '17210', '9202103', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '小柳町', 'オヤナギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市月橋町', '17', '17210', '9202104', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '月橋町', 'ツキハシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡津別町西3条', '01', '01544', '0920211', '北海道', 'ホッカイドウ', '網走郡津別町', 'アバシリグンツベツチョウ', '西3条', 'ニシ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市鶴来朝日町', '17', '17210', '9202111', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '鶴来朝日町', 'ツルギアサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市鶴来日吉町', '17', '17210', '9202112', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '鶴来日吉町', 'ツルギヒヨシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市八幡町', '17', '17210', '9202113', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '八幡町', 'ヤワタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市三宮町', '17', '17210', '9202114', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '三宮町', 'サンノミヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市白山町', '17', '17210', '9202115', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '白山町', 'シラヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市中島町', '17', '17210', '9202116', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '中島町', 'ナカジママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡津別町緑町', '01', '01544', '0920212', '北海道', 'ホッカイドウ', '網走郡津別町', 'アバシリグンツベツチョウ', '緑町', 'ミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市鶴来本町1丁目', '17', '17210', '9202121', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '鶴来本町', 'ツルギホンマチ', null, null, '1丁目', '01チョウメ');
INSERT INTO `ms_addresses` VALUES ('123083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市鶴来本町2丁目', '17', '17210', '9202121', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '鶴来本町', 'ツルギホンマチ', null, null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('123084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市鶴来本町3丁目', '17', '17210', '9202121', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '鶴来本町', 'ツルギホンマチ', null, null, '3丁目', '03チョウメ');
INSERT INTO `ms_addresses` VALUES ('123085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市鶴来本町4丁目', '17', '17210', '9202121', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '鶴来本町', 'ツルギホンマチ', null, null, '4丁目', '04チョウメ');
INSERT INTO `ms_addresses` VALUES ('123086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市鶴来知守町', '17', '17210', '9202122', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '鶴来知守町', 'ツルギチモリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市鶴来日詰町', '17', '17210', '9202123', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '鶴来日詰町', 'ツルギヒヅメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市鶴来清沢町', '17', '17210', '9202124', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '鶴来清沢町', 'ツルギセイサワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市鶴来今町', '17', '17210', '9202125', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '鶴来今町', 'ツルギイママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市鶴来新町', '17', '17210', '9202126', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '鶴来新町', 'ツルギシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市鶴来上東町', '17', '17210', '9202127', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '鶴来上東町', 'ツルギカミヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市鶴来下東町', '17', '17210', '9202128', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '鶴来下東町', 'ツルギシモヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市鶴来古町', '17', '17210', '9202129', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '鶴来古町', 'ツルギフルマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡津別町西4条', '01', '01544', '0920213', '北海道', 'ホッカイドウ', '網走郡津別町', 'アバシリグンツベツチョウ', '西4条', 'ニシ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市森島町', '17', '17210', '9202131', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '森島町', 'モリジママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市明島町', '17', '17210', '9202132', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '明島町', 'アカラジママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市鶴来大国町', '17', '17210', '9202133', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '鶴来大国町', 'ツルギオオクニマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市鶴来水戸町2丁目', '17', '17210', '9202134', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '鶴来水戸町', 'ツルギミトマチ', null, null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('123099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市鶴来水戸町3丁目', '17', '17210', '9202134', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '鶴来水戸町', 'ツルギミトマチ', null, null, '3丁目', '03チョウメ');
INSERT INTO `ms_addresses` VALUES ('123100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市鶴来水戸町4丁目', '17', '17210', '9202134', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '鶴来水戸町', 'ツルギミトマチ', null, null, '4丁目', '04チョウメ');
INSERT INTO `ms_addresses` VALUES ('123101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡津別町西2条', '01', '01544', '0920214', '北海道', 'ホッカイドウ', '網走郡津別町', 'アバシリグンツベツチョウ', '西2条', 'ニシ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市安養寺町', '17', '17210', '9202141', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '安養寺町', 'アンヨウジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市深瀬新町', '17', '17210', '9202142', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '深瀬新町', 'フカゼシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市七原町', '17', '17210', '9202143', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '七原町', 'シチハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市大竹町', '17', '17210', '9202144', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '大竹町', 'オオダケマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市明法島町', '17', '17210', '9202145', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '明法島町', 'ミョウホウジママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市日向町', '17', '17210', '9202146', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '日向町', 'ヒュウガマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市中ノ郷町', '17', '17210', '9202147', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '中ノ郷町', 'ナカノゴウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市行町', '17', '17210', '9202148', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '行町', 'アルキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡津別町1条通', '01', '01544', '0920215', '北海道', 'ホッカイドウ', '網走郡津別町', 'アバシリグンツベツチョウ', '1条通', '01ジョウドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市荒屋町', '17', '17210', '9202151', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '荒屋町', 'アラヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市明光1丁目', '17', '17210', '9202152', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '明光', 'メイコウ', null, null, '1丁目', '01チョウメ');
INSERT INTO `ms_addresses` VALUES ('123113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市明光2丁目', '17', '17210', '9202152', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '明光', 'メイコウ', null, null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('123114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市明光3丁目', '17', '17210', '9202152', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '明光', 'メイコウ', null, null, '3丁目', '03チョウメ');
INSERT INTO `ms_addresses` VALUES ('123115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市明光4丁目', '17', '17210', '9202152', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '明光', 'メイコウ', null, null, '4丁目', '04チョウメ');
INSERT INTO `ms_addresses` VALUES ('123116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市日御子町', '17', '17210', '9202153', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '日御子町', 'ヒノミコマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市井口町', '17', '17210', '9202154', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '井口町', 'イノクチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市知気寺町', '17', '17210', '9202155', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '知気寺町', 'チキジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡津別町東2条', '01', '01544', '0920216', '北海道', 'ホッカイドウ', '網走郡津別町', 'アバシリグンツベツチョウ', '東2条', 'ヒガシ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市熱野町', '17', '17210', '9202161', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '熱野町', 'ネツノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市道法寺町', '17', '17210', '9202162', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '道法寺町', 'ドウホウジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市柴木町', '17', '17210', '9202163', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '柴木町', 'シバキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市柴木2丁目', '17', '17210', '9202164', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '柴木', 'シバキ', null, null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('123124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市富光寺町', '17', '17210', '9202165', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '富光寺町', 'トミコウジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市鶴来桑島町', '17', '17210', '9202166', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '鶴来桑島町', 'ツルギクワジママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市部入道町', '17', '17210', '9202167', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '部入道町', 'ブニュウドウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡津別町東3条', '01', '01544', '0920217', '北海道', 'ホッカイドウ', '網走郡津別町', 'アバシリグンツベツチョウ', '東3条', 'ヒガシ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡津別町東4条', '01', '01544', '0920218', '北海道', 'ホッカイドウ', '網走郡津別町', 'アバシリグンツベツチョウ', '東4条', 'ヒガシ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡津別町高台', '01', '01544', '0920221', '北海道', 'ホッカイドウ', '網走郡津別町', 'アバシリグンツベツチョウ', '高台', 'タカダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡津別町上里', '01', '01544', '0920222', '北海道', 'ホッカイドウ', '網走郡津別町', 'アバシリグンツベツチョウ', '上里', 'カミサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡津別町美都', '01', '01544', '0920223', '北海道', 'ホッカイドウ', '網走郡津別町', 'アバシリグンツベツチョウ', '美都', 'ミト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡津別町豊永', '01', '01544', '0920224', '北海道', 'ホッカイドウ', '網走郡津別町', 'アバシリグンツベツチョウ', '豊永', 'トヨナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡津別町共和', '01', '01544', '0920225', '北海道', 'ホッカイドウ', '網走郡津別町', 'アバシリグンツベツチョウ', '共和', 'キョウワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市河内町口直海', '17', '17210', '9202301', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '河内町口直海', 'カワチマチクチノミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市河内町ふじが丘', '17', '17210', '9202302', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '河内町ふじが丘', 'カワチマチフジガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市河内町福岡', '17', '17210', '9202303', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '河内町福岡', 'カワチマチフクオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市河内町きりの里', '17', '17210', '9202304', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '河内町きりの里', 'カワチマチキリノサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市河内町江津', '17', '17210', '9202305', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '河内町江津', 'カワチマチゴウヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市河内町吉岡', '17', '17210', '9202306', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '河内町吉岡', 'カワチマチヨシオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡津別町大通', '01', '01544', '0920231', '北海道', 'ホッカイドウ', '網走郡津別町', 'アバシリグンツベツチョウ', '大通', 'オオドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市河内町中直海', '17', '17210', '9202311', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '河内町中直海', 'カワチマチナカノミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市河内町奥池', '17', '17210', '9202312', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '河内町奥池', 'カワチマチオクイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市河内町久保', '17', '17210', '9202313', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '河内町久保', 'カワチマチクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市河内町吹上', '17', '17210', '9202314', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '河内町吹上', 'カワチマチフキアゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市河内町板尾', '17', '17210', '9202315', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '河内町板尾', 'カワチマチイタオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市河内町金間', '17', '17210', '9202316', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '河内町金間', 'カワチマチキンマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市河内町下折', '17', '17210', '9202317', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '河内町下折', 'カワチマチソソリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市河内町内尾', '17', '17210', '9202318', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '河内町内尾', 'カワチマチウツオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡津別町新町', '01', '01544', '0920232', '北海道', 'ホッカイドウ', '網走郡津別町', 'アバシリグンツベツチョウ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市吉野', '17', '17210', '9202321', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '吉野', 'ヨシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市佐良', '17', '17210', '9202322', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '佐良', 'サラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市瀬波', '17', '17210', '9202323', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '瀬波', 'セナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市中宮', '17', '17210', '9202324', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '中宮', 'チュウグウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市木滑新', '17', '17210', '9202325', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '木滑新', 'キナメリシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市木滑', '17', '17210', '9202326', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '木滑', 'キナメリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市市原', '17', '17210', '9202327', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '市原', 'イチハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡津別町柏町', '01', '01544', '0920233', '北海道', 'ホッカイドウ', '網走郡津別町', 'アバシリグンツベツチョウ', '柏町', 'カシワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市瀬戸', '17', '17210', '9202331', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '瀬戸', 'セト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市荒谷', '17', '17210', '9202332', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '荒谷', 'アラタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市尾添', '17', '17210', '9202333', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '尾添', 'オゾウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市深瀬', '17', '17210', '9202334', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '深瀬', 'フカゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市女原', '17', '17210', '9202335', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '女原', 'オナバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市東二口', '17', '17210', '9202336', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '東二口', 'ヒガシフタクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市五味島', '17', '17210', '9202337', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '五味島', 'ゴミジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市釜谷', '17', '17210', '9202338', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '釜谷', 'カマダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市鴇ケ谷', '17', '17210', '9202339', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '鴇ケ谷', 'トガタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡津別町旭町', '01', '01544', '0920234', '北海道', 'ホッカイドウ', '網走郡津別町', 'アバシリグンツベツチョウ', '旭町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市釜清水町', '17', '17210', '9202341', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '釜清水町', 'カマシミズマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市下吉谷町', '17', '17210', '9202342', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '下吉谷町', 'シモヨシタニマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市西佐良町', '17', '17210', '9202343', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '西佐良町', 'ニシサラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市上吉谷町', '17', '17210', '9202344', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '上吉谷町', 'カミヨシタニマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市三ツ屋野町', '17', '17210', '9202345', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '三ツ屋野町', 'ミツヤノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市河原山町', '17', '17210', '9202346', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '河原山町', 'カワハラヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市仏師ケ野町', '17', '17210', '9202347', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '仏師ケ野町', 'ブシガノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡津別町幸町', '01', '01544', '0920235', '北海道', 'ホッカイドウ', '網走郡津別町', 'アバシリグンツベツチョウ', '幸町', 'サイワイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市柳原町', '17', '17210', '9202351', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '柳原町', 'ヤナギハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市野地町', '17', '17210', '9202352', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '野地町', 'ノウヂマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市左礫町', '17', '17210', '9202353', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '左礫町', 'ヒダリツブテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市三ツ瀬町', '17', '17210', '9202354', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '三ツ瀬町', 'ミツセマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市数瀬町', '17', '17210', '9202355', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '数瀬町', 'カズセマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市阿手町', '17', '17210', '9202356', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '阿手町', 'アテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市五十谷町', '17', '17210', '9202357', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '五十谷町', 'ゴジュウダニマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡津別町本町', '01', '01544', '0920236', '北海道', 'ホッカイドウ', '網走郡津別町', 'アバシリグンツベツチョウ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市三坂町', '17', '17210', '9202361', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '三坂町', 'ミサカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市別宮町', '17', '17210', '9202362', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '別宮町', 'ベツクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市別宮出町', '17', '17210', '9202363', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '別宮出町', 'ベツクデマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市杉森町', '17', '17210', '9202364', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '杉森町', 'スギモリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市神子清水町', '17', '17210', '9202365', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '神子清水町', 'ミコシミズマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市渡津町', '17', '17210', '9202366', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '渡津町', 'ワタヅマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市相滝町', '17', '17210', '9202367', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '相滝町', 'アイタキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市出合町', '17', '17210', '9202368', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '出合町', 'デアイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市広瀬町', '17', '17210', '9202371', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '広瀬町', 'ヒロセマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市瀬木野町', '17', '17210', '9202372', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '瀬木野町', 'セギノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市河合町', '17', '17210', '9202373', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '河合町', 'カワイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市下野町', '17', '17210', '9202374', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '下野町', 'シモノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市上野町', '17', '17210', '9202375', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '上野町', 'カミノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市若原町', '17', '17210', '9202376', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '若原町', 'ワカバラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市白峰', '17', '17210', '9202501', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '白峰', 'シラミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市桑島', '17', '17210', '9202502', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '桑島', 'クワジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市下田原', '17', '17210', '9202503', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '下田原', 'シモタワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市才田町', '17', '17201', '9203101', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '才田町', 'サイダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市忠縄町', '17', '17201', '9203102', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '忠縄町', 'タダナワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市湖陽', '17', '17201', '9203103', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '湖陽', 'コヨウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市八田町東', '17', '17201', '9203104', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '八田町東', 'ハッタマチヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市八田町西', '17', '17201', '9203105', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '八田町西', 'ハッタマチニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市八田町', '17', '17201', '9203106', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '八田町', 'ハッタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市湖南町', '17', '17201', '9203107', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '湖南町', 'コナンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市梅田町', '17', '17201', '9203111', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '梅田町', 'ウメダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市観法寺町', '17', '17201', '9203112', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '観法寺町', 'カンポウジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市塚崎町', '17', '17201', '9203113', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '塚崎町', 'ツカザキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市吉原町', '17', '17201', '9203114', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '吉原町', 'ヨシワラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市弥勒町', '17', '17201', '9203115', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '弥勒町', 'ミロクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市南森本町', '17', '17201', '9203116', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '南森本町', 'ミナミモリモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市北森本町', '17', '17201', '9203117', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '北森本町', 'キタモリモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市大場町', '17', '17201', '9203121', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '大場町', 'オオバマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市福久町', '17', '17201', '9203122', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '福久町', 'フクヒサマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市福久東', '17', '17201', '9203123', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '福久東', 'フクヒサヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市荒屋', '17', '17201', '9203124', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '荒屋', 'アラヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市荒屋町', '17', '17201', '9203125', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '荒屋町', 'アラヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市福久', '17', '17201', '9203126', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '福久', 'フクヒサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市百坂町', '17', '17201', '9203131', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '百坂町', 'モモサカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市法光寺町', '17', '17201', '9203132', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '法光寺町', 'ホウコウジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市柳橋町', '17', '17201', '9203133', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '柳橋町', 'ヤナギバシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市金市町', '17', '17201', '9203134', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '金市町', 'カナイチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市横枕町', '17', '17201', '9203135', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '横枕町', 'ヨコマクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡津別町本岐', '01', '01544', '0920351', '北海道', 'ホッカイドウ', '網走郡津別町', 'アバシリグンツベツチョウ', '本岐', 'ホンキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡津別町木樋', '01', '01544', '0920352', '北海道', 'ホッカイドウ', '網走郡津別町', 'アバシリグンツベツチョウ', '木樋', 'キトイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡津別町二又', '01', '01544', '0920353', '北海道', 'ホッカイドウ', '網走郡津別町', 'アバシリグンツベツチョウ', '二又', 'フタマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡津別町双葉', '01', '01544', '0920354', '北海道', 'ホッカイドウ', '網走郡津別町', 'アバシリグンツベツチョウ', '双葉', 'フタバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡津別町恩根', '01', '01544', '0920355', '北海道', 'ホッカイドウ', '網走郡津別町', 'アバシリグンツベツチョウ', '恩根', 'オンネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡津別町栄', '01', '01544', '0920356', '北海道', 'ホッカイドウ', '網走郡津別町', 'アバシリグンツベツチョウ', '栄', 'サカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡津別町大昭', '01', '01544', '0920357', '北海道', 'ホッカイドウ', '網走郡津別町', 'アバシリグンツベツチョウ', '大昭', 'タイショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡津別町沼沢', '01', '01544', '0920358', '北海道', 'ホッカイドウ', '網走郡津別町', 'アバシリグンツベツチョウ', '沼沢', 'ヌマサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡津別町相生', '01', '01544', '0920361', '北海道', 'ホッカイドウ', '網走郡津別町', 'アバシリグンツベツチョウ', '相生', 'アイオイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡津別町布川', '01', '01544', '0920362', '北海道', 'ホッカイドウ', '網走郡津別町', 'アバシリグンツベツチョウ', '布川', 'ヌノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市鞍月東', '17', '17201', '9208201', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '鞍月東', 'クラツキヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市西都', '17', '17201', '9208202', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '西都', 'セイト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市鞍月', '17', '17201', '9208203', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '鞍月', 'クラツキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市戸水', '17', '17201', '9208204', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '戸水', 'トミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市大友', '17', '17201', '9208205', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '大友', 'オオトモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市直江町', '17', '17201', '9208216', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '直江町', 'ナオエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市近岡町', '17', '17201', '9208217', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '近岡町', 'チカオカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市直江北', '17', '17201', '9208218', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '直江北', 'ナオエキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市御供田町', '17', '17201', '9208221', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '御供田町', 'ゴクデンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市大友町', '17', '17201', '9208222', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '大友町', 'オオトモマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県石川郡野々市町', '17', '17344', '9210000', '石川県', 'イシカワケン', '石川郡野々市町', 'イシカワグンノノイチマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('123384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市高畠', '17', '17201', '9218001', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '高畠', 'タカバタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市玉鉾', '17', '17201', '9218002', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '玉鉾', 'タマボコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市玉鉾町', '17', '17201', '9218003', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '玉鉾町', 'タマボコマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市米丸町', '17', '17201', '9218004', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '米丸町', 'ヨネマルマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市間明町', '17', '17201', '9218005', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '間明町', 'マギラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市進和町', '17', '17201', '9218006', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '進和町', 'シンワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市入江', '17', '17201', '9218011', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '入江', 'イリエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市本江町', '17', '17201', '9218012', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '本江町', 'モトエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市新神田', '17', '17201', '9218013', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '新神田', 'シンカンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市糸田', '17', '17201', '9218014', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '糸田', 'イトダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市東力', '17', '17201', '9218015', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '東力', 'トウリキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市東力町', '17', '17201', '9218016', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '東力町', 'トウリキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市御影町', '17', '17201', '9218021', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '御影町', 'ミカゲマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市中村町', '17', '17201', '9218022', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '中村町', 'ナカムラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市千日町', '17', '17201', '9218023', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '千日町', 'センニチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市白菊町', '17', '17201', '9218024', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '白菊町', 'シラギクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市増泉', '17', '17201', '9218025', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '増泉', 'マスイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市糸田新町', '17', '17201', '9218026', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '糸田新町', 'イトダシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市神田', '17', '17201', '9218027', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '神田', 'カンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市野町', '17', '17201', '9218031', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '野町', 'ノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市清川町', '17', '17201', '9218032', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '清川町', 'キヨカワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市寺町', '17', '17201', '9218033', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '寺町', 'テラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市泉野町', '17', '17201', '9218034', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '泉野町', 'イズミノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市泉が丘', '17', '17201', '9218035', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '泉が丘', 'イズミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市弥生', '17', '17201', '9218036', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '弥生', 'ヤヨイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市泉', '17', '17201', '9218041', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '泉', 'イズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市泉本町', '17', '17201', '9218042', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '泉本町', 'イズミホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市西泉', '17', '17201', '9218043', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '西泉', 'ニシイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市米泉町', '17', '17201', '9218044', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '米泉町', 'ヨナイズミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市大桑町ア', '17', '17201', '9218046', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '大桑町', 'オオクワマチ', null, null, 'ア', 'ア');
INSERT INTO `ms_addresses` VALUES ('123414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市大桑町イ', '17', '17201', '9218046', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '大桑町', 'オオクワマチ', null, null, 'イ', 'イ');
INSERT INTO `ms_addresses` VALUES ('123415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市大桑町ヰ', '17', '17201', '9218046', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '大桑町', 'オオクワマチ', null, null, 'ヰ', 'イ');
INSERT INTO `ms_addresses` VALUES ('123416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市大桑町ウ', '17', '17201', '9218046', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '大桑町', 'オオクワマチ', null, null, 'ウ', 'ウ');
INSERT INTO `ms_addresses` VALUES ('123417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市大桑町上野', '17', '17201', '9218046', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '大桑町', 'オオクワマチ', null, null, '上野', 'ウエノ');
INSERT INTO `ms_addresses` VALUES ('123418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市大桑町ヲ', '17', '17201', '9218046', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '大桑町', 'オオクワマチ', null, null, 'ヲ', 'オ');
INSERT INTO `ms_addresses` VALUES ('123419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市大桑町オ乙', '17', '17201', '9218046', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '大桑町', 'オオクワマチ', null, null, 'オ乙', 'オオツ');
INSERT INTO `ms_addresses` VALUES ('123420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市大桑町鐘搗山', '17', '17201', '9218046', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '大桑町', 'オオクワマチ', null, null, '鐘搗山', 'カネツキヤマ');
INSERT INTO `ms_addresses` VALUES ('123421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市大桑町上川原', '17', '17201', '9218046', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '大桑町', 'オオクワマチ', null, null, '上川原', 'カミカワラ');
INSERT INTO `ms_addresses` VALUES ('123422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市大桑町上猫下', '17', '17201', '9218046', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '大桑町', 'オオクワマチ', null, null, '上猫下', 'カミネコシタ');
INSERT INTO `ms_addresses` VALUES ('123423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市大桑町ク', '17', '17201', '9218046', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '大桑町', 'オオクワマチ', null, null, 'ク', 'ク');
INSERT INTO `ms_addresses` VALUES ('123424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市大桑町ケ', '17', '17201', '9218046', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '大桑町', 'オオクワマチ', null, null, 'ケ', 'ケ');
INSERT INTO `ms_addresses` VALUES ('123425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市大桑町御所谷', '17', '17201', '9218046', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '大桑町', 'オオクワマチ', null, null, '御所谷', 'ゴショガダニ');
INSERT INTO `ms_addresses` VALUES ('123426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市大桑町小寺山', '17', '17201', '9218046', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '大桑町', 'オオクワマチ', null, null, '小寺山', 'コデラヤマ');
INSERT INTO `ms_addresses` VALUES ('123427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市大桑町シ', '17', '17201', '9218046', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '大桑町', 'オオクワマチ', null, null, 'シ', 'シ');
INSERT INTO `ms_addresses` VALUES ('123428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市大桑町下上野', '17', '17201', '9218046', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '大桑町', 'オオクワマチ', null, null, '下上野', 'シモウエノ');
INSERT INTO `ms_addresses` VALUES ('123429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市大桑町下西欠', '17', '17201', '9218046', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '大桑町', 'オオクワマチ', null, null, '下西欠', 'シモニシガケ');
INSERT INTO `ms_addresses` VALUES ('123430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市大桑町平', '17', '17201', '9218046', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '大桑町', 'オオクワマチ', null, null, '平', 'ダイラ');
INSERT INTO `ms_addresses` VALUES ('123431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市大桑町チ', '17', '17201', '9218046', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '大桑町', 'オオクワマチ', null, null, 'チ', 'チ');
INSERT INTO `ms_addresses` VALUES ('123432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市大桑町ツ乙', '17', '17201', '9218046', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '大桑町', 'オオクワマチ', null, null, 'ツ乙', 'ツオツ');
INSERT INTO `ms_addresses` VALUES ('123433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市大桑町ツ丙', '17', '17201', '9218046', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '大桑町', 'オオクワマチ', null, null, 'ツ丙', 'ツヘイ');
INSERT INTO `ms_addresses` VALUES ('123434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市大桑町テ', '17', '17201', '9218046', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '大桑町', 'オオクワマチ', null, null, 'テ', 'テ');
INSERT INTO `ms_addresses` VALUES ('123435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市大桑町ト', '17', '17201', '9218046', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '大桑町', 'オオクワマチ', null, null, 'ト', 'ト');
INSERT INTO `ms_addresses` VALUES ('123436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市大桑町中上野', '17', '17201', '9218046', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '大桑町', 'オオクワマチ', null, null, '中上野', 'ナカウエノ');
INSERT INTO `ms_addresses` VALUES ('123437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市大桑町中尾山', '17', '17201', '9218046', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '大桑町', 'オオクワマチ', null, null, '中尾山', 'ナカオヤマ');
INSERT INTO `ms_addresses` VALUES ('123438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市大桑町中平', '17', '17201', '9218046', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '大桑町', 'オオクワマチ', null, null, '中平', 'ナカダイラ');
INSERT INTO `ms_addresses` VALUES ('123439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市大桑町中ノ大平', '17', '17201', '9218046', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '大桑町', 'オオクワマチ', null, null, '中ノ大平', 'ナカノオオヒラ');
INSERT INTO `ms_addresses` VALUES ('123440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市大桑町ニ', '17', '17201', '9218046', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '大桑町', 'オオクワマチ', null, null, 'ニ', 'ニ');
INSERT INTO `ms_addresses` VALUES ('123441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市大桑町西ノ山', '17', '17201', '9218046', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '大桑町', 'オオクワマチ', null, null, '西ノ山', 'ニシノヤマ');
INSERT INTO `ms_addresses` VALUES ('123442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市大桑町猫シタイ', '17', '17201', '9218046', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '大桑町', 'オオクワマチ', null, null, '猫シタイ', 'ネコノシタイ');
INSERT INTO `ms_addresses` VALUES ('123443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市大桑町ノ', '17', '17201', '9218046', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '大桑町', 'オオクワマチ', null, null, 'ノ', 'ノ');
INSERT INTO `ms_addresses` VALUES ('123444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市大桑町ハ', '17', '17201', '9218046', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '大桑町', 'オオクワマチ', null, null, 'ハ', 'ハ');
INSERT INTO `ms_addresses` VALUES ('123445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市大桑町開', '17', '17201', '9218046', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '大桑町', 'オオクワマチ', null, null, '開', 'ヒラキ');
INSERT INTO `ms_addresses` VALUES ('123446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市大桑町ヘ', '17', '17201', '9218046', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '大桑町', 'オオクワマチ', null, null, 'ヘ', 'ヘ');
INSERT INTO `ms_addresses` VALUES ('123447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市大桑町ホ', '17', '17201', '9218046', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '大桑町', 'オオクワマチ', null, null, 'ホ', 'ホ');
INSERT INTO `ms_addresses` VALUES ('123448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市大桑町法師山', '17', '17201', '9218046', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '大桑町', 'オオクワマチ', null, null, '法師山', 'ホウシヤマ');
INSERT INTO `ms_addresses` VALUES ('123449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市大桑町坊山', '17', '17201', '9218046', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '大桑町', 'オオクワマチ', null, null, '坊山', 'ボウヤマ');
INSERT INTO `ms_addresses` VALUES ('123450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市大桑町マ', '17', '17201', '9218046', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '大桑町', 'オオクワマチ', null, null, 'マ', 'マ');
INSERT INTO `ms_addresses` VALUES ('123451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市大桑町鱒川淵', '17', '17201', '9218046', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '大桑町', 'オオクワマチ', null, null, '鱒川淵', 'マスカワブチ');
INSERT INTO `ms_addresses` VALUES ('123452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市大桑町ム', '17', '17201', '9218046', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '大桑町', 'オオクワマチ', null, null, 'ム', 'ム');
INSERT INTO `ms_addresses` VALUES ('123453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市大桑町元末', '17', '17201', '9218046', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '大桑町', 'オオクワマチ', null, null, '元末', 'モトスエ');
INSERT INTO `ms_addresses` VALUES ('123454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市大桑町元涌波庚', '17', '17201', '9218046', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '大桑町', 'オオクワマチ', null, null, '元涌波庚', 'モトワクナミコウ');
INSERT INTO `ms_addresses` VALUES ('123455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市大桑町ヤ', '17', '17201', '9218046', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '大桑町', 'オオクワマチ', null, null, 'ヤ', 'ヤ');
INSERT INTO `ms_addresses` VALUES ('123456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市大桑町リ', '17', '17201', '9218046', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '大桑町', 'オオクワマチ', null, null, 'リ', 'リ');
INSERT INTO `ms_addresses` VALUES ('123457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市大桑町ル', '17', '17201', '9218046', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '大桑町', 'オオクワマチ', null, null, 'ル', 'ル');
INSERT INTO `ms_addresses` VALUES ('123458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市大桑町レ乙', '17', '17201', '9218046', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '大桑町', 'オオクワマチ', null, null, 'レ乙', 'レオツ');
INSERT INTO `ms_addresses` VALUES ('123459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市大桑町レ甲', '17', '17201', '9218046', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '大桑町', 'オオクワマチ', null, null, 'レ甲', 'レコウ');
INSERT INTO `ms_addresses` VALUES ('123460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市大桑町ロ乙', '17', '17201', '9218046', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '大桑町', 'オオクワマチ', null, null, 'ロ乙', 'ロオツ');
INSERT INTO `ms_addresses` VALUES ('123461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市大桑町ロ甲', '17', '17201', '9218046', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '大桑町', 'オオクワマチ', null, null, 'ロ甲', 'ロコウ');
INSERT INTO `ms_addresses` VALUES ('123462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市大桑町和', '17', '17201', '9218046', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '大桑町', 'オオクワマチ', null, null, '和', 'ワ');
INSERT INTO `ms_addresses` VALUES ('123463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市三小牛町ヘ', '17', '17201', '9218046', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '三小牛町', 'ミツコウジマチ', null, null, 'ヘ', 'ヘ');
INSERT INTO `ms_addresses` VALUES ('123464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市大豆田本町ハ', '17', '17201', '9218047', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '大豆田本町', 'マメダホンマチ', null, null, 'ハ', 'ハ');
INSERT INTO `ms_addresses` VALUES ('123465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市大豆田本町ロ', '17', '17201', '9218047', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '大豆田本町', 'マメダホンマチ', null, null, 'ロ', 'ロ');
INSERT INTO `ms_addresses` VALUES ('123466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市黒田', '17', '17201', '9218051', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '黒田', 'クロダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市保古', '17', '17201', '9218052', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '保古', 'ホゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市保古町', '17', '17201', '9218053', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '保古町', 'ホゴマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市西金沢', '17', '17201', '9218054', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '西金沢', 'ニシカナザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市西金沢新町', '17', '17201', '9218055', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '西金沢新町', 'ニシカナザワシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市押野', '17', '17201', '9218056', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '押野', 'オシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市森戸', '17', '17201', '9218061', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '森戸', 'モリト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市新保本', '17', '17201', '9218062', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '新保本', 'シンボホン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市八日市出町', '17', '17201', '9218063', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '八日市出町', 'ヨウカイチデマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市八日市', '17', '17201', '9218064', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '八日市', 'ヨウカイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市上荒屋', '17', '17201', '9218065', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '上荒屋', 'カミアラヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市矢木', '17', '17201', '9218066', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '矢木', 'ヤギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市法島町', '17', '17201', '9218101', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '法島町', 'ホウシママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市西大桑町', '17', '17201', '9218102', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '西大桑町', 'ニシオオクワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市つつじが丘', '17', '17201', '9218103', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', 'つつじが丘', 'ツツジガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市野田町', '17', '17201', '9218104', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '野田町', 'ノダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市平和町', '17', '17201', '9218105', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '平和町', 'ヘイワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市十一屋町', '17', '17201', '9218106', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '十一屋町', 'ジュウイチヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市若草町', '17', '17201', '9218111', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '若草町', 'ワカクサマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市長坂', '17', '17201', '9218112', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '長坂', 'ナガサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市長坂町', '17', '17201', '9218114', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '長坂町', 'ナガサカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市長坂台', '17', '17201', '9218115', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '長坂台', 'ナガサカダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市泉野出町', '17', '17201', '9218116', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '泉野出町', 'イズミノデマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市緑が丘', '17', '17201', '9218117', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '緑が丘', 'ミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市平栗', '17', '17201', '9218121', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '平栗', 'ヒラグリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市清瀬町', '17', '17201', '9218122', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '清瀬町', 'キヨセマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市坪野町', '17', '17201', '9218123', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '坪野町', 'ツボノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市倉ケ嶽', '17', '17201', '9218124', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '倉ケ嶽', 'クラガタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市三十苅町', '17', '17201', '9218131', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '三十苅町', 'サンジュウガリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市しじま台', '17', '17201', '9218132', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', 'しじま台', 'シジマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市四十万町', '17', '17201', '9218133', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '四十万町', 'シジママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市南四十万', '17', '17201', '9218134', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '南四十万', 'ミナミシジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市四十万', '17', '17201', '9218135', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '四十万', 'シジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市馬替', '17', '17201', '9218141', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '馬替', 'マガエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市光が丘', '17', '17201', '9218142', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '光が丘', 'ヒカリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市大額町', '17', '17201', '9218143', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '大額町', 'オオヌカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市額谷町', '17', '17201', '9218144', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '額谷町', 'ヌカダニマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市額谷', '17', '17201', '9218145', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '額谷', 'ヌカダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市額乙丸町', '17', '17201', '9218146', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '額乙丸町', 'ヌカオトマルマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市大額', '17', '17201', '9218147', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '大額', 'オオヌカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市額新保', '17', '17201', '9218148', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '額新保', 'ヌカシンボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市額新町', '17', '17201', '9218149', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '額新町', 'ヌカシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市窪', '17', '17201', '9218151', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '窪', 'クボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市高尾', '17', '17201', '9218152', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '高尾', 'タカオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市高尾町', '17', '17201', '9218153', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '高尾町', 'タカオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市高尾南', '17', '17201', '9218154', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '高尾南', 'タカオミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市高尾台', '17', '17201', '9218155', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '高尾台', 'タカオダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市有松', '17', '17201', '9218161', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '有松', 'アリマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市三馬', '17', '17201', '9218162', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '三馬', 'ミンマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市横川', '17', '17201', '9218163', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '横川', 'ヨコガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市久安', '17', '17201', '9218164', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '久安', 'ヒサヤス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市富樫', '17', '17201', '9218171', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '富樫', 'トガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市伏見新町', '17', '17201', '9218172', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '伏見新町', 'フシミシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市円光寺', '17', '17201', '9218173', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '円光寺', 'エンコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市山科町', '17', '17201', '9218174', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '山科町', 'ヤマシナマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市山科', '17', '17201', '9218175', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '山科', 'ヤマシナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市円光寺本町', '17', '17201', '9218176', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '円光寺本町', 'エンコウジホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市伏見台', '17', '17201', '9218177', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '伏見台', 'フシミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県金沢市寺地', '17', '17201', '9218178', '石川県', 'イシカワケン', '金沢市', 'カナザワシ', '寺地', 'テラジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県石川郡野々市町御経塚', '17', '17344', '9218801', '石川県', 'イシカワケン', '石川郡野々市町', 'イシカワグンノノイチマチ', '御経塚', 'オキョウヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県石川郡野々市町押野', '17', '17344', '9218802', '石川県', 'イシカワケン', '石川郡野々市町', 'イシカワグンノノイチマチ', '押野', 'オシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県石川郡野々市町押越', '17', '17344', '9218803', '石川県', 'イシカワケン', '石川郡野々市町', 'イシカワグンノノイチマチ', '押越', 'オシコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県石川郡野々市町野代', '17', '17344', '9218804', '石川県', 'イシカワケン', '石川郡野々市町', 'イシカワグンノノイチマチ', '野代', 'ノシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県石川郡野々市町稲荷', '17', '17344', '9218805', '石川県', 'イシカワケン', '石川郡野々市町', 'イシカワグンノノイチマチ', '稲荷', 'イナリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県石川郡野々市町三日市町', '17', '17344', '9218806', '石川県', 'イシカワケン', '石川郡野々市町', 'イシカワグンノノイチマチ', '三日市町', 'ミッカイチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県石川郡野々市町二日市町', '17', '17344', '9218807', '石川県', 'イシカワケン', '石川郡野々市町', 'イシカワグンノノイチマチ', '二日市町', 'フツカイチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県石川郡野々市町長池', '17', '17344', '9218808', '石川県', 'イシカワケン', '石川郡野々市町', 'イシカワグンノノイチマチ', '長池', 'ナガイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県石川郡野々市町高橋町', '17', '17344', '9218811', '石川県', 'イシカワケン', '石川郡野々市町', 'イシカワグンノノイチマチ', '高橋町', 'タカハシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県石川郡野々市町扇が丘', '17', '17344', '9218812', '石川県', 'イシカワケン', '石川郡野々市町', 'イシカワグンノノイチマチ', '扇が丘', 'オウギガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県石川郡野々市町住吉町', '17', '17344', '9218813', '石川県', 'イシカワケン', '石川郡野々市町', 'イシカワグンノノイチマチ', '住吉町', 'スミヨシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県石川郡野々市町菅原町', '17', '17344', '9218814', '石川県', 'イシカワケン', '石川郡野々市町', 'イシカワグンノノイチマチ', '菅原町', 'スガハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県石川郡野々市町本町', '17', '17344', '9218815', '石川県', 'イシカワケン', '石川郡野々市町', 'イシカワグンノノイチマチ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県石川郡野々市町若松町', '17', '17344', '9218816', '石川県', 'イシカワケン', '石川郡野々市町', 'イシカワグンノノイチマチ', '若松町', 'ワカマツマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県石川郡野々市町横宮町', '17', '17344', '9218817', '石川県', 'イシカワケン', '石川郡野々市町', 'イシカワグンノノイチマチ', '横宮町', 'ヨコミヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県石川郡野々市町白山町', '17', '17344', '9218821', '石川県', 'イシカワケン', '石川郡野々市町', 'イシカワグンノノイチマチ', '白山町', 'ハクサンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県石川郡野々市町矢作', '17', '17344', '9218822', '石川県', 'イシカワケン', '石川郡野々市町', 'イシカワグンノノイチマチ', '矢作', 'ヤハギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県石川郡野々市町粟田', '17', '17344', '9218823', '石川県', 'イシカワケン', '石川郡野々市町', 'イシカワグンノノイチマチ', '粟田', 'アワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県石川郡野々市町新庄', '17', '17344', '9218824', '石川県', 'イシカワケン', '石川郡野々市町', 'イシカワグンノノイチマチ', '新庄', 'シンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県石川郡野々市町三納', '17', '17344', '9218825', '石川県', 'イシカワケン', '石川郡野々市町', 'イシカワグンノノイチマチ', '三納', 'サンノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県石川郡野々市町下林', '17', '17344', '9218831', '石川県', 'イシカワケン', '石川郡野々市町', 'イシカワグンノノイチマチ', '下林', 'シモバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県石川郡野々市町藤平田', '17', '17344', '9218832', '石川県', 'イシカワケン', '石川郡野々市町', 'イシカワグンノノイチマチ', '藤平田', 'トヘイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県石川郡野々市町藤平', '17', '17344', '9218833', '石川県', 'イシカワケン', '石川郡野々市町', 'イシカワグンノノイチマチ', '藤平', 'フジヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県石川郡野々市町中林', '17', '17344', '9218834', '石川県', 'イシカワケン', '石川郡野々市町', 'イシカワグンノノイチマチ', '中林', 'ナカバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県石川郡野々市町上林', '17', '17344', '9218835', '石川県', 'イシカワケン', '石川郡野々市町', 'イシカワグンノノイチマチ', '上林', 'カンバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県石川郡野々市町末松', '17', '17344', '9218836', '石川県', 'イシカワケン', '石川郡野々市町', 'イシカワグンノノイチマチ', '末松', 'スエマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県石川郡野々市町清金', '17', '17344', '9218837', '石川県', 'イシカワケン', '石川郡野々市町', 'イシカワグンノノイチマチ', '清金', 'キヨカネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県石川郡野々市町郷町', '17', '17344', '9218841', '石川県', 'イシカワケン', '石川郡野々市町', 'イシカワグンノノイチマチ', '郷町', 'ゴウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県石川郡野々市町徳用町', '17', '17344', '9218842', '石川県', 'イシカワケン', '石川郡野々市町', 'イシカワグンノノイチマチ', '徳用町', 'トクモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県石川郡野々市町田尻町', '17', '17344', '9218843', '石川県', 'イシカワケン', '石川郡野々市町', 'イシカワグンノノイチマチ', '田尻町', 'タノシリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県石川郡野々市町堀内', '17', '17344', '9218844', '石川県', 'イシカワケン', '石川郡野々市町', 'イシカワグンノノイチマチ', '堀内', 'ホリウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県石川郡野々市町太平寺', '17', '17344', '9218845', '石川県', 'イシカワケン', '石川郡野々市町', 'イシカワグンノノイチマチ', '太平寺', 'タヘイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県石川郡野々市町位川', '17', '17344', '9218846', '石川県', 'イシカワケン', '石川郡野々市町', 'イシカワグンノノイチマチ', '位川', 'クライガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県石川郡野々市町蓮花寺町', '17', '17344', '9218847', '石川県', 'イシカワケン', '石川郡野々市町', 'イシカワグンノノイチマチ', '蓮花寺町', 'レンゲジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県石川郡野々市町柳町', '17', '17344', '9218848', '石川県', 'イシカワケン', '石川郡野々市町', 'イシカワグンノノイチマチ', '柳町', 'ヤナギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市', '17', '17206', '9220000', '石川県', 'イシカワケン', '加賀市', 'カガシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('123630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市大聖寺上木町', '17', '17206', '9220001', '石川県', 'イシカワケン', '加賀市', 'カガシ', '大聖寺上木町', 'ダイショウジウワギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市大聖寺下福田町', '17', '17206', '9220002', '石川県', 'イシカワケン', '加賀市', 'カガシ', '大聖寺下福田町', 'ダイショウジシモフクダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市大聖寺荻生町', '17', '17206', '9220003', '石川県', 'イシカワケン', '加賀市', 'カガシ', '大聖寺荻生町', 'ダイショウジオギュウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市大聖寺朝日町', '17', '17206', '9220004', '石川県', 'イシカワケン', '加賀市', 'カガシ', '大聖寺朝日町', 'ダイショウジアサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市大聖寺上福田町', '17', '17206', '9220004', '石川県', 'イシカワケン', '加賀市', 'カガシ', '大聖寺上福田町', 'ダイショウジカミフクダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市大聖寺新川町', '17', '17206', '9220004', '石川県', 'イシカワケン', '加賀市', 'カガシ', '大聖寺新川町', 'ダイショウジシンカワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市大聖寺畑町', '17', '17206', '9220004', '石川県', 'イシカワケン', '加賀市', 'カガシ', '大聖寺畑町', 'ダイショウジハタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市大聖寺畑山町', '17', '17206', '9220004', '石川県', 'イシカワケン', '加賀市', 'カガシ', '大聖寺畑山町', 'ダイショウジハタヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市大聖寺松島町', '17', '17206', '9220004', '石川県', 'イシカワケン', '加賀市', 'カガシ', '大聖寺松島町', 'ダイショウジマツシママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市豊町ハ', '17', '17206', '9220004', '石川県', 'イシカワケン', '加賀市', 'カガシ', '豊町', 'ユタカマチ', null, null, 'ハ', 'ハ');
INSERT INTO `ms_addresses` VALUES ('123640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市大聖寺岡町', '17', '17206', '9220005', '石川県', 'イシカワケン', '加賀市', 'カガシ', '大聖寺岡町', 'ダイショウジオカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市大聖寺藤ノ木町', '17', '17206', '9220006', '石川県', 'イシカワケン', '加賀市', 'カガシ', '大聖寺藤ノ木町', 'ダイショウジフジノキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市大聖寺天神下町', '17', '17206', '9220007', '石川県', 'イシカワケン', '加賀市', 'カガシ', '大聖寺天神下町', 'ダイショウジテンジンシタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市大聖寺春日町', '17', '17206', '9220011', '石川県', 'イシカワケン', '加賀市', 'カガシ', '大聖寺春日町', 'ダイショウジカスガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市大聖寺敷地', '17', '17206', '9220011', '石川県', 'イシカワケン', '加賀市', 'カガシ', '大聖寺敷地', 'ダイショウジシキジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市大聖寺東敷地町', '17', '17206', '9220011', '石川県', 'イシカワケン', '加賀市', 'カガシ', '大聖寺東敷地町', 'ダイショウジヒガシシキジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市大聖寺平床', '17', '17206', '9220011', '石川県', 'イシカワケン', '加賀市', 'カガシ', '大聖寺平床', 'ダイショウジヒラトコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市下河崎町', '17', '17206', '9220012', '石川県', 'イシカワケン', '加賀市', 'カガシ', '下河崎町', 'シモカワサキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市上河崎町', '17', '17206', '9220013', '石川県', 'イシカワケン', '加賀市', 'カガシ', '上河崎町', 'カミカワサキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市中代町', '17', '17206', '9220014', '石川県', 'イシカワケン', '加賀市', 'カガシ', '中代町', 'ナカダイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市保賀町', '17', '17206', '9220015', '石川県', 'イシカワケン', '加賀市', 'カガシ', '保賀町', 'ホウガマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市大聖寺新栄町', '17', '17206', '9220021', '石川県', 'イシカワケン', '加賀市', 'カガシ', '大聖寺新栄町', 'ダイショウジシンサカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市大聖寺曙町', '17', '17206', '9220022', '石川県', 'イシカワケン', '加賀市', 'カガシ', '大聖寺曙町', 'ダイショウジアケボノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市大聖寺大名竹町', '17', '17206', '9220023', '石川県', 'イシカワケン', '加賀市', 'カガシ', '大聖寺大名竹町', 'ダイショウジダイミョウダケマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市大聖寺永町', '17', '17206', '9220024', '石川県', 'イシカワケン', '加賀市', 'カガシ', '大聖寺永町', 'ダイショウジナガマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市大聖寺耳聞山仲町', '17', '17206', '9220025', '石川県', 'イシカワケン', '加賀市', 'カガシ', '大聖寺耳聞山仲町', 'ダイショウジミミキヤマナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市大聖寺亀町', '17', '17206', '9220026', '石川県', 'イシカワケン', '加賀市', 'カガシ', '大聖寺亀町', 'ダイショウジガメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市大聖寺耳聞山町', '17', '17206', '9220027', '石川県', 'イシカワケン', '加賀市', 'カガシ', '大聖寺耳聞山町', 'ダイショウジミミキヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市大聖寺麻畠町', '17', '17206', '9220028', '石川県', 'イシカワケン', '加賀市', 'カガシ', '大聖寺麻畠町', 'ダイショウジアサバタケマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市大聖寺木呂場町', '17', '17206', '9220031', '石川県', 'イシカワケン', '加賀市', 'カガシ', '大聖寺木呂場町', 'ダイショウジコロバマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市大聖寺金子町', '17', '17206', '9220032', '石川県', 'イシカワケン', '加賀市', 'カガシ', '大聖寺金子町', 'ダイショウジカネコマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市大聖寺法華坊町', '17', '17206', '9220033', '石川県', 'イシカワケン', '加賀市', 'カガシ', '大聖寺法華坊町', 'ダイショウジホッケボウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市大聖寺荒町', '17', '17206', '9220034', '石川県', 'イシカワケン', '加賀市', 'カガシ', '大聖寺荒町', 'ダイショウジアラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市大聖寺鉄砲町', '17', '17206', '9220035', '石川県', 'イシカワケン', '加賀市', 'カガシ', '大聖寺鉄砲町', 'ダイショウジテッポウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市大聖寺一本橋町', '17', '17206', '9220036', '石川県', 'イシカワケン', '加賀市', 'カガシ', '大聖寺一本橋町', 'ダイショウジイッポンバシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市大聖寺鍛冶町', '17', '17206', '9220037', '石川県', 'イシカワケン', '加賀市', 'カガシ', '大聖寺鍛冶町', 'ダイショウジカジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市大聖寺山田町', '17', '17206', '9220038', '石川県', 'イシカワケン', '加賀市', 'カガシ', '大聖寺山田町', 'ダイショウジヤマダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市大聖寺本町', '17', '17206', '9220041', '石川県', 'イシカワケン', '加賀市', 'カガシ', '大聖寺本町', 'ダイショウジホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市大聖寺魚町', '17', '17206', '9220042', '石川県', 'イシカワケン', '加賀市', 'カガシ', '大聖寺魚町', 'ダイショウジウオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市大聖寺五軒町', '17', '17206', '9220043', '石川県', 'イシカワケン', '加賀市', 'カガシ', '大聖寺五軒町', 'ダイショウジゴケンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市大聖寺東横町', '17', '17206', '9220044', '石川県', 'イシカワケン', '加賀市', 'カガシ', '大聖寺東横町', 'ダイショウジヒガシヨコマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市大聖寺十一町', '17', '17206', '9220045', '石川県', 'イシカワケン', '加賀市', 'カガシ', '大聖寺十一町', 'ダイショウジジュウイチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市大聖寺観音町', '17', '17206', '9220046', '石川県', 'イシカワケン', '加賀市', 'カガシ', '大聖寺観音町', 'ダイショウジカンノンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市大聖寺中町', '17', '17206', '9220047', '石川県', 'イシカワケン', '加賀市', 'カガシ', '大聖寺中町', 'ダイショウジナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市大聖寺馬場町', '17', '17206', '9220048', '石川県', 'イシカワケン', '加賀市', 'カガシ', '大聖寺馬場町', 'ダイショウジババマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市大聖寺仲町', '17', '17206', '9220051', '石川県', 'イシカワケン', '加賀市', 'カガシ', '大聖寺仲町', 'ダイショウジナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市大聖寺福田町', '17', '17206', '9220052', '石川県', 'イシカワケン', '加賀市', 'カガシ', '大聖寺福田町', 'ダイショウジフクダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市大聖寺鷹匠町', '17', '17206', '9220053', '石川県', 'イシカワケン', '加賀市', 'カガシ', '大聖寺鷹匠町', 'ダイショウジタカジョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市大聖寺寺町', '17', '17206', '9220054', '石川県', 'イシカワケン', '加賀市', 'カガシ', '大聖寺寺町', 'ダイショウジテラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市大聖寺京町', '17', '17206', '9220055', '石川県', 'イシカワケン', '加賀市', 'カガシ', '大聖寺京町', 'ダイショウジキョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市大聖寺片原町', '17', '17206', '9220056', '石川県', 'イシカワケン', '加賀市', 'カガシ', '大聖寺片原町', 'ダイショウジカタハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市大聖寺八間道', '17', '17206', '9220057', '石川県', 'イシカワケン', '加賀市', 'カガシ', '大聖寺八間道', 'ダイショウジハチケンミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市大聖寺相生町', '17', '17206', '9220061', '石川県', 'イシカワケン', '加賀市', 'カガシ', '大聖寺相生町', 'ダイショウジアイオイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市大聖寺松ケ根町', '17', '17206', '9220062', '石川県', 'イシカワケン', '加賀市', 'カガシ', '大聖寺松ケ根町', 'ダイショウジマツガネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市大聖寺新町', '17', '17206', '9220063', '石川県', 'イシカワケン', '加賀市', 'カガシ', '大聖寺新町', 'ダイショウジシンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市大聖寺北片原町', '17', '17206', '9220064', '石川県', 'イシカワケン', '加賀市', 'カガシ', '大聖寺北片原町', 'ダイショウジキタカタハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市大聖寺新旗陽町', '17', '17206', '9220065', '石川県', 'イシカワケン', '加賀市', 'カガシ', '大聖寺新旗陽町', 'ダイショウジシンキヨウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市大聖寺殿町', '17', '17206', '9220066', '石川県', 'イシカワケン', '加賀市', 'カガシ', '大聖寺殿町', 'ダイショウジトノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市大聖寺番場町', '17', '17206', '9220067', '石川県', 'イシカワケン', '加賀市', 'カガシ', '大聖寺番場町', 'ダイショウジバンバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市大聖寺新組町', '17', '17206', '9220068', '石川県', 'イシカワケン', '加賀市', 'カガシ', '大聖寺新組町', 'ダイショウジシンクミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市山中温泉中田町', '17', '17206', '9220101', '石川県', 'イシカワケン', '加賀市', 'カガシ', '山中温泉中田町', 'ヤマナカオンセンナカダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市山中温泉二天町', '17', '17206', '9220101', '石川県', 'イシカワケン', '加賀市', 'カガシ', '山中温泉二天町', 'ヤマナカオンセンニテンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市山中温泉長谷田町日の出団地', '17', '17206', '9220102', '石川県', 'イシカワケン', '加賀市', 'カガシ', '山中温泉長谷田町', 'ヤマナカオンセンハセダマチ', null, null, '日の出団地', 'ヒノデダンチ');
INSERT INTO `ms_addresses` VALUES ('123693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市山中温泉長谷田町', '17', '17206', '9220103', '石川県', 'イシカワケン', '加賀市', 'カガシ', '山中温泉長谷田町', 'ヤマナカオンセンハセダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市山中温泉旭町', '17', '17206', '9220104', '石川県', 'イシカワケン', '加賀市', 'カガシ', '山中温泉旭町', 'ヤマナカオンセンアサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市山中温泉長谷田町泉町', '17', '17206', '9220105', '石川県', 'イシカワケン', '加賀市', 'カガシ', '山中温泉長谷田町', 'ヤマナカオンセンハセダマチ', null, null, '泉町', 'イズミマチ');
INSERT INTO `ms_addresses` VALUES ('123696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市山中温泉上原町', '17', '17206', '9220106', '石川県', 'イシカワケン', '加賀市', 'カガシ', '山中温泉上原町', 'ヤマナカオンセンウワバラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市山中温泉上原町漆器団地', '17', '17206', '9220107', '石川県', 'イシカワケン', '加賀市', 'カガシ', '山中温泉上原町', 'ヤマナカオンセンウワバラマチ', null, null, '漆器団地', 'シツキダンチ');
INSERT INTO `ms_addresses` VALUES ('123698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市山中温泉上原町しらさぎ団地', '17', '17206', '9220108', '石川県', 'イシカワケン', '加賀市', 'カガシ', '山中温泉上原町', 'ヤマナカオンセンウワバラマチ', null, null, 'しらさぎ団地', 'シラサギダンチ');
INSERT INTO `ms_addresses` VALUES ('123699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市山中温泉宮の杜', '17', '17206', '9220109', '石川県', 'イシカワケン', '加賀市', 'カガシ', '山中温泉宮の杜', 'ヤマナカオンセンミヤノモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市山中温泉塚谷町', '17', '17206', '9220111', '石川県', 'イシカワケン', '加賀市', 'カガシ', '山中温泉塚谷町', 'ヤマナカオンセンツカタニマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市山中温泉西桂木町', '17', '17206', '9220112', '石川県', 'イシカワケン', '加賀市', 'カガシ', '山中温泉西桂木町', 'ヤマナカオンセンニシカツラギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市山中温泉東桂木町', '17', '17206', '9220113', '石川県', 'イシカワケン', '加賀市', 'カガシ', '山中温泉東桂木町', 'ヤマナカオンセンヒガシカツラギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市山中温泉東町', '17', '17206', '9220114', '石川県', 'イシカワケン', '加賀市', 'カガシ', '山中温泉東町', 'ヤマナカオンセンヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市山中温泉本町', '17', '17206', '9220115', '石川県', 'イシカワケン', '加賀市', 'カガシ', '山中温泉本町', 'ヤマナカオンセンホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市山中温泉白山町', '17', '17206', '9220116', '石川県', 'イシカワケン', '加賀市', 'カガシ', '山中温泉白山町', 'ヤマナカオンセンハクサンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市山中温泉上野町', '17', '17206', '9220117', '石川県', 'イシカワケン', '加賀市', 'カガシ', '山中温泉上野町', 'ヤマナカオンセンウエノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市山中温泉上野町緑ケ丘', '17', '17206', '9220117', '石川県', 'イシカワケン', '加賀市', 'カガシ', '山中温泉上野町', 'ヤマナカオンセンウエノマチ', null, null, '緑ケ丘', 'ミドリガオカ');
INSERT INTO `ms_addresses` VALUES ('123708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市山中温泉加美谷台', '17', '17206', '9220118', '石川県', 'イシカワケン', '加賀市', 'カガシ', '山中温泉加美谷台', 'ヤマナカオンセンカミヤダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市山中温泉富士見町', '17', '17206', '9220121', '石川県', 'イシカワケン', '加賀市', 'カガシ', '山中温泉富士見町', 'ヤマナカオンセンフジミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市山中温泉湯の本町', '17', '17206', '9220122', '石川県', 'イシカワケン', '加賀市', 'カガシ', '山中温泉湯の本町', 'ヤマナカオンセンユノホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市山中温泉薬師町', '17', '17206', '9220123', '石川県', 'イシカワケン', '加賀市', 'カガシ', '山中温泉薬師町', 'ヤマナカオンセンヤクシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市山中温泉湯の出町', '17', '17206', '9220124', '石川県', 'イシカワケン', '加賀市', 'カガシ', '山中温泉湯の出町', 'ヤマナカオンセンユノデマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市山中温泉栄町', '17', '17206', '9220125', '石川県', 'イシカワケン', '加賀市', 'カガシ', '山中温泉栄町', 'ヤマナカオンセンサカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市山中温泉河鹿町', '17', '17206', '9220126', '石川県', 'イシカワケン', '加賀市', 'カガシ', '山中温泉河鹿町', 'ヤマナカオンセンカジカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市山中温泉下谷町', '17', '17206', '9220127', '石川県', 'イシカワケン', '加賀市', 'カガシ', '山中温泉下谷町', 'ヤマナカオンセンシモタニマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市山中温泉こおろぎ町', '17', '17206', '9220128', '石川県', 'イシカワケン', '加賀市', 'カガシ', '山中温泉こおろぎ町', 'ヤマナカオンセンコオロギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市山中温泉南町', '17', '17206', '9220129', '石川県', 'イシカワケン', '加賀市', 'カガシ', '山中温泉南町', 'ヤマナカオンセンミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市山中温泉四十九院町', '17', '17206', '9220131', '石川県', 'イシカワケン', '加賀市', 'カガシ', '山中温泉四十九院町', 'ヤマナカオンセンシジュウクインマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市山中温泉中津原町', '17', '17206', '9220132', '石川県', 'イシカワケン', '加賀市', 'カガシ', '山中温泉中津原町', 'ヤマナカオンセンナカツハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市山中温泉滝町', '17', '17206', '9220133', '石川県', 'イシカワケン', '加賀市', 'カガシ', '山中温泉滝町', 'ヤマナカオンセンタキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市山中温泉荒谷町', '17', '17206', '9220134', '石川県', 'イシカワケン', '加賀市', 'カガシ', '山中温泉荒谷町', 'ヤマナカオンセンアラタニマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市山中温泉菅生谷町', '17', '17206', '9220134', '石川県', 'イシカワケン', '加賀市', 'カガシ', '山中温泉菅生谷町', 'ヤマナカオンセンスゴウダニマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市山中温泉今立町', '17', '17206', '9220135', '石川県', 'イシカワケン', '加賀市', 'カガシ', '山中温泉今立町', 'ヤマナカオンセンイマダチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市山中温泉大土町', '17', '17206', '9220135', '石川県', 'イシカワケン', '加賀市', 'カガシ', '山中温泉大土町', 'ヤマナカオンセンオオヅチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市山中温泉枯淵町', '17', '17206', '9220136', '石川県', 'イシカワケン', '加賀市', 'カガシ', '山中温泉枯淵町', 'ヤマナカオンセンカレブチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市山中温泉九谷町', '17', '17206', '9220136', '石川県', 'イシカワケン', '加賀市', 'カガシ', '山中温泉九谷町', 'ヤマナカオンセンクタニマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市山中温泉坂下町', '17', '17206', '9220136', '石川県', 'イシカワケン', '加賀市', 'カガシ', '山中温泉坂下町', 'ヤマナカオンセンサカノシモマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市山中温泉杉水町', '17', '17206', '9220136', '石川県', 'イシカワケン', '加賀市', 'カガシ', '山中温泉杉水町', 'ヤマナカオンセンスギノミズマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市山中温泉片谷町', '17', '17206', '9220136', '石川県', 'イシカワケン', '加賀市', 'カガシ', '山中温泉片谷町', 'ヤマナカオンセンヘキタニマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市山中温泉真砂町', '17', '17206', '9220136', '石川県', 'イシカワケン', '加賀市', 'カガシ', '山中温泉真砂町', 'ヤマナカオンセンマナゴマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市山中温泉風谷町', '17', '17206', '9220137', '石川県', 'イシカワケン', '加賀市', 'カガシ', '山中温泉風谷町', 'ヤマナカオンセンカゼタニマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市山中温泉我谷町', '17', '17206', '9220137', '石川県', 'イシカワケン', '加賀市', 'カガシ', '山中温泉我谷町', 'ヤマナカオンセンワガタニマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市山中温泉栢野町', '17', '17206', '9220138', '石川県', 'イシカワケン', '加賀市', 'カガシ', '山中温泉栢野町', 'ヤマナカオンセンカヤノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市山中温泉菅谷町', '17', '17206', '9220139', '石川県', 'イシカワケン', '加賀市', 'カガシ', '山中温泉菅谷町', 'ヤマナカオンセンスガタニマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市上野町丸山', '17', '17206', '9220222', '石川県', 'イシカワケン', '加賀市', 'カガシ', '上野町', 'ウワノマチ', null, null, '丸山', 'マルヤマ');
INSERT INTO `ms_addresses` VALUES ('123738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市加茂町', '17', '17206', '9220241', '石川県', 'イシカワケン', '加賀市', 'カガシ', '加茂町', 'カモマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市山代温泉', '17', '17206', '9220242', '石川県', 'イシカワケン', '加賀市', 'カガシ', '山代温泉', 'ヤマシロオンセン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市山代温泉北部', '17', '17206', '9220243', '石川県', 'イシカワケン', '加賀市', 'カガシ', '山代温泉', 'ヤマシロオンセン', null, null, '北部', 'ホクブ');
INSERT INTO `ms_addresses` VALUES ('123741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市山代温泉神明町', '17', '17206', '9220244', '石川県', 'イシカワケン', '加賀市', 'カガシ', '山代温泉', 'ヤマシロオンセン', null, null, '神明町', 'シンメイチョウ');
INSERT INTO `ms_addresses` VALUES ('123742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市山代温泉山背台', '17', '17206', '9220245', '石川県', 'イシカワケン', '加賀市', 'カガシ', '山代温泉', 'ヤマシロオンセン', null, null, '山背台', 'ヤマセダイ');
INSERT INTO `ms_addresses` VALUES ('123743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市山代温泉八幡', '17', '17206', '9220246', '石川県', 'イシカワケン', '加賀市', 'カガシ', '山代温泉', 'ヤマシロオンセン', null, null, '八幡', 'ハチマン');
INSERT INTO `ms_addresses` VALUES ('123744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市山代温泉上宮', '17', '17206', '9220247', '石川県', 'イシカワケン', '加賀市', 'カガシ', '山代温泉', 'ヤマシロオンセン', null, null, '上宮', 'ウワミヤ');
INSERT INTO `ms_addresses` VALUES ('123745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市山代温泉桜町', '17', '17206', '9220250', '石川県', 'イシカワケン', '加賀市', 'カガシ', '山代温泉桜町', 'ヤマシロオンセンサクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市山代温泉大和町', '17', '17206', '9220251', '石川県', 'イシカワケン', '加賀市', 'カガシ', '山代温泉', 'ヤマシロオンセン', null, null, '大和町', 'ヤマトマチ');
INSERT INTO `ms_addresses` VALUES ('123747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市山代温泉九谷町', '17', '17206', '9220252', '石川県', 'イシカワケン', '加賀市', 'カガシ', '山代温泉', 'ヤマシロオンセン', null, null, '九谷町', 'クタニマチ');
INSERT INTO `ms_addresses` VALUES ('123748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市山代温泉東山町', '17', '17206', '9220253', '石川県', 'イシカワケン', '加賀市', 'カガシ', '山代温泉', 'ヤマシロオンセン', null, null, '東山町', 'ヒガシヤママチ');
INSERT INTO `ms_addresses` VALUES ('123749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市山代温泉温泉通り', '17', '17206', '9220254', '石川県', 'イシカワケン', '加賀市', 'カガシ', '山代温泉', 'ヤマシロオンセン', null, null, '温泉通り', 'オンセンドオリ');
INSERT INTO `ms_addresses` VALUES ('123750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市山代温泉幸町', '17', '17206', '9220255', '石川県', 'イシカワケン', '加賀市', 'カガシ', '山代温泉', 'ヤマシロオンセン', null, null, '幸町', 'サイワイチョウ');
INSERT INTO `ms_addresses` VALUES ('123751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市山代温泉万松園通', '17', '17206', '9220256', '石川県', 'イシカワケン', '加賀市', 'カガシ', '山代温泉', 'ヤマシロオンセン', null, null, '万松園通', 'バンショウエンドオリ');
INSERT INTO `ms_addresses` VALUES ('123752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市山代温泉桔梗丘', '17', '17206', '9220257', '石川県', 'イシカワケン', '加賀市', 'カガシ', '山代温泉', 'ヤマシロオンセン', null, null, '桔梗丘', 'キキョウガオカ');
INSERT INTO `ms_addresses` VALUES ('123753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市山代温泉南町', '17', '17206', '9220258', '石川県', 'イシカワケン', '加賀市', 'カガシ', '山代温泉', 'ヤマシロオンセン', null, null, '南町', 'ミナミチョウ');
INSERT INTO `ms_addresses` VALUES ('123754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市横北町', '17', '17206', '9220261', '石川県', 'イシカワケン', '加賀市', 'カガシ', '横北町', 'ヨコギタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市柏野町', '17', '17206', '9220262', '石川県', 'イシカワケン', '加賀市', 'カガシ', '柏野町', 'カシワノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市塔尾町', '17', '17206', '9220263', '石川県', 'イシカワケン', '加賀市', 'カガシ', '塔尾町', 'トノオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市須谷町', '17', '17206', '9220264', '石川県', 'イシカワケン', '加賀市', 'カガシ', '須谷町', 'スダニマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市水田丸町', '17', '17206', '9220265', '石川県', 'イシカワケン', '加賀市', 'カガシ', '水田丸町', 'ミズタマルマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市小坂町', '17', '17206', '9220266', '石川県', 'イシカワケン', '加賀市', 'カガシ', '小坂町', 'コサカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市二ツ屋町', '17', '17206', '9220267', '石川県', 'イシカワケン', '加賀市', 'カガシ', '二ツ屋町', 'フタツヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市尾俣町', '17', '17206', '9220271', '石川県', 'イシカワケン', '加賀市', 'カガシ', '尾俣町', 'オマタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市尾俣町大桜', '17', '17206', '9220272', '石川県', 'イシカワケン', '加賀市', 'カガシ', '尾俣町', 'オマタマチ', null, null, '大桜', 'オオザクラ');
INSERT INTO `ms_addresses` VALUES ('123763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市桂谷町', '17', '17206', '9220273', '石川県', 'イシカワケン', '加賀市', 'カガシ', '桂谷町', 'カツラタニマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市別所町', '17', '17206', '9220274', '石川県', 'イシカワケン', '加賀市', 'カガシ', '別所町', 'ベッショマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市別所町富士見ケ丘', '17', '17206', '9220275', '石川県', 'イシカワケン', '加賀市', 'カガシ', '別所町', 'ベッショマチ', null, null, '富士見ケ丘', 'フジミガオカ');
INSERT INTO `ms_addresses` VALUES ('123766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市河南町淀町', '17', '17206', '9220276', '石川県', 'イシカワケン', '加賀市', 'カガシ', '河南町', 'カワミナミマチ', null, null, '淀町', 'ヨドマチ');
INSERT INTO `ms_addresses` VALUES ('123767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市河南町', '17', '17206', '9220277', '石川県', 'イシカワケン', '加賀市', 'カガシ', '河南町', 'カワミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市荒木町', '17', '17206', '9220278', '石川県', 'イシカワケン', '加賀市', 'カガシ', '荒木町', 'アラキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市高塚町', '17', '17206', '9220301', '石川県', 'イシカワケン', '加賀市', 'カガシ', '高塚町', 'タカツカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市打越町', '17', '17206', '9220302', '石川県', 'イシカワケン', '加賀市', 'カガシ', '打越町', 'ウチコシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市箱宮町', '17', '17206', '9220303', '石川県', 'イシカワケン', '加賀市', 'カガシ', '箱宮町', 'ハコミヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市分校町', '17', '17206', '9220304', '石川県', 'イシカワケン', '加賀市', 'カガシ', '分校町', 'ブンギョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市梶井町', '17', '17206', '9220305', '石川県', 'イシカワケン', '加賀市', 'カガシ', '梶井町', 'カジイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市中島町', '17', '17206', '9220306', '石川県', 'イシカワケン', '加賀市', 'カガシ', '中島町', 'ナカジママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市干拓町', '17', '17206', '9220307', '石川県', 'イシカワケン', '加賀市', 'カガシ', '干拓町', 'カンタクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市栄谷町', '17', '17206', '9220311', '石川県', 'イシカワケン', '加賀市', 'カガシ', '栄谷町', 'サカエダニマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市宇谷町', '17', '17206', '9220312', '石川県', 'イシカワケン', '加賀市', 'カガシ', '宇谷町', 'ウダニマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市勅使町', '17', '17206', '9220313', '石川県', 'イシカワケン', '加賀市', 'カガシ', '勅使町', 'チョクシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市河原町', '17', '17206', '9220314', '石川県', 'イシカワケン', '加賀市', 'カガシ', '河原町', 'カワラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市清水町', '17', '17206', '9220315', '石川県', 'イシカワケン', '加賀市', 'カガシ', '清水町', 'シミズマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市松山町', '17', '17206', '9220316', '石川県', 'イシカワケン', '加賀市', 'カガシ', '松山町', 'マツヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市森町', '17', '17206', '9220321', '石川県', 'イシカワケン', '加賀市', 'カガシ', '森町', 'モリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市上野町', '17', '17206', '9220322', '石川県', 'イシカワケン', '加賀市', 'カガシ', '上野町', 'ウワノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市若葉台', '17', '17206', '9220323', '石川県', 'イシカワケン', '加賀市', 'カガシ', '若葉台', 'ワカバダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市七日市新町', '17', '17206', '9220324', '石川県', 'イシカワケン', '加賀市', 'カガシ', '七日市新町', 'ナンカイチシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市二子塚町', '17', '17206', '9220325', '石川県', 'イシカワケン', '加賀市', 'カガシ', '二子塚町', 'フタゴヅカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市桑原町', '17', '17206', '9220326', '石川県', 'イシカワケン', '加賀市', 'カガシ', '桑原町', 'クワバラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市動橋町', '17', '17206', '9220331', '石川県', 'イシカワケン', '加賀市', 'カガシ', '動橋町', 'イブリハシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市庄町', '17', '17206', '9220332', '石川県', 'イシカワケン', '加賀市', 'カガシ', '庄町', 'ショウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市津波倉町', '17', '17206', '9220333', '石川県', 'イシカワケン', '加賀市', 'カガシ', '津波倉町', 'ツバクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市西島町', '17', '17206', '9220334', '石川県', 'イシカワケン', '加賀市', 'カガシ', '西島町', 'ニシジママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市七日市町', '17', '17206', '9220335', '石川県', 'イシカワケン', '加賀市', 'カガシ', '七日市町', 'ナンカイチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市八日市町', '17', '17206', '9220336', '石川県', 'イシカワケン', '加賀市', 'カガシ', '八日市町', 'ヨウカイチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市合河町', '17', '17206', '9220337', '石川県', 'イシカワケン', '加賀市', 'カガシ', '合河町', 'アイカワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市新保町', '17', '17206', '9220401', '石川県', 'イシカワケン', '加賀市', 'カガシ', '新保町', 'シンボマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市柴山町', '17', '17206', '9220402', '石川県', 'イシカワケン', '加賀市', 'カガシ', '柴山町', 'シバヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市一白町', '17', '17206', '9220403', '石川県', 'イシカワケン', '加賀市', 'カガシ', '一白町', 'イッパクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市源平町', '17', '17206', '9220404', '石川県', 'イシカワケン', '加賀市', 'カガシ', '源平町', 'ゲンペイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市手塚町', '17', '17206', '9220405', '石川県', 'イシカワケン', '加賀市', 'カガシ', '手塚町', 'テヅカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市伊切町', '17', '17206', '9220406', '石川県', 'イシカワケン', '加賀市', 'カガシ', '伊切町', 'イキリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市潮津町', '17', '17206', '9220411', '石川県', 'イシカワケン', '加賀市', 'カガシ', '潮津町', 'ウシオヅマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市片山津温泉', '17', '17206', '9220412', '石川県', 'イシカワケン', '加賀市', 'カガシ', '片山津温泉', 'カタヤマヅオンセン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市湖城町', '17', '17206', '9220413', '石川県', 'イシカワケン', '加賀市', 'カガシ', '湖城町', 'コジョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市片山津町', '17', '17206', '9220414', '石川県', 'イシカワケン', '加賀市', 'カガシ', '片山津町', 'カタヤマヅマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市冨塚町', '17', '17206', '9220421', '石川県', 'イシカワケン', '加賀市', 'カガシ', '冨塚町', 'トミツカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市弓波町', '17', '17206', '9220422', '石川県', 'イシカワケン', '加賀市', 'カガシ', '弓波町', 'ユミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市作見町', '17', '17206', '9220423', '石川県', 'イシカワケン', '加賀市', 'カガシ', '作見町', 'サクミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市小菅波町', '17', '17206', '9220424', '石川県', 'イシカワケン', '加賀市', 'カガシ', '小菅波町', 'コスガナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市大菅波町', '17', '17206', '9220425', '石川県', 'イシカワケン', '加賀市', 'カガシ', '大菅波町', 'オオスガナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市天日町', '17', '17206', '9220426', '石川県', 'イシカワケン', '加賀市', 'カガシ', '天日町', 'テンニチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市ときわ台', '17', '17206', '9220427', '石川県', 'イシカワケン', '加賀市', 'カガシ', 'ときわ台', 'トキワダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市尾中町', '17', '17206', '9220428', '石川県', 'イシカワケン', '加賀市', 'カガシ', '尾中町', 'オチュウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市山田町', '17', '17206', '9220431', '石川県', 'イシカワケン', '加賀市', 'カガシ', '山田町', 'ヤマダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市東山田町', '17', '17206', '9220432', '石川県', 'イシカワケン', '加賀市', 'カガシ', '東山田町', 'ヒガシヤマダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市西山田町', '17', '17206', '9220433', '石川県', 'イシカワケン', '加賀市', 'カガシ', '西山田町', 'ニシヤマダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市北山田町', '17', '17206', '9220434', '石川県', 'イシカワケン', '加賀市', 'カガシ', '北山田町', 'キタヤマダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市希望が丘', '17', '17206', '9220435', '石川県', 'イシカワケン', '加賀市', 'カガシ', '希望が丘', 'キボウガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市松が丘', '17', '17206', '9220436', '石川県', 'イシカワケン', '加賀市', 'カガシ', '松が丘', 'マツガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市白山台', '17', '17206', '9220437', '石川県', 'イシカワケン', '加賀市', 'カガシ', '白山台', 'ハクサンダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市篠原新町', '17', '17206', '9220441', '石川県', 'イシカワケン', '加賀市', 'カガシ', '篠原新町', 'シノハラシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市篠原町', '17', '17206', '9220442', '石川県', 'イシカワケン', '加賀市', 'カガシ', '篠原町', 'シノハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市野田町', '17', '17206', '9220443', '石川県', 'イシカワケン', '加賀市', 'カガシ', '野田町', 'ノダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市宮地町', '17', '17206', '9220444', '石川県', 'イシカワケン', '加賀市', 'カガシ', '宮地町', 'ミヤジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市小塩辻町', '17', '17206', '9220445', '石川県', 'イシカワケン', '加賀市', 'カガシ', '小塩辻町', 'オシオツジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市塩浜町', '17', '17206', '9220446', '石川県', 'イシカワケン', '加賀市', 'カガシ', '塩浜町', 'シオハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市美岬町', '17', '17206', '9220551', '石川県', 'イシカワケン', '加賀市', 'カガシ', '美岬町', 'ミサキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市田尻町', '17', '17206', '9220552', '石川県', 'イシカワケン', '加賀市', 'カガシ', '田尻町', 'タジリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市小塩町', '17', '17206', '9220553', '石川県', 'イシカワケン', '加賀市', 'カガシ', '小塩町', 'オシオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市橋立町', '17', '17206', '9220554', '石川県', 'イシカワケン', '加賀市', 'カガシ', '橋立町', 'ハシタテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市宮町', '17', '17206', '9220561', '石川県', 'イシカワケン', '加賀市', 'カガシ', '宮町', 'ミヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市高尾町', '17', '17206', '9220562', '石川県', 'イシカワケン', '加賀市', 'カガシ', '高尾町', 'タカオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市豊町', '17', '17206', '9220563', '石川県', 'イシカワケン', '加賀市', 'カガシ', '豊町', 'ユタカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市片野町', '17', '17206', '9220564', '石川県', 'イシカワケン', '加賀市', 'カガシ', '片野町', 'カタノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市黒崎町', '17', '17206', '9220565', '石川県', 'イシカワケン', '加賀市', 'カガシ', '黒崎町', 'クロサキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市深田町', '17', '17206', '9220566', '石川県', 'イシカワケン', '加賀市', 'カガシ', '深田町', 'フカタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市大聖寺瀬越町', '17', '17206', '9220671', '石川県', 'イシカワケン', '加賀市', 'カガシ', '大聖寺瀬越町', 'ダイショウジセゴエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市吉崎町', '17', '17206', '9220672', '石川県', 'イシカワケン', '加賀市', 'カガシ', '吉崎町', 'ヨシザキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市塩屋町', '17', '17206', '9220673', '石川県', 'イシカワケン', '加賀市', 'カガシ', '塩屋町', 'シオヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福井県あわら市吉崎', '18', '18208', '9220679', '福井県', 'フクイケン', 'あわら市', 'アワラシ', '吉崎', 'ヨシザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市大聖寺関町', '17', '17206', '9220801', '石川県', 'イシカワケン', '加賀市', 'カガシ', '大聖寺関町', 'ダイショウジセキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市大聖寺越前町', '17', '17206', '9220802', '石川県', 'イシカワケン', '加賀市', 'カガシ', '大聖寺越前町', 'ダイショウジエチゼンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市大聖寺越前三ツ屋町', '17', '17206', '9220803', '石川県', 'イシカワケン', '加賀市', 'カガシ', '大聖寺越前三ツ屋町', 'ダイショウジエチゼンミツヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市大聖寺三ツ屋町', '17', '17206', '9220803', '石川県', 'イシカワケン', '加賀市', 'カガシ', '大聖寺三ツ屋町', 'ダイショウジミツヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市大聖寺中新道', '17', '17206', '9220804', '石川県', 'イシカワケン', '加賀市', 'カガシ', '大聖寺中新道', 'ダイショウジナカシンミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市大聖寺新屋敷町', '17', '17206', '9220805', '石川県', 'イシカワケン', '加賀市', 'カガシ', '大聖寺新屋敷町', 'ダイショウジシンヤシキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市大聖寺大新道', '17', '17206', '9220806', '石川県', 'イシカワケン', '加賀市', 'カガシ', '大聖寺大新道', 'ダイショウジオオシンミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市大聖寺神明町', '17', '17206', '9220807', '石川県', 'イシカワケン', '加賀市', 'カガシ', '大聖寺神明町', 'ダイショウジシンメイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市大聖寺南町', '17', '17206', '9220811', '石川県', 'イシカワケン', '加賀市', 'カガシ', '大聖寺南町', 'ダイショウジミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市大聖寺田原町', '17', '17206', '9220812', '石川県', 'イシカワケン', '加賀市', 'カガシ', '大聖寺田原町', 'ダイショウジタワラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市大聖寺弓町', '17', '17206', '9220813', '石川県', 'イシカワケン', '加賀市', 'カガシ', '大聖寺弓町', 'ダイショウジユミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市大聖寺菅生町', '17', '17206', '9220814', '石川県', 'イシカワケン', '加賀市', 'カガシ', '大聖寺菅生町', 'ダイショウジスゴウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市大聖寺菅生', '17', '17206', '9220815', '石川県', 'イシカワケン', '加賀市', 'カガシ', '大聖寺菅生', 'ダイショウジスゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市大聖寺東町', '17', '17206', '9220816', '石川県', 'イシカワケン', '加賀市', 'カガシ', '大聖寺東町', 'ダイショウジヒガシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市南郷町', '17', '17206', '9220821', '石川県', 'イシカワケン', '加賀市', 'カガシ', '南郷町', 'ナンゴウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市吸坂町', '17', '17206', '9220822', '石川県', 'イシカワケン', '加賀市', 'カガシ', '吸坂町', 'スイサカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市黒瀬町', '17', '17206', '9220823', '石川県', 'イシカワケン', '加賀市', 'カガシ', '黒瀬町', 'クロセマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市日谷町', '17', '17206', '9220824', '石川県', 'イシカワケン', '加賀市', 'カガシ', '日谷町', 'ヒノヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市直下町', '17', '17206', '9220825', '石川県', 'イシカワケン', '加賀市', 'カガシ', '直下町', 'ソソリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市幸町', '17', '17206', '9220831', '石川県', 'イシカワケン', '加賀市', 'カガシ', '幸町', 'サイワイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市百々町', '17', '17206', '9220832', '石川県', 'イシカワケン', '加賀市', 'カガシ', '百々町', 'ドドマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市曾宇町', '17', '17206', '9220833', '石川県', 'イシカワケン', '加賀市', 'カガシ', '曾宇町', 'ソウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市美谷が丘', '17', '17206', '9220834', '石川県', 'イシカワケン', '加賀市', 'カガシ', '美谷が丘', 'ミタニガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市細坪町', '17', '17206', '9220835', '石川県', 'イシカワケン', '加賀市', 'カガシ', '細坪町', 'ホソツボマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市白鳥町', '17', '17206', '9220836', '石川県', 'イシカワケン', '加賀市', 'カガシ', '白鳥町', 'シラトリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市大聖寺下屋敷町', '17', '17206', '9220841', '石川県', 'イシカワケン', '加賀市', 'カガシ', '大聖寺下屋敷町', 'ダイショウジシタヤシキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市熊坂町', '17', '17206', '9220842', '石川県', 'イシカワケン', '加賀市', 'カガシ', '熊坂町', 'クマサカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市大同町', '17', '17206', '9220843', '石川県', 'イシカワケン', '加賀市', 'カガシ', '大同町', 'ダイドウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市白望台町', '17', '17206', '9220844', '石川県', 'イシカワケン', '加賀市', 'カガシ', '白望台町', 'ハクボウダイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市大聖寺錦城ケ丘', '17', '17206', '9220851', '石川県', 'イシカワケン', '加賀市', 'カガシ', '大聖寺錦城ケ丘', 'ダイショウジキンジョウガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市大聖寺緑ケ丘', '17', '17206', '9220852', '石川県', 'イシカワケン', '加賀市', 'カガシ', '大聖寺緑ケ丘', 'ダイショウジミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市大聖寺三ツ町', '17', '17206', '9220853', '石川県', 'イシカワケン', '加賀市', 'カガシ', '大聖寺三ツ町', 'ダイショウジミツマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市三木町', '17', '17206', '9220854', '石川県', 'イシカワケン', '加賀市', 'カガシ', '三木町', 'ミキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市橘町', '17', '17206', '9220855', '石川県', 'イシカワケン', '加賀市', 'カガシ', '橘町', 'タチバナマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市奥谷町', '17', '17206', '9220856', '石川県', 'イシカワケン', '加賀市', 'カガシ', '奥谷町', 'オクノヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市永井町', '17', '17206', '9220857', '石川県', 'イシカワケン', '加賀市', 'カガシ', '永井町', 'ナガイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市大聖寺地方町', '17', '17206', '9220861', '石川県', 'イシカワケン', '加賀市', 'カガシ', '大聖寺地方町', 'ダイショウジジカタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市大聖寺錦町', '17', '17206', '9220862', '石川県', 'イシカワケン', '加賀市', 'カガシ', '大聖寺錦町', 'ダイショウジニシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市大聖寺今出町', '17', '17206', '9220863', '石川県', 'イシカワケン', '加賀市', 'カガシ', '大聖寺今出町', 'ダイショウジイマデマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市大聖寺西栄町', '17', '17206', '9220864', '石川県', 'イシカワケン', '加賀市', 'カガシ', '大聖寺西栄町', 'ダイショウジニシサカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県加賀市大聖寺西町', '17', '17206', '9220865', '石川県', 'イシカワケン', '加賀市', 'カガシ', '大聖寺西町', 'ダイショウジニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市', '17', '17203', '9230000', '石川県', 'イシカワケン', '小松市', 'コマツシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('123909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市大島町', '17', '17203', '9230001', '石川県', 'イシカワケン', '小松市', 'コマツシ', '大島町', 'オオシママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市小島町', '17', '17203', '9230002', '石川県', 'イシカワケン', '小松市', 'コマツシ', '小島町', 'コジママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市安宅町', '17', '17203', '9230003', '石川県', 'イシカワケン', '小松市', 'コマツシ', '安宅町', 'アタカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市長崎町', '17', '17203', '9230004', '石川県', 'イシカワケン', '小松市', 'コマツシ', '長崎町', 'ナガサキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市坊丸町', '17', '17203', '9230005', '石川県', 'イシカワケン', '小松市', 'コマツシ', '坊丸町', 'ボウマルマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市蛭川町', '17', '17203', '9230011', '石川県', 'イシカワケン', '小松市', 'コマツシ', '蛭川町', 'ビルガワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市東蛭川町', '17', '17203', '9230012', '石川県', 'イシカワケン', '小松市', 'コマツシ', '東蛭川町', 'ヒガシヒルガワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市城北町', '17', '17203', '9230013', '石川県', 'イシカワケン', '小松市', 'コマツシ', '城北町', 'ジョウホクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市松梨町', '17', '17203', '9230014', '石川県', 'イシカワケン', '小松市', 'コマツシ', '松梨町', 'マツナシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市犬丸町', '17', '17203', '9230015', '石川県', 'イシカワケン', '小松市', 'コマツシ', '犬丸町', 'イヌマルマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市御館町', '17', '17203', '9230016', '石川県', 'イシカワケン', '小松市', 'コマツシ', '御館町', 'オタチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市島田町', '17', '17203', '9230021', '石川県', 'イシカワケン', '小松市', 'コマツシ', '島田町', 'シマダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市美原町', '17', '17203', '9230022', '石川県', 'イシカワケン', '小松市', 'コマツシ', '美原町', 'ミハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市梅田町', '17', '17203', '9230023', '石川県', 'イシカワケン', '小松市', 'コマツシ', '梅田町', 'ウメダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市茶屋町', '17', '17203', '9230024', '石川県', 'イシカワケン', '小松市', 'コマツシ', '茶屋町', 'チャヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市天神町', '17', '17203', '9230025', '石川県', 'イシカワケン', '小松市', 'コマツシ', '天神町', 'テンジンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市下牧町', '17', '17203', '9230026', '石川県', 'イシカワケン', '小松市', 'コマツシ', '下牧町', 'シモマキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市上牧町', '17', '17203', '9230027', '石川県', 'イシカワケン', '小松市', 'コマツシ', '上牧町', 'カミマキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市梯町', '17', '17203', '9230028', '石川県', 'イシカワケン', '小松市', 'コマツシ', '梯町', 'カケハシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市高堂町', '17', '17203', '9230031', '石川県', 'イシカワケン', '小松市', 'コマツシ', '高堂町', 'タカンドウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市荒屋町', '17', '17203', '9230032', '石川県', 'イシカワケン', '小松市', 'コマツシ', '荒屋町', 'アラヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市野田町', '17', '17203', '9230033', '石川県', 'イシカワケン', '小松市', 'コマツシ', '野田町', 'ノダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市長田町', '17', '17203', '9230034', '石川県', 'イシカワケン', '小松市', 'コマツシ', '長田町', 'ナガダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市あけぼの町', '17', '17203', '9230035', '石川県', 'イシカワケン', '小松市', 'コマツシ', 'あけぼの町', 'アケボノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市平面町', '17', '17203', '9230036', '石川県', 'イシカワケン', '小松市', 'コマツシ', '平面町', 'ヒラオモテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市問屋町', '17', '17203', '9230037', '石川県', 'イシカワケン', '小松市', 'コマツシ', '問屋町', 'トンヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市千代町', '17', '17203', '9230041', '石川県', 'イシカワケン', '小松市', 'コマツシ', '千代町', 'センダイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市能美町', '17', '17203', '9230042', '石川県', 'イシカワケン', '小松市', 'コマツシ', '能美町', 'ノミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市一針町', '17', '17203', '9230043', '石川県', 'イシカワケン', '小松市', 'コマツシ', '一針町', 'ヒトツハリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市川辺町', '17', '17203', '9230044', '石川県', 'イシカワケン', '小松市', 'コマツシ', '川辺町', 'カワベマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市上八里町', '17', '17203', '9230051', '石川県', 'イシカワケン', '小松市', 'コマツシ', '上八里町', 'カミヤサトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市下八里町', '17', '17203', '9230052', '石川県', 'イシカワケン', '小松市', 'コマツシ', '下八里町', 'シモヤサトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市河田町', '17', '17203', '9230053', '石川県', 'イシカワケン', '小松市', 'コマツシ', '河田町', 'コウダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市小野町', '17', '17203', '9230054', '石川県', 'イシカワケン', '小松市', 'コマツシ', '小野町', 'オノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市古府町', '17', '17203', '9230055', '石川県', 'イシカワケン', '小松市', 'コマツシ', '古府町', 'コフマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市八里台', '17', '17203', '9230056', '石川県', 'イシカワケン', '小松市', 'コマツシ', '八里台', 'ヤサトダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市国府台', '17', '17203', '9230061', '石川県', 'イシカワケン', '小松市', 'コマツシ', '国府台', 'コクフダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市里川町', '17', '17203', '9230062', '石川県', 'イシカワケン', '小松市', 'コマツシ', '里川町', 'サトカワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市鵜川町', '17', '17203', '9230063', '石川県', 'イシカワケン', '小松市', 'コマツシ', '鵜川町', 'ウガワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市遊泉寺町', '17', '17203', '9230064', '石川県', 'イシカワケン', '小松市', 'コマツシ', '遊泉寺町', 'ユウセンジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市立明寺町', '17', '17203', '9230065', '石川県', 'イシカワケン', '小松市', 'コマツシ', '立明寺町', 'リュウミョウジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市埴田町', '17', '17203', '9230066', '石川県', 'イシカワケン', '小松市', 'コマツシ', '埴田町', 'ハネダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市中海町', '17', '17203', '9230071', '石川県', 'イシカワケン', '小松市', 'コマツシ', '中海町', 'ナカウミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市みどり町', '17', '17203', '9230072', '石川県', 'イシカワケン', '小松市', 'コマツシ', 'みどり町', 'ミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市岩渕町', '17', '17203', '9230073', '石川県', 'イシカワケン', '小松市', 'コマツシ', '岩渕町', 'イワブチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市桂町', '17', '17203', '9230074', '石川県', 'イシカワケン', '小松市', 'コマツシ', '桂町', 'カツラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市原町', '17', '17203', '9230075', '石川県', 'イシカワケン', '小松市', 'コマツシ', '原町', 'ハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市麦口町', '17', '17203', '9230076', '石川県', 'イシカワケン', '小松市', 'コマツシ', '麦口町', 'ムギクチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市上麦口町', '17', '17203', '9230077', '石川県', 'イシカワケン', '小松市', 'コマツシ', '上麦口町', 'カミムギクチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市嵐町', '17', '17203', '9230078', '石川県', 'イシカワケン', '小松市', 'コマツシ', '嵐町', 'アラシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市中ノ峠町', '17', '17203', '9230078', '石川県', 'イシカワケン', '小松市', 'コマツシ', '中ノ峠町', 'ナカノトウゲマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市正蓮寺町', '17', '17203', '9230151', '石川県', 'イシカワケン', '小松市', 'コマツシ', '正蓮寺町', 'ショウレンジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市五国寺町', '17', '17203', '9230152', '石川県', 'イシカワケン', '小松市', 'コマツシ', '五国寺町', 'ゴコウジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市金平町', '17', '17203', '9230153', '石川県', 'イシカワケン', '小松市', 'コマツシ', '金平町', 'カナヒラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市金野町', '17', '17203', '9230154', '石川県', 'イシカワケン', '小松市', 'コマツシ', '金野町', 'カネノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市江指町', '17', '17203', '9230155', '石川県', 'イシカワケン', '小松市', 'コマツシ', '江指町', 'エサシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市大野町', '17', '17203', '9230156', '石川県', 'イシカワケン', '小松市', 'コマツシ', '大野町', 'オオノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市花坂町', '17', '17203', '9230157', '石川県', 'イシカワケン', '小松市', 'コマツシ', '花坂町', 'ハナサカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市池城町', '17', '17203', '9230161', '石川県', 'イシカワケン', '小松市', 'コマツシ', '池城町', 'イケノジョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市波佐羅町', '17', '17203', '9230162', '石川県', 'イシカワケン', '小松市', 'コマツシ', '波佐羅町', 'ハサラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市塩原町', '17', '17203', '9230163', '石川県', 'イシカワケン', '小松市', 'コマツシ', '塩原町', 'シオハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市布橋町', '17', '17203', '9230164', '石川県', 'イシカワケン', '小松市', 'コマツシ', '布橋町', 'ヌノハシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市沢町', '17', '17203', '9230165', '石川県', 'イシカワケン', '小松市', 'コマツシ', '沢町', 'サワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市松岡町', '17', '17203', '9230166', '石川県', 'イシカワケン', '小松市', 'コマツシ', '松岡町', 'マツオカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市観音下町', '17', '17203', '9230171', '石川県', 'イシカワケン', '小松市', 'コマツシ', '観音下町', 'カナガソマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市尾小屋町', '17', '17203', '9230172', '石川県', 'イシカワケン', '小松市', 'コマツシ', '尾小屋町', 'オゴヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市丸山町', '17', '17203', '9230173', '石川県', 'イシカワケン', '小松市', 'コマツシ', '丸山町', 'マルヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市花立町', '17', '17203', '9230174', '石川県', 'イシカワケン', '小松市', 'コマツシ', '花立町', 'ハナタテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市新保町', '17', '17203', '9230175', '石川県', 'イシカワケン', '小松市', 'コマツシ', '新保町', 'シンボマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市西俣町', '17', '17203', '9230176', '石川県', 'イシカワケン', '小松市', 'コマツシ', '西俣町', 'ニシマタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市岩上町', '17', '17203', '9230177', '石川県', 'イシカワケン', '小松市', 'コマツシ', '岩上町', 'イワガミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市長谷町', '17', '17203', '9230181', '石川県', 'イシカワケン', '小松市', 'コマツシ', '長谷町', 'ナガタニマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市波佐谷町', '17', '17203', '9230182', '石川県', 'イシカワケン', '小松市', 'コマツシ', '波佐谷町', 'ハサダニマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市瀬領町', '17', '17203', '9230183', '石川県', 'イシカワケン', '小松市', 'コマツシ', '瀬領町', 'セイリョマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市打木町', '17', '17203', '9230184', '石川県', 'イシカワケン', '小松市', 'コマツシ', '打木町', 'ウツギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市赤瀬町', '17', '17203', '9230185', '石川県', 'イシカワケン', '小松市', 'コマツシ', '赤瀬町', 'アカゼマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市大杉町', '17', '17203', '9230186', '石川県', 'イシカワケン', '小松市', 'コマツシ', '大杉町', 'オオスギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市上リ江町', '17', '17203', '9230187', '石川県', 'イシカワケン', '小松市', 'コマツシ', '上リ江町', 'アガリエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市矢崎町', '17', '17203', '9230301', '石川県', 'イシカワケン', '小松市', 'コマツシ', '矢崎町', 'ヤザキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市符津町', '17', '17203', '9230302', '石川県', 'イシカワケン', '小松市', 'コマツシ', '符津町', 'フツマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市島町', '17', '17203', '9230303', '石川県', 'イシカワケン', '小松市', 'コマツシ', '島町', 'シママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市下粟津町', '17', '17203', '9230304', '石川県', 'イシカワケン', '小松市', 'コマツシ', '下粟津町', 'シモアワヅマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市蓑輪町', '17', '17203', '9230305', '石川県', 'イシカワケン', '小松市', 'コマツシ', '蓑輪町', 'ミノワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市松生町', '17', '17203', '9230306', '石川県', 'イシカワケン', '小松市', 'コマツシ', '松生町', 'マツオイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市木場町', '17', '17203', '9230311', '石川県', 'イシカワケン', '小松市', 'コマツシ', '木場町', 'キバマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市木場台', '17', '17203', '9230312', '石川県', 'イシカワケン', '小松市', 'コマツシ', '木場台', 'キバダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市津波倉町', '17', '17203', '9230313', '石川県', 'イシカワケン', '小松市', 'コマツシ', '津波倉町', 'ツバクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市おびし町', '17', '17203', '9230314', '石川県', 'イシカワケン', '小松市', 'コマツシ', 'おびし町', 'オビシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市小山田町', '17', '17203', '9230315', '石川県', 'イシカワケン', '小松市', 'コマツシ', '小山田町', 'コヤマダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市井口町', '17', '17203', '9230316', '石川県', 'イシカワケン', '小松市', 'コマツシ', '井口町', 'イノクチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('123999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市白山田町', '17', '17203', '9230321', '石川県', 'イシカワケン', '小松市', 'コマツシ', '白山田町', 'シラヤマダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市牧口町', '17', '17203', '9230322', '石川県', 'イシカワケン', '小松市', 'コマツシ', '牧口町', 'マキグチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市西荒谷町', '17', '17203', '9230323', '石川県', 'イシカワケン', '小松市', 'コマツシ', '西荒谷町', 'ニシアラタニマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市日用町', '17', '17203', '9230324', '石川県', 'イシカワケン', '小松市', 'コマツシ', '日用町', 'ヒヨウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市西原町', '17', '17203', '9230325', '石川県', 'イシカワケン', '小松市', 'コマツシ', '西原町', 'ニシハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市粟津温泉', '17', '17203', '9230326', '石川県', 'イシカワケン', '小松市', 'コマツシ', '粟津温泉', 'アワヅオンセン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市粟津町', '17', '17203', '9230326', '石川県', 'イシカワケン', '小松市', 'コマツシ', '粟津町', 'アワヅマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市戸津町', '17', '17203', '9230327', '石川県', 'イシカワケン', '小松市', 'コマツシ', '戸津町', 'トヅマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市南陽町', '17', '17203', '9230328', '石川県', 'イシカワケン', '小松市', 'コマツシ', '南陽町', 'ナンヨウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市上荒屋町', '17', '17203', '9230331', '石川県', 'イシカワケン', '小松市', 'コマツシ', '上荒屋町', 'カミアラヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市湯上町', '17', '17203', '9230332', '石川県', 'イシカワケン', '小松市', 'コマツシ', '湯上町', 'ユノカミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市馬場町', '17', '17203', '9230333', '石川県', 'イシカワケン', '小松市', 'コマツシ', '馬場町', 'バンバマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市菩提町', '17', '17203', '9230334', '石川県', 'イシカワケン', '小松市', 'コマツシ', '菩提町', 'ボダイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市滝ケ原町', '17', '17203', '9230335', '石川県', 'イシカワケン', '小松市', 'コマツシ', '滝ケ原町', 'タキガハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市那谷町', '17', '17203', '9230336', '石川県', 'イシカワケン', '小松市', 'コマツシ', '那谷町', 'ナタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市春日町', '17', '17203', '9230341', '石川県', 'イシカワケン', '小松市', 'コマツシ', '春日町', 'カスガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市矢田野町', '17', '17203', '9230342', '石川県', 'イシカワケン', '小松市', 'コマツシ', '矢田野町', 'ヤタノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市矢沢町', '17', '17203', '9230343', '石川県', 'イシカワケン', '小松市', 'コマツシ', '矢沢町', 'ヤザワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市林町', '17', '17203', '9230344', '石川県', 'イシカワケン', '小松市', 'コマツシ', '林町', 'ハヤシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市二ツ梨町', '17', '17203', '9230345', '石川県', 'イシカワケン', '小松市', 'コマツシ', '二ツ梨町', 'フタツナシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市園町', '17', '17203', '9230801', '石川県', 'イシカワケン', '小松市', 'コマツシ', '園町', 'ソノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市上小松町', '17', '17203', '9230802', '石川県', 'イシカワケン', '小松市', 'コマツシ', '上小松町', 'カミコマツマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市宝町', '17', '17203', '9230803', '石川県', 'イシカワケン', '小松市', 'コマツシ', '宝町', 'タカラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市光町', '17', '17203', '9230804', '石川県', 'イシカワケン', '小松市', 'コマツシ', '光町', 'ヒカリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市御宮町', '17', '17203', '9230805', '石川県', 'イシカワケン', '小松市', 'コマツシ', '御宮町', 'オミヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市小寺町', '17', '17203', '9230806', '石川県', 'イシカワケン', '小松市', 'コマツシ', '小寺町', 'コデラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市白江町', '17', '17203', '9230811', '石川県', 'イシカワケン', '小松市', 'コマツシ', '白江町', 'シラエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市漆町', '17', '17203', '9230812', '石川県', 'イシカワケン', '小松市', 'コマツシ', '漆町', 'ウルシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市金屋町', '17', '17203', '9230812', '石川県', 'イシカワケン', '小松市', 'コマツシ', '金屋町', 'カナヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市糸町', '17', '17203', '9230813', '石川県', 'イシカワケン', '小松市', 'コマツシ', '糸町', 'イトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市白松町', '17', '17203', '9230814', '石川県', 'イシカワケン', '小松市', 'コマツシ', '白松町', 'シラマツマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市佐々木町', '17', '17203', '9230821', '石川県', 'イシカワケン', '小松市', 'コマツシ', '佐々木町', 'ササキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市光陽町', '17', '17203', '9230822', '石川県', 'イシカワケン', '小松市', 'コマツシ', '光陽町', 'コウヨウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市荒木田町', '17', '17203', '9230823', '石川県', 'イシカワケン', '小松市', 'コマツシ', '荒木田町', 'アラキダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市軽海町', '17', '17203', '9230824', '石川県', 'イシカワケン', '小松市', 'コマツシ', '軽海町', 'カルミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市西軽海町', '17', '17203', '9230825', '石川県', 'イシカワケン', '小松市', 'コマツシ', '西軽海町', 'ニシカルミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市希望丘', '17', '17203', '9230826', '石川県', 'イシカワケン', '小松市', 'コマツシ', '希望丘', 'キボウガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市打越町', '17', '17203', '9230831', '石川県', 'イシカワケン', '小松市', 'コマツシ', '打越町', 'ウチコシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市若杉町', '17', '17203', '9230832', '石川県', 'イシカワケン', '小松市', 'コマツシ', '若杉町', 'ワカスギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市八幡加賀八幡', '17', '17203', '9230833', '石川県', 'イシカワケン', '小松市', 'コマツシ', '八幡', 'ヤワタ', null, null, '加賀八幡', 'カガヤワタ');
INSERT INTO `ms_addresses` VALUES ('124042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市千木野町', '17', '17203', '9230834', '石川県', 'イシカワケン', '小松市', 'コマツシ', '千木野町', 'セギノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市吉竹町', '17', '17203', '9230835', '石川県', 'イシカワケン', '小松市', 'コマツシ', '吉竹町', 'ヨシタケマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市鹿町', '17', '17203', '9230836', '石川県', 'イシカワケン', '小松市', 'コマツシ', '鹿町', 'シカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市本江町', '17', '17203', '9230841', '石川県', 'イシカワケン', '小松市', 'コマツシ', '本江町', 'ホンゴウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市東山町', '17', '17203', '9230842', '石川県', 'イシカワケン', '小松市', 'コマツシ', '東山町', 'ヒガシヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市蓮代寺町', '17', '17203', '9230843', '石川県', 'イシカワケン', '小松市', 'コマツシ', '蓮代寺町', 'レンダイジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市三谷町', '17', '17203', '9230844', '石川県', 'イシカワケン', '小松市', 'コマツシ', '三谷町', 'サンダニマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市北浅井町', '17', '17203', '9230851', '石川県', 'イシカワケン', '小松市', 'コマツシ', '北浅井町', 'キタアサイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市南浅井町', '17', '17203', '9230852', '石川県', 'イシカワケン', '小松市', 'コマツシ', '南浅井町', 'ミナミアサイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市扇町', '17', '17203', '9230853', '石川県', 'イシカワケン', '小松市', 'コマツシ', '扇町', 'オウギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市大領町', '17', '17203', '9230854', '石川県', 'イシカワケン', '小松市', 'コマツシ', '大領町', 'ダイリョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市沖町', '17', '17203', '9230861', '石川県', 'イシカワケン', '小松市', 'コマツシ', '沖町', 'オキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市清六町', '17', '17203', '9230862', '石川県', 'イシカワケン', '小松市', 'コマツシ', '清六町', 'セイロクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市三田町', '17', '17203', '9230862', '石川県', 'イシカワケン', '小松市', 'コマツシ', '三田町', 'ミタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市不動島町', '17', '17203', '9230863', '石川県', 'イシカワケン', '小松市', 'コマツシ', '不動島町', 'フドウジママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市有明町', '17', '17203', '9230864', '石川県', 'イシカワケン', '小松市', 'コマツシ', '有明町', 'アリアケマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市福乃宮町', '17', '17203', '9230865', '石川県', 'イシカワケン', '小松市', 'コマツシ', '福乃宮町', 'フクノミヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市白嶺町', '17', '17203', '9230866', '石川県', 'イシカワケン', '小松市', 'コマツシ', '白嶺町', 'シラネマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市幸町', '17', '17203', '9230867', '石川県', 'イシカワケン', '小松市', 'コマツシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市日の出町', '17', '17203', '9230868', '石川県', 'イシカワケン', '小松市', 'コマツシ', '日の出町', 'ヒノデマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市八日市町地方', '17', '17203', '9230868', '石川県', 'イシカワケン', '小松市', 'コマツシ', '八日市町地方', 'ヨウカイチマチジガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市泉町', '17', '17203', '9230901', '石川県', 'イシカワケン', '小松市', 'コマツシ', '泉町', 'イズミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市古城町', '17', '17203', '9230902', '石川県', 'イシカワケン', '小松市', 'コマツシ', '古城町', 'コジョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市丸の内公園町', '17', '17203', '9230903', '石川県', 'イシカワケン', '小松市', 'コマツシ', '丸の内公園町', 'マルノウチコウエンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市丸の内町', '17', '17203', '9230903', '石川県', 'イシカワケン', '小松市', 'コマツシ', '丸の内町', 'マルノウチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市丸内町', '17', '17203', '9230903', '石川県', 'イシカワケン', '小松市', 'コマツシ', '丸内町', 'マルノウチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市小馬出町', '17', '17203', '9230904', '石川県', 'イシカワケン', '小松市', 'コマツシ', '小馬出町', 'コンマデマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市地子町', '17', '17203', '9230905', '石川県', 'イシカワケン', '小松市', 'コマツシ', '地子町', 'ジシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市鷹匠町', '17', '17203', '9230905', '石川県', 'イシカワケン', '小松市', 'コマツシ', '鷹匠町', 'タカジョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市新大工町', '17', '17203', '9230906', '石川県', 'イシカワケン', '小松市', 'コマツシ', '新大工町', 'シンダイクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市浜田町', '17', '17203', '9230907', '石川県', 'イシカワケン', '小松市', 'コマツシ', '浜田町', 'ハマダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市浮城町', '17', '17203', '9230908', '石川県', 'イシカワケン', '小松市', 'コマツシ', '浮城町', 'ウキシロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市大川町', '17', '17203', '9230911', '石川県', 'イシカワケン', '小松市', 'コマツシ', '大川町', 'オオカワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市新町', '17', '17203', '9230912', '石川県', 'イシカワケン', '小松市', 'コマツシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市松任町', '17', '17203', '9230913', '石川県', 'イシカワケン', '小松市', 'コマツシ', '松任町', 'マットウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市新鍛冶町', '17', '17203', '9230914', '石川県', 'イシカワケン', '小松市', 'コマツシ', '新鍛冶町', 'シンカジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市細工町', '17', '17203', '9230915', '石川県', 'イシカワケン', '小松市', 'コマツシ', '細工町', 'サイクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市材木町', '17', '17203', '9230916', '石川県', 'イシカワケン', '小松市', 'コマツシ', '材木町', 'ザイモクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市中町', '17', '17203', '9230917', '石川県', 'イシカワケン', '小松市', 'コマツシ', '中町', 'ナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市京町', '17', '17203', '9230918', '石川県', 'イシカワケン', '小松市', 'コマツシ', '京町', 'キョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市殿町', '17', '17203', '9230919', '石川県', 'イシカワケン', '小松市', 'コマツシ', '殿町', 'トノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市土居原町', '17', '17203', '9230921', '石川県', 'イシカワケン', '小松市', 'コマツシ', '土居原町', 'ドイハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市飴屋町', '17', '17203', '9230922', '石川県', 'イシカワケン', '小松市', 'コマツシ', '飴屋町', 'アメヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市東町', '17', '17203', '9230923', '石川県', 'イシカワケン', '小松市', 'コマツシ', '東町', 'ヒガシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市三日市町', '17', '17203', '9230924', '石川県', 'イシカワケン', '小松市', 'コマツシ', '三日市町', 'ミッカイチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市八日市町', '17', '17203', '9230925', '石川県', 'イシカワケン', '小松市', 'コマツシ', '八日市町', 'ヨウカイチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市龍助町', '17', '17203', '9230926', '石川県', 'イシカワケン', '小松市', 'コマツシ', '龍助町', 'リュウスケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市西町', '17', '17203', '9230927', '石川県', 'イシカワケン', '小松市', 'コマツシ', '西町', 'ニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市大文字町', '17', '17203', '9230931', '石川県', 'イシカワケン', '小松市', 'コマツシ', '大文字町', 'ダイモンジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市寺町', '17', '17203', '9230932', '石川県', 'イシカワケン', '小松市', 'コマツシ', '寺町', 'テラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市本鍛冶町', '17', '17203', '9230933', '石川県', 'イシカワケン', '小松市', 'コマツシ', '本鍛冶町', 'ホンカジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市栄町', '17', '17203', '9230934', '石川県', 'イシカワケン', '小松市', 'コマツシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市上寺町', '17', '17203', '9230935', '石川県', 'イシカワケン', '小松市', 'コマツシ', '上寺町', 'カミデラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市本大工町', '17', '17203', '9230936', '石川県', 'イシカワケン', '小松市', 'コマツシ', '本大工町', 'ホンダイクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市本町', '17', '17203', '9230937', '石川県', 'イシカワケン', '小松市', 'コマツシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市芦田町', '17', '17203', '9230938', '石川県', 'イシカワケン', '小松市', 'コマツシ', '芦田町', 'アシダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市城南町', '17', '17203', '9230941', '石川県', 'イシカワケン', '小松市', 'コマツシ', '城南町', 'ジョウナンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市桜木町', '17', '17203', '9230942', '石川県', 'イシカワケン', '小松市', 'コマツシ', '桜木町', 'サクラギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市育成町', '17', '17203', '9230943', '石川県', 'イシカワケン', '小松市', 'コマツシ', '育成町', 'イクセイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市古河町', '17', '17203', '9230944', '石川県', 'イシカワケン', '小松市', 'コマツシ', '古河町', 'フルカワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市末広町', '17', '17203', '9230945', '石川県', 'イシカワケン', '小松市', 'コマツシ', '末広町', 'スエヒロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市相生町', '17', '17203', '9230946', '石川県', 'イシカワケン', '小松市', 'コマツシ', '相生町', 'アイオイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市日吉町', '17', '17203', '9230947', '石川県', 'イシカワケン', '小松市', 'コマツシ', '日吉町', 'ヒヨシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市錦町', '17', '17203', '9230948', '石川県', 'イシカワケン', '小松市', 'コマツシ', '錦町', 'ニシキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市白山町', '17', '17203', '9230951', '石川県', 'イシカワケン', '小松市', 'コマツシ', '白山町', 'ハクサンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市大和町', '17', '17203', '9230952', '石川県', 'イシカワケン', '小松市', 'コマツシ', '大和町', 'ヤマトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市旭町', '17', '17203', '9230953', '石川県', 'イシカワケン', '小松市', 'コマツシ', '旭町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市八幡町', '17', '17203', '9230954', '石川県', 'イシカワケン', '小松市', 'コマツシ', '八幡町', 'ヤワタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市上本折町', '17', '17203', '9230955', '石川県', 'イシカワケン', '小松市', 'コマツシ', '上本折町', 'カミモトオリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市西本折町', '17', '17203', '9230956', '石川県', 'イシカワケン', '小松市', 'コマツシ', '西本折町', 'ニシモトオリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市本折町', '17', '17203', '9230957', '石川県', 'イシカワケン', '小松市', 'コマツシ', '本折町', 'モトオリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市清水町', '17', '17203', '9230958', '石川県', 'イシカワケン', '小松市', 'コマツシ', '清水町', 'シミズマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市向本折町', '17', '17203', '9230961', '石川県', 'イシカワケン', '小松市', 'コマツシ', '向本折町', 'ムカイモトオリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市大領中町', '17', '17203', '9230962', '石川県', 'イシカワケン', '小松市', 'コマツシ', '大領中町', 'ダイリョウナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市須天町', '17', '17203', '9230963', '石川県', 'イシカワケン', '小松市', 'コマツシ', '須天町', 'スアママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市今江町', '17', '17203', '9230964', '石川県', 'イシカワケン', '小松市', 'コマツシ', '今江町', 'イマエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市串町', '17', '17203', '9230965', '石川県', 'イシカワケン', '小松市', 'コマツシ', '串町', 'クシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市野立町', '17', '17203', '9230965', '石川県', 'イシカワケン', '小松市', 'コマツシ', '野立町', 'ノダチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市串茶屋町', '17', '17203', '9230966', '石川県', 'イシカワケン', '小松市', 'コマツシ', '串茶屋町', 'クシチャヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市青路町', '17', '17203', '9230967', '石川県', 'イシカワケン', '小松市', 'コマツシ', '青路町', 'アオジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市村松町', '17', '17203', '9230968', '石川県', 'イシカワケン', '小松市', 'コマツシ', '村松町', 'ムラマツマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市四丁町', '17', '17203', '9230971', '石川県', 'イシカワケン', '小松市', 'コマツシ', '四丁町', 'シチョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市月津町', '17', '17203', '9230972', '石川県', 'イシカワケン', '小松市', 'コマツシ', '月津町', 'ツキヅマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市扇原町', '17', '17203', '9230973', '石川県', 'イシカワケン', '小松市', 'コマツシ', '扇原町', 'オウバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市月美丘', '17', '17203', '9230974', '石川県', 'イシカワケン', '小松市', 'コマツシ', '月美丘', 'ツキミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市矢田町', '17', '17203', '9230975', '石川県', 'イシカワケン', '小松市', 'コマツシ', '矢田町', 'ヤタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市矢田新町', '17', '17203', '9230976', '石川県', 'イシカワケン', '小松市', 'コマツシ', '矢田新町', 'ヤタシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市額見町', '17', '17203', '9230977', '石川県', 'イシカワケン', '小松市', 'コマツシ', '額見町', 'ヌカミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市拓栄町', '17', '17203', '9230981', '石川県', 'イシカワケン', '小松市', 'コマツシ', '拓栄町', 'タクエイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市松崎町', '17', '17203', '9230982', '石川県', 'イシカワケン', '小松市', 'コマツシ', '松崎町', 'マツザキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市日末町', '17', '17203', '9230983', '石川県', 'イシカワケン', '小松市', 'コマツシ', '日末町', 'ヒズエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市佐美町', '17', '17203', '9230984', '石川県', 'イシカワケン', '小松市', 'コマツシ', '佐美町', 'サミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市浜佐美町', '17', '17203', '9230985', '石川県', 'イシカワケン', '小松市', 'コマツシ', '浜佐美町', 'ハマサミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市木曽町', '17', '17203', '9230991', '石川県', 'イシカワケン', '小松市', 'コマツシ', '木曽町', 'キソマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市鶴ケ島町', '17', '17203', '9230992', '石川県', 'イシカワケン', '小松市', 'コマツシ', '鶴ケ島町', 'ツルガシママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市浮柳町', '17', '17203', '9230993', '石川県', 'イシカワケン', '小松市', 'コマツシ', '浮柳町', 'ウキヤナギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市工業団地', '17', '17203', '9230994', '石川県', 'イシカワケン', '小松市', 'コマツシ', '工業団地', 'コウギョウダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市安宅新町', '17', '17203', '9230995', '石川県', 'イシカワケン', '小松市', 'コマツシ', '安宅新町', 'アタカシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市草野町', '17', '17203', '9230996', '石川県', 'イシカワケン', '小松市', 'コマツシ', '草野町', 'クサノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市浜佐美本町', '17', '17203', '9230997', '石川県', 'イシカワケン', '小松市', 'コマツシ', '浜佐美本町', 'ハマサミホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県小松市義仲町', '17', '17203', '9230998', '石川県', 'イシカワケン', '小松市', 'コマツシ', '義仲町', 'ヨシナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県能美市', '17', '17211', '9231100', '石川県', 'イシカワケン', '能美市', 'ノミシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('124144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県能美市粟生町', '17', '17211', '9231101', '石川県', 'イシカワケン', '能美市', 'ノミシ', '粟生町', 'アオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県能美市新保町', '17', '17211', '9231102', '石川県', 'イシカワケン', '能美市', 'ノミシ', '新保町', 'シンボマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県能美市秋常町', '17', '17211', '9231103', '石川県', 'イシカワケン', '能美市', 'ノミシ', '秋常町', 'アキツネマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県能美市湯谷町', '17', '17211', '9231104', '石川県', 'イシカワケン', '能美市', 'ノミシ', '湯谷町', 'ユノタニマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県能美市石子町', '17', '17211', '9231105', '石川県', 'イシカワケン', '能美市', 'ノミシ', '石子町', 'イシコマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県能美市和田町', '17', '17211', '9231106', '石川県', 'イシカワケン', '能美市', 'ノミシ', '和田町', 'ワダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県能美市末寺町', '17', '17211', '9231107', '石川県', 'イシカワケン', '能美市', 'ノミシ', '末寺町', 'マツジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県能美市泉台町', '17', '17211', '9231111', '石川県', 'イシカワケン', '能美市', 'ノミシ', '泉台町', 'イズミダイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県能美市佐野町', '17', '17211', '9231112', '石川県', 'イシカワケン', '能美市', 'ノミシ', '佐野町', 'サノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県能美市牛島町', '17', '17211', '9231113', '石川県', 'イシカワケン', '能美市', 'ノミシ', '牛島町', 'ウシジママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県能美市小杉町', '17', '17211', '9231114', '石川県', 'イシカワケン', '能美市', 'ノミシ', '小杉町', 'コスギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県能美市大長野町', '17', '17211', '9231115', '石川県', 'イシカワケン', '能美市', 'ノミシ', '大長野町', 'オオナガノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県能美市小長野町', '17', '17211', '9231116', '石川県', 'イシカワケン', '能美市', 'ノミシ', '小長野町', 'コナガノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県能美市末信町', '17', '17211', '9231117', '石川県', 'イシカワケン', '能美市', 'ノミシ', '末信町', 'スエノブマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県能美市寺井町', '17', '17211', '9231121', '石川県', 'イシカワケン', '能美市', 'ノミシ', '寺井町', 'テライマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県能美市東任田町', '17', '17211', '9231122', '石川県', 'イシカワケン', '能美市', 'ノミシ', '東任田町', 'ヒガシトウダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県能美市吉光町', '17', '17211', '9231123', '石川県', 'イシカワケン', '能美市', 'ノミシ', '吉光町', 'ヨシミツマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県能美市三道山町', '17', '17211', '9231124', '石川県', 'イシカワケン', '能美市', 'ノミシ', '三道山町', 'サンドウヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県能美郡川北町', '17', '17324', '9231200', '石川県', 'イシカワケン', '能美郡川北町', 'ノミグンカワキタマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('124164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県能美市岩内町', '17', '17211', '9231201', '石川県', 'イシカワケン', '能美市', 'ノミシ', '岩内町', 'イワウチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県能美市莇生町', '17', '17211', '9231202', '石川県', 'イシカワケン', '能美市', 'ノミシ', '莇生町', 'アゾウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県能美市三ツ口町', '17', '17211', '9231203', '石川県', 'イシカワケン', '能美市', 'ノミシ', '三ツ口町', 'ミツクチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県能美市長滝町', '17', '17211', '9231204', '石川県', 'イシカワケン', '能美市', 'ノミシ', '長滝町', 'ナガタキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県能美市宮竹町', '17', '17211', '9231205', '石川県', 'イシカワケン', '能美市', 'ノミシ', '宮竹町', 'ミヤタケマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県能美市灯台笹町', '17', '17211', '9231206', '石川県', 'イシカワケン', '能美市', 'ノミシ', '灯台笹町', 'トダシノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県能美市岩本町', '17', '17211', '9231207', '石川県', 'イシカワケン', '能美市', 'ノミシ', '岩本町', 'イワモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県能美市和佐谷町', '17', '17211', '9231208', '石川県', 'イシカワケン', '能美市', 'ノミシ', '和佐谷町', 'ワサダニマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県能美市旭台', '17', '17211', '9231211', '石川県', 'イシカワケン', '能美市', 'ノミシ', '旭台', 'アサヒダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県能美市大口町', '17', '17211', '9231212', '石川県', 'イシカワケン', '能美市', 'ノミシ', '大口町', 'オオクチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県能美市坪野町', '17', '17211', '9231213', '石川県', 'イシカワケン', '能美市', 'ノミシ', '坪野町', 'ツボノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県能美市金剛寺町', '17', '17211', '9231214', '石川県', 'イシカワケン', '能美市', 'ノミシ', '金剛寺町', 'コンゴウジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県能美市舘町', '17', '17211', '9231215', '石川県', 'イシカワケン', '能美市', 'ノミシ', '舘町', 'タチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県能美市鍋谷町', '17', '17211', '9231216', '石川県', 'イシカワケン', '能美市', 'ノミシ', '鍋谷町', 'ナベタニマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県能美市仏大寺町', '17', '17211', '9231217', '石川県', 'イシカワケン', '能美市', 'ノミシ', '仏大寺町', 'ブツタイジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県能美市湯屋町', '17', '17211', '9231221', '石川県', 'イシカワケン', '能美市', 'ノミシ', '湯屋町', 'ユノヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県能美市徳山町', '17', '17211', '9231222', '石川県', 'イシカワケン', '能美市', 'ノミシ', '徳山町', 'トクサンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県能美市寺畠町', '17', '17211', '9231223', '石川県', 'イシカワケン', '能美市', 'ノミシ', '寺畠町', 'テラバタケマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県能美市和気町', '17', '17211', '9231224', '石川県', 'イシカワケン', '能美市', 'ノミシ', '和気町', 'ワケマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県能美市松が岡', '17', '17211', '9231225', '石川県', 'イシカワケン', '能美市', 'ノミシ', '松が岡', 'マツガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県能美市緑が丘', '17', '17211', '9231226', '石川県', 'イシカワケン', '能美市', 'ノミシ', '緑が丘', 'ミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県能美市和光台', '17', '17211', '9231227', '石川県', 'イシカワケン', '能美市', 'ノミシ', '和光台', 'ワコウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県能美市上開発町', '17', '17211', '9231231', '石川県', 'イシカワケン', '能美市', 'ノミシ', '上開発町', 'カミカイハツマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県能美市下開発町', '17', '17211', '9231232', '石川県', 'イシカワケン', '能美市', 'ノミシ', '下開発町', 'シモカイハツマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県能美市荒屋町', '17', '17211', '9231233', '石川県', 'イシカワケン', '能美市', 'ノミシ', '荒屋町', 'アラヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県能美市高座町', '17', '17211', '9231234', '石川県', 'イシカワケン', '能美市', 'ノミシ', '高座町', 'コウザマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県能美市徳久町', '17', '17211', '9231235', '石川県', 'イシカワケン', '能美市', 'ノミシ', '徳久町', 'トクヒサマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県能美市北市町', '17', '17211', '9231236', '石川県', 'イシカワケン', '能美市', 'ノミシ', '北市町', 'キタイチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県能美市上清水町', '17', '17211', '9231237', '石川県', 'イシカワケン', '能美市', 'ノミシ', '上清水町', 'カミシミズマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県能美市下清水町', '17', '17211', '9231238', '石川県', 'イシカワケン', '能美市', 'ノミシ', '下清水町', 'シモシミズマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県能美市山田町', '17', '17211', '9231241', '石川県', 'イシカワケン', '能美市', 'ノミシ', '山田町', 'ヤマダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県能美市火釜町', '17', '17211', '9231242', '石川県', 'イシカワケン', '能美市', 'ノミシ', '火釜町', 'ヒガママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県能美市三ツ屋町', '17', '17211', '9231243', '石川県', 'イシカワケン', '能美市', 'ノミシ', '三ツ屋町', 'ミツヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県能美市来丸町', '17', '17211', '9231244', '石川県', 'イシカワケン', '能美市', 'ノミシ', '来丸町', 'ライマルマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県能美市辰口町', '17', '17211', '9231245', '石川県', 'イシカワケン', '能美市', 'ノミシ', '辰口町', 'タツノクチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県能美市倉重町', '17', '17211', '9231246', '石川県', 'イシカワケン', '能美市', 'ノミシ', '倉重町', 'クラシゲマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県能美市出口町', '17', '17211', '9231247', '石川県', 'イシカワケン', '能美市', 'ノミシ', '出口町', 'デグチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県能美郡川北町藤蔵', '17', '17324', '9231251', '石川県', 'イシカワケン', '能美郡川北町', 'ノミグンカワキタマチ', '藤蔵', 'トウゾウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県能美郡川北町中島', '17', '17324', '9231252', '石川県', 'イシカワケン', '能美郡川北町', 'ノミグンカワキタマチ', '中島', 'ナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県能美郡川北町三反田', '17', '17324', '9231253', '石川県', 'イシカワケン', '能美郡川北町', 'ノミグンカワキタマチ', '三反田', 'サンタンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県能美郡川北町サンコーポラス', '17', '17324', '9231254', '石川県', 'イシカワケン', '能美郡川北町', 'ノミグンカワキタマチ', 'サンコーポラス', 'サンコーポラス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県能美郡川北町土室', '17', '17324', '9231261', '石川県', 'イシカワケン', '能美郡川北町', 'ノミグンカワキタマチ', '土室', 'ツチムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県能美郡川北町草深', '17', '17324', '9231262', '石川県', 'イシカワケン', '能美郡川北町', 'ノミグンカワキタマチ', '草深', 'クサブカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県能美郡川北町下土室', '17', '17324', '9231263', '石川県', 'イシカワケン', '能美郡川北町', 'ノミグンカワキタマチ', '下土室', 'シモツチムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県能美郡川北町山田先出', '17', '17324', '9231264', '石川県', 'イシカワケン', '能美郡川北町', 'ノミグンカワキタマチ', '山田先出', 'ヤマダセンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県能美郡川北町上先出', '17', '17324', '9231265', '石川県', 'イシカワケン', '能美郡川北町', 'ノミグンカワキタマチ', '上先出', 'カミセンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県能美郡川北町下先出', '17', '17324', '9231266', '石川県', 'イシカワケン', '能美郡川北町', 'ノミグンカワキタマチ', '下先出', 'シモセンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県能美郡川北町壱ツ屋', '17', '17324', '9231267', '石川県', 'イシカワケン', '能美郡川北町', 'ノミグンカワキタマチ', '壱ツ屋', 'ヒトツヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県能美郡川北町与九郎島', '17', '17324', '9231268', '石川県', 'イシカワケン', '能美郡川北町', 'ノミグンカワキタマチ', '与九郎島', 'ヨクロウジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県能美郡川北町上田子島', '17', '17324', '9231269', '石川県', 'イシカワケン', '能美郡川北町', 'ノミグンカワキタマチ', '上田子島', 'カミダゴジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県能美郡川北町田子島', '17', '17324', '9231271', '石川県', 'イシカワケン', '能美郡川北町', 'ノミグンカワキタマチ', '田子島', 'ダゴジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県能美郡川北町下田子島', '17', '17324', '9231272', '石川県', 'イシカワケン', '能美郡川北町', 'ノミグンカワキタマチ', '下田子島', 'シモタゴジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県能美郡川北町舟場島', '17', '17324', '9231273', '石川県', 'イシカワケン', '能美郡川北町', 'ノミグンカワキタマチ', '舟場島', 'フナバジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県能美郡川北町木呂場', '17', '17324', '9231274', '石川県', 'イシカワケン', '能美郡川北町', 'ノミグンカワキタマチ', '木呂場', 'コロバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県能美郡川北町木呂場新', '17', '17324', '9231275', '石川県', 'イシカワケン', '能美郡川北町', 'ノミグンカワキタマチ', '木呂場新', 'コロバシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県能美郡川北町橘', '17', '17324', '9231276', '石川県', 'イシカワケン', '能美郡川北町', 'ノミグンカワキタマチ', '橘', 'タチバナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県能美郡川北町橘新', '17', '17324', '9231277', '石川県', 'イシカワケン', '能美郡川北町', 'ノミグンカワキタマチ', '橘新', 'タチバナシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県能美郡川北町朝日', '17', '17324', '9231278', '石川県', 'イシカワケン', '能美郡川北町', 'ノミグンカワキタマチ', '朝日', 'アサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市', '17', '17210', '9240000', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('124285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市八田町', '17', '17210', '9240001', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '八田町', 'ハッタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市八田中町', '17', '17210', '9240002', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '八田中町', 'ハッタナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市中新保町', '17', '17210', '9240003', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '中新保町', 'ナカシンボマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市旭丘', '17', '17210', '9240004', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '旭丘', 'アサヒガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市一塚町', '17', '17210', '9240005', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '一塚町', 'イチヅカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市村井新町', '17', '17210', '9240006', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '村井新町', 'ムライシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市倉部町', '17', '17210', '9240007', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '倉部町', 'クラベマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市横江町', '17', '17210', '9240011', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '横江町', 'ヨコエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市福増町', '17', '17210', '9240012', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '福増町', 'フクマスマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市番匠町', '17', '17210', '9240013', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '番匠町', 'バンジョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市五歩市町', '17', '17210', '9240014', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '五歩市町', 'ゴボイチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市新田町', '17', '17210', '9240015', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '新田町', 'シンデンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市宮永市町', '17', '17210', '9240016', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '宮永市町', 'ミヤナガイチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市宮永町', '17', '17210', '9240017', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '宮永町', 'ミヤナガマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市宮永新町', '17', '17210', '9240018', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '宮永新町', 'ミヤナガシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市あさひ荘苑', '17', '17210', '9240019', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', 'あさひ荘苑', 'アサヒソウエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市新成', '17', '17210', '9240020', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '新成', 'シンナリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市竹松町', '17', '17210', '9240021', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '竹松町', 'タケマツマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市相木町', '17', '17210', '9240022', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '相木町', 'アイノキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市成町', '17', '17210', '9240023', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '成町', 'ナリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市北安田町', '17', '17210', '9240024', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '北安田町', 'キタヤスタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市蕪城', '17', '17210', '9240025', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '蕪城', 'ブジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市平木町', '17', '17210', '9240026', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '平木町', 'ヒラギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市相川町', '17', '17210', '9240027', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '相川町', 'ソウゴマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市相川新町', '17', '17210', '9240028', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '相川新町', 'ソウゴシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市村井東', '17', '17210', '9240031', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '村井東', 'ムライヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市村井町', '17', '17210', '9240032', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '村井町', 'ムライマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市宮丸町', '17', '17210', '9240033', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '宮丸町', 'ミヤマルマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市小上町', '17', '17210', '9240034', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '小上町', 'コガミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市上柏野町', '17', '17210', '9240035', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '上柏野町', 'カミカシワノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市中柏野町', '17', '17210', '9240036', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '中柏野町', 'ナカカシワノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市荒屋柏野町', '17', '17210', '9240037', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '荒屋柏野町', 'アラヤカシワノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市下柏野町', '17', '17210', '9240038', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '下柏野町', 'シモカシワノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市東美沢野町', '17', '17210', '9240041', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '東美沢野町', 'ヒガシミサワノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市東柏町', '17', '17210', '9240042', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '東柏町', 'ヒガシカシワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市柏町', '17', '17210', '9240043', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '柏町', 'カシワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市西柏町', '17', '17210', '9240044', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '西柏町', 'ニシカシワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市西柏', '17', '17210', '9240045', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '西柏', 'ニシカシワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市西美沢野', '17', '17210', '9240046', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '西美沢野', 'ニシミサワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市西美沢野町', '17', '17210', '9240047', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '西美沢野町', 'ニシミサワノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市美沢野町', '17', '17210', '9240048', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '美沢野町', 'ミサワノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市福留町', '17', '17210', '9240051', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '福留町', 'フクドメマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市源兵島町', '17', '17210', '9240052', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '源兵島町', 'ゲンペイジママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市水澄町', '17', '17210', '9240053', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '水澄町', 'ミスミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市米光町', '17', '17210', '9240054', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '米光町', 'ヨネミツマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市北島町', '17', '17210', '9240055', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '北島町', 'キタジママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市阿弥陀島町', '17', '17210', '9240056', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '阿弥陀島町', 'アミダジママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市松本町', '17', '17210', '9240057', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '松本町', 'マツモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市石立町', '17', '17210', '9240058', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '石立町', 'イシタテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市福留南', '17', '17210', '9240059', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '福留南', 'フクドメミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市宮保町', '17', '17210', '9240061', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '宮保町', 'ミヤボマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市笠間新', '17', '17210', '9240062', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '笠間新', 'カサマシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市笠間町', '17', '17210', '9240063', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '笠間町', 'カサママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市黒瀬町', '17', '17210', '9240064', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '黒瀬町', 'クロセマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市七郎町', '17', '17210', '9240065', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '七郎町', 'シチロウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市上小川町', '17', '17210', '9240066', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '上小川町', 'カミオガワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市小川町', '17', '17210', '9240067', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '小川町', 'オガワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市宮保新町', '17', '17210', '9240068', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '宮保新町', 'ミヤボシンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市宮原町', '17', '17210', '9240069', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '宮原町', 'ミヤハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市徳光町', '17', '17210', '9240071', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '徳光町', 'トクミツマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市千代野西', '17', '17210', '9240072', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '千代野西', 'チヨノニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市千代野東', '17', '17210', '9240073', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '千代野東', 'チヨノヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市千代野南', '17', '17210', '9240074', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '千代野南', 'チヨノミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市米永町', '17', '17210', '9240075', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '米永町', 'ヨネナガマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市法仏町', '17', '17210', '9240076', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '法仏町', 'ホウブツマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市田中町', '17', '17210', '9240801', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '田中町', 'タナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市専福寺町', '17', '17210', '9240802', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '専福寺町', 'センプクジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市乾町', '17', '17210', '9240803', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '乾町', 'イヌイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市徳丸町', '17', '17210', '9240804', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '徳丸町', 'トクマルマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市若宮', '17', '17210', '9240805', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '若宮', 'ワカミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市石同新町', '17', '17210', '9240806', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '石同新町', 'イシドウシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市石同町', '17', '17210', '9240807', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '石同町', 'イシドウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市布市', '17', '17210', '9240808', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '布市', 'ヌノイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市長竹町', '17', '17210', '9240811', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '長竹町', 'ナガタケマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市橋爪町', '17', '17210', '9240812', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '橋爪町', 'ハシヅメマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市福正寺町', '17', '17210', '9240813', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '福正寺町', 'フクショウジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市橋爪新町', '17', '17210', '9240814', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '橋爪新町', 'ハシヅメシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市三浦町', '17', '17210', '9240815', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '三浦町', 'ミウラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市三幸町', '17', '17210', '9240816', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '三幸町', 'ミユキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市幸明町', '17', '17210', '9240817', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '幸明町', 'コウミョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市中奥町', '17', '17210', '9240818', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '中奥町', 'ナカオクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市青葉台', '17', '17210', '9240819', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '青葉台', 'アオバダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市美里町', '17', '17210', '9240820', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '美里町', 'ミサトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市木津町', '17', '17210', '9240821', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '木津町', 'コウヅマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市みずほ', '17', '17210', '9240822', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', 'みずほ', 'ミズホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市坊丸町', '17', '17210', '9240823', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '坊丸町', 'ボウマルマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市田地町', '17', '17210', '9240824', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '田地町', 'タチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市菅波町', '17', '17210', '9240825', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '菅波町', 'スガナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市乙丸町', '17', '17210', '9240826', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '乙丸町', 'オトマルマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市今平町', '17', '17210', '9240827', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '今平町', 'イマヒラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市上二口町', '17', '17210', '9240828', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '上二口町', 'カミフタクチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市藤波', '17', '17210', '9240831', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '藤波', 'フジナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市藤木町', '17', '17210', '9240832', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '藤木町', 'フジノキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市向島町', '17', '17210', '9240833', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '向島町', 'ムカイジママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市矢頃島町', '17', '17210', '9240834', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '矢頃島町', 'ヤゴロジママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市漆島町', '17', '17210', '9240835', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '漆島町', 'ウルシジママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市山島台', '17', '17210', '9240836', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '山島台', 'ヤマジマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市吉田町', '17', '17210', '9240837', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '吉田町', 'ヨシダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市八束穂', '17', '17210', '9240838', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '八束穂', 'ヤツカホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市平松町', '17', '17210', '9240841', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '平松町', 'ヒラマツマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市剣崎町', '17', '17210', '9240842', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '剣崎町', 'ケンザキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市安吉町', '17', '17210', '9240843', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '安吉町', 'ヤスヨシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市寄新保町', '17', '17210', '9240844', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '寄新保町', 'ヨリシンボマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市島田町', '17', '17210', '9240845', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '島田町', 'シマダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市上島田町', '17', '17210', '9240846', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '上島田町', 'カミシマダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市内方新保町', '17', '17210', '9240847', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '内方新保町', 'ウチカタシンボマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市長島町', '17', '17210', '9240848', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '長島町', 'ナガシママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市御影堂町', '17', '17210', '9240851', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '御影堂町', 'ゴエドウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市四ツ屋町', '17', '17210', '9240852', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '四ツ屋町', 'ヨツヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市上安田町', '17', '17210', '9240853', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '上安田町', 'カミヤスタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市出合島町', '17', '17210', '9240854', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '出合島町', 'デアイジママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市水島町', '17', '17210', '9240855', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '水島町', 'ミズシママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市番田町', '17', '17210', '9240856', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '番田町', 'バンダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市福永町', '17', '17210', '9240857', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '福永町', 'フクナガマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市福新町', '17', '17210', '9240858', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '福新町', 'フクシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市横町', '17', '17210', '9240861', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '横町', 'ヨコマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市安田町', '17', '17210', '9240862', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '安田町', 'ヤスタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市博労', '17', '17210', '9240863', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '博労', 'バクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市馬場', '17', '17210', '9240864', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '馬場', 'ババ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市倉光', '17', '17210', '9240865', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '倉光', 'クラミツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市倉光西', '17', '17210', '9240866', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '倉光西', 'クラミツニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市茶屋', '17', '17210', '9240867', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '茶屋', 'チャヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市西新町', '17', '17210', '9240871', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '西新町', 'ニシシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市古城町', '17', '17210', '9240872', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '古城町', 'フルシロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市八日市町', '17', '17210', '9240873', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '八日市町', 'ヨウカイチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市四日市町', '17', '17210', '9240874', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '四日市町', 'ヨッカイチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市辰巳町', '17', '17210', '9240875', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '辰巳町', 'タツミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市鍛治町', '17', '17210', '9240876', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '鍛治町', 'カジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市中町', '17', '17210', '9240877', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '中町', 'ナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市末広', '17', '17210', '9240878', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '末広', 'スエヒロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市八ツ矢新町', '17', '17210', '9240881', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '八ツ矢新町', 'ヤツヤシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市八ツ矢町', '17', '17210', '9240882', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '八ツ矢町', 'ヤツヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市東一番町', '17', '17210', '9240883', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '東一番町', 'ヒガシイチバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市東新町', '17', '17210', '9240884', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '東新町', 'ヒガシシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市殿町', '17', '17210', '9240885', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '殿町', 'トノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市東二番町', '17', '17210', '9240886', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '東二番町', 'ヒガシニバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市東三番町', '17', '17210', '9240887', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '東三番町', 'ヒガシサンバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市旭町', '17', '17210', '9240888', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '旭町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋市', '17', '17207', '9250000', '石川県', 'イシカワケン', '羽咋市', 'ハクイシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('124439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋市柴垣町', '17', '17207', '9250001', '石川県', 'イシカワケン', '羽咋市', 'ハクイシ', '柴垣町', 'シバガキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋市滝谷町', '17', '17207', '9250002', '石川県', 'イシカワケン', '羽咋市', 'ハクイシ', '滝谷町', 'タキダニマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋市寺家町', '17', '17207', '9250003', '石川県', 'イシカワケン', '羽咋市', 'ハクイシ', '寺家町', 'ジケマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋市一ノ宮町', '17', '17207', '9250004', '石川県', 'イシカワケン', '羽咋市', 'ハクイシ', '一ノ宮町', 'イチノミヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋市滝町', '17', '17207', '9250005', '石川県', 'イシカワケン', '羽咋市', 'ハクイシ', '滝町', 'タキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋市上中山町', '17', '17207', '9250011', '石川県', 'イシカワケン', '羽咋市', 'ハクイシ', '上中山町', 'カミナカヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋市千路町', '17', '17207', '9250012', '石川県', 'イシカワケン', '羽咋市', 'ハクイシ', '千路町', 'チジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋市東釜屋町', '17', '17207', '9250013', '石川県', 'イシカワケン', '羽咋市', 'ハクイシ', '東釜屋町', 'ヒガシカマヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋市釜屋町', '17', '17207', '9250014', '石川県', 'イシカワケン', '羽咋市', 'ハクイシ', '釜屋町', 'カマヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋市大川町', '17', '17207', '9250015', '石川県', 'イシカワケン', '羽咋市', 'ハクイシ', '大川町', 'オオカワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋市羽咋町', '17', '17207', '9250016', '石川県', 'イシカワケン', '羽咋市', 'ハクイシ', '羽咋町', 'ハクイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋市西釜屋町', '17', '17207', '9250017', '石川県', 'イシカワケン', '羽咋市', 'ハクイシ', '西釜屋町', 'ニシカマヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋市柳田町', '17', '17207', '9250018', '石川県', 'イシカワケン', '羽咋市', 'ハクイシ', '柳田町', 'ヤナイダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋市吉崎町', '17', '17207', '9250021', '石川県', 'イシカワケン', '羽咋市', 'ハクイシ', '吉崎町', 'ヨシサキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋市深江町', '17', '17207', '9250022', '石川県', 'イシカワケン', '羽咋市', 'ハクイシ', '深江町', 'フカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋市若草町', '17', '17207', '9250023', '石川県', 'イシカワケン', '羽咋市', 'ハクイシ', '若草町', 'ワカクサマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋市三ツ屋町', '17', '17207', '9250024', '石川県', 'イシカワケン', '羽咋市', 'ハクイシ', '三ツ屋町', 'ミツヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋市太田町', '17', '17207', '9250025', '石川県', 'イシカワケン', '羽咋市', 'ハクイシ', '太田町', 'オオタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋市石野町', '17', '17207', '9250026', '石川県', 'イシカワケン', '羽咋市', 'ハクイシ', '石野町', 'イシノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋市鶴多町', '17', '17207', '9250027', '石川県', 'イシカワケン', '羽咋市', 'ハクイシ', '鶴多町', 'ツルタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋市次場町', '17', '17207', '9250028', '石川県', 'イシカワケン', '羽咋市', 'ハクイシ', '次場町', 'スバマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋市東的場町', '17', '17207', '9250031', '石川県', 'イシカワケン', '羽咋市', 'ハクイシ', '東的場町', 'ヒガシマトバマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋市東川原町', '17', '17207', '9250032', '石川県', 'イシカワケン', '羽咋市', 'ハクイシ', '東川原町', 'ヒガシカワラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋市川原町', '17', '17207', '9250033', '石川県', 'イシカワケン', '羽咋市', 'ハクイシ', '川原町', 'カワラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋市旭町', '17', '17207', '9250034', '石川県', 'イシカワケン', '羽咋市', 'ハクイシ', '旭町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋市本町', '17', '17207', '9250035', '石川県', 'イシカワケン', '羽咋市', 'ハクイシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋市的場町', '17', '17207', '9250036', '石川県', 'イシカワケン', '羽咋市', 'ハクイシ', '的場町', 'マトバマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋市立開町', '17', '17207', '9250041', '石川県', 'イシカワケン', '羽咋市', 'ハクイシ', '立開町', 'リュウガイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋市土橋町', '17', '17207', '9250042', '石川県', 'イシカワケン', '羽咋市', 'ハクイシ', '土橋町', 'ツチハシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋市粟原町', '17', '17207', '9250043', '石川県', 'イシカワケン', '羽咋市', 'ハクイシ', '粟原町', 'アワラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋市新保町', '17', '17207', '9250044', '石川県', 'イシカワケン', '羽咋市', 'ハクイシ', '新保町', 'シンボマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋市粟生町', '17', '17207', '9250045', '石川県', 'イシカワケン', '羽咋市', 'ハクイシ', '粟生町', 'アオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋市兵庫町', '17', '17207', '9250046', '石川県', 'イシカワケン', '羽咋市', 'ハクイシ', '兵庫町', 'ヒョウゴマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋市御坊山町', '17', '17207', '9250047', '石川県', 'イシカワケン', '羽咋市', 'ハクイシ', '御坊山町', 'ゴボウヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋市松ケ下町', '17', '17207', '9250048', '石川県', 'イシカワケン', '羽咋市', 'ハクイシ', '松ケ下町', 'マツガシタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋市柳橋町', '17', '17207', '9250049', '石川県', 'イシカワケン', '羽咋市', 'ハクイシ', '柳橋町', 'ヤナギバシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋市島出町', '17', '17207', '9250051', '石川県', 'イシカワケン', '羽咋市', 'ハクイシ', '島出町', 'シマデマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋市中央町', '17', '17207', '9250052', '石川県', 'イシカワケン', '羽咋市', 'ハクイシ', '中央町', 'チュウオウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋市南中央町', '17', '17207', '9250053', '石川県', 'イシカワケン', '羽咋市', 'ハクイシ', '南中央町', 'ミナミチュウオウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋市千里浜町', '17', '17207', '9250054', '石川県', 'イシカワケン', '羽咋市', 'ハクイシ', '千里浜町', 'チリハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町', '17', '17384', '9250100', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('124480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町安津見', '17', '17384', '9250121', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '安津見', 'アヅミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町倉垣', '17', '17384', '9250122', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '倉垣', 'クラカキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町矢駄', '17', '17384', '9250123', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '矢駄', 'ヤダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町西山', '17', '17384', '9250124', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '西山', 'ニシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町米浜', '17', '17384', '9250131', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '米浜', 'ヨネハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町穴口', '17', '17384', '9250132', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '穴口', 'アナグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町大坂', '17', '17384', '9250133', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '大坂', 'オオサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町上棚', '17', '17384', '9250134', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '上棚', 'ウワダナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町二所宮', '17', '17384', '9250135', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '二所宮', 'ニショノミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町舘', '17', '17384', '9250136', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '舘', 'タチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町福井', '17', '17384', '9250137', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '福井', 'フクイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町高浜町', '17', '17384', '9250141', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '高浜町', 'タカハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町福野', '17', '17384', '9250142', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '福野', 'フクノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町宿女', '17', '17384', '9250143', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '宿女', 'ヤドメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町坪野', '17', '17384', '9250144', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '坪野', 'ツボノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町岩田', '17', '17384', '9250145', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '岩田', 'イワタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町甘田', '17', '17384', '9250146', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '甘田', 'アマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町大島', '17', '17384', '9250147', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '大島', 'オシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町長沢', '17', '17384', '9250148', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '長沢', 'ナガサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町梨谷小山', '17', '17384', '9250151', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '梨谷小山', 'ナシタニコヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町北吉田', '17', '17384', '9250152', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '北吉田', 'キタヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町清水今江', '17', '17384', '9250153', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '清水今江', 'シミズイマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町末吉', '17', '17384', '9250154', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '末吉', 'スエヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町神代', '17', '17384', '9250155', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '神代', 'カクミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町矢蔵谷', '17', '17384', '9250156', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '矢蔵谷', 'ヤグラダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町堀松', '17', '17384', '9250157', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '堀松', 'ホリマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町赤住', '17', '17384', '9250161', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '赤住', 'アカスミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町百浦', '17', '17384', '9250162', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '百浦', 'モモウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町小浦', '17', '17384', '9250163', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '小浦', 'オウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町大津', '17', '17384', '9250164', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '大津', 'オオヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町上野', '17', '17384', '9250165', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '上野', 'ウワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町安部屋', '17', '17384', '9250166', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '安部屋', 'アブヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町町', '17', '17384', '9250167', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '町', 'マチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町川尻', '17', '17384', '9250168', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '川尻', 'カワシリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町印内', '17', '17384', '9250201', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '印内', 'インナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町代田', '17', '17384', '9250202', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '代田', 'シナンタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町新林', '17', '17384', '9250203', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '新林', 'シンバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町牧山', '17', '17384', '9250204', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '牧山', 'マキヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町仏木', '17', '17384', '9250205', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '仏木', 'ホトギリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町谷屋', '17', '17384', '9250206', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '谷屋', 'タニヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町栗山', '17', '17384', '9250207', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '栗山', 'クリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町矢田', '17', '17384', '9250211', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '矢田', 'ヤタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町徳田', '17', '17384', '9250212', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '徳田', 'トクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町舘開', '17', '17384', '9250213', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '舘開', 'タチヒラキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町火打谷', '17', '17384', '9250214', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '火打谷', 'ヒウチダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町出雲', '17', '17384', '9250215', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '出雲', 'イズモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町日用', '17', '17384', '9250301', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '日用', 'ヒヨウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町町居', '17', '17384', '9250302', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '町居', 'マチイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町日下田', '17', '17384', '9250303', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '日下田', 'ヒゲタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町中山', '17', '17384', '9250304', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '中山', 'ナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町豊後名', '17', '17384', '9250305', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '豊後名', 'ブンゴメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町草木', '17', '17384', '9250306', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '草木', 'クサギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町荒屋', '17', '17384', '9250307', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '荒屋', 'アラヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町谷神', '17', '17384', '9250311', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '谷神', 'ヤチカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町六実', '17', '17384', '9250312', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '六実', 'ムツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町三明', '17', '17384', '9250313', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '三明', 'サンミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町中畠', '17', '17384', '9250314', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '中畠', 'ナカバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町福浦港', '17', '17384', '9250315', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '福浦港', 'フクラコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町富来牛下巌門', '17', '17384', '9250345', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '富来牛下', 'トギウシオロシ', null, null, '巌門', 'ガンモン');
INSERT INTO `ms_addresses` VALUES ('124541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町釈迦堂', '17', '17384', '9250371', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '釈迦堂', 'シャカドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町直海', '17', '17384', '9250372', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '直海', 'ノウミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町小室', '17', '17384', '9250373', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '小室', 'コモロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町松木', '17', '17384', '9250374', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '松木', 'マツノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町若葉台', '17', '17384', '9250375', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '若葉台', 'ワカバダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町長田', '17', '17384', '9250376', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '長田', 'ナガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町田原', '17', '17384', '9250381', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '田原', 'タワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町米町', '17', '17384', '9250382', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '米町', 'コンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町大笹', '17', '17384', '9250383', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '大笹', 'オオザサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町五里峠', '17', '17384', '9250384', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '五里峠', 'ゴリトウゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町牛ケ首', '17', '17384', '9250385', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '牛ケ首', 'ウシガクビ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町切留', '17', '17384', '9250421', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '切留', 'キリドメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町地保', '17', '17384', '9250422', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '地保', 'ジホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町鵜野屋', '17', '17384', '9250423', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '鵜野屋', 'ウノヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町入釜', '17', '17384', '9250424', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '入釜', 'イリガマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町灯', '17', '17384', '9250425', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '灯', 'トボシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町阿川', '17', '17384', '9250426', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '阿川', 'アコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町楚和', '17', '17384', '9250427', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '楚和', 'ソワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町尊保', '17', '17384', '9250431', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '尊保', 'ソンボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町今田', '17', '17384', '9250432', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '今田', 'イマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町和田', '17', '17384', '9250433', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '和田', 'ワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町大西', '17', '17384', '9250434', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '大西', 'オオニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町江添', '17', '17384', '9250435', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '江添', 'エゾエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町貝田', '17', '17384', '9250436', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '貝田', 'カイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町田中', '17', '17384', '9250437', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '田中', 'タナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町八千代', '17', '17384', '9250438', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '八千代', 'ヤチヨ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町広地', '17', '17384', '9250441', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '広地', 'ヒロジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町東小室', '17', '17384', '9250442', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '東小室', 'ヒガシオモロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町富来七海', '17', '17384', '9250443', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '富来七海', 'トギシツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町富来生神', '17', '17384', '9250444', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '富来生神', 'トギウルカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町富来牛下', '17', '17384', '9250445', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '富来牛下', 'トギウシオロシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町富来地頭町', '17', '17384', '9250446', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '富来地頭町', 'トギジトウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町富来領家町', '17', '17384', '9250447', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '富来領家町', 'トギリョウケマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町富来高田', '17', '17384', '9250448', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '富来高田', 'トギタカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町八幡', '17', '17384', '9250451', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '八幡', 'ヤワタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町中泉', '17', '17384', '9250452', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '中泉', 'ナカイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町八幡座主', '17', '17384', '9250452', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '八幡座主', 'ヤワタザス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町里本江', '17', '17384', '9250453', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '里本江', 'サトホンゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町相神', '17', '17384', '9250454', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '相神', 'アイカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町中浜', '17', '17384', '9250455', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '中浜', 'ナカハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町草江', '17', '17384', '9250456', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '草江', 'ソウゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町給分', '17', '17384', '9250457', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '給分', 'キュウブン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町大福寺', '17', '17384', '9250561', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '大福寺', 'ダイフクジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町栢木', '17', '17384', '9250562', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '栢木', 'カイノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町稲敷', '17', '17384', '9250563', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '稲敷', 'イナシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町酒見', '17', '17384', '9250564', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '酒見', 'サカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町香能', '17', '17384', '9250565', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '香能', 'カノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町西海風戸', '17', '17384', '9250566', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '西海風戸', 'サイカイフト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町西海風無', '17', '17384', '9250571', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '西海風無', 'サイカイカザナシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町西海千ノ浦', '17', '17384', '9250572', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '西海千ノ浦', 'サイカイチノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町西海久喜', '17', '17384', '9250573', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '西海久喜', 'サイカイヒサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町赤崎', '17', '17384', '9250574', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '赤崎', 'アカサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町小窪', '17', '17384', '9250575', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '小窪', 'オクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町鹿頭', '17', '17384', '9250576', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '鹿頭', 'シシズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町笹波', '17', '17384', '9250577', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '笹波', 'ササナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡志賀町前浜', '17', '17384', '9250578', '石川県', 'イシカワケン', '羽咋郡志賀町', 'ハクイグンシカマチ', '前浜', 'マエハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋市菅池町', '17', '17207', '9250601', '石川県', 'イシカワケン', '羽咋市', 'ハクイシ', '菅池町', 'スガイケマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋市千石町', '17', '17207', '9250602', '石川県', 'イシカワケン', '羽咋市', 'ハクイシ', '千石町', 'センゴクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋市福水町', '17', '17207', '9250603', '石川県', 'イシカワケン', '羽咋市', 'ハクイシ', '福水町', 'フクミズマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋市白石町', '17', '17207', '9250604', '石川県', 'イシカワケン', '羽咋市', 'ハクイシ', '白石町', 'シロイシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋市宇土野町', '17', '17207', '9250605', '石川県', 'イシカワケン', '羽咋市', 'ハクイシ', '宇土野町', 'ウドノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋市白瀬町', '17', '17207', '9250606', '石川県', 'イシカワケン', '羽咋市', 'ハクイシ', '白瀬町', 'シロセマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋市上白瀬町', '17', '17207', '9250607', '石川県', 'イシカワケン', '羽咋市', 'ハクイシ', '上白瀬町', 'カミシロセマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋市神子原町', '17', '17207', '9250608', '石川県', 'イシカワケン', '羽咋市', 'ハクイシ', '神子原町', 'ミコハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋市上江町', '17', '17207', '9250611', '石川県', 'イシカワケン', '羽咋市', 'ハクイシ', '上江町', 'ウワエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋市垣内田町', '17', '17207', '9250612', '石川県', 'イシカワケン', '羽咋市', 'ハクイシ', '垣内田町', 'カクッタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋市飯山町', '17', '17207', '9250613', '石川県', 'イシカワケン', '羽咋市', 'ハクイシ', '飯山町', 'イノヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋市中川町', '17', '17207', '9250614', '石川県', 'イシカワケン', '羽咋市', 'ハクイシ', '中川町', 'ナカガワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋市千代町', '17', '17207', '9250615', '石川県', 'イシカワケン', '羽咋市', 'ハクイシ', '千代町', 'チヨマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋市四町', '17', '17207', '9250616', '石川県', 'イシカワケン', '羽咋市', 'ハクイシ', '四町', 'シチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋市円井町', '17', '17207', '9250617', '石川県', 'イシカワケン', '羽咋市', 'ハクイシ', '円井町', 'ツムライマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋市菱分町', '17', '17207', '9250621', '石川県', 'イシカワケン', '羽咋市', 'ハクイシ', '菱分町', 'ヒシワケマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋市堀替新町', '17', '17207', '9250622', '石川県', 'イシカワケン', '羽咋市', 'ハクイシ', '堀替新町', 'ホリカエシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋市本江町', '17', '17207', '9250623', '石川県', 'イシカワケン', '羽咋市', 'ハクイシ', '本江町', 'ホンゴウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋市志々見町', '17', '17207', '9250624', '石川県', 'イシカワケン', '羽咋市', 'ハクイシ', '志々見町', 'シジミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋市尾長町', '17', '17207', '9250625', '石川県', 'イシカワケン', '羽咋市', 'ハクイシ', '尾長町', 'オナガマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋市千田町', '17', '17207', '9250626', '石川県', 'イシカワケン', '羽咋市', 'ハクイシ', '千田町', 'センダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市', '17', '17202', '9260000', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('124641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市鵜浦町', '17', '17202', '9260001', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '鵜浦町', 'ウノウラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市湯川町', '17', '17202', '9260002', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '湯川町', 'ユガワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市沢野町', '17', '17202', '9260003', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '沢野町', 'サワノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市殿町', '17', '17202', '9260004', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '殿町', 'トノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市岡町', '17', '17202', '9260005', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '岡町', 'オカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市大田新町', '17', '17202', '9260006', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '大田新町', 'オオタシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市大田町', '17', '17202', '9260006', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '大田町', 'オオタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市三室町', '17', '17202', '9260007', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '三室町', 'ミムロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市佐味町', '17', '17202', '9260011', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '佐味町', 'サミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市報国町', '17', '17202', '9260012', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '報国町', 'ホウコクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市万行町', '17', '17202', '9260012', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '万行町', 'マンギョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市佐野町', '17', '17202', '9260013', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '佐野町', 'サノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市緑ケ丘町', '17', '17202', '9260014', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '緑ケ丘町', 'ミドリガオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市矢田町', '17', '17202', '9260014', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '矢田町', 'ヤタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市矢田新町', '17', '17202', '9260015', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '矢田新町', 'ヤタシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市大和町', '17', '17202', '9260016', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '大和町', 'ヤマトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市巴町', '17', '17202', '9260021', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '巴町', 'トモエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市本府中町', '17', '17202', '9260021', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '本府中町', 'モトフチュウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市天神川原町', '17', '17202', '9260022', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '天神川原町', 'テンジンカワラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市竹町', '17', '17202', '9260023', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '竹町', 'タケマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市古屋敷町', '17', '17202', '9260024', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '古屋敷町', 'フルヤシキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市古城町', '17', '17202', '9260025', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '古城町', 'フルシロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市小池川原町', '17', '17202', '9260026', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '小池川原町', 'コイケガワラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市後畠町', '17', '17202', '9260027', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '後畠町', 'ウシロバタケマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市藤野町', '17', '17202', '9260028', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '藤野町', 'フジノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市古府町', '17', '17202', '9260031', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '古府町', 'フルコマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市南ケ丘町', '17', '17202', '9260032', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '南ケ丘町', 'ミナミガオカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市千野町', '17', '17202', '9260033', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '千野町', 'チノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市多根町', '17', '17202', '9260034', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '多根町', 'タネマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市八田町', '17', '17202', '9260035', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '八田町', 'ハッタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市中挾町', '17', '17202', '9260036', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '中挾町', 'ナカバサミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市国下町', '17', '17202', '9260037', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '国下町', 'コクガマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市八幡町', '17', '17202', '9260038', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '八幡町', 'ヤワタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市府中町', '17', '17202', '9260041', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '府中町', 'フチュウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市作事町', '17', '17202', '9260042', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '作事町', 'サクジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市橘町', '17', '17202', '9260043', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '橘町', 'タチバナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市相生町', '17', '17202', '9260044', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '相生町', 'アイオイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市袖ケ江町', '17', '17202', '9260045', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '袖ケ江町', 'ソデガエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市神明町', '17', '17202', '9260046', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '神明町', 'シンメイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市大手町', '17', '17202', '9260047', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '大手町', 'オオテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市桧物町', '17', '17202', '9260048', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '桧物町', 'ヒモノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市郡町', '17', '17202', '9260051', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '郡町', 'コオリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市山王町', '17', '17202', '9260052', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '山王町', 'サンノウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市上府中町', '17', '17202', '9260053', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '上府中町', 'カミフチュウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市川原町', '17', '17202', '9260054', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '川原町', 'カワラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市今町', '17', '17202', '9260055', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '今町', 'イママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市塗師町', '17', '17202', '9260056', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '塗師町', 'ヌシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市鍛冶町', '17', '17202', '9260057', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '鍛冶町', 'カジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市湊町', '17', '17202', '9260058', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '湊町', 'ミナトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市石崎町', '17', '17202', '9260171', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '石崎町', 'イシザキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市石崎町東', '17', '17202', '9260172', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '石崎町', 'イシザキマチ', null, null, '東', 'ヒガシ');
INSERT INTO `ms_addresses` VALUES ('124692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市石崎町西', '17', '17202', '9260173', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '石崎町', 'イシザキマチ', null, null, '西', 'ニシ');
INSERT INTO `ms_addresses` VALUES ('124693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市奥原町', '17', '17202', '9260174', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '奥原町', 'オクハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市和倉町', '17', '17202', '9260175', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '和倉町', 'ワクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市和倉町ひばり', '17', '17202', '9260176', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '和倉町ひばり', 'ワクラマチヒバリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市光陽台', '17', '17202', '9260177', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '光陽台', 'コウヨウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市石崎町香島', '17', '17202', '9260178', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '石崎町', 'イシザキマチ', null, null, '香島', 'カシマ');
INSERT INTO `ms_addresses` VALUES ('124698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市泉南台', '17', '17202', '9260179', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '泉南台', 'センナンダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市能登島祖母ケ浦町', '17', '17202', '9260201', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '能登島祖母ケ浦町', 'ノトジマバガウラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市能登島八ケ崎町', '17', '17202', '9260202', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '能登島八ケ崎町', 'ノトジマハチガサキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市能登島えの目町', '17', '17202', '9260203', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '能登島えの目町', 'ノトジマエノメマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市能登島長崎町', '17', '17202', '9260204', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '能登島長崎町', 'ノトジマナガサキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市能登島野崎町', '17', '17202', '9260205', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '能登島野崎町', 'ノトジマノザキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市能登島日出ケ島町', '17', '17202', '9260206', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '能登島日出ケ島町', 'ノトジマヒデガシママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市能登島二穴町', '17', '17202', '9260207', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '能登島二穴町', 'ノトジマフタアナマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市能登島向田町', '17', '17202', '9260211', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '能登島向田町', 'ノトジマコウダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市能登島佐波町', '17', '17202', '9260212', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '能登島佐波町', 'ノトジマサナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市能登島須曽町', '17', '17202', '9260213', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '能登島須曽町', 'ノトジマスソマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市能登島別所町', '17', '17202', '9260214', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '能登島別所町', 'ノトジマベッショマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市能登島南町', '17', '17202', '9260215', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '能登島南町', 'ノトジマミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市能登島曲町', '17', '17202', '9260216', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '能登島曲町', 'ノトジママガリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市能登島無関町', '17', '17202', '9260221', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '能登島無関町', 'ノトジマムセキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市能登島閨町', '17', '17202', '9260222', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '能登島閨町', 'ノトジマネヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市能登島半浦町', '17', '17202', '9260223', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '能登島半浦町', 'ノトジマハンノウラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市能登島百万石町', '17', '17202', '9260224', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '能登島百万石町', 'ノトジマヒャクマンゴクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市能登島通町', '17', '17202', '9260225', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '能登島通町', 'ノトジマトオリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市能登島田尻町', '17', '17202', '9260226', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '能登島田尻町', 'ノトジマタジリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市能登島久木町', '17', '17202', '9260227', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '能登島久木町', 'ノトジマクキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市江泊町日室町', '17', '17202', '9260361', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '江泊町', 'エノトマリマチ', null, null, '日室町', 'ヒムロマチ');
INSERT INTO `ms_addresses` VALUES ('124723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市大野木町', '17', '17202', '9260362', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '大野木町', 'オオノギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市江泊町', '17', '17202', '9260363', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '江泊町', 'エノトマリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市庵町白鳥町', '17', '17202', '9260364', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '庵町', 'イオリマチ', null, null, '白鳥町', 'シラトリマチ');
INSERT INTO `ms_addresses` VALUES ('124726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市江泊町白鳥町', '17', '17202', '9260364', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '江泊町', 'エノトマリマチ', null, null, '白鳥町', 'シラトマリマチ');
INSERT INTO `ms_addresses` VALUES ('124727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市庵町百海町', '17', '17202', '9260365', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '庵町', 'イオリマチ', null, null, '百海町', 'ドウミマチ');
INSERT INTO `ms_addresses` VALUES ('124728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市庵町', '17', '17202', '9260366', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '庵町', 'イオリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市庵町虫崎町', '17', '17202', '9260367', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '庵町', 'イオリマチ', null, null, '虫崎町', 'ムシサキマチ');
INSERT INTO `ms_addresses` VALUES ('124730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市佐々波町', '17', '17202', '9260371', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '佐々波町', 'サザナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市麻生町', '17', '17202', '9260372', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '麻生町', 'アソウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市小栗町', '17', '17202', '9260373', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '小栗町', 'オグリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市清水平町', '17', '17202', '9260374', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '清水平町', 'シミズダイラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市柑子町', '17', '17202', '9260375', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '柑子町', 'コウジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市外林町', '17', '17202', '9260376', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '外林町', 'ソトバヤシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市黒崎町', '17', '17202', '9260381', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '黒崎町', 'クロサキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市花園町', '17', '17202', '9260382', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '花園町', 'ハナゾノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市東浜町', '17', '17202', '9260383', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '東浜町', 'トウノハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市大泊町', '17', '17202', '9260384', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '大泊町', 'オオトマリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市山崎町', '17', '17202', '9260385', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '山崎町', 'ヤマザキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市山崎町小川内町', '17', '17202', '9260386', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '山崎町', 'ヤマザキマチ', null, null, '小川内町', 'コウチマチ');
INSERT INTO `ms_addresses` VALUES ('124742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市熊淵町', '17', '17202', '9260387', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '熊淵町', 'クマブチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市熊淵町水上町', '17', '17202', '9260388', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '熊淵町', 'クマブチマチ', null, null, '水上町', 'ミズカミマチ');
INSERT INTO `ms_addresses` VALUES ('124744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市熊淵町滝の尻町', '17', '17202', '9260389', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '熊淵町', 'クマブチマチ', null, null, '滝の尻町', 'タキノシリマチ');
INSERT INTO `ms_addresses` VALUES ('124745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市昭和町', '17', '17202', '9260801', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '昭和町', 'ショウワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市三島町', '17', '17202', '9260802', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '三島町', 'ミシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市米町', '17', '17202', '9260803', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '米町', 'コメマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市生駒町', '17', '17202', '9260804', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '生駒町', 'イコマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市亀山町', '17', '17202', '9260805', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '亀山町', 'カメヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市一本杉町', '17', '17202', '9260806', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '一本杉町', 'イッポンスギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市阿良町', '17', '17202', '9260807', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '阿良町', 'アラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市木町', '17', '17202', '9260808', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '木町', 'キマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市御祓町', '17', '17202', '9260811', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '御祓町', 'ミソギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市北藤橋町', '17', '17202', '9260812', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '北藤橋町', 'キタフジハシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市南藤橋町', '17', '17202', '9260813', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '南藤橋町', 'ミナミフジハシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市所口町', '17', '17202', '9260814', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '所口町', 'トコログチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市栄町', '17', '17202', '9260815', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市岩屋町', '17', '17202', '9260816', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '岩屋町', 'イワヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市藤橋町', '17', '17202', '9260816', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '藤橋町', 'フジハシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市西藤橋町', '17', '17202', '9260817', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '西藤橋町', 'ニシフジハシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市馬出町', '17', '17202', '9260818', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '馬出町', 'マダシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市国分町', '17', '17202', '9260821', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '国分町', 'コクブマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市細口町', '17', '17202', '9260822', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '細口町', 'ホソグチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市青葉台町', '17', '17202', '9260823', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '青葉台町', 'アオバダイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市下町', '17', '17202', '9260824', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '下町', 'シモマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市徳田町', '17', '17202', '9260824', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '徳田町', 'トクダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市江曽町', '17', '17202', '9260825', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '江曽町', 'エソマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市飯川町', '17', '17202', '9260826', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '飯川町', 'イガワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市若林町', '17', '17202', '9260827', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '若林町', 'ワカバヤシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市白馬町', '17', '17202', '9260828', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '白馬町', 'シロウママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市徳田新町', '17', '17202', '9260829', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '徳田新町', 'トクダシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市青山町', '17', '17202', '9260831', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '青山町', 'アオヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市池崎町', '17', '17202', '9260831', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '池崎町', 'イケザキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市盤若野町', '17', '17202', '9260832', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '盤若野町', 'ハンニャノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市旭町', '17', '17202', '9260833', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '旭町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市東三階町', '17', '17202', '9260834', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '東三階町', 'ヒガシミカイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市西三階町', '17', '17202', '9260835', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '西三階町', 'ニシミカイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市町屋町', '17', '17202', '9260836', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '町屋町', 'マチヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市温井町', '17', '17202', '9260837', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '温井町', 'ヌクイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市満仁町', '17', '17202', '9260838', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '満仁町', 'マニマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市松百町', '17', '17202', '9260841', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '松百町', 'マットウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市松百新町', '17', '17202', '9260842', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '松百新町', 'マットウシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市赤浦町', '17', '17202', '9260843', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '赤浦町', 'アカウラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市直津町', '17', '17202', '9260844', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '直津町', 'タダツマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市新保町', '17', '17202', '9260845', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '新保町', 'シンボマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市祖浜町', '17', '17202', '9260846', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '祖浜町', 'ソハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市つつじが浜', '17', '17202', '9260851', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', 'つつじが浜', 'ツツジガハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市小島町', '17', '17202', '9260852', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '小島町', 'コジママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市津向町', '17', '17202', '9260853', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '津向町', 'ツムギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市なぎの浦', '17', '17202', '9260854', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', 'なぎの浦', 'ナギノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市小丸山台', '17', '17202', '9260855', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '小丸山台', 'コマルヤマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市寿町', '17', '17202', '9260861', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '寿町', 'コトブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市常盤町', '17', '17202', '9260862', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '常盤町', 'トキワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市白銀町', '17', '17202', '9260863', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '白銀町', 'シロガネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市魚町', '17', '17202', '9260864', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '魚町', 'ウオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市松本町', '17', '17202', '9260865', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '松本町', 'マツモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市富岡町', '17', '17202', '9260866', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '富岡町', 'トミオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市桜町', '17', '17202', '9260867', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '桜町', 'サクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡穴水町', '17', '17461', '9270000', '石川県', 'イシカワケン', '鳳珠郡穴水町', 'ホウスグンアナミズマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('124828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡穴水町樟谷', '17', '17461', '9270001', '石川県', 'イシカワケン', '鳳珠郡穴水町', 'ホウスグンアナミズマチ', '樟谷', 'クノギタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡穴水町菅谷', '17', '17461', '9270002', '石川県', 'イシカワケン', '鳳珠郡穴水町', 'ホウスグンアナミズマチ', '菅谷', 'スゲンタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡穴水町伊久留', '17', '17461', '9270003', '石川県', 'イシカワケン', '鳳珠郡穴水町', 'ホウスグンアナミズマチ', '伊久留', 'イクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡穴水町曽山', '17', '17461', '9270004', '石川県', 'イシカワケン', '鳳珠郡穴水町', 'ホウスグンアナミズマチ', '曽山', 'ソヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡穴水町東中谷', '17', '17461', '9270005', '石川県', 'イシカワケン', '鳳珠郡穴水町', 'ホウスグンアナミズマチ', '東中谷', 'ヒガシナカンタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡穴水町旭ケ丘', '17', '17461', '9270006', '石川県', 'イシカワケン', '鳳珠郡穴水町', 'ホウスグンアナミズマチ', '旭ケ丘', 'アサヒガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡穴水町岩車', '17', '17461', '9270007', '石川県', 'イシカワケン', '鳳珠郡穴水町', 'ホウスグンアナミズマチ', '岩車', 'イワグルマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡穴水町川尻', '17', '17461', '9270008', '石川県', 'イシカワケン', '鳳珠郡穴水町', 'ホウスグンアナミズマチ', '川尻', 'カワシリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡穴水町比良', '17', '17461', '9270009', '石川県', 'イシカワケン', '鳳珠郡穴水町', 'ホウスグンアナミズマチ', '比良', 'ビラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡穴水町木原', '17', '17461', '9270011', '石川県', 'イシカワケン', '鳳珠郡穴水町', 'ホウスグンアナミズマチ', '木原', 'キハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡穴水町藤巻', '17', '17461', '9270012', '石川県', 'イシカワケン', '鳳珠郡穴水町', 'ホウスグンアナミズマチ', '藤巻', 'フジマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡穴水町瑞鳳', '17', '17461', '9270013', '石川県', 'イシカワケン', '鳳珠郡穴水町', 'ホウスグンアナミズマチ', '瑞鳳', 'ズイホウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡穴水町梶', '17', '17461', '9270014', '石川県', 'イシカワケン', '鳳珠郡穴水町', 'ホウスグンアナミズマチ', '梶', 'カジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡穴水町中居', '17', '17461', '9270015', '石川県', 'イシカワケン', '鳳珠郡穴水町', 'ホウスグンアナミズマチ', '中居', 'ナカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡穴水町中居南', '17', '17461', '9270016', '石川県', 'イシカワケン', '鳳珠郡穴水町', 'ホウスグンアナミズマチ', '中居南', 'ナカイミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡穴水町波志借', '17', '17461', '9270017', '石川県', 'イシカワケン', '鳳珠郡穴水町', 'ホウスグンアナミズマチ', '波志借', 'ハジカシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡穴水町七海', '17', '17461', '9270021', '石川県', 'イシカワケン', '鳳珠郡穴水町', 'ホウスグンアナミズマチ', '七海', 'シツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡穴水町北七海', '17', '17461', '9270022', '石川県', 'イシカワケン', '鳳珠郡穴水町', 'ホウスグンアナミズマチ', '北七海', 'キタシツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡穴水町麦ケ浦', '17', '17461', '9270023', '石川県', 'イシカワケン', '鳳珠郡穴水町', 'ホウスグンアナミズマチ', '麦ケ浦', 'ムキガウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡穴水町由比ケ丘', '17', '17461', '9270024', '石川県', 'イシカワケン', '鳳珠郡穴水町', 'ホウスグンアナミズマチ', '由比ケ丘', 'ユイガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡穴水町内浦', '17', '17461', '9270025', '石川県', 'イシカワケン', '鳳珠郡穴水町', 'ホウスグンアナミズマチ', '内浦', 'ウチウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡穴水町大町', '17', '17461', '9270026', '石川県', 'イシカワケン', '鳳珠郡穴水町', 'ホウスグンアナミズマチ', '大町', 'オオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡穴水町川島', '17', '17461', '9270027', '石川県', 'イシカワケン', '鳳珠郡穴水町', 'ホウスグンアナミズマチ', '川島', 'カワジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡穴水町鵜島', '17', '17461', '9270031', '石川県', 'イシカワケン', '鳳珠郡穴水町', 'ホウスグンアナミズマチ', '鵜島', 'ウジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡穴水町乙ケ崎', '17', '17461', '9270032', '石川県', 'イシカワケン', '鳳珠郡穴水町', 'ホウスグンアナミズマチ', '乙ケ崎', 'オトガサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡穴水町緑ケ丘', '17', '17461', '9270033', '石川県', 'イシカワケン', '鳳珠郡穴水町', 'ホウスグンアナミズマチ', '緑ケ丘', 'ミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡穴水町新崎', '17', '17461', '9270034', '石川県', 'イシカワケン', '鳳珠郡穴水町', 'ホウスグンアナミズマチ', '新崎', 'ニンザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡穴水町志ケ浦', '17', '17461', '9270035', '石川県', 'イシカワケン', '鳳珠郡穴水町', 'ホウスグンアナミズマチ', '志ケ浦', 'シガウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡穴水町望洋台', '17', '17461', '9270036', '石川県', 'イシカワケン', '鳳珠郡穴水町', 'ホウスグンアナミズマチ', '望洋台', 'ボウヨウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡穴水町根木', '17', '17461', '9270037', '石川県', 'イシカワケン', '鳳珠郡穴水町', 'ホウスグンアナミズマチ', '根木', 'ネキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡穴水町鹿島', '17', '17461', '9270038', '石川県', 'イシカワケン', '鳳珠郡穴水町', 'ホウスグンアナミズマチ', '鹿島', 'カシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡穴水町曽福', '17', '17461', '9270039', '石川県', 'イシカワケン', '鳳珠郡穴水町', 'ホウスグンアナミズマチ', '曽福', 'ソブク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡穴水町天神谷', '17', '17461', '9270041', '石川県', 'イシカワケン', '鳳珠郡穴水町', 'ホウスグンアナミズマチ', '天神谷', 'テンジンダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡穴水町宇留地', '17', '17461', '9270042', '石川県', 'イシカワケン', '鳳珠郡穴水町', 'ホウスグンアナミズマチ', '宇留地', 'ウルチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡穴水町越の原', '17', '17461', '9270043', '石川県', 'イシカワケン', '鳳珠郡穴水町', 'ホウスグンアナミズマチ', '越の原', 'コシノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡穴水町鹿路', '17', '17461', '9270044', '石川県', 'イシカワケン', '鳳珠郡穴水町', 'ホウスグンアナミズマチ', '鹿路', 'ロクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡穴水町河内', '17', '17461', '9270045', '石川県', 'イシカワケン', '鳳珠郡穴水町', 'ホウスグンアナミズマチ', '河内', 'カワチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡穴水町越渡', '17', '17461', '9270046', '石川県', 'イシカワケン', '鳳珠郡穴水町', 'ホウスグンアナミズマチ', '越渡', 'コエト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡穴水町汁谷', '17', '17461', '9270046', '石川県', 'イシカワケン', '鳳珠郡穴水町', 'ホウスグンアナミズマチ', '汁谷', 'シルタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡穴水町上中', '17', '17461', '9270047', '石川県', 'イシカワケン', '鳳珠郡穴水町', 'ホウスグンアナミズマチ', '上中', 'カミナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡穴水町大角間', '17', '17461', '9270048', '石川県', 'イシカワケン', '鳳珠郡穴水町', 'ホウスグンアナミズマチ', '大角間', 'オオカクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡穴水町桂谷', '17', '17461', '9270049', '石川県', 'イシカワケン', '鳳珠郡穴水町', 'ホウスグンアナミズマチ', '桂谷', 'カツラダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡穴水町小又', '17', '17461', '9270051', '石川県', 'イシカワケン', '鳳珠郡穴水町', 'ホウスグンアナミズマチ', '小又', 'オマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡穴水町平野', '17', '17461', '9270052', '石川県', 'イシカワケン', '鳳珠郡穴水町', 'ホウスグンアナミズマチ', '平野', 'ヒラノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡穴水町此木', '17', '17461', '9270053', '石川県', 'イシカワケン', '鳳珠郡穴水町', 'ホウスグンアナミズマチ', '此木', 'クノギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡穴水町上野', '17', '17461', '9270054', '石川県', 'イシカワケン', '鳳珠郡穴水町', 'ホウスグンアナミズマチ', '上野', 'ウワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡穴水町地蔵坊', '17', '17461', '9270055', '石川県', 'イシカワケン', '鳳珠郡穴水町', 'ホウスグンアナミズマチ', '地蔵坊', 'ジゾウボウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡穴水町上唐川', '17', '17461', '9270056', '石川県', 'イシカワケン', '鳳珠郡穴水町', 'ホウスグンアナミズマチ', '上唐川', 'カミカラカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡穴水町下唐川', '17', '17461', '9270057', '石川県', 'イシカワケン', '鳳珠郡穴水町', 'ホウスグンアナミズマチ', '下唐川', 'シモカラカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡穴水町挾石', '17', '17461', '9270058', '石川県', 'イシカワケン', '鳳珠郡穴水町', 'ホウスグンアナミズマチ', '挾石', 'ハサミシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡穴水町竹太', '17', '17461', '9270201', '石川県', 'イシカワケン', '鳳珠郡穴水町', 'ホウスグンアナミズマチ', '竹太', 'タケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡穴水町古君', '17', '17461', '9270202', '石川県', 'イシカワケン', '鳳珠郡穴水町', 'ホウスグンアナミズマチ', '古君', 'フルキミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡穴水町花園', '17', '17461', '9270203', '石川県', 'イシカワケン', '鳳珠郡穴水町', 'ホウスグンアナミズマチ', '花園', 'ハナゾノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡穴水町明千寺', '17', '17461', '9270204', '石川県', 'イシカワケン', '鳳珠郡穴水町', 'ホウスグンアナミズマチ', '明千寺', 'ミョウセンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡穴水町宇加川', '17', '17461', '9270205', '石川県', 'イシカワケン', '鳳珠郡穴水町', 'ホウスグンアナミズマチ', '宇加川', 'ウカガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡穴水町前波', '17', '17461', '9270206', '石川県', 'イシカワケン', '鳳珠郡穴水町', 'ホウスグンアナミズマチ', '前波', 'マエナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡穴水町沖波', '17', '17461', '9270207', '石川県', 'イシカワケン', '鳳珠郡穴水町', 'ホウスグンアナミズマチ', '沖波', 'オキナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡穴水町甲', '17', '17461', '9270211', '石川県', 'イシカワケン', '鳳珠郡穴水町', 'ホウスグンアナミズマチ', '甲', 'カブト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡穴水町黒崎', '17', '17461', '9270212', '石川県', 'イシカワケン', '鳳珠郡穴水町', 'ホウスグンアナミズマチ', '黒崎', 'クロサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡穴水町至誠', '17', '17461', '9270213', '石川県', 'イシカワケン', '鳳珠郡穴水町', 'ホウスグンアナミズマチ', '至誠', 'シセイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡穴水町小甲', '17', '17461', '9270214', '石川県', 'イシカワケン', '鳳珠郡穴水町', 'ホウスグンアナミズマチ', '小甲', 'コカブト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡穴水町大甲', '17', '17461', '9270215', '石川県', 'イシカワケン', '鳳珠郡穴水町', 'ホウスグンアナミズマチ', '大甲', 'オオカブト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡穴水町曽良', '17', '17461', '9270221', '石川県', 'イシカワケン', '鳳珠郡穴水町', 'ホウスグンアナミズマチ', '曽良', 'ソラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡穴水町大郷', '17', '17461', '9270222', '石川県', 'イシカワケン', '鳳珠郡穴水町', 'ホウスグンアナミズマチ', '大郷', 'ダイゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡穴水町鹿波', '17', '17461', '9270223', '石川県', 'イシカワケン', '鳳珠郡穴水町', 'ホウスグンアナミズマチ', '鹿波', 'カナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡穴水町鹿上', '17', '17461', '9270224', '石川県', 'イシカワケン', '鳳珠郡穴水町', 'ホウスグンアナミズマチ', '鹿上', 'シカガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡穴水町野並', '17', '17461', '9270225', '石川県', 'イシカワケン', '鳳珠郡穴水町', 'ホウスグンアナミズマチ', '野並', 'ノナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡穴水町山中', '17', '17461', '9270231', '石川県', 'イシカワケン', '鳳珠郡穴水町', 'ホウスグンアナミズマチ', '山中', 'ヤマナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡穴水町東山', '17', '17461', '9270232', '石川県', 'イシカワケン', '鳳珠郡穴水町', 'ホウスグンアナミズマチ', '東山', 'ヒガシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡穴水町女良川', '17', '17461', '9270233', '石川県', 'イシカワケン', '鳳珠郡穴水町', 'ホウスグンアナミズマチ', '女良川', 'メラガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡穴水町小又山中', '17', '17461', '9270234', '石川県', 'イシカワケン', '鳳珠郡穴水町', 'ホウスグンアナミズマチ', '小又', 'オマタ', null, null, '山中', 'ヤマナカ');
INSERT INTO `ms_addresses` VALUES ('124899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡穴水町市ノ坂', '17', '17461', '9270235', '石川県', 'イシカワケン', '鳳珠郡穴水町', 'ホウスグンアナミズマチ', '市ノ坂', 'イチノサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡能登町七見', '17', '17463', '9270301', '石川県', 'イシカワケン', '鳳珠郡能登町', 'ホウスグンノトチョウ', '七見', 'シチミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡能登町鵜川', '17', '17463', '9270302', '石川県', 'イシカワケン', '鳳珠郡能登町', 'ホウスグンノトチョウ', '鵜川', 'ウカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡能登町小垣', '17', '17463', '9270303', '石川県', 'イシカワケン', '鳳珠郡能登町', 'ホウスグンノトチョウ', '小垣', 'オガキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡能登町柿生', '17', '17463', '9270304', '石川県', 'イシカワケン', '鳳珠郡能登町', 'ホウスグンノトチョウ', '柿生', 'カキオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡能登町武連', '17', '17463', '9270305', '石川県', 'イシカワケン', '鳳珠郡能登町', 'ホウスグンノトチョウ', '武連', 'ムレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡能登町瑞穂', '17', '17463', '9270311', '石川県', 'イシカワケン', '鳳珠郡能登町', 'ホウスグンノトチョウ', '瑞穂', 'ミズホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡能登町本木', '17', '17463', '9270312', '石川県', 'イシカワケン', '鳳珠郡能登町', 'ホウスグンノトチョウ', '本木', 'ホンキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡能登町木住', '17', '17463', '9270313', '石川県', 'イシカワケン', '鳳珠郡能登町', 'ホウスグンノトチョウ', '木住', 'キズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡能登町山田', '17', '17463', '9270314', '石川県', 'イシカワケン', '鳳珠郡能登町', 'ホウスグンノトチョウ', '山田', 'ヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡能登町豊ケ丘', '17', '17463', '9270315', '石川県', 'イシカワケン', '鳳珠郡能登町', 'ホウスグンノトチョウ', '豊ケ丘', 'トヨガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡能登町爼倉', '17', '17463', '9270321', '石川県', 'イシカワケン', '鳳珠郡能登町', 'ホウスグンノトチョウ', '爼倉', 'マナイタグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡能登町宮地', '17', '17463', '9270322', '石川県', 'イシカワケン', '鳳珠郡能登町', 'ホウスグンノトチョウ', '宮地', 'ミヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡能登町鮭尾', '17', '17463', '9270323', '石川県', 'イシカワケン', '鳳珠郡能登町', 'ホウスグンノトチョウ', '鮭尾', 'サケオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡能登町柏木', '17', '17463', '9270324', '石川県', 'イシカワケン', '鳳珠郡能登町', 'ホウスグンノトチョウ', '柏木', 'カシワギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡能登町太田原', '17', '17463', '9270325', '石川県', 'イシカワケン', '鳳珠郡能登町', 'ホウスグンノトチョウ', '太田原', 'オオダワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡能登町', '17', '17463', '9270400', '石川県', 'イシカワケン', '鳳珠郡能登町', 'ホウスグンノトチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('124918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡能登町宇出津山分', '17', '17463', '9270431', '石川県', 'イシカワケン', '鳳珠郡能登町', 'ホウスグンノトチョウ', '宇出津山分', 'ウシツヤマブン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡能登町宇出津新', '17', '17463', '9270432', '石川県', 'イシカワケン', '鳳珠郡能登町', 'ホウスグンノトチョウ', '宇出津新', 'ウシツシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡能登町宇出津', '17', '17463', '9270433', '石川県', 'イシカワケン', '鳳珠郡能登町', 'ホウスグンノトチョウ', '宇出津', 'ウシツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡能登町崎山', '17', '17463', '9270434', '石川県', 'イシカワケン', '鳳珠郡能登町', 'ホウスグンノトチョウ', '崎山', 'サキヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡能登町宇出津新港', '17', '17463', '9270435', '石川県', 'イシカワケン', '鳳珠郡能登町', 'ホウスグンノトチョウ', '宇出津新港', 'ウシツシンコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡能登町藤波', '17', '17463', '9270441', '石川県', 'イシカワケン', '鳳珠郡能登町', 'ホウスグンノトチョウ', '藤波', 'フジナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡能登町波並', '17', '17463', '9270442', '石川県', 'イシカワケン', '鳳珠郡能登町', 'ホウスグンノトチョウ', '波並', 'ハナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡能登町矢波', '17', '17463', '9270443', '石川県', 'イシカワケン', '鳳珠郡能登町', 'ホウスグンノトチョウ', '矢波', 'ヤナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡能登町猪平', '17', '17463', '9270444', '石川県', 'イシカワケン', '鳳珠郡能登町', 'ホウスグンノトチョウ', '猪平', 'イノヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡能登町藤ノ瀬', '17', '17463', '9270451', '石川県', 'イシカワケン', '鳳珠郡能登町', 'ホウスグンノトチョウ', '藤ノ瀬', 'フジノセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡能登町宇加塚', '17', '17463', '9270452', '石川県', 'イシカワケン', '鳳珠郡能登町', 'ホウスグンノトチョウ', '宇加塚', 'ウカヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡能登町鶴町', '17', '17463', '9270453', '石川県', 'イシカワケン', '鳳珠郡能登町', 'ホウスグンノトチョウ', '鶴町', 'ツルマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡能登町曽又', '17', '17463', '9270454', '石川県', 'イシカワケン', '鳳珠郡能登町', 'ホウスグンノトチョウ', '曽又', 'ソマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡能登町明野', '17', '17463', '9270551', '石川県', 'イシカワケン', '鳳珠郡能登町', 'ホウスグンノトチョウ', '明野', 'アケノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡能登町越坂', '17', '17463', '9270552', '石川県', 'イシカワケン', '鳳珠郡能登町', 'ホウスグンノトチョウ', '越坂', 'オッサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡能登町小木', '17', '17463', '9270553', '石川県', 'イシカワケン', '鳳珠郡能登町', 'ホウスグンノトチョウ', '小木', 'オギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡能登町市之瀬', '17', '17463', '9270554', '石川県', 'イシカワケン', '鳳珠郡能登町', 'ホウスグンノトチョウ', '市之瀬', 'イチノセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡能登町羽生ろ', '17', '17463', '9270555', '石川県', 'イシカワケン', '鳳珠郡能登町', 'ホウスグンノトチョウ', '羽生', 'ハニュウ', null, null, 'ろ', 'ロ');
INSERT INTO `ms_addresses` VALUES ('124939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡能登町羽生い', '17', '17463', '9270561', '石川県', 'イシカワケン', '鳳珠郡能登町', 'ホウスグンノトチョウ', '羽生', 'ハニュウ', null, null, 'い', 'イ');
INSERT INTO `ms_addresses` VALUES ('124940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡能登町真脇', '17', '17463', '9270562', '石川県', 'イシカワケン', '鳳珠郡能登町', 'ホウスグンノトチョウ', '真脇', 'マワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡能登町姫', '17', '17463', '9270563', '石川県', 'イシカワケン', '鳳珠郡能登町', 'ホウスグンノトチョウ', '姫', 'ヒメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡能登町小浦', '17', '17463', '9270564', '石川県', 'イシカワケン', '鳳珠郡能登町', 'ホウスグンノトチョウ', '小浦', 'オウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡能登町羽根', '17', '17463', '9270565', '石川県', 'イシカワケン', '鳳珠郡能登町', 'ホウスグンノトチョウ', '羽根', 'ハネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡能登町恋路', '17', '17463', '9270601', '石川県', 'イシカワケン', '鳳珠郡能登町', 'ホウスグンノトチョウ', '恋路', 'コイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡能登町松波', '17', '17463', '9270602', '石川県', 'イシカワケン', '鳳珠郡能登町', 'ホウスグンノトチョウ', '松波', 'マツナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡能登町明生', '17', '17463', '9270602', '石川県', 'イシカワケン', '鳳珠郡能登町', 'ホウスグンノトチョウ', '明生', 'ミョウジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡能登町布浦', '17', '17463', '9270603', '石川県', 'イシカワケン', '鳳珠郡能登町', 'ホウスグンノトチョウ', '布浦', 'ヌノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡能登町九里川尻', '17', '17463', '9270604', '石川県', 'イシカワケン', '鳳珠郡能登町', 'ホウスグンノトチョウ', '九里川尻', 'クリカワシリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡能登町立壁', '17', '17463', '9270605', '石川県', 'イシカワケン', '鳳珠郡能登町', 'ホウスグンノトチョウ', '立壁', 'タテカベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡能登町四方山', '17', '17463', '9270606', '石川県', 'イシカワケン', '鳳珠郡能登町', 'ホウスグンノトチョウ', '四方山', 'ヨモヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡能登町白丸', '17', '17463', '9270607', '石川県', 'イシカワケン', '鳳珠郡能登町', 'ホウスグンノトチョウ', '白丸', 'シロマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡能登町内浦長尾', '17', '17463', '9270608', '石川県', 'イシカワケン', '鳳珠郡能登町', 'ホウスグンノトチョウ', '内浦長尾', 'ウチウラナゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡能登町新保', '17', '17463', '9270609', '石川県', 'イシカワケン', '鳳珠郡能登町', 'ホウスグンノトチョウ', '新保', 'シンボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡能登町清真', '17', '17463', '9270611', '石川県', 'イシカワケン', '鳳珠郡能登町', 'ホウスグンノトチョウ', '清真', 'キヨザネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡能登町秋吉', '17', '17463', '9270612', '石川県', 'イシカワケン', '鳳珠郡能登町', 'ホウスグンノトチョウ', '秋吉', 'アキヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡能登町河ケ谷', '17', '17463', '9270613', '石川県', 'イシカワケン', '鳳珠郡能登町', 'ホウスグンノトチョウ', '河ケ谷', 'カガタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡能登町満泉寺', '17', '17463', '9270614', '石川県', 'イシカワケン', '鳳珠郡能登町', 'ホウスグンノトチョウ', '満泉寺', 'マンセンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡能登町山中', '17', '17463', '9270614', '石川県', 'イシカワケン', '鳳珠郡能登町', 'ホウスグンノトチョウ', '山中', 'ヤマナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡能登町宮犬', '17', '17463', '9270615', '石川県', 'イシカワケン', '鳳珠郡能登町', 'ホウスグンノトチョウ', '宮犬', 'ミヤイヌ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡能登町上', '17', '17463', '9270621', '石川県', 'イシカワケン', '鳳珠郡能登町', 'ホウスグンノトチョウ', '上', 'カミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡能登町不動寺', '17', '17463', '9270622', '石川県', 'イシカワケン', '鳳珠郡能登町', 'ホウスグンノトチョウ', '不動寺', 'フドウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡能登町行延', '17', '17463', '9270623', '石川県', 'イシカワケン', '鳳珠郡能登町', 'ホウスグンノトチョウ', '行延', 'ユキノベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡能登町時長', '17', '17463', '9270624', '石川県', 'イシカワケン', '鳳珠郡能登町', 'ホウスグンノトチョウ', '時長', 'トキナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡能登町国重', '17', '17463', '9270625', '石川県', 'イシカワケン', '鳳珠郡能登町', 'ホウスグンノトチョウ', '国重', 'クニシゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡能登町泉', '17', '17463', '9270626', '石川県', 'イシカワケン', '鳳珠郡能登町', 'ホウスグンノトチョウ', '泉', 'イズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡能登町駒渡', '17', '17463', '9270626', '石川県', 'イシカワケン', '鳳珠郡能登町', 'ホウスグンノトチョウ', '駒渡', 'コマワタリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡能登町田代', '17', '17463', '9270626', '石川県', 'イシカワケン', '鳳珠郡能登町', 'ホウスグンノトチョウ', '田代', 'タシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡能登町滝之坊', '17', '17463', '9270627', '石川県', 'イシカワケン', '鳳珠郡能登町', 'ホウスグンノトチョウ', '滝之坊', 'タキノボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡能登町福光', '17', '17463', '9270627', '石川県', 'イシカワケン', '鳳珠郡能登町', 'ホウスグンノトチョウ', '福光', 'フクミツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県珠洲市', '17', '17205', '9271200', '石川県', 'イシカワケン', '珠洲市', 'スズシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('124972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県珠洲市正院町岡田', '17', '17205', '9271201', '石川県', 'イシカワケン', '珠洲市', 'スズシ', '正院町岡田', 'ショウインマチオカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県珠洲市正院町飯塚', '17', '17205', '9271202', '石川県', 'イシカワケン', '珠洲市', 'スズシ', '正院町飯塚', 'ショウインマチイイヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県珠洲市正院町平床', '17', '17205', '9271203', '石川県', 'イシカワケン', '珠洲市', 'スズシ', '正院町平床', 'ショウインマチヒラトコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県珠洲市蛸島町', '17', '17205', '9271204', '石川県', 'イシカワケン', '珠洲市', 'スズシ', '蛸島町', 'タコジママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県珠洲市正院町川尻', '17', '17205', '9271205', '石川県', 'イシカワケン', '珠洲市', 'スズシ', '正院町川尻', 'ショウインマチカワシリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県珠洲市正院町正院', '17', '17205', '9271206', '石川県', 'イシカワケン', '珠洲市', 'スズシ', '正院町正院', 'ショウインマチショウイン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県珠洲市正院町小路', '17', '17205', '9271207', '石川県', 'イシカワケン', '珠洲市', 'スズシ', '正院町小路', 'ショウインマチコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県珠洲市岩坂町', '17', '17205', '9271211', '石川県', 'イシカワケン', '珠洲市', 'スズシ', '岩坂町', 'イワサカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県珠洲市熊谷町', '17', '17205', '9271212', '石川県', 'イシカワケン', '珠洲市', 'スズシ', '熊谷町', 'クマンタニマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県珠洲市野々江町', '17', '17205', '9271213', '石川県', 'イシカワケン', '珠洲市', 'スズシ', '野々江町', 'ノノエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県珠洲市飯田町', '17', '17205', '9271214', '石川県', 'イシカワケン', '珠洲市', 'スズシ', '飯田町', 'イイダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県珠洲市上戸町北方', '17', '17205', '9271215', '石川県', 'イシカワケン', '珠洲市', 'スズシ', '上戸町北方', 'ウエドマチキタガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県珠洲市上戸町寺社', '17', '17205', '9271216', '石川県', 'イシカワケン', '珠洲市', 'スズシ', '上戸町寺社', 'ウエドマチジシャ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県珠洲市上戸町南方', '17', '17205', '9271217', '石川県', 'イシカワケン', '珠洲市', 'スズシ', '上戸町南方', 'ウエドマチミナミガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県珠洲市宝立町春日野', '17', '17205', '9271221', '石川県', 'イシカワケン', '珠洲市', 'スズシ', '宝立町春日野', 'ホウリュウマチカスガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県珠洲市宝立町金峰寺', '17', '17205', '9271221', '石川県', 'イシカワケン', '珠洲市', 'スズシ', '宝立町金峰寺', 'ホウリュウマチコンポウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県珠洲市宝立町鵜飼', '17', '17205', '9271222', '石川県', 'イシカワケン', '珠洲市', 'スズシ', '宝立町鵜飼', 'ホウリュウマチウカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県珠洲市宝立町鵜島', '17', '17205', '9271223', '石川県', 'イシカワケン', '珠洲市', 'スズシ', '宝立町鵜島', 'ホウリュウマチウシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県珠洲市宝立町南黒丸', '17', '17205', '9271224', '石川県', 'イシカワケン', '珠洲市', 'スズシ', '宝立町南黒丸', 'ホウリュウマチミナミクロマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県珠洲市宝立町宗玄', '17', '17205', '9271225', '石川県', 'イシカワケン', '珠洲市', 'スズシ', '宝立町宗玄', 'ホウリュウマチソウゲン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県珠洲市宝立町馬渡', '17', '17205', '9271226', '石川県', 'イシカワケン', '珠洲市', 'スズシ', '宝立町馬渡', 'ホウリュウマチマワタリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県珠洲市宝立町大町泥木', '17', '17205', '9271227', '石川県', 'イシカワケン', '珠洲市', 'スズシ', '宝立町大町泥木', 'ホウリュウマチオオマチドロノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県珠洲市宝立町二艘丹', '17', '17205', '9271227', '石川県', 'イシカワケン', '珠洲市', 'スズシ', '宝立町二艘丹', 'ホウリュウマチニソウフネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県珠洲市宝立町柏原', '17', '17205', '9271228', '石川県', 'イシカワケン', '珠洲市', 'スズシ', '宝立町柏原', 'ホウリュウマチカシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県珠洲市宝立町黒峰', '17', '17205', '9271228', '石川県', 'イシカワケン', '珠洲市', 'スズシ', '宝立町黒峰', 'ホウリュウマチクロミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県珠洲市若山町鈴内', '17', '17205', '9271231', '石川県', 'イシカワケン', '珠洲市', 'スズシ', '若山町鈴内', 'ワカヤママチスズナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県珠洲市若山町広栗', '17', '17205', '9271232', '石川県', 'イシカワケン', '珠洲市', 'スズシ', '若山町広栗', 'ワカヤママチヒログリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('124999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県珠洲市若山町出田', '17', '17205', '9271233', '石川県', 'イシカワケン', '珠洲市', 'スズシ', '若山町出田', 'ワカヤママチスッタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県珠洲市若山町経念', '17', '17205', '9271234', '石川県', 'イシカワケン', '珠洲市', 'スズシ', '若山町経念', 'ワカヤママチキョウネン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県珠洲市若山町中田', '17', '17205', '9271235', '石川県', 'イシカワケン', '珠洲市', 'スズシ', '若山町中田', 'ワカヤママチナカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県珠洲市若山町向', '17', '17205', '9271235', '石川県', 'イシカワケン', '珠洲市', 'スズシ', '若山町向', 'ワカヤママチムカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県珠洲市若山町中', '17', '17205', '9271236', '石川県', 'イシカワケン', '珠洲市', 'スズシ', '若山町中', 'ワカヤママチナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県珠洲市若山町宇都山', '17', '17205', '9271237', '石川県', 'イシカワケン', '珠洲市', 'スズシ', '若山町宇都山', 'ワカヤママチウツヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県珠洲市若山町大坊', '17', '17205', '9271237', '石川県', 'イシカワケン', '珠洲市', 'スズシ', '若山町大坊', 'ワカヤママチダイボウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県珠洲市若山町延武', '17', '17205', '9271238', '石川県', 'イシカワケン', '珠洲市', 'スズシ', '若山町延武', 'ワカヤママチノブタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県珠洲市若山町火宮', '17', '17205', '9271238', '石川県', 'イシカワケン', '珠洲市', 'スズシ', '若山町火宮', 'ワカヤママチヒミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県珠洲市若山町古蔵', '17', '17205', '9271239', '石川県', 'イシカワケン', '珠洲市', 'スズシ', '若山町古蔵', 'ワカヤママチフルクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県珠洲市高屋町', '17', '17205', '9271301', '石川県', 'イシカワケン', '珠洲市', 'スズシ', '高屋町', 'タカヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県珠洲市笹波町', '17', '17205', '9271302', '石川県', 'イシカワケン', '珠洲市', 'スズシ', '笹波町', 'ササナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県珠洲市石神町', '17', '17205', '9271303', '石川県', 'イシカワケン', '珠洲市', 'スズシ', '石神町', 'イシガミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県珠洲市馬緤町', '17', '17205', '9271304', '石川県', 'イシカワケン', '珠洲市', 'スズシ', '馬緤町', 'マツナギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県珠洲市若山町上正力', '17', '17205', '9271311', '石川県', 'イシカワケン', '珠洲市', 'スズシ', '若山町上正力', 'ワカヤママチカミショウリキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県珠洲市若山町二子', '17', '17205', '9271312', '石川県', 'イシカワケン', '珠洲市', 'スズシ', '若山町二子', 'ワカヤママチフタゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県珠洲市若山町宗末', '17', '17205', '9271313', '石川県', 'イシカワケン', '珠洲市', 'スズシ', '若山町宗末', 'ワカヤママチムネスエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県珠洲市若山町上黒丸', '17', '17205', '9271314', '石川県', 'イシカワケン', '珠洲市', 'スズシ', '若山町上黒丸', 'ワカヤママチカミクロマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県珠洲市若山町白滝', '17', '17205', '9271315', '石川県', 'イシカワケン', '珠洲市', 'スズシ', '若山町白滝', 'ワカヤママチシラタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県珠洲市若山町南山', '17', '17205', '9271315', '石川県', 'イシカワケン', '珠洲市', 'スズシ', '若山町南山', 'ワカヤママチミナミヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県珠洲市若山町洲巻', '17', '17205', '9271316', '石川県', 'イシカワケン', '珠洲市', 'スズシ', '若山町洲巻', 'ワカヤママチスマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県珠洲市若山町上山', '17', '17205', '9271317', '石川県', 'イシカワケン', '珠洲市', 'スズシ', '若山町上山', 'ワカヤママチカミヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県珠洲市若山町北山', '17', '17205', '9271318', '石川県', 'イシカワケン', '珠洲市', 'スズシ', '若山町北山', 'ワカヤママチキタヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県珠洲市若山町吉ケ池', '17', '17205', '9271319', '石川県', 'イシカワケン', '珠洲市', 'スズシ', '若山町吉ケ池', 'ワカヤママチヨシガイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県珠洲市大谷町', '17', '17205', '9271321', '石川県', 'イシカワケン', '珠洲市', 'スズシ', '大谷町', 'オオタニマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県珠洲市長橋町', '17', '17205', '9271322', '石川県', 'イシカワケン', '珠洲市', 'スズシ', '長橋町', 'ナガハシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県珠洲市片岩町', '17', '17205', '9271323', '石川県', 'イシカワケン', '珠洲市', 'スズシ', '片岩町', 'カタイワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県珠洲市清水町', '17', '17205', '9271324', '石川県', 'イシカワケン', '珠洲市', 'スズシ', '清水町', 'シミズマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県珠洲市仁江町', '17', '17205', '9271325', '石川県', 'イシカワケン', '珠洲市', 'スズシ', '仁江町', 'ニエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県珠洲市真浦町', '17', '17205', '9271326', '石川県', 'イシカワケン', '珠洲市', 'スズシ', '真浦町', 'マウラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県珠洲市狼煙町', '17', '17205', '9271441', '石川県', 'イシカワケン', '珠洲市', 'スズシ', '狼煙町', 'ノロシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県珠洲市狼煙新町', '17', '17205', '9271442', '石川県', 'イシカワケン', '珠洲市', 'スズシ', '狼煙新町', 'ノロシシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県珠洲市東山中町', '17', '17205', '9271443', '石川県', 'イシカワケン', '珠洲市', 'スズシ', '東山中町', 'ヒガシヤマナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県珠洲市唐笠町八ケ山', '17', '17205', '9271444', '石川県', 'イシカワケン', '珠洲市', 'スズシ', '唐笠町八ケ山', 'カラカサマチハッカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県珠洲市唐笠町', '17', '17205', '9271445', '石川県', 'イシカワケン', '珠洲市', 'スズシ', '唐笠町', 'カラカサマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県珠洲市折戸町', '17', '17205', '9271446', '石川県', 'イシカワケン', '珠洲市', 'スズシ', '折戸町', 'オリトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県珠洲市川浦町', '17', '17205', '9271447', '石川県', 'イシカワケン', '珠洲市', 'スズシ', '川浦町', 'カワウラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県珠洲市三崎町寺家', '17', '17205', '9271451', '石川県', 'イシカワケン', '珠洲市', 'スズシ', '三崎町寺家', 'ミサキマチジケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県珠洲市三崎町粟津', '17', '17205', '9271452', '石川県', 'イシカワケン', '珠洲市', 'スズシ', '三崎町粟津', 'ミサキマチアワヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県珠洲市三崎町森腰', '17', '17205', '9271453', '石川県', 'イシカワケン', '珠洲市', 'スズシ', '三崎町森腰', 'ミサキマチモリコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県珠洲市三崎町宇治', '17', '17205', '9271454', '石川県', 'イシカワケン', '珠洲市', 'スズシ', '三崎町宇治', 'ミサキマチウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県珠洲市三崎町引砂', '17', '17205', '9271455', '石川県', 'イシカワケン', '珠洲市', 'スズシ', '三崎町引砂', 'ミサキマチヒキスナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県珠洲市三崎町高波', '17', '17205', '9271456', '石川県', 'イシカワケン', '珠洲市', 'スズシ', '三崎町高波', 'ミサキマチコウナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県珠洲市三崎町大屋', '17', '17205', '9271457', '石川県', 'イシカワケン', '珠洲市', 'スズシ', '三崎町大屋', 'ミサキマチオオヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県珠洲市三崎町伏見', '17', '17205', '9271461', '石川県', 'イシカワケン', '珠洲市', 'スズシ', '三崎町伏見', 'ミサキマチフシミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県珠洲市三崎町小泊', '17', '17205', '9271462', '石川県', 'イシカワケン', '珠洲市', 'スズシ', '三崎町小泊', 'ミサキマチコドマリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県珠洲市三崎町雲津', '17', '17205', '9271463', '石川県', 'イシカワケン', '珠洲市', 'スズシ', '三崎町雲津', 'ミサキマチモヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県珠洲市三崎町細屋', '17', '17205', '9271464', '石川県', 'イシカワケン', '珠洲市', 'スズシ', '三崎町細屋', 'ミサキマチホソヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県珠洲市三崎町二本松', '17', '17205', '9271465', '石川県', 'イシカワケン', '珠洲市', 'スズシ', '三崎町二本松', 'ミサキマチニホンマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県珠洲市三崎町杉山', '17', '17205', '9271466', '石川県', 'イシカワケン', '珠洲市', 'スズシ', '三崎町杉山', 'ミサキマチスギヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県珠洲市三崎町本', '17', '17205', '9271467', '石川県', 'イシカワケン', '珠洲市', 'スズシ', '三崎町本', 'ミサキマチホン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県珠洲市三崎町内方', '17', '17205', '9271468', '石川県', 'イシカワケン', '珠洲市', 'スズシ', '三崎町内方', 'ミサキマチナイホウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町西円山', '17', '17204', '9272101', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町西円山', 'モンゼンマチニシマルヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町浦上', '17', '17204', '9272102', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町浦上', 'モンゼンマチウラカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町八幡', '17', '17204', '9272102', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町八幡', 'モンゼンマチヤワタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町宮古場', '17', '17204', '9272103', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町宮古場', 'モンゼンマチミヤコバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町山辺', '17', '17204', '9272104', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町山辺', 'モンゼンマチヤマベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町田村', '17', '17204', '9272105', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町田村', 'モンゼンマチタムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町浅生田', '17', '17204', '9272106', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町浅生田', 'モンゼンマチアソダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町安代原', '17', '17204', '9272107', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町安代原', 'モンゼンマチアンダイハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町中野屋', '17', '17204', '9272108', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町中野屋', 'モンゼンマチナカノヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町滝上', '17', '17204', '9272111', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町滝上', 'モンゼンマチタキノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町四位', '17', '17204', '9272112', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町四位', 'モンゼンマチシイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町俊兼', '17', '17204', '9272113', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町俊兼', 'モンゼンマチトシカネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町嶺', '17', '17204', '9272113', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町嶺', 'モンゼンマチミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町谷口', '17', '17204', '9272114', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町谷口', 'モンゼンマチタニグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町本内', '17', '17204', '9272115', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町本内', 'モンゼンマチモトウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町貝吹', '17', '17204', '9272121', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町貝吹', 'モンゼンマチカイフキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町原', '17', '17204', '9272122', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町原', 'モンゼンマチハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町荒屋', '17', '17204', '9272123', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町荒屋', 'モンゼンマチアラヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町東大町', '17', '17204', '9272124', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町東大町', 'モンゼンマチヒガシオオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町別所', '17', '17204', '9272125', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町別所', 'モンゼンマチベッショ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町能納屋', '17', '17204', '9272126', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町能納屋', 'モンゼンマチノウノヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町二又川', '17', '17204', '9272127', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町二又川', 'モンゼンマチフタマタガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町平', '17', '17204', '9272131', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町平', 'モンゼンマチタイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町長井坂', '17', '17204', '9272132', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町長井坂', 'モンゼンマチナガイザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町定広', '17', '17204', '9272133', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町定広', 'モンゼンマチサダヒロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町地原', '17', '17204', '9272134', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町地原', 'モンゼンマチチハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町百成', '17', '17204', '9272135', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町百成', 'モンゼンマチドウミキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町鑓川', '17', '17204', '9272136', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町鑓川', 'モンゼンマチヤリカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町内保', '17', '17204', '9272137', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町内保', 'モンゼンマチウチボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町堀腰', '17', '17204', '9272138', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町堀腰', 'モンゼンマチホリコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町小石', '17', '17204', '9272141', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町小石', 'モンゼンマチオイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町上河内', '17', '17204', '9272142', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町上河内', 'モンゼンマチカミガワチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町風原', '17', '17204', '9272143', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町風原', 'モンゼンマチカザハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町猿橋', '17', '17204', '9272144', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町猿橋', 'モンゼンマチサルハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町小滝', '17', '17204', '9272145', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町小滝', 'モンゼンマチコダキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町西中尾', '17', '17204', '9272146', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町西中尾', 'モンゼンマチニシナカオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町鬼屋', '17', '17204', '9272147', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町鬼屋', 'モンゼンマチオニヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町走出', '17', '17204', '9272151', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町走出', 'モンゼンマチハシリデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町広瀬', '17', '17204', '9272152', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町広瀬', 'モンゼンマチヒロセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町深田', '17', '17204', '9272153', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町深田', 'モンゼンマチフカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町栃木', '17', '17204', '9272154', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町栃木', 'モンゼンマチトチノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町日野尾', '17', '17204', '9272155', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町日野尾', 'モンゼンマチヒノオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町門前', '17', '17204', '9272156', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町門前', 'モンゼンマチモンゼン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町六郎木', '17', '17204', '9272161', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町六郎木', 'モンゼンマチロクロギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町勝田', '17', '17204', '9272162', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町勝田', 'モンゼンマチカツタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町大生', '17', '17204', '9272163', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町大生', 'モンゼンマチオハエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町道下', '17', '17204', '9272164', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町道下', 'モンゼンマチトウゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町黒島町', '17', '17204', '9272165', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町黒島町', 'モンゼンマチクロシママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町鹿磯', '17', '17204', '9272166', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町鹿磯', 'モンゼンマチカイソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町深見', '17', '17204', '9272167', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町深見', 'モンゼンマチフカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町本市', '17', '17204', '9272171', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町本市', 'モンゼンマチモトイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町高根尾', '17', '17204', '9272172', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町高根尾', 'モンゼンマチタカネオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町館', '17', '17204', '9272173', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町館', 'モンゼンマチタチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町広岡', '17', '17204', '9272174', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町広岡', 'モンゼンマチヒロオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町清水', '17', '17204', '9272175', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町清水', 'モンゼンマチシミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町和田', '17', '17204', '9272176', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町和田', 'モンゼンマチワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町皆月', '17', '17204', '9272271', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町皆月', 'モンゼンマチミナヅキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町樽見', '17', '17204', '9272272', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町樽見', 'モンゼンマチタルミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町暮坂', '17', '17204', '9272273', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町暮坂', 'モンゼンマチクレサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町井守上坂', '17', '17204', '9272274', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町井守上坂', 'モンゼンマチイモリアゲサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町薄野', '17', '17204', '9272275', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町薄野', 'モンゼンマチススキノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町百成大角間', '17', '17204', '9272276', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町百成大角間', 'モンゼンマチドウミキオオカクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町餅田', '17', '17204', '9272277', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町餅田', 'モンゼンマチモチダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町鵜山', '17', '17204', '9272281', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町鵜山', 'モンゼンマチウヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町大滝', '17', '17204', '9272282', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町大滝', 'モンゼンマチオオタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町中谷内', '17', '17204', '9272283', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町中谷内', 'モンゼンマチナカヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町矢徳', '17', '17204', '9272284', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町矢徳', 'モンゼンマチヤトク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町吉浦', '17', '17204', '9272285', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町吉浦', 'モンゼンマチヨシウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町五十洲', '17', '17204', '9272286', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町五十洲', 'モンゼンマチイギス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町二又', '17', '17204', '9272301', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町二又', 'モンゼンマチフタマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町山是清', '17', '17204', '9272302', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町山是清', 'モンゼンマチヤマコレキヨ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町江崎', '17', '17204', '9272303', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町江崎', 'モンゼンマチエサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町白禿', '17', '17204', '9272304', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町白禿', 'モンゼンマチシラハゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町大切', '17', '17204', '9272305', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町大切', 'モンゼンマチオオギリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町切狭', '17', '17204', '9272311', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町切狭', 'モンゼンマチキリバサミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町西中谷', '17', '17204', '9272312', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町西中谷', 'モンゼンマチニシナカタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町清沢', '17', '17204', '9272313', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町清沢', 'モンゼンマチセイザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町飯川谷', '17', '17204', '9272314', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町飯川谷', 'モンゼンマチイガワダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町久川', '17', '17204', '9272321', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町久川', 'モンゼンマチキュウカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町窕', '17', '17204', '9272322', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町窕', 'モンゼンマチウツロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町神明原', '17', '17204', '9272323', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町神明原', 'モンゼンマチシメハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町馬渡', '17', '17204', '9272324', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町馬渡', 'モンゼンマチマワタリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町滝町', '17', '17204', '9272325', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町滝町', 'モンゼンマチタキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町渡瀬', '17', '17204', '9272331', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町渡瀬', 'モンゼンマチワタセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町木原月', '17', '17204', '9272332', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町木原月', 'モンゼンマチキハラヅキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町館分', '17', '17204', '9272333', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町館分', 'モンゼンマチタチブン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町馬場', '17', '17204', '9272333', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町馬場', 'モンゼンマチバンバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町上代', '17', '17204', '9272334', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町上代', 'モンゼンマチウワダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町黒岩', '17', '17204', '9272335', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町黒岩', 'モンゼンマチクロイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町入山', '17', '17204', '9272336', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町入山', 'モンゼンマチイリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町大釜', '17', '17204', '9272341', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町大釜', 'モンゼンマチオオガマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町剱地', '17', '17204', '9272342', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町剱地', 'モンゼンマチツルギジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町大泊', '17', '17204', '9272343', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町大泊', 'モンゼンマチオオドマリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町腰細', '17', '17204', '9272344', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町腰細', 'モンゼンマチコシボソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町赤神', '17', '17204', '9272345', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町赤神', 'モンゼンマチアカカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町千代', '17', '17204', '9272351', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町千代', 'モンゼンマチセンダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町北川', '17', '17204', '9272352', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町北川', 'モンゼンマチキタガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町是清', '17', '17204', '9272353', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町是清', 'モンゼンマチコレキヨ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町池田', '17', '17204', '9272354', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町池田', 'モンゼンマチイケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町藤浜', '17', '17204', '9272355', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町藤浜', 'モンゼンマチフジノハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町小山', '17', '17204', '9272361', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町小山', 'モンゼンマチコヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町椎木', '17', '17204', '9272362', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町椎木', 'モンゼンマチシイノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町新町分', '17', '17204', '9272363', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町新町分', 'モンゼンマチシンマチブン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町鍛治屋', '17', '17204', '9272364', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町鍛治屋', 'モンゼンマチカジヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町南', '17', '17204', '9272365', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町南', 'モンゼンマチミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市門前町中田', '17', '17204', '9272366', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '門前町中田', 'モンゼンマチナカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市', '17', '17204', '9280000', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('125163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市河井町', '17', '17204', '9280001', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '河井町', 'カワイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市久手川町', '17', '17204', '9280002', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '久手川町', 'フテガワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市塚田町', '17', '17204', '9280003', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '塚田町', 'ツカダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市稲舟町', '17', '17204', '9280004', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '稲舟町', 'イナブネマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市大野町', '17', '17204', '9280005', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '大野町', 'オオノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市惣領町', '17', '17204', '9280006', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '惣領町', 'ソウリョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市深見町', '17', '17204', '9280007', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '深見町', 'フカミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市マリンタウン', '17', '17204', '9280008', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', 'マリンタウン', 'マリンタウン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市杉平町', '17', '17204', '9280011', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '杉平町', 'スギヒラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市横地町', '17', '17204', '9280012', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '横地町', 'ヨコジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市石休場町', '17', '17204', '9280013', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '石休場町', 'イシヤスミバマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市山ノ上町', '17', '17204', '9280014', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '山ノ上町', 'ヤマノウエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市市ノ瀬町', '17', '17204', '9280015', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '市ノ瀬町', 'イチノセマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市熊野町', '17', '17204', '9280016', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '熊野町', 'クマノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市二ツ屋町', '17', '17204', '9280021', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '二ツ屋町', 'フタツヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市宅田町', '17', '17204', '9280022', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '宅田町', 'タクダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市気勝平町', '17', '17204', '9280023', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '気勝平町', 'ケカチダイラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市山岸町', '17', '17204', '9280024', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '山岸町', 'ヤマギシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市東中尾町', '17', '17204', '9280025', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '東中尾町', 'ヒガシナカオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市西脇町', '17', '17204', '9280026', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '西脇町', 'ニシワキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市北谷町', '17', '17204', '9280027', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '北谷町', 'キタダニマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市打越町', '17', '17204', '9280028', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '打越町', 'ウチコシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市二勢町', '17', '17204', '9280031', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '二勢町', 'フタセマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市小伊勢町', '17', '17204', '9280032', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '小伊勢町', 'オイセマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市稲屋町', '17', '17204', '9280033', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '稲屋町', 'トウヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市長井町', '17', '17204', '9280034', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '長井町', 'ナガイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市別所谷町', '17', '17204', '9280035', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '別所谷町', 'ベッショダニマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市滝又町', '17', '17204', '9280036', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '滝又町', 'タキマタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市空熊町', '17', '17204', '9280037', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '空熊町', 'ソラクママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市中段町', '17', '17204', '9280041', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '中段町', 'チュウダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市山本町', '17', '17204', '9280042', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '山本町', 'ヤマモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市房田町', '17', '17204', '9280043', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '房田町', 'フサダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市下黒川町', '17', '17204', '9280044', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '下黒川町', 'シモクロガワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市上黒川町', '17', '17204', '9280045', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '上黒川町', 'カミクロガワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市二俣町', '17', '17204', '9280046', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '二俣町', 'フタマタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市繩又町', '17', '17204', '9280047', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '繩又町', 'ナワマタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市小池町', '17', '17204', '9280051', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '小池町', 'オイケマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市下山町', '17', '17204', '9280052', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '下山町', 'シモヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市赤崎町', '17', '17204', '9280053', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '赤崎町', 'アカサキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市大沢町', '17', '17204', '9280054', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '大沢町', 'オオザワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市上大沢町', '17', '17204', '9280055', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '上大沢町', 'カミオオザワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市西二又町', '17', '17204', '9280056', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '西二又町', 'ニシフタマタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市上山町', '17', '17204', '9280057', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '上山町', 'カミヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市新橋通', '17', '17204', '9280061', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '新橋通', 'シンバシドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市堀町', '17', '17204', '9280062', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '堀町', 'ホリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市南町', '17', '17204', '9280062', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '南町', 'ミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市水守町', '17', '17204', '9280063', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '水守町', 'ミトモリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市釜屋谷町', '17', '17204', '9280064', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '釜屋谷町', 'カマヤダニマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市鵜入町', '17', '17204', '9280065', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '鵜入町', 'ウニュウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市美谷町', '17', '17204', '9280066', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '美谷町', 'ミタニマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市光浦町', '17', '17204', '9280067', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '光浦町', 'ヒカリウラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市平成町', '17', '17204', '9280068', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '平成町', 'ヘイセイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市輪島崎町', '17', '17204', '9280071', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '輪島崎町', 'ワジマザキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市海士町', '17', '17204', '9280072', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '海士町', 'アママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市海士町舳倉島', '17', '17204', '9280072', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '海士町', 'アママチ', null, null, '舳倉島', 'ヘグラジマ');
INSERT INTO `ms_addresses` VALUES ('125218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市鳳至町', '17', '17204', '9280073', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '鳳至町', 'フゲシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市鳳至町袖ケ浜', '17', '17204', '9280073', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '鳳至町', 'フゲシマチ', null, null, '袖ケ浜', 'ソデガハマ');
INSERT INTO `ms_addresses` VALUES ('125220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市鳳至町鳳至丁', '17', '17204', '9280074', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '鳳至町', 'フゲシマチ', null, null, '鳳至丁', 'ホウシチョウ');
INSERT INTO `ms_addresses` VALUES ('125221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市鳳至町下町', '17', '17204', '9280075', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '鳳至町', 'フゲシマチ', null, null, '下町', 'シモマチ');
INSERT INTO `ms_addresses` VALUES ('125222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市鳳至町石浦町', '17', '17204', '9280076', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '鳳至町', 'フゲシマチ', null, null, '石浦町', 'イシウラマチ');
INSERT INTO `ms_addresses` VALUES ('125223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市鳳至町上町', '17', '17204', '9280077', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '鳳至町', 'フゲシマチ', null, null, '上町', 'カミマチ');
INSERT INTO `ms_addresses` VALUES ('125224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市鳳至町堂金田', '17', '17204', '9280077', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '鳳至町', 'フゲシマチ', null, null, '堂金田', 'ドウキンダ');
INSERT INTO `ms_addresses` VALUES ('125225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市鳳至町稲荷町', '17', '17204', '9280078', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '鳳至町', 'フゲシマチ', null, null, '稲荷町', 'イナリマチ');
INSERT INTO `ms_addresses` VALUES ('125226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市鳳至町畠田', '17', '17204', '9280079', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '鳳至町', 'フゲシマチ', null, null, '畠田', 'ハタケダ');
INSERT INTO `ms_addresses` VALUES ('125227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市町野町広江', '17', '17204', '9280201', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '町野町広江', 'マチノマチヒロエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市町野町寺地', '17', '17204', '9280202', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '町野町寺地', 'マチノマチテラジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市町野町敷戸', '17', '17204', '9280203', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '町野町敷戸', 'マチノマチシキド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市町野町南時国', '17', '17204', '9280204', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '町野町南時国', 'マチノマチミナミトキクニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市町野町西時国', '17', '17204', '9280205', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '町野町西時国', 'マチノマチニシトキクニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市町野町曽々木', '17', '17204', '9280206', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '町野町曽々木', 'マチノマチソソギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市町野町牛尾', '17', '17204', '9280211', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '町野町牛尾', 'マチノマチウシオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市町野町寺山', '17', '17204', '9280212', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '町野町寺山', 'マチノマチテラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市町野町舞谷', '17', '17204', '9280213', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '町野町舞谷', 'マチノマチマイダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市町野町佐野', '17', '17204', '9280214', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '町野町佐野', 'マチノマチサノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市町野町粟蔵', '17', '17204', '9280215', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '町野町粟蔵', 'マチノマチアワグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市町野町桶戸', '17', '17204', '9280216', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '町野町桶戸', 'マチノマチオケド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市町野町井面', '17', '17204', '9280217', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '町野町井面', 'マチノマチイノモテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市町野町鈴屋', '17', '17204', '9280218', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '町野町鈴屋', 'マチノマチスズヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市町野町真久', '17', '17204', '9280221', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '町野町真久', 'マチノマチサンサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市町野町東', '17', '17204', '9280222', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '町野町東', 'マチノマチヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市町野町北円山', '17', '17204', '9280223', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '町野町北円山', 'マチノマチキタマルヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市町野町麦生野', '17', '17204', '9280224', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '町野町麦生野', 'マチノマチムギュウノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市町野町徳成谷内', '17', '17204', '9280225', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '町野町徳成谷内', 'マチノマチトクナリヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市町野町徳成', '17', '17204', '9280226', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '町野町徳成', 'マチノマチトクナリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市町野町大川', '17', '17204', '9280231', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '町野町大川', 'マチノマチオオカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市町野町伏戸', '17', '17204', '9280232', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '町野町伏戸', 'マチノマチフセド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市町野町東大野', '17', '17204', '9280233', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '町野町東大野', 'マチノマチヒガシオオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市町野町真喜野', '17', '17204', '9280234', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '町野町真喜野', 'マチノマチマキノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市町野町川西', '17', '17204', '9280235', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '町野町川西', 'マチノマチカワニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市町野町金蔵', '17', '17204', '9280236', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '町野町金蔵', 'マチノマチカナクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市渋田町', '17', '17204', '9280241', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '渋田町', 'シブタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市東印内町', '17', '17204', '9280242', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '東印内町', 'ヒガシインナイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市西山町', '17', '17204', '9280243', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '西山町', 'ニシヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市西院内町', '17', '17204', '9280244', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '西院内町', 'ニシインナイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市東山町', '17', '17204', '9280245', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '東山町', 'ヒガシヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市里町', '17', '17204', '9280246', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '里町', 'サトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市小田屋町', '17', '17204', '9280251', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '小田屋町', 'オダヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市忍町', '17', '17204', '9280252', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '忍町', 'シノブマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市尊利地町', '17', '17204', '9280253', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '尊利地町', 'ソリジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市名舟町', '17', '17204', '9280254', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '名舟町', 'ナフネマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市野田町', '17', '17204', '9280255', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '野田町', 'ノダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市白米町', '17', '17204', '9280256', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '白米町', 'シロヨネマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡能登町上長尾', '17', '17463', '9280301', '石川県', 'イシカワケン', '鳳珠郡能登町', 'ホウスグンノトチョウ', '上長尾', 'カミナガオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡能登町小間生', '17', '17463', '9280302', '石川県', 'イシカワケン', '鳳珠郡能登町', 'ホウスグンノトチョウ', '小間生', 'オモウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡能登町桐畑', '17', '17463', '9280303', '石川県', 'イシカワケン', '鳳珠郡能登町', 'ホウスグンノトチョウ', '桐畑', 'キリハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡能登町鈴ケ嶺', '17', '17463', '9280304', '石川県', 'イシカワケン', '鳳珠郡能登町', 'ホウスグンノトチョウ', '鈴ケ嶺', 'スズガミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡能登町久田', '17', '17463', '9280305', '石川県', 'イシカワケン', '鳳珠郡能登町', 'ホウスグンノトチョウ', '久田', 'キュウデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡能登町石井', '17', '17463', '9280306', '石川県', 'イシカワケン', '鳳珠郡能登町', 'ホウスグンノトチョウ', '石井', 'イシイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡能登町国光', '17', '17463', '9280307', '石川県', 'イシカワケン', '鳳珠郡能登町', 'ホウスグンノトチョウ', '国光', 'クニミツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡能登町鴨川', '17', '17463', '9280308', '石川県', 'イシカワケン', '鳳珠郡能登町', 'ホウスグンノトチョウ', '鴨川', 'カモガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡能登町合鹿', '17', '17463', '9280311', '石川県', 'イシカワケン', '鳳珠郡能登町', 'ホウスグンノトチョウ', '合鹿', 'ゴウロク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡能登町上町', '17', '17463', '9280312', '石川県', 'イシカワケン', '鳳珠郡能登町', 'ホウスグンノトチョウ', '上町', 'カンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡能登町天坂', '17', '17463', '9280313', '石川県', 'イシカワケン', '鳳珠郡能登町', 'ホウスグンノトチョウ', '天坂', 'テンザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡能登町笹川', '17', '17463', '9280314', '石川県', 'イシカワケン', '鳳珠郡能登町', 'ホウスグンノトチョウ', '笹川', 'ササガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡能登町十郎原', '17', '17463', '9280321', '石川県', 'イシカワケン', '鳳珠郡能登町', 'ホウスグンノトチョウ', '十郎原', 'ジュウロバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡能登町寺分', '17', '17463', '9280322', '石川県', 'イシカワケン', '鳳珠郡能登町', 'ホウスグンノトチョウ', '寺分', 'テラブン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡能登町五郎左エ門分', '17', '17463', '9280323', '石川県', 'イシカワケン', '鳳珠郡能登町', 'ホウスグンノトチョウ', '五郎左エ門分', 'ゴロザエモンブン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡能登町中斉', '17', '17463', '9280324', '石川県', 'イシカワケン', '鳳珠郡能登町', 'ホウスグンノトチョウ', '中斉', 'ナカサイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡能登町神和住', '17', '17463', '9280325', '石川県', 'イシカワケン', '鳳珠郡能登町', 'ホウスグンノトチョウ', '神和住', 'カミワスミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡能登町斉和', '17', '17463', '9280326', '石川県', 'イシカワケン', '鳳珠郡能登町', 'ホウスグンノトチョウ', '斉和', 'サイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡能登町柳田', '17', '17463', '9280331', '石川県', 'イシカワケン', '鳳珠郡能登町', 'ホウスグンノトチョウ', '柳田', 'ヤナギダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡能登町五十里', '17', '17463', '9280332', '石川県', 'イシカワケン', '鳳珠郡能登町', 'ホウスグンノトチョウ', '五十里', 'イカリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡能登町黒川', '17', '17463', '9280333', '石川県', 'イシカワケン', '鳳珠郡能登町', 'ホウスグンノトチョウ', '黒川', 'クロカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡能登町当目', '17', '17463', '9280334', '石川県', 'イシカワケン', '鳳珠郡能登町', 'ホウスグンノトチョウ', '当目', 'トウメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡能登町大箱', '17', '17463', '9280335', '石川県', 'イシカワケン', '鳳珠郡能登町', 'ホウスグンノトチョウ', '大箱', 'オオバコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鳳珠郡能登町北河内', '17', '17463', '9280336', '石川県', 'イシカワケン', '鳳珠郡能登町', 'ホウスグンノトチョウ', '北河内', 'キタカワチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県能美市赤井町', '17', '17211', '9290101', '石川県', 'イシカワケン', '能美市', 'ノミシ', '赤井町', 'アカイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県能美市西任田町', '17', '17211', '9290102', '石川県', 'イシカワケン', '能美市', 'ノミシ', '西任田町', 'ニシトウダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県能美市五間堂町', '17', '17211', '9290103', '石川県', 'イシカワケン', '能美市', 'ノミシ', '五間堂町', 'ゴケンドウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県能美市中庄町', '17', '17211', '9290104', '石川県', 'イシカワケン', '能美市', 'ノミシ', '中庄町', 'ナカノショウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県能美市中ノ江町', '17', '17211', '9290105', '石川県', 'イシカワケン', '能美市', 'ノミシ', '中ノ江町', 'ナカノゴウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県能美市西二口町', '17', '17211', '9290106', '石川県', 'イシカワケン', '能美市', 'ノミシ', '西二口町', 'ニシフタクチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県能美市福岡町', '17', '17211', '9290107', '石川県', 'イシカワケン', '能美市', 'ノミシ', '福岡町', 'フクオカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県能美市吉原町', '17', '17211', '9290111', '石川県', 'イシカワケン', '能美市', 'ノミシ', '吉原町', 'ヨシハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県能美市福島町', '17', '17211', '9290112', '石川県', 'イシカワケン', '能美市', 'ノミシ', '福島町', 'フクシママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県能美市大成町', '17', '17211', '9290113', '石川県', 'イシカワケン', '能美市', 'ノミシ', '大成町', 'タイセイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県能美市浜開発町', '17', '17211', '9290114', '石川県', 'イシカワケン', '能美市', 'ノミシ', '浜開発町', 'ハマカイハツマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県能美市下ノ江町', '17', '17211', '9290115', '石川県', 'イシカワケン', '能美市', 'ノミシ', '下ノ江町', 'シモノゴウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県能美市高坂町', '17', '17211', '9290116', '石川県', 'イシカワケン', '能美市', 'ノミシ', '高坂町', 'タカサカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県能美市根上町', '17', '17211', '9290116', '石川県', 'イシカワケン', '能美市', 'ノミシ', '根上町', 'ネアガリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県能美市吉原釜屋町', '17', '17211', '9290121', '石川県', 'イシカワケン', '能美市', 'ノミシ', '吉原釜屋町', 'ヨシハラガマヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県能美市大浜町', '17', '17211', '9290122', '石川県', 'イシカワケン', '能美市', 'ノミシ', '大浜町', 'オオハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県能美市中町', '17', '17211', '9290123', '石川県', 'イシカワケン', '能美市', 'ノミシ', '中町', 'ナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県能美市浜町', '17', '17211', '9290124', '石川県', 'イシカワケン', '能美市', 'ノミシ', '浜町', 'ハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県能美市道林町', '17', '17211', '9290125', '石川県', 'イシカワケン', '能美市', 'ノミシ', '道林町', 'ドウリンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県能美市山口町', '17', '17211', '9290126', '石川県', 'イシカワケン', '能美市', 'ノミシ', '山口町', 'ヤマグチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市鹿島町', '17', '17210', '9290201', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '鹿島町', 'カシママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市西米光町', '17', '17210', '9290202', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '西米光町', 'ニシヨネミツマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市若草町', '17', '17210', '9290203', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '若草町', 'ワカクサマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市平加町', '17', '17210', '9290204', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '平加町', 'ヒラカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市蓮池町', '17', '17210', '9290205', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '蓮池町', 'ハスイケマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市鹿島平', '17', '17210', '9290206', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '鹿島平', 'カシマダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市井関町', '17', '17210', '9290211', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '井関町', 'イセキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市手取町', '17', '17210', '9290212', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '手取町', 'テドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市末正町', '17', '17210', '9290213', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '末正町', 'スエマサマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市長屋町', '17', '17210', '9290214', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '長屋町', 'チョウヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市美川南町', '17', '17210', '9290215', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '美川南町', 'ミカワミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市美川本吉町', '17', '17210', '9290216', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '美川本吉町', 'ミカワモトヨシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市湊町', '17', '17210', '9290217', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '湊町', 'ミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市美川今町', '17', '17210', '9290221', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '美川今町', 'ミカワイママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市美川新町', '17', '17210', '9290222', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '美川新町', 'ミカワシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市美川北町', '17', '17210', '9290223', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '美川北町', 'ミカワキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市美川中町', '17', '17210', '9290224', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '美川中町', 'ミカワナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市美川和波町', '17', '17210', '9290231', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '美川和波町', 'ミカワワナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市美川末広町', '17', '17210', '9290232', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '美川末広町', 'ミカワスエヒロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市美川浜町', '17', '17210', '9290233', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '美川浜町', 'ミカワハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市美川神幸町', '17', '17210', '9290234', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '美川神幸町', 'ミカワジンコウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県白山市美川永代町', '17', '17210', '9290235', '石川県', 'イシカワケン', '白山市', 'ハクサンシ', '美川永代町', 'ミカワエイタイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡津幡町', '17', '17361', '9290300', '石川県', 'イシカワケン', '河北郡津幡町', 'カホクグンツバタマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('125350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡津幡町瓜生', '17', '17361', '9290301', '石川県', 'イシカワケン', '河北郡津幡町', 'カホクグンツバタマチ', '瓜生', 'ウリュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡津幡町木ノ窪', '17', '17361', '9290302', '石川県', 'イシカワケン', '河北郡津幡町', 'カホクグンツバタマチ', '木ノ窪', 'キノクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡津幡町牛首', '17', '17361', '9290303', '石川県', 'イシカワケン', '河北郡津幡町', 'カホクグンツバタマチ', '牛首', 'ウシクビ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡津幡町上河合', '17', '17361', '9290304', '石川県', 'イシカワケン', '河北郡津幡町', 'カホクグンツバタマチ', '上河合', 'カミカワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡津幡町下河合', '17', '17361', '9290305', '石川県', 'イシカワケン', '河北郡津幡町', 'カホクグンツバタマチ', '下河合', 'シモカワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡津幡町興津', '17', '17361', '9290306', '石川県', 'イシカワケン', '河北郡津幡町', 'カホクグンツバタマチ', '興津', 'キョウヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡津幡町種', '17', '17361', '9290307', '石川県', 'イシカワケン', '河北郡津幡町', 'カホクグンツバタマチ', '種', 'タネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡津幡町平野', '17', '17361', '9290307', '石川県', 'イシカワケン', '河北郡津幡町', 'カホクグンツバタマチ', '平野', 'ヒラノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡津幡町菩提寺', '17', '17361', '9290308', '石川県', 'イシカワケン', '河北郡津幡町', 'カホクグンツバタマチ', '菩提寺', 'ボダイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡津幡町上大田', '17', '17361', '9290309', '石川県', 'イシカワケン', '河北郡津幡町', 'カホクグンツバタマチ', '上大田', 'カミオオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡津幡町池ケ原', '17', '17361', '9290311', '石川県', 'イシカワケン', '河北郡津幡町', 'カホクグンツバタマチ', '池ケ原', 'イケガハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡津幡町小熊', '17', '17361', '9290312', '石川県', 'イシカワケン', '河北郡津幡町', 'カホクグンツバタマチ', '小熊', 'コンマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡津幡町中山', '17', '17361', '9290313', '石川県', 'イシカワケン', '河北郡津幡町', 'カホクグンツバタマチ', '中山', 'ナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡津幡町上矢田', '17', '17361', '9290314', '石川県', 'イシカワケン', '河北郡津幡町', 'カホクグンツバタマチ', '上矢田', 'カミヤタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡津幡町下矢田', '17', '17361', '9290315', '石川県', 'イシカワケン', '河北郡津幡町', 'カホクグンツバタマチ', '下矢田', 'シモヤタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡津幡町御門', '17', '17361', '9290316', '石川県', 'イシカワケン', '河北郡津幡町', 'カホクグンツバタマチ', '御門', 'ミカド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡津幡町谷内', '17', '17361', '9290317', '石川県', 'イシカワケン', '河北郡津幡町', 'カホクグンツバタマチ', '谷内', 'ヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡津幡町領家', '17', '17361', '9290318', '石川県', 'イシカワケン', '河北郡津幡町', 'カホクグンツバタマチ', '領家', 'リョウケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡津幡町能瀬', '17', '17361', '9290319', '石川県', 'イシカワケン', '河北郡津幡町', 'カホクグンツバタマチ', '能瀬', 'ノセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡津幡町加茂', '17', '17361', '9290321', '石川県', 'イシカワケン', '河北郡津幡町', 'カホクグンツバタマチ', '加茂', 'カモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡津幡町緑が丘', '17', '17361', '9290322', '石川県', 'イシカワケン', '河北郡津幡町', 'カホクグンツバタマチ', '緑が丘', 'ミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡津幡町津幡', '17', '17361', '9290323', '石川県', 'イシカワケン', '河北郡津幡町', 'カホクグンツバタマチ', '津幡', 'ツバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡津幡町浅田', '17', '17361', '9290324', '石川県', 'イシカワケン', '河北郡津幡町', 'カホクグンツバタマチ', '浅田', 'アサダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡津幡町加賀爪', '17', '17361', '9290325', '石川県', 'イシカワケン', '河北郡津幡町', 'カホクグンツバタマチ', '加賀爪', 'カガツメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡津幡町清水', '17', '17361', '9290326', '石川県', 'イシカワケン', '河北郡津幡町', 'カホクグンツバタマチ', '清水', 'シミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡津幡町庄', '17', '17361', '9290327', '石川県', 'イシカワケン', '河北郡津幡町', 'カホクグンツバタマチ', '庄', 'ショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡津幡町湖東', '17', '17361', '9290328', '石川県', 'イシカワケン', '河北郡津幡町', 'カホクグンツバタマチ', '湖東', 'コトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡津幡町舟橋', '17', '17361', '9290328', '石川県', 'イシカワケン', '河北郡津幡町', 'カホクグンツバタマチ', '舟橋', 'フナバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡津幡町中橋', '17', '17361', '9290331', '石川県', 'イシカワケン', '河北郡津幡町', 'カホクグンツバタマチ', '中橋', 'ナカバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡津幡町中須加', '17', '17361', '9290332', '石川県', 'イシカワケン', '河北郡津幡町', 'カホクグンツバタマチ', '中須加', 'ナカスカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡津幡町五反田', '17', '17361', '9290333', '石川県', 'イシカワケン', '河北郡津幡町', 'カホクグンツバタマチ', '五反田', 'ゴタンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡津幡町川尻', '17', '17361', '9290334', '石川県', 'イシカワケン', '河北郡津幡町', 'カホクグンツバタマチ', '川尻', 'カワシリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡津幡町井上の荘', '17', '17361', '9290335', '石川県', 'イシカワケン', '河北郡津幡町', 'カホクグンツバタマチ', '井上の荘', 'イノウエノショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡津幡町横浜', '17', '17361', '9290341', '石川県', 'イシカワケン', '河北郡津幡町', 'カホクグンツバタマチ', '横浜', 'ヨコハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡津幡町北中条', '17', '17361', '9290342', '石川県', 'イシカワケン', '河北郡津幡町', 'カホクグンツバタマチ', '北中条', 'キタチュウジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡津幡町南中条', '17', '17361', '9290343', '石川県', 'イシカワケン', '河北郡津幡町', 'カホクグンツバタマチ', '南中条', 'ミナミチュウジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡津幡町浅谷', '17', '17361', '9290344', '石川県', 'イシカワケン', '河北郡津幡町', 'カホクグンツバタマチ', '浅谷', 'アサンタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡津幡町太田', '17', '17361', '9290345', '石川県', 'イシカワケン', '河北郡津幡町', 'カホクグンツバタマチ', '太田', 'オオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡津幡町潟端', '17', '17361', '9290346', '石川県', 'イシカワケン', '河北郡津幡町', 'カホクグンツバタマチ', '潟端', 'カタバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡津幡町彦太郎畠', '17', '17361', '9290401', '石川県', 'イシカワケン', '河北郡津幡町', 'カホクグンツバタマチ', '彦太郎畠', 'ヒコタロウバタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡津幡町笠池ケ原', '17', '17361', '9290402', '石川県', 'イシカワケン', '河北郡津幡町', 'カホクグンツバタマチ', '笠池ケ原', 'カサイケガハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡津幡町莇谷', '17', '17361', '9290403', '石川県', 'イシカワケン', '河北郡津幡町', 'カホクグンツバタマチ', '莇谷', 'アザミダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡津幡町大畠', '17', '17361', '9290404', '石川県', 'イシカワケン', '河北郡津幡町', 'カホクグンツバタマチ', '大畠', 'オオバタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡津幡町上野', '17', '17361', '9290405', '石川県', 'イシカワケン', '河北郡津幡町', 'カホクグンツバタマチ', '上野', 'ウワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡津幡町籠月', '17', '17361', '9290406', '石川県', 'イシカワケン', '河北郡津幡町', 'カホクグンツバタマチ', '籠月', 'コモツキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡津幡町鳥屋尾', '17', '17361', '9290407', '石川県', 'イシカワケン', '河北郡津幡町', 'カホクグンツバタマチ', '鳥屋尾', 'トリヤオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡津幡町河内', '17', '17361', '9290411', '石川県', 'イシカワケン', '河北郡津幡町', 'カホクグンツバタマチ', '河内', 'カワチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡津幡町九折', '17', '17361', '9290412', '石川県', 'イシカワケン', '河北郡津幡町', 'カホクグンツバタマチ', '九折', 'ツヅラオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡津幡町倶利伽羅', '17', '17361', '9290413', '石川県', 'イシカワケン', '河北郡津幡町', 'カホクグンツバタマチ', '倶利伽羅', 'クリカラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡津幡町山森', '17', '17361', '9290414', '石川県', 'イシカワケン', '河北郡津幡町', 'カホクグンツバタマチ', '山森', 'ヤマモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡津幡町越中坂', '17', '17361', '9290415', '石川県', 'イシカワケン', '河北郡津幡町', 'カホクグンツバタマチ', '越中坂', 'エッチュウザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡津幡町刈安', '17', '17361', '9290416', '石川県', 'イシカワケン', '河北郡津幡町', 'カホクグンツバタマチ', '刈安', 'カリヤス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡津幡町坂戸', '17', '17361', '9290417', '石川県', 'イシカワケン', '河北郡津幡町', 'カホクグンツバタマチ', '坂戸', 'サカド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡津幡町原', '17', '17361', '9290421', '石川県', 'イシカワケン', '河北郡津幡町', 'カホクグンツバタマチ', '原', 'ハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡津幡町上藤又', '17', '17361', '9290422', '石川県', 'イシカワケン', '河北郡津幡町', 'カホクグンツバタマチ', '上藤又', 'カミフジマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡津幡町下中', '17', '17361', '9290423', '石川県', 'イシカワケン', '河北郡津幡町', 'カホクグンツバタマチ', '下中', 'シモナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡津幡町下藤又', '17', '17361', '9290424', '石川県', 'イシカワケン', '河北郡津幡町', 'カホクグンツバタマチ', '下藤又', 'シモフジマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡津幡町七野', '17', '17361', '9290425', '石川県', 'イシカワケン', '河北郡津幡町', 'カホクグンツバタマチ', '七野', 'シチノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡津幡町竹橋', '17', '17361', '9290426', '石川県', 'イシカワケン', '河北郡津幡町', 'カホクグンツバタマチ', '竹橋', 'タケハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡津幡町富田', '17', '17361', '9290427', '石川県', 'イシカワケン', '河北郡津幡町', 'カホクグンツバタマチ', '富田', 'トミタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡津幡町大窪', '17', '17361', '9290431', '石川県', 'イシカワケン', '河北郡津幡町', 'カホクグンツバタマチ', '大窪', 'オオクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡津幡町北横根', '17', '17361', '9290432', '石川県', 'イシカワケン', '河北郡津幡町', 'カホクグンツバタマチ', '北横根', 'キタヨコネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡津幡町南横根', '17', '17361', '9290433', '石川県', 'イシカワケン', '河北郡津幡町', 'カホクグンツバタマチ', '南横根', 'ミナミヨコネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡津幡町常徳', '17', '17361', '9290434', '石川県', 'イシカワケン', '河北郡津幡町', 'カホクグンツバタマチ', '常徳', 'ジョウトク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡津幡町舟尾', '17', '17361', '9290434', '石川県', 'イシカワケン', '河北郡津幡町', 'カホクグンツバタマチ', '舟尾', 'フナオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡津幡町材木', '17', '17361', '9290435', '石川県', 'イシカワケン', '河北郡津幡町', 'カホクグンツバタマチ', '材木', 'ザイモク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡津幡町朝日畑', '17', '17361', '9290436', '石川県', 'イシカワケン', '河北郡津幡町', 'カホクグンツバタマチ', '朝日畑', 'アサヒバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡津幡町相窪', '17', '17361', '9290437', '石川県', 'イシカワケン', '河北郡津幡町', 'カホクグンツバタマチ', '相窪', 'アイクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡津幡町東荒屋', '17', '17361', '9290441', '石川県', 'イシカワケン', '河北郡津幡町', 'カホクグンツバタマチ', '東荒屋', 'ヒガシアラヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡津幡町大坪', '17', '17361', '9290442', '石川県', 'イシカワケン', '河北郡津幡町', 'カホクグンツバタマチ', '大坪', 'オオツボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡津幡町別所', '17', '17361', '9290443', '石川県', 'イシカワケン', '河北郡津幡町', 'カホクグンツバタマチ', '別所', 'ベッショ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡津幡町仮生', '17', '17361', '9290444', '石川県', 'イシカワケン', '河北郡津幡町', 'カホクグンツバタマチ', '仮生', 'ケショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡津幡町井野河内', '17', '17361', '9290445', '石川県', 'イシカワケン', '河北郡津幡町', 'カホクグンツバタマチ', '井野河内', 'イノカワチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡津幡町明神', '17', '17361', '9290446', '石川県', 'イシカワケン', '河北郡津幡町', 'カホクグンツバタマチ', '明神', 'ミョウジン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡津幡町旭山', '17', '17361', '9290447', '石川県', 'イシカワケン', '河北郡津幡町', 'カホクグンツバタマチ', '旭山', 'アサヒヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡津幡町宮田', '17', '17361', '9290451', '石川県', 'イシカワケン', '河北郡津幡町', 'カホクグンツバタマチ', '宮田', 'ミヤダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡津幡町田屋', '17', '17361', '9290452', '石川県', 'イシカワケン', '河北郡津幡町', 'カホクグンツバタマチ', '田屋', 'タヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡津幡町岩崎', '17', '17361', '9290453', '石川県', 'イシカワケン', '河北郡津幡町', 'カホクグンツバタマチ', '岩崎', 'イワサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡津幡町杉瀬', '17', '17361', '9290454', '石川県', 'イシカワケン', '河北郡津幡町', 'カホクグンツバタマチ', '杉瀬', 'スギノセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡津幡町倉見', '17', '17361', '9290455', '石川県', 'イシカワケン', '河北郡津幡町', 'カホクグンツバタマチ', '倉見', 'クラミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡津幡町七黒', '17', '17361', '9290456', '石川県', 'イシカワケン', '河北郡津幡町', 'カホクグンツバタマチ', '七黒', 'シチクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡津幡町八ノ谷', '17', '17361', '9290461', '石川県', 'イシカワケン', '河北郡津幡町', 'カホクグンツバタマチ', '八ノ谷', 'ハチノタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡津幡町市谷', '17', '17361', '9290462', '石川県', 'イシカワケン', '河北郡津幡町', 'カホクグンツバタマチ', '市谷', 'イチノタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡津幡町蓮花寺', '17', '17361', '9290463', '石川県', 'イシカワケン', '河北郡津幡町', 'カホクグンツバタマチ', '蓮花寺', 'レンゲジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡津幡町山北', '17', '17361', '9290464', '石川県', 'イシカワケン', '河北郡津幡町', 'カホクグンツバタマチ', '山北', 'ヤマキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡津幡町鳥越', '17', '17361', '9290465', '石川県', 'イシカワケン', '河北郡津幡町', 'カホクグンツバタマチ', '鳥越', 'トリゴエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡津幡町吉倉', '17', '17361', '9290466', '石川県', 'イシカワケン', '河北郡津幡町', 'カホクグンツバタマチ', '吉倉', 'ヨシクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県河北郡津幡町大熊', '17', '17361', '9290467', '石川県', 'イシカワケン', '河北郡津幡町', 'カホクグンツバタマチ', '大熊', 'オンマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県かほく市', '17', '17209', '9291100', '石川県', 'イシカワケン', 'かほく市', 'カホクシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('125445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県かほく市余地', '17', '17209', '9291101', '石川県', 'イシカワケン', 'かほく市', 'カホクシ', '余地', 'ヨチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県かほく市上田名', '17', '17209', '9291102', '石川県', 'イシカワケン', 'かほく市', 'カホクシ', '上田名', 'ウワダナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県かほく市谷', '17', '17209', '9291103', '石川県', 'イシカワケン', 'かほく市', 'カホクシ', '谷', 'タニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県かほく市笠島', '17', '17209', '9291104', '石川県', 'イシカワケン', 'かほく市', 'カホクシ', '笠島', 'カサシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県かほく市横山', '17', '17209', '9291105', '石川県', 'イシカワケン', 'かほく市', 'カホクシ', '横山', 'ヨコヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県かほく市気屋', '17', '17209', '9291111', '石川県', 'イシカワケン', 'かほく市', 'カホクシ', '気屋', 'キヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県かほく市多田', '17', '17209', '9291112', '石川県', 'イシカワケン', 'かほく市', 'カホクシ', '多田', 'タダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県かほく市指江', '17', '17209', '9291113', '石川県', 'イシカワケン', 'かほく市', 'カホクシ', '指江', 'サシエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県かほく市狩鹿野', '17', '17209', '9291114', '石川県', 'イシカワケン', 'かほく市', 'カホクシ', '狩鹿野', 'カルガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県かほく市上山田', '17', '17209', '9291115', '石川県', 'イシカワケン', 'かほく市', 'カホクシ', '上山田', 'カミヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県かほく市下山田', '17', '17209', '9291116', '石川県', 'イシカワケン', 'かほく市', 'カホクシ', '下山田', 'シモヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県かほく市鉢伏', '17', '17209', '9291117', '石川県', 'イシカワケン', 'かほく市', 'カホクシ', '鉢伏', 'ハチブセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県かほく市宇気', '17', '17209', '9291121', '石川県', 'イシカワケン', 'かほく市', 'カホクシ', '宇気', 'ウケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県かほく市七窪', '17', '17209', '9291122', '石川県', 'イシカワケン', 'かほく市', 'カホクシ', '七窪', 'ナナクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県かほく市森', '17', '17209', '9291123', '石川県', 'イシカワケン', 'かほく市', 'カホクシ', '森', 'モリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県かほく市宇野気', '17', '17209', '9291125', '石川県', 'イシカワケン', 'かほく市', 'カホクシ', '宇野気', 'ウノケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県かほく市内日角', '17', '17209', '9291126', '石川県', 'イシカワケン', 'かほく市', 'カホクシ', '内日角', 'ウチヒスミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県かほく市大崎', '17', '17209', '9291127', '石川県', 'イシカワケン', 'かほく市', 'カホクシ', '大崎', 'オオサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県かほく市木津', '17', '17209', '9291171', '石川県', 'イシカワケン', 'かほく市', 'カホクシ', '木津', 'キヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県かほく市松浜', '17', '17209', '9291172', '石川県', 'イシカワケン', 'かほく市', 'カホクシ', '松浜', 'マツハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県かほく市遠塚', '17', '17209', '9291173', '石川県', 'イシカワケン', 'かほく市', 'カホクシ', '遠塚', 'トオヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県かほく市浜北', '17', '17209', '9291174', '石川県', 'イシカワケン', 'かほく市', 'カホクシ', '浜北', 'ハマキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県かほく市秋浜', '17', '17209', '9291175', '石川県', 'イシカワケン', 'かほく市', 'カホクシ', '秋浜', 'アキハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県かほく市外日角', '17', '17209', '9291176', '石川県', 'イシカワケン', 'かほく市', 'カホクシ', '外日角', 'ソトヒスミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県かほく市白尾', '17', '17209', '9291177', '石川県', 'イシカワケン', 'かほく市', 'カホクシ', '白尾', 'シロオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県かほく市野寺', '17', '17209', '9291201', '石川県', 'イシカワケン', 'かほく市', 'カホクシ', '野寺', 'ノデラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県かほく市八野', '17', '17209', '9291202', '石川県', 'イシカワケン', 'かほく市', 'カホクシ', '八野', 'ハチノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県かほく市黒川', '17', '17209', '9291203', '石川県', 'イシカワケン', 'かほく市', 'カホクシ', '黒川', 'クロガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県かほく市箕打', '17', '17209', '9291204', '石川県', 'イシカワケン', 'かほく市', 'カホクシ', '箕打', 'ミウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県かほく市若緑', '17', '17209', '9291205', '石川県', 'イシカワケン', 'かほく市', 'カホクシ', '若緑', 'ワカミドリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県かほく市元女', '17', '17209', '9291206', '石川県', 'イシカワケン', 'かほく市', 'カホクシ', '元女', 'ガンニョ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県かほく市夏栗', '17', '17209', '9291207', '石川県', 'イシカワケン', 'かほく市', 'カホクシ', '夏栗', 'ナツグリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県かほく市瀬戸町', '17', '17209', '9291208', '石川県', 'イシカワケン', 'かほく市', 'カホクシ', '瀬戸町', 'セトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県かほく市学園台', '17', '17209', '9291210', '石川県', 'イシカワケン', 'かほく市', 'カホクシ', '学園台', 'ガクエンダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県かほく市二ツ屋', '17', '17209', '9291211', '石川県', 'イシカワケン', 'かほく市', 'カホクシ', '二ツ屋', 'フタツヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県かほく市中沼', '17', '17209', '9291212', '石川県', 'イシカワケン', 'かほく市', 'カホクシ', '中沼', 'ナカヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県かほく市長柄町', '17', '17209', '9291213', '石川県', 'イシカワケン', 'かほく市', 'カホクシ', '長柄町', 'ナガラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県かほく市内高松', '17', '17209', '9291214', '石川県', 'イシカワケン', 'かほく市', 'カホクシ', '内高松', 'ウチタカマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県かほく市高松', '17', '17209', '9291215', '石川県', 'イシカワケン', 'かほく市', 'カホクシ', '高松', 'タカマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡宝達志水町', '17', '17386', '9291300', '石川県', 'イシカワケン', '羽咋郡宝達志水町', 'ハクイグンホウダツシミズチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('125492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡宝達志水町宝達', '17', '17386', '9291301', '石川県', 'イシカワケン', '羽咋郡宝達志水町', 'ハクイグンホウダツシミズチョウ', '宝達', 'ホウダツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡宝達志水町山崎', '17', '17386', '9291302', '石川県', 'イシカワケン', '羽咋郡宝達志水町', 'ハクイグンホウダツシミズチョウ', '山崎', 'ヤマザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡宝達志水町河原', '17', '17386', '9291303', '石川県', 'イシカワケン', '羽咋郡宝達志水町', 'ハクイグンホウダツシミズチョウ', '河原', 'カワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡宝達志水町南吉田', '17', '17386', '9291304', '石川県', 'イシカワケン', '羽咋郡宝達志水町', 'ハクイグンホウダツシミズチョウ', '南吉田', 'ミナミヨシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡宝達志水町竹生野', '17', '17386', '9291305', '石川県', 'イシカワケン', '羽咋郡宝達志水町', 'ハクイグンホウダツシミズチョウ', '竹生野', 'タコノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡宝達志水町門前', '17', '17386', '9291311', '石川県', 'イシカワケン', '羽咋郡宝達志水町', 'ハクイグンホウダツシミズチョウ', '門前', 'モンゼン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡宝達志水町上田', '17', '17386', '9291312', '石川県', 'イシカワケン', '羽咋郡宝達志水町', 'ハクイグンホウダツシミズチョウ', '上田', 'ウワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡宝達志水町東間', '17', '17386', '9291313', '石川県', 'イシカワケン', '羽咋郡宝達志水町', 'ハクイグンホウダツシミズチョウ', '東間', 'アズマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡宝達志水町紺屋町', '17', '17386', '9291314', '石川県', 'イシカワケン', '羽咋郡宝達志水町', 'ハクイグンホウダツシミズチョウ', '紺屋町', 'コンヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡宝達志水町東野', '17', '17386', '9291315', '石川県', 'イシカワケン', '羽咋郡宝達志水町', 'ハクイグンホウダツシミズチョウ', '東野', 'ヒガシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡宝達志水町中野', '17', '17386', '9291316', '石川県', 'イシカワケン', '羽咋郡宝達志水町', 'ハクイグンホウダツシミズチョウ', '中野', 'ナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡宝達志水町上田出', '17', '17386', '9291321', '石川県', 'イシカワケン', '羽咋郡宝達志水町', 'ハクイグンホウダツシミズチョウ', '上田出', 'ウワダデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡宝達志水町三日町', '17', '17386', '9291322', '石川県', 'イシカワケン', '羽咋郡宝達志水町', 'ハクイグンホウダツシミズチョウ', '三日町', 'ミッカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡宝達志水町御舘', '17', '17386', '9291323', '石川県', 'イシカワケン', '羽咋郡宝達志水町', 'ハクイグンホウダツシミズチョウ', '御舘', 'オタチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡宝達志水町正友', '17', '17386', '9291324', '石川県', 'イシカワケン', '羽咋郡宝達志水町', 'ハクイグンホウダツシミズチョウ', '正友', 'マサトモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡宝達志水町坪山', '17', '17386', '9291325', '石川県', 'イシカワケン', '羽咋郡宝達志水町', 'ハクイグンホウダツシミズチョウ', '坪山', 'ツボヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡宝達志水町冬野', '17', '17386', '9291326', '石川県', 'イシカワケン', '羽咋郡宝達志水町', 'ハクイグンホウダツシミズチョウ', '冬野', 'フユノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡宝達志水町森本', '17', '17386', '9291327', '石川県', 'イシカワケン', '羽咋郡宝達志水町', 'ハクイグンホウダツシミズチョウ', '森本', 'モリモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡宝達志水町米出', '17', '17386', '9291331', '石川県', 'イシカワケン', '羽咋郡宝達志水町', 'ハクイグンホウダツシミズチョウ', '米出', 'コメダシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡宝達志水町北川尻', '17', '17386', '9291332', '石川県', 'イシカワケン', '羽咋郡宝達志水町', 'ハクイグンホウダツシミズチョウ', '北川尻', 'キタカワシリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡宝達志水町免田', '17', '17386', '9291333', '石川県', 'イシカワケン', '羽咋郡宝達志水町', 'ハクイグンホウダツシミズチョウ', '免田', 'メンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡宝達志水町宿', '17', '17386', '9291341', '石川県', 'イシカワケン', '羽咋郡宝達志水町', 'ハクイグンホウダツシミズチョウ', '宿', 'シュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡宝達志水町麦生', '17', '17386', '9291342', '石川県', 'イシカワケン', '羽咋郡宝達志水町', 'ハクイグンホウダツシミズチョウ', '麦生', 'ムギウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡宝達志水町小川', '17', '17386', '9291343', '石川県', 'イシカワケン', '羽咋郡宝達志水町', 'ハクイグンホウダツシミズチョウ', '小川', 'オガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡宝達志水町今浜', '17', '17386', '9291344', '石川県', 'イシカワケン', '羽咋郡宝達志水町', 'ハクイグンホウダツシミズチョウ', '今浜', 'イマハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡宝達志水町今浜新', '17', '17386', '9291345', '石川県', 'イシカワケン', '羽咋郡宝達志水町', 'ハクイグンホウダツシミズチョウ', '今浜新', 'イマハマシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡宝達志水町向瀬', '17', '17386', '9291401', '石川県', 'イシカワケン', '羽咋郡宝達志水町', 'ハクイグンホウダツシミズチョウ', '向瀬', 'ムコセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡宝達志水町清水原', '17', '17386', '9291402', '石川県', 'イシカワケン', '羽咋郡宝達志水町', 'ハクイグンホウダツシミズチョウ', '清水原', 'シミズバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡宝達志水町走入', '17', '17386', '9291402', '石川県', 'イシカワケン', '羽咋郡宝達志水町', 'ハクイグンホウダツシミズチョウ', '走入', 'ハシリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡宝達志水町見砂', '17', '17386', '9291402', '石川県', 'イシカワケン', '羽咋郡宝達志水町', 'ハクイグンホウダツシミズチョウ', '見砂', 'ミサゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡宝達志水町所司原', '17', '17386', '9291403', '石川県', 'イシカワケン', '羽咋郡宝達志水町', 'ハクイグンホウダツシミズチョウ', '所司原', 'ショシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡宝達志水町新宮', '17', '17386', '9291404', '石川県', 'イシカワケン', '羽咋郡宝達志水町', 'ハクイグンホウダツシミズチョウ', '新宮', 'シングウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡宝達志水町当熊', '17', '17386', '9291404', '石川県', 'イシカワケン', '羽咋郡宝達志水町', 'ハクイグンホウダツシミズチョウ', '当熊', 'トウノクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡宝達志水町原', '17', '17386', '9291404', '石川県', 'イシカワケン', '羽咋郡宝達志水町', 'ハクイグンホウダツシミズチョウ', '原', 'ハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡宝達志水町海老坂', '17', '17386', '9291405', '石川県', 'イシカワケン', '羽咋郡宝達志水町', 'ハクイグンホウダツシミズチョウ', '海老坂', 'エビサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡宝達志水町針山', '17', '17386', '9291405', '石川県', 'イシカワケン', '羽咋郡宝達志水町', 'ハクイグンホウダツシミズチョウ', '針山', 'ハリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡宝達志水町聖川', '17', '17386', '9291405', '石川県', 'イシカワケン', '羽咋郡宝達志水町', 'ハクイグンホウダツシミズチョウ', '聖川', 'ヒジリカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡宝達志水町平床', '17', '17386', '9291405', '石川県', 'イシカワケン', '羽咋郡宝達志水町', 'ハクイグンホウダツシミズチョウ', '平床', 'ヒラトコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡宝達志水町石坂', '17', '17386', '9291406', '石川県', 'イシカワケン', '羽咋郡宝達志水町', 'ハクイグンホウダツシミズチョウ', '石坂', 'イシサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡宝達志水町下石', '17', '17386', '9291406', '石川県', 'イシカワケン', '羽咋郡宝達志水町', 'ハクイグンホウダツシミズチョウ', '下石', 'サガリシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡宝達志水町散田', '17', '17386', '9291406', '石川県', 'イシカワケン', '羽咋郡宝達志水町', 'ハクイグンホウダツシミズチョウ', '散田', 'サンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡宝達志水町柳瀬', '17', '17386', '9291411', '石川県', 'イシカワケン', '羽咋郡宝達志水町', 'ハクイグンホウダツシミズチョウ', '柳瀬', 'ヤナセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡宝達志水町荻島', '17', '17386', '9291412', '石川県', 'イシカワケン', '羽咋郡宝達志水町', 'ハクイグンホウダツシミズチョウ', '荻島', 'オギノシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡宝達志水町荻谷', '17', '17386', '9291413', '石川県', 'イシカワケン', '羽咋郡宝達志水町', 'ハクイグンホウダツシミズチョウ', '荻谷', 'オギノヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡宝達志水町敷波', '17', '17386', '9291414', '石川県', 'イシカワケン', '羽咋郡宝達志水町', 'ハクイグンホウダツシミズチョウ', '敷波', 'シキナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡宝達志水町敷浪', '17', '17386', '9291415', '石川県', 'イシカワケン', '羽咋郡宝達志水町', 'ハクイグンホウダツシミズチョウ', '敷浪', 'シキナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡宝達志水町出浜', '17', '17386', '9291416', '石川県', 'イシカワケン', '羽咋郡宝達志水町', 'ハクイグンホウダツシミズチョウ', '出浜', 'デハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡宝達志水町二口', '17', '17386', '9291421', '石川県', 'イシカワケン', '羽咋郡宝達志水町', 'ハクイグンホウダツシミズチョウ', '二口', 'フタクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡宝達志水町杉野屋', '17', '17386', '9291422', '石川県', 'イシカワケン', '羽咋郡宝達志水町', 'ハクイグンホウダツシミズチョウ', '杉野屋', 'スギノヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡宝達志水町菅原', '17', '17386', '9291423', '石川県', 'イシカワケン', '羽咋郡宝達志水町', 'ハクイグンホウダツシミズチョウ', '菅原', 'スガハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡宝達志水町吉野屋', '17', '17386', '9291424', '石川県', 'イシカワケン', '羽咋郡宝達志水町', 'ハクイグンホウダツシミズチョウ', '吉野屋', 'ヨシノヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡宝達志水町子浦', '17', '17386', '9291425', '石川県', 'イシカワケン', '羽咋郡宝達志水町', 'ハクイグンホウダツシミズチョウ', '子浦', 'シオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡宝達志水町荻市', '17', '17386', '9291426', '石川県', 'イシカワケン', '羽咋郡宝達志水町', 'ハクイグンホウダツシミズチョウ', '荻市', 'オギチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鹿島郡中能登町金丸', '17', '17407', '9291521', '石川県', 'イシカワケン', '鹿島郡中能登町', 'カシマグンナカノトマチ', '金丸', 'カネマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋市下曽祢町', '17', '17207', '9291571', '石川県', 'イシカワケン', '羽咋市', 'ハクイシ', '下曽祢町', 'シモソネマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋市大町', '17', '17207', '9291572', '石川県', 'イシカワケン', '羽咋市', 'ハクイシ', '大町', 'オオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋市四柳町', '17', '17207', '9291573', '石川県', 'イシカワケン', '羽咋市', 'ハクイシ', '四柳町', 'ヨツヤナギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋市酒井町', '17', '17207', '9291574', '石川県', 'イシカワケン', '羽咋市', 'ハクイシ', '酒井町', 'サカイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋市金丸出町', '17', '17207', '9291575', '石川県', 'イシカワケン', '羽咋市', 'ハクイシ', '金丸出町', 'カネマルデマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋市鹿島路町', '17', '17207', '9291576', '石川県', 'イシカワケン', '羽咋市', 'ハクイシ', '鹿島路町', 'カシマジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋市東潟町', '17', '17207', '9291577', '石川県', 'イシカワケン', '羽咋市', 'ハクイシ', '東潟町', 'ヒガシカタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鹿島郡中能登町西馬場', '17', '17407', '9291601', '石川県', 'イシカワケン', '鹿島郡中能登町', 'カシマグンナカノトマチ', '西馬場', 'ニシババ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鹿島郡中能登町能登部上', '17', '17407', '9291602', '石川県', 'イシカワケン', '鹿島郡中能登町', 'カシマグンナカノトマチ', '能登部上', 'ノトベカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鹿島郡中能登町徳丸', '17', '17407', '9291603', '石川県', 'イシカワケン', '鹿島郡中能登町', 'カシマグンナカノトマチ', '徳丸', 'トクマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鹿島郡中能登町能登部下', '17', '17407', '9291604', '石川県', 'イシカワケン', '鹿島郡中能登町', 'カシマグンナカノトマチ', '能登部下', 'ノトベシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鹿島郡中能登町下後山', '17', '17407', '9291605', '石川県', 'イシカワケン', '鹿島郡中能登町', 'カシマグンナカノトマチ', '下後山', 'シモウシロヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鹿島郡中能登町上後山', '17', '17407', '9291606', '石川県', 'イシカワケン', '鹿島郡中能登町', 'カシマグンナカノトマチ', '上後山', 'カミウシロヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鹿島郡中能登町久江', '17', '17407', '9291631', '石川県', 'イシカワケン', '鹿島郡中能登町', 'カシマグンナカノトマチ', '久江', 'クエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鹿島郡中能登町小田中', '17', '17407', '9291632', '石川県', 'イシカワケン', '鹿島郡中能登町', 'カシマグンナカノトマチ', '小田中', 'コダナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鹿島郡中能登町藤井', '17', '17407', '9291633', '石川県', 'イシカワケン', '鹿島郡中能登町', 'カシマグンナカノトマチ', '藤井', 'フジイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鹿島郡中能登町福田', '17', '17407', '9291634', '石川県', 'イシカワケン', '鹿島郡中能登町', 'カシマグンナカノトマチ', '福田', 'フクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鹿島郡中能登町高畠', '17', '17407', '9291635', '石川県', 'イシカワケン', '鹿島郡中能登町', 'カシマグンナカノトマチ', '高畠', 'タカバタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鹿島郡中能登町小金森', '17', '17407', '9291636', '石川県', 'イシカワケン', '鹿島郡中能登町', 'カシマグンナカノトマチ', '小金森', 'コガネモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鹿島郡中能登町曽祢', '17', '17407', '9291637', '石川県', 'イシカワケン', '鹿島郡中能登町', 'カシマグンナカノトマチ', '曽祢', 'ソネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鹿島郡中能登町', '17', '17407', '9291700', '石川県', 'イシカワケン', '鹿島郡中能登町', 'カシマグンナカノトマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('125577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鹿島郡中能登町川田', '17', '17407', '9291701', '石川県', 'イシカワケン', '鹿島郡中能登町', 'カシマグンナカノトマチ', '川田', 'カワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鹿島郡中能登町大槻', '17', '17407', '9291702', '石川県', 'イシカワケン', '鹿島郡中能登町', 'カシマグンナカノトマチ', '大槻', 'オオヅキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鹿島郡中能登町春木', '17', '17407', '9291703', '石川県', 'イシカワケン', '鹿島郡中能登町', 'カシマグンナカノトマチ', '春木', 'ハルキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鹿島郡中能登町末坂', '17', '17407', '9291704', '石川県', 'イシカワケン', '鹿島郡中能登町', 'カシマグンナカノトマチ', '末坂', 'スエザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鹿島郡中能登町花見月', '17', '17407', '9291705', '石川県', 'イシカワケン', '鹿島郡中能登町', 'カシマグンナカノトマチ', '花見月', 'ハナミツキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鹿島郡中能登町瀬戸', '17', '17407', '9291706', '石川県', 'イシカワケン', '鹿島郡中能登町', 'カシマグンナカノトマチ', '瀬戸', 'セト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鹿島郡中能登町廿九日', '17', '17407', '9291711', '石川県', 'イシカワケン', '鹿島郡中能登町', 'カシマグンナカノトマチ', '廿九日', 'ヒズメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鹿島郡中能登町新庄', '17', '17407', '9291712', '石川県', 'イシカワケン', '鹿島郡中能登町', 'カシマグンナカノトマチ', '新庄', 'シンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鹿島郡中能登町今羽坂', '17', '17407', '9291713', '石川県', 'イシカワケン', '鹿島郡中能登町', 'カシマグンナカノトマチ', '今羽坂', 'イマハザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鹿島郡中能登町羽坂', '17', '17407', '9291714', '石川県', 'イシカワケン', '鹿島郡中能登町', 'カシマグンナカノトマチ', '羽坂', 'ハザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鹿島郡中能登町一青', '17', '17407', '9291715', '石川県', 'イシカワケン', '鹿島郡中能登町', 'カシマグンナカノトマチ', '一青', 'ヒトト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鹿島郡中能登町黒氏', '17', '17407', '9291716', '石川県', 'イシカワケン', '鹿島郡中能登町', 'カシマグンナカノトマチ', '黒氏', 'クロジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鹿島郡中能登町良川', '17', '17407', '9291717', '石川県', 'イシカワケン', '鹿島郡中能登町', 'カシマグンナカノトマチ', '良川', 'ヨシカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鹿島郡中能登町井田', '17', '17407', '9291721', '石川県', 'イシカワケン', '鹿島郡中能登町', 'カシマグンナカノトマチ', '井田', 'イダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鹿島郡中能登町小竹', '17', '17407', '9291722', '石川県', 'イシカワケン', '鹿島郡中能登町', 'カシマグンナカノトマチ', '小竹', 'オダケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鹿島郡中能登町水白', '17', '17407', '9291723', '石川県', 'イシカワケン', '鹿島郡中能登町', 'カシマグンナカノトマチ', '水白', 'ミジロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鹿島郡中能登町尾崎', '17', '17407', '9291724', '石川県', 'イシカワケン', '鹿島郡中能登町', 'カシマグンナカノトマチ', '尾崎', 'オサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鹿島郡中能登町東馬場', '17', '17407', '9291725', '石川県', 'イシカワケン', '鹿島郡中能登町', 'カシマグンナカノトマチ', '東馬場', 'ヒガシババ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鹿島郡中能登町最勝講', '17', '17407', '9291726', '石川県', 'イシカワケン', '鹿島郡中能登町', 'カシマグンナカノトマチ', '最勝講', 'サイスコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鹿島郡中能登町久乃木', '17', '17407', '9291801', '石川県', 'イシカワケン', '鹿島郡中能登町', 'カシマグンナカノトマチ', '久乃木', 'クノギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鹿島郡中能登町武部', '17', '17407', '9291802', '石川県', 'イシカワケン', '鹿島郡中能登町', 'カシマグンナカノトマチ', '武部', 'タケベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鹿島郡中能登町西', '17', '17407', '9291803', '石川県', 'イシカワケン', '鹿島郡中能登町', 'カシマグンナカノトマチ', '西', 'ニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鹿島郡中能登町在江', '17', '17407', '9291804', '石川県', 'イシカワケン', '鹿島郡中能登町', 'カシマグンナカノトマチ', '在江', 'アルエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鹿島郡中能登町坪川', '17', '17407', '9291805', '石川県', 'イシカワケン', '鹿島郡中能登町', 'カシマグンナカノトマチ', '坪川', 'ツボカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鹿島郡中能登町二宮', '17', '17407', '9291811', '石川県', 'イシカワケン', '鹿島郡中能登町', 'カシマグンナカノトマチ', '二宮', 'ニノミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鹿島郡中能登町石動山', '17', '17407', '9291812', '石川県', 'イシカワケン', '鹿島郡中能登町', 'カシマグンナカノトマチ', '石動山', 'セキドウサン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鹿島郡中能登町蟻ケ原', '17', '17407', '9291813', '石川県', 'イシカワケン', '鹿島郡中能登町', 'カシマグンナカノトマチ', '蟻ケ原', 'アリガハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鹿島郡中能登町原山', '17', '17407', '9291814', '石川県', 'イシカワケン', '鹿島郡中能登町', 'カシマグンナカノトマチ', '原山', 'ハラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鹿島郡中能登町芹川', '17', '17407', '9291815', '石川県', 'イシカワケン', '鹿島郡中能登町', 'カシマグンナカノトマチ', '芹川', 'セリカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鹿島郡中能登町浅井', '17', '17407', '9291816', '石川県', 'イシカワケン', '鹿島郡中能登町', 'カシマグンナカノトマチ', '浅井', 'アサイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鹿島郡中能登町徳前', '17', '17407', '9291817', '石川県', 'イシカワケン', '鹿島郡中能登町', 'カシマグンナカノトマチ', '徳前', 'トクゼン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県鹿島郡中能登町二宮あおば台', '17', '17407', '9291818', '石川県', 'イシカワケン', '鹿島郡中能登町', 'カシマグンナカノトマチ', '二宮あおば台', 'ニノミヤアオバダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市川尻町', '17', '17202', '9292101', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '川尻町', 'カワシリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市舟尾町', '17', '17202', '9292102', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '舟尾町', 'フノオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市東山町', '17', '17202', '9292103', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '東山町', 'ヒガシヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市垣吉町', '17', '17202', '9292104', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '垣吉町', 'カキヨシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市新屋町', '17', '17202', '9292105', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '新屋町', 'アラヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市高田町', '17', '17202', '9292111', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '高田町', 'タカタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市杉森町', '17', '17202', '9292112', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '杉森町', 'スギモリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市西下町', '17', '17202', '9292113', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '西下町', 'ニシシモマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市伊久留町', '17', '17202', '9292114', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '伊久留町', 'イクロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市七原町', '17', '17202', '9292115', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '七原町', 'シツハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市吉田町', '17', '17202', '9292116', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '吉田町', 'ヨシタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市田鶴浜町', '17', '17202', '9292121', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '田鶴浜町', 'タツルハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市上野ケ丘町', '17', '17202', '9292122', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '上野ケ丘町', 'ウワノガオカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市三引町', '17', '17202', '9292123', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '三引町', 'ミビキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市白浜町', '17', '17202', '9292124', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '白浜町', 'シラハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市深見町', '17', '17202', '9292125', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '深見町', 'フカミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市大津町', '17', '17202', '9292126', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '大津町', 'オオツマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市中島町河内', '17', '17202', '9292201', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '中島町河内', 'ナカジママチカワチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市中島町別所', '17', '17202', '9292202', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '中島町別所', 'ナカジママチベッショ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市中島町北免田', '17', '17202', '9292203', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '中島町北免田', 'ナカジママチキタメンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市中島町上畠', '17', '17202', '9292204', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '中島町上畠', 'ナカジママチウワバタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市中島町町屋', '17', '17202', '9292205', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '中島町町屋', 'ナカジママチマチヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市中島町鳥越', '17', '17202', '9292206', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '中島町鳥越', 'ナカジママチトリゴエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市中島町大平', '17', '17202', '9292207', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '中島町大平', 'ナカジママチオオダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市中島町古江', '17', '17202', '9292208', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '中島町古江', 'ナカジママチフルエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市中島町西谷内', '17', '17202', '9292209', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '中島町西谷内', 'ナカジママチニシヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市中島町横見', '17', '17202', '9292211', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '中島町横見', 'ナカジママチヨコミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市中島町田岸', '17', '17202', '9292212', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '中島町田岸', 'ナカジママチタギシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市中島町外', '17', '17202', '9292213', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '中島町外', 'ナカジママチソデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市中島町小牧', '17', '17202', '9292214', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '中島町小牧', 'ナカジママチオマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市中島町深浦', '17', '17202', '9292215', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '中島町深浦', 'ナカジママチフカウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市中島町長浦', '17', '17202', '9292216', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '中島町長浦', 'ナカジママチナガウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市中島町鹿島台', '17', '17202', '9292217', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '中島町鹿島台', 'ナカジママチカシマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市中島町瀬嵐', '17', '17202', '9292218', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '中島町瀬嵐', 'ナカジママチセアラシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市中島町谷内', '17', '17202', '9292221', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '中島町谷内', 'ナカジママチヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市中島町中島', '17', '17202', '9292222', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '中島町中島', 'ナカジママチナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市中島町上町', '17', '17202', '9292223', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '中島町上町', 'ナカジママチカンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市中島町山戸田', '17', '17202', '9292224', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '中島町山戸田', 'ナカジママチヤマトダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市中島町宮前', '17', '17202', '9292225', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '中島町宮前', 'ナカジママチミヤノマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市中島町横田', '17', '17202', '9292226', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '中島町横田', 'ナカジママチヨコタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市中島町藤瀬', '17', '17202', '9292227', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '中島町藤瀬', 'ナカジママチフジノセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市中島町奥吉田', '17', '17202', '9292231', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '中島町奥吉田', 'ナカジママチオクヨシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市中島町筆染', '17', '17202', '9292232', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '中島町筆染', 'ナカジママチフデソメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市中島町笠師', '17', '17202', '9292233', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '中島町笠師', 'ナカジママチカサシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市中島町塩津', '17', '17202', '9292234', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '中島町塩津', 'ナカジママチシオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市中島町浜田', '17', '17202', '9292241', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '中島町浜田', 'ナカジママチハマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市中島町崎山', '17', '17202', '9292242', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '中島町崎山', 'ナカジママチサキヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市中島町河崎', '17', '17202', '9292243', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '中島町河崎', 'ナカジママチカワザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市中島町豊田町', '17', '17202', '9292244', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '中島町豊田町', 'ナカジママチトヨタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市中島町豊田', '17', '17202', '9292245', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '中島町豊田', 'ナカジママチトヨタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市中島町土川', '17', '17202', '9292246', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '中島町土川', 'ナカジママチツチカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県七尾市中島町外原', '17', '17202', '9292247', '石川県', 'イシカワケン', '七尾市', 'ナナオシ', '中島町外原', 'ナカジママチソドハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市三井町与呂見', '17', '17204', '9292361', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '三井町与呂見', 'ミイマチヨロミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市三井町中', '17', '17204', '9292362', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '三井町中', 'ミイマチナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市三井町興徳寺', '17', '17204', '9292363', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '三井町興徳寺', 'ミイマチコウトクジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市大和町', '17', '17204', '9292364', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '大和町', 'ヤマトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市三井町渡合', '17', '17204', '9292365', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '三井町渡合', 'ミイマチドアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市三井町本江', '17', '17204', '9292366', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '三井町本江', 'ミイマチホンコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市三井町仁行', '17', '17204', '9292367', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '三井町仁行', 'ミイマチニギョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市三井町三洲穂', '17', '17204', '9292371', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '三井町三洲穂', 'ミイマチミズホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市三井町洲衛', '17', '17204', '9292372', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '三井町洲衛', 'ミイマチスエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市三井町市ノ坂', '17', '17204', '9292373', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '三井町市ノ坂', 'ミイマチイチノサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市三井町内屋', '17', '17204', '9292374', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '三井町内屋', 'ミイマチウチヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市三井町細屋', '17', '17204', '9292375', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '三井町細屋', 'ミイマチホソヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市三井町新保', '17', '17204', '9292376', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '三井町新保', 'ミイマチシンボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市三井町漆原', '17', '17204', '9292377', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '三井町漆原', 'ミイマチウルシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市三井町小泉', '17', '17204', '9292378', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '三井町小泉', 'ミイマチコイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県輪島市三井町長沢', '17', '17204', '9292379', '石川県', 'イシカワケン', '輪島市', 'ワジマシ', '三井町長沢', 'ミイマチナガサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走市', '01', '01211', '0930000', '北海道', 'ホッカイドウ', '網走市', 'アバシリシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('125684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市明輪町', '16', '16201', '9300001', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '明輪町', 'メイリンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市新富町', '16', '16201', '9300002', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '新富町', 'シントミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市桜町', '16', '16201', '9300003', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '桜町', 'サクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市桜橋通り', '16', '16201', '9300004', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '桜橋通り', 'サクラバシドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市新桜町', '16', '16201', '9300005', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '新桜町', 'シンサクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市新総曲輪', '16', '16201', '9300006', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '新総曲輪', 'シンソウガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市宝町', '16', '16201', '9300007', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '宝町', 'タカラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市神通本町', '16', '16201', '9300008', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '神通本町', 'ジンヅウホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市神通町', '16', '16201', '9300009', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '神通町', 'ジンヅウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走市南1条東', '01', '01211', '0930001', '北海道', 'ホッカイドウ', '網走市', 'アバシリシ', '南1条東', 'ミナミ01ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市稲荷元町', '16', '16201', '9300010', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '稲荷元町', 'イナリモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市稲荷町', '16', '16201', '9300012', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '稲荷町', 'イナリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市館出町', '16', '16201', '9300014', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '館出町', 'タチイデマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市於保多町', '16', '16201', '9300015', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '於保多町', 'オオタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市柳町', '16', '16201', '9300016', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '柳町', 'ヤナギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市東田地方町', '16', '16201', '9300017', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '東田地方町', 'ヒガシデンヂガタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市千歳町', '16', '16201', '9300018', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '千歳町', 'チトセマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市弥生町', '16', '16201', '9300019', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '弥生町', 'ヤヨイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走市南2条東', '01', '01211', '0930002', '北海道', 'ホッカイドウ', '網走市', 'アバシリシ', '南2条東', 'ミナミ02ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市今木町', '16', '16201', '9300021', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '今木町', 'イマギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市小島町', '16', '16201', '9300022', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '小島町', 'コジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市北新町', '16', '16201', '9300023', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '北新町', 'キタシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市新川原町', '16', '16201', '9300024', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '新川原町', 'シンカワラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市日之出町', '16', '16201', '9300025', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '日之出町', 'ヒノデマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八人町', '16', '16201', '9300026', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八人町', 'ハチニンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市蛯町', '16', '16201', '9300027', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '蛯町', 'エビチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市荒町', '16', '16201', '9300028', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '荒町', 'アラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市本町', '16', '16201', '9300029', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走市南3条東', '01', '01211', '0930003', '北海道', 'ホッカイドウ', '網走市', 'アバシリシ', '南3条東', 'ミナミ03ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市住吉町', '16', '16201', '9300031', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '住吉町', 'スミヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市栄町', '16', '16201', '9300032', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市元町', '16', '16201', '9300033', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '元町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市清水元町', '16', '16201', '9300034', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '清水元町', 'シミズモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市清水中町', '16', '16201', '9300035', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '清水中町', 'シミズナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市清水町', '16', '16201', '9300036', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '清水町', 'シミズマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市音羽町', '16', '16201', '9300037', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '音羽町', 'オトワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市緑町', '16', '16201', '9300038', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '緑町', 'ミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市東町', '16', '16201', '9300039', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '東町', 'ヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走市南4条東', '01', '01211', '0930004', '北海道', 'ホッカイドウ', '網走市', 'アバシリシ', '南4条東', 'ミナミ04ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市向川原町', '16', '16201', '9300041', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '向川原町', 'ムコウガワラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市泉町', '16', '16201', '9300042', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '泉町', 'イズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市石倉町', '16', '16201', '9300043', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '石倉町', 'イシクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市中央通り', '16', '16201', '9300044', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '中央通り', 'チュウオウドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市砂町', '16', '16201', '9300045', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '砂町', 'スナマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市堤町通り', '16', '16201', '9300046', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '堤町通り', 'ツツミチョウドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市常盤町', '16', '16201', '9300047', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '常盤町', 'トキワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市白銀町', '16', '16201', '9300048', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '白銀町', 'シロガネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市豊川町', '16', '16201', '9300049', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '豊川町', 'トヨカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走市南5条東', '01', '01211', '0930005', '北海道', 'ホッカイドウ', '網走市', 'アバシリシ', '南5条東', 'ミナミ05ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市室町通り', '16', '16201', '9300051', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '室町通り', 'ムロマチドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市五番町', '16', '16201', '9300052', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '五番町', 'ゴバンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市辰巳町', '16', '16201', '9300053', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '辰巳町', 'タツミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市南新町', '16', '16201', '9300054', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '南新町', 'ミナミシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市梅沢町', '16', '16201', '9300055', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '梅沢町', 'ウメザワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市南田町', '16', '16201', '9300056', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '南田町', 'ミナミダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市上本町', '16', '16201', '9300057', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '上本町', 'カミホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市古鍛冶町', '16', '16201', '9300058', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '古鍛冶町', 'フルカジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市三番町', '16', '16201', '9300059', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '三番町', 'サンバンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走市南6条東', '01', '01211', '0930006', '北海道', 'ホッカイドウ', '網走市', 'アバシリシ', '南6条東', 'ミナミ06ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市一番町', '16', '16201', '9300061', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '一番町', 'イチバンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市西町', '16', '16201', '9300062', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '西町', 'ニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市太田口通り', '16', '16201', '9300063', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '太田口通り', 'オオタグチドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市山王町', '16', '16201', '9300064', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '山王町', 'サンノウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市星井町', '16', '16201', '9300065', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '星井町', 'ホシイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市千石町', '16', '16201', '9300066', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '千石町', 'センゴクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市越前町', '16', '16201', '9300067', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '越前町', 'エチゼンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市西四十物町', '16', '16201', '9300068', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '西四十物町', 'ニシアイモンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市旅籠町', '16', '16201', '9300069', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '旅籠町', 'ハタゴマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走市南7条東', '01', '01211', '0930007', '北海道', 'ホッカイドウ', '網走市', 'アバシリシ', '南7条東', 'ミナミ07ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市平吹町', '16', '16201', '9300071', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '平吹町', 'ヒラキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市桃井町', '16', '16201', '9300072', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '桃井町', 'モモノイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市西山王町', '16', '16201', '9300073', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '西山王町', 'ニシサンノウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市堀端町', '16', '16201', '9300074', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '堀端町', 'ホリハタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市相生町', '16', '16201', '9300075', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '相生町', 'アイオイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市長柄町', '16', '16201', '9300076', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '長柄町', 'ナガエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市磯部町', '16', '16201', '9300077', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '磯部町', 'イソベマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市土居原町', '16', '16201', '9300078', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '土居原町', 'ドイハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走市南8条東', '01', '01211', '0930008', '北海道', 'ホッカイドウ', '網走市', 'アバシリシ', '南8条東', 'ミナミ08ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市本丸', '16', '16201', '9300081', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '本丸', 'ホンマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市桜木町', '16', '16201', '9300082', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '桜木町', 'サクラギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市総曲輪', '16', '16201', '9300083', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '総曲輪', 'ソウガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市大手町', '16', '16201', '9300084', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '大手町', 'オオテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市丸の内', '16', '16201', '9300085', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '丸の内', 'マルノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市鹿島町', '16', '16201', '9300086', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '鹿島町', 'カシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市安野屋町', '16', '16201', '9300087', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '安野屋町', 'ヤスノヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市諏訪川原', '16', '16201', '9300088', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '諏訪川原', 'スワノカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市七軒町', '16', '16201', '9300089', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '七軒町', 'シチケンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走市南9条東', '01', '01211', '0930009', '北海道', 'ホッカイドウ', '網走市', 'アバシリシ', '南9条東', 'ミナミ09ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市愛宕町', '16', '16201', '9300091', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '愛宕町', 'アタゴマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市安田町', '16', '16201', '9300092', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '安田町', 'ヤスダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市内幸町', '16', '16201', '9300093', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '内幸町', 'ウチサイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市安住町', '16', '16201', '9300094', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '安住町', 'アズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市舟橋南町', '16', '16201', '9300095', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '舟橋南町', 'フナハシミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市舟橋北町', '16', '16201', '9300096', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '舟橋北町', 'フナハシキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市芝園町', '16', '16201', '9300097', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '芝園町', 'シバゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市舟橋今町', '16', '16201', '9300098', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '舟橋今町', 'フナハシイママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走市南10条東', '01', '01211', '0930010', '北海道', 'ホッカイドウ', '網走市', 'アバシリシ', '南10条東', 'ミナミ10ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市中沖', '16', '16201', '9300101', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '中沖', 'ナカオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市呉羽野田', '16', '16201', '9300102', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '呉羽野田', 'クレハノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市北代', '16', '16201', '9300103', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '北代', 'キタダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市北代中部', '16', '16201', '9300103', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '北代中部', 'キタダイチュウブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市北代東部', '16', '16201', '9300103', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '北代東部', 'キタダイトウブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市北代北部', '16', '16201', '9300103', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '北代北部', 'キタダイホクブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市北代新', '16', '16201', '9300104', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '北代新', 'キタダイシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市北代藤ケ丘', '16', '16201', '9300105', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '北代藤ケ丘', 'キタダイフジガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市高木', '16', '16201', '9300106', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '高木', 'タカギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市高木西', '16', '16201', '9300106', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '高木西', 'タカギニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市高木東', '16', '16201', '9300106', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '高木東', 'タカギヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市高木南', '16', '16201', '9300106', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '高木南', 'タカギミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市大塚', '16', '16201', '9300107', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '大塚', 'オオツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市大塚北', '16', '16201', '9300107', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '大塚北', 'オオツカキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市大塚西', '16', '16201', '9300107', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '大塚西', 'オオツカニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市大塚東', '16', '16201', '9300107', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '大塚東', 'オオツカヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市大塚南', '16', '16201', '9300107', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '大塚南', 'オオツカミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市本郷', '16', '16201', '9300108', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '本郷', 'ホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市本郷西部', '16', '16201', '9300108', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '本郷西部', 'ホンゴウセイブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市本郷中部', '16', '16201', '9300108', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '本郷中部', 'ホンゴウチュウブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市本郷東部', '16', '16201', '9300108', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '本郷東部', 'ホンゴウトウブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市本郷北部', '16', '16201', '9300108', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '本郷北部', 'ホンゴウホクブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走市南1条西', '01', '01211', '0930011', '北海道', 'ホッカイドウ', '網走市', 'アバシリシ', '南1条西', 'ミナミ01ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市長岡', '16', '16201', '9300111', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '長岡', 'ナガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八ケ山', '16', '16201', '9300112', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八ケ山', 'ハッカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市長岡新', '16', '16201', '9300113', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '長岡新', 'ナガオカシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市茶屋新町', '16', '16201', '9300114', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '茶屋新町', 'チャヤシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市茶屋町', '16', '16201', '9300115', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '茶屋町', 'チャヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市追分茶屋', '16', '16201', '9300116', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '追分茶屋', 'オイワケチャヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走市南2条西', '01', '01211', '0930012', '北海道', 'ホッカイドウ', '網走市', 'アバシリシ', '南2条西', 'ミナミ02ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市呉羽苑', '16', '16201', '9300121', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '呉羽苑', 'クレハエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市呉羽新富田町', '16', '16201', '9300122', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '呉羽新富田町', 'クレハシントミタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市呉羽富田町', '16', '16201', '9300123', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '呉羽富田町', 'クレハトミタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市呉羽水上町', '16', '16201', '9300124', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '呉羽水上町', 'クレハミズカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市呉羽つつじが丘', '16', '16201', '9300125', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '呉羽つつじが丘', 'クレハツツジガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市呉羽東町', '16', '16201', '9300126', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '呉羽東町', 'クレハヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市呉羽丸富町', '16', '16201', '9300127', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '呉羽丸富町', 'クレハマルトミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走市南3条西', '01', '01211', '0930013', '北海道', 'ホッカイドウ', '網走市', 'アバシリシ', '南3条西', 'ミナミ03ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市呉羽昭和町', '16', '16201', '9300131', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '呉羽昭和町', 'クレハショウワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市呉羽姫本', '16', '16201', '9300132', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '呉羽姫本', 'クレハヒメモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市呉羽川西', '16', '16201', '9300133', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '呉羽川西', 'クレハカワニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市呉羽貴船巻', '16', '16201', '9300134', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '呉羽貴船巻', 'クレハキフネマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市呉羽中の町', '16', '16201', '9300135', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '呉羽中の町', 'クレハナカノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市呉羽三ツ塚', '16', '16201', '9300136', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '呉羽三ツ塚', 'クレハミツヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市呉羽本町', '16', '16201', '9300137', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '呉羽本町', 'クレハホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市呉羽町', '16', '16201', '9300138', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '呉羽町', 'クレハマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市呉羽町北', '16', '16201', '9300138', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '呉羽町北', 'クレハマチキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市呉羽町西', '16', '16201', '9300138', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '呉羽町西', 'クレハマチニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走市南4条西', '01', '01211', '0930014', '北海道', 'ホッカイドウ', '網走市', 'アバシリシ', '南4条西', 'ミナミ04ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市吉作新町', '16', '16201', '9300141', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '吉作新町', 'ヨシヅクリシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市吉作', '16', '16201', '9300142', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '吉作', 'ヨシヅクリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市西金屋', '16', '16201', '9300143', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '西金屋', 'ニシカナヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市住吉', '16', '16201', '9300144', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '住吉', 'スミヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走市南5条西', '01', '01211', '0930015', '北海道', 'ホッカイドウ', '網走市', 'アバシリシ', '南5条西', 'ミナミ05ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市古沢', '16', '16201', '9300151', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '古沢', 'フルサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市杉谷', '16', '16201', '9300152', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '杉谷', 'スギタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市境野新', '16', '16201', '9300153', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '境野新', 'サカイノシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市平岡', '16', '16201', '9300154', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '平岡', 'ヒラオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市三熊', '16', '16201', '9300155', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '三熊', 'サンノクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市坂下新', '16', '16201', '9300156', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '坂下新', 'サカシタシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市山本', '16', '16201', '9300156', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '山本', 'ヤマモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市開ケ丘', '16', '16201', '9300157', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '開ケ丘', 'ヒラキガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市池多', '16', '16201', '9300158', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '池多', 'イケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走市南6条西', '01', '01211', '0930016', '北海道', 'ホッカイドウ', '網走市', 'アバシリシ', '南6条西', 'ミナミ06ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市東老田', '16', '16201', '9300161', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '東老田', 'ヒガシオイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市花木', '16', '16201', '9300162', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '花木', 'ハナノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市栃谷', '16', '16201', '9300163', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '栃谷', 'トチダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市北押川', '16', '16201', '9300164', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '北押川', 'キタオシカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市西押川', '16', '16201', '9300165', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '西押川', 'ニシオシカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市中老田', '16', '16201', '9300166', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '中老田', 'ナカオイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走市南7条西', '01', '01211', '0930017', '北海道', 'ホッカイドウ', '網走市', 'アバシリシ', '南7条西', 'ミナミ07ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市野々上', '16', '16201', '9300171', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '野々上', 'ノノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市北二ツ屋', '16', '16201', '9300172', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '北二ツ屋', 'キタフタツヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市野口', '16', '16201', '9300173', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '野口', 'ノグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市野口南部', '16', '16201', '9300173', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '野口南部', 'ノグチナンブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市野口北部', '16', '16201', '9300173', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '野口北部', 'ノグチホクブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市野町', '16', '16201', '9300174', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '野町', 'ノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市願海寺', '16', '16201', '9300175', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '願海寺', 'ガンカイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市願海寺新町', '16', '16201', '9300176', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '願海寺新町', 'ガンカイジシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市西二俣', '16', '16201', '9300177', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '西二俣', 'ニシフタマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走市南8条西', '01', '01211', '0930018', '北海道', 'ホッカイドウ', '網走市', 'アバシリシ', '南8条西', 'ミナミ08ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走市南9条西', '01', '01211', '0930019', '北海道', 'ホッカイドウ', '網走市', 'アバシリシ', '南9条西', 'ミナミ09ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走市南10条西', '01', '01211', '0930020', '北海道', 'ホッカイドウ', '網走市', 'アバシリシ', '南10条西', 'ミナミ10ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡舟橋村', '16', '16321', '9300200', '富山県', 'トヤマケン', '中新川郡舟橋村', 'ナカニイカワグンフナハシムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('125869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町', '16', '16323', '9300200', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('125870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町泉', '16', '16323', '9300201', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '泉', 'イズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町若宮', '16', '16323', '9300202', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '若宮', 'ワカミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町若林', '16', '16323', '9300203', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '若林', 'ワカバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町寺田', '16', '16323', '9300204', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '寺田', 'テラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町寺田新', '16', '16323', '9300205', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '寺田新', 'テラダシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町竹鼻新', '16', '16323', '9300206', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '竹鼻新', 'タケハナシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町浦田新', '16', '16323', '9300207', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '浦田新', 'ウラダシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町浦田', '16', '16323', '9300208', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '浦田', 'ウラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町寺田ことぶき町', '16', '16323', '9300209', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '寺田ことぶき町', 'テラダコトブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走市南11条西', '01', '01211', '0930021', '北海道', 'ホッカイドウ', '網走市', 'アバシリシ', '南11条西', 'ミナミ11ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町辻', '16', '16323', '9300211', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '辻', 'ツジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町沢端', '16', '16323', '9300212', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '沢端', 'サワハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町野口新', '16', '16323', '9300213', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '野口新', 'ノグチシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町五百石', '16', '16323', '9300214', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '五百石', 'ゴヒャクコク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町宮成', '16', '16323', '9300215', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '宮成', 'ミヤナリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町大窪', '16', '16323', '9300216', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '大窪', 'オオクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町野口', '16', '16323', '9300217', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '野口', 'ノグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町二ツ塚', '16', '16323', '9300218', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '二ツ塚', 'フタツヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町田添', '16', '16323', '9300219', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '田添', 'タゾエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走市南12条西', '01', '01211', '0930022', '北海道', 'ホッカイドウ', '網走市', 'アバシリシ', '南12条西', 'ミナミ12ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町前沢', '16', '16323', '9300221', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '前沢', 'マエザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町貫田', '16', '16323', '9300222', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '貫田', 'ヌキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町上鉾木', '16', '16323', '9300223', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '上鉾木', 'カミホコノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町西芦原', '16', '16323', '9300224', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '西芦原', 'ニシアシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町本郷島', '16', '16323', '9300225', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '本郷島', 'ホンゴウジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町道新', '16', '16323', '9300226', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '道新', 'ドウシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町草野', '16', '16323', '9300227', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '草野', 'クサノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町手屋', '16', '16323', '9300228', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '手屋', 'タヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町前沢新町', '16', '16323', '9300229', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '前沢新町', 'マエザワシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走市南13条西', '01', '01211', '0930023', '北海道', 'ホッカイドウ', '網走市', 'アバシリシ', '南13条西', 'ミナミ13ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町坂井沢', '16', '16323', '9300231', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '坂井沢', 'サカイザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町金剛寺', '16', '16323', '9300232', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '金剛寺', 'コンゴウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町上金剛寺', '16', '16323', '9300233', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '上金剛寺', 'カミコンゴウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町下段', '16', '16323', '9300234', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '下段', 'シタダン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町榎', '16', '16323', '9300235', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '榎', 'エノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町新堀', '16', '16323', '9300236', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '新堀', 'シンボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町柿の木沢', '16', '16323', '9300237', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '柿の木沢', 'カキノキザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走市南14条西', '01', '01211', '0930024', '北海道', 'ホッカイドウ', '網走市', 'アバシリシ', '南14条西', 'ミナミ14ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町道源寺', '16', '16323', '9300241', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '道源寺', 'ドウゲンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町寺坪', '16', '16323', '9300242', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '寺坪', 'テラツボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町米道', '16', '16323', '9300243', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '米道', 'ヨネミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町末谷口', '16', '16323', '9300244', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '末谷口', 'スエタニグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町沢中山', '16', '16323', '9300245', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '沢中山', 'サワナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町中山', '16', '16323', '9300245', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '中山', 'ナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町鋳物師沢', '16', '16323', '9300246', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '鋳物師沢', 'イモノシザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町末三賀', '16', '16323', '9300247', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '末三賀', 'スエサンガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町野村', '16', '16323', '9300248', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '野村', 'ノムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町大島', '16', '16323', '9300251', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '大島', 'オオシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町日俣', '16', '16323', '9300252', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '日俣', 'ヒマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町大窪開', '16', '16323', '9300253', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '大窪開', 'オオクボビラキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町古川', '16', '16323', '9300254', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '古川', 'フルカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町向新庄', '16', '16323', '9300255', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '向新庄', 'ムカイシンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町一本木', '16', '16323', '9300256', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '一本木', 'イッポンギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町川原木', '16', '16323', '9300257', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '川原木', 'カワラギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町大石原', '16', '16323', '9300261', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '大石原', 'オオイシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町蔵本新', '16', '16323', '9300262', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '蔵本新', 'クラモトシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町大清水', '16', '16323', '9300263', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '大清水', 'オオショウズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町東大森', '16', '16323', '9300264', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '東大森', 'ヒガシオオモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町泊新', '16', '16323', '9300265', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '泊新', 'トマリシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町三ツ塚', '16', '16323', '9300266', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '三ツ塚', 'ミツヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町三ツ塚新', '16', '16323', '9300266', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '三ツ塚新', 'ミツヅカシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町西大森', '16', '16323', '9300267', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '西大森', 'ニシオオモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町高原八ツ屋', '16', '16323', '9300268', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '高原八ツ屋', 'タカハラヤツヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町半屋', '16', '16323', '9300269', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '半屋', 'ナカリヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町浅生', '16', '16323', '9300271', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '浅生', 'アソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町塚越', '16', '16323', '9300272', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '塚越', 'ツカゴシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町横沢', '16', '16323', '9300273', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '横沢', 'ヨコザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町五郎丸', '16', '16323', '9300274', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '五郎丸', 'ゴロウマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町利田', '16', '16323', '9300275', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '利田', 'リタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町鉾ノ木', '16', '16323', '9300276', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '鉾ノ木', 'ホコノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡舟橋村舟橋', '16', '16321', '9300281', '富山県', 'トヤマケン', '中新川郡舟橋村', 'ナカニイカワグンフナハシムラ', '舟橋', 'フナハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡舟橋村仏生寺', '16', '16321', '9300282', '富山県', 'トヤマケン', '中新川郡舟橋村', 'ナカニイカワグンフナハシムラ', '仏生寺', 'ブッショウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡舟橋村海老江', '16', '16321', '9300283', '富山県', 'トヤマケン', '中新川郡舟橋村', 'ナカニイカワグンフナハシムラ', '海老江', 'エビエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡舟橋村竹鼻', '16', '16321', '9300284', '富山県', 'トヤマケン', '中新川郡舟橋村', 'ナカニイカワグンフナハシムラ', '竹鼻', 'タケハナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡舟橋村古海老江', '16', '16321', '9300285', '富山県', 'トヤマケン', '中新川郡舟橋村', 'ナカニイカワグンフナハシムラ', '古海老江', 'フルエビエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡舟橋村東芦原', '16', '16321', '9300286', '富山県', 'トヤマケン', '中新川郡舟橋村', 'ナカニイカワグンフナハシムラ', '東芦原', 'ヒガシアシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡舟橋村稲荷', '16', '16321', '9300287', '富山県', 'トヤマケン', '中新川郡舟橋村', 'ナカニイカワグンフナハシムラ', '稲荷', 'イナリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡舟橋村国重', '16', '16321', '9300288', '富山県', 'トヤマケン', '中新川郡舟橋村', 'ナカニイカワグンフナハシムラ', '国重', 'クニシゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡舟橋村竹内', '16', '16321', '9300289', '富山県', 'トヤマケン', '中新川郡舟橋村', 'ナカニイカワグンフナハシムラ', '竹内', 'タケノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町', '16', '16322', '9300300', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('125953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町竹鼻', '16', '16322', '9300301', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '竹鼻', 'タケハナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町石仏', '16', '16322', '9300302', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '石仏', 'イシボトケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町大永田', '16', '16322', '9300303', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '大永田', 'オナガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町森尻', '16', '16322', '9300304', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '森尻', 'モリジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町荒田', '16', '16322', '9300305', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '荒田', 'アレタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走市台町', '01', '01211', '0930031', '北海道', 'ホッカイドウ', '網走市', 'アバシリシ', '台町', 'ダイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町弥市', '16', '16322', '9300311', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '弥市', 'ヤイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町東江上', '16', '16322', '9300312', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '東江上', 'ヒガシエガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町中江上', '16', '16322', '9300313', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '中江上', 'ナカエガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町若杉', '16', '16322', '9300314', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '若杉', 'ワカスギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町若杉新', '16', '16322', '9300315', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '若杉新', 'ワカスギシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町中小泉', '16', '16322', '9300316', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '中小泉', 'ナカコイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町江又', '16', '16322', '9300317', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '江又', 'エマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町江上', '16', '16322', '9300318', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '江上', 'エガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走市港町', '01', '01211', '0930032', '北海道', 'ホッカイドウ', '網走市', 'アバシリシ', '港町', 'ミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町天神町', '16', '16322', '9300321', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '天神町', 'テンジンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町栄町', '16', '16322', '9300322', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '栄町', 'サカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町西町', '16', '16322', '9300323', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '西町', 'ニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町新町', '16', '16322', '9300324', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町三日市', '16', '16322', '9300325', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '三日市', 'ミッカイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町柳町', '16', '16322', '9300326', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '柳町', 'ヤナギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走市駒場北', '01', '01211', '0930033', '北海道', 'ホッカイドウ', '網走市', 'アバシリシ', '駒場北', 'コマバキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町旭町', '16', '16322', '9300331', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '旭町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町石浦町', '16', '16322', '9300332', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '石浦町', 'イシウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町上中町', '16', '16322', '9300333', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '上中町', 'カミナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町西中町', '16', '16322', '9300334', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '西中町', 'ニシナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町幸町', '16', '16322', '9300335', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町松和町', '16', '16322', '9300336', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '松和町', 'マツワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走市つくしケ丘', '01', '01211', '0930034', '北海道', 'ホッカイドウ', '網走市', 'アバシリシ', 'つくしケ丘', 'ツクシガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町錦町', '16', '16322', '9300341', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '錦町', 'ニシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町神明町', '16', '16322', '9300342', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '神明町', 'シンメイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町東町', '16', '16322', '9300343', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '東町', 'ヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町森元町', '16', '16322', '9300344', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '森元町', 'モリモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町南町', '16', '16322', '9300345', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '南町', 'ミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町鍵町', '16', '16322', '9300346', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '鍵町', 'カギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町熊野町', '16', '16322', '9300347', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '熊野町', 'クマノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走市駒場南', '01', '01211', '0930035', '北海道', 'ホッカイドウ', '網走市', 'アバシリシ', '駒場南', 'コマバミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町北島', '16', '16322', '9300351', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '北島', 'キタジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町上法音寺', '16', '16322', '9300352', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '上法音寺', 'カミホウオンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町法音寺', '16', '16322', '9300353', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '法音寺', 'ホウオンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町大坪', '16', '16322', '9300354', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '大坪', 'オオツボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町横法音寺', '16', '16322', '9300355', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '横法音寺', 'ヨコホウオンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町上正', '16', '16322', '9300356', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '上正', 'カミショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町正印', '16', '16322', '9300357', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '正印', 'ショイン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町正印新', '16', '16322', '9300358', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '正印新', 'ショインシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町湯上野', '16', '16322', '9300361', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '湯上野', 'ユウワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('125999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町稗田', '16', '16322', '9300362', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '稗田', 'ヒエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町和合', '16', '16322', '9300363', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '和合', 'ワゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町横越', '16', '16322', '9300364', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '横越', 'ヨコゴシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町神田', '16', '16322', '9300365', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '神田', 'ジンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町新村', '16', '16322', '9300366', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '新村', 'シンムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町野福', '16', '16322', '9300367', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '野福', 'ノフク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町川原田', '16', '16322', '9300368', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '川原田', 'カワハラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町中開発', '16', '16322', '9300371', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '中開発', 'ナカカイホツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町上経田', '16', '16322', '9300372', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '上経田', 'カミキョウデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町下経田', '16', '16322', '9300373', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '下経田', 'シモキョウデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町相ノ木新町', '16', '16322', '9300374', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '相ノ木新町', 'アイノキシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町上荒又', '16', '16322', '9300375', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '上荒又', 'カミアラマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町下荒又', '16', '16322', '9300376', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '下荒又', 'シモアラマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町新清水', '16', '16322', '9300377', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '新清水', 'アラシミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町放士ケ瀬', '16', '16322', '9300378', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '放士ケ瀬', 'ホウジガセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町放士ケ瀬新', '16', '16322', '9300379', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '放士ケ瀬新', 'ホウジガセシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町久金', '16', '16322', '9300381', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '久金', 'ヒサガネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町下青出', '16', '16322', '9300382', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '下青出', 'シモアオイデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町上条沖', '16', '16322', '9300383', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '上条沖', 'ジョウジョウオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町青出新', '16', '16322', '9300384', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '青出新', 'アオイデシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町飯坂', '16', '16322', '9300385', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '飯坂', 'イイザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町中青出', '16', '16322', '9300386', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '中青出', 'ナカアオイデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町飯坂新', '16', '16322', '9300387', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '飯坂新', 'イイザカシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町久金新', '16', '16322', '9300388', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '久金新', 'ヒサガネシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町広野新', '16', '16322', '9300401', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '広野新', 'ヒロノシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町広市新', '16', '16322', '9300402', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '広市新', 'ヒロイチシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町野開発', '16', '16322', '9300403', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '野開発', 'ノカイホツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町三杉町', '16', '16322', '9300404', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '三杉町', 'ミスギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町郷柿沢', '16', '16322', '9300405', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '郷柿沢', 'ゴウカキザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町柿沢新', '16', '16322', '9300406', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '柿沢新', 'カキザワシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走市桂町', '01', '01211', '0930041', '北海道', 'ホッカイドウ', '網走市', 'アバシリシ', '桂町', 'カツラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町砂林開', '16', '16322', '9300411', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '砂林開', 'スナバヤシビラキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町広野', '16', '16322', '9300412', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '広野', 'ヒロノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町一の越', '16', '16322', '9300413', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '一の越', 'イチノコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町永代', '16', '16322', '9300414', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '永代', 'エイタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町松原野', '16', '16322', '9300415', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '松原野', 'マツバラノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町黒川', '16', '16322', '9300416', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '黒川', 'クロカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町五位尾', '16', '16322', '9300417', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '五位尾', 'ゴイオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走市潮見', '01', '01211', '0930042', '北海道', 'ホッカイドウ', '網走市', 'アバシリシ', '潮見', 'シオミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町片地', '16', '16322', '9300421', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '片地', 'カタジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町眼目', '16', '16322', '9300422', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '眼目', 'サッカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町野島', '16', '16322', '9300423', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '野島', 'ノジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町斉ノ神新', '16', '16322', '9300424', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '斉ノ神新', 'サイノカミシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町田島野', '16', '16322', '9300425', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '田島野', 'タジマノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走市錦町', '01', '01211', '0930043', '北海道', 'ホッカイドウ', '網走市', 'アバシリシ', '錦町', 'ニシキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町釈泉寺', '16', '16322', '9300431', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '釈泉寺', 'シャクセンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町稲村', '16', '16322', '9300432', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '稲村', 'イナムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町中村', '16', '16322', '9300433', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '中村', 'ナカムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町下田', '16', '16322', '9300434', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '下田', 'ゲダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町折戸', '16', '16322', '9300435', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '折戸', 'オリト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町蓬沢', '16', '16322', '9300436', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '蓬沢', 'ヨモギザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町伊折', '16', '16322', '9300437', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '伊折', 'イオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町馬場島', '16', '16322', '9300438', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '馬場島', 'バンバジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走市天都山', '01', '01211', '0930044', '北海道', 'ホッカイドウ', '網走市', 'アバシリシ', '天都山', 'テントザン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町東種', '16', '16322', '9300441', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '東種', 'ヒガシタネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町千石', '16', '16322', '9300442', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '千石', 'センゴク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町骨原', '16', '16322', '9300443', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '骨原', 'コツハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町西種', '16', '16322', '9300444', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '西種', 'ニシタネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町水上', '16', '16322', '9300445', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '水上', 'ミズカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走市大曲', '01', '01211', '0930045', '北海道', 'ホッカイドウ', '網走市', 'アバシリシ', '大曲', 'オオマガリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町極楽寺', '16', '16322', '9300451', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '極楽寺', 'ゴクラクジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町須山', '16', '16322', '9300452', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '須山', 'スヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町堤谷', '16', '16322', '9300453', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '堤谷', 'ツツミダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町湯神子', '16', '16322', '9300454', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '湯神子', 'ユノミコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町湯崎野', '16', '16322', '9300455', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '湯崎野', 'ユサキノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町丸山', '16', '16322', '9300456', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '丸山', 'マルヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町湯神子野', '16', '16322', '9300457', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '湯神子野', 'ユノミコノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町眼目新', '16', '16322', '9300458', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '眼目新', 'サッカシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走市新町', '01', '01211', '0930046', '北海道', 'ホッカイドウ', '網走市', 'アバシリシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町大松新', '16', '16322', '9300461', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '大松新', 'オオマツシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町大松', '16', '16322', '9300462', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '大松', 'オオマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町大岩', '16', '16322', '9300463', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '大岩', 'オオイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町浅生', '16', '16322', '9300464', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '浅生', 'アソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町大沢', '16', '16322', '9300465', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '大沢', 'オオサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町桧谷', '16', '16322', '9300466', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '桧谷', 'ヒノタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町塩谷', '16', '16322', '9300467', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '塩谷', 'シオノタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町新屋', '16', '16322', '9300471', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '新屋', 'アラヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町女川', '16', '16322', '9300472', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '女川', 'オナガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町柿沢', '16', '16322', '9300473', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '柿沢', 'カキザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町舘', '16', '16322', '9300474', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '舘', 'タチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走市北1条東', '01', '01211', '0930051', '北海道', 'ホッカイドウ', '網走市', 'アバシリシ', '北1条東', 'キタ01ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走市北2条東', '01', '01211', '0930052', '北海道', 'ホッカイドウ', '網走市', 'アバシリシ', '北2条東', 'キタ02ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走市北3条東', '01', '01211', '0930053', '北海道', 'ホッカイドウ', '網走市', 'アバシリシ', '北3条東', 'キタ03ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走市北4条東', '01', '01211', '0930054', '北海道', 'ホッカイドウ', '網走市', 'アバシリシ', '北4条東', 'キタ04ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走市北5条東', '01', '01211', '0930055', '北海道', 'ホッカイドウ', '網走市', 'アバシリシ', '北5条東', 'キタ05ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走市北6条東', '01', '01211', '0930056', '北海道', 'ホッカイドウ', '網走市', 'アバシリシ', '北6条東', 'キタ06ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走市北7条東', '01', '01211', '0930057', '北海道', 'ホッカイドウ', '網走市', 'アバシリシ', '北7条東', 'キタ07ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走市北8条東', '01', '01211', '0930058', '北海道', 'ホッカイドウ', '網走市', 'アバシリシ', '北8条東', 'キタ08ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走市北9条東', '01', '01211', '0930059', '北海道', 'ホッカイドウ', '網走市', 'アバシリシ', '北9条東', 'キタ09ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走市北10条東', '01', '01211', '0930060', '北海道', 'ホッカイドウ', '網走市', 'アバシリシ', '北10条東', 'キタ10ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走市北11条東', '01', '01211', '0930061', '北海道', 'ホッカイドウ', '網走市', 'アバシリシ', '北11条東', 'キタ11ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走市北12条東', '01', '01211', '0930062', '北海道', 'ホッカイドウ', '網走市', 'アバシリシ', '北12条東', 'キタ12ジョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走市北1条西', '01', '01211', '0930071', '北海道', 'ホッカイドウ', '網走市', 'アバシリシ', '北1条西', 'キタ01ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走市北2条西', '01', '01211', '0930072', '北海道', 'ホッカイドウ', '網走市', 'アバシリシ', '北2条西', 'キタ02ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走市北3条西', '01', '01211', '0930073', '北海道', 'ホッカイドウ', '網走市', 'アバシリシ', '北3条西', 'キタ03ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走市北4条西', '01', '01211', '0930074', '北海道', 'ホッカイドウ', '網走市', 'アバシリシ', '北4条西', 'キタ04ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走市北5条西', '01', '01211', '0930075', '北海道', 'ホッカイドウ', '網走市', 'アバシリシ', '北5条西', 'キタ05ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走市北6条西', '01', '01211', '0930076', '北海道', 'ホッカイドウ', '網走市', 'アバシリシ', '北6条西', 'キタ06ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走市北7条西', '01', '01211', '0930077', '北海道', 'ホッカイドウ', '網走市', 'アバシリシ', '北7条西', 'キタ07ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走市北8条西', '01', '01211', '0930078', '北海道', 'ホッカイドウ', '網走市', 'アバシリシ', '北8条西', 'キタ08ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走市北9条西', '01', '01211', '0930079', '北海道', 'ホッカイドウ', '網走市', 'アバシリシ', '北9条西', 'キタ09ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走市北10条西', '01', '01211', '0930080', '北海道', 'ホッカイドウ', '網走市', 'アバシリシ', '北10条西', 'キタ10ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市中島', '16', '16201', '9300801', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '中島', 'ナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市下新北町', '16', '16201', '9300802', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '下新北町', 'シモシンキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市下新本町', '16', '16201', '9300803', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '下新本町', 'シモシンホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市下新町', '16', '16201', '9300804', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '下新町', 'シモシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市湊入船町', '16', '16201', '9300805', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '湊入船町', 'ミナトイリフネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市木場町', '16', '16201', '9300806', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '木場町', 'キバマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市下新西町', '16', '16201', '9300807', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '下新西町', 'シモシンニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市下新日曹町', '16', '16201', '9300808', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '下新日曹町', 'シモシンニッソウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市興人町', '16', '16201', '9300809', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '興人町', 'コウジンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走市北11条西', '01', '01211', '0930081', '北海道', 'ホッカイドウ', '網走市', 'アバシリシ', '北11条西', 'キタ11ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市千代田町', '16', '16201', '9300811', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '千代田町', 'チヨダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市松若町', '16', '16201', '9300812', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '松若町', 'マツワカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市下赤江町', '16', '16201', '9300813', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '下赤江町', 'シモアカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市下冨居', '16', '16201', '9300814', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '下冨居', 'シモフゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市千成町', '16', '16201', '9300815', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '千成町', 'センナリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市上赤江町', '16', '16201', '9300816', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '上赤江町', 'カミアカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市下奥井', '16', '16201', '9300817', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '下奥井', 'シモオクイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市奥田町', '16', '16201', '9300818', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '奥田町', 'オクダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市奥田本町', '16', '16201', '9300819', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '奥田本町', 'オクダホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走市北12条西', '01', '01211', '0930082', '北海道', 'ホッカイドウ', '網走市', 'アバシリシ', '北12条西', 'キタ12ジョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市飯野', '16', '16201', '9300821', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '飯野', 'イイノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市新屋', '16', '16201', '9300822', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '新屋', 'アラヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市新屋新町', '16', '16201', '9300823', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '新屋新町', 'アラヤシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市鶴ケ丘町', '16', '16201', '9300824', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '鶴ケ丘町', 'ツルガオカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市上飯野新町', '16', '16201', '9300825', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '上飯野新町', 'カミイイノシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市上庄町', '16', '16201', '9300826', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '上庄町', 'カミショウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市上飯野', '16', '16201', '9300827', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '上飯野', 'カミイイノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走市海岸町', '01', '01211', '0930083', '北海道', 'ホッカイドウ', '網走市', 'アバシリシ', '海岸町', 'カイガンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市中冨居新町', '16', '16201', '9300830', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '中冨居新町', 'ナカフゴシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市鍋田', '16', '16201', '9300831', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '鍋田', 'ナベタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市中冨居', '16', '16201', '9300832', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '中冨居', 'ナカフゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市冨居栄町', '16', '16201', '9300833', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '冨居栄町', 'フゴサカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市問屋町', '16', '16201', '9300834', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '問屋町', 'トイヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市上冨居', '16', '16201', '9300835', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '上冨居', 'カミフゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市上冨居新町', '16', '16201', '9300836', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '上冨居新町', 'カミフゴシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市上赤江', '16', '16201', '9300837', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '上赤江', 'カミアカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市下赤江', '16', '16201', '9300838', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '下赤江', 'シモアカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市新冨居', '16', '16201', '9300839', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '新冨居', 'シンフゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走市向陽ケ丘', '01', '01211', '0930084', '北海道', 'ホッカイドウ', '網走市', 'アバシリシ', '向陽ケ丘', 'コウヨウガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市四ツ葉町', '16', '16201', '9300841', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '四ツ葉町', 'ヨツバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市窪新町', '16', '16201', '9300842', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '窪新町', 'クボシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市窪本町', '16', '16201', '9300843', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '窪本町', 'クボモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市綾田町', '16', '16201', '9300845', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '綾田町', 'アイデンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市奥井町', '16', '16201', '9300846', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '奥井町', 'オクイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市曙町', '16', '16201', '9300847', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '曙町', 'アケボノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市久方町', '16', '16201', '9300848', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '久方町', 'ヒサカタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市稲荷園町', '16', '16201', '9300849', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '稲荷園町', 'イナリソノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走市明治', '01', '01211', '0930085', '北海道', 'ホッカイドウ', '網走市', 'アバシリシ', '明治', 'メイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市奥田双葉町', '16', '16201', '9300851', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '奥田双葉町', 'オクダフタバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市奥田寿町', '16', '16201', '9300852', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '奥田寿町', 'オクダコトブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市永楽町', '16', '16201', '9300853', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '永楽町', 'エイラクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市城北町', '16', '16201', '9300854', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '城北町', 'ジョウホクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市赤江町', '16', '16201', '9300855', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '赤江町', 'アカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市牛島新町', '16', '16201', '9300856', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '牛島新町', 'ウシジマシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市奥田新町', '16', '16201', '9300857', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '奥田新町', 'オクダシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市牛島町', '16', '16201', '9300858', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '牛島町', 'ウシジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市牛島本町', '16', '16201', '9300859', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '牛島本町', 'ウシジマホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走市二ツ岩', '01', '01211', '0930086', '北海道', 'ホッカイドウ', '網走市', 'アバシリシ', '二ツ岩', 'フタツイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市有沢新町', '16', '16201', '9300861', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '有沢新町', 'アリサワシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市有沢', '16', '16201', '9300862', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '有沢', 'アリサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市有明町', '16', '16201', '9300863', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '有明町', 'アリアケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市羽根', '16', '16201', '9300864', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '羽根', 'ハネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市久郷', '16', '16201', '9300865', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '久郷', 'クゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市高田', '16', '16201', '9300866', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '高田', 'タカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市庄高田', '16', '16201', '9300867', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '庄高田', 'ショウタカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走市美岬', '01', '01211', '0930087', '北海道', 'ホッカイドウ', '網走市', 'アバシリシ', '美岬', 'ミサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市下野', '16', '16201', '9300871', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '下野', 'シモノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市下野新', '16', '16201', '9300872', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '下野新', 'シモノシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市金屋', '16', '16201', '9300873', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '金屋', 'カナヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市寺町', '16', '16201', '9300874', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '寺町', 'テラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市寺町けや木台', '16', '16201', '9300875', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '寺町けや木台', 'テラマチケヤキダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市文京町', '16', '16201', '9300876', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '文京町', 'ブンキョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走市三眺', '01', '01211', '0930088', '北海道', 'ホッカイドウ', '網走市', 'アバシリシ', '三眺', 'サンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市安養坊', '16', '16201', '9300881', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '安養坊', 'アンヨウボウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市五艘', '16', '16201', '9300882', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '五艘', 'ゴソウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市五福新町', '16', '16201', '9300883', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '五福新町', 'ゴフクシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市五福末広町', '16', '16201', '9300884', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '五福末広町', 'ゴフクスエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市鵯島', '16', '16201', '9300885', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '鵯島', 'ヒヨドリジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市ひよどり南台', '16', '16201', '9300886', '富山県', 'トヤマケン', '富山市', 'トヤマシ', 'ひよどり南台', 'ヒヨドリミナミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市五福', '16', '16201', '9300887', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '五福', 'ゴフク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走市緑町', '01', '01211', '0930089', '北海道', 'ホッカイドウ', '網走市', 'アバシリシ', '緑町', 'ミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市石坂新', '16', '16201', '9300891', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '石坂新', 'イシサカシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市石坂', '16', '16201', '9300892', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '石坂', 'イシサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市石坂東町', '16', '16201', '9300893', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '石坂東町', 'イシサカヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市田刈屋新町', '16', '16201', '9300894', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '田刈屋新町', 'タカリヤシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市駒見', '16', '16201', '9300895', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '駒見', 'コマミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市畑中', '16', '16201', '9300896', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '畑中', 'ハタナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市田刈屋', '16', '16201', '9300897', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '田刈屋', 'タカリヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市桜谷みどり町', '16', '16201', '9300898', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '桜谷みどり町', 'サクラダニミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走市文化', '01', '01211', '0930090', '北海道', 'ホッカイドウ', '網走市', 'アバシリシ', '文化', 'ブンカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市手屋', '16', '16201', '9300901', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '手屋', 'タヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市宮成新', '16', '16201', '9300902', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '宮成新', 'ミヤナリシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市中野新', '16', '16201', '9300903', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '中野新', 'ナカノシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市一本木', '16', '16201', '9300904', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '一本木', 'イッポンギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市五本榎', '16', '16201', '9300905', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '五本榎', 'ゴホンエノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市金泉寺', '16', '16201', '9300906', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '金泉寺', 'キンセンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市本郷島', '16', '16201', '9300911', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '本郷島', 'ホンゴウジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市日俣', '16', '16201', '9300912', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '日俣', 'ヒマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市荏原新町', '16', '16201', '9300913', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '荏原新町', 'エバラシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市荏原', '16', '16201', '9300914', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '荏原', 'エバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市荏原駅前通り', '16', '16201', '9300915', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '荏原駅前通り', 'エバラエキマエドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市向新庄', '16', '16201', '9300916', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '向新庄', 'ムカイシンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市向新庄町', '16', '16201', '9300916', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '向新庄町', 'ムカイシンジョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市中間島', '16', '16201', '9300921', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '中間島', 'チュウゲンジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市大江干', '16', '16201', '9300922', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '大江干', 'オオエボシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市町新', '16', '16201', '9300923', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '町新', 'マチシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市新金代', '16', '16201', '9300924', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '新金代', 'シンカナダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市栄新町', '16', '16201', '9300925', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '栄新町', 'サカエシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市金代', '16', '16201', '9300926', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '金代', 'カナダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市大江干新町', '16', '16201', '9300927', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '大江干新町', 'オオエボシシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市富岡町', '16', '16201', '9300928', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '富岡町', 'トミオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市朝日', '16', '16201', '9300931', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '朝日', 'アサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市藤木新町', '16', '16201', '9300932', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '藤木新町', 'フジノキシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市藤木新', '16', '16201', '9300933', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '藤木新', 'フジノキシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市藤の木台', '16', '16201', '9300934', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '藤の木台', 'フジノキダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市藤見町', '16', '16201', '9300935', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '藤見町', 'フジミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市藤木', '16', '16201', '9300936', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '藤木', 'フジノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市藤木中町', '16', '16201', '9300941', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '藤木中町', 'フジノキナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市藤の木園町', '16', '16201', '9300942', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '藤の木園町', 'フジノキソノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市藤代町', '16', '16201', '9300943', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '藤代町', 'フジシロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市開', '16', '16201', '9300944', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '開', 'ヒラキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市経堂', '16', '16201', '9300951', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '経堂', 'キョウドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市町村', '16', '16201', '9300952', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '町村', 'マチムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市秋吉', '16', '16201', '9300953', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '秋吉', 'アキヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市秋吉新町', '16', '16201', '9300954', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '秋吉新町', 'アキヨシシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市天正寺', '16', '16201', '9300955', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '天正寺', 'テンショウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市西長江本町', '16', '16201', '9300961', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '西長江本町', 'ニシナガエホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市長江本町', '16', '16201', '9300962', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '長江本町', 'ナガエホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市不二越町', '16', '16201', '9300963', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '不二越町', 'フジコシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市東石金町', '16', '16201', '9300964', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '東石金町', 'ヒガシイシガネマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市不二越本町', '16', '16201', '9300965', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '不二越本町', 'フジコシホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市石金', '16', '16201', '9300966', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '石金', 'イシガネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市双代町', '16', '16201', '9300971', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '双代町', 'ソウタイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市長江新町', '16', '16201', '9300972', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '長江新町', 'ナガエシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市長江東町', '16', '16201', '9300973', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '長江東町', 'ナガエヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市長江', '16', '16201', '9300974', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '長江', 'ナガエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市西長江', '16', '16201', '9300975', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '西長江', 'ニシナガエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市西新庄', '16', '16201', '9300981', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '西新庄', 'ニシシンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市荒川', '16', '16201', '9300982', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '荒川', 'アラカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市荒川常盤台', '16', '16201', '9300983', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '荒川常盤台', 'アラカワトキワダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市常盤台', '16', '16201', '9300983', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '常盤台', 'トキワダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市荒川新町', '16', '16201', '9300984', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '荒川新町', 'アラカワシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市田中町', '16', '16201', '9300985', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '田中町', 'タナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市新庄銀座', '16', '16201', '9300991', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '新庄銀座', 'シンジョウギンザ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市新庄町', '16', '16201', '9300992', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '新庄町', 'シンジョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市新園町', '16', '16201', '9300993', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '新園町', 'シンソノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市新庄新町', '16', '16201', '9300994', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '新庄新町', 'シンジョウシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市新庄中央町', '16', '16201', '9300995', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '新庄中央町', 'シンジョウチュウオウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市新庄本町', '16', '16201', '9300996', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '新庄本町', 'シンジョウホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市新庄北町', '16', '16201', '9300997', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '新庄北町', 'シンジョウキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市東福沢津毛', '16', '16201', '9301261', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '東福沢', 'ヒガシフクサワ', null, null, '津毛', 'ツゲ');
INSERT INTO `ms_addresses` VALUES ('126256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市東黒牧', '16', '16201', '9301262', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '東黒牧', 'ヒガシクロマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市東黒牧上野', '16', '16201', '9301263', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '東黒牧', 'ヒガシクロマキ', null, null, '上野', 'ウワノ');
INSERT INTO `ms_addresses` VALUES ('126258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市大山布目', '16', '16201', '9301264', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '大山布目', 'オオヤマヌノメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市小谷', '16', '16201', '9301265', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '小谷', 'オタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市砂見', '16', '16201', '9301266', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '砂見', 'スナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市砂見芋平', '16', '16201', '9301267', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '砂見', 'スナミ', null, null, '芋平', 'イモヒラ');
INSERT INTO `ms_addresses` VALUES ('126262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市楜ケ原', '16', '16201', '9301268', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '楜ケ原', 'クルミガハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市石渕', '16', '16201', '9301271', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '石渕', 'イシブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市下双嶺', '16', '16201', '9301272', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '下双嶺', 'シモゾウレイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市小坂', '16', '16201', '9301273', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '小坂', 'コサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市大双嶺', '16', '16201', '9301274', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '大双嶺', 'オオゾウレイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市大清水', '16', '16201', '9301275', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '大清水', 'オオシミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市折谷', '16', '16201', '9301276', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '折谷', 'オリタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市東福沢', '16', '16201', '9301281', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '東福沢', 'ヒガシフクサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市牧野', '16', '16201', '9301282', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '牧野', 'マキノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市日尾', '16', '16201', '9301283', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '日尾', 'ヒオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市馬瀬', '16', '16201', '9301284', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '馬瀬', 'ウマノセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市瀬戸', '16', '16201', '9301285', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '瀬戸', 'セト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市小佐波', '16', '16201', '9301286', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '小佐波', 'オザナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市東福沢火土呂', '16', '16201', '9301287', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '東福沢', 'ヒガシフクサワ', null, null, '火土呂', 'ヒドロ');
INSERT INTO `ms_addresses` VALUES ('126279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市馬瀬口', '16', '16201', '9301301', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '馬瀬口', 'マセグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市馬瀬口殿様林', '16', '16201', '9301302', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '馬瀬口', 'マセグチ', null, null, '殿様林', 'トノサマバヤシ');
INSERT INTO `ms_addresses` VALUES ('126281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市善名', '16', '16201', '9301303', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '善名', 'ゼンナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市南大場', '16', '16201', '9301304', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '南大場', 'ミナミオオバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市下番', '16', '16201', '9301305', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '下番', 'シモノバン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走市能取港町', '01', '01211', '0930131', '北海道', 'ホッカイドウ', '網走市', 'アバシリシ', '能取港町', 'ノトロミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市大山北新町', '16', '16201', '9301311', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '大山北新町', 'オオヤマキタシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市上滝', '16', '16201', '9301312', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '上滝', 'カミダキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市中滝', '16', '16201', '9301313', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '中滝', 'ナカダキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市三室荒屋', '16', '16201', '9301314', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '三室荒屋', 'ミムロアラヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市中番', '16', '16201', '9301315', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '中番', 'ナカノバン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市中番新栄町', '16', '16201', '9301316', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '中番', 'ナカノバン', null, null, '新栄町', 'シンサカエマチ');
INSERT INTO `ms_addresses` VALUES ('126291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市三室荒屋新栄町', '16', '16201', '9301316', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '三室荒屋', 'ミムロアラヤ', null, null, '新栄町', 'シンサカエマチ');
INSERT INTO `ms_addresses` VALUES ('126292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走市二見ケ岡', '01', '01211', '0930132', '北海道', 'ホッカイドウ', '網走市', 'アバシリシ', '二見ケ岡', 'フタミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市新町', '16', '16201', '9301321', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '新町', 'アラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市大山上野', '16', '16201', '9301321', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '大山上野', 'オオヤマウワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市岡田', '16', '16201', '9301322', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '岡田', 'オカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市東小俣', '16', '16201', '9301323', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '東小俣', 'ヒガシオマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市西小俣', '16', '16201', '9301324', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '西小俣', 'ニシオマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市文珠寺', '16', '16201', '9301325', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '文珠寺', 'モンジュジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市花崎', '16', '16201', '9301326', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '花崎', 'ハナサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市大栗', '16', '16201', '9301327', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '大栗', 'オオグリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市小原屋', '16', '16201', '9301328', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '小原屋', 'オハラヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走市嘉多山', '01', '01211', '0930133', '北海道', 'ホッカイドウ', '網走市', 'アバシリシ', '嘉多山', 'カタヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市田畠', '16', '16201', '9301331', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '田畠', 'タバタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市津羽見', '16', '16201', '9301332', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '津羽見', 'ツワミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市上大浦', '16', '16201', '9301333', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '上大浦', 'カミオオウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市中大浦', '16', '16201', '9301334', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '中大浦', 'ナカオオウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市下大浦', '16', '16201', '9301335', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '下大浦', 'シモオオウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市桑原', '16', '16201', '9301336', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '桑原', 'クワハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市田畠風見台', '16', '16201', '9301337', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '田畠', 'タバタケ', null, null, '風見台', 'カザミダイ');
INSERT INTO `ms_addresses` VALUES ('126310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市田畠明日美野', '16', '16201', '9301338', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '田畠', 'タバタケ', null, null, '明日美野', 'アスミノ');
INSERT INTO `ms_addresses` VALUES ('126311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走市越歳', '01', '01211', '0930134', '北海道', 'ホッカイドウ', '網走市', 'アバシリシ', '越歳', 'コシトシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走市卯原内', '01', '01211', '0930135', '北海道', 'ホッカイドウ', '網走市', 'アバシリシ', '卯原内', 'ウバラナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走市平和', '01', '01211', '0930136', '北海道', 'ホッカイドウ', '網走市', 'アバシリシ', '平和', 'ヘイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町伊豆林', '16', '16323', '9301361', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '伊豆林', 'イズバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町下田', '16', '16323', '9301361', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '下田', 'ミサダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町吉峰野開', '16', '16323', '9301362', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '吉峰野開', 'ヨシミネノビラキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町米道谷内', '16', '16323', '9301362', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '米道', 'ヨネミチ', null, null, '谷内', 'タニウチ');
INSERT INTO `ms_addresses` VALUES ('126318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町米道東谷', '16', '16323', '9301362', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '米道', 'ヨネミチ', null, null, '東谷', 'ヒガシダニ');
INSERT INTO `ms_addresses` VALUES ('126319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町栃津', '16', '16323', '9301363', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '栃津', 'トチヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町天林', '16', '16323', '9301364', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '天林', 'テンバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町東中野新', '16', '16323', '9301365', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '東中野新', 'ヒガシナカノシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町横江野開', '16', '16323', '9301366', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '横江野開', 'ヨコエノビラキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町宮路', '16', '16323', '9301367', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '宮路', 'ミヤジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町岩峅寺', '16', '16323', '9301368', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '岩峅寺', 'イワクラジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町岩峅野', '16', '16323', '9301369', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '岩峅野', 'イワクラノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町横江立山地区', '16', '16323', '9301377', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '横江', 'ヨコエ', null, null, '立山地区', 'タテヤマチク');
INSERT INTO `ms_addresses` VALUES ('126328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町称名', '16', '16323', '9301401', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '称名', 'ショウミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町桂台', '16', '16323', '9301402', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '桂台', 'カツラダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町ブナ坂', '16', '16323', '9301403', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', 'ブナ坂', 'ブナザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町藤橋', '16', '16323', '9301404', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '藤橋', 'フジバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町千寿ケ原', '16', '16323', '9301405', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '千寿ケ原', 'センジュガハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町芦峅寺', '16', '16323', '9301406', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '芦峅寺', 'アシクラジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町前谷', '16', '16323', '9301407', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '前谷', 'マエタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町千垣', '16', '16323', '9301408', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '千垣', 'チガキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町美女平', '16', '16323', '9301411', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '美女平', 'ビジョダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町弥陀ケ原', '16', '16323', '9301412', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '弥陀ケ原', 'ミダガハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町天狗平', '16', '16323', '9301413', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '天狗平', 'テングダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町室堂', '16', '16323', '9301414', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '室堂', 'ムロドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町雷鳥沢', '16', '16323', '9301415', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '雷鳥沢', 'ライチョウザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町剣御前', '16', '16323', '9301416', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '剣御前', 'ツルギゴゼン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町剣沢', '16', '16323', '9301417', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '剣沢', 'ツルギサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町立山頂上', '16', '16323', '9301418', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '立山頂上', 'タテヤマチョウジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市本宮粟巣野', '16', '16201', '9301451', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '本宮', 'ホングウ', null, null, '粟巣野', 'アワスノ');
INSERT INTO `ms_addresses` VALUES ('126345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市本宮花切割', '16', '16201', '9301452', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '本宮', 'ホングウ', null, null, '花切割', 'ハナキリワリ');
INSERT INTO `ms_addresses` VALUES ('126346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市原極楽坂', '16', '16201', '9301453', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '原', 'ハラ', null, null, '極楽坂', 'ゴクラクザカ');
INSERT INTO `ms_addresses` VALUES ('126347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市原', '16', '16201', '9301454', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '原', 'ハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市本宮', '16', '16201', '9301455', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '本宮', 'ホングウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市小見', '16', '16201', '9301456', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '小見', 'オミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市有峰太郎平', '16', '16201', '9301457', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '有峰', 'アリミネ', null, null, '太郎平', 'タロウダイラ');
INSERT INTO `ms_addresses` VALUES ('126351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市有峰', '16', '16201', '9301458', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '有峰', 'アリミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市亀谷', '16', '16201', '9301459', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '亀谷', 'カメガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市和田', '16', '16201', '9301461', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '和田', 'ワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市中地山', '16', '16201', '9301462', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '中地山', 'ナカチヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水須', '16', '16201', '9301463', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水須', 'ミズス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市才覚地', '16', '16201', '9301464', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '才覚地', 'サイカクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市牧', '16', '16201', '9301465', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '牧', 'マキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市大山松木', '16', '16201', '9301466', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '大山松木', 'オオヤママツノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市常呂町東浜', '01', '01208', '0930202', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '常呂町東浜', 'トコロチョウヒガシハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市常呂町常呂', '01', '01208', '0930210', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '常呂町常呂', 'トコロチョウトコロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市山田中瀬', '16', '16201', '9302101', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '山田中瀬', 'ヤマダナカノセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市山田宿坊', '16', '16201', '9302102', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '山田宿坊', 'ヤマダスクボウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市山田宿坊柳川', '16', '16201', '9302103', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '山田宿坊', 'ヤマダスクボウ', null, null, '柳川', 'ヤナイゴ');
INSERT INTO `ms_addresses` VALUES ('126364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市山田宿坊沢連', '16', '16201', '9302104', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '山田宿坊', 'ヤマダスクボウ', null, null, '沢連', 'ソウレ');
INSERT INTO `ms_addresses` VALUES ('126365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市山田湯', '16', '16201', '9302105', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '山田湯', 'ヤマダユ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市山田北山', '16', '16201', '9302106', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '山田北山', 'ヤマダキタヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市山田中瀬竹の内', '16', '16201', '9302107', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '山田中瀬', 'ヤマダナカノセ', null, null, '竹の内', 'タケノウチ');
INSERT INTO `ms_addresses` VALUES ('126368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市山田中瀬上中瀬', '16', '16201', '9302108', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '山田中瀬', 'ヤマダナカノセ', null, null, '上中瀬', 'カミナカノセ');
INSERT INTO `ms_addresses` VALUES ('126369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市山田鎌倉', '16', '16201', '9302111', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '山田鎌倉', 'ヤマダカマクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市山田若土', '16', '16201', '9302112', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '山田若土', 'ヤマダワカヅチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市山田谷', '16', '16201', '9302113', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '山田谷', 'ヤマダタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市山田居舟', '16', '16201', '9302114', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '山田居舟', 'ヤマダイブネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市山田鍋谷', '16', '16201', '9302114', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '山田鍋谷', 'ヤマダナベタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市山田小谷', '16', '16201', '9302115', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '山田小谷', 'ヤマダコダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市山田小谷中根', '16', '16201', '9302116', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '山田小谷', 'ヤマダコダニ', null, null, '中根', 'ナカネ');
INSERT INTO `ms_addresses` VALUES ('126376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市山田赤目谷', '16', '16201', '9302117', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '山田赤目谷', 'ヤマダアカメダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市山田白井谷', '16', '16201', '9302121', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '山田白井谷', 'ヤマダシロイダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市山田小島城山', '16', '16201', '9302122', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '山田小島', 'ヤマダコジマ', null, null, '城山', 'ジョウヤマ');
INSERT INTO `ms_addresses` VALUES ('126379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市山田小島', '16', '16201', '9302123', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '山田小島', 'ヤマダコジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市山田中村', '16', '16201', '9302124', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '山田中村', 'ヤマダナカムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市山田今山田', '16', '16201', '9302125', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '山田今山田', 'ヤマダイマヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市山田清水', '16', '16201', '9302126', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '山田清水', 'ヤマダショウズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市山田牧', '16', '16201', '9302127', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '山田牧', 'ヤマダマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市山田沼又', '16', '16201', '9302128', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '山田沼又', 'ヤマダヌマノマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市常呂町土佐', '01', '01208', '0930213', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '常呂町土佐', 'トコロチョウトサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市常呂町共立', '01', '01208', '0930214', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '常呂町共立', 'トコロチョウキョウリツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市常呂町岐阜', '01', '01208', '0930215', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '常呂町岐阜', 'トコロチョウギフ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市常呂町栄浦', '01', '01208', '0930216', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '常呂町栄浦', 'トコロチョウサカエウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市草島', '16', '16201', '9302201', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '草島', 'クサジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市富浦町', '16', '16201', '9302202', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '富浦町', 'トミウラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市新千原崎', '16', '16201', '9302203', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '新千原崎', 'シンチハラザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市金山新桜ケ丘', '16', '16201', '9302204', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '金山新桜ケ丘', 'カナヤマシンサクラガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市金山新東', '16', '16201', '9302205', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '金山新東', 'カナヤマシンヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市金山新', '16', '16201', '9302206', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '金山新', 'カナヤマシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市金山新北', '16', '16201', '9302206', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '金山新北', 'カナヤマシンキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市金山新中', '16', '16201', '9302206', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '金山新中', 'カナヤマシンナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市金山新西', '16', '16201', '9302206', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '金山新西', 'カナヤマシンニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市金山新南', '16', '16201', '9302206', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '金山新南', 'カナヤマシンミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市草島新町', '16', '16201', '9302207', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '草島新町', 'クサジマシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市古川', '16', '16201', '9302208', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '古川', 'フルカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市宮尾', '16', '16201', '9302211', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '宮尾', 'ミヤオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市松木新', '16', '16201', '9302212', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '松木新', 'マツノキシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市松木', '16', '16201', '9302213', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '松木', 'マツノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市百塚', '16', '16201', '9302214', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '百塚', 'ヒャクヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市山岸', '16', '16201', '9302215', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '山岸', 'ヤマギシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市今市', '16', '16201', '9302221', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '今市', 'イマイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八幡', '16', '16201', '9302222', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八幡', 'ヤハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八幡新町', '16', '16201', '9302223', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八幡新町', 'ヤハタシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市田尻', '16', '16201', '9302224', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '田尻', 'タノシリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市田尻西', '16', '16201', '9302224', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '田尻西', 'タノシリニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市田尻東', '16', '16201', '9302224', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '田尻東', 'タノシリヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市田尻南', '16', '16201', '9302224', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '田尻南', 'タノシリミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市寺島', '16', '16201', '9302225', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '寺島', 'テラシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八町', '16', '16201', '9302226', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八町', 'ハッチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八町北', '16', '16201', '9302226', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八町北', 'ハッチョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八町中', '16', '16201', '9302226', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八町中', 'ハッチョウナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八町西', '16', '16201', '9302226', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八町西', 'ハッチョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八町東', '16', '16201', '9302226', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八町東', 'ハッチョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八町南', '16', '16201', '9302226', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八町南', 'ハッチョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市利波', '16', '16201', '9302227', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '利波', 'トナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市布目東町', '16', '16201', '9302231', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '布目東町', 'ヌノメヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市布目南町', '16', '16201', '9302232', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '布目南町', 'ヌノメミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市布目', '16', '16201', '9302233', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '布目', 'ヌノメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市布目北', '16', '16201', '9302233', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '布目北', 'ヌノメキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市布目西', '16', '16201', '9302233', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '布目西', 'ヌノメニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市布目緑町', '16', '16201', '9302234', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '布目緑町', 'ヌノメミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市布目新町', '16', '16201', '9302235', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '布目新町', 'ヌノメシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市布目旭', '16', '16201', '9302236', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '布目旭', 'ヌノメアサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市打出', '16', '16201', '9302237', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '打出', 'ウチイデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市打出新', '16', '16201', '9302238', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '打出新', 'ウチイデシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市つばめ野', '16', '16201', '9302239', '富山県', 'トヤマケン', '富山市', 'トヤマシ', 'つばめ野', 'ツバメノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市四方西岩瀬', '16', '16201', '9302241', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '四方西岩瀬', 'ヨカタニシイワセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市四方北窪', '16', '16201', '9302242', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '四方北窪', 'ヨカタキタクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市四方', '16', '16201', '9302243', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '四方', 'ヨカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市四方荒屋', '16', '16201', '9302243', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '四方荒屋', 'ヨカタアラヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市四方茶園町', '16', '16201', '9302244', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '四方茶園町', 'ヨカタチャエンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市四方江代町', '16', '16201', '9302245', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '四方江代町', 'ヨカタエダイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市四方新', '16', '16201', '9302246', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '四方新', 'ヨカタシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市四方新出町', '16', '16201', '9302247', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '四方新出町', 'ヨカタシンデマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市四方南町', '16', '16201', '9302248', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '四方南町', 'ヨカタミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市四方東野割町', '16', '16201', '9302251', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '四方東野割町', 'ヨカタヒガシノワリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市四方西野割町', '16', '16201', '9302252', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '四方西野割町', 'ヨカタニシノワリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市四方野割町', '16', '16201', '9302252', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '四方野割町', 'ヨカタノワリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市四方田町', '16', '16201', '9302253', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '四方田町', 'ヨカタタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市四方神明町', '16', '16201', '9302254', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '四方神明町', 'ヨカタシンメイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市四方一番町', '16', '16201', '9302255', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '四方一番町', 'ヨカタイチバンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市四方港町', '16', '16201', '9302256', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '四方港町', 'ヨカタミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市四方二番町', '16', '16201', '9302257', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '四方二番町', 'ヨカタニバンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市四方恵比須町', '16', '16201', '9302258', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '四方恵比須町', 'ヨカタエビスマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走市能取', '01', '01211', '0930241', '北海道', 'ホッカイドウ', '網走市', 'アバシリシ', '能取', 'ノトリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町高原', '16', '16323', '9303201', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '高原', 'タカハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町女川新', '16', '16323', '9303202', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '女川新', 'オナガワシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町上福来', '16', '16323', '9303203', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '上福来', 'カミフクライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町東野', '16', '16323', '9303204', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '東野', 'ヒガシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町福来', '16', '16323', '9303205', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '福来', 'フクライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町竹林', '16', '16323', '9303206', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '竹林', 'タケバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町下新', '16', '16323', '9303208', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '下新', 'シモシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町日中', '16', '16323', '9303211', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '日中', 'ニッチュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町柴山', '16', '16323', '9303212', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '柴山', 'シバヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町日中上野', '16', '16323', '9303213', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '日中上野', 'ニッチュウウワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町下白岩', '16', '16323', '9303214', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '下白岩', 'シモシライワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町石坂', '16', '16323', '9303215', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '石坂', 'イシザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町福田', '16', '16323', '9303216', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '福田', 'フクタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町野沢', '16', '16323', '9303217', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '野沢', 'ノザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町四谷尾', '16', '16323', '9303221', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '四谷尾', 'シダニオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町谷口', '16', '16323', '9303222', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '谷口', 'タニグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町虫谷', '16', '16323', '9303223', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '虫谷', 'ムシタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町白岩', '16', '16323', '9303224', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '白岩', 'シライワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町六郎谷', '16', '16323', '9303231', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '六郎谷', 'ロクロウダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町目桑', '16', '16323', '9303232', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '目桑', 'メッカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町谷', '16', '16323', '9303233', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '谷', 'タニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町伊勢屋', '16', '16323', '9303234', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '伊勢屋', 'イセヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町長倉', '16', '16323', '9303235', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '長倉', 'ナガクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町小又', '16', '16323', '9303236', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '小又', 'オマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町松倉', '16', '16323', '9303237', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '松倉', 'マツクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町座主坊', '16', '16323', '9303238', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '座主坊', 'ザシュウボウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町池田', '16', '16323', '9303239', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '池田', 'イケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町下沢', '16', '16323', '9303241', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '下沢', 'シモザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町芦見', '16', '16323', '9303242', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '芦見', 'アシミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町下瀬戸', '16', '16323', '9303243', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '下瀬戸', 'シモセト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町上瀬戸', '16', '16323', '9303244', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '上瀬戸', 'カミセト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町上末', '16', '16323', '9303245', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '上末', 'ウワズエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町中林', '16', '16323', '9303246', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '中林', 'ナカバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町瀬戸新', '16', '16323', '9303247', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '瀬戸新', 'セトシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町新瀬戸', '16', '16323', '9303248', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '新瀬戸', 'シンセト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町上中', '16', '16323', '9303251', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '上中', 'カミナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町末上野', '16', '16323', '9303252', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '末上野', 'スエウワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町長屋', '16', '16323', '9303253', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '長屋', 'ナガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町上宮', '16', '16323', '9303254', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '上宮', 'カミミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町小林', '16', '16323', '9303255', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '小林', 'コバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町野町', '16', '16323', '9303261', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '野町', 'ノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町金剛新', '16', '16323', '9303262', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '金剛新', 'コンゴウシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町淵上', '16', '16323', '9303263', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '淵上', 'フチガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町沢新', '16', '16323', '9303264', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '沢新', 'サワシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町米沢', '16', '16323', '9303265', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '米沢', 'ヨネザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町前沢新', '16', '16323', '9303266', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '前沢新', 'マエザワシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町江崎', '16', '16323', '9303267', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '江崎', 'エサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡立山町横江高野地区', '16', '16323', '9303277', '富山県', 'トヤマケン', '中新川郡立山町', 'ナカニイカワグンタテヤママチ', '横江', 'ヨコエ', null, null, '高野地区', 'タカノチク');
INSERT INTO `ms_addresses` VALUES ('126501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市常呂町豊川', '01', '01208', '0930331', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '常呂町豊川', 'トコロチョウトヨカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市常呂町富丘', '01', '01208', '0930332', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '常呂町富丘', 'トコロチョウトミオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市常呂町福山', '01', '01208', '0930333', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '常呂町福山', 'トコロチョウフクヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市常呂町日吉', '01', '01208', '0930334', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '常呂町日吉', 'トコロチョウヒヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市常呂町吉野', '01', '01208', '0930335', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '常呂町吉野', 'トコロチョウヨシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市常呂町登', '01', '01208', '0930336', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '常呂町登', 'トコロチョウノボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道常呂郡佐呂間町浪速', '01', '01552', '0930421', '北海道', 'ホッカイドウ', '常呂郡佐呂間町', 'トコログンサロマチョウ', '浪速', 'ナニワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道常呂郡佐呂間町幌岩', '01', '01552', '0930422', '北海道', 'ホッカイドウ', '常呂郡佐呂間町', 'トコログンサロマチョウ', '幌岩', 'ホロイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道常呂郡佐呂間町浜佐呂間', '01', '01552', '0930423', '北海道', 'ホッカイドウ', '常呂郡佐呂間町', 'トコログンサロマチョウ', '浜佐呂間', 'ハマサロマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道常呂郡佐呂間町仁倉', '01', '01552', '0930424', '北海道', 'ホッカイドウ', '常呂郡佐呂間町', 'トコログンサロマチョウ', '仁倉', 'ニクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道常呂郡佐呂間町', '01', '01552', '0930500', '北海道', 'ホッカイドウ', '常呂郡佐呂間町', 'トコログンサロマチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('126512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道常呂郡佐呂間町宮前町', '01', '01552', '0930501', '北海道', 'ホッカイドウ', '常呂郡佐呂間町', 'トコログンサロマチョウ', '宮前町', 'ミヤマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道常呂郡佐呂間町永代町', '01', '01552', '0930502', '北海道', 'ホッカイドウ', '常呂郡佐呂間町', 'トコログンサロマチョウ', '永代町', 'エイダイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道常呂郡佐呂間町幸町', '01', '01552', '0930503', '北海道', 'ホッカイドウ', '常呂郡佐呂間町', 'トコログンサロマチョウ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道常呂郡佐呂間町西富', '01', '01552', '0930504', '北海道', 'ホッカイドウ', '常呂郡佐呂間町', 'トコログンサロマチョウ', '西富', 'ニシトミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道常呂郡佐呂間町北', '01', '01552', '0930505', '北海道', 'ホッカイドウ', '常呂郡佐呂間町', 'トコログンサロマチョウ', '北', 'キタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道常呂郡佐呂間町富武士', '01', '01552', '0930506', '北海道', 'ホッカイドウ', '常呂郡佐呂間町', 'トコログンサロマチョウ', '富武士', 'トップシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道常呂郡佐呂間町東', '01', '01552', '0930507', '北海道', 'ホッカイドウ', '常呂郡佐呂間町', 'トコログンサロマチョウ', '東', 'ヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道常呂郡佐呂間町知来', '01', '01552', '0930508', '北海道', 'ホッカイドウ', '常呂郡佐呂間町', 'トコログンサロマチョウ', '知来', 'チライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道常呂郡佐呂間町若里', '01', '01552', '0930532', '北海道', 'ホッカイドウ', '常呂郡佐呂間町', 'トコログンサロマチョウ', '若里', 'ワカサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡湧別町計呂地', '01', '01559', '0930651', '北海道', 'ホッカイドウ', '紋別郡湧別町', 'モンベツグンユウベツチョウ', '計呂地', 'ケロチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡湧別町志撫子', '01', '01559', '0930652', '北海道', 'ホッカイドウ', '紋別郡湧別町', 'モンベツグンユウベツチョウ', '志撫子', 'シブシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡湧別町芭露', '01', '01559', '0930731', '北海道', 'ホッカイドウ', '紋別郡湧別町', 'モンベツグンユウベツチョウ', '芭露', 'バロウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡湧別町上芭露', '01', '01559', '0930732', '北海道', 'ホッカイドウ', '紋別郡湧別町', 'モンベツグンユウベツチョウ', '上芭露', 'カミバロウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡湧別町西芭露', '01', '01559', '0930733', '北海道', 'ホッカイドウ', '紋別郡湧別町', 'モンベツグンユウベツチョウ', '西芭露', 'ニシバロウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡湧別町東芭露', '01', '01559', '0930734', '北海道', 'ホッカイドウ', '紋別郡湧別町', 'モンベツグンユウベツチョウ', '東芭露', 'ヒガシバロウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡湧別町福島', '01', '01559', '0930735', '北海道', 'ホッカイドウ', '紋別郡湧別町', 'モンベツグンユウベツチョウ', '福島', 'フクシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水落', '16', '16201', '9318301', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水落', 'ミズオチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市緑陽町', '16', '16201', '9318302', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '緑陽町', 'リョクヨウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市米田', '16', '16201', '9318303', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '米田', 'ヨネダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市米田町', '16', '16201', '9318304', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '米田町', 'ヨネダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市豊若町', '16', '16201', '9318305', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '豊若町', 'トヨワカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市米田すずかけ台', '16', '16201', '9318306', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '米田すずかけ台', 'ヨネダスズカケダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市豊田', '16', '16201', '9318311', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '豊田', 'トヨタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市豊田本町', '16', '16201', '9318312', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '豊田本町', 'トヨタホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市豊田町', '16', '16201', '9318313', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '豊田町', 'トヨタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市粟島町', '16', '16201', '9318314', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '粟島町', 'アワジママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市高園町', '16', '16201', '9318315', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '高園町', 'タカゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市豊丘町', '16', '16201', '9318316', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '豊丘町', 'トヨオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市犬島', '16', '16201', '9318321', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '犬島', 'イヌジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市豊島町', '16', '16201', '9318322', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '豊島町', 'トヨシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市豊城新町', '16', '16201', '9318323', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '豊城新町', 'トヨシロシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市豊城町', '16', '16201', '9318324', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '豊城町', 'トヨシロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市城川原', '16', '16201', '9318325', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '城川原', 'ジョウガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市上野新町', '16', '16201', '9318326', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '上野新町', 'ウワノシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市上野新', '16', '16201', '9318327', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '上野新', 'ウワノシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市犬島新町', '16', '16201', '9318328', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '犬島新町', 'イヌジマシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市森住町', '16', '16201', '9318331', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '森住町', 'モリズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市森', '16', '16201', '9318332', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '森', 'モリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市蓮町', '16', '16201', '9318333', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '蓮町', 'ハスマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市千原崎', '16', '16201', '9318334', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '千原崎', 'チハラザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市西宮町', '16', '16201', '9318335', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '西宮町', 'ニシノミヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市高畠町', '16', '16201', '9318336', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '高畠町', 'タカバタケマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市森若町', '16', '16201', '9318337', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '森若町', 'モリワカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市岩瀬御蔵町', '16', '16201', '9318341', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '岩瀬御蔵町', 'イワセオクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市岩瀬神明町', '16', '16201', '9318342', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '岩瀬神明町', 'イワセシンメイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市岩瀬幸町', '16', '16201', '9318343', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '岩瀬幸町', 'イワセサイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市岩瀬新町', '16', '16201', '9318344', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '岩瀬新町', 'イワセシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市西宮', '16', '16201', '9318345', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '西宮', 'ニシミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市岩瀬荒木町', '16', '16201', '9318346', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '岩瀬荒木町', 'イワセアラキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市岩瀬土場町', '16', '16201', '9318347', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '岩瀬土場町', 'イワセドバマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市岩瀬堺町', '16', '16201', '9318351', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '岩瀬堺町', 'イワセサカイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市岩瀬表町', '16', '16201', '9318352', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '岩瀬表町', 'イワセオモテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市岩瀬文化町', '16', '16201', '9318353', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '岩瀬文化町', 'イワセブンカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市岩瀬祇園町', '16', '16201', '9318354', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '岩瀬祇園町', 'イワセギオンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市岩瀬新川町', '16', '16201', '9318355', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '岩瀬新川町', 'イワセニイカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市岩瀬大町', '16', '16201', '9318356', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '岩瀬大町', 'イワセオオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市岩瀬福来町', '16', '16201', '9318357', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '岩瀬福来町', 'イワセフクライマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市東岩瀬町', '16', '16201', '9318358', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '東岩瀬町', 'ヒガシイワセマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市東岩瀬村', '16', '16201', '9318359', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '東岩瀬村', 'ヒガシイワセムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市岩瀬白山町', '16', '16201', '9318361', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '岩瀬白山町', 'イワセハクサンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市岩瀬梅本町', '16', '16201', '9318362', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '岩瀬梅本町', 'イワセウメモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市岩瀬仲町', '16', '16201', '9318363', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '岩瀬仲町', 'イワセナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市岩瀬港町', '16', '16201', '9318364', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '岩瀬港町', 'イワセミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市岩瀬入船町', '16', '16201', '9318365', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '岩瀬入船町', 'イワセイリフネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市岩瀬萩浦町', '16', '16201', '9318366', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '岩瀬萩浦町', 'イワセハギウラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市岩瀬松原町', '16', '16201', '9318367', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '岩瀬松原町', 'イワセマツバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市岩瀬古志町', '16', '16201', '9318371', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '岩瀬古志町', 'イワセコシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市岩瀬天池町', '16', '16201', '9318372', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '岩瀬天池町', 'イワセアマイケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市岩瀬前田町', '16', '16201', '9318373', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '岩瀬前田町', 'イワセマエダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市岩瀬赤田町', '16', '16201', '9318374', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '岩瀬赤田町', 'イワセアカダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市岩瀬高畠町', '16', '16201', '9318375', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '岩瀬高畠町', 'イワセタカバタケマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市岩瀬池田町', '16', '16201', '9318376', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '岩瀬池田町', 'イワセイケダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市岩瀬諏訪町', '16', '16201', '9318377', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '岩瀬諏訪町', 'イワセスワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市岩瀬天神町', '16', '16201', '9318378', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '岩瀬天神町', 'イワセテンジンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市田畑新町', '16', '16201', '9318401', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '田畑新町', 'タバタシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市田畑北部', '16', '16201', '9318402', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '田畑北部', 'タバタホクブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市田畑', '16', '16201', '9318403', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '田畑', 'タバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市加古町', '16', '16201', '9318404', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '加古町', 'カコマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市海岸通', '16', '16201', '9318405', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '海岸通', 'カイガンドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市松浦町', '16', '16201', '9318406', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '松浦町', 'マツウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市海岸通新町', '16', '16201', '9318407', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '海岸通新町', 'カイガンドオリシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市那智町', '16', '16201', '9318408', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '那智町', 'ナチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市清風町', '16', '16201', '9318409', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '清風町', 'セイフウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市高来', '16', '16201', '9318411', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '高来', 'コウライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市横越', '16', '16201', '9318412', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '横越', 'ヨコゴシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市野田', '16', '16201', '9318413', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '野田', 'ノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市浜黒崎', '16', '16201', '9318414', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '浜黒崎', 'ハマクロサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市針日', '16', '16201', '9318415', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '針日', 'ハリヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市日方江', '16', '16201', '9318416', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '日方江', 'ヒカタエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市古志町', '16', '16201', '9318417', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '古志町', 'コシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市平榎', '16', '16201', '9318421', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '平榎', 'ヒラエノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市野中', '16', '16201', '9318422', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '野中', 'ノナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市町袋', '16', '16201', '9318423', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '町袋', 'マチブクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市宮成', '16', '16201', '9318425', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '宮成', 'ミヤナリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市宮成中部', '16', '16201', '9318426', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '宮成中部', 'ミヤナリチュウブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市宮条', '16', '16201', '9318427', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '宮条', 'ミヤジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市野中新', '16', '16201', '9318428', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '野中新', 'ノナカシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市針原中町', '16', '16201', '9318431', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '針原中町', 'ハリワラナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市針原中', '16', '16201', '9318432', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '針原中', 'ハリワラナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市針原新町', '16', '16201', '9318433', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '針原新町', 'ハリワラシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市三上', '16', '16201', '9318434', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '三上', 'ミカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市小西', '16', '16201', '9318435', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '小西', 'コニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市宮園町', '16', '16201', '9318436', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '宮園町', 'ミヤゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市宮町', '16', '16201', '9318437', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '宮町', 'ミヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市高島', '16', '16201', '9318441', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '高島', 'タカシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市楠木', '16', '16201', '9318442', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '楠木', 'クスノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市下飯野', '16', '16201', '9318443', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '下飯野', 'シモイイノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市東ケ丘', '16', '16201', '9318444', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '東ケ丘', 'ヒガシガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市道正', '16', '16201', '9318445', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '道正', 'ドウショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市銀嶺町', '16', '16201', '9318451', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '銀嶺町', 'ギンレイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市東富山寿町', '16', '16201', '9318452', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '東富山寿町', 'ヒガシトヤマコトブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市中田', '16', '16201', '9318453', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '中田', 'ナカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市住友町', '16', '16201', '9318454', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '住友町', 'スミトモチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市晴海台', '16', '16201', '9318455', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '晴海台', 'ハルミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市永久町', '16', '16201', '9318456', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '永久町', 'トワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市', '16', '16209', '9320000', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('126727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市久利須', '16', '16209', '9320001', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '久利須', 'クリス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市森屋', '16', '16209', '9320002', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '森屋', 'モリヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市北屋敷', '16', '16209', '9320003', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '北屋敷', 'キタヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市二ノ滝', '16', '16209', '9320004', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '二ノ滝', 'ニノタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市下屋敷', '16', '16209', '9320005', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '下屋敷', 'シモヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市高坂', '16', '16209', '9320006', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '高坂', 'タカサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市名ケ滝', '16', '16209', '9320007', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '名ケ滝', 'ミョウガダキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市菅ケ原', '16', '16209', '9320008', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '菅ケ原', 'スガハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市原牧', '16', '16209', '9320011', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '原牧', 'ハラマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市嶺', '16', '16209', '9320012', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '嶺', 'ミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市清原', '16', '16209', '9320013', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '清原', 'キヨハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市岩崎', '16', '16209', '9320014', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '岩崎', 'イワサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市矢波', '16', '16209', '9320015', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '矢波', 'ヤナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市糠子島', '16', '16209', '9320016', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '糠子島', 'ヌカゴジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市了輪', '16', '16209', '9320017', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '了輪', 'リョウワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市別所滝', '16', '16209', '9320018', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '別所滝', 'ベッショダキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市田川', '16', '16209', '9320021', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '田川', 'タガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市桜町', '16', '16209', '9320022', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '桜町', 'サクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市横谷', '16', '16209', '9320023', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '横谷', 'ヨコダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市屋波牧', '16', '16209', '9320024', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '屋波牧', 'ヤナミマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市宮中', '16', '16209', '9320025', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '宮中', 'ミヤナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市宮須', '16', '16209', '9320026', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '宮須', 'ミヤス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市法楽寺', '16', '16209', '9320027', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '法楽寺', 'ホウラクジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市岡', '16', '16209', '9320031', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '岡', 'オカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市地崎', '16', '16209', '9320032', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '地崎', 'ジサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市芹川', '16', '16209', '9320033', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '芹川', 'セリカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市坂又', '16', '16209', '9320034', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '坂又', 'サカマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市西中野', '16', '16209', '9320035', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '西中野', 'ニシナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市宇治新', '16', '16209', '9320036', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '宇治新', 'ウジシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市石王丸', '16', '16209', '9320037', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '石王丸', 'イシオウマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市東福町', '16', '16209', '9320041', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '東福町', 'ヒガシフクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市西福町', '16', '16209', '9320042', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '西福町', 'ニシフクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市畠中町', '16', '16209', '9320043', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '畠中町', 'ハタケナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市新富町', '16', '16209', '9320044', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '新富町', 'シントミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市中央町', '16', '16209', '9320045', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '中央町', 'チュウオウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市観音町', '16', '16209', '9320046', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '観音町', 'カンノンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市城山町', '16', '16209', '9320047', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '城山町', 'シロヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市八和町', '16', '16209', '9320048', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '八和町', 'ヤツワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市今石動町', '16', '16209', '9320051', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '今石動町', 'イマイスルギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市泉町', '16', '16209', '9320052', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '泉町', 'イズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市石動町', '16', '16209', '9320053', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '石動町', 'イスルギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市上野本', '16', '16209', '9320054', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '上野本', 'ウワノホン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市西町', '16', '16209', '9320055', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '西町', 'ニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市小矢部', '16', '16209', '9320056', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '小矢部', 'オヤベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市本町', '16', '16209', '9320057', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市小矢部町', '16', '16209', '9320058', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '小矢部町', 'オヤベマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市道坪野', '16', '16209', '9320061', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '道坪野', 'ドウツボノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市安楽寺', '16', '16209', '9320062', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '安楽寺', 'アンラクジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市峰坪野', '16', '16209', '9320063', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '峰坪野', 'ミネツボノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市谷坪野', '16', '16209', '9320064', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '谷坪野', 'タニツボノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市論田', '16', '16209', '9320065', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '論田', 'ロンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市荒間', '16', '16209', '9320071', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '荒間', 'アラマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市峠', '16', '16209', '9320072', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '峠', 'トウゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市岩尾滝', '16', '16209', '9320073', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '岩尾滝', 'イワオダキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市千石', '16', '16209', '9320074', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '千石', 'センゴク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市嘉例谷', '16', '16209', '9320075', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '嘉例谷', 'カレイダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市下後亟', '16', '16209', '9320101', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '下後亟', 'シモゴゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市水島', '16', '16209', '9320102', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '水島', 'ミズシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市経田', '16', '16209', '9320103', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '経田', 'キョウデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市西川原', '16', '16209', '9320104', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '西川原', 'ニシガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市胡麻島', '16', '16209', '9320105', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '胡麻島', 'ゴマジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市内御堂', '16', '16209', '9320106', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '内御堂', 'ウチオンドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市新西', '16', '16209', '9320111', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '新西', 'シンニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市清沢', '16', '16209', '9320112', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '清沢', 'キヨサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市岩武', '16', '16209', '9320113', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '岩武', 'イワタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市清水', '16', '16209', '9320114', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '清水', 'シミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市津沢', '16', '16209', '9320115', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '津沢', 'ツザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市西島', '16', '16209', '9320116', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '西島', 'ニシノシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市矢水町', '16', '16209', '9320121', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '矢水町', 'ヤスイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市浅地', '16', '16209', '9320122', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '浅地', 'アサジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市高木', '16', '16209', '9320123', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '高木', 'タカキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市蓑輪', '16', '16209', '9320124', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '蓑輪', 'ミノワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市鴨島', '16', '16209', '9320125', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '鴨島', 'カモジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市下川崎', '16', '16209', '9320126', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '下川崎', 'シモガワサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市興法寺', '16', '16209', '9320127', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '興法寺', 'コウボウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市戸久', '16', '16209', '9320128', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '戸久', 'トヒサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市安養寺', '16', '16209', '9320129', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '安養寺', 'アンヨウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市名畑', '16', '16209', '9320131', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '名畑', 'ナバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市杉谷内', '16', '16209', '9320132', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '杉谷内', 'スンナイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市小森谷', '16', '16209', '9320133', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '小森谷', 'コモリダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市平桜', '16', '16209', '9320134', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '平桜', 'ヒラザクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市藤森', '16', '16209', '9320135', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '藤森', 'フジノモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市平田', '16', '16209', '9320136', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '平田', 'ヒラタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市渋江', '16', '16209', '9320137', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '渋江', 'シブエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市高屋', '16', '16210', '9320201', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '高屋', 'タカヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市清水明', '16', '16210', '9320202', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '清水明', 'シミズミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市岩屋', '16', '16210', '9320203', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '岩屋', 'イワヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市飛騨屋', '16', '16210', '9320204', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '飛騨屋', 'ヒダヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市井波軸屋', '16', '16210', '9320205', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '井波軸屋', 'イナミジクヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市安室', '16', '16210', '9320206', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '安室', 'アジツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市利屋', '16', '16210', '9320206', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '利屋', 'トギヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市専勝寺', '16', '16210', '9320207', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '専勝寺', 'センショウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市井波', '16', '16210', '9320211', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '井波', 'イナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市山斐', '16', '16210', '9320212', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '山斐', 'ヤマヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市井波栄町', '16', '16210', '9320213', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '井波栄町', 'イナミサカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市今町', '16', '16210', '9320214', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '今町', 'イママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市山下', '16', '16210', '9320215', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '山下', 'ヤマシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市井波末広町', '16', '16210', '9320216', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '井波末広町', 'イナミスエヒロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市本町', '16', '16210', '9320217', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市坪野', '16', '16210', '9320218', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '坪野', 'ツボノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市木崎野', '16', '16210', '9320221', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '木崎野', 'キザキノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市坂ノ下', '16', '16210', '9320222', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '坂ノ下', 'サカノシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市松島', '16', '16210', '9320223', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '松島', 'マツシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市藤橋', '16', '16210', '9320224', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '藤橋', 'フジハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市畑方', '16', '16210', '9320225', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '畑方', 'ハタカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市北川', '16', '16210', '9320226', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '北川', 'キタガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市北新町', '16', '16210', '9320227', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '北新町', 'キタシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市井波東町', '16', '16210', '9320228', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '井波東町', 'イナミヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市山見', '16', '16210', '9320231', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '山見', 'ヤマミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市京願町', '16', '16210', '9320232', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '京願町', 'キョウガンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市堀道', '16', '16210', '9320233', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '堀道', 'ホリミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市八日町', '16', '16210', '9320234', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '八日町', 'ヨウカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市六日町', '16', '16210', '9320235', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '六日町', 'ムイカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市三日町', '16', '16210', '9320236', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '三日町', 'ミッカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市山見町並', '16', '16210', '9320237', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '山見町並', 'ヤマミマチナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市下新町', '16', '16210', '9320238', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '下新町', 'シモアラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市川原崎', '16', '16210', '9320241', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '川原崎', 'カワラサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市谷', '16', '16210', '9320242', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '谷', 'タニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市志観寺', '16', '16210', '9320243', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '志観寺', 'シカンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市連代寺', '16', '16210', '9320244', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '連代寺', 'レンタイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市清玄寺', '16', '16210', '9320245', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '清玄寺', 'セイゲンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市東城寺', '16', '16210', '9320246', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '東城寺', 'トウジョウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市院瀬見', '16', '16210', '9320247', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '院瀬見', 'イゼミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市沖', '16', '16210', '9320248', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '沖', 'オキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市野能原', '16', '16210', '9320251', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '野能原', 'ノノウハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市高瀬', '16', '16210', '9320252', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '高瀬', 'タカセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市戸板', '16', '16210', '9320253', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '戸板', 'トイタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市五領', '16', '16210', '9320254', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '五領', 'ゴリョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市五領島', '16', '16210', '9320255', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '五領島', 'ゴリョウジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市今里', '16', '16210', '9320256', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '今里', 'イマザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市北市', '16', '16210', '9320257', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '北市', 'キタイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市三清東', '16', '16210', '9320258', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '三清東', 'サンキヨヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市庄川町三谷', '16', '16208', '9320301', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '庄川町三谷', 'ショウガワマチミタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市庄川町庄', '16', '16208', '9320302', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '庄川町庄', 'ショウガワマチショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市庄川町落シ', '16', '16208', '9320303', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '庄川町落シ', 'ショウガワマチオトシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市庄川町隠尾', '16', '16208', '9320303', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '庄川町隠尾', 'ショウガワマチカクリョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市庄川町名ケ原', '16', '16208', '9320303', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '庄川町名ケ原', 'ショウガワマチミョウガハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市庄川町湯谷', '16', '16208', '9320303', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '庄川町湯谷', 'ショウガワマチユダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市庄川町湯山', '16', '16208', '9320303', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '庄川町湯山', 'ショウガワマチユヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市庄川町横住', '16', '16208', '9320303', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '庄川町横住', 'ショウガワマチヨコズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市庄川町小牧', '16', '16208', '9320304', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '庄川町小牧', 'ショウガワマチコマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市庄川町前山', '16', '16208', '9320304', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '庄川町前山', 'ショウガワマチマエヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市庄川町金屋', '16', '16208', '9320305', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '庄川町金屋', 'ショウガワマチカナヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市庄川町古上野', '16', '16208', '9320311', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '庄川町古上野', 'ショウガワマチフルウエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市庄川町高儀新', '16', '16208', '9320312', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '庄川町高儀新', 'ショウガワマチタカギシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市庄川町五ケ', '16', '16208', '9320313', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '庄川町五ケ', 'ショウガワマチゴカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市庄川町青島', '16', '16208', '9320314', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '庄川町青島', 'ショウガワマチアオシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市庄川町示野', '16', '16208', '9320315', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '庄川町示野', 'ショウガワマチシメノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市庄川町天正', '16', '16208', '9320316', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '庄川町天正', 'ショウガワマチテンショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市庄川町筏', '16', '16208', '9320317', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '庄川町筏', 'ショウガワマチイカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市利賀村大牧', '16', '16210', '9320371', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '利賀村大牧', 'トガムラオオマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市利賀村北原', '16', '16210', '9320371', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '利賀村北原', 'トガムラキタハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市利賀村下原', '16', '16210', '9320371', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '利賀村下原', 'トガムラシモハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市利賀村栃原', '16', '16210', '9320371', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '利賀村栃原', 'トガムラトチハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市利賀村長崎', '16', '16210', '9320371', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '利賀村長崎', 'トガムラナガサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市五社', '16', '16209', '9320801', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '五社', 'ゴシャ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市七社', '16', '16209', '9320802', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '七社', 'シチシャ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市道明', '16', '16209', '9320803', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '道明', 'ドウミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市下中', '16', '16209', '9320804', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '下中', 'シモナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市西中', '16', '16209', '9320805', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '西中', 'ニシナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市水落', '16', '16209', '9320806', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '水落', 'ミズオチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市柳原', '16', '16209', '9320807', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '柳原', 'ヤナギハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市石名田', '16', '16209', '9320808', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '石名田', 'イシナダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市水牧', '16', '16209', '9320811', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '水牧', 'ミズマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市金屋本江', '16', '16209', '9320812', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '金屋本江', 'カナヤホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市野寺', '16', '16209', '9320813', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '野寺', 'ノデラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市赤倉', '16', '16209', '9320814', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '赤倉', 'アカクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市高木出', '16', '16209', '9320815', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '高木出', 'タカギデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市福久', '16', '16209', '9320816', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '福久', 'フクヒサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市小神', '16', '16209', '9320817', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '小神', 'オコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市鷲島', '16', '16209', '9320821', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '鷲島', 'ワシガシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市和沢', '16', '16209', '9320822', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '和沢', 'ワサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市福上', '16', '16209', '9320823', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '福上', 'フクガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市下島', '16', '16209', '9320824', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '下島', 'シモジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市島', '16', '16209', '9320825', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '島', 'シマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市茄子島', '16', '16209', '9320826', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '茄子島', 'ナスジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市後谷', '16', '16209', '9320831', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '後谷', 'ウシロダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市野端', '16', '16209', '9320832', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '野端', 'ノバナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市綾子', '16', '16209', '9320833', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '綾子', 'アヤコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市蓮沼', '16', '16209', '9320834', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '蓮沼', 'ハスヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市石坂', '16', '16209', '9320835', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '石坂', 'イシサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市埴生', '16', '16209', '9320836', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '埴生', 'ハニュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市吉和台', '16', '16209', '9320837', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '吉和台', 'ヨシワダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市メルヘンランド', '16', '16209', '9320838', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', 'メルヘンランド', 'メルヘンランド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市道林寺', '16', '16209', '9320841', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '道林寺', 'ドウリンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市長', '16', '16209', '9320842', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '長', 'チョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市棚田', '16', '16209', '9320843', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '棚田', 'タナダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市北一', '16', '16209', '9320844', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '北一', 'キタイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市松尾', '16', '16209', '9320845', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '松尾', 'マツオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市松永', '16', '16209', '9320846', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '松永', 'マツナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市末友', '16', '16209', '9320851', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '末友', 'スエトモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市安養寺新', '16', '16209', '9320852', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '安養寺新', 'アンヨウジシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市臼谷', '16', '16209', '9320853', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '臼谷', 'ウスタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市末沢新', '16', '16209', '9320854', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '末沢新', 'スエザワシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市川開新', '16', '16209', '9320855', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '川開新', 'カワビラキシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市フロンティアパーク', '16', '16209', '9320856', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', 'フロンティアパーク', 'フロンティアパーク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市八講田', '16', '16209', '9320861', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '八講田', 'ハッコウデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市五郎丸', '16', '16209', '9320862', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '五郎丸', 'ゴロウマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市内山', '16', '16209', '9320863', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '内山', 'ウチヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県小矢部市八伏', '16', '16209', '9320864', '富山県', 'トヤマケン', '小矢部市', 'オヤベシ', '八伏', 'ハチブセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市', '16', '16202', '9330000', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('126963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市富岡町', '16', '16202', '9330001', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '富岡町', 'トミオカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市吉久', '16', '16202', '9330002', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '吉久', 'ヨシヒサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市能町', '16', '16202', '9330003', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '能町', 'ノウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市能町東', '16', '16202', '9330004', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '能町東', 'ノウマチヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市能町南', '16', '16202', '9330005', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '能町南', 'ノウマチミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市角三島', '16', '16202', '9330006', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '角三島', 'ツノミシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市角', '16', '16202', '9330007', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '角', 'ツノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市材木町', '16', '16202', '9330008', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '材木町', 'ザイモクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市石瀬', '16', '16202', '9330011', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '石瀬', 'イシゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市美原町', '16', '16202', '9330012', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '美原町', 'ミハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市三女子', '16', '16202', '9330013', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '三女子', 'サンヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市野村', '16', '16202', '9330014', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '野村', 'ノムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市明園町', '16', '16202', '9330015', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '明園町', 'アケゾノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市大野', '16', '16202', '9330016', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '大野', 'オオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市前田町', '16', '16202', '9330017', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '前田町', 'マエダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市高陵町', '16', '16202', '9330018', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '高陵町', 'コウリョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市下関町', '16', '16202', '9330021', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '下関町', 'シモゼキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市白金町', '16', '16202', '9330022', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '白金町', 'シロガネマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市末広町', '16', '16202', '9330023', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '末広町', 'スエヒロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市宮脇町', '16', '16202', '9330024', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '宮脇町', 'ミヤワキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市片原横町', '16', '16202', '9330025', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '片原横町', 'カタハラヨコマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市片原町', '16', '16202', '9330026', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '片原町', 'カタハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市片原中島町', '16', '16202', '9330027', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '片原中島町', 'カタハラナカジママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市大福院', '16', '16202', '9330028', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '大福院', 'ダイフクイン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市御旅屋町', '16', '16202', '9330029', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '御旅屋町', 'オタヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市中央町', '16', '16202', '9330030', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '中央町', 'チュウオウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市中川町', '16', '16202', '9330031', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '中川町', 'ナカガワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市定塚町', '16', '16202', '9330032', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '定塚町', 'ジョウヅカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市東下関', '16', '16202', '9330033', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '東下関', 'ヒガシシモゼキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市大仏町', '16', '16202', '9330034', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '大仏町', 'ダイブツマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市新横町', '16', '16202', '9330035', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '新横町', 'シンヨコマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市桐木町', '16', '16202', '9330036', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '桐木町', 'キリノキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市定塚', '16', '16202', '9330037', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '定塚', 'ジョウヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市坂下町', '16', '16202', '9330038', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '坂下町', 'サカシタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市大手町', '16', '16202', '9330039', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '大手町', 'オオテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市城東', '16', '16202', '9330041', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '城東', 'ジョウトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('126999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市中川栄町', '16', '16202', '9330042', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '中川栄町', 'ナカガワサカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市中川上町', '16', '16202', '9330043', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '中川上町', 'ナカガワカミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市古城', '16', '16202', '9330044', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '古城', 'コジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市本丸町', '16', '16202', '9330045', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '本丸町', 'ホンマルマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市中川本町', '16', '16202', '9330046', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '中川本町', 'ナカガワホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市東中川町', '16', '16202', '9330047', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '東中川町', 'ヒガシナカガワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市東野', '16', '16202', '9330051', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '東野', 'ヒガシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市北定塚', '16', '16202', '9330052', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '北定塚', 'キタジョウヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市城北町', '16', '16202', '9330053', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '城北町', 'ジョウホクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市古定塚', '16', '16202', '9330054', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '古定塚', 'フルジョウヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市中川園町', '16', '16202', '9330055', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '中川園町', 'ナカガワソノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市中川', '16', '16202', '9330056', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '中川', 'ナカガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市広小路', '16', '16202', '9330057', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '広小路', 'ヒロコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市川口宮袋', '16', '16211', '9330058', '富山県', 'トヤマケン', '射水市', 'イミズシ', '川口宮袋', 'カワグチミヤブクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市青葉町', '16', '16202', '9330061', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '青葉町', 'アオバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市江尻', '16', '16202', '9330062', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '江尻', 'エジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市鶴寄町', '16', '16202', '9330063', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '鶴寄町', 'ツルヨセマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市宝町', '16', '16202', '9330064', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '宝町', 'タカラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市江尻白山町', '16', '16202', '9330065', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '江尻白山町', 'エジリシラヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市春日丘', '16', '16202', '9330066', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '春日丘', 'カスガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市高伏町', '16', '16202', '9330067', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '高伏町', 'コウフクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市鷲北新', '16', '16202', '9330071', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '鷲北新', 'ワシキタシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市旭ケ丘', '16', '16202', '9330072', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '旭ケ丘', 'アサヒガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市荻布', '16', '16202', '9330073', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '荻布', 'オギノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市荻布新町', '16', '16202', '9330074', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '荻布新町', 'オギノシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市新能町', '16', '16202', '9330075', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '新能町', 'シンノウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市米島', '16', '16202', '9330076', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '米島', 'ヨネジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市能町駅南', '16', '16202', '9330077', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '能町駅南', 'ノウマチエキナン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市荻布四つ葉町', '16', '16202', '9330078', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '荻布四つ葉町', 'オギノヨツバマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市伏木国分', '16', '16202', '9330101', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '伏木国分', 'フシキコクブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市伏木磯町', '16', '16202', '9330102', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '伏木磯町', 'フシキイソマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市伏木中央町', '16', '16202', '9330103', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '伏木中央町', 'フシキチュウオウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市伏木湊町', '16', '16202', '9330104', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '伏木湊町', 'フシキミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市伏木錦町', '16', '16202', '9330105', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '伏木錦町', 'フシキニシキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市伏木本町', '16', '16202', '9330106', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '伏木本町', 'フシキホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市伏木東一宮', '16', '16202', '9330111', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '伏木東一宮', 'フシキヒガシイチノミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市伏木古国府', '16', '16202', '9330112', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '伏木古国府', 'フシキフルコクフ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市伏木', '16', '16202', '9330113', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '伏木', 'フシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市伏木古府', '16', '16202', '9330114', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '伏木古府', 'フシキコフ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市伏木古府元町', '16', '16202', '9330115', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '伏木古府元町', 'フシキコフモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市伏木一宮', '16', '16202', '9330116', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '伏木一宮', 'フシキイチノミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市伏木矢田新町', '16', '16202', '9330121', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '伏木矢田新町', 'フシキヤタシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市伏木矢田上町', '16', '16202', '9330122', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '伏木矢田上町', 'フシキヤタカミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市伏木矢田', '16', '16202', '9330123', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '伏木矢田', 'フシキヤタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市高美町', '16', '16202', '9330124', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '高美町', 'タカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市伏木矢田万葉台', '16', '16202', '9330125', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '伏木矢田', 'フシキヤタ', null, null, '万葉台', 'マンヨウダイ');
INSERT INTO `ms_addresses` VALUES ('127045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市城光寺', '16', '16202', '9330126', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '城光寺', 'ジョウコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市太田伊勢領', '16', '16202', '9330131', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '太田伊勢領', 'オオタイセリョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市太田中村', '16', '16202', '9330132', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '太田', 'オオタ', null, null, '中村', 'ナカムラ');
INSERT INTO `ms_addresses` VALUES ('127048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市太田', '16', '16202', '9330133', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '太田', 'オオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市太田辰ノ口', '16', '16202', '9330134', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '太田', 'オオタ', null, null, '辰ノ口', 'タツノクチ');
INSERT INTO `ms_addresses` VALUES ('127050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市太田旦保', '16', '16202', '9330134', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '太田', 'オオタ', null, null, '旦保', 'タンボ');
INSERT INTO `ms_addresses` VALUES ('127051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市太田雨晴', '16', '16202', '9330135', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '太田', 'オオタ', null, null, '雨晴', 'アマハラ');
INSERT INTO `ms_addresses` VALUES ('127052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市渋谷', '16', '16202', '9330136', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '渋谷', 'シブヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市太田谷内', '16', '16202', '9330137', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '太田谷内', 'オオタヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市西田', '16', '16202', '9330137', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '西田', 'サイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市太田山岸', '16', '16202', '9330138', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '太田山岸', 'オオタヤマギシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市山屋', '16', '16211', '9330201', '富山県', 'トヤマケン', '射水市', 'イミズシ', '山屋', 'ヤマヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市下村三箇', '16', '16211', '9330202', '富山県', 'トヤマケン', '射水市', 'イミズシ', '下村三箇', 'シモムラサンガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市加茂東部', '16', '16211', '9330203', '富山県', 'トヤマケン', '射水市', 'イミズシ', '加茂東部', 'カモトウブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市加茂中部', '16', '16211', '9330204', '富山県', 'トヤマケン', '射水市', 'イミズシ', '加茂中部', 'カモチュウブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市加茂西部', '16', '16211', '9330205', '富山県', 'トヤマケン', '射水市', 'イミズシ', '加茂西部', 'カモセイブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市倉垣小杉', '16', '16211', '9330206', '富山県', 'トヤマケン', '射水市', 'イミズシ', '倉垣小杉', 'クラガキコスギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市白石', '16', '16211', '9330207', '富山県', 'トヤマケン', '射水市', 'イミズシ', '白石', 'シライシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市八講', '16', '16211', '9330208', '富山県', 'トヤマケン', '射水市', 'イミズシ', '八講', 'ハッコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市摺出寺', '16', '16211', '9330209', '富山県', 'トヤマケン', '射水市', 'イミズシ', '摺出寺', 'スリデジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市堀岡新明神', '16', '16211', '9330221', '富山県', 'トヤマケン', '射水市', 'イミズシ', '堀岡新明神', 'ホリオカシンミョウジン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市海竜町', '16', '16211', '9330222', '富山県', 'トヤマケン', '射水市', 'イミズシ', '海竜町', 'カイリュウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市堀岡', '16', '16211', '9330223', '富山県', 'トヤマケン', '射水市', 'イミズシ', '堀岡', 'ホリオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市堀岡古明神', '16', '16211', '9330224', '富山県', 'トヤマケン', '射水市', 'イミズシ', '堀岡古明神', 'ホリオカフルミョウジン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市草岡町', '16', '16211', '9330225', '富山県', 'トヤマケン', '射水市', 'イミズシ', '草岡町', 'クサオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市堀江千石', '16', '16211', '9330226', '富山県', 'トヤマケン', '射水市', 'イミズシ', '堀江千石', 'ホリエセンゴク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市射水町', '16', '16211', '9330227', '富山県', 'トヤマケン', '射水市', 'イミズシ', '射水町', 'イミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市堀岡明神新', '16', '16211', '9330228', '富山県', 'トヤマケン', '射水市', 'イミズシ', '堀岡明神新', 'ホリオカミョウジンシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市海老江浜開', '16', '16211', '9330231', '富山県', 'トヤマケン', '射水市', 'イミズシ', '海老江浜開', 'エビエハマビラキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市浜開新町', '16', '16211', '9330232', '富山県', 'トヤマケン', '射水市', 'イミズシ', '浜開新町', 'ハマビラキシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市海老江', '16', '16211', '9330233', '富山県', 'トヤマケン', '射水市', 'イミズシ', '海老江', 'エビエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市海老江七軒', '16', '16211', '9330234', '富山県', 'トヤマケン', '射水市', 'イミズシ', '海老江七軒', 'エビエシチケン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市海老江練合', '16', '16211', '9330235', '富山県', 'トヤマケン', '射水市', 'イミズシ', '海老江練合', 'エビエネリヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市東明七軒', '16', '16211', '9330236', '富山県', 'トヤマケン', '射水市', 'イミズシ', '東明七軒', 'トウメイシチケン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市東明東町', '16', '16211', '9330237', '富山県', 'トヤマケン', '射水市', 'イミズシ', '東明東町', 'トウメイヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市東明中町', '16', '16211', '9330238', '富山県', 'トヤマケン', '射水市', 'イミズシ', '東明中町', 'トウメイナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市東明西町', '16', '16211', '9330239', '富山県', 'トヤマケン', '射水市', 'イミズシ', '東明西町', 'トウメイニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市かもめ台', '16', '16211', '9330240', '富山県', 'トヤマケン', '射水市', 'イミズシ', 'かもめ台', 'カモメダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市足洗新町', '16', '16211', '9330241', '富山県', 'トヤマケン', '射水市', 'イミズシ', '足洗新町', 'アシアライシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市本江針山開', '16', '16211', '9330242', '富山県', 'トヤマケン', '射水市', 'イミズシ', '本江針山開', 'ホンゴウハリヤマビラキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市本江足洗', '16', '16211', '9330243', '富山県', 'トヤマケン', '射水市', 'イミズシ', '本江', 'ホンゴウ', null, null, '足洗', 'アシアライ');
INSERT INTO `ms_addresses` VALUES ('127089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市本江', '16', '16211', '9330244', '富山県', 'トヤマケン', '射水市', 'イミズシ', '本江', 'ホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市本江北', '16', '16211', '9330244', '富山県', 'トヤマケン', '射水市', 'イミズシ', '本江北', 'ホンゴウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市本江三箇', '16', '16211', '9330244', '富山県', 'トヤマケン', '射水市', 'イミズシ', '本江三箇', 'ホンゴウサンガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市本江中', '16', '16211', '9330244', '富山県', 'トヤマケン', '射水市', 'イミズシ', '本江中', 'ホンゴウナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市本江西', '16', '16211', '9330244', '富山県', 'トヤマケン', '射水市', 'イミズシ', '本江西', 'ホンゴウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市本江後新', '16', '16211', '9330244', '富山県', 'トヤマケン', '射水市', 'イミズシ', '本江後新', 'ホンゴウノチシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市本江東', '16', '16211', '9330244', '富山県', 'トヤマケン', '射水市', 'イミズシ', '本江東', 'ホンゴウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市本江南', '16', '16211', '9330244', '富山県', 'トヤマケン', '射水市', 'イミズシ', '本江南', 'ホンゴウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市本江利波', '16', '16211', '9330245', '富山県', 'トヤマケン', '射水市', 'イミズシ', '本江利波', 'ホンゴウトナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市本江道番', '16', '16211', '9330246', '富山県', 'トヤマケン', '射水市', 'イミズシ', '本江', 'ホンゴウ', null, null, '道番', 'ミチバン');
INSERT INTO `ms_addresses` VALUES ('127099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市本江中新', '16', '16211', '9330247', '富山県', 'トヤマケン', '射水市', 'イミズシ', '本江中新', 'ホンゴウナカシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市本江針山', '16', '16211', '9330248', '富山県', 'トヤマケン', '射水市', 'イミズシ', '本江針山', 'ホンゴウハリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市本江針山新', '16', '16211', '9330249', '富山県', 'トヤマケン', '射水市', 'イミズシ', '本江針山新', 'ホンゴウハリヤマシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市有磯', '16', '16211', '9330251', '富山県', 'トヤマケン', '射水市', 'イミズシ', '有磯', 'アリソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市七美', '16', '16211', '9330252', '富山県', 'トヤマケン', '射水市', 'イミズシ', '七美', 'シチミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市七美中野', '16', '16211', '9330253', '富山県', 'トヤマケン', '射水市', 'イミズシ', '七美中野', 'シチミナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市勝木原', '16', '16202', '9330301', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '勝木原', 'ノデワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市西広谷', '16', '16202', '9330302', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '西広谷', 'ニシヒロタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市山川', '16', '16202', '9330303', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '山川', 'ヤマカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市境', '16', '16202', '9330304', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '境', 'サカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市江道', '16', '16202', '9330305', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '江道', 'エンドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市五十辺', '16', '16202', '9330306', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '五十辺', 'イカラベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市笹八口', '16', '16202', '9330307', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '笹八口', 'ササヤツクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市八口', '16', '16202', '9330308', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '八口', 'ヤツクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市大源寺', '16', '16202', '9330311', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '大源寺', 'ダイゲンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市大源寺大源寺新町', '16', '16202', '9330312', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '大源寺', 'ダイゲンジ', null, null, '大源寺新町', 'ダイゲンジシンマチ');
INSERT INTO `ms_addresses` VALUES ('127118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市福田六家', '16', '16202', '9330313', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '福田六家', 'フクタロッケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市福栄町', '16', '16202', '9330314', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '福栄町', 'フクエイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市西園町', '16', '16202', '9330315', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '西園町', 'ニシゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市新栄町', '16', '16202', '9330316', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '新栄町', 'シンサカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市蜂ケ島', '16', '16202', '9330317', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '蜂ケ島', 'ハチガシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市池田', '16', '16202', '9330318', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '池田', 'イケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市荒屋敷', '16', '16202', '9330319', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '荒屋敷', 'アラヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市六家', '16', '16202', '9330321', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '六家', 'ロッケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市樋詰', '16', '16202', '9330322', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '樋詰', 'ヒヅメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市西高町', '16', '16202', '9330323', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '西高町', 'ニシタカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市立野高池町', '16', '16202', '9330324', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '立野', 'タテノ', null, null, '高池町', 'タカイケチョウ');
INSERT INTO `ms_addresses` VALUES ('127129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市立野', '16', '16202', '9330325', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '立野', 'タテノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市立野美鳥町', '16', '16202', '9330326', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '立野美鳥町', 'タテノミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市柴野内島', '16', '16202', '9330327', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '柴野内島', 'シバノウチジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市内島', '16', '16202', '9330328', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '内島', 'ウチジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市柴野内島柴園町', '16', '16202', '9330329', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '柴野内島', 'シバノウチジマ', null, null, '柴園町', 'シバゾノチョウ');
INSERT INTO `ms_addresses` VALUES ('127134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市中保', '16', '16202', '9330331', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '中保', 'ナカホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市若保町', '16', '16202', '9330331', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '若保町', 'ワカホチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市小竹', '16', '16202', '9330332', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '小竹', 'オダケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市本保', '16', '16202', '9330333', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '本保', 'ホンボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市三ケ', '16', '16202', '9330334', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '三ケ', 'サンガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市今市', '16', '16202', '9330335', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '今市', 'イマイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市上開発', '16', '16202', '9330336', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '上開発', 'カミカイホツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市千鳥丘町', '16', '16202', '9330337', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '千鳥丘町', 'チドリガオカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市駒方', '16', '16202', '9330338', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '駒方', 'コマガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市上渡', '16', '16202', '9330341', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '上渡', 'カミワタリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市東石堤', '16', '16202', '9330342', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '東石堤', 'ヒガシイシヅツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市宝来町', '16', '16202', '9330343', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '宝来町', 'タカラギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市笹川', '16', '16202', '9330344', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '笹川', 'ササガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市平成町', '16', '16202', '9330345', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '平成町', 'ヘイセイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市四日市', '16', '16202', '9330351', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '四日市', 'ヨッカイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市十日市', '16', '16202', '9330352', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '十日市', 'トウカイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市麻生谷', '16', '16202', '9330353', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '麻生谷', 'アソウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市六日市', '16', '16202', '9330354', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '六日市', 'ムイカイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市石堤', '16', '16202', '9330355', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '石堤', 'イシヅツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市谷内', '16', '16202', '9330356', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '谷内', 'ヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市柴野', '16', '16202', '9330357', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '柴野', 'シバノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市蓮花寺新町', '16', '16202', '9330801', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '蓮花寺新町', 'レンゲジシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市蓮花寺', '16', '16202', '9330802', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '蓮花寺', 'レンゲジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市出来田', '16', '16202', '9330803', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '出来田', 'デキデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市問屋町', '16', '16202', '9330804', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '問屋町', 'トンヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市赤江町', '16', '16202', '9330805', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '赤江町', 'アカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市赤祖父', '16', '16202', '9330806', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '赤祖父', 'アカソフ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市井口本江', '16', '16202', '9330807', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '井口本江', 'イグチホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市高園町', '16', '16202', '9330808', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '高園町', 'タカゾノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市出来田新町', '16', '16202', '9330809', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '出来田新町', 'デキデンシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市深沢', '16', '16202', '9330811', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '深沢', 'フカサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市明和町', '16', '16202', '9330812', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '明和町', 'メイワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市下伏間江', '16', '16202', '9330813', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '下伏間江', 'シモフスマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市上伏間江', '16', '16202', '9330814', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '上伏間江', 'カミフスマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市西広上', '16', '16202', '9330815', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '西広上', 'ニシヒロカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市二塚', '16', '16202', '9330816', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '二塚', 'フタヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市東藤平蔵', '16', '16202', '9330817', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '東藤平蔵', 'ヒガシトウヘイゾウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市林新', '16', '16202', '9330818', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '林新', 'ハヤシシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市下島町', '16', '16202', '9330821', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '下島町', 'シモジママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市十二町島', '16', '16202', '9330822', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '十二町島', 'ジュウニチョウジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市北蔵新', '16', '16202', '9330823', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '北蔵新', 'キタクラシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市西藤平蔵', '16', '16202', '9330824', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '西藤平蔵', 'ニシトウヘイゾウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市佐野緑町', '16', '16202', '9330825', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '佐野緑町', 'サノミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市佐野', '16', '16202', '9330826', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '佐野', 'サノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市泉が丘', '16', '16202', '9330827', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '泉が丘', 'イズミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市和田上町', '16', '16202', '9330828', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '和田上町', 'ワダカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市福田', '16', '16202', '9330829', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '福田', 'フクタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市若富町', '16', '16202', '9330831', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '若富町', 'ワカトミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市和田', '16', '16202', '9330832', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '和田', 'ワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市荒見崎', '16', '16202', '9330833', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '荒見崎', 'アラミサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市蔵野町', '16', '16202', '9330834', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '蔵野町', 'クラノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市辻', '16', '16202', '9330835', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '辻', 'ツジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市石塚', '16', '16202', '9330836', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '石塚', 'イシヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市上北島', '16', '16202', '9330837', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '上北島', 'カミキタジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市北島', '16', '16202', '9330838', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '北島', 'キタジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市和田西町', '16', '16202', '9330839', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '和田西町', 'ワダニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市金屋町', '16', '16202', '9330841', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '金屋町', 'カナヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市横田町', '16', '16202', '9330842', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '横田町', 'ヨコタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市永楽町', '16', '16202', '9330843', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '永楽町', 'エイラクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市羽広', '16', '16202', '9330844', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '羽広', 'ハビロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市松原町', '16', '16202', '9330845', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '松原町', 'マツバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市扇町', '16', '16202', '9330846', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '扇町', 'オウギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市千石町', '16', '16202', '9330847', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '千石町', 'センゴクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市西町', '16', '16202', '9330848', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '西町', 'ニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市横田本町', '16', '16202', '9330849', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '横田本町', 'ヨコタホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市上関', '16', '16202', '9330851', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '上関', 'カミゼキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市上関町', '16', '16202', '9330851', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '上関町', 'カミゼキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市下黒田', '16', '16202', '9330852', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '下黒田', 'シモクロダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市上黒田', '16', '16202', '9330853', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '上黒田', 'カミクロダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市上黒田新', '16', '16202', '9330853', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '上黒田新', 'カミクロダシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市黒田新町', '16', '16202', '9330854', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '黒田新町', 'クロダシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市市場通り', '16', '16202', '9330855', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '市場通り', 'イチバドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市鐘紡町', '16', '16202', '9330856', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '鐘紡町', 'カネボウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市木津', '16', '16202', '9330857', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '木津', 'キヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市泉町', '16', '16202', '9330858', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '泉町', 'イズミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市寺町', '16', '16202', '9330861', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '寺町', 'テラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市新寺町', '16', '16202', '9330862', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '新寺町', 'シンテラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市関本町', '16', '16202', '9330863', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '関本町', 'セキホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市関町', '16', '16202', '9330864', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '関町', 'セキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市蓮美町', '16', '16202', '9330865', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '蓮美町', 'ハスミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市清水町', '16', '16202', '9330866', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '清水町', 'シミズマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市大鋸屋町', '16', '16202', '9330867', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '大鋸屋町', 'オガヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市大工中町', '16', '16202', '9330868', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '大工中町', 'ダイクナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市関大町', '16', '16202', '9330869', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '関大町', 'セキオオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市駅南', '16', '16202', '9330871', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '駅南', 'エキナン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市芳野', '16', '16202', '9330872', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '芳野', 'ヨシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市南田町', '16', '16202', '9330873', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '南田町', 'ミナミダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市京田', '16', '16202', '9330874', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '京田', 'キョウデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市神田新町', '16', '16202', '9330875', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '神田新町', 'カンダシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市神主町', '16', '16202', '9330876', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '神主町', 'カンヌシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市荒川町', '16', '16202', '9330877', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '荒川町', 'アラカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市東上関', '16', '16202', '9330878', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '東上関', 'ヒガシカミゼキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市八丁道', '16', '16202', '9330879', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '八丁道', 'ハッチョウミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市向野本町', '16', '16202', '9330901', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '向野本町', 'ムカイノホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市向野町', '16', '16202', '9330902', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '向野町', 'ムカイノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市熊野町', '16', '16202', '9330903', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '熊野町', 'クマノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市新成町', '16', '16202', '9330904', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '新成町', 'シンセイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市明野町', '16', '16202', '9330905', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '明野町', 'アケノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市五福町', '16', '16202', '9330906', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '五福町', 'ゴフクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市地子木町', '16', '16202', '9330907', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '地子木町', 'ジシキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市木町', '16', '16202', '9330908', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '木町', 'キマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市開発本町', '16', '16202', '9330909', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '開発本町', 'カイホツホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市あわら町', '16', '16202', '9330911', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', 'あわら町', 'アワラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市丸の内', '16', '16202', '9330912', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '丸の内', 'マルノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市本町', '16', '16202', '9330913', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市小馬出町', '16', '16202', '9330914', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '小馬出町', 'コンマダシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市千木屋町', '16', '16202', '9330915', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '千木屋町', 'センギヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市大町', '16', '16202', '9330916', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '大町', 'オオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市京町', '16', '16202', '9330917', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '京町', 'キョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市大坪町', '16', '16202', '9330918', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '大坪町', 'オオツボマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市源平町', '16', '16202', '9330921', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '源平町', 'ゲンペイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市三番町', '16', '16202', '9330922', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '三番町', 'サンバンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市一番町', '16', '16202', '9330923', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '一番町', 'イチバンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市堀上町', '16', '16202', '9330924', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '堀上町', 'ホリカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市白銀町', '16', '16202', '9330925', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '白銀町', 'シロガネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市御馬出町', '16', '16202', '9330926', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '御馬出町', 'オンマダシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市利屋町', '16', '16202', '9330927', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '利屋町', 'トギヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市守山町', '16', '16202', '9330928', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '守山町', 'モリヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市木舟町', '16', '16202', '9330929', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '木舟町', 'キフネマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市二番町', '16', '16202', '9330931', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '二番町', 'ニバンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市鴨島町', '16', '16202', '9330932', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '鴨島町', 'カモジママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市南幸町', '16', '16202', '9330933', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '南幸町', 'ミナミサイワイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市博労町', '16', '16202', '9330934', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '博労町', 'バクロウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市博労本町', '16', '16202', '9330935', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '博労本町', 'バクロウホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市旅篭町', '16', '16202', '9330936', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '旅篭町', 'ハタゴマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市通町', '16', '16202', '9330937', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '通町', 'トオリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市風呂屋町', '16', '16202', '9330938', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '風呂屋町', 'フロヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市内免', '16', '16202', '9330941', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '内免', 'ナイメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市川原町', '16', '16202', '9330942', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '川原町', 'カワラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市川原本町', '16', '16202', '9330943', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '川原本町', 'カワラホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市中島町', '16', '16202', '9330944', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '中島町', 'ナカジママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市金屋本町', '16', '16202', '9330945', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '金屋本町', 'カナヤホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市昭和町', '16', '16202', '9330946', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '昭和町', 'ショウワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市本郷', '16', '16202', '9330947', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '本郷', 'ホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市上四屋', '16', '16202', '9330948', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '上四屋', 'カミヨツヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市四屋', '16', '16202', '9330949', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '四屋', 'ヨツヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市長慶寺', '16', '16202', '9330951', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '長慶寺', 'チョウケイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市下窪', '16', '16202', '9330952', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '下窪', 'シタクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市横田', '16', '16202', '9330953', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '横田', 'ヨコタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市美幸町', '16', '16202', '9330954', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '美幸町', 'ミユキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市瑞穂町', '16', '16202', '9330955', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '瑞穂町', 'ミズホマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市宮田町', '16', '16202', '9330956', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '宮田町', 'ミヤタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市早川', '16', '16202', '9330957', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '早川', 'ハヤカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市波岡', '16', '16202', '9330958', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '波岡', 'ハオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市長江', '16', '16202', '9330959', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '長江', 'ナガエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市佐加野', '16', '16202', '9330961', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '佐加野', 'サガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市佐加野東', '16', '16202', '9330962', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '佐加野東', 'サガノヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市上八ケ新', '16', '16202', '9330963', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '上八ケ新', 'カミハッカシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市答野島', '16', '16202', '9330964', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '答野島', 'トウノシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市高辻', '16', '16202', '9330965', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '高辻', 'タカツジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市月野谷', '16', '16202', '9330966', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '月野谷', 'ツキノヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市手洗野', '16', '16202', '9330967', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '手洗野', 'タライノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市国吉', '16', '16202', '9330968', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '国吉', 'クニヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市五十里西町', '16', '16202', '9330971', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '五十里西町', 'イカリニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市五十里東町', '16', '16202', '9330972', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '五十里東町', 'イカリヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市五十里', '16', '16202', '9330973', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '五十里', 'イカリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市岩坪', '16', '16202', '9330974', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '岩坪', 'イワツボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市答野出', '16', '16202', '9330975', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '答野出', 'トウノデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市島崎', '16', '16202', '9330976', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '島崎', 'シマサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市細池', '16', '16202', '9330977', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '細池', 'ホソイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市頭川', '16', '16202', '9330978', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '頭川', 'ズカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市二上', '16', '16202', '9330981', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '二上', 'フタガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市二上新', '16', '16202', '9330981', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '二上新', 'フタガミシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市二上町', '16', '16202', '9330981', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '二上町', 'フタガミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市八ケ', '16', '16202', '9330982', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '八ケ', 'ハッカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市守護町', '16', '16202', '9330983', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '守護町', 'シュゴマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市守護町新', '16', '16202', '9330983', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '守護町新', 'シュゴマチシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市守山', '16', '16202', '9330984', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '守山', 'モリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市須田', '16', '16202', '9330985', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '須田', 'スダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市西海老坂', '16', '16202', '9330986', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '西海老坂', 'ニシエビサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市東海老坂', '16', '16202', '9330987', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '東海老坂', 'ヒガシエビサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市庄西町', '16', '16211', '9340001', '富山県', 'トヤマケン', '射水市', 'イミズシ', '庄西町', 'ショウセイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市港町', '16', '16211', '9340002', '富山県', 'トヤマケン', '射水市', 'イミズシ', '港町', 'ミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市庄川本町', '16', '16211', '9340003', '富山県', 'トヤマケン', '射水市', 'イミズシ', '庄川本町', 'ショウガワホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市西新湊', '16', '16211', '9340004', '富山県', 'トヤマケン', '射水市', 'イミズシ', '西新湊', 'ニシシンミナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市善光寺', '16', '16211', '9340005', '富山県', 'トヤマケン', '射水市', 'イミズシ', '善光寺', 'ゼンコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市本町', '16', '16211', '9340011', '富山県', 'トヤマケン', '射水市', 'イミズシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市中央町', '16', '16211', '9340012', '富山県', 'トヤマケン', '射水市', 'イミズシ', '中央町', 'チュウオウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市立町', '16', '16211', '9340013', '富山県', 'トヤマケン', '射水市', 'イミズシ', '立町', 'タテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市緑町', '16', '16211', '9340014', '富山県', 'トヤマケン', '射水市', 'イミズシ', '緑町', 'ミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市桜町', '16', '16211', '9340015', '富山県', 'トヤマケン', '射水市', 'イミズシ', '桜町', 'サクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市三日曽根', '16', '16211', '9340016', '富山県', 'トヤマケン', '射水市', 'イミズシ', '三日曽根', 'ミッカソネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市堀岡新明神西浜', '16', '16211', '9340021', '富山県', 'トヤマケン', '射水市', 'イミズシ', '堀岡新明神', 'ホリオカシンミョウジン', null, null, '西浜', 'ニシハマ');
INSERT INTO `ms_addresses` VALUES ('127365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市放生津町', '16', '16211', '9340022', '富山県', 'トヤマケン', '射水市', 'イミズシ', '放生津町', 'ホウジョウヅマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市海王町', '16', '16211', '9340023', '富山県', 'トヤマケン', '射水市', 'イミズシ', '海王町', 'カイオウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市越の潟町', '16', '16211', '9340024', '富山県', 'トヤマケン', '射水市', 'イミズシ', '越の潟町', 'コシノカタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市八幡町', '16', '16211', '9340025', '富山県', 'トヤマケン', '射水市', 'イミズシ', '八幡町', 'ハチマンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市二の丸町', '16', '16211', '9340026', '富山県', 'トヤマケン', '射水市', 'イミズシ', '二の丸町', 'ニノマルマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市中新湊', '16', '16211', '9340027', '富山県', 'トヤマケン', '射水市', 'イミズシ', '中新湊', 'ナカシンミナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市奈呉の江', '16', '16211', '9340031', '富山県', 'トヤマケン', '射水市', 'イミズシ', '奈呉の江', 'ナゴノエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市片口', '16', '16211', '9340032', '富山県', 'トヤマケン', '射水市', 'イミズシ', '片口', 'カタグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市新片町', '16', '16211', '9340033', '富山県', 'トヤマケン', '射水市', 'イミズシ', '新片町', 'シンカタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市高場新町', '16', '16211', '9340034', '富山県', 'トヤマケン', '射水市', 'イミズシ', '高場新町', 'タカバシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市新堀', '16', '16211', '9340035', '富山県', 'トヤマケン', '射水市', 'イミズシ', '新堀', 'シンボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市片口高場', '16', '16211', '9340036', '富山県', 'トヤマケン', '射水市', 'イミズシ', '片口高場', 'カタグチタカバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市片口久々江', '16', '16211', '9340037', '富山県', 'トヤマケン', '射水市', 'イミズシ', '片口久々江', 'カタグチクグエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市津幡江', '16', '16211', '9340038', '富山県', 'トヤマケン', '射水市', 'イミズシ', '津幡江', 'ツバタエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市久々湊', '16', '16211', '9340039', '富山県', 'トヤマケン', '射水市', 'イミズシ', '久々湊', 'クグミナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市作道新生町', '16', '16211', '9340041', '富山県', 'トヤマケン', '射水市', 'イミズシ', '作道', 'ツクリミチ', null, null, '新生町', 'シンセイチョウ');
INSERT INTO `ms_addresses` VALUES ('127381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市作道', '16', '16211', '9340042', '富山県', 'トヤマケン', '射水市', 'イミズシ', '作道', 'ツクリミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市野村', '16', '16211', '9340043', '富山県', 'トヤマケン', '射水市', 'イミズシ', '野村', 'ノムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市殿村', '16', '16211', '9340044', '富山県', 'トヤマケン', '射水市', 'イミズシ', '殿村', 'トノムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市沖', '16', '16211', '9340045', '富山県', 'トヤマケン', '射水市', 'イミズシ', '沖', 'オキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市今井', '16', '16211', '9340046', '富山県', 'トヤマケン', '射水市', 'イミズシ', '今井', 'イマイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市高木', '16', '16211', '9340047', '富山県', 'トヤマケン', '射水市', 'イミズシ', '高木', 'タカキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市布目', '16', '16211', '9340048', '富山県', 'トヤマケン', '射水市', 'イミズシ', '布目', 'ヌノメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市鏡宮', '16', '16211', '9340049', '富山県', 'トヤマケン', '射水市', 'イミズシ', '鏡宮', 'カガノミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市宮袋', '16', '16211', '9340051', '富山県', 'トヤマケン', '射水市', 'イミズシ', '宮袋', 'ミヤブクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市松木', '16', '16211', '9340052', '富山県', 'トヤマケン', '射水市', 'イミズシ', '松木', 'マツノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市朴木', '16', '16211', '9340053', '富山県', 'トヤマケン', '射水市', 'イミズシ', '朴木', 'ホオノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市神楽町', '16', '16211', '9340054', '富山県', 'トヤマケン', '射水市', 'イミズシ', '神楽町', 'カグラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市沖塚原', '16', '16211', '9340055', '富山県', 'トヤマケン', '射水市', 'イミズシ', '沖塚原', 'オキツカハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市寺塚原', '16', '16211', '9340056', '富山県', 'トヤマケン', '射水市', 'イミズシ', '寺塚原', 'テラツカハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市坂東', '16', '16211', '9340057', '富山県', 'トヤマケン', '射水市', 'イミズシ', '坂東', 'バンドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市川口', '16', '16211', '9340058', '富山県', 'トヤマケン', '射水市', 'イミズシ', '川口', 'カワグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市下牧野', '16', '16202', '9340091', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '下牧野', 'シモマキノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市中曾根', '16', '16202', '9340092', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '中曾根', 'ナカソネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市姫野', '16', '16202', '9340093', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '姫野', 'ヒメノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市放生津', '16', '16202', '9340093', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '放生津', 'ホウジョウヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市堀岡又新', '16', '16202', '9340094', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '堀岡又新', 'ホリオカマタシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市石丸', '16', '16202', '9340095', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '石丸', 'イシマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市金屋', '16', '16202', '9340096', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '金屋', 'カナヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市牧野金屋', '16', '16202', '9340097', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '牧野金屋', 'マキノカナヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市上牧野', '16', '16202', '9340098', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '上牧野', 'カミマキノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市若葉町', '16', '16202', '9340099', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '若葉町', 'ワカバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市', '16', '16205', '9350000', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('127428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市北八代', '16', '16205', '9350001', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '北八代', 'キタヤシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市阿尾', '16', '16205', '9350002', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '阿尾', 'アオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市間島', '16', '16205', '9350003', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '間島', 'マシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市北大町', '16', '16205', '9350004', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '北大町', 'キタオオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市栄町', '16', '16205', '9350005', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市稲積', '16', '16205', '9350006', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '稲積', 'イナヅミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市指崎', '16', '16205', '9350007', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '指崎', 'サッサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市中央町', '16', '16205', '9350011', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '中央町', 'チュウオウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市比美町', '16', '16205', '9350012', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '比美町', 'ヒミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市南大町', '16', '16205', '9350013', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '南大町', 'ミナミオオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市地蔵町', '16', '16205', '9350014', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '地蔵町', 'ジゾウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市伊勢大町', '16', '16205', '9350015', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '伊勢大町', 'イセオオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市本町', '16', '16205', '9350016', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市丸の内', '16', '16205', '9350017', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '丸の内', 'マルノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市幸町', '16', '16205', '9350021', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市朝日本町', '16', '16205', '9350022', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '朝日本町', 'アサヒホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市朝日丘', '16', '16205', '9350023', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '朝日丘', 'アサヒガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市窪', '16', '16205', '9350024', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '窪', 'クボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市鞍川', '16', '16205', '9350025', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '鞍川', 'クラカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市大野', '16', '16205', '9350026', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '大野', 'オオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市大野新', '16', '16205', '9350027', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '大野新', 'オオノシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市柳田', '16', '16205', '9350031', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '柳田', 'ヤナイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市島尾', '16', '16205', '9350032', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '島尾', 'シマオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市宮田', '16', '16205', '9350033', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '宮田', 'ミヤダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市小竹', '16', '16205', '9350034', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '小竹', 'オダケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市上田子', '16', '16205', '9350035', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '上田子', 'カミタコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市下田子', '16', '16205', '9350036', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '下田子', 'シモタコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市上泉', '16', '16205', '9350037', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '上泉', 'カミイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市園', '16', '16205', '9350041', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '園', 'ソノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市湖光', '16', '16205', '9350042', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '湖光', 'コウコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市川崎', '16', '16205', '9350043', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '川崎', 'カワサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市川尻', '16', '16205', '9350044', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '川尻', 'カワシリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市海津', '16', '16205', '9350045', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '海津', 'カイヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市下久津呂', '16', '16205', '9350046', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '下久津呂', 'シモクヅロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市上久津呂', '16', '16205', '9350047', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '上久津呂', 'カミクヅロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市十二町', '16', '16205', '9350051', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '十二町', 'ジュウニチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市坂津', '16', '16205', '9350052', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '坂津', 'サカツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市万尾', '16', '16205', '9350053', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '万尾', 'モオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市粟原', '16', '16205', '9350054', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '粟原', 'アワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市中谷内', '16', '16205', '9350055', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '中谷内', 'ナカヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市上田', '16', '16205', '9350056', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '上田', 'ウワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市西朴木', '16', '16205', '9350057', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '西朴木', 'ニシホオノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市余川', '16', '16205', '9350061', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '余川', 'ヨカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市諏訪野', '16', '16205', '9350062', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '諏訪野', 'スワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市加納', '16', '16205', '9350063', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '加納', 'カノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市中尾', '16', '16205', '9350064', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '中尾', 'ナカオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市泉', '16', '16205', '9350065', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '泉', 'イズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市七分一', '16', '16205', '9350066', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '七分一', 'シチブイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市柿谷', '16', '16205', '9350067', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '柿谷', 'カキナヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市大浦新町', '16', '16205', '9350101', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '大浦新町', 'オオウラシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市中島', '16', '16205', '9350102', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '中島', 'ナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市大浦', '16', '16205', '9350103', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '大浦', 'オオウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市堀田', '16', '16205', '9350104', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '堀田', 'ホリタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市蒲田', '16', '16205', '9350105', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '蒲田', 'カワタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市神代', '16', '16205', '9350106', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '神代', 'コウジロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市矢方', '16', '16205', '9350107', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '矢方', 'ヤノホウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市布施', '16', '16205', '9350111', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '布施', 'フセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市飯久保', '16', '16205', '9350112', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '飯久保', 'イクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市惣領', '16', '16205', '9350113', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '惣領', 'ソウリョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市仏生寺', '16', '16205', '9350114', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '仏生寺', 'ブッショウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市鞍骨', '16', '16205', '9350115', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '鞍骨', 'クラボネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市鉾根', '16', '16205', '9350115', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '鉾根', 'ホコネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市三田窪', '16', '16205', '9350116', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '三田窪', 'ミタクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市矢田部', '16', '16205', '9350116', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '矢田部', 'ヤタベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市深原', '16', '16205', '9350117', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '深原', 'フカハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市熊無', '16', '16205', '9350251', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '熊無', 'クマナシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市中村', '16', '16205', '9350252', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '中村', 'ナカムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市谷屋', '16', '16205', '9350253', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '谷屋', 'タニヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市新保', '16', '16205', '9350254', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '新保', 'シンボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市早借', '16', '16205', '9350255', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '早借', 'ハヤカシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市田江', '16', '16205', '9350256', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '田江', 'タエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市小窪', '16', '16205', '9350257', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '小窪', 'オクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市論田', '16', '16205', '9350258', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '論田', 'ロンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市三尾', '16', '16205', '9350261', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '三尾', 'ミオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市日名田', '16', '16205', '9350262', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '日名田', 'ヒナタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市小久米', '16', '16205', '9350263', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '小久米', 'オグメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市日詰', '16', '16205', '9350264', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '日詰', 'ヒヅメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市久目', '16', '16205', '9350265', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '久目', 'クメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市触坂', '16', '16205', '9350266', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '触坂', 'フレザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市見内', '16', '16205', '9350267', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '見内', 'ミウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市葛葉', '16', '16205', '9350268', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '葛葉', 'クズバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市床鍋', '16', '16205', '9350269', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '床鍋', 'トコナベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市老谷', '16', '16205', '9350271', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '老谷', 'オイダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市岩瀬', '16', '16205', '9350272', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '岩瀬', 'イワガセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市桑院', '16', '16205', '9350273', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '桑院', 'クワノイン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市赤毛', '16', '16205', '9350274', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '赤毛', 'アカゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市土倉', '16', '16205', '9350275', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '土倉', 'ツチクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市坪池', '16', '16205', '9350276', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '坪池', 'ツボイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市棚懸', '16', '16205', '9350277', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '棚懸', 'タナガケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市一の島', '16', '16205', '9350278', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '一の島', 'イチノシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市角間', '16', '16205', '9350331', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '角間', 'カクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市森寺', '16', '16205', '9350332', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '森寺', 'モリデラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市吉滝', '16', '16205', '9350333', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '吉滝', 'ヨシタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市針木', '16', '16205', '9350334', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '針木', 'ハリノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市胡桃', '16', '16205', '9350335', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '胡桃', 'クルミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市国見', '16', '16205', '9350336', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '国見', 'クニミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市小滝', '16', '16205', '9350337', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '小滝', 'オタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市磯辺', '16', '16205', '9350338', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '磯辺', 'イソベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市一刎', '16', '16205', '9350341', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '一刎', 'ヒトハネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市吉懸', '16', '16205', '9350342', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '吉懸', 'ヨシガケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市味川', '16', '16205', '9350343', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '味川', 'アジカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市上余川', '16', '16205', '9350344', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '上余川', 'カミヨカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市寺尾', '16', '16205', '9350345', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '寺尾', 'テラオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市懸札', '16', '16205', '9350346', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '懸札', 'カケフダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市脇', '16', '16205', '9350401', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '脇', 'ワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市中波', '16', '16205', '9350402', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '中波', 'ナカナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市中田', '16', '16205', '9350403', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '中田', 'ナカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市平沢', '16', '16205', '9350404', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '平沢', 'ヒラサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市吉岡', '16', '16205', '9350405', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '吉岡', 'ヨシオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市平', '16', '16205', '9350406', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '平', 'ダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市姿', '16', '16205', '9350411', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '姿', 'スガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市大境', '16', '16205', '9350412', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '大境', 'オオザカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市小境', '16', '16205', '9350413', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '小境', 'コザカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市白川', '16', '16205', '9350414', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '白川', 'シラガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市戸津宮', '16', '16205', '9350415', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '戸津宮', 'トツミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市大窪', '16', '16205', '9350416', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '大窪', 'オオクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市長坂', '16', '16205', '9350417', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '長坂', 'ナガサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市脇方', '16', '16205', '9350421', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '脇方', 'ワキガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市宇波', '16', '16205', '9350422', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '宇波', 'ウナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市泊', '16', '16205', '9350423', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '泊', 'トマリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市小杉', '16', '16205', '9350424', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '小杉', 'コスギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市薮田', '16', '16205', '9350425', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '薮田', 'ヤブタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県氷見市五十谷', '16', '16205', '9350426', '富山県', 'トヤマケン', '氷見市', 'ヒミシ', '五十谷', 'イカダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市', '16', '16206', '9360000', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('127560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市三ケ', '16', '16206', '9360001', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '三ケ', 'サンガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市中村', '16', '16206', '9360002', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '中村', 'ナカムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市吉浦', '16', '16206', '9360003', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '吉浦', 'ヨシウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市笠木', '16', '16206', '9360004', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '笠木', 'カサギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市浜四ツ屋', '16', '16206', '9360005', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '浜四ツ屋', 'ハマヨツヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市荒俣', '16', '16206', '9360006', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '荒俣', 'アラマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市荒俣新町', '16', '16206', '9360007', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '荒俣新町', 'アラマタシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市高塚', '16', '16206', '9360011', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '高塚', 'タカツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市高塚曙町', '16', '16206', '9360012', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '高塚曙町', 'タカツカアケボノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市高塚新市営住宅', '16', '16206', '9360013', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '高塚新市営住宅', 'タカツカシンシエイジュウタク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市高塚新町', '16', '16206', '9360014', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '高塚新町', 'タカツカシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市高塚寿町', '16', '16206', '9360015', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '高塚寿町', 'タカツカコトブキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市曲渕', '16', '16206', '9360016', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '曲渕', 'マガリブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市二ツ破', '16', '16206', '9360017', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '二ツ破', 'フタツヤブリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市坪川', '16', '16206', '9360018', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '坪川', 'ツボカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市坪川新', '16', '16206', '9360019', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '坪川新', 'ツボカワシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市中川原', '16', '16206', '9360021', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '中川原', 'ナカガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市辰野新町', '16', '16206', '9360022', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '辰野新町', 'タツノシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市柳原', '16', '16206', '9360023', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '柳原', 'ヤナギハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市辰野', '16', '16206', '9360024', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '辰野', 'タツノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市柳原新町', '16', '16206', '9360025', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '柳原新町', 'ヤナギハラシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市公園通り', '16', '16206', '9360026', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '公園通り', 'コウエンドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市常盤町', '16', '16206', '9360027', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '常盤町', 'トキワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市今町', '16', '16206', '9360031', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '今町', 'イママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市神明町', '16', '16206', '9360032', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '神明町', 'シンメイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市吾妻町', '16', '16206', '9360033', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '吾妻町', 'アヅマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市吾妻町雇用促進住宅', '16', '16206', '9360034', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '吾妻町', 'アヅマチョウ', null, null, '雇用促進住宅', 'コヨウソクシンジュウタク');
INSERT INTO `ms_addresses` VALUES ('127587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市四間町', '16', '16206', '9360035', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '四間町', 'シケンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市中町', '16', '16206', '9360036', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '中町', 'ナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市武平太町', '16', '16206', '9360037', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '武平太町', 'ブヘダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市北町', '16', '16206', '9360038', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '北町', 'キタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市夷子町', '16', '16206', '9360039', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '夷子町', 'エビスマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市松原町', '16', '16206', '9360041', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '松原町', 'マツバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市荒町', '16', '16206', '9360042', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '荒町', 'アラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市瓢町', '16', '16206', '9360043', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '瓢町', 'フクベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市馬町', '16', '16206', '9360044', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '馬町', 'ウママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市七間町', '16', '16206', '9360045', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '七間町', 'シチケンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市河浦町', '16', '16206', '9360046', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '河浦町', 'カワウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市大町', '16', '16206', '9360047', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '大町', 'オオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市三穂町', '16', '16206', '9360048', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '三穂町', 'ミホマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市寺家町', '16', '16206', '9360051', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '寺家町', 'ジケイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市清水町', '16', '16206', '9360052', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '清水町', 'シミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市上小泉', '16', '16206', '9360053', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '上小泉', 'カミコイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市上小泉雇用促進住宅', '16', '16206', '9360054', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '上小泉', 'カミコイズミ', null, null, '雇用促進住宅', 'コヨウソクシンジュウタク');
INSERT INTO `ms_addresses` VALUES ('127604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市泉ケ丘', '16', '16206', '9360055', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '泉ケ丘', 'イズミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市田中新町', '16', '16206', '9360056', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '田中新町', 'タナカシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市田中町', '16', '16206', '9360057', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '田中町', 'タナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市下小泉町', '16', '16206', '9360058', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '下小泉町', 'シモコイズミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市晒屋', '16', '16206', '9360059', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '晒屋', 'サラシヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市神家町', '16', '16206', '9360060', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '神家町', 'ジンカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市浜町', '16', '16206', '9360061', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '浜町', 'ハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市橋場町', '16', '16206', '9360062', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '橋場町', 'ハシバマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市瀬羽町', '16', '16206', '9360063', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '瀬羽町', 'セワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市河端町', '16', '16206', '9360064', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '河端町', 'カワバタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市下島', '16', '16206', '9360065', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '下島', 'シモジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市菰原', '16', '16206', '9360066', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '菰原', 'コモハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市菰原台', '16', '16206', '9360067', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '菰原台', 'コモハラダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市加島町', '16', '16206', '9360068', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '加島町', 'カシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市山王町', '16', '16206', '9360069', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '山王町', 'サンノウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市横町', '16', '16206', '9360070', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '横町', 'ヨコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市領家町', '16', '16206', '9360071', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '領家町', 'リョウケマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市緑町', '16', '16206', '9360072', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '緑町', 'ミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市幸町', '16', '16206', '9360073', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市新富町', '16', '16206', '9360074', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '新富町', 'シントミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市江尻', '16', '16206', '9360075', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '江尻', 'エジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市高月南台', '16', '16206', '9360076', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '高月南台', 'タカツキミナミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市魚躬', '16', '16206', '9360077', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '魚躬', 'ウオノミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市高月町', '16', '16206', '9360078', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '高月町', 'タカツキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市大島', '16', '16206', '9360801', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '大島', 'オオジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市大掛', '16', '16206', '9360802', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '大掛', 'オオガケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市栗山', '16', '16206', '9360803', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '栗山', 'クリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市杉本', '16', '16206', '9360804', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '杉本', 'スギモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市大窪', '16', '16206', '9360805', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '大窪', 'オオクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市北野', '16', '16206', '9360806', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '北野', 'キタノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市四ツ屋', '16', '16206', '9360807', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '四ツ屋', 'ヨツヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市追分', '16', '16206', '9360808', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '追分', 'オイワケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市大浦', '16', '16206', '9360811', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '大浦', 'オオウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市上大浦', '16', '16206', '9360811', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '上大浦', 'カミオオウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市下大浦', '16', '16206', '9360811', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '下大浦', 'シモオオウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市堀内', '16', '16206', '9360812', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '堀内', 'ホリウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市大日', '16', '16206', '9360813', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '大日', 'ダイニチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市千鳥', '16', '16206', '9360814', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '千鳥', 'チドリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市室山', '16', '16206', '9360815', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '室山', 'ムロヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市中野', '16', '16206', '9360816', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '中野', 'ナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市下野', '16', '16206', '9360817', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '下野', 'シモノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市大林', '16', '16206', '9360818', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '大林', 'オオバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市蓑輪', '16', '16206', '9360821', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '蓑輪', 'ミノワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市小森', '16', '16206', '9360822', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '小森', 'コモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市東福寺野', '16', '16206', '9360823', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '東福寺野', 'トウフクジノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市本江', '16', '16206', '9360824', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '本江', 'ホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市安田', '16', '16206', '9360825', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '安田', 'ヤスダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市田林', '16', '16206', '9360826', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '田林', 'タバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市東福寺', '16', '16206', '9360827', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '東福寺', 'トウフクジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市野尻', '16', '16206', '9360831', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '野尻', 'ノジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市森野新', '16', '16206', '9360832', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '森野新', 'モリノシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市大崎野', '16', '16206', '9360833', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '大崎野', 'オオサキノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市東福寺開', '16', '16206', '9360834', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '東福寺開', 'トウフクジビラキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市開', '16', '16206', '9360835', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '開', 'ヒラキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市改養寺', '16', '16206', '9360836', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '改養寺', 'カイヨウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市東金屋', '16', '16206', '9360837', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '東金屋', 'ヒガシカナヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市道寺', '16', '16206', '9360838', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '道寺', 'ドウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市柴', '16', '16206', '9360841', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '柴', 'シバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市赤浜栄町', '16', '16206', '9360842', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '赤浜栄町', 'アカハマサカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市赤浜', '16', '16206', '9360843', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '赤浜', 'アカハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市寺町', '16', '16206', '9360844', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '寺町', 'テラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市森尻新', '16', '16206', '9360845', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '森尻新', 'モリジリシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市堀江', '16', '16206', '9360846', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '堀江', 'ホリエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市天望町', '16', '16206', '9360847', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '天望町', 'テンボウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市常光寺', '16', '16206', '9360848', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '常光寺', 'ジョウコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市高柳', '16', '16206', '9360849', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '高柳', 'タカヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市沖田新', '16', '16206', '9360851', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '沖田新', 'オキダシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市上島', '16', '16206', '9360852', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '上島', 'カミジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市上梅沢', '16', '16206', '9360853', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '上梅沢', 'カミウメザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市小林', '16', '16206', '9360854', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '小林', 'コバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市有金', '16', '16206', '9360855', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '有金', 'アリカネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市大門', '16', '16206', '9360856', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '大門', 'ダイモン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市下梅沢', '16', '16206', '9360857', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '下梅沢', 'シモウメザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市中新', '16', '16206', '9360861', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '中新', 'ナカシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市四屋新', '16', '16206', '9360862', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '四屋新', 'ヨツヤシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市栃山', '16', '16206', '9360863', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '栃山', 'トチヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市金屋', '16', '16206', '9360864', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '金屋', 'カナヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市七口', '16', '16206', '9360865', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '七口', 'ナナクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市宮窪新', '16', '16206', '9360866', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '宮窪新', 'ミヤノクボシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市宮窪台', '16', '16206', '9360867', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '宮窪台', 'ミヤノクボダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市宮窪', '16', '16206', '9360868', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '宮窪', 'ミヤノクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市大島新', '16', '16206', '9360871', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '大島新', 'オオジマシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市二塚', '16', '16206', '9360872', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '二塚', 'フタツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市横道', '16', '16206', '9360873', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '横道', 'ヨコミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市大榎', '16', '16206', '9360874', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '大榎', 'オオエノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市中塚', '16', '16206', '9360875', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '中塚', 'ナカツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市稲泉新', '16', '16206', '9360876', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '稲泉新', 'イナイズミシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市稲泉', '16', '16206', '9360877', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '稲泉', 'イナイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市藤栄', '16', '16206', '9360881', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '藤栄', 'フジエイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市中野島', '16', '16206', '9360882', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '中野島', 'ナカノシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市野町', '16', '16206', '9360883', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '野町', 'ノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市米島', '16', '16206', '9360884', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '米島', 'ヨネジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県滑川市法花寺', '16', '16206', '9360885', '富山県', 'トヤマケン', '滑川市', 'ナメリカワシ', '法花寺', 'ホッケジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県中新川郡上市町護摩堂', '16', '16322', '9360891', '富山県', 'トヤマケン', '中新川郡上市町', 'ナカニイカワグンカミイチマチ', '護摩堂', 'ゴマドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市', '16', '16204', '9370000', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('127711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市浜経田', '16', '16204', '9370001', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '浜経田', 'ハマキョウデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市平伝寺', '16', '16204', '9370002', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '平伝寺', 'ヘイデンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市持光寺', '16', '16204', '9370003', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '持光寺', 'ジコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市岡経田', '16', '16204', '9370004', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '岡経田', 'オカキョウデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市天王', '16', '16204', '9370005', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '天王', 'テンノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市経田西町', '16', '16204', '9370006', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '経田西町', 'キョウデンニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市経田中町', '16', '16204', '9370007', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '経田中町', 'キョウデンナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市東町', '16', '16204', '9370008', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '東町', 'ヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市寿町', '16', '16204', '9370009', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '寿町', 'コトブキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市新経田', '16', '16204', '9370010', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '新経田', 'シンキョウデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市木下新', '16', '16204', '9370011', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '木下新', 'キノシタシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市東尾崎', '16', '16204', '9370012', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '東尾崎', 'ヒガシオザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市天神野新', '16', '16204', '9370013', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '天神野新', 'テンジンノシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市青柳', '16', '16204', '9370014', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '青柳', 'アオヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市東山', '16', '16204', '9370015', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '東山', 'ヒガシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市立石', '16', '16204', '9370016', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '立石', 'タテイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市江口', '16', '16204', '9370017', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '江口', 'エグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市西尾崎', '16', '16204', '9370018', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '西尾崎', 'ニシオサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市蛇田', '16', '16204', '9370021', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '蛇田', 'ヘビタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市小川寺', '16', '16204', '9370022', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '小川寺', 'オガワジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市長引野', '16', '16204', '9370023', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '長引野', 'ナガビキノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市布施爪', '16', '16204', '9370024', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '布施爪', 'フセヅメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市黒沢', '16', '16204', '9370025', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '黒沢', 'クロサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市大沢', '16', '16204', '9370026', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '大沢', 'オオサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市御影', '16', '16204', '9370027', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '御影', 'ミカゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市日尾', '16', '16204', '9370028', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '日尾', 'ヒオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市道坂', '16', '16204', '9370031', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '道坂', 'ドウザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市貝田新', '16', '16204', '9370032', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '貝田新', 'カイダシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市島尻', '16', '16204', '9370033', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '島尻', 'シマジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市東城', '16', '16204', '9370034', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '東城', 'トウジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市黒谷', '16', '16204', '9370035', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '黒谷', 'クロダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市山女', '16', '16204', '9370036', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '山女', 'アケビ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市東蔵', '16', '16204', '9370037', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '東蔵', 'トウゾウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市平沢', '16', '16204', '9370038', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '平沢', 'ヒラサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市大菅沼', '16', '16204', '9370039', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '大菅沼', 'オオスガヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市吉島', '16', '16204', '9370041', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '吉島', 'キチジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市六郎丸', '16', '16204', '9370042', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '六郎丸', 'ロクロウマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市袋', '16', '16204', '9370043', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '袋', 'フクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市横枕', '16', '16204', '9370044', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '横枕', 'ヨコマクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市相木', '16', '16204', '9370045', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '相木', 'アイノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市上村木', '16', '16204', '9370046', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '上村木', 'カミムラキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市相木新', '16', '16204', '9370047', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '相木新', 'アイノキシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市駅前新町', '16', '16204', '9370051', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '駅前新町', 'エキマエシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市緑町', '16', '16204', '9370052', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '緑町', 'ミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市村木町', '16', '16204', '9370053', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '村木町', 'ムラキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市金浦町', '16', '16204', '9370054', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '金浦町', 'カナウラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市中央通り', '16', '16204', '9370055', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '中央通り', 'チュウオウドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市諏訪町', '16', '16204', '9370056', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '諏訪町', 'スワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市港町', '16', '16204', '9370057', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '港町', 'ミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市火の宮町', '16', '16204', '9370058', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '火の宮町', 'ヒノミヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市末広町', '16', '16204', '9370059', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '末広町', 'スエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市仏田', '16', '16204', '9370061', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '仏田', 'ブツデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市仏又', '16', '16204', '9370062', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '仏又', 'ブツマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市青島', '16', '16204', '9370063', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '青島', 'アオジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市高畠', '16', '16204', '9370064', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '高畠', 'タカバタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市北中', '16', '16204', '9370065', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '北中', 'キタナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市北鬼江', '16', '16204', '9370066', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '北鬼江', 'キタオニエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市釈迦堂', '16', '16204', '9370067', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '釈迦堂', 'シャカドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市本新', '16', '16204', '9370068', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '本新', 'モトシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市本新町', '16', '16204', '9370068', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '本新町', 'モトシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市新金屋', '16', '16204', '9370801', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '新金屋', 'シンカナヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市下村木町', '16', '16204', '9370802', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '下村木町', 'シモムラキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市本江新町', '16', '16204', '9370803', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '本江新町', 'ホンゴウシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市並木町', '16', '16204', '9370804', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '並木町', 'ナミキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市本江', '16', '16204', '9370805', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '本江', 'ホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市友道', '16', '16204', '9370806', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '友道', 'トモミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市大光寺', '16', '16204', '9370807', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '大光寺', 'ダイコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市三田', '16', '16204', '9370811', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '三田', 'サンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市印田', '16', '16204', '9370812', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '印田', 'インデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市石垣新', '16', '16204', '9370813', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '石垣新', 'イシガキシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市石垣', '16', '16204', '9370814', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '石垣', 'イシガキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市大海寺新', '16', '16204', '9370815', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '大海寺新', 'ダイカイジシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市大海寺野', '16', '16204', '9370816', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '大海寺野', 'ダイカイジノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市出', '16', '16204', '9370821', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '出', 'イデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市舛田', '16', '16204', '9370822', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '舛田', 'マスダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市湯上', '16', '16204', '9370823', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '湯上', 'ユノエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市室田', '16', '16204', '9370824', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '室田', 'ムロダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市稗畠', '16', '16204', '9370825', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '稗畠', 'ヒエバタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市北山', '16', '16204', '9370826', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '北山', 'キタヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市坪野', '16', '16204', '9370827', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '坪野', 'ツボノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市池谷', '16', '16204', '9370828', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '池谷', 'イケダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市観音堂', '16', '16204', '9370831', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '観音堂', 'カンノンドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市金山谷', '16', '16204', '9370832', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '金山谷', 'カナヤマダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市小菅沼', '16', '16204', '9370833', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '小菅沼', 'コスガヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市鹿熊', '16', '16204', '9370834', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '鹿熊', 'カクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市大熊', '16', '16204', '9370835', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '大熊', 'オオクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市鉢', '16', '16204', '9370836', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '鉢', 'ハチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市虎谷', '16', '16204', '9370837', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '虎谷', 'トラダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市佐伯', '16', '16204', '9370841', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '佐伯', 'サエキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市吉野', '16', '16204', '9370842', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '吉野', 'ヨシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市上野', '16', '16204', '9370843', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '上野', 'ウワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市下椿', '16', '16204', '9370844', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '下椿', 'シモツバキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市舛方', '16', '16204', '9370845', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '舛方', 'マスカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市有山', '16', '16204', '9370846', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '有山', 'アリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市浅生', '16', '16204', '9370847', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '浅生', 'アソウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市住吉', '16', '16204', '9370851', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '住吉', 'スミヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市慶野', '16', '16204', '9370852', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '慶野', 'ケイノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市宮津', '16', '16204', '9370853', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '宮津', 'ミヤヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市弥源寺', '16', '16204', '9370854', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '弥源寺', 'ヤゲンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市川原', '16', '16204', '9370855', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '川原', 'カワハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市川縁', '16', '16204', '9370856', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '川縁', 'カワベリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市三ケ', '16', '16204', '9370857', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '三ケ', 'サンガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市鴨川町', '16', '16204', '9370861', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '鴨川町', 'カモガワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市文化町', '16', '16204', '9370862', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '文化町', 'ブンカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市新宿', '16', '16204', '9370863', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '新宿', 'シンジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市新角川', '16', '16204', '9370864', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '新角川', 'シンカドガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市上口', '16', '16204', '9370865', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '上口', 'カミグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市本町', '16', '16204', '9370866', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市真成寺町', '16', '16204', '9370867', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '真成寺町', 'シンジョウジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県魚津市双葉町', '16', '16204', '9370868', '富山県', 'トヤマケン', '魚津市', 'ウオヅシ', '双葉町', 'フタバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市', '16', '16207', '9380000', '富山県', 'トヤマケン', '黒部市', 'クロベシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('127831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市荒俣', '16', '16207', '9380001', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '荒俣', 'アラマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市飛騨', '16', '16207', '9380002', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '飛騨', 'ヒダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市六天', '16', '16207', '9380003', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '六天', 'ロクテン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市飯沢', '16', '16207', '9380004', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '飯沢', 'イイザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市吉田', '16', '16207', '9380005', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '吉田', 'ヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市大開', '16', '16207', '9380006', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '大開', 'オオビラキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市黒部新', '16', '16207', '9380011', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '黒部新', 'クロベシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市出島', '16', '16207', '9380012', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '出島', 'デジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市沓掛', '16', '16207', '9380013', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '沓掛', 'クツカケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市植木', '16', '16207', '9380014', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '植木', 'ウエキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市北野', '16', '16207', '9380015', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '北野', 'キタノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市古御堂', '16', '16207', '9380021', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '古御堂', 'フルミドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市金屋', '16', '16207', '9380022', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '金屋', 'カナヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市堀高', '16', '16207', '9380023', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '堀高', 'ホリタカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市高橋', '16', '16207', '9380024', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '高橋', 'タカハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市堀切新', '16', '16207', '9380025', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '堀切新', 'ホリキリシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市田家角内', '16', '16207', '9380026', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '田家角内', 'タイガグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市中新', '16', '16207', '9380027', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '中新', 'ナカシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市栃沢', '16', '16207', '9380028', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '栃沢', 'トチザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市三日市', '16', '16207', '9380031', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '三日市', 'ミッカイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市天池', '16', '16207', '9380032', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '天池', 'アマイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市中野道', '16', '16207', '9380033', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '中野道', 'ナカノミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市中野', '16', '16207', '9380034', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '中野', 'ナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市牧野', '16', '16207', '9380035', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '牧野', 'マキノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市北新', '16', '16207', '9380036', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '北新', 'キタシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市新牧野', '16', '16207', '9380037', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '新牧野', 'シンマキノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市新天', '16', '16207', '9380038', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '新天', 'シンテン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市堂田', '16', '16207', '9380039', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '堂田', 'ドウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市堀切', '16', '16207', '9380041', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '堀切', 'ホリキリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市天神新', '16', '16207', '9380042', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '天神新', 'テンジンシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市犬山', '16', '16207', '9380043', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '犬山', 'イヌヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市荒町', '16', '16207', '9380044', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '荒町', 'アラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市田家新', '16', '16207', '9380045', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '田家新', 'タイエシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市神谷', '16', '16207', '9380046', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '神谷', 'コンタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市窪野', '16', '16207', '9380047', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '窪野', 'クボノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市阿古屋野', '16', '16207', '9380048', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '阿古屋野', 'アコヤノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市山田', '16', '16207', '9380049', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '山田', 'ヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市立野', '16', '16207', '9380051', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '立野', 'タテノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市経立野', '16', '16207', '9380052', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '経立野', 'キョウタテノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市山立野', '16', '16207', '9380053', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '山立野', 'ヤマタテノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市岡', '16', '16207', '9380054', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '岡', 'オカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市浜石田', '16', '16207', '9380055', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '浜石田', 'ハマイシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市新町', '16', '16207', '9380056', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市石田新', '16', '16207', '9380057', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '石田新', 'イシダシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市正光寺新', '16', '16207', '9380058', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '正光寺新', 'ショウコウジシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市石田', '16', '16207', '9380059', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '石田', 'イシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市生地神区', '16', '16207', '9380061', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '生地神区', 'イクジシンク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市生地轟下', '16', '16207', '9380062', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '生地', 'イクジ', null, null, '轟下', 'トドロキシタ');
INSERT INTO `ms_addresses` VALUES ('127879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市生地四ツ屋新', '16', '16207', '9380063', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '生地四ツ屋新', 'イクジヨツヤシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市生地緑町', '16', '16207', '9380064', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '生地', 'イクジ', null, null, '緑町', 'ミドリマチ');
INSERT INTO `ms_addresses` VALUES ('127881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市生地神明町', '16', '16207', '9380065', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '生地', 'イクジ', null, null, '神明町', 'シンメイマチ');
INSERT INTO `ms_addresses` VALUES ('127882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市生地', '16', '16207', '9380066', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '生地', 'イクジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市生地山新', '16', '16207', '9380071', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '生地山新', 'イクジヤマシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市生地中区', '16', '16207', '9380072', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '生地中区', 'イクジナカク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市生地上町', '16', '16207', '9380073', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '生地', 'イクジ', null, null, '上町', 'カミマチ');
INSERT INTO `ms_addresses` VALUES ('127886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市生地四十物町', '16', '16207', '9380074', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '生地', 'イクジ', null, null, '四十物町', 'アイモノチョウ');
INSERT INTO `ms_addresses` VALUES ('127887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市生地大町', '16', '16207', '9380075', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '生地', 'イクジ', null, null, '大町', 'オオマチ');
INSERT INTO `ms_addresses` VALUES ('127888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市生地宮川町', '16', '16207', '9380076', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '生地', 'イクジ', null, null, '宮川町', 'ミヤガワチョウ');
INSERT INTO `ms_addresses` VALUES ('127889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市生地経新', '16', '16207', '9380081', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '生地経新', 'イクジキョウシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市生地芦区', '16', '16207', '9380082', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '生地芦区', 'イクジアシク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市生地阿弥陀堂', '16', '16207', '9380083', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '生地', 'イクジ', null, null, '阿弥陀堂', 'アミダドウ');
INSERT INTO `ms_addresses` VALUES ('127892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市生地芦崎', '16', '16207', '9380084', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '生地芦崎', 'イクジアシザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市生地吉田', '16', '16207', '9380085', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '生地吉田', 'イクジヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市生地吉田新', '16', '16207', '9380086', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '生地吉田新', 'イクジヨシダシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡入善町今江', '16', '16342', '9380101', '富山県', 'トヤマケン', '下新川郡入善町', 'シモニイカワグンニュウゼンマチ', '今江', 'イマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡入善町古林', '16', '16342', '9380102', '富山県', 'トヤマケン', '下新川郡入善町', 'シモニイカワグンニュウゼンマチ', '古林', 'フルバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡入善町舟見', '16', '16342', '9380103', '富山県', 'トヤマケン', '下新川郡入善町', 'シモニイカワグンニュウゼンマチ', '舟見', 'フナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡入善町西中', '16', '16342', '9380104', '富山県', 'トヤマケン', '下新川郡入善町', 'シモニイカワグンニュウゼンマチ', '西中', 'ニシナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡入善町中沢', '16', '16342', '9380105', '富山県', 'トヤマケン', '下新川郡入善町', 'シモニイカワグンニュウゼンマチ', '中沢', 'ナカザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡入善町野中', '16', '16342', '9380106', '富山県', 'トヤマケン', '下新川郡入善町', 'シモニイカワグンニュウゼンマチ', '野中', 'ノナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡朝日町殿町', '16', '16343', '9380161', '富山県', 'トヤマケン', '下新川郡朝日町', 'シモニイカワグンアサヒマチ', '殿町', 'トノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡朝日町山崎', '16', '16343', '9380162', '富山県', 'トヤマケン', '下新川郡朝日町', 'シモニイカワグンアサヒマチ', '山崎', 'ヤマザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡朝日町山崎岩崎', '16', '16343', '9380162', '富山県', 'トヤマケン', '下新川郡朝日町', 'シモニイカワグンアサヒマチ', '山崎', 'ヤマザキ', null, null, '岩崎', 'イワサキ');
INSERT INTO `ms_addresses` VALUES ('127904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡朝日町山崎小在池', '16', '16343', '9380162', '富山県', 'トヤマケン', '下新川郡朝日町', 'シモニイカワグンアサヒマチ', '山崎', 'ヤマザキ', null, null, '小在池', 'コザイケ');
INSERT INTO `ms_addresses` VALUES ('127905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡朝日町山崎越', '16', '16343', '9380162', '富山県', 'トヤマケン', '下新川郡朝日町', 'シモニイカワグンアサヒマチ', '山崎', 'ヤマザキ', null, null, '越', 'コシ');
INSERT INTO `ms_addresses` VALUES ('127906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡朝日町山崎辻', '16', '16343', '9380162', '富山県', 'トヤマケン', '下新川郡朝日町', 'シモニイカワグンアサヒマチ', '山崎', 'ヤマザキ', null, null, '辻', 'ツジ');
INSERT INTO `ms_addresses` VALUES ('127907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡朝日町山崎花房', '16', '16343', '9380162', '富山県', 'トヤマケン', '下新川郡朝日町', 'シモニイカワグンアサヒマチ', '山崎', 'ヤマザキ', null, null, '花房', 'ハナフサ');
INSERT INTO `ms_addresses` VALUES ('127908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡朝日町山崎羽入', '16', '16343', '9380162', '富山県', 'トヤマケン', '下新川郡朝日町', 'シモニイカワグンアサヒマチ', '山崎', 'ヤマザキ', null, null, '羽入', 'ハニュウ');
INSERT INTO `ms_addresses` VALUES ('127909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡朝日町山崎坊', '16', '16343', '9380162', '富山県', 'トヤマケン', '下新川郡朝日町', 'シモニイカワグンアサヒマチ', '山崎', 'ヤマザキ', null, null, '坊', 'ボウ');
INSERT INTO `ms_addresses` VALUES ('127910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡朝日町湯ノ瀬', '16', '16343', '9380163', '富山県', 'トヤマケン', '下新川郡朝日町', 'シモニイカワグンアサヒマチ', '湯ノ瀬', 'ユノセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡朝日町棚山', '16', '16343', '9380164', '富山県', 'トヤマケン', '下新川郡朝日町', 'シモニイカワグンアサヒマチ', '棚山', 'タナヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡朝日町山崎新', '16', '16343', '9380165', '富山県', 'トヤマケン', '下新川郡朝日町', 'シモニイカワグンアサヒマチ', '山崎新', 'ヤマザキシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡朝日町細野', '16', '16343', '9380166', '富山県', 'トヤマケン', '下新川郡朝日町', 'シモニイカワグンアサヒマチ', '細野', 'ホソノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡朝日町山王', '16', '16343', '9380167', '富山県', 'トヤマケン', '下新川郡朝日町', 'シモニイカワグンアサヒマチ', '山王', 'サンノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡朝日町藤塚横道', '16', '16343', '9380168', '富山県', 'トヤマケン', '下新川郡朝日町', 'シモニイカワグンアサヒマチ', '藤塚', 'フジツカ', null, null, '横道', 'ヨコミチ');
INSERT INTO `ms_addresses` VALUES ('127916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡朝日町下野', '16', '16343', '9380169', '富山県', 'トヤマケン', '下新川郡朝日町', 'シモニイカワグンアサヒマチ', '下野', 'シモノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市宇奈月町明日', '16', '16207', '9380171', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '宇奈月町明日', 'ウナヅキマチアケビ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市宇奈月町土山', '16', '16207', '9380172', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '宇奈月町土山', 'ウナヅキマチドヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市宇奈月町中谷', '16', '16207', '9380173', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '宇奈月町中谷', 'ウナヅキマチナカダン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市宇奈月町音澤', '16', '16207', '9380174', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '宇奈月町音澤', 'ウナヅキマチオトザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市宇奈月町愛本橋爪東官林地内', '16', '16207', '9380175', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '宇奈月町愛本橋爪東官林地内', 'ウナヅキマチアイモトハシヅメヒガシカンリンチナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市宇奈月町中ノ口', '16', '16207', '9380176', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '宇奈月町中ノ口', 'ウナヅキマチナカノクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市宇奈月町愛本新', '16', '16207', '9380177', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '宇奈月町愛本新', 'ウナヅキマチアイモトシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市宇奈月町栗虫', '16', '16207', '9380178', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '宇奈月町栗虫', 'ウナヅキマチクリムシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市宇奈月町舟見', '16', '16207', '9380179', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '宇奈月町舟見', 'ウナヅキマチフナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市宇奈月町音澤', '16', '16207', '9380274', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '宇奈月町音澤', 'ウナヅキマチオトザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市宇奈月町内山', '16', '16207', '9380281', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '宇奈月町内山', 'ウナヅキマチウチヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市宇奈月温泉', '16', '16207', '9380282', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '宇奈月温泉', 'ウナヅキオンセン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市黒部峡谷口', '16', '16207', '9380283', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '黒部峡谷口', 'クロベキョウコクグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市荻生', '16', '16207', '9380801', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '荻生', 'オギュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市若栗', '16', '16207', '9380802', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '若栗', 'ワカグリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市栗寺', '16', '16207', '9380803', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '栗寺', 'クリデラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市宮野', '16', '16207', '9380804', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '宮野', 'ミヤノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市吉城寺', '16', '16207', '9380805', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '吉城寺', 'キチジョウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市前沢', '16', '16207', '9380806', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '前沢', 'マエザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市山田新', '16', '16207', '9380807', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '山田新', 'ヤマダシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市内生谷', '16', '16207', '9380811', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '内生谷', 'ウチュウダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市笠破', '16', '16207', '9380812', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '笠破', 'カサヤブリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市田籾', '16', '16207', '9380813', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '田籾', 'タモミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市嘉例沢', '16', '16207', '9380814', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '嘉例沢', 'カレイサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市福平', '16', '16207', '9380815', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '福平', 'フクヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市池尻', '16', '16207', '9380816', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '池尻', 'イケジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市柳沢', '16', '16207', '9380821', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '柳沢', 'ヤナギサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市別所', '16', '16207', '9380822', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '別所', 'ベッショ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市釈迦堂', '16', '16207', '9380823', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '釈迦堂', 'シャカドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市阿弥陀堂', '16', '16207', '9380824', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '阿弥陀堂', 'アミダドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市尾山', '16', '16207', '9380825', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '尾山', 'オヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市朴谷', '16', '16207', '9380826', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '朴谷', 'ホオノキダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市中陣', '16', '16207', '9380827', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '中陣', 'ナカジン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市宮沢', '16', '16207', '9380831', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '宮沢', 'ミヤザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市枕野', '16', '16207', '9380832', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '枕野', 'マクラノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市本野', '16', '16207', '9380833', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '本野', 'モトノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市中山', '16', '16207', '9380834', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '中山', 'ナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市石田野', '16', '16207', '9380835', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '石田野', 'イシダノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市鏡野', '16', '16207', '9380836', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '鏡野', 'カガミノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市田家野', '16', '16207', '9380837', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '田家野', 'タイエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市宇奈月町下立', '16', '16207', '9380861', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '宇奈月町下立', 'ウナヅキマチオリタテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市宇奈月町浦山', '16', '16207', '9380862', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '宇奈月町浦山', 'ウナヅキマチウラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市宇奈月町熊野', '16', '16207', '9380863', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '宇奈月町熊野', 'ウナヅキマチクマノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県黒部市宇奈月町栃屋', '16', '16207', '9380864', '富山県', 'トヤマケン', '黒部市', 'クロベシ', '宇奈月町栃屋', 'ウナヅキマチトチヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市', '16', '16201', '9390000', '富山県', 'トヤマケン', '富山市', 'トヤマシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('127986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市福岡町赤丸', '16', '16202', '9390101', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '福岡町赤丸', 'フクオカマチアカマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市福岡町三日市', '16', '16202', '9390102', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '福岡町三日市', 'フクオカマチミッカイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市福岡町西', '16', '16202', '9390103', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '福岡町西', 'フクオカマチニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市福岡町加茂', '16', '16202', '9390104', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '福岡町加茂', 'フクオカマチカモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市福岡町馬場', '16', '16202', '9390105', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '福岡町馬場', 'フクオカマチバンバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市福岡町舞谷', '16', '16202', '9390106', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '福岡町舞谷', 'フクオカマチマイノヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市福岡町福岡', '16', '16202', '9390111', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '福岡町福岡', 'フクオカマチフクオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('127993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市福岡町福岡旭町', '16', '16202', '9390111', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '福岡町福岡', 'フクオカマチフクオカ', null, null, '旭町', 'アサヒマチ');
INSERT INTO `ms_addresses` VALUES ('127994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市福岡町福岡大蔵町', '16', '16202', '9390111', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '福岡町福岡', 'フクオカマチフクオカ', null, null, '大蔵町', 'オオクラチョウ');
INSERT INTO `ms_addresses` VALUES ('127995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市福岡町福岡清水町', '16', '16202', '9390111', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '福岡町福岡', 'フクオカマチフクオカ', null, null, '清水町', 'シミズチョウ');
INSERT INTO `ms_addresses` VALUES ('127996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市福岡町福岡中町', '16', '16202', '9390111', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '福岡町福岡', 'フクオカマチフクオカ', null, null, '中町', 'ナカマチ');
INSERT INTO `ms_addresses` VALUES ('127997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市福岡町福岡新旭町', '16', '16202', '9390111', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '福岡町福岡新', 'フクオカマチフクオカシン', null, null, '旭町', 'アサヒマチ');
INSERT INTO `ms_addresses` VALUES ('127998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市福岡町福岡新大蔵町', '16', '16202', '9390111', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '福岡町福岡新', 'フクオカマチフクオカシン', null, null, '大蔵町', 'オオクラチョウ');
INSERT INTO `ms_addresses` VALUES ('127999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市福岡町福岡新清水町', '16', '16202', '9390111', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '福岡町福岡新', 'フクオカマチフクオカシン', null, null, '清水町', 'シミズチョウ');
INSERT INTO `ms_addresses` VALUES ('128000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市福岡町荒屋敷表元町', '16', '16202', '9390112', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '福岡町荒屋敷', 'フクオカマチアラヤシキ', null, null, '表元町', 'オモテモトマチ');
INSERT INTO `ms_addresses` VALUES ('128001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市福岡町荒屋敷中央通り', '16', '16202', '9390112', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '福岡町荒屋敷', 'フクオカマチアラヤシキ', null, null, '中央通り', 'チュウオウドオリ');
INSERT INTO `ms_addresses` VALUES ('128002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市福岡町大滝表元町', '16', '16202', '9390112', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '福岡町大滝', 'フクオカマチオオタキ', null, null, '表元町', 'オモテモトマチ');
INSERT INTO `ms_addresses` VALUES ('128003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市福岡町下蓑新表元町', '16', '16202', '9390112', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '福岡町下蓑新', 'フクオカマチシモミノシン', null, null, '表元町', 'オモテモトマチ');
INSERT INTO `ms_addresses` VALUES ('128004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市福岡町福岡表元町', '16', '16202', '9390112', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '福岡町福岡', 'フクオカマチフクオカ', null, null, '表元町', 'オモテモトマチ');
INSERT INTO `ms_addresses` VALUES ('128005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市福岡町福岡新中央通り', '16', '16202', '9390112', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '福岡町福岡新', 'フクオカマチフクオカシン', null, null, '中央通り', 'チュウオウドオリ');
INSERT INTO `ms_addresses` VALUES ('128006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市福岡町上蓑末広町', '16', '16202', '9390113', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '福岡町上蓑', 'フクオカマチカミミノ', null, null, '末広町', 'スエヒロチョウ');
INSERT INTO `ms_addresses` VALUES ('128007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市福岡町下蓑末広町', '16', '16202', '9390113', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '福岡町下蓑', 'フクオカマチシモミノ', null, null, '末広町', 'スエヒロチョウ');
INSERT INTO `ms_addresses` VALUES ('128008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市福岡町下蓑中島町', '16', '16202', '9390113', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '福岡町下蓑', 'フクオカマチシモミノ', null, null, '中島町', 'ナカジママチ');
INSERT INTO `ms_addresses` VALUES ('128009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市福岡町下蓑元町', '16', '16202', '9390113', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '福岡町下蓑', 'フクオカマチシモミノ', null, null, '元町', 'モトマチ');
INSERT INTO `ms_addresses` VALUES ('128010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市福岡町下蓑新末広町', '16', '16202', '9390113', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '福岡町下蓑新', 'フクオカマチシモミノシン', null, null, '末広町', 'スエヒロチョウ');
INSERT INTO `ms_addresses` VALUES ('128011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市福岡町福岡中島町', '16', '16202', '9390113', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '福岡町福岡', 'フクオカマチフクオカ', null, null, '中島町', 'ナカジママチ');
INSERT INTO `ms_addresses` VALUES ('128012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市福岡町下蓑新栄町', '16', '16202', '9390115', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '福岡町下蓑', 'フクオカマチシモミノ', null, null, '新栄町', 'シンサカエマチ');
INSERT INTO `ms_addresses` VALUES ('128013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市福岡町下蓑新', '16', '16202', '9390115', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '福岡町下蓑新', 'フクオカマチシモミノシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市福岡町下蓑新新栄町', '16', '16202', '9390115', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '福岡町下蓑新', 'フクオカマチシモミノシン', null, null, '新栄町', 'シンサカエマチ');
INSERT INTO `ms_addresses` VALUES ('128015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市福岡町福岡新新栄町', '16', '16202', '9390115', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '福岡町福岡新', 'フクオカマチフクオカシン', null, null, '新栄町', 'シンサカエマチ');
INSERT INTO `ms_addresses` VALUES ('128016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市福岡町下蓑', '16', '16202', '9390116', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '福岡町下蓑', 'フクオカマチシモミノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市福岡町大野桜木町', '16', '16202', '9390117', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '福岡町大野', 'フクオカマチオオノ', null, null, '桜木町', 'サクラギチョウ');
INSERT INTO `ms_addresses` VALUES ('128018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市福岡町大野早稲田町', '16', '16202', '9390117', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '福岡町大野', 'フクオカマチオオノ', null, null, '早稲田町', 'ワセダマチ');
INSERT INTO `ms_addresses` VALUES ('128019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市福岡町福岡新', '16', '16202', '9390117', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '福岡町福岡新', 'フクオカマチフクオカシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市福岡町福岡新桜木町', '16', '16202', '9390117', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '福岡町福岡新', 'フクオカマチフクオカシン', null, null, '桜木町', 'サクラギチョウ');
INSERT INTO `ms_addresses` VALUES ('128021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市福岡町福岡新西干場', '16', '16202', '9390117', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '福岡町福岡新', 'フクオカマチフクオカシン', null, null, '西干場', 'ニシホシバ');
INSERT INTO `ms_addresses` VALUES ('128022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市福岡町福岡新早稲田町', '16', '16202', '9390117', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '福岡町福岡新', 'フクオカマチフクオカシン', null, null, '早稲田町', 'ワセダマチ');
INSERT INTO `ms_addresses` VALUES ('128023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市福岡町大野', '16', '16202', '9390118', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '福岡町大野', 'フクオカマチオオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市福岡町大滝橋上町', '16', '16202', '9390119', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '福岡町大滝', 'フクオカマチオオタキ', null, null, '橋上町', 'ハシガミチョウ');
INSERT INTO `ms_addresses` VALUES ('128025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市福岡町福岡西町', '16', '16202', '9390119', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '福岡町福岡', 'フクオカマチフクオカ', null, null, '西町', 'ニシチョウ');
INSERT INTO `ms_addresses` VALUES ('128026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市福岡町福岡堀川町', '16', '16202', '9390119', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '福岡町福岡', 'フクオカマチフクオカ', null, null, '堀川町', 'ホリカワチョウ');
INSERT INTO `ms_addresses` VALUES ('128027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市福岡町福岡新西町', '16', '16202', '9390119', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '福岡町福岡新', 'フクオカマチフクオカシン', null, null, '西町', 'ニシチョウ');
INSERT INTO `ms_addresses` VALUES ('128028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市福岡町福岡新橋上町', '16', '16202', '9390119', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '福岡町福岡新', 'フクオカマチフクオカシン', null, null, '橋上町', 'ハシガミチョウ');
INSERT INTO `ms_addresses` VALUES ('128029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市福岡町福岡新堀川町', '16', '16202', '9390119', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '福岡町福岡新', 'フクオカマチフクオカシン', null, null, '堀川町', 'ホリカワチョウ');
INSERT INTO `ms_addresses` VALUES ('128030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市福岡町下老子', '16', '16202', '9390121', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '福岡町下老子', 'フクオカマチシモオイゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市福岡町一歩二歩', '16', '16202', '9390122', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '福岡町一歩二歩', 'フクオカマチイチブニブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市福岡町西川原島', '16', '16202', '9390123', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '福岡町西川原島', 'フクオカマチニシカワラジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市福岡町小伊勢領', '16', '16202', '9390124', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '福岡町小伊勢領', 'フクオカマチコイセリョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市福岡町矢部', '16', '16202', '9390125', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '福岡町矢部', 'フクオカマチヤベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市福岡町蓑島', '16', '16202', '9390126', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '福岡町蓑島', 'フクオカマチミノジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市福岡町上蓑', '16', '16202', '9390127', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '福岡町上蓑', 'フクオカマチカミミノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市福岡町江尻', '16', '16202', '9390128', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '福岡町江尻', 'フクオカマチエジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市福岡町荒屋敷', '16', '16202', '9390131', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '福岡町荒屋敷', 'フクオカマチアラヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市福岡町大滝', '16', '16202', '9390132', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '福岡町大滝', 'フクオカマチオオタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市福岡町大滝木舟新', '16', '16202', '9390132', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '福岡町大滝', 'フクオカマチオオタキ', null, null, '木舟新', 'キブネシン');
INSERT INTO `ms_addresses` VALUES ('128041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市福岡町開ほつ', '16', '16202', '9390133', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '福岡町開ほつ', 'フクオカマチカイホツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市福岡町木舟', '16', '16202', '9390134', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '福岡町木舟', 'フクオカマチキブネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市福岡町本領', '16', '16202', '9390135', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '福岡町本領', 'フクオカマチホンリョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市福岡町鳥倉', '16', '16202', '9390141', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '福岡町鳥倉', 'フクオカマチトリクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市福岡町土屋', '16', '16202', '9390142', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '福岡町土屋', 'フクオカマチツチヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市福岡町下向田', '16', '16202', '9390143', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '福岡町下向田', 'フクオカマチシモムクタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市福岡町上向田', '16', '16202', '9390144', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '福岡町上向田', 'フクオカマチカミムクタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市福岡町上野', '16', '16202', '9390145', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '福岡町上野', 'フクオカマチウワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市福岡町沢川', '16', '16202', '9390151', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '福岡町沢川', 'フクオカマチソウゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市福岡町五位', '16', '16202', '9390152', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '福岡町五位', 'フクオカマチゴイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市福岡町花尾', '16', '16202', '9390153', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '福岡町花尾', 'フクオカマチハナオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市福岡町栃丘', '16', '16202', '9390154', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '福岡町栃丘', 'フクオカマチトチオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市福岡町西明寺', '16', '16202', '9390155', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '福岡町西明寺', 'フクオカマチサイミョウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市福岡町小野', '16', '16202', '9390156', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '福岡町小野', 'フクオカマチコノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '石川県羽咋郡宝達志水町沢川', '17', '17386', '9390171', '石川県', 'イシカワケン', '羽咋郡宝達志水町', 'ハクイグンホウダツシミズチョウ', '沢川', 'ソウゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市犬内', '16', '16211', '9390231', '富山県', 'トヤマケン', '射水市', 'イミズシ', '犬内', 'インナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市大門', '16', '16211', '9390232', '富山県', 'トヤマケン', '射水市', 'イミズシ', '大門', 'ダイモン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市大門新', '16', '16211', '9390233', '富山県', 'トヤマケン', '射水市', 'イミズシ', '大門新', 'ダイモンシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市二口', '16', '16211', '9390234', '富山県', 'トヤマケン', '射水市', 'イミズシ', '二口', 'フタクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市枇杷首', '16', '16211', '9390235', '富山県', 'トヤマケン', '射水市', 'イミズシ', '枇杷首', 'ビワクビ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市中村', '16', '16211', '9390241', '富山県', 'トヤマケン', '射水市', 'イミズシ', '中村', 'ナカムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市安吉', '16', '16211', '9390242', '富山県', 'トヤマケン', '射水市', 'イミズシ', '安吉', 'ヤスヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市下若', '16', '16211', '9390243', '富山県', 'トヤマケン', '射水市', 'イミズシ', '下若', 'シモワカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市本田', '16', '16211', '9390244', '富山県', 'トヤマケン', '射水市', 'イミズシ', '本田', 'ホンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市棚田', '16', '16211', '9390245', '富山県', 'トヤマケン', '射水市', 'イミズシ', '棚田', 'タナダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市大門本江', '16', '16211', '9390246', '富山県', 'トヤマケン', '射水市', 'イミズシ', '大門本江', 'ダイモンホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市あおば台', '16', '16211', '9390247', '富山県', 'トヤマケン', '射水市', 'イミズシ', 'あおば台', 'アオバダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市土合', '16', '16211', '9390251', '富山県', 'トヤマケン', '射水市', 'イミズシ', '土合', 'ドアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市下条', '16', '16211', '9390252', '富山県', 'トヤマケン', '射水市', 'イミズシ', '下条', 'ゲジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市堀内', '16', '16211', '9390253', '富山県', 'トヤマケン', '射水市', 'イミズシ', '堀内', 'ホリウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市島', '16', '16211', '9390254', '富山県', 'トヤマケン', '射水市', 'イミズシ', '島', 'シマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市上条', '16', '16211', '9390255', '富山県', 'トヤマケン', '射水市', 'イミズシ', '上条', 'ジョウジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市広上', '16', '16211', '9390256', '富山県', 'トヤマケン', '射水市', 'イミズシ', '広上', 'ヒロカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市西広上', '16', '16211', '9390257', '富山県', 'トヤマケン', '射水市', 'イミズシ', '西広上', 'ニシヒロカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市大島北野', '16', '16211', '9390271', '富山県', 'トヤマケン', '射水市', 'イミズシ', '大島北野', 'オオシマキタノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市若杉', '16', '16211', '9390272', '富山県', 'トヤマケン', '射水市', 'イミズシ', '若杉', 'ワカスギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市中野', '16', '16211', '9390273', '富山県', 'トヤマケン', '射水市', 'イミズシ', '中野', 'ナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市小島', '16', '16211', '9390274', '富山県', 'トヤマケン', '射水市', 'イミズシ', '小島', 'コジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市八塚', '16', '16211', '9390275', '富山県', 'トヤマケン', '射水市', 'イミズシ', '八塚', 'ヤツヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市北野', '16', '16211', '9390276', '富山県', 'トヤマケン', '射水市', 'イミズシ', '北野', 'キタノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市北高木', '16', '16211', '9390281', '富山県', 'トヤマケン', '射水市', 'イミズシ', '北高木', 'キタタカキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市南高木', '16', '16211', '9390282', '富山県', 'トヤマケン', '射水市', 'イミズシ', '南高木', 'ミナミタカギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市鳥取', '16', '16211', '9390283', '富山県', 'トヤマケン', '射水市', 'イミズシ', '鳥取', 'トットリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市新開発', '16', '16211', '9390284', '富山県', 'トヤマケン', '射水市', 'イミズシ', '新開発', 'シンカイホツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市本開発', '16', '16211', '9390285', '富山県', 'トヤマケン', '射水市', 'イミズシ', '本開発', 'ホンカイホツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市今開発', '16', '16211', '9390286', '富山県', 'トヤマケン', '射水市', 'イミズシ', '今開発', 'イマカイホツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市赤井', '16', '16211', '9390287', '富山県', 'トヤマケン', '射水市', 'イミズシ', '赤井', 'アカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市小林', '16', '16211', '9390288', '富山県', 'トヤマケン', '射水市', 'イミズシ', '小林', 'コバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市', '16', '16211', '9390300', '富山県', 'トヤマケン', '射水市', 'イミズシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('128096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市稲積', '16', '16211', '9390301', '富山県', 'トヤマケン', '射水市', 'イミズシ', '稲積', 'イナヅミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市大江', '16', '16211', '9390302', '富山県', 'トヤマケン', '射水市', 'イミズシ', '大江', 'オオゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市西高木', '16', '16211', '9390303', '富山県', 'トヤマケン', '射水市', 'イミズシ', '西高木', 'ニシタカギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市小杉白石', '16', '16211', '9390304', '富山県', 'トヤマケン', '射水市', 'イミズシ', '小杉白石', 'コスギシライシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市小杉白石小白石', '16', '16211', '9390304', '富山県', 'トヤマケン', '射水市', 'イミズシ', '小杉白石', 'コスギシライシ', null, null, '小白石', 'コシライシ');
INSERT INTO `ms_addresses` VALUES ('128101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市鷲塚', '16', '16211', '9390305', '富山県', 'トヤマケン', '射水市', 'イミズシ', '鷲塚', 'ワシヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市手崎', '16', '16211', '9390306', '富山県', 'トヤマケン', '射水市', 'イミズシ', '手崎', 'テサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市戸破針原', '16', '16211', '9390307', '富山県', 'トヤマケン', '射水市', 'イミズシ', '戸破', 'ヒバリ', null, null, '針原', 'ハリハラ');
INSERT INTO `ms_addresses` VALUES ('128104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市黒河', '16', '16211', '9390311', '富山県', 'トヤマケン', '射水市', 'イミズシ', '黒河', 'クロカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市黒河新', '16', '16211', '9390311', '富山県', 'トヤマケン', '射水市', 'イミズシ', '黒河新', 'クロカワシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市中老田新', '16', '16211', '9390312', '富山県', 'トヤマケン', '射水市', 'イミズシ', '中老田新', 'ナカオイタシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市塚越', '16', '16211', '9390313', '富山県', 'トヤマケン', '射水市', 'イミズシ', '塚越', 'ツカゴシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市土代', '16', '16211', '9390314', '富山県', 'トヤマケン', '射水市', 'イミズシ', '土代', 'ドダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市椎土', '16', '16211', '9390315', '富山県', 'トヤマケン', '射水市', 'イミズシ', '椎土', 'シイド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市小杉北野', '16', '16211', '9390316', '富山県', 'トヤマケン', '射水市', 'イミズシ', '小杉北野', 'コスギキタノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市山本新', '16', '16211', '9390317', '富山県', 'トヤマケン', '射水市', 'イミズシ', '山本新', 'ヤマモトシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市池多', '16', '16211', '9390318', '富山県', 'トヤマケン', '射水市', 'イミズシ', '池多', 'イケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市東太閤山', '16', '16211', '9390319', '富山県', 'トヤマケン', '射水市', 'イミズシ', '東太閤山', 'ヒガシタイコウヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市青井谷', '16', '16211', '9390321', '富山県', 'トヤマケン', '射水市', 'イミズシ', '青井谷', 'アオイダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市青井谷新屋敷', '16', '16211', '9390321', '富山県', 'トヤマケン', '射水市', 'イミズシ', '青井谷', 'アオイダニ', null, null, '新屋敷', 'アラヤシキ');
INSERT INTO `ms_addresses` VALUES ('128116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市青井谷五官野', '16', '16211', '9390321', '富山県', 'トヤマケン', '射水市', 'イミズシ', '青井谷', 'アオイダニ', null, null, '五官野', 'ゴカンノ');
INSERT INTO `ms_addresses` VALUES ('128117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市青井谷三野', '16', '16211', '9390321', '富山県', 'トヤマケン', '射水市', 'イミズシ', '青井谷', 'アオイダニ', null, null, '三野', 'サンノ');
INSERT INTO `ms_addresses` VALUES ('128118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市青井谷西谷', '16', '16211', '9390321', '富山県', 'トヤマケン', '射水市', 'イミズシ', '青井谷', 'アオイダニ', null, null, '西谷', 'ニシタニ');
INSERT INTO `ms_addresses` VALUES ('128119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市青井谷水上谷', '16', '16211', '9390321', '富山県', 'トヤマケン', '射水市', 'イミズシ', '青井谷', 'アオイダニ', null, null, '水上谷', 'ミズカミタニ');
INSERT INTO `ms_addresses` VALUES ('128120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市宿屋', '16', '16211', '9390321', '富山県', 'トヤマケン', '射水市', 'イミズシ', '宿屋', 'シュクヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市浄土寺', '16', '16211', '9390321', '富山県', 'トヤマケン', '射水市', 'イミズシ', '浄土寺', 'ジョウドジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市浄土寺林寺', '16', '16211', '9390321', '富山県', 'トヤマケン', '射水市', 'イミズシ', '浄土寺', 'ジョウドジ', null, null, '林寺', 'ハヤシデラ');
INSERT INTO `ms_addresses` VALUES ('128123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市浄土寺東谷', '16', '16211', '9390321', '富山県', 'トヤマケン', '射水市', 'イミズシ', '浄土寺', 'ジョウドジ', null, null, '東谷', 'ヒガシタニ');
INSERT INTO `ms_addresses` VALUES ('128124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市入会地', '16', '16211', '9390321', '富山県', 'トヤマケン', '射水市', 'イミズシ', '入会地', 'ニュウカイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市野手', '16', '16211', '9390321', '富山県', 'トヤマケン', '射水市', 'イミズシ', '野手', 'ノデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市流通センター青井谷1丁目', '16', '16211', '9390321', '富山県', 'トヤマケン', '射水市', 'イミズシ', '流通センター', 'リュウツウセンター', null, null, '青井谷1丁目', 'アオイダニ01チョウメ');
INSERT INTO `ms_addresses` VALUES ('128127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市流通センター青井谷2丁目', '16', '16211', '9390321', '富山県', 'トヤマケン', '射水市', 'イミズシ', '流通センター', 'リュウツウセンター', null, null, '青井谷2丁目', 'アオイダニ02チョウメ');
INSERT INTO `ms_addresses` VALUES ('128128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市上野', '16', '16211', '9390322', '富山県', 'トヤマケン', '射水市', 'イミズシ', '上野', 'ウワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市平野', '16', '16211', '9390323', '富山県', 'トヤマケン', '射水市', 'イミズシ', '平野', 'ヒラノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市下条新', '16', '16211', '9390331', '富山県', 'トヤマケン', '射水市', 'イミズシ', '下条新', 'ゲジョウシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市一条', '16', '16211', '9390332', '富山県', 'トヤマケン', '射水市', 'イミズシ', '一条', 'イチジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市橋下条', '16', '16211', '9390332', '富山県', 'トヤマケン', '射水市', 'イミズシ', '橋下条', 'ハシゲジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市橋下条赤田', '16', '16211', '9390332', '富山県', 'トヤマケン', '射水市', 'イミズシ', '橋下条', 'ハシゲジョウ', null, null, '赤田', 'アカタ');
INSERT INTO `ms_addresses` VALUES ('128134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市橋下条駅南通り', '16', '16211', '9390332', '富山県', 'トヤマケン', '射水市', 'イミズシ', '橋下条', 'ハシゲジョウ', null, null, '駅南通り', 'エキナンドオリ');
INSERT INTO `ms_addresses` VALUES ('128135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市橋下条囲山', '16', '16211', '9390332', '富山県', 'トヤマケン', '射水市', 'イミズシ', '橋下条', 'ハシゲジョウ', null, null, '囲山', 'カコイヤマ');
INSERT INTO `ms_addresses` VALUES ('128136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市橋下条五歩一', '16', '16211', '9390332', '富山県', 'トヤマケン', '射水市', 'イミズシ', '橋下条', 'ハシゲジョウ', null, null, '五歩一', 'ゴフイチ');
INSERT INTO `ms_addresses` VALUES ('128137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市橋下条大白', '16', '16211', '9390332', '富山県', 'トヤマケン', '射水市', 'イミズシ', '橋下条', 'ハシゲジョウ', null, null, '大白', 'ダイハク');
INSERT INTO `ms_addresses` VALUES ('128138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市橋下条二の井', '16', '16211', '9390332', '富山県', 'トヤマケン', '射水市', 'イミズシ', '橋下条', 'ハシゲジョウ', null, null, '二の井', 'ニノイ');
INSERT INTO `ms_addresses` VALUES ('128139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市日宮', '16', '16211', '9390332', '富山県', 'トヤマケン', '射水市', 'イミズシ', '日宮', 'ヒノミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市三ケ', '16', '16211', '9390341', '富山県', 'トヤマケン', '射水市', 'イミズシ', '三ケ', 'サンガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市三ケ愛宕', '16', '16211', '9390341', '富山県', 'トヤマケン', '射水市', 'イミズシ', '三ケ', 'サンガ', null, null, '愛宕', 'アタゴ');
INSERT INTO `ms_addresses` VALUES ('128142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市三ケ伊勢領', '16', '16211', '9390341', '富山県', 'トヤマケン', '射水市', 'イミズシ', '三ケ', 'サンガ', null, null, '伊勢領', 'イセリョ');
INSERT INTO `ms_addresses` VALUES ('128143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市三ケ一番町', '16', '16211', '9390341', '富山県', 'トヤマケン', '射水市', 'イミズシ', '三ケ', 'サンガ', null, null, '一番町', 'イチバンマチ');
INSERT INTO `ms_addresses` VALUES ('128144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市三ケ貝塚町', '16', '16211', '9390341', '富山県', 'トヤマケン', '射水市', 'イミズシ', '三ケ', 'サンガ', null, null, '貝塚町', 'カイヅカマチ');
INSERT INTO `ms_addresses` VALUES ('128145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市三ケ上新町', '16', '16211', '9390341', '富山県', 'トヤマケン', '射水市', 'イミズシ', '三ケ', 'サンガ', null, null, '上新町', 'カミシンマチ');
INSERT INTO `ms_addresses` VALUES ('128146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市三ケさくら町', '16', '16211', '9390341', '富山県', 'トヤマケン', '射水市', 'イミズシ', '三ケ', 'サンガ', null, null, 'さくら町', 'サクラマチ');
INSERT INTO `ms_addresses` VALUES ('128147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市三ケ白銀町', '16', '16211', '9390341', '富山県', 'トヤマケン', '射水市', 'イミズシ', '三ケ', 'サンガ', null, null, '白銀町', 'シロガネチョウ');
INSERT INTO `ms_addresses` VALUES ('128148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市三ケ新三ケ', '16', '16211', '9390341', '富山県', 'トヤマケン', '射水市', 'イミズシ', '三ケ', 'サンガ', null, null, '新三ケ', 'シンサンガ');
INSERT INTO `ms_addresses` VALUES ('128149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市三ケ新富町', '16', '16211', '9390341', '富山県', 'トヤマケン', '射水市', 'イミズシ', '三ケ', 'サンガ', null, null, '新富町', 'シントミチョウ');
INSERT INTO `ms_addresses` VALUES ('128150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市三ケ水源町', '16', '16211', '9390341', '富山県', 'トヤマケン', '射水市', 'イミズシ', '三ケ', 'サンガ', null, null, '水源町', 'スイゲンチョウ');
INSERT INTO `ms_addresses` VALUES ('128151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市三ケ諏訪町', '16', '16211', '9390341', '富山県', 'トヤマケン', '射水市', 'イミズシ', '三ケ', 'サンガ', null, null, '諏訪町', 'スワチョウ');
INSERT INTO `ms_addresses` VALUES ('128152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市三ケ高寺', '16', '16211', '9390341', '富山県', 'トヤマケン', '射水市', 'イミズシ', '三ケ', 'サンガ', null, null, '高寺', 'タカデラ');
INSERT INTO `ms_addresses` VALUES ('128153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市三ケ田町', '16', '16211', '9390341', '富山県', 'トヤマケン', '射水市', 'イミズシ', '三ケ', 'サンガ', null, null, '田町', 'タマチ');
INSERT INTO `ms_addresses` VALUES ('128154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市三ケ常盤町', '16', '16211', '9390341', '富山県', 'トヤマケン', '射水市', 'イミズシ', '三ケ', 'サンガ', null, null, '常盤町', 'トキワチョウ');
INSERT INTO `ms_addresses` VALUES ('128155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市三ケ錦町', '16', '16211', '9390341', '富山県', 'トヤマケン', '射水市', 'イミズシ', '三ケ', 'サンガ', null, null, '錦町', 'ニシキチョウ');
INSERT INTO `ms_addresses` VALUES ('128156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市三ケ西町', '16', '16211', '9390341', '富山県', 'トヤマケン', '射水市', 'イミズシ', '三ケ', 'サンガ', null, null, '西町', 'ニシチョウ');
INSERT INTO `ms_addresses` VALUES ('128157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市三ケ初音町', '16', '16211', '9390341', '富山県', 'トヤマケン', '射水市', 'イミズシ', '三ケ', 'サンガ', null, null, '初音町', 'ハツネチョウ');
INSERT INTO `ms_addresses` VALUES ('128158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市三ケ本中町', '16', '16211', '9390341', '富山県', 'トヤマケン', '射水市', 'イミズシ', '三ケ', 'サンガ', null, null, '本中町', 'ホンナカマチ');
INSERT INTO `ms_addresses` VALUES ('128159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市三ケ本丸町', '16', '16211', '9390341', '富山県', 'トヤマケン', '射水市', 'イミズシ', '三ケ', 'サンガ', null, null, '本丸町', 'ホンマルマチ');
INSERT INTO `ms_addresses` VALUES ('128160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市三ケ水上', '16', '16211', '9390341', '富山県', 'トヤマケン', '射水市', 'イミズシ', '三ケ', 'サンガ', null, null, '水上', 'ミズカミ');
INSERT INTO `ms_addresses` VALUES ('128161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市三ケ元町', '16', '16211', '9390341', '富山県', 'トヤマケン', '射水市', 'イミズシ', '三ケ', 'サンガ', null, null, '元町', 'モトマチ');
INSERT INTO `ms_addresses` VALUES ('128162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市戸破', '16', '16211', '9390351', '富山県', 'トヤマケン', '射水市', 'イミズシ', '戸破', 'ヒバリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市戸破荒町', '16', '16211', '9390351', '富山県', 'トヤマケン', '射水市', 'イミズシ', '戸破', 'ヒバリ', null, null, '荒町', 'アラマチ');
INSERT INTO `ms_addresses` VALUES ('128164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市戸破江上', '16', '16211', '9390351', '富山県', 'トヤマケン', '射水市', 'イミズシ', '戸破', 'ヒバリ', null, null, '江上', 'エガミ');
INSERT INTO `ms_addresses` VALUES ('128165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市戸破鍛治屋橋', '16', '16211', '9390351', '富山県', 'トヤマケン', '射水市', 'イミズシ', '戸破', 'ヒバリ', null, null, '鍛治屋橋', 'カジヤバシ');
INSERT INTO `ms_addresses` VALUES ('128166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市戸破神川町', '16', '16211', '9390351', '富山県', 'トヤマケン', '射水市', 'イミズシ', '戸破', 'ヒバリ', null, null, '神川町', 'カミカワチョウ');
INSERT INTO `ms_addresses` VALUES ('128167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市戸破北手崎', '16', '16211', '9390351', '富山県', 'トヤマケン', '射水市', 'イミズシ', '戸破', 'ヒバリ', null, null, '北手崎', 'キタテサキ');
INSERT INTO `ms_addresses` VALUES ('128168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市戸破木舟町', '16', '16211', '9390351', '富山県', 'トヤマケン', '射水市', 'イミズシ', '戸破', 'ヒバリ', null, null, '木舟町', 'キブネマチ');
INSERT INTO `ms_addresses` VALUES ('128169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市戸破栄町', '16', '16211', '9390351', '富山県', 'トヤマケン', '射水市', 'イミズシ', '戸破', 'ヒバリ', null, null, '栄町', 'サカエマチ');
INSERT INTO `ms_addresses` VALUES ('128170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市戸破さくら町', '16', '16211', '9390351', '富山県', 'トヤマケン', '射水市', 'イミズシ', '戸破', 'ヒバリ', null, null, 'さくら町', 'サクラマチ');
INSERT INTO `ms_addresses` VALUES ('128171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市戸破昭和通り', '16', '16211', '9390351', '富山県', 'トヤマケン', '射水市', 'イミズシ', '戸破', 'ヒバリ', null, null, '昭和通り', 'ショウワドオリ');
INSERT INTO `ms_addresses` VALUES ('128172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市戸破新栄町', '16', '16211', '9390351', '富山県', 'トヤマケン', '射水市', 'イミズシ', '戸破', 'ヒバリ', null, null, '新栄町', 'シンサカエマチ');
INSERT INTO `ms_addresses` VALUES ('128173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市戸破新町', '16', '16211', '9390351', '富山県', 'トヤマケン', '射水市', 'イミズシ', '戸破', 'ヒバリ', null, null, '新町', 'シンマチ');
INSERT INTO `ms_addresses` VALUES ('128174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市戸破末永町', '16', '16211', '9390351', '富山県', 'トヤマケン', '射水市', 'イミズシ', '戸破', 'ヒバリ', null, null, '末永町', 'スエナガチョウ');
INSERT INTO `ms_addresses` VALUES ('128175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市戸破高寺', '16', '16211', '9390351', '富山県', 'トヤマケン', '射水市', 'イミズシ', '戸破', 'ヒバリ', null, null, '高寺', 'タカデラ');
INSERT INTO `ms_addresses` VALUES ('128176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市戸破高穂町', '16', '16211', '9390351', '富山県', 'トヤマケン', '射水市', 'イミズシ', '戸破', 'ヒバリ', null, null, '高穂町', 'タカホチョウ');
INSERT INTO `ms_addresses` VALUES ('128177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市戸破宝町', '16', '16211', '9390351', '富山県', 'トヤマケン', '射水市', 'イミズシ', '戸破', 'ヒバリ', null, null, '宝町', 'タカラマチ');
INSERT INTO `ms_addresses` VALUES ('128178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市戸破茶屋町', '16', '16211', '9390351', '富山県', 'トヤマケン', '射水市', 'イミズシ', '戸破', 'ヒバリ', null, null, '茶屋町', 'チャヤマチ');
INSERT INTO `ms_addresses` VALUES ('128179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市戸破中央通り', '16', '16211', '9390351', '富山県', 'トヤマケン', '射水市', 'イミズシ', '戸破', 'ヒバリ', null, null, '中央通り', 'チュウオウドオリ');
INSERT INTO `ms_addresses` VALUES ('128180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市戸破中町', '16', '16211', '9390351', '富山県', 'トヤマケン', '射水市', 'イミズシ', '戸破', 'ヒバリ', null, null, '中町', 'ナカマチ');
INSERT INTO `ms_addresses` VALUES ('128181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市戸破西楠町', '16', '16211', '9390351', '富山県', 'トヤマケン', '射水市', 'イミズシ', '戸破', 'ヒバリ', null, null, '西楠町', 'ニシクスノキチョウ');
INSERT INTO `ms_addresses` VALUES ('128182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市戸破乗舟町', '16', '16211', '9390351', '富山県', 'トヤマケン', '射水市', 'イミズシ', '戸破', 'ヒバリ', null, null, '乗舟町', 'ノリブネチョウ');
INSERT INTO `ms_addresses` VALUES ('128183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市戸破平成町', '16', '16211', '9390351', '富山県', 'トヤマケン', '射水市', 'イミズシ', '戸破', 'ヒバリ', null, null, '平成町', 'ヘイセイマチ');
INSERT INTO `ms_addresses` VALUES ('128184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市戸破南通り', '16', '16211', '9390351', '富山県', 'トヤマケン', '射水市', 'イミズシ', '戸破', 'ヒバリ', null, null, '南通り', 'ミナミドオリ');
INSERT INTO `ms_addresses` VALUES ('128185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市戸破元町', '16', '16211', '9390351', '富山県', 'トヤマケン', '射水市', 'イミズシ', '戸破', 'ヒバリ', null, null, '元町', 'モトマチ');
INSERT INTO `ms_addresses` VALUES ('128186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市戸破若葉町', '16', '16211', '9390351', '富山県', 'トヤマケン', '射水市', 'イミズシ', '戸破', 'ヒバリ', null, null, '若葉町', 'ワカバチョウ');
INSERT INTO `ms_addresses` VALUES ('128187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市戸破若宮町', '16', '16211', '9390351', '富山県', 'トヤマケン', '射水市', 'イミズシ', '戸破', 'ヒバリ', null, null, '若宮町', 'ワカミヤチョウ');
INSERT INTO `ms_addresses` VALUES ('128188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市太閤町', '16', '16211', '9390361', '富山県', 'トヤマケン', '射水市', 'イミズシ', '太閤町', 'タイコウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市太閤山', '16', '16211', '9390362', '富山県', 'トヤマケン', '射水市', 'イミズシ', '太閤山', 'タイコウヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市中太閤山', '16', '16211', '9390363', '富山県', 'トヤマケン', '射水市', 'イミズシ', '中太閤山', 'ナカタイコウヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市南太閤山', '16', '16211', '9390364', '富山県', 'トヤマケン', '射水市', 'イミズシ', '南太閤山', 'ミナミタイコウヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市水戸田', '16', '16211', '9390401', '富山県', 'トヤマケン', '射水市', 'イミズシ', '水戸田', 'ミトダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市流通センター水戸田', '16', '16211', '9390402', '富山県', 'トヤマケン', '射水市', 'イミズシ', '流通センター水戸田', 'リュウツウセンターミトダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市生源寺', '16', '16211', '9390403', '富山県', 'トヤマケン', '射水市', 'イミズシ', '生源寺', 'ショウゲンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市市井', '16', '16211', '9390404', '富山県', 'トヤマケン', '射水市', 'イミズシ', '市井', 'イチノイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市藤巻', '16', '16211', '9390405', '富山県', 'トヤマケン', '射水市', 'イミズシ', '藤巻', 'フジマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市開口', '16', '16211', '9390406', '富山県', 'トヤマケン', '射水市', 'イミズシ', '開口', 'カイグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市竹鼻', '16', '16211', '9390407', '富山県', 'トヤマケン', '射水市', 'イミズシ', '竹鼻', 'タケハナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市若林', '16', '16211', '9390408', '富山県', 'トヤマケン', '射水市', 'イミズシ', '若林', 'ワカバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市円池', '16', '16211', '9390411', '富山県', 'トヤマケン', '射水市', 'イミズシ', '円池', 'ツブライケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市荒町', '16', '16211', '9390412', '富山県', 'トヤマケン', '射水市', 'イミズシ', '荒町', 'アラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市串田', '16', '16211', '9390413', '富山県', 'トヤマケン', '射水市', 'イミズシ', '串田', 'クシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市生源寺新', '16', '16211', '9390414', '富山県', 'トヤマケン', '射水市', 'イミズシ', '生源寺新', 'ショウゲンジシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市梅木', '16', '16211', '9390415', '富山県', 'トヤマケン', '射水市', 'イミズシ', '梅木', 'ウメノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市串田新', '16', '16211', '9390416', '富山県', 'トヤマケン', '射水市', 'イミズシ', '串田新', 'クシタシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市小泉', '16', '16211', '9390417', '富山県', 'トヤマケン', '射水市', 'イミズシ', '小泉', 'コイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県射水市布目沢', '16', '16211', '9390418', '富山県', 'トヤマケン', '射水市', 'イミズシ', '布目沢', 'ヌノメザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水橋東浜町', '16', '16201', '9390501', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水橋東浜町', 'ミズハシヒガシハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水橋地蔵町', '16', '16201', '9390502', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水橋地蔵町', 'ミズハシヂゾウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水橋西出町', '16', '16201', '9390503', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水橋西出町', 'ミズハシニシデマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水橋田町', '16', '16201', '9390504', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水橋田町', 'ミズハシタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水橋東天神町', '16', '16201', '9390505', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水橋東天神町', 'ミズハシヒガシテンジンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水橋大町中部地区', '16', '16201', '9390506', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水橋大町', 'ミズハシオオマチ', null, null, '中部地区', 'チュウブチク');
INSERT INTO `ms_addresses` VALUES ('128218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水橋中大町', '16', '16201', '9390506', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水橋中大町', 'ミズハシナカオオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水橋西天神町', '16', '16201', '9390507', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水橋西天神町', 'ミズハシニシテンジンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水橋西浜町', '16', '16201', '9390508', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水橋西浜町', 'ミズハシニシハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水橋町', '16', '16201', '9390509', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水橋町', 'ミズハシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水橋朝日町', '16', '16201', '9390511', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水橋朝日町', 'ミズハシアサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水橋魚躬', '16', '16201', '9390511', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水橋魚躬', 'ミズハシウオノミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水橋高月', '16', '16201', '9390511', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水橋高月', 'ミズハシタカツキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水橋東出町', '16', '16201', '9390512', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水橋東出町', 'ミズハシヒガシデマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水橋中出町', '16', '16201', '9390513', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水橋中出町', 'ミズハシナカデマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水橋稲荷町', '16', '16201', '9390514', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水橋稲荷町', 'ミズハシイナリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水橋新町', '16', '16201', '9390515', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水橋新町', 'ミズハシシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水橋下段', '16', '16201', '9390521', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水橋下段', 'ミズハシシタダン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水橋中村町', '16', '16201', '9390521', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水橋中村町', 'ミズハシナカムラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水橋中村栄町', '16', '16201', '9390522', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水橋中村栄町', 'ミズハシナカムラサカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水橋中村新町', '16', '16201', '9390523', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水橋中村新町', 'ミズハシナカムラシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水橋東舘町', '16', '16201', '9390524', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水橋東舘町', 'ミズハシヒガシタチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水橋新舘町', '16', '16201', '9390525', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水橋新舘町', 'ミズハシシンタチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水橋舘町', '16', '16201', '9390526', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水橋舘町', 'ミズハシタチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水橋新大町', '16', '16201', '9390527', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水橋新大町', 'ミズハシシンオオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水橋明治町', '16', '16201', '9390528', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水橋明治町', 'ミズハシメイジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水橋市江', '16', '16201', '9390531', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水橋市江', 'ミズハシイチエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水橋市江新町', '16', '16201', '9390532', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水橋市江新町', 'ミズハシイチエシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水橋高志園町', '16', '16201', '9390533', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水橋高志園町', 'ミズハシコシゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水橋狐塚', '16', '16201', '9390534', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水橋狐塚', 'ミズハシキツネヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水橋開発町', '16', '16201', '9390535', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水橋開発町', 'ミズハシカイホツマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水橋柳寺', '16', '16201', '9390536', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水橋柳寺', 'ミズハシヤナギデラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水橋鏡田', '16', '16201', '9390541', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水橋鏡田', 'ミズハシカガミダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水橋堅田', '16', '16201', '9390542', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水橋堅田', 'ミズハシカタダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水橋五郎丸', '16', '16201', '9390543', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水橋五郎丸', 'ミズハシゴロウマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水橋上砂子坂', '16', '16201', '9390544', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水橋上砂子坂', 'ミズハシカミスナゴザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水橋下砂子坂', '16', '16201', '9390544', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水橋下砂子坂', 'ミズハシシモスナゴザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水橋下砂子坂新', '16', '16201', '9390544', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水橋下砂子坂新', 'ミズハシシモスナゴザカシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水橋伊勢領', '16', '16201', '9390545', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水橋伊勢領', 'ミズハシイセリョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水橋上桜木', '16', '16201', '9390546', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水橋上桜木', 'ミズハシカミサクラギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水橋桜木', '16', '16201', '9390546', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水橋桜木', 'ミズハシサクラギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水橋小池', '16', '16201', '9390547', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水橋小池', 'ミズハシコイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水橋石政', '16', '16201', '9390551', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水橋石政', 'ミズハシイシマサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水橋恋塚', '16', '16201', '9390552', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水橋恋塚', 'ミズハシコイヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水橋小出', '16', '16201', '9390553', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水橋小出', 'ミズハシコイデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水橋専光寺', '16', '16201', '9390554', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水橋専光寺', 'ミズハシセンコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水橋高寺', '16', '16201', '9390555', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水橋高寺', 'ミズハシタカデラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水橋曲淵', '16', '16201', '9390556', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水橋曲淵', 'ミズハシマガリブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水橋大正', '16', '16201', '9390557', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水橋大正', 'ミズハシタイショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水橋大正南部', '16', '16201', '9390557', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水橋大正南部', 'ミズハシタイショウナンブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水橋大正北部', '16', '16201', '9390557', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水橋大正北部', 'ミズハシタイショウホクブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水橋上条新町', '16', '16201', '9390558', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水橋上条新町', 'ミズハシジョウジョウシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水橋石割', '16', '16201', '9390561', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水橋石割', 'ミズハシイシワリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水橋田伏', '16', '16201', '9390562', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水橋田伏', 'ミズハシタブセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水橋佐野竹', '16', '16201', '9390563', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水橋佐野竹', 'ミズハシサノタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水橋清水堂', '16', '16201', '9390564', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水橋清水堂', 'ミズハシシミズドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水橋金広', '16', '16201', '9390565', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水橋金広', 'ミズハシカネヒロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水橋中馬場', '16', '16201', '9390566', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水橋中馬場', 'ミズハシナカバンバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水橋北馬場', '16', '16201', '9390567', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水橋北馬場', 'ミズハシキタバンバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水橋平塚', '16', '16201', '9390568', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水橋平塚', 'ミズハシヒラツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡入善町', '16', '16342', '9390600', '富山県', 'トヤマケン', '下新川郡入善町', 'シモニイカワグンニュウゼンマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('128274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡入善町古黒部', '16', '16342', '9390611', '富山県', 'トヤマケン', '下新川郡入善町', 'シモニイカワグンニュウゼンマチ', '古黒部', 'フルクロベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡入善町藤原', '16', '16342', '9390612', '富山県', 'トヤマケン', '下新川郡入善町', 'シモニイカワグンニュウゼンマチ', '藤原', 'フジワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡入善町田の又', '16', '16342', '9390613', '富山県', 'トヤマケン', '下新川郡入善町', 'シモニイカワグンニュウゼンマチ', '田の又', 'タノマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡入善町君島', '16', '16342', '9390614', '富山県', 'トヤマケン', '下新川郡入善町', 'シモニイカワグンニュウゼンマチ', '君島', 'キミジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡入善町八幡', '16', '16342', '9390615', '富山県', 'トヤマケン', '下新川郡入善町', 'シモニイカワグンニュウゼンマチ', '八幡', 'ヤハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡入善町横山', '16', '16342', '9390616', '富山県', 'トヤマケン', '下新川郡入善町', 'シモニイカワグンニュウゼンマチ', '横山', 'ヨコヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡入善町春日', '16', '16342', '9390617', '富山県', 'トヤマケン', '下新川郡入善町', 'シモニイカワグンニュウゼンマチ', '春日', 'カスガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡入善町荒又', '16', '16342', '9390621', '富山県', 'トヤマケン', '下新川郡入善町', 'シモニイカワグンニュウゼンマチ', '荒又', 'アラマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡入善町日吉', '16', '16342', '9390622', '富山県', 'トヤマケン', '下新川郡入善町', 'シモニイカワグンニュウゼンマチ', '日吉', 'ヒヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡入善町小杉', '16', '16342', '9390623', '富山県', 'トヤマケン', '下新川郡入善町', 'シモニイカワグンニュウゼンマチ', '小杉', 'コスギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡入善町青島', '16', '16342', '9390624', '富山県', 'トヤマケン', '下新川郡入善町', 'シモニイカワグンニュウゼンマチ', '青島', 'アオシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡入善町神林', '16', '16342', '9390625', '富山県', 'トヤマケン', '下新川郡入善町', 'シモニイカワグンニュウゼンマチ', '神林', 'カンバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡入善町入膳', '16', '16342', '9390626', '富山県', 'トヤマケン', '下新川郡入善町', 'シモニイカワグンニュウゼンマチ', '入膳', 'ニュウゼン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡入善町椚山', '16', '16342', '9390627', '富山県', 'トヤマケン', '下新川郡入善町', 'シモニイカワグンニュウゼンマチ', '椚山', 'クヌギヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡入善町椚山新', '16', '16342', '9390628', '富山県', 'トヤマケン', '下新川郡入善町', 'シモニイカワグンニュウゼンマチ', '椚山新', 'クヌギヤマシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡入善町下山', '16', '16342', '9390631', '富山県', 'トヤマケン', '下新川郡入善町', 'シモニイカワグンニュウゼンマチ', '下山', 'ニザヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡入善町墓ノ木', '16', '16342', '9390632', '富山県', 'トヤマケン', '下新川郡入善町', 'シモニイカワグンニュウゼンマチ', '墓ノ木', 'ハカノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡入善町浦山新', '16', '16342', '9390633', '富山県', 'トヤマケン', '下新川郡入善町', 'シモニイカワグンニュウゼンマチ', '浦山新', 'ウラヤマシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡入善町小摺戸', '16', '16342', '9390634', '富山県', 'トヤマケン', '下新川郡入善町', 'シモニイカワグンニュウゼンマチ', '小摺戸', 'コスリド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡入善町若栗新', '16', '16342', '9390635', '富山県', 'トヤマケン', '下新川郡入善町', 'シモニイカワグンニュウゼンマチ', '若栗新', 'ワカグリシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡入善町一宿', '16', '16342', '9390636', '富山県', 'トヤマケン', '下新川郡入善町', 'シモニイカワグンニュウゼンマチ', '一宿', 'イチヤドリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡入善町新屋', '16', '16342', '9390637', '富山県', 'トヤマケン', '下新川郡入善町', 'シモニイカワグンニュウゼンマチ', '新屋', 'アラヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡入善町下上野', '16', '16342', '9390641', '富山県', 'トヤマケン', '下新川郡入善町', 'シモニイカワグンニュウゼンマチ', '下上野', 'シモウワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡入善町上野', '16', '16342', '9390642', '富山県', 'トヤマケン', '下新川郡入善町', 'シモニイカワグンニュウゼンマチ', '上野', 'ウワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡入善町青木', '16', '16342', '9390643', '富山県', 'トヤマケン', '下新川郡入善町', 'シモニイカワグンニュウゼンマチ', '青木', 'アオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡入善町福島新', '16', '16342', '9390644', '富山県', 'トヤマケン', '下新川郡入善町', 'シモニイカワグンニュウゼンマチ', '福島新', 'フクジマシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡入善町福島', '16', '16342', '9390645', '富山県', 'トヤマケン', '下新川郡入善町', 'シモニイカワグンニュウゼンマチ', '福島', 'フクジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡入善町青木新', '16', '16342', '9390646', '富山県', 'トヤマケン', '下新川郡入善町', 'シモニイカワグンニュウゼンマチ', '青木新', 'アオキシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡入善町道古', '16', '16342', '9390647', '富山県', 'トヤマケン', '下新川郡入善町', 'シモニイカワグンニュウゼンマチ', '道古', 'ドウコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡入善町上飯野新', '16', '16342', '9390651', '富山県', 'トヤマケン', '下新川郡入善町', 'シモニイカワグンニュウゼンマチ', '上飯野新', 'カミイイノシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡入善町袖沢', '16', '16342', '9390652', '富山県', 'トヤマケン', '下新川郡入善町', 'シモニイカワグンニュウゼンマチ', '袖沢', 'ソデザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡入善町上飯野', '16', '16342', '9390653', '富山県', 'トヤマケン', '下新川郡入善町', 'シモニイカワグンニュウゼンマチ', '上飯野', 'カミイイノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡入善町板屋', '16', '16342', '9390654', '富山県', 'トヤマケン', '下新川郡入善町', 'シモニイカワグンニュウゼンマチ', '板屋', 'イタヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡入善町五郎八', '16', '16342', '9390655', '富山県', 'トヤマケン', '下新川郡入善町', 'シモニイカワグンニュウゼンマチ', '五郎八', 'ゴロウハチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡入善町笹原', '16', '16342', '9390656', '富山県', 'トヤマケン', '下新川郡入善町', 'シモニイカワグンニュウゼンマチ', '笹原', 'ササワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡入善町東狐', '16', '16342', '9390657', '富山県', 'トヤマケン', '下新川郡入善町', 'シモニイカワグンニュウゼンマチ', '東狐', 'トッコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡入善町高瀬', '16', '16342', '9390661', '富山県', 'トヤマケン', '下新川郡入善町', 'シモニイカワグンニュウゼンマチ', '高瀬', 'タカセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡入善町下飯野新', '16', '16342', '9390662', '富山県', 'トヤマケン', '下新川郡入善町', 'シモニイカワグンニュウゼンマチ', '下飯野新', 'シモイイノシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡入善町下飯野', '16', '16342', '9390663', '富山県', 'トヤマケン', '下新川郡入善町', 'シモニイカワグンニュウゼンマチ', '下飯野', 'シモイイノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡入善町蛇沢', '16', '16342', '9390664', '富山県', 'トヤマケン', '下新川郡入善町', 'シモニイカワグンニュウゼンマチ', '蛇沢', 'ヘビサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡入善町本村', '16', '16342', '9390665', '富山県', 'トヤマケン', '下新川郡入善町', 'シモニイカワグンニュウゼンマチ', '本村', 'ホンムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡入善町高畠', '16', '16342', '9390666', '富山県', 'トヤマケン', '下新川郡入善町', 'シモニイカワグンニュウゼンマチ', '高畠', 'タカバタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡入善町芦崎', '16', '16342', '9390667', '富山県', 'トヤマケン', '下新川郡入善町', 'シモニイカワグンニュウゼンマチ', '芦崎', 'アシザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡入善町東五十里', '16', '16342', '9390671', '富山県', 'トヤマケン', '下新川郡入善町', 'シモニイカワグンニュウゼンマチ', '東五十里', 'ヒガシイカリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡入善町田中', '16', '16342', '9390672', '富山県', 'トヤマケン', '下新川郡入善町', 'シモニイカワグンニュウゼンマチ', '田中', 'タナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡入善町吉原東', '16', '16342', '9390673', '富山県', 'トヤマケン', '下新川郡入善町', 'シモニイカワグンニュウゼンマチ', '吉原東', 'ヨシワラヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡入善町吉原', '16', '16342', '9390674', '富山県', 'トヤマケン', '下新川郡入善町', 'シモニイカワグンニュウゼンマチ', '吉原', 'ヨシワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡入善町道市', '16', '16342', '9390675', '富山県', 'トヤマケン', '下新川郡入善町', 'シモニイカワグンニュウゼンマチ', '道市', 'ドイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡入善町目川', '16', '16342', '9390676', '富山県', 'トヤマケン', '下新川郡入善町', 'シモニイカワグンニュウゼンマチ', '目川', 'メガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡入善町木根', '16', '16342', '9390677', '富山県', 'トヤマケン', '下新川郡入善町', 'シモニイカワグンニュウゼンマチ', '木根', 'キノネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡入善町神子沢', '16', '16342', '9390678', '富山県', 'トヤマケン', '下新川郡入善町', 'シモニイカワグンニュウゼンマチ', '神子沢', 'ミコザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡入善町五十里', '16', '16342', '9390679', '富山県', 'トヤマケン', '下新川郡入善町', 'シモニイカワグンニュウゼンマチ', '五十里', 'イカリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡朝日町', '16', '16343', '9390700', '富山県', 'トヤマケン', '下新川郡朝日町', 'シモニイカワグンアサヒマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('128328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡朝日町横尾', '16', '16343', '9390701', '富山県', 'トヤマケン', '下新川郡朝日町', 'シモニイカワグンアサヒマチ', '横尾', 'ヨコオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡朝日町元屋敷', '16', '16343', '9390702', '富山県', 'トヤマケン', '下新川郡朝日町', 'シモニイカワグンアサヒマチ', '元屋敷', 'モトヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡朝日町宮崎', '16', '16343', '9390703', '富山県', 'トヤマケン', '下新川郡朝日町', 'シモニイカワグンアサヒマチ', '宮崎', 'ミヤザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡朝日町境', '16', '16343', '9390704', '富山県', 'トヤマケン', '下新川郡朝日町', 'シモニイカワグンアサヒマチ', '境', 'サカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡朝日町大平', '16', '16343', '9390705', '富山県', 'トヤマケン', '下新川郡朝日町', 'シモニイカワグンアサヒマチ', '大平', 'ダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡朝日町笹川', '16', '16343', '9390711', '富山県', 'トヤマケン', '下新川郡朝日町', 'シモニイカワグンアサヒマチ', '笹川', 'ササガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡朝日町蛭谷', '16', '16343', '9390712', '富山県', 'トヤマケン', '下新川郡朝日町', 'シモニイカワグンアサヒマチ', '蛭谷', 'ビルタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡朝日町長野', '16', '16343', '9390713', '富山県', 'トヤマケン', '下新川郡朝日町', 'シモニイカワグンアサヒマチ', '長野', 'ナガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡朝日町桜町', '16', '16343', '9390714', '富山県', 'トヤマケン', '下新川郡朝日町', 'シモニイカワグンアサヒマチ', '桜町', 'サクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡朝日町南保', '16', '16343', '9390715', '富山県', 'トヤマケン', '下新川郡朝日町', 'シモニイカワグンアサヒマチ', '南保', 'ナンボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡朝日町南保町', '16', '16343', '9390716', '富山県', 'トヤマケン', '下新川郡朝日町', 'シモニイカワグンアサヒマチ', '南保町', 'ナンボマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡朝日町石谷', '16', '16343', '9390717', '富山県', 'トヤマケン', '下新川郡朝日町', 'シモニイカワグンアサヒマチ', '石谷', 'イシタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡朝日町三枚橋', '16', '16343', '9390721', '富山県', 'トヤマケン', '下新川郡朝日町', 'シモニイカワグンアサヒマチ', '三枚橋', 'サンマイバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡朝日町大家庄', '16', '16343', '9390722', '富山県', 'トヤマケン', '下新川郡朝日町', 'シモニイカワグンアサヒマチ', '大家庄', 'オオイエノショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡朝日町不動堂', '16', '16343', '9390723', '富山県', 'トヤマケン', '下新川郡朝日町', 'シモニイカワグンアサヒマチ', '不動堂', 'フドウドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡朝日町横水', '16', '16343', '9390724', '富山県', 'トヤマケン', '下新川郡朝日町', 'シモニイカワグンアサヒマチ', '横水', 'ヨコミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡朝日町高橋', '16', '16343', '9390725', '富山県', 'トヤマケン', '下新川郡朝日町', 'シモニイカワグンアサヒマチ', '高橋', 'タカハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡朝日町下山新', '16', '16343', '9390726', '富山県', 'トヤマケン', '下新川郡朝日町', 'シモニイカワグンアサヒマチ', '下山新', 'ニザヤマシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡朝日町金山', '16', '16343', '9390727', '富山県', 'トヤマケン', '下新川郡朝日町', 'シモニイカワグンアサヒマチ', '金山', 'カナヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡朝日町窪田', '16', '16343', '9390728', '富山県', 'トヤマケン', '下新川郡朝日町', 'シモニイカワグンアサヒマチ', '窪田', 'クボタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡朝日町舟川新', '16', '16343', '9390729', '富山県', 'トヤマケン', '下新川郡朝日町', 'シモニイカワグンアサヒマチ', '舟川新', 'フナガワシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡朝日町東草野', '16', '16343', '9390731', '富山県', 'トヤマケン', '下新川郡朝日町', 'シモニイカワグンアサヒマチ', '東草野', 'ヒガシクサノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡朝日町中草野', '16', '16343', '9390732', '富山県', 'トヤマケン', '下新川郡朝日町', 'シモニイカワグンアサヒマチ', '中草野', 'ナカクサノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡朝日町月山', '16', '16343', '9390733', '富山県', 'トヤマケン', '下新川郡朝日町', 'シモニイカワグンアサヒマチ', '月山', 'ツキヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡朝日町草野', '16', '16343', '9390734', '富山県', 'トヤマケン', '下新川郡朝日町', 'シモニイカワグンアサヒマチ', '草野', 'クサノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡朝日町赤川', '16', '16343', '9390735', '富山県', 'トヤマケン', '下新川郡朝日町', 'シモニイカワグンアサヒマチ', '赤川', 'アカガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡朝日町浜草野', '16', '16343', '9390736', '富山県', 'トヤマケン', '下新川郡朝日町', 'シモニイカワグンアサヒマチ', '浜草野', 'ハマクサノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡朝日町月山新', '16', '16343', '9390737', '富山県', 'トヤマケン', '下新川郡朝日町', 'シモニイカワグンアサヒマチ', '月山新', 'ツキヤマシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡朝日町泊', '16', '16343', '9390741', '富山県', 'トヤマケン', '下新川郡朝日町', 'シモニイカワグンアサヒマチ', '泊', 'トマリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡朝日町沼保', '16', '16343', '9390742', '富山県', 'トヤマケン', '下新川郡朝日町', 'シモニイカワグンアサヒマチ', '沼保', 'ヌマホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡朝日町道下', '16', '16343', '9390743', '富山県', 'トヤマケン', '下新川郡朝日町', 'シモニイカワグンアサヒマチ', '道下', 'ドウゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡朝日町平柳', '16', '16343', '9390744', '富山県', 'トヤマケン', '下新川郡朝日町', 'シモニイカワグンアサヒマチ', '平柳', 'ヒラヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡朝日町西町', '16', '16343', '9390745', '富山県', 'トヤマケン', '下新川郡朝日町', 'シモニイカワグンアサヒマチ', '西町', 'ニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡朝日町荒川', '16', '16343', '9390746', '富山県', 'トヤマケン', '下新川郡朝日町', 'シモニイカワグンアサヒマチ', '荒川', 'アラカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡朝日町大屋', '16', '16343', '9390747', '富山県', 'トヤマケン', '下新川郡朝日町', 'シモニイカワグンアサヒマチ', '大屋', 'ダイヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡朝日町大屋新', '16', '16343', '9390748', '富山県', 'トヤマケン', '下新川郡朝日町', 'シモニイカワグンアサヒマチ', '大屋新', 'ダイヤシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡朝日町泊新', '16', '16343', '9390749', '富山県', 'トヤマケン', '下新川郡朝日町', 'シモニイカワグンアサヒマチ', '泊新', 'トマリシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県下新川郡朝日町野新', '16', '16343', '9390751', '富山県', 'トヤマケン', '下新川郡朝日町', 'シモニイカワグンアサヒマチ', '野新', 'ノシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市戸出市野瀬', '16', '16202', '9391101', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '戸出市野瀬', 'トイデイチノセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市戸出曙町', '16', '16202', '9391102', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '戸出曙町', 'トイデアケボノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市戸出狼', '16', '16202', '9391102', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '戸出狼', 'トイデオオカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市戸出池田町', '16', '16202', '9391103', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '戸出池田町', 'トイデイケダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市戸出町', '16', '16202', '9391104', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '戸出町', 'トイデマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市戸出伊勢領', '16', '16202', '9391105', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '戸出伊勢領', 'トイデイセリョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市戸出徳市', '16', '16202', '9391111', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '戸出徳市', 'トイデトクイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市戸出春日', '16', '16202', '9391112', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '戸出春日', 'トイデカスガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市戸出石代', '16', '16202', '9391113', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '戸出石代', 'トイデコクダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市戸出西部金屋', '16', '16202', '9391114', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '戸出西部金屋', 'トイデニシブカナヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市戸出吉住新', '16', '16202', '9391115', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '戸出吉住新', 'トイデヨシズミシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市戸出吉住', '16', '16202', '9391116', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '戸出吉住', 'トイデヨシズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市戸出大清水', '16', '16202', '9391117', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '戸出大清水', 'トイデオオシミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市戸出栄町', '16', '16202', '9391118', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '戸出栄町', 'トイデサカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市オフィスパーク', '16', '16202', '9391119', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', 'オフィスパーク', 'オフィスパーク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市戸出葵町', '16', '16202', '9391121', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '戸出葵町', 'トイデアオイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市戸出青園町', '16', '16202', '9391121', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '戸出青園町', 'トイデアオゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市戸出光明寺', '16', '16202', '9391121', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '戸出光明寺', 'トイデコウミョウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市戸出古戸出', '16', '16202', '9391122', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '戸出古戸出', 'トイデフルトイデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市戸出行兼', '16', '16202', '9391123', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '戸出行兼', 'トイデユキカネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市戸出六十歩', '16', '16202', '9391124', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '戸出六十歩', 'トイデロクジュウブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市戸出岡御所', '16', '16202', '9391125', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '戸出岡御所', 'トイデオカゴショ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市醍醐', '16', '16202', '9391131', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '醍醐', 'ダイゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市戸出竹', '16', '16202', '9391132', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '戸出竹', 'トイデタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市戸出放寺', '16', '16202', '9391133', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '戸出放寺', 'トイデホウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市戸出放寺新', '16', '16202', '9391134', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '戸出放寺新', 'トイデホウジシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市戸出竹北', '16', '16202', '9391135', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '戸出竹北', 'トイデタケキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市戸出延島', '16', '16202', '9391136', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '戸出延島', 'トイデノベジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市常国', '16', '16202', '9391251', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '常国', 'ツネクニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市常国みどり台', '16', '16202', '9391252', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '常国みどり台', 'ツネクニミドリダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市若杉', '16', '16202', '9391253', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '若杉', 'ワカスギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市滝新', '16', '16202', '9391254', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '滝新', 'タキシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市滝', '16', '16202', '9391255', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '滝', 'タキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市小泉新', '16', '16202', '9391261', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '小泉新', 'コイズミシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市山下', '16', '16202', '9391262', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '山下', 'サンカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市御坊山', '16', '16202', '9391263', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '御坊山', 'ゴボウヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市島新', '16', '16202', '9391263', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '島新', 'シマシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市下山田', '16', '16202', '9391264', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '下山田', 'シモヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市東保新', '16', '16202', '9391265', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '東保新', 'ヒガシボシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市今泉新', '16', '16202', '9391266', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '今泉新', 'イマイズミシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市今泉', '16', '16202', '9391267', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '今泉', 'イマイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市下麻生伸町', '16', '16202', '9391271', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '下麻生伸町', 'シモアソウシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市下麻生', '16', '16202', '9391272', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '下麻生', 'シモアソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市葦附', '16', '16202', '9391273', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '葦附', 'アシツキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市上麻生', '16', '16202', '9391274', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '上麻生', 'カミアソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県高岡市中田', '16', '16202', '9391275', '富山県', 'トヤマケン', '高岡市', 'タカオカシ', '中田', 'ナカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市', '16', '16208', '9391300', '富山県', 'トヤマケン', '砺波市', 'トナミシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('128419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市石丸', '16', '16208', '9391301', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '石丸', 'イシマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市東石丸', '16', '16208', '9391302', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '東石丸', 'ヒガシイシマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市大窪', '16', '16208', '9391303', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '大窪', 'オオクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市秋元', '16', '16208', '9391304', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '秋元', 'アキモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市千保', '16', '16208', '9391305', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '千保', 'センボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市宮村', '16', '16208', '9391306', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '宮村', 'ミヤムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市堀内', '16', '16208', '9391307', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '堀内', 'ホリノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市三郎丸', '16', '16208', '9391308', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '三郎丸', 'サブロマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市下中条', '16', '16208', '9391311', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '下中条', 'シモナカジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市東開発', '16', '16208', '9391312', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '東開発', 'ヒガシカイホツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市柳瀬', '16', '16208', '9391313', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '柳瀬', 'ヤナゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市久泉', '16', '16208', '9391314', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '久泉', 'ヒサイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市太田', '16', '16208', '9391315', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '太田', 'オオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市大門', '16', '16208', '9391316', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '大門', 'オオカド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市矢木', '16', '16208', '9391317', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '矢木', 'ヤギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市祖泉', '16', '16208', '9391318', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '祖泉', 'ソイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市新明', '16', '16208', '9391321', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '新明', 'シンミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市中野', '16', '16208', '9391322', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '中野', 'ナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市上中野', '16', '16208', '9391323', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '上中野', 'カミナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市荒高屋', '16', '16208', '9391324', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '荒高屋', 'アラダカヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市花島', '16', '16208', '9391325', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '花島', 'ハナジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市鹿島', '16', '16208', '9391326', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '鹿島', 'カノシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市五郎丸', '16', '16208', '9391327', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '五郎丸', 'ゴロマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市大辻', '16', '16208', '9391328', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '大辻', 'オオツジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市深江', '16', '16208', '9391331', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '深江', 'フカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市永福町', '16', '16208', '9391332', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '永福町', 'エイフクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市苗加', '16', '16208', '9391333', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '苗加', 'ノウカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市野村島', '16', '16208', '9391334', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '野村島', 'ノムラジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市鷹栖', '16', '16208', '9391335', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '鷹栖', 'タカノス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市西中', '16', '16208', '9391336', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '西中', 'ニシナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市神島', '16', '16208', '9391337', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '神島', 'カミジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市鷹栖出', '16', '16208', '9391338', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '鷹栖出', 'タカノスデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市高波', '16', '16208', '9391341', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '高波', 'タカナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市小島', '16', '16208', '9391342', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '小島', 'オジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市新富町', '16', '16208', '9391343', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '新富町', 'シントミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市中神', '16', '16208', '9391344', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '中神', 'ナカガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市林', '16', '16208', '9391345', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '林', 'ハヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市狐島', '16', '16208', '9391346', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '狐島', 'キツネジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市下中', '16', '16208', '9391347', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '下中', 'シモナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市東中', '16', '16208', '9391348', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '東中', 'ヒガシナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市千代', '16', '16208', '9391351', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '千代', 'センダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市宮丸', '16', '16208', '9391352', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '宮丸', 'ミヤマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市十年明', '16', '16208', '9391353', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '十年明', 'ジュウネンミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市新栄町', '16', '16208', '9391354', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '新栄町', 'シンサカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市杉木', '16', '16208', '9391355', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '杉木', 'スギノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市若草町', '16', '16208', '9391356', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '若草町', 'ワカクサマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市小杉', '16', '16208', '9391357', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '小杉', 'コスギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市木下', '16', '16208', '9391358', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '木下', 'キノシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市平成町', '16', '16208', '9391361', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '平成町', 'ヘイセイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市鍋島', '16', '16208', '9391362', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '鍋島', 'ナベシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市太郎丸', '16', '16208', '9391363', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '太郎丸', 'タロウマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市豊町', '16', '16208', '9391364', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '豊町', 'ユタカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市三島町', '16', '16208', '9391365', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '三島町', 'ミシママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市表町', '16', '16208', '9391366', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '表町', 'オモテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市広上町', '16', '16208', '9391367', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '広上町', 'ヒロカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市本町', '16', '16208', '9391368', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市栄町', '16', '16208', '9391371', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市新又', '16', '16208', '9391372', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '新又', 'アラマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市一番町', '16', '16208', '9391373', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '一番町', 'イチバンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市山王町', '16', '16208', '9391374', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '山王町', 'サンノウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市中央町', '16', '16208', '9391375', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '中央町', 'チュウオウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市平和町', '16', '16208', '9391376', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '平和町', 'ヘイワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市寿町', '16', '16208', '9391377', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '寿町', 'コトブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市春日町', '16', '16208', '9391378', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '春日町', 'ハルヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市中村', '16', '16208', '9391381', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '中村', 'ナカムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市花園町', '16', '16208', '9391382', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '花園町', 'ハナゾノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市高道', '16', '16208', '9391383', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '高道', 'タカンド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市坪内', '16', '16208', '9391384', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '坪内', 'ツボノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市東幸町', '16', '16208', '9391385', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '東幸町', 'ヒガシサイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市幸町', '16', '16208', '9391386', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市となみ町', '16', '16208', '9391387', '富山県', 'トヤマケン', '砺波市', 'トナミシ', 'となみ町', 'トナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市宮沢町', '16', '16208', '9391388', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '宮沢町', 'ミヤザワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市東保', '16', '16208', '9391401', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '東保', 'ヒガシボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市本小林', '16', '16208', '9391401', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '本小林', 'モトコバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市増山', '16', '16208', '9391402', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '増山', 'マスヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市宮新', '16', '16208', '9391403', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '宮新', 'ミヤシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市宮森新', '16', '16208', '9391404', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '宮森新', 'ミヤモリシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市福岡', '16', '16208', '9391405', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '福岡', 'フクオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市宮森', '16', '16208', '9391406', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '宮森', 'ミヤモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市権正寺', '16', '16208', '9391407', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '権正寺', 'ゴンショウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市八十歩', '16', '16208', '9391408', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '八十歩', 'ハチジュウブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市上和田', '16', '16208', '9391411', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '上和田', 'カミワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市正権寺', '16', '16208', '9391412', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '正権寺', 'ショウゴンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市市谷', '16', '16208', '9391413', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '市谷', 'イチノタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市坪野', '16', '16208', '9391414', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '坪野', 'ツボノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市池原', '16', '16208', '9391415', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '池原', 'イケノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市芹谷', '16', '16208', '9391416', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '芹谷', 'セリダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市頼成新', '16', '16208', '9391417', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '頼成新', 'ランジョウシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市東別所新', '16', '16208', '9391421', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '東別所新', 'ヒガシベッショシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市浅谷', '16', '16208', '9391422', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '浅谷', 'アサンタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市東別所', '16', '16208', '9391423', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '東別所', 'ヒガシベッショ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市栃上', '16', '16208', '9391424', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '栃上', 'トチアゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市井栗谷', '16', '16208', '9391425', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '井栗谷', 'イグリダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市川内', '16', '16208', '9391426', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '川内', 'コウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市伏木谷', '16', '16208', '9391427', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '伏木谷', 'フシキダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市五谷', '16', '16208', '9391428', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '五谷', 'ゴタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市寺尾', '16', '16208', '9391429', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '寺尾', 'テラオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市頼成', '16', '16208', '9391431', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '頼成', 'ランジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市徳万', '16', '16208', '9391432', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '徳万', 'トクマン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市徳万新', '16', '16208', '9391433', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '徳万新', 'トクマンシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市三合', '16', '16208', '9391434', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '三合', 'ミアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市三合新', '16', '16208', '9391435', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '三合新', 'ミアイシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市福山', '16', '16208', '9391436', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '福山', 'フクヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市茶ノ木', '16', '16208', '9391437', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '茶ノ木', 'チャノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県砺波市安川', '16', '16208', '9391438', '富山県', 'トヤマケン', '砺波市', 'トナミシ', '安川', 'ヤスカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市本江', '16', '16210', '9391501', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '本江', 'ホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市野尻', '16', '16210', '9391502', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '野尻', 'ノジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市岩武新', '16', '16210', '9391503', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '岩武新', 'イワタケシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市川除新', '16', '16210', '9391504', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '川除新', 'カワヨケシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市長源寺', '16', '16210', '9391505', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '長源寺', 'チョウゲンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市高儀', '16', '16210', '9391506', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '高儀', 'タカギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市二日町', '16', '16210', '9391507', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '二日町', 'フツカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市高堀', '16', '16210', '9391511', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '高堀', 'タカホリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市上野', '16', '16210', '9391512', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '上野', 'ウエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市野尻野', '16', '16210', '9391513', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '野尻野', 'ノジリノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市年代', '16', '16210', '9391514', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '年代', 'ネンダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市福野軸屋', '16', '16210', '9391515', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '福野軸屋', 'フクノジクヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市焼野', '16', '16210', '9391516', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '焼野', 'ヤケノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市百町', '16', '16210', '9391517', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '百町', 'ヒャクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市松原', '16', '16210', '9391518', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '松原', 'マツバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市苗島', '16', '16210', '9391521', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '苗島', 'ノジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市野新', '16', '16210', '9391522', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '野新', 'ノシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市野原', '16', '16210', '9391523', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '野原', 'ノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市雨潜', '16', '16210', '9391524', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '雨潜', 'アメクグリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市三清西', '16', '16210', '9391525', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '三清西', 'サンキヨニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市江田', '16', '16210', '9391526', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '江田', 'エダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市森清', '16', '16210', '9391527', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '森清', 'モリキヨ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市安清', '16', '16210', '9391528', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '安清', 'ヤスキヨ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市院林', '16', '16210', '9391531', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '院林', 'インバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市寺家', '16', '16210', '9391532', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '寺家', 'ジケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市八塚', '16', '16210', '9391533', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '八塚', 'ヤツヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市広安', '16', '16210', '9391534', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '広安', 'ヒロヤス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市石田', '16', '16210', '9391535', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '石田', 'イシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市東石田', '16', '16210', '9391536', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '東石田', 'ヒガシイシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市田屋', '16', '16210', '9391537', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '田屋', 'タヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市田尻', '16', '16210', '9391538', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '田尻', 'タジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市晩田', '16', '16210', '9391541', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '晩田', 'バンデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市梅ケ島', '16', '16210', '9391542', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '梅ケ島', 'ウメガシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市下吉江', '16', '16210', '9391543', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '下吉江', 'シモヨシエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市新邸', '16', '16210', '9391544', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '新邸', 'シンテイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市布袋', '16', '16210', '9391545', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '布袋', 'ホテイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市森', '16', '16210', '9391546', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '森', 'モリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市三ツ屋', '16', '16210', '9391547', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '三ツ屋', 'ミツヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市桐木', '16', '16210', '9391548', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '桐木', 'キリノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市前田', '16', '16210', '9391549', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '前田', 'マエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市上津', '16', '16210', '9391551', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '上津', 'ジョウヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市柴田屋', '16', '16210', '9391552', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '柴田屋', 'シバタヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市上川崎', '16', '16210', '9391553', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '上川崎', 'カミカワサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市安居', '16', '16210', '9391554', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '安居', 'ヤスイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市七村滝寺', '16', '16210', '9391555', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '七村滝寺', 'ナナムラタキデラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市福野', '16', '16210', '9391561', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '福野', 'フクノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市福野浦町', '16', '16210', '9391562', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '福野', 'フクノ', null, null, '浦町', 'ウラマチ');
INSERT INTO `ms_addresses` VALUES ('128577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市福野辰巳町', '16', '16210', '9391563', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '福野', 'フクノ', null, null, '辰巳町', 'タツミマチ');
INSERT INTO `ms_addresses` VALUES ('128578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市福野御蔵町', '16', '16210', '9391564', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '福野', 'フクノ', null, null, '御蔵町', 'オクラマチ');
INSERT INTO `ms_addresses` VALUES ('128579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市福野新町', '16', '16210', '9391565', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '福野', 'フクノ', null, null, '新町', 'シンマチ');
INSERT INTO `ms_addresses` VALUES ('128580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市福野田中町', '16', '16210', '9391566', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '福野', 'フクノ', null, null, '田中町', 'タナカマチ');
INSERT INTO `ms_addresses` VALUES ('128581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市福野上町', '16', '16210', '9391567', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '福野', 'フクノ', null, null, '上町', 'カンマチ');
INSERT INTO `ms_addresses` VALUES ('128582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市福野横町', '16', '16210', '9391568', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '福野', 'フクノ', null, null, '横町', 'ヨコマチ');
INSERT INTO `ms_addresses` VALUES ('128583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市松原新', '16', '16210', '9391571', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '松原新', 'マツバラシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市福野駅前通り', '16', '16210', '9391572', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '福野', 'フクノ', null, null, '駅前通り', 'エキマエドオリ');
INSERT INTO `ms_addresses` VALUES ('128585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市福野南町', '16', '16210', '9391573', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '福野', 'フクノ', null, null, '南町', 'ミナミマチ');
INSERT INTO `ms_addresses` VALUES ('128586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市福野七ツ屋', '16', '16210', '9391574', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '福野', 'フクノ', null, null, '七ツ屋', 'ナナツヤ');
INSERT INTO `ms_addresses` VALUES ('128587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市上三日市', '16', '16210', '9391575', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '上三日市', 'カミミッカイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市やかた', '16', '16210', '9391576', '富山県', 'トヤマケン', '南砺市', 'ナントシ', 'やかた', 'ヤカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市寺家新屋敷', '16', '16210', '9391577', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '寺家新屋敷', 'ジケアラヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市', '16', '16210', '9391600', '富山県', 'トヤマケン', '南砺市', 'ナントシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('128595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市人母', '16', '16210', '9391601', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '人母', 'ヒトブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市高窪', '16', '16210', '9391602', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '高窪', 'タカクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市砂子谷', '16', '16210', '9391603', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '砂子谷', 'スナゴダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市土山', '16', '16210', '9391604', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '土山', 'ドヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市小又', '16', '16210', '9391605', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '小又', 'オマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市能美', '16', '16210', '9391606', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '能美', 'ノミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市福光', '16', '16210', '9391610', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '福光', 'フクミツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市岩安', '16', '16210', '9391611', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '岩安', 'イワヤス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市岩木', '16', '16210', '9391612', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '岩木', 'イワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市川西', '16', '16210', '9391613', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '川西', 'カワニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市蔵原', '16', '16210', '9391614', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '蔵原', 'クラハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市湯谷', '16', '16210', '9391615', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '湯谷', 'ユダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市和泉', '16', '16210', '9391621', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '和泉', 'イズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市遊部川原', '16', '16210', '9391622', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '遊部川原', 'アソブカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市松木', '16', '16210', '9391623', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '松木', 'マツノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市八幡', '16', '16210', '9391624', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '八幡', 'ハチマン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市中ノ江', '16', '16210', '9391625', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '中ノ江', 'ナカノゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市法林寺', '16', '16210', '9391626', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '法林寺', 'ホウリンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市福光旭町', '16', '16210', '9391631', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '福光', 'フクミツ', null, null, '旭町', 'アサヒマチ');
INSERT INTO `ms_addresses` VALUES ('128614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市福光観音町', '16', '16210', '9391632', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '福光', 'フクミツ', null, null, '観音町', 'カンノンマチ');
INSERT INTO `ms_addresses` VALUES ('128615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市福光東町', '16', '16210', '9391633', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '福光', 'フクミツ', null, null, '東町', 'ヒガシマチ');
INSERT INTO `ms_addresses` VALUES ('128616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市福光寺町', '16', '16210', '9391634', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '福光', 'フクミツ', null, null, '寺町', 'テラマチ');
INSERT INTO `ms_addresses` VALUES ('128617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市福光中央通り', '16', '16210', '9391635', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '福光', 'フクミツ', null, null, '中央通り', 'チュウオウドオリ');
INSERT INTO `ms_addresses` VALUES ('128618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市福光神田町', '16', '16210', '9391636', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '福光', 'フクミツ', null, null, '神田町', 'カンダマチ');
INSERT INTO `ms_addresses` VALUES ('128619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市福光西町', '16', '16210', '9391637', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '福光', 'フクミツ', null, null, '西町', 'ニシマチ');
INSERT INTO `ms_addresses` VALUES ('128620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市福光川原町', '16', '16210', '9391641', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '福光', 'フクミツ', null, null, '川原町', 'カワハラマチ');
INSERT INTO `ms_addresses` VALUES ('128621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市福光味噌屋町', '16', '16210', '9391642', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '福光', 'フクミツ', null, null, '味噌屋町', 'ミソヤチョウ');
INSERT INTO `ms_addresses` VALUES ('128622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市福光本町', '16', '16210', '9391643', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '福光', 'フクミツ', null, null, '本町', 'ホンマチ');
INSERT INTO `ms_addresses` VALUES ('128623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市福光五宝町', '16', '16210', '9391644', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '福光', 'フクミツ', null, null, '五宝町', 'ゴホウマチ');
INSERT INTO `ms_addresses` VALUES ('128624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市福光中荒町', '16', '16210', '9391645', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '福光', 'フクミツ', null, null, '中荒町', 'ナカアラマチ');
INSERT INTO `ms_addresses` VALUES ('128625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市福光荒町', '16', '16210', '9391646', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '福光', 'フクミツ', null, null, '荒町', 'アラマチ');
INSERT INTO `ms_addresses` VALUES ('128626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市福光東新町', '16', '16210', '9391651', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '福光', 'フクミツ', null, null, '東新町', 'ヒガシシンマチ');
INSERT INTO `ms_addresses` VALUES ('128627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市福光新町', '16', '16210', '9391652', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '福光新町', 'フクミツシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市福光宮脇町', '16', '16210', '9391653', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '福光', 'フクミツ', null, null, '宮脇町', 'ミヤワキチョウ');
INSERT INTO `ms_addresses` VALUES ('128629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市福光栄町', '16', '16210', '9391654', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '福光', 'フクミツ', null, null, '栄町', 'サカエマチ');
INSERT INTO `ms_addresses` VALUES ('128630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市坂本', '16', '16210', '9391655', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '坂本', 'サカモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市天神', '16', '16210', '9391661', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '天神', 'テンジン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市福光天神町', '16', '16210', '9391662', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '福光', 'フクミツ', null, null, '天神町', 'テンジンマチ');
INSERT INTO `ms_addresses` VALUES ('128633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市竹内', '16', '16210', '9391664', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '竹内', 'タケウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市小山', '16', '16210', '9391665', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '小山', 'コヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市山本', '16', '16210', '9391666', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '山本', 'ヤマモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市開発', '16', '16210', '9391667', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '開発', 'カイホツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市小坂', '16', '16210', '9391671', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '小坂', 'コザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市広谷', '16', '16210', '9391672', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '広谷', 'ヒロタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市糸谷新', '16', '16210', '9391673', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '糸谷新', 'イトダニシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市香城寺', '16', '16210', '9391674', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '香城寺', 'コウジョウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市祖谷', '16', '16210', '9391675', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '祖谷', 'ソダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市舘', '16', '16210', '9391676', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '舘', 'タチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市才川七', '16', '16210', '9391681', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '才川七', 'サイカワシチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市小二又', '16', '16210', '9391682', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '小二又', 'コブタマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市小院瀬見', '16', '16210', '9391684', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '小院瀬見', 'コインゼミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市遊部', '16', '16210', '9391701', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '遊部', 'アソブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市吉江中', '16', '16210', '9391702', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '吉江中', 'ヨシエナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市一日市', '16', '16210', '9391703', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '一日市', 'シテイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市田中', '16', '16210', '9391704', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '田中', 'タナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市在房', '16', '16210', '9391711', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '在房', 'アリフサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市久戸', '16', '16210', '9391712', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '久戸', 'ヒサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市神成', '16', '16210', '9391713', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '神成', 'カミナリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市高畠', '16', '16210', '9391714', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '高畠', 'タカバタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市宗守', '16', '16210', '9391715', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '宗守', 'ムネモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市荒見崎', '16', '16210', '9391716', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '荒見崎', 'アラミサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市梅原', '16', '16210', '9391716', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '梅原', 'ウメハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市東殿', '16', '16210', '9391721', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '東殿', 'ヒガシトノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市徳成', '16', '16210', '9391722', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '徳成', 'トクナリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市利波河', '16', '16210', '9391723', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '利波河', 'トノゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市梅野', '16', '16210', '9391724', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '梅野', 'ウメノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市鍛治', '16', '16210', '9391725', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '鍛治', 'カジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市荒木', '16', '16210', '9391732', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '荒木', 'アラキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市下野', '16', '16210', '9391733', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '下野', 'シタノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市竹林', '16', '16210', '9391734', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '竹林', 'タケバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市小林', '16', '16210', '9391735', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '小林', 'コバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市神宮寺', '16', '16210', '9391735', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '神宮寺', 'ジングウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市高宮', '16', '16210', '9391741', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '高宮', 'タカミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市吉江野', '16', '16210', '9391742', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '吉江野', 'ヨシエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市大塚', '16', '16210', '9391743', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '大塚', 'オオツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市天池', '16', '16210', '9391744', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '天池', 'アマイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市縄蔵', '16', '16210', '9391745', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '縄蔵', 'ナワグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市出村', '16', '16210', '9391746', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '出村', 'デムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市山田', '16', '16210', '9391747', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '山田', 'ヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市赤坂', '16', '16210', '9391751', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '赤坂', 'アカサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市大西', '16', '16210', '9391752', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '大西', 'オオニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市嫁兼', '16', '16210', '9391754', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '嫁兼', 'ヨメガネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市立野原西', '16', '16210', '9391755', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '立野原西', 'タテノガハラニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市土生新', '16', '16210', '9391756', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '土生新', 'ハブシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市土生', '16', '16210', '9391757', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '土生', 'ハブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市殿', '16', '16210', '9391758', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '殿', 'トノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市太美', '16', '16210', '9391761', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '太美', 'フトミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市七曲', '16', '16210', '9391762', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '七曲', 'ナナマガリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市樋瀬戸', '16', '16210', '9391763', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '樋瀬戸', 'ヒノセト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市吉見', '16', '16210', '9391764', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '吉見', 'ヨシミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市綱掛', '16', '16210', '9391765', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '綱掛', 'ツナカケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市立野脇', '16', '16210', '9391766', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '立野脇', 'タテノワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市刀利', '16', '16210', '9391766', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '刀利', 'トウリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市北野長楽寺', '16', '16210', '9391801', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '北野', 'キタノ', null, null, '長楽寺', 'チョウラクジ');
INSERT INTO `ms_addresses` VALUES ('128693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市北野次郎丸', '16', '16210', '9391802', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '北野', 'キタノ', null, null, '次郎丸', 'ジロウマル');
INSERT INTO `ms_addresses` VALUES ('128694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市東西原', '16', '16210', '9391803', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '東西原', 'ヒガシニシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市西明', '16', '16210', '9391804', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '西明', 'サイミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市細野', '16', '16210', '9391805', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '細野', 'ホソノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市北野吉松', '16', '16210', '9391806', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '北野', 'キタノ', null, null, '吉松', 'ヨシマツ');
INSERT INTO `ms_addresses` VALUES ('128698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市北野', '16', '16210', '9391807', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '北野', 'キタノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市理休', '16', '16210', '9391811', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '理休', 'リキュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市蓑谷', '16', '16210', '9391812', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '蓑谷', 'ミノダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市正谷', '16', '16210', '9391813', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '正谷', 'マサタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市大宮野', '16', '16210', '9391814', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '大宮野', 'オオミヤノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市城端東新田', '16', '16210', '9391815', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '城端', 'ジョウハナ', null, null, '東新田', 'ヒガシシンデン');
INSERT INTO `ms_addresses` VALUES ('128704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市城端東上', '16', '16210', '9391816', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '城端', 'ジョウハナ', null, null, '東上', 'ヒガシカミ');
INSERT INTO `ms_addresses` VALUES ('128705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市城端東下', '16', '16210', '9391817', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '城端', 'ジョウハナ', null, null, '東下', 'ヒガシシモ');
INSERT INTO `ms_addresses` VALUES ('128706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市城端川島', '16', '16210', '9391818', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '城端', 'ジョウハナ', null, null, '川島', 'カワシマ');
INSERT INTO `ms_addresses` VALUES ('128707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市泉沢', '16', '16210', '9391821', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '泉沢', 'イズミザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市林道', '16', '16210', '9391822', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '林道', 'リンドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市打尾', '16', '16210', '9391823', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '打尾', 'ウチオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市上田', '16', '16210', '9391824', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '上田', 'ウエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市大鋸屋', '16', '16210', '9391824', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '大鋸屋', 'オガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市大鋸屋大谷島', '16', '16210', '9391825', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '大鋸屋', 'オガヤ', null, null, '大谷島', 'オオタニジマ');
INSERT INTO `ms_addresses` VALUES ('128713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市瀬戸', '16', '16210', '9391826', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '瀬戸', 'セト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市盛新', '16', '16210', '9391827', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '盛新', 'モリシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市中尾', '16', '16210', '9391828', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '中尾', 'ナカオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市千福', '16', '16210', '9391831', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '千福', 'センプク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市千福新', '16', '16210', '9391831', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '千福新', 'センプクシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市塔尾', '16', '16210', '9391832', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '塔尾', 'トウノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市上見', '16', '16210', '9391833', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '上見', 'ウワミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市上原', '16', '16210', '9391834', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '上原', 'カミハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市京塚', '16', '16210', '9391835', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '京塚', 'キョウヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市立野原東', '16', '16210', '9391835', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '立野原東', 'タテノハラヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市南原', '16', '16210', '9391835', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '南原', 'ミナミハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市雁巻島', '16', '16210', '9391836', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '雁巻島', 'ガンマキジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市大宮野新', '16', '16210', '9391837', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '大宮野新', 'オオミヤノシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市西原', '16', '16210', '9391837', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '西原', 'ニシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市細木', '16', '16210', '9391841', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '細木', 'ホソキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市野田', '16', '16210', '9391842', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '野田', 'ノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市金戸', '16', '16210', '9391843', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '金戸', 'カネト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市野口', '16', '16210', '9391844', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '野口', 'ノグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市示野', '16', '16210', '9391845', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '示野', 'シメノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市経塚野', '16', '16210', '9391846', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '経塚野', 'キョウヅカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市国広', '16', '16210', '9391846', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '国広', 'クニヒロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市信末', '16', '16210', '9391851', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '信末', 'ノブスエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市是安', '16', '16210', '9391852', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '是安', 'コレヤス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市城端出丸', '16', '16210', '9391853', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '城端', 'ジョウハナ', null, null, '出丸', 'デマル');
INSERT INTO `ms_addresses` VALUES ('128737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市城端栄町', '16', '16210', '9391854', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '城端', 'ジョウハナ', null, null, '栄町', 'サカエマチ');
INSERT INTO `ms_addresses` VALUES ('128738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市大窪', '16', '16210', '9391855', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '大窪', 'オオクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市是安末広町', '16', '16210', '9391856', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '是安', 'コレヤス', null, null, '末広町', 'スエヒロチョウ');
INSERT INTO `ms_addresses` VALUES ('128740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市城端', '16', '16210', '9391861', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '城端', 'ジョウハナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市城端西下', '16', '16210', '9391862', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '城端', 'ジョウハナ', null, null, '西下', 'ニシシモ');
INSERT INTO `ms_addresses` VALUES ('128742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市城端西上', '16', '16210', '9391863', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '城端', 'ジョウハナ', null, null, '西上', 'ニシカミ');
INSERT INTO `ms_addresses` VALUES ('128743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市城端大工町', '16', '16210', '9391864', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '城端', 'ジョウハナ', null, null, '大工町', 'ダイクマチ');
INSERT INTO `ms_addresses` VALUES ('128744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市城端新町', '16', '16210', '9391865', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '城端', 'ジョウハナ', null, null, '新町', 'シンマチ');
INSERT INTO `ms_addresses` VALUES ('128745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市城端南町', '16', '16210', '9391866', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '城端', 'ジョウハナ', null, null, '南町', 'ミナミマチ');
INSERT INTO `ms_addresses` VALUES ('128746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市城端野下', '16', '16210', '9391867', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '城端', 'ジョウハナ', null, null, '野下', 'ノゲ');
INSERT INTO `ms_addresses` VALUES ('128747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市城端西新田', '16', '16210', '9391868', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '城端', 'ジョウハナ', null, null, '西新田', 'ニシシンデン');
INSERT INTO `ms_addresses` VALUES ('128748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市池尻', '16', '16210', '9391871', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '池尻', 'イケノシリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市久保', '16', '16210', '9391872', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '久保', 'クボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市池田', '16', '16210', '9391873', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '池田', 'イケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市蛇喰', '16', '16210', '9391874', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '蛇喰', 'ジャバミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市大野', '16', '16210', '9391875', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '大野', 'オオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市川上中', '16', '16210', '9391876', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '川上中', 'カワカミナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市井口', '16', '16210', '9391877', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '井口', 'イノクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市上広安', '16', '16210', '9391878', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '上広安', 'カミヒロヤス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市宮後', '16', '16210', '9391879', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '宮後', 'ミヤノウシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市祖山', '16', '16210', '9391901', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '祖山', 'ソヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市大崩島', '16', '16210', '9391902', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '大崩島', 'オオクズシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市寿川', '16', '16210', '9391903', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '寿川', 'スガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市入谷', '16', '16210', '9391904', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '入谷', 'イリタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市東中江', '16', '16210', '9391905', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '東中江', 'ヒガシナカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市高草嶺', '16', '16210', '9391906', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '高草嶺', 'タカソウレイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市夏焼', '16', '16210', '9391907', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '夏焼', 'ナツヤケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市下出', '16', '16210', '9391908', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '下出', 'シモデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市篭渡', '16', '16210', '9391911', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '篭渡', 'カゴド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市大島', '16', '16210', '9391912', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '大島', 'オオシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市田向', '16', '16210', '9391913', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '田向', 'タムカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市上梨', '16', '16210', '9391914', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '上梨', 'カミナシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市相倉', '16', '16210', '9391915', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '相倉', 'アイノクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市見座', '16', '16210', '9391916', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '見座', 'ミザ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市杉尾', '16', '16210', '9391921', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '杉尾', 'スギオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市渡原', '16', '16210', '9391922', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '渡原', 'ドノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市下梨', '16', '16210', '9391923', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '下梨', 'シモナシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市中畑', '16', '16210', '9391924', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '中畑', 'ナカバタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市来栖', '16', '16210', '9391925', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '来栖', 'クルス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市小来栖', '16', '16210', '9391926', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '小来栖', 'コグルス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市梨谷', '16', '16210', '9391927', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '梨谷', 'ナシタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市上松尾', '16', '16210', '9391928', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '上松尾', 'カミマツオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市皆葎', '16', '16210', '9391961', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '皆葎', 'カイムクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市猪谷', '16', '16210', '9391962', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '猪谷', 'イノタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市成出', '16', '16210', '9391963', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '成出', 'ナルデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市楮', '16', '16210', '9391964', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '楮', 'コウズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市真木', '16', '16210', '9391965', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '真木', 'マキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市東赤尾', '16', '16210', '9391966', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '東赤尾', 'ヒガシアカオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市小原', '16', '16210', '9391967', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '小原', 'オハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市上平細島', '16', '16210', '9391968', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '上平細島', 'カミタイラホソジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市小瀬', '16', '16210', '9391971', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '小瀬', 'オゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市葎島', '16', '16210', '9391972', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '葎島', 'ムクラジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市菅沼', '16', '16210', '9391973', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '菅沼', 'スガヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市田下', '16', '16210', '9391974', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '田下', 'タノシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市上中田', '16', '16210', '9391975', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '上中田', 'カミナカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市新屋', '16', '16210', '9391976', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '新屋', 'アタラシヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市西赤尾町', '16', '16210', '9391977', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '西赤尾町', 'ニシアカオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市下島', '16', '16210', '9391978', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '下島', 'シタジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市漆谷', '16', '16210', '9391979', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '漆谷', 'ウルシタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市芦生', '16', '16201', '9392161', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '芦生', 'アシュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市今生津', '16', '16201', '9392162', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '今生津', 'イモヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市布尻', '16', '16201', '9392163', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '布尻', 'ヌノシリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市町長', '16', '16201', '9392164', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '町長', 'マチナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市寺津', '16', '16201', '9392165', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '寺津', 'テラヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市薄波', '16', '16201', '9392171', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '薄波', 'ウスナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市太田薄波', '16', '16201', '9392171', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '太田薄波', 'オオタウスナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市吉野', '16', '16201', '9392172', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '吉野', 'ヨシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市伏木', '16', '16201', '9392173', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '伏木', 'フシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市小糸', '16', '16201', '9392174', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '小糸', 'コイト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市東猪谷', '16', '16201', '9392175', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '東猪谷', 'ヒガシイノタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市舟渡', '16', '16201', '9392176', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '舟渡', 'フナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市西笹津', '16', '16201', '9392181', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '西笹津', 'ニシササヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市岩稲', '16', '16201', '9392182', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '岩稲', 'イワイネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市割山', '16', '16201', '9392183', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '割山', 'ワリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市楡原', '16', '16201', '9392184', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '楡原', 'ニレハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市庵谷', '16', '16201', '9392185', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '庵谷', 'イオリダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市片掛', '16', '16201', '9392186', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '片掛', 'カタカケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市猪谷', '16', '16201', '9392187', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '猪谷', 'イノタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市蟹寺', '16', '16201', '9392188', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '蟹寺', 'カニデラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市加賀沢', '16', '16201', '9392189', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '加賀沢', 'カガサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市合田', '16', '16201', '9392201', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '合田', 'ゴウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市新村', '16', '16201', '9392201', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '新村', 'シンムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市小黒', '16', '16201', '9392202', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '小黒', 'オグロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市松野', '16', '16201', '9392203', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '松野', 'マツノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市万願寺', '16', '16201', '9392204', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '万願寺', 'マンガンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市二松', '16', '16201', '9392205', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '二松', 'フタマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市坂本', '16', '16201', '9392206', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '坂本', 'サカモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市大野', '16', '16201', '9392207', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '大野', 'オオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市南野田', '16', '16201', '9392208', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '南野田', 'ミナミノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市東大久保', '16', '16201', '9392209', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '東大久保', 'ヒガシオオクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市市場', '16', '16201', '9392211', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '市場', 'イチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市舟倉', '16', '16201', '9392212', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '舟倉', 'フナクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市牛ケ増', '16', '16201', '9392213', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '牛ケ増', 'ウシガマセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市寺家', '16', '16201', '9392214', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '寺家', 'ジケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市直坂', '16', '16201', '9392215', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '直坂', 'スグザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市横樋', '16', '16201', '9392216', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '横樋', 'ヨコドイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市西大沢', '16', '16201', '9392221', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '西大沢', 'ニシオオサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市笹津押上', '16', '16201', '9392222', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '笹津', 'ササヅ', null, null, '押上', 'オシアゲ');
INSERT INTO `ms_addresses` VALUES ('128843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市笹津', '16', '16201', '9392223', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '笹津', 'ササヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市春日', '16', '16201', '9392224', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '春日', 'カスガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市長走', '16', '16201', '9392225', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '長走', 'ナガシリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市下タ林', '16', '16201', '9392226', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '下タ林', 'シタバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市稲代', '16', '16201', '9392231', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '稲代', 'イナシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市稲代幸町', '16', '16201', '9392231', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '稲代', 'イナシロ', null, null, '幸町', 'サイワイチョウ');
INSERT INTO `ms_addresses` VALUES ('128849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市小羽', '16', '16201', '9392232', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '小羽', 'コバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市長川原', '16', '16201', '9392233', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '長川原', 'ナンカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市須原', '16', '16201', '9392234', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '須原', 'スワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市下伏', '16', '16201', '9392235', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '下伏', 'ゲブセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市土', '16', '16201', '9392236', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '土', 'ド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市根上', '16', '16201', '9392237', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '根上', 'ネノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市葛原', '16', '16201', '9392238', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '葛原', 'ツヅハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市神通', '16', '16201', '9392241', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '神通', 'ジンヅウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市塩', '16', '16201', '9392242', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '塩', 'シオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市中大久保', '16', '16201', '9392243', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '中大久保', 'ナカオオクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市西塩野', '16', '16201', '9392244', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '西塩野', 'ニシシオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市加納', '16', '16201', '9392245', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '加納', 'カノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市岩木', '16', '16201', '9392246', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '岩木', 'イワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市岩木新', '16', '16201', '9392247', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '岩木新', 'イワキシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市大久保新町', '16', '16201', '9392251', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '大久保新町', 'オオクボシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市下大久保', '16', '16201', '9392251', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '下大久保', 'シモオオクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市下大久保若草町', '16', '16201', '9392251', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '下大久保', 'シモオオクボ', null, null, '若草町', 'ワカクサチョウ');
INSERT INTO `ms_addresses` VALUES ('128866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市下大久保新町', '16', '16201', '9392251', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '下大久保新町', 'シモオオクボシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市下大久保東ケ丘', '16', '16201', '9392251', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '下大久保東ケ丘', 'シモオオクボヒガシガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市下大久保緑町', '16', '16201', '9392251', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '下大久保緑町', 'シモオオクボミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市上大久保', '16', '16201', '9392252', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '上大久保', 'カミオオクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市上大久保泉町', '16', '16201', '9392252', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '上大久保泉町', 'カミオオクボイズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市上大久保北新町', '16', '16201', '9392252', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '上大久保北新町', 'カミオオクボキタシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市上大久保栄町', '16', '16201', '9392252', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '上大久保栄町', 'カミオオクボサカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市上大久保東新町', '16', '16201', '9392252', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '上大久保東新町', 'カミオオクボヒガシシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八木山', '16', '16201', '9392253', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八木山', 'ヤキヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市高内', '16', '16201', '9392254', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '高内', 'タカウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市長附', '16', '16201', '9392255', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '長附', 'ナガツキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市上二杉', '16', '16201', '9392256', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '上二杉', 'カミフタスギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市南花園町', '16', '16201', '9392257', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '南花園町', 'ミナミハナゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町寺家', '16', '16201', '9392301', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町寺家', 'ヤツオマチジケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町杉田', '16', '16201', '9392302', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町杉田', 'ヤツオマチスギタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町大杉', '16', '16201', '9392303', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町大杉', 'ヤツオマチオオスギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町黒田', '16', '16201', '9392304', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町黒田', 'ヤツオマチクロダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町井田新', '16', '16201', '9392305', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町井田新', 'ヤツオマチイダシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町井田', '16', '16201', '9392306', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町井田', 'ヤツオマチイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町中神通', '16', '16201', '9392311', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町中神通', 'ヤツオマチナカジンヅウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町西神通', '16', '16201', '9392311', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町西神通', 'ヤツオマチニシジンヅウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町薄島', '16', '16201', '9392312', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町薄島', 'ヤツオマチウスジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町滅鬼', '16', '16201', '9392313', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町滅鬼', 'ヤツオマチメッキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町城生', '16', '16201', '9392314', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町城生', 'ヤツオマチジョウノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町野飼', '16', '16201', '9392314', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町野飼', 'ヤツオマチノガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町井栗谷', '16', '16201', '9392315', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町井栗谷', 'ヤツオマチイクリタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町深谷', '16', '16201', '9392316', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町深谷', 'ヤツオマチフカダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町丸山', '16', '16201', '9392317', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町丸山', 'ヤツオマチマルヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町小長谷', '16', '16201', '9392321', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町小長谷', 'ヤツオマチコナガタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町小長谷新', '16', '16201', '9392322', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町小長谷新', 'ヤツオマチコナガタニシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町村杉', '16', '16201', '9392323', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町村杉', 'ヤツオマチムラスギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町北谷', '16', '16201', '9392324', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町北谷', 'ヤツオマチキタダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町東坂下', '16', '16201', '9392324', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町東坂下', 'ヤツオマチサコギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町外堀', '16', '16201', '9392325', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町外堀', 'ヤツオマチソトボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町宮腰', '16', '16201', '9392325', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町宮腰', 'ヤツオマチミヤノコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町岩屋', '16', '16201', '9392326', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町岩屋', 'ヤツオマチイワヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町樫尾', '16', '16201', '9392327', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町樫尾', 'ヤツオマチカシオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町下笹原', '16', '16201', '9392331', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町下笹原', 'ヤツオマチシモササハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町掛畑', '16', '16201', '9392332', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町掛畑', 'ヤツオマチカケハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町上黒瀬', '16', '16201', '9392332', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町上黒瀬', 'ヤツオマチカミクロゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町桐谷', '16', '16201', '9392333', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町桐谷', 'ヤツオマチキリダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町小井波', '16', '16201', '9392333', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町小井波', 'ヤツオマチコイナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町滝脇', '16', '16201', '9392333', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町滝脇', 'ヤツオマチタキノワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町上笹原', '16', '16201', '9392334', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町上笹原', 'ヤツオマチカミササハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町茗ケ原', '16', '16201', '9392335', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町茗ケ原', 'ヤツオマチミョウガハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町角間', '16', '16201', '9392336', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町角間', 'ヤツオマチカクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町梅苑町', '16', '16201', '9392337', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町梅苑町', 'ヤツオマチウメゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町鏡町', '16', '16201', '9392341', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町鏡町', 'ヤツオマチカガミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町上新町', '16', '16201', '9392342', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町上新町', 'ヤツオマチカミシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町諏訪町', '16', '16201', '9392343', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町諏訪町', 'ヤツオマチスワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町東新町', '16', '16201', '9392344', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町東新町', 'ヤツオマチヒガシシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町西新町', '16', '16201', '9392345', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町西新町', 'ヤツオマチニシシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町天満町', '16', '16201', '9392351', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町天満町', 'ヤツオマチテンマンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町下新町', '16', '16201', '9392352', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町下新町', 'ヤツオマチシタシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町今町', '16', '16201', '9392353', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町今町', 'ヤツオマチイママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町東町', '16', '16201', '9392354', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町東町', 'ヤツオマチヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町西町', '16', '16201', '9392355', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町西町', 'ヤツオマチニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町三田', '16', '16201', '9392361', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町三田', 'ヤツオマチミタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町奥田', '16', '16201', '9392362', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町奥田', 'ヤツオマチオクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町新田', '16', '16201', '9392363', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町新田', 'ヤツオマチシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町水谷', '16', '16201', '9392364', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町水谷', 'ヤツオマチミズタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町妙川寺', '16', '16201', '9392365', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町妙川寺', 'ヤツオマチミョウセンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町保内', '16', '16201', '9392366', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町保内', 'ヤツオマチヤスウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町平林', '16', '16201', '9392367', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町平林', 'ヤツオマチヒラバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町松原', '16', '16201', '9392367', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町松原', 'ヤツオマチマツバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町田中', '16', '16201', '9392371', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町田中', 'ヤツオマチタナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町翠尾', '16', '16201', '9392371', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町翠尾', 'ヤツオマチミスオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町舘本郷', '16', '16201', '9392372', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町舘本郷', 'ヤツオマチタチホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町高善寺', '16', '16201', '9392373', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町高善寺', 'ヤツオマチコウゼンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町上高善寺', '16', '16201', '9392374', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町上高善寺', 'ヤツオマチカミコウゼンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町石戸', '16', '16201', '9392375', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町石戸', 'ヤツオマチセキド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町福島', '16', '16201', '9392376', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町福島', 'ヤツオマチフクジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町油', '16', '16201', '9392401', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町油', 'ヤツオマチアブラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町西葛坂', '16', '16201', '9392401', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町西葛坂', 'ヤツオマチニシクズサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町東葛坂', '16', '16201', '9392401', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町東葛坂', 'ヤツオマチヒガシクズサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町上田池', '16', '16201', '9392402', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町上田池', 'ヤツオマチカミタイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町下田池', '16', '16201', '9392402', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町下田池', 'ヤツオマチシモタイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町八十島', '16', '16201', '9392402', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町八十島', 'ヤツオマチヤトジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町道畑下中山', '16', '16201', '9392403', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町道畑下中山', 'ヤツオマチドバタケシモナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町宮ノ下', '16', '16201', '9392403', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町宮ノ下', 'ヤツオマチミヤノシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町上ケ島', '16', '16201', '9392404', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町上ケ島', 'ヤツオマチウエガシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町水口', '16', '16201', '9392404', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町水口', 'ヤツオマチミナクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町青根', '16', '16201', '9392405', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町青根', 'ヤツオマチアオネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町岩島', '16', '16201', '9392405', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町岩島', 'ヤツオマチイワシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町高峯', '16', '16201', '9392406', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町高峯', 'ヤツオマチタカミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町乗嶺', '16', '16201', '9392406', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町乗嶺', 'ヤツオマチノリミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町下乗嶺', '16', '16201', '9392407', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町下乗嶺', 'ヤツオマチシモノリミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町新名', '16', '16201', '9392407', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町新名', 'ヤツオマチシンミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町東川倉', '16', '16201', '9392411', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町東川倉', 'ヤツオマチヒガシカワクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町東布谷', '16', '16201', '9392412', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町東布谷', 'ヤツオマチヒガシヌノタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町赤石', '16', '16201', '9392413', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町赤石', 'ヤツオマチアカイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町東松瀬', '16', '16201', '9392414', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町東松瀬', 'ヤツオマチヒガシマツゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町猟師ケ原', '16', '16201', '9392414', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町猟師ケ原', 'ヤツオマチリョウシガハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町桂原', '16', '16201', '9392415', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町桂原', 'ヤツオマチカツラハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町西松瀬', '16', '16201', '9392415', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町西松瀬', 'ヤツオマチニシマツゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町谷折', '16', '16201', '9392416', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町谷折', 'ヤツオマチタニオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町布谷', '16', '16201', '9392416', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町布谷', 'ヤツオマチヌノタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町川住', '16', '16201', '9392417', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町川住', 'ヤツオマチカワスミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町下牧', '16', '16201', '9392417', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町下牧', 'ヤツオマチシモマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町西川倉', '16', '16201', '9392417', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町西川倉', 'ヤツオマチニシカワクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町田頭', '16', '16201', '9392421', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町田頭', 'ヤツオマチタノカシラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町西原', '16', '16201', '9392422', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町西原', 'ヤツオマチニシガハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町新屋', '16', '16201', '9392423', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町新屋', 'ヤツオマチアラヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町東原', '16', '16201', '9392424', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町東原', 'ヤツオマチヒガシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町庵谷', '16', '16201', '9392425', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町庵谷', 'ヤツオマチイオリダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町切詰', '16', '16201', '9392426', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町切詰', 'ヤツオマチキリヅメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町栗須', '16', '16201', '9392431', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町栗須', 'ヤツオマチクリス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町栃折', '16', '16201', '9392431', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町栃折', 'ヤツオマチトチオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町薄尾', '16', '16201', '9392432', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町薄尾', 'ヤツオマチススキオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町中山', '16', '16201', '9392432', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町中山', 'ヤツオマチナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町清水', '16', '16201', '9392433', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町清水', 'ヤツオマチショウズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町花房', '16', '16201', '9392433', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町花房', 'ヤツオマチハナブサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町島地', '16', '16201', '9392434', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町島地', 'ヤツオマチシマジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町上牧', '16', '16201', '9392435', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町上牧', 'ヤツオマチカミマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町下島', '16', '16201', '9392435', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町下島', 'ヤツオマチシモジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町内名', '16', '16201', '9392436', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町内名', 'ヤツオマチウチミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町中島', '16', '16201', '9392436', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町中島', 'ヤツオマチナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町高野', '16', '16201', '9392437', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町高野', 'ヤツオマチタカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町水無', '16', '16201', '9392437', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町水無', 'ヤツオマチミズナシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町大下', '16', '16201', '9392441', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町大下', 'ヤツオマチオオシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町下仁歩', '16', '16201', '9392442', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町下仁歩', 'ヤツオマチシモニンブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町中仁歩', '16', '16201', '9392443', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町中仁歩', 'ヤツオマチナカニンブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町上仁歩', '16', '16201', '9392444', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町上仁歩', 'ヤツオマチカミニンブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町入谷', '16', '16201', '9392445', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町入谷', 'ヤツオマチイリタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町草連坂', '16', '16201', '9392446', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町草連坂', 'ヤツオマチソウレンザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('128999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町鼠谷', '16', '16201', '9392447', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町鼠谷', 'ヤツオマチヨメダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町平沢', '16', '16201', '9392451', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町平沢', 'ヤツオマチヒラサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町三ツ松', '16', '16201', '9392452', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町三ツ松', 'ヤツオマチミツマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町倉ケ谷', '16', '16201', '9392453', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町倉ケ谷', 'ヤツオマチクラガタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町尾畑', '16', '16201', '9392454', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町尾畑', 'ヤツオマチオバタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町武道原', '16', '16201', '9392454', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町武道原', 'ヤツオマチブドウハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町大玉生', '16', '16201', '9392455', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町大玉生', 'ヤツオマチオオダモウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町正間', '16', '16201', '9392456', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町正間', 'ヤツオマチマサマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町茗ケ島', '16', '16201', '9392456', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町茗ケ島', 'ヤツオマチミョウガジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町高熊', '16', '16201', '9392461', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町高熊', 'ヤツオマチタカクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町柴橋', '16', '16201', '9392462', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町柴橋', 'ヤツオマチシバハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町高橋', '16', '16201', '9392462', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町高橋', 'ヤツオマチタカハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町中', '16', '16201', '9392463', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町中', 'ヤツオマチナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町谷内', '16', '16201', '9392463', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町谷内', 'ヤツオマチヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町竹ノ内', '16', '16201', '9392464', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町竹ノ内', 'ヤツオマチタケノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町宮ケ島', '16', '16201', '9392464', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町宮ケ島', 'ヤツオマチミヤガシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町尾久', '16', '16201', '9392465', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町尾久', 'ヤツオマチオギュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町窪', '16', '16201', '9392465', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町窪', 'ヤツオマチクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町天池', '16', '16201', '9392466', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町天池', 'ヤツオマチアマイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町追分', '16', '16201', '9392467', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町追分', 'ヤツオマチオイワケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町高瀬', '16', '16201', '9392467', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町高瀬', 'ヤツオマチタカセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町坂ノ下', '16', '16201', '9392471', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町坂ノ下', 'ヤツオマチサカノシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町高尾', '16', '16201', '9392471', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町高尾', 'ヤツオマチタカオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町野須郷', '16', '16201', '9392472', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町野須郷', 'ヤツオマチノスゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町和山', '16', '16201', '9392472', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町和山', 'ヤツオマチワヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町上ノ名', '16', '16201', '9392473', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町上ノ名', 'ヤツオマチウエノミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町峯', '16', '16201', '9392473', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町峯', 'ヤツオマチミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町下ノ名', '16', '16201', '9392474', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町下ノ名', 'ヤツオマチシタノミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町須郷', '16', '16201', '9392474', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町須郷', 'ヤツオマチスゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町足谷', '16', '16201', '9392475', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町足谷', 'ヤツオマチアシタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町柚木', '16', '16201', '9392475', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町柚木', 'ヤツオマチユノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町細滝', '16', '16201', '9392476', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町細滝', 'ヤツオマチホソダキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八尾町上野', '16', '16201', '9392477', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八尾町上野', 'ヤツオマチウワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市利賀村栗当', '16', '16210', '9392501', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '利賀村栗当', 'トガムラクリトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市利賀村高沼', '16', '16210', '9392502', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '利賀村高沼', 'トガムラタカヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市利賀村草嶺', '16', '16210', '9392503', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '利賀村草嶺', 'トガムラソウレイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市利賀村押場', '16', '16210', '9392504', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '利賀村押場', 'トガムラオシバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市利賀村北豆谷', '16', '16210', '9392505', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '利賀村北豆谷', 'トガムラキタマメダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市利賀村大豆谷', '16', '16210', '9392506', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '利賀村大豆谷', 'トガムラオオマメダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市利賀村', '16', '16210', '9392507', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '利賀村', 'トガムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市利賀村岩渕', '16', '16210', '9392508', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '利賀村岩渕', 'トガムライワブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市利賀村北島', '16', '16210', '9392509', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '利賀村北島', 'トガムラキタジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市利賀村百瀬川', '16', '16210', '9392511', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '利賀村百瀬川', 'トガムラモモセガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市利賀村中村', '16', '16210', '9392512', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '利賀村中村', 'トガムラナカムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市利賀村上百瀬', '16', '16210', '9392513', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '利賀村上百瀬', 'トガムラカミモモセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市利賀村上畠', '16', '16210', '9392514', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '利賀村上畠', 'トガムラウエバタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市利賀村細島', '16', '16210', '9392515', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '利賀村細島', 'トガムラホソジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市利賀村坂上', '16', '16210', '9392516', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '利賀村坂上', 'トガムラサカウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市利賀村阿別当', '16', '16210', '9392517', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '利賀村阿別当', 'トガムラアベットウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市利賀村大勘場', '16', '16210', '9392518', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '利賀村大勘場', 'トガムラタイカンバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県南砺市利賀村水無', '16', '16210', '9392519', '富山県', 'トヤマケン', '南砺市', 'ナントシ', '利賀村水無', 'トガムラミズナシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市婦中町小長沢', '16', '16201', '9392601', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '婦中町小長沢', 'フチュウマチコナガサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市婦中町下邑', '16', '16201', '9392602', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '婦中町下邑', 'フチュウマチシモムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市婦中町羽根', '16', '16201', '9392603', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '婦中町羽根', 'フチュウマチハネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市婦中町小野島', '16', '16201', '9392604', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '婦中町小野島', 'フチュウマチコノシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市婦中町富川', '16', '16201', '9392604', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '婦中町富川', 'フチュウマチトミカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市婦中町河原町', '16', '16201', '9392605', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '婦中町河原町', 'フチュウマチカワラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市婦中町長沢', '16', '16201', '9392606', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '婦中町長沢', 'フチュウマチナガサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市婦中町ひまわり台', '16', '16201', '9392606', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '婦中町ひまわり台', 'フチュウマチヒマワリダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市婦中町新町', '16', '16201', '9392607', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '婦中町新町', 'フチュウマチアラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市婦中町かたかご台', '16', '16201', '9392611', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '婦中町かたかご台', 'フチュウマチカタカゴダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市婦中町下吉川', '16', '16201', '9392611', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '婦中町下吉川', 'フチュウマチシモヨシカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市婦中町高田', '16', '16201', '9392611', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '婦中町高田', 'フチュウマチタカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市婦中町上吉川', '16', '16201', '9392612', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '婦中町上吉川', 'フチュウマチカミヨシカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市婦中町上吉川ニュータウン', '16', '16201', '9392612', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '婦中町上吉川ニュータウン', 'フチュウマチカミヨシカワニュータウン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市婦中町高日附', '16', '16201', '9392613', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '婦中町高日附', 'フチュウマチタカヒヅキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市婦中町上井沢', '16', '16201', '9392614', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '婦中町上井沢', 'フチュウマチカミイサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市婦中町熊野道', '16', '16201', '9392615', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '婦中町熊野道', 'フチュウマチヤンド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市婦中町小倉', '16', '16201', '9392616', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '婦中町小倉', 'フチュウマチオグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市婦中町島田', '16', '16201', '9392617', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '婦中町島田', 'フチュウマチシマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市婦中町富崎', '16', '16201', '9392621', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '婦中町富崎', 'フチュウマチトミサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市婦中町沢田', '16', '16201', '9392622', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '婦中町沢田', 'フチュウマチサワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市婦中町千里', '16', '16201', '9392622', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '婦中町千里', 'フチュウマチチサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市婦中町鉾木', '16', '16201', '9392622', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '婦中町鉾木', 'フチュウマチホコノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市婦中町蓮花寺', '16', '16201', '9392623', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '婦中町蓮花寺', 'フチュウマチレンゲジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市婦中町下瀬', '16', '16201', '9392624', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '婦中町下瀬', 'フチュウマチシモゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市婦中町上瀬', '16', '16201', '9392625', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '婦中町上瀬', 'フチュウマチカミゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市婦中町三瀬', '16', '16201', '9392625', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '婦中町三瀬', 'フチュウマチサンノセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市婦中町高山', '16', '16201', '9392625', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '婦中町高山', 'フチュウマチタカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市婦中町道島', '16', '16201', '9392626', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '婦中町道島', 'フチュウマチドウジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市婦中町上野', '16', '16201', '9392627', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '婦中町上野', 'フチュウマチウワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市婦中町皆杓', '16', '16201', '9392627', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '婦中町皆杓', 'フチュウマチカイジャク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市婦中町高塚', '16', '16201', '9392631', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '婦中町高塚', 'フチュウマチタカツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市婦中町宮ケ谷', '16', '16201', '9392631', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '婦中町宮ケ谷', 'フチュウマチミヤガタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市婦中町外輪野', '16', '16201', '9392632', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '婦中町外輪野', 'フチュウマチソトワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市婦中町吉住', '16', '16201', '9392632', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '婦中町吉住', 'フチュウマチヨシズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市婦中町東谷', '16', '16201', '9392633', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '婦中町東谷', 'フチュウマチヒガシタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市婦中町牛滑', '16', '16201', '9392634', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '婦中町牛滑', 'フチュウマチウシナメリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市婦中町大瀬谷', '16', '16201', '9392635', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '婦中町大瀬谷', 'フチュウマチオオセダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市婦中町東山', '16', '16201', '9392636', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '婦中町東山', 'フチュウマチヒガシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市婦中町葎原', '16', '16201', '9392636', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '婦中町葎原', 'フチュウマチムクガハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市婦中町鶚谷', '16', '16201', '9392637', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '婦中町鶚谷', 'フチュウマチミサゴダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市婦中町細谷', '16', '16201', '9392638', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '婦中町細谷', 'フチュウマチホソタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市婦中町吉谷', '16', '16201', '9392638', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '婦中町吉谷', 'フチュウマチヨシタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市婦中町平等', '16', '16201', '9392639', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '婦中町平等', 'フチュウマチダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市婦中町余川西余川', '16', '16201', '9392649', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '婦中町余川', 'フチュウマチヨカワ', null, null, '西余川', 'ニシヨカワ');
INSERT INTO `ms_addresses` VALUES ('129098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市婦中町西本郷', '16', '16201', '9392701', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '婦中町西本郷', 'フチュウマチニシホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市婦中町田島', '16', '16201', '9392702', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '婦中町田島', 'フチュウマチタジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市婦中町希望ケ丘', '16', '16201', '9392703', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '婦中町希望ケ丘', 'フチュウマチキボウガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市婦中町羽根新', '16', '16201', '9392704', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '婦中町羽根新', 'フチュウマチハネシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市婦中町宮ケ島', '16', '16201', '9392705', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '婦中町宮ケ島', 'フチュウマチミヤガシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市婦中町速星', '16', '16201', '9392706', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '婦中町速星', 'フチュウマチハヤホシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市婦中町東本郷', '16', '16201', '9392707', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '婦中町東本郷', 'フチュウマチヒガシホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市婦中町島本郷', '16', '16201', '9392708', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '婦中町島本郷', 'フチュウマチシマホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市婦中町夢ケ丘', '16', '16201', '9392709', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '婦中町夢ケ丘', 'フチュウマチユメガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市婦中町鵜坂', '16', '16201', '9392711', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '婦中町鵜坂', 'フチュウマチウサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市婦中町塚原', '16', '16201', '9392712', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '婦中町塚原', 'フチュウマチツカハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市婦中町上轡田', '16', '16201', '9392713', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '婦中町上轡田', 'フチュウマチカミクツワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市婦中町増田', '16', '16201', '9392714', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '婦中町増田', 'フチュウマチマスダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市婦中町下坂倉', '16', '16201', '9392715', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '婦中町下坂倉', 'フチュウマチシモサカクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市婦中町下轡田', '16', '16201', '9392716', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '婦中町下轡田', 'フチュウマチシモクツワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市婦中町上田島', '16', '16201', '9392717', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '婦中町上田島', 'フチュウマチカミタジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市婦中町分田', '16', '16201', '9392718', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '婦中町分田', 'フチュウマチブンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市婦中町西ヶ丘', '16', '16201', '9392719', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '婦中町西ヶ丘', 'フチュウマチニシガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市婦中町板倉', '16', '16201', '9392721', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '婦中町板倉', 'フチュウマチイタクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市婦中町板倉新', '16', '16201', '9392721', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '婦中町板倉新', 'フチュウマチイタクラシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市婦中町添島', '16', '16201', '9392722', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '婦中町添島', 'フチュウマチソエジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市婦中町萩島', '16', '16201', '9392723', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '婦中町萩島', 'フチュウマチハギノシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市婦中町ねむの木', '16', '16201', '9392724', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '婦中町ねむの木', 'フチュウマチネムノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市婦中町持田', '16', '16201', '9392725', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '婦中町持田', 'フチュウマチモチデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市婦中町蔵島', '16', '16201', '9392726', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '婦中町蔵島', 'フチュウマチゾウジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市婦中町砂子田', '16', '16201', '9392727', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '婦中町砂子田', 'フチュウマチスナゴダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市婦中町蛍川', '16', '16201', '9392728', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '婦中町蛍川', 'フチュウマチホタルガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市婦中町響の杜', '16', '16201', '9392729', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '婦中町響の杜', 'フチュウマチヒビキノモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市婦中町青島', '16', '16201', '9392731', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '婦中町青島', 'フチュウマチアオジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市婦中町横野', '16', '16201', '9392732', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '婦中町横野', 'フチュウマチヨコノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市婦中町成子', '16', '16201', '9392733', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '婦中町成子', 'フチュウマチナルコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市婦中町新屋', '16', '16201', '9392734', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '婦中町新屋', 'フチュウマチアラヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市婦中町為成新', '16', '16201', '9392735', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '婦中町為成新', 'フチュウマチタメナリシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市婦中町上新屋', '16', '16201', '9392736', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '婦中町上新屋', 'フチュウマチカミアラヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市婦中町十五丁', '16', '16201', '9392737', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '婦中町十五丁', 'フチュウマチジュウゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市婦中町道喜島', '16', '16201', '9392738', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '婦中町道喜島', 'フチュウマチドウキジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市婦中町中名', '16', '16201', '9392741', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '婦中町中名', 'フチュウマチナカノミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市婦中町堀', '16', '16201', '9392742', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '婦中町堀', 'フチュウマチホリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市婦中町清水島', '16', '16201', '9392743', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '婦中町清水島', 'フチュウマチシミズシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市婦中町地角', '16', '16201', '9392744', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '婦中町地角', 'フチュウマチジカク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市婦中町広田', '16', '16201', '9392745', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '婦中町広田', 'フチュウマチヒロタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市婦中町浜子', '16', '16201', '9392746', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '婦中町浜子', 'フチュウマチハマノコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市婦中町中島', '16', '16201', '9392747', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '婦中町中島', 'フチュウマチナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市婦中町田屋', '16', '16201', '9392748', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '婦中町田屋', 'フチュウマチタヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市婦中町田屋新', '16', '16201', '9392748', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '婦中町田屋新', 'フチュウマチタヤシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市婦中町余川東余川', '16', '16201', '9392749', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '婦中町余川', 'フチュウマチヨカワ', null, null, '東余川', 'ヒガシヨカワ');
INSERT INTO `ms_addresses` VALUES ('129144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市婦中町安田', '16', '16201', '9392751', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '婦中町安田', 'フチュウマチヤスダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市婦中町小泉', '16', '16201', '9392752', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '婦中町小泉', 'フチュウマチコイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市婦中町笹倉', '16', '16201', '9392753', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '婦中町笹倉', 'フチュウマチササクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市婦中町麦島', '16', '16201', '9392754', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '婦中町麦島', 'フチュウマチムギジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市婦中町袋', '16', '16201', '9392755', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '婦中町袋', 'フチュウマチフクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市婦中町下井沢', '16', '16201', '9392756', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '婦中町下井沢', 'フチュウマチシモイサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市婦中町道場', '16', '16201', '9392757', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '婦中町道場', 'フチュウマチドウジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市婦中町下条', '16', '16201', '9392758', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '婦中町下条', 'フチュウマチゲジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市婦中町友坂', '16', '16201', '9392759', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '婦中町友坂', 'フチュウマチトモサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水橋印田町', '16', '16201', '9393501', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水橋印田町', 'ミズハシインデンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水橋川原町', '16', '16201', '9393502', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水橋川原町', 'ミズハシカワラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水橋立山町', '16', '16201', '9393503', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水橋立山町', 'ミズハシタテヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水橋今町', '16', '16201', '9393504', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水橋今町', 'ミズハシイママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水橋浜町', '16', '16201', '9393505', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水橋浜町', 'ミズハシハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水橋山王町', '16', '16201', '9393506', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水橋山王町', 'ミズハシサンノウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水橋中町', '16', '16201', '9393511', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水橋中町', 'ミズハシナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水橋大町西部地区', '16', '16201', '9393512', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水橋大町', 'ミズハシオオマチ', null, null, '西部地区', 'セイブチク');
INSERT INTO `ms_addresses` VALUES ('129162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水橋西大町', '16', '16201', '9393512', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水橋西大町', 'ミズハシニシオオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水橋大正町', '16', '16201', '9393513', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水橋大正町', 'ミズハシタイショウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水橋新堂町', '16', '16201', '9393514', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水橋新堂町', 'ミズハシシンドウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水橋辻ケ堂', '16', '16201', '9393515', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水橋辻ケ堂', 'ミズハシツジガドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水橋荒町', '16', '16201', '9393516', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水橋荒町', 'ミズハシアラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水橋畠等', '16', '16201', '9393521', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水橋畠等', 'ミズハシハタケラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水橋花の井町', '16', '16201', '9393522', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水橋花の井町', 'ミズハシハナノイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水橋池田舘', '16', '16201', '9393523', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水橋池田舘', 'ミズハシイケダタチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水橋伊勢屋', '16', '16201', '9393524', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水橋伊勢屋', 'ミズハシイセヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水橋駅前', '16', '16201', '9393525', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水橋駅前', 'ミズハシエキマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水橋昭和町', '16', '16201', '9393526', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水橋昭和町', 'ミズハシショウワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水橋池田町', '16', '16201', '9393531', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水橋池田町', 'ミズハシイケダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水橋二ツ屋', '16', '16201', '9393532', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水橋二ツ屋', 'ミズハシフタツヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水橋高堂', '16', '16201', '9393533', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水橋高堂', 'ミズハシタカドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水橋金尾', '16', '16201', '9393534', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水橋金尾', 'ミズハシカナオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水橋番頭名', '16', '16201', '9393534', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水橋番頭名', 'ミズハシバンドウミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水橋新堀', '16', '16201', '9393535', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水橋新堀', 'ミズハシシンボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水橋金尾新', '16', '16201', '9393536', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水橋金尾新', 'ミズハシカナオシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水橋沖', '16', '16201', '9393541', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水橋沖', 'ミズハシオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水橋開発', '16', '16201', '9393542', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水橋開発', 'ミズハシカイホツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水橋常願寺', '16', '16201', '9393543', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水橋常願寺', 'ミズハシジョウガンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水橋入江', '16', '16201', '9393544', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水橋入江', 'ミズハシイリエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水橋入部町', '16', '16201', '9393545', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水橋入部町', 'ミズハシニュウブマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水橋二杉', '16', '16201', '9393546', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水橋二杉', 'ミズハシフタスギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水橋柴草', '16', '16201', '9393547', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水橋柴草', 'ミズハシシバクサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市三郷', '16', '16201', '9393548', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '三郷', 'サンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水橋中村', '16', '16201', '9393551', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水橋中村', 'ミズハシナカムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水橋肘崎', '16', '16201', '9393552', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水橋肘崎', 'ミズハシカイナザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水橋上的場', '16', '16201', '9393553', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水橋上的場', 'ミズハシカミマトバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水橋的場', '16', '16201', '9393553', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水橋的場', 'ミズハシマトバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水橋小路', '16', '16201', '9393554', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水橋小路', 'ミズハシショウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水橋市田袋', '16', '16201', '9393555', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水橋市田袋', 'ミズハシイチダブクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水橋中新町', '16', '16201', '9393556', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水橋中新町', 'ミズハシナカシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水橋新保', '16', '16201', '9393557', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水橋新保', 'ミズハシシンボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水橋新保新町', '16', '16201', '9393557', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水橋新保新町', 'ミズハシシンボシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水橋平榎', '16', '16201', '9393557', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水橋平榎', 'ミズハシヒラエノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市水橋町袋', '16', '16201', '9393557', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '水橋町袋', 'ミズハシマチブクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市大泉東部', '16', '16201', '9398001', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '大泉東部', 'オオイズミトウブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市公文名', '16', '16201', '9398002', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '公文名', 'クモンミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市西公文名町', '16', '16201', '9398003', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '西公文名町', 'ニシクモンミョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市西公文名', '16', '16201', '9398004', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '西公文名', 'ニシクモンミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市中市', '16', '16201', '9398005', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '中市', 'ナカイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市山室', '16', '16201', '9398006', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '山室', 'ヤマムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市山室向陽台', '16', '16201', '9398007', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '山室向陽台', 'ヤマムロコウヨウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市山室新町', '16', '16201', '9398008', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '山室新町', 'ヤマムロシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市不二栄町', '16', '16201', '9398011', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '不二栄町', 'フジサカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市高原本町', '16', '16201', '9398012', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '高原本町', 'タカハラホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市高原町', '16', '16201', '9398013', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '高原町', 'タカハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市中川原新町', '16', '16201', '9398014', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '中川原新町', 'ナカガワラシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市中川原', '16', '16201', '9398015', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '中川原', 'ナカガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市中川原台', '16', '16201', '9398016', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '中川原台', 'ナカガワラダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市松ケ丘', '16', '16201', '9398017', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '松ケ丘', 'マツガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市若葉台', '16', '16201', '9398021', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '若葉台', 'ワカバダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市山室荒屋', '16', '16201', '9398022', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '山室荒屋', 'ヤマムロアラヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市古寺', '16', '16201', '9398023', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '古寺', 'フルデラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市古寺新町', '16', '16201', '9398024', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '古寺新町', 'フルデラシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市大島', '16', '16201', '9398025', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '大島', 'オオシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市山室荒屋新町', '16', '16201', '9398026', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '山室荒屋新町', 'ヤマムロアラヤシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市東流杉', '16', '16201', '9398031', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '東流杉', 'ヒガシナガレスギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市流杉', '16', '16201', '9398032', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '流杉', 'ナガレスギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市横内', '16', '16201', '9398033', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '横内', 'ヨコウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市新横内町', '16', '16201', '9398034', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '新横内町', 'シンヨコウチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市大宮町', '16', '16201', '9398035', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '大宮町', 'オオミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市高屋敷', '16', '16201', '9398036', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '高屋敷', 'タカヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市太田中区', '16', '16201', '9398041', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '太田中区', 'オオタナカク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市太田北区', '16', '16201', '9398042', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '太田北区', 'オオタキタク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市太田向陽台', '16', '16201', '9398043', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '太田向陽台', 'オオタコウヨウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市太田南町', '16', '16201', '9398044', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '太田南町', 'オオタミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市本郷町', '16', '16201', '9398045', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '本郷町', 'ホンゴウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市本郷新', '16', '16201', '9398046', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '本郷新', 'ホンゴウシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市清住町', '16', '16201', '9398047', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '清住町', 'キヨズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市太田', '16', '16201', '9398048', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '太田', 'オオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市大泉中部', '16', '16201', '9398051', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '大泉中部', 'オオイズミチュウブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市大泉1区南部', '16', '16201', '9398052', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '大泉1区南部', 'オオイズミ01クナンブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市堀川天山町', '16', '16201', '9398053', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '堀川天山町', 'ホリカワテンザンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市新堀町', '16', '16201', '9398054', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '新堀町', 'シンボリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市下堀', '16', '16201', '9398055', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '下堀', 'シモホリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市上堀町', '16', '16201', '9398056', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '上堀町', 'カミホリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市堀', '16', '16201', '9398057', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '堀', 'ホリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市大泉', '16', '16201', '9398058', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '大泉', 'オオイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市上新保', '16', '16201', '9398061', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '上新保', 'カミシンボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市上堀南町', '16', '16201', '9398062', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '上堀南町', 'カミホリミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市小杉', '16', '16201', '9398063', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '小杉', 'コスギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市赤田', '16', '16201', '9398064', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '赤田', 'アカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市赤田新町', '16', '16201', '9398065', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '赤田新町', 'アカダシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市朝菜町', '16', '16201', '9398066', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '朝菜町', 'アサナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市上袋', '16', '16201', '9398071', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '上袋', 'カミブクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市堀川町', '16', '16201', '9398072', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '堀川町', 'ホリカワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市大町', '16', '16201', '9398073', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '大町', 'オオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市大町南台', '16', '16201', '9398074', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '大町南台', 'オオマチミナミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市今泉', '16', '16201', '9398075', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '今泉', 'イマイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市太郎丸', '16', '16201', '9398076', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '太郎丸', 'タロウマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市春日町', '16', '16201', '9398077', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '春日町', 'カスガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市堀川小泉町', '16', '16201', '9398081', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '堀川小泉町', 'ホリカワコイズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市小泉町', '16', '16201', '9398082', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '小泉町', 'コイズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市西中野本町', '16', '16201', '9398083', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '西中野本町', 'ニシナカノホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市西中野町', '16', '16201', '9398084', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '西中野町', 'ニシナカノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市中野新町', '16', '16201', '9398085', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '中野新町', 'ナカノシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市東中野町', '16', '16201', '9398086', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '東中野町', 'ヒガシナカノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市大泉町', '16', '16201', '9398087', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '大泉町', 'オオイズミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市旭町', '16', '16201', '9398091', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '旭町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市雄山町', '16', '16201', '9398092', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '雄山町', 'オヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市大泉東町', '16', '16201', '9398093', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '大泉東町', 'オオイズミヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市大泉本町', '16', '16201', '9398094', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '大泉本町', 'オオイズミホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市大泉中町', '16', '16201', '9398095', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '大泉中町', 'オオイズミナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市西大泉', '16', '16201', '9398096', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '西大泉', 'ニシオオイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市大泉北町', '16', '16201', '9398097', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '大泉北町', 'オオイズミキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市西野新', '16', '16201', '9398101', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '西野新', 'ニシノシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市昭和新町', '16', '16201', '9398102', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '昭和新町', 'ショウワシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市大場', '16', '16201', '9398103', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '大場', 'オオバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市西番', '16', '16201', '9398104', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '西番', 'ニシノバン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市城新町', '16', '16201', '9398111', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '城新町', 'ジョウシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市城ケ丘', '16', '16201', '9398112', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '城ケ丘', 'ジョウガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市城若町', '16', '16201', '9398113', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '城若町', 'ジョウワカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市城村', '16', '16201', '9398114', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '城村', 'ジョウムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市城村新町', '16', '16201', '9398115', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '城村新町', 'ジョウムラシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市石屋', '16', '16201', '9398121', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '石屋', 'イシヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市新名', '16', '16201', '9398122', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '新名', 'シンミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市関', '16', '16201', '9398123', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '関', 'セキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八川', '16', '16201', '9398124', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八川', 'ハチカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市中屋', '16', '16201', '9398131', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '中屋', 'ナカヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市月岡町', '16', '16201', '9398132', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '月岡町', 'ツキオカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市月見が丘', '16', '16201', '9398133', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '月見が丘', 'ツキミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市上千俵町', '16', '16201', '9398134', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '上千俵町', 'カミセンビョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市千俵町', '16', '16201', '9398135', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '千俵町', 'センビョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市月見町', '16', '16201', '9398136', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '月見町', 'ツキミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市開発', '16', '16201', '9398137', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '開発', 'カイホツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市上千俵', '16', '16201', '9398138', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '上千俵', 'カミセンビョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市月岡新', '16', '16201', '9398139', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '月岡新', 'ツキオカシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市月岡東緑町', '16', '16201', '9398141', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '月岡東緑町', 'ツキオカヒガシミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市月岡西緑町', '16', '16201', '9398142', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '月岡西緑町', 'ツキオカニシミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市上布目', '16', '16201', '9398143', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '上布目', 'カミヌノメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市上今町', '16', '16201', '9398144', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '上今町', 'カミイママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市大井', '16', '16201', '9398145', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '大井', 'オオイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市中布目', '16', '16201', '9398146', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '中布目', 'ナカヌノメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市上栄', '16', '16201', '9398151', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '上栄', 'カミサカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市経力', '16', '16201', '9398152', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '経力', 'キョウリキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市吉岡', '16', '16201', '9398153', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '吉岡', 'ヨシオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市森田', '16', '16201', '9398154', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '森田', 'モリタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市江本', '16', '16201', '9398155', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '江本', 'エノモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市珠泉東町', '16', '16201', '9398156', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '珠泉東町', 'タマイズミヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市珠泉西町', '16', '16201', '9398157', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '珠泉西町', 'タマイズミニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市牧田', '16', '16201', '9398161', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '牧田', 'マキダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市青柳', '16', '16201', '9398162', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '青柳', 'アオヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市青柳新', '16', '16201', '9398163', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '青柳新', 'アオヤナギシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市林崎', '16', '16201', '9398164', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '林崎', 'ハヤシザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市杉瀬', '16', '16201', '9398165', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '杉瀬', 'スギセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市上熊野', '16', '16201', '9398166', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '上熊野', 'カミクマノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市宮保', '16', '16201', '9398171', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '宮保', 'ミヤノホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市辰尾', '16', '16201', '9398172', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '辰尾', 'タツオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市辰尾新町', '16', '16201', '9398173', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '辰尾新町', 'タツオシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市下栗山', '16', '16201', '9398174', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '下栗山', 'シモクリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市上栗山', '16', '16201', '9398175', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '上栗山', 'カミクリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市南栗山', '16', '16201', '9398176', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '南栗山', 'ミナミクリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市安養寺', '16', '16201', '9398177', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '安養寺', 'アンヨウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市栗山', '16', '16201', '9398178', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '栗山', 'クリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市若竹町', '16', '16201', '9398181', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '若竹町', 'ワカタケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市悪王寺', '16', '16201', '9398182', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '悪王寺', 'アクオウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市小中', '16', '16201', '9398183', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '小中', 'コナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市二俣新町', '16', '16201', '9398184', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '二俣新町', 'フタマタシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市二俣', '16', '16201', '9398185', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '二俣', 'フタマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市布市', '16', '16201', '9398191', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '布市', 'ヌノイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市布市新町', '16', '16201', '9398192', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '布市新町', 'ヌノイチシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市石田', '16', '16201', '9398193', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '石田', 'イシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市南金屋', '16', '16201', '9398194', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '南金屋', 'ミナミカナヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市上野', '16', '16201', '9398195', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '上野', 'ウワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市上野南町', '16', '16201', '9398196', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '上野南町', 'ウワノミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市上野寿町', '16', '16201', '9398197', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '上野寿町', 'ウワノコトブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市花園町', '16', '16201', '9398201', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '花園町', 'ハナゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市西田地方町', '16', '16201', '9398202', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '西田地方町', 'ニシデンジガタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市西田地方', '16', '16201', '9398203', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '西田地方', 'ニシデンジガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市根塚町', '16', '16201', '9398204', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '根塚町', 'ネヅカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市新根塚町', '16', '16201', '9398205', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '新根塚町', 'シンネヅカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市布瀬町', '16', '16201', '9398206', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '布瀬町', 'ヌノセマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市布瀬本町', '16', '16201', '9398207', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '布瀬本町', 'ヌノセホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市布瀬町南', '16', '16201', '9398208', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '布瀬町南', 'ヌノセマチミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市二口町', '16', '16201', '9398211', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '二口町', 'フタクチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市掛尾町', '16', '16201', '9398212', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '掛尾町', 'カケオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市黒瀬', '16', '16201', '9398213', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '黒瀬', 'クロセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市黒崎', '16', '16201', '9398214', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '黒崎', 'クロサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市掛尾栄町', '16', '16201', '9398215', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '掛尾栄町', 'カケオサカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市黒瀬北町', '16', '16201', '9398216', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '黒瀬北町', 'クロセキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市八日町', '16', '16201', '9398221', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '八日町', 'ヨウカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市蜷川', '16', '16201', '9398222', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '蜷川', 'ニナガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市島田', '16', '16201', '9398223', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '島田', 'シマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市友杉', '16', '16201', '9398224', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '友杉', 'トモスギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市上八日町', '16', '16201', '9398225', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '上八日町', 'カミヨウカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市下熊野', '16', '16201', '9398231', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '下熊野', 'シモクマノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市南央町', '16', '16201', '9398232', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '南央町', 'ナンオウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市任海', '16', '16201', '9398233', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '任海', 'トウミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市南中田', '16', '16201', '9398234', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '南中田', 'ミナミナカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市惣在寺', '16', '16201', '9398241', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '惣在寺', 'ソウザイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市福居', '16', '16201', '9398242', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '福居', 'フクイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市押上', '16', '16201', '9398243', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '押上', 'オシアゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市吉倉', '16', '16201', '9398244', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '吉倉', 'ヨシクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市西荒屋', '16', '16201', '9398251', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '西荒屋', 'ニシアラヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市秋ケ島', '16', '16201', '9398252', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '秋ケ島', 'アキガシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市新保', '16', '16201', '9398253', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '新保', 'シンボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市別名', '16', '16201', '9398254', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '別名', 'ベツミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市萩原', '16', '16201', '9398261', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '萩原', 'ハギハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市塚原', '16', '16201', '9398262', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '塚原', 'ツカハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市才覚寺', '16', '16201', '9398263', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '才覚寺', 'サイカクジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市経田', '16', '16201', '9398264', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '経田', 'キョウデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市太郎丸西町', '16', '16201', '9398271', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '太郎丸西町', 'タロウマルニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市太郎丸本町', '16', '16201', '9398272', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '太郎丸本町', 'タロウマルホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市今泉西部町', '16', '16201', '9398281', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '今泉西部町', 'イマイズミセイブマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '富山県富山市今泉北部町', '16', '16201', '9398282', '富山県', 'トヤマケン', '富山市', 'トヤマシ', '今泉北部町', 'イマイズミホクブマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別市', '01', '01219', '0940000', '北海道', 'ホッカイドウ', '紋別市', 'モンベツシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('129394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市', '15', '15202', '9400000', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('129395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市川辺町', '15', '15202', '9400001', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '川辺町', 'カワベマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市十二潟町', '15', '15202', '9400002', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '十二潟町', 'ジュウニガタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市高見', '15', '15202', '9400003', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '高見', 'タカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市高見町', '15', '15202', '9400004', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '高見町', 'タカミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市東高見', '15', '15202', '9400006', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '東高見', 'ヒガシタカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市黒津町', '15', '15202', '9400007', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '黒津町', 'クロヅマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市天神町', '15', '15202', '9400008', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '天神町', 'テンジンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別市北浜町', '01', '01219', '0940001', '北海道', 'ホッカイドウ', '紋別市', 'モンベツシ', '北浜町', 'キタハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市下々条町', '15', '15202', '9400011', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '下々条町', 'シモゲジョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市下々条', '15', '15202', '9400012', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '下々条', 'シモゲジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市原町', '15', '15202', '9400013', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '原町', 'ハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市北園町', '15', '15202', '9400014', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '北園町', 'キタゾノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市寿', '15', '15202', '9400015', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '寿', 'コトブキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市宝', '15', '15202', '9400016', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '宝', 'タカラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市中瀬', '15', '15202', '9400017', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '中瀬', 'ナカセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別市真砂町', '01', '01219', '0940002', '北海道', 'ホッカイドウ', '紋別市', 'モンベツシ', '真砂町', 'マサゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市城岡', '15', '15202', '9400021', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '城岡', 'ジョウオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市東新町', '15', '15202', '9400022', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '東新町', 'ヒガシアラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市新町', '15', '15202', '9400023', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '新町', 'アラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市西新町', '15', '15202', '9400024', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '西新町', 'ニシアラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市泉', '15', '15202', '9400025', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '泉', 'イズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市石内', '15', '15202', '9400026', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '石内', 'イシウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市西蔵王', '15', '15202', '9400027', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '西蔵王', 'ニシザオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市蔵王', '15', '15202', '9400028', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '蔵王', 'ザオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市東蔵王', '15', '15202', '9400029', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '東蔵王', 'ヒガシザオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別市弁天町', '01', '01219', '0940003', '北海道', 'ホッカイドウ', '紋別市', 'モンベツシ', '弁天町', 'ベンテンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市地蔵', '15', '15202', '9400031', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '地蔵', 'ジゾウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市干場', '15', '15202', '9400032', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '干場', 'ホシバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市今朝白', '15', '15202', '9400033', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '今朝白', 'ケサジロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市福住', '15', '15202', '9400034', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '福住', 'フクズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市東神田', '15', '15202', '9400035', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '東神田', 'ヒガシカンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市愛宕', '15', '15202', '9400036', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '愛宕', 'アタゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市東栄', '15', '15202', '9400037', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '東栄', 'ヒガシサカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市琴平', '15', '15202', '9400038', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '琴平', 'コトヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別市本町', '01', '01219', '0940004', '北海道', 'ホッカイドウ', '紋別市', 'モンベツシ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市学校町', '15', '15202', '9400041', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '学校町', 'ガッコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市前田', '15', '15202', '9400042', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '前田', 'マエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市土合', '15', '15202', '9400043', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '土合', 'ドアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市住吉', '15', '15202', '9400044', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '住吉', 'スミヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市金房', '15', '15202', '9400045', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '金房', 'カネフサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市四郎丸', '15', '15202', '9400046', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '四郎丸', 'シロウマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市弓町', '15', '15202', '9400047', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '弓町', 'ユミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市台町', '15', '15202', '9400048', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '台町', 'ダイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別市幸町', '01', '01219', '0940005', '北海道', 'ホッカイドウ', '紋別市', 'モンベツシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市西神田町', '15', '15202', '9400051', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '西神田町', 'ニシカンダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市神田町', '15', '15202', '9400052', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '神田町', 'カンダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市長町', '15', '15202', '9400053', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '長町', 'ナガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市稽古町', '15', '15202', '9400054', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '稽古町', 'ケイコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市袋町', '15', '15202', '9400055', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '袋町', 'フクロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市呉服町', '15', '15202', '9400056', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '呉服町', 'ゴフクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別市潮見町', '01', '01219', '0940006', '北海道', 'ホッカイドウ', '紋別市', 'モンベツシ', '潮見町', 'シオミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市城内町', '15', '15202', '9400061', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '城内町', 'ジョウナイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市大手通', '15', '15202', '9400062', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '大手通', 'オオテドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市旭町', '15', '15202', '9400063', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '旭町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市殿町', '15', '15202', '9400064', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '殿町', 'トノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市坂之上町', '15', '15202', '9400065', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '坂之上町', 'サカノウエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市東坂之上町', '15', '15202', '9400066', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '東坂之上町', 'ヒガシサカノウエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市関東町', '15', '15202', '9400067', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '関東町', 'カントウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別市落石町', '01', '01219', '0940007', '北海道', 'ホッカイドウ', '紋別市', 'モンベツシ', '落石町', 'オチイシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市表町', '15', '15202', '9400071', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '表町', 'オモテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市柳原町', '15', '15202', '9400072', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '柳原町', 'ヤナギハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市船江町', '15', '15202', '9400073', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '船江町', 'フナエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市上田町', '15', '15202', '9400074', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '上田町', 'ウエダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市渡里町', '15', '15202', '9400075', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '渡里町', 'ワタリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市本町', '15', '15202', '9400076', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市南町', '15', '15202', '9400081', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '南町', 'ミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市千歳', '15', '15202', '9400082', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '千歳', 'センザイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市宮原', '15', '15202', '9400083', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '宮原', 'ミヤバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市幸町', '15', '15202', '9400084', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市草生津', '15', '15202', '9400085', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '草生津', 'クソウヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市西千手', '15', '15202', '9400086', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '西千手', 'ニシセンジュ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市千手', '15', '15202', '9400087', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '千手', 'センジュ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市柏町', '15', '15202', '9400088', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '柏町', 'カシワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市松葉', '15', '15202', '9400091', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '松葉', 'マツバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市昭和', '15', '15202', '9400092', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '昭和', 'ショウワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市水道町', '15', '15202', '9400093', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '水道町', 'スイドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市中島', '15', '15202', '9400094', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '中島', 'ナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市日赤町', '15', '15202', '9400095', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '日赤町', 'ニッセキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市春日', '15', '15202', '9400096', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '春日', 'カスガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市山田', '15', '15202', '9400097', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '山田', 'ヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市信濃', '15', '15202', '9400098', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '信濃', 'シナノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市文納', '15', '15202', '9400101', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '文納', 'ブンノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市人面', '15', '15202', '9400102', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '人面', 'ヒトヅラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市二ツ郷屋', '15', '15202', '9400103', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '二ツ郷屋', 'フタツゴウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市山屋', '15', '15202', '9400104', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '山屋', 'ヤマヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市明戸', '15', '15202', '9400105', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '明戸', 'アケト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市水沢', '15', '15202', '9400106', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '水沢', 'ミズサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別市港町', '01', '01219', '0940011', '北海道', 'ホッカイドウ', '紋別市', 'モンベツシ', '港町', 'ミナトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市下塩', '15', '15202', '9400111', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '下塩', 'シモジオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市二日町', '15', '15202', '9400112', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '二日町', 'フツカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市熊袋', '15', '15202', '9400113', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '熊袋', 'クマノフクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市山口', '15', '15202', '9400114', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '山口', 'ヤマグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市下樫出', '15', '15202', '9400115', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '下樫出', 'シモカシイデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市上樫出', '15', '15202', '9400116', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '上樫出', 'カミカシイデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別市新港町', '01', '01219', '0940012', '北海道', 'ホッカイドウ', '紋別市', 'モンベツシ', '新港町', 'シンコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市九川', '15', '15202', '9400121', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '九川', 'クカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市塩中', '15', '15202', '9400122', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '塩中', 'シオナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市梅野俣', '15', '15202', '9400123', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '梅野俣', 'ウメノマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市平中野俣', '15', '15202', '9400124', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '平中野俣', 'ヒラナカノマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市葎谷', '15', '15202', '9400125', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '葎谷', 'ムグラダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市山葵谷', '15', '15202', '9400126', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '山葵谷', 'ワサビダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市滝之口', '15', '15202', '9400127', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '滝之口', 'タキノクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市上塩', '15', '15202', '9400128', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '上塩', 'カミシオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市塩新町', '15', '15202', '9400129', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '塩新町', 'シオアラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別市南が丘町', '01', '01219', '0940013', '北海道', 'ホッカイドウ', '紋別市', 'モンベツシ', '南が丘町', 'ミナミガオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市吉水', '15', '15202', '9400131', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '吉水', 'ヨシミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市栃尾原', '15', '15202', '9400132', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '栃尾原', 'トチオハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市巻渕', '15', '15202', '9400133', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '巻渕', 'マキフチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市栃尾原町', '15', '15202', '9400134', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '栃尾原町', 'トチオハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市金沢', '15', '15202', '9400135', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '金沢', 'カナザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市東が丘', '15', '15202', '9400136', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '東が丘', 'ヒガシガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市平', '15', '15202', '9400137', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '平', 'タイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別市緑町', '01', '01219', '0940014', '北海道', 'ホッカイドウ', '紋別市', 'モンベツシ', '緑町', 'ミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市栃尾島田', '15', '15202', '9400141', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '栃尾島田', 'トチオシマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市本所', '15', '15202', '9400142', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '本所', 'ホンジョ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市入塩川', '15', '15202', '9400143', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '入塩川', 'イリシオガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市菅畑', '15', '15202', '9400144', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '菅畑', 'スガバタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市栃堀', '15', '15202', '9400145', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '栃堀', 'トチボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市小向', '15', '15202', '9400146', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '小向', 'コムカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市赤谷', '15', '15202', '9400147', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '赤谷', 'アカタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市大川戸', '15', '15202', '9400148', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '大川戸', 'オオカワド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市栃倉', '15', '15202', '9400149', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '栃倉', 'トチクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別市花園町', '01', '01219', '0940015', '北海道', 'ホッカイドウ', '紋別市', 'モンベツシ', '花園町', 'ハナゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市吹谷', '15', '15202', '9400151', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '吹谷', 'フキダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市来伝', '15', '15202', '9400152', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '来伝', 'ライデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市寒沢', '15', '15202', '9400153', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '寒沢', 'カンザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市松尾', '15', '15202', '9400154', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '松尾', 'マツオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市栗山沢', '15', '15202', '9400155', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '栗山沢', 'クリヤマザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市鴉ケ島', '15', '15202', '9400201', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '鴉ケ島', 'カラスガシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市栃尾岩野外新田', '15', '15202', '9400202', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '栃尾岩野外新田', 'トチオイワノソトシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市楡原', '15', '15202', '9400203', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '楡原', 'ニレバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市新栄町', '15', '15202', '9400204', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '新栄町', 'シンサカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市栄町', '15', '15202', '9400205', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '栄町', 'サカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別市大山町', '01', '01219', '0940021', '北海道', 'ホッカイドウ', '紋別市', 'モンベツシ', '大山町', 'オオヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市小貫', '15', '15202', '9400211', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '小貫', 'コツナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市土ケ谷', '15', '15202', '9400212', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '土ケ谷', 'ツチガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市栃尾山田町', '15', '15202', '9400213', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '栃尾山田町', 'トチオヤマダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市栃尾山田', '15', '15202', '9400214', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '栃尾山田', 'トチオヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市栃尾町', '15', '15202', '9400215', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '栃尾町', 'トチオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市栃尾新町', '15', '15202', '9400216', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '栃尾新町', 'トチオアラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市栃尾大町', '15', '15202', '9400217', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '栃尾大町', 'トチオオオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市栃尾表町', '15', '15202', '9400218', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '栃尾表町', 'トチオオモテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別市新生', '01', '01219', '0940022', '北海道', 'ホッカイドウ', '紋別市', 'モンベツシ', '新生', 'シンセイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市金町', '15', '15202', '9400221', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '金町', 'カネマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市中央公園', '15', '15202', '9400222', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '中央公園', 'チュウオウコウエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市栃尾本町', '15', '15202', '9400223', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '栃尾本町', 'トチオホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市東町', '15', '15202', '9400224', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '東町', 'アズマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市仲子町', '15', '15202', '9400225', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '仲子町', 'ナカゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市滝の下町', '15', '15202', '9400226', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '滝の下町', 'タキノシタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市谷内', '15', '15202', '9400227', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '谷内', 'ヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別市元紋別', '01', '01219', '0940023', '北海道', 'ホッカイドウ', '紋別市', 'モンベツシ', '元紋別', 'モトモンベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市栃尾旭町', '15', '15202', '9400231', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '栃尾旭町', 'トチオアサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市天下島', '15', '15202', '9400232', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '天下島', 'アマガシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市栃尾宮沢', '15', '15202', '9400233', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '栃尾宮沢', 'トチオミヤザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市栃尾泉', '15', '15202', '9400234', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '栃尾泉', 'トチオイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市栃尾大野', '15', '15202', '9400235', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '栃尾大野', 'トチオオオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市栃尾大野町', '15', '15202', '9400236', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '栃尾大野町', 'トチオオオノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市上の原町', '15', '15202', '9400237', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '上の原町', 'ウエノハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別市藻別', '01', '01219', '0940024', '北海道', 'ホッカイドウ', '紋別市', 'モンベツシ', '藻別', 'モベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市北荷頃', '15', '15202', '9400241', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '北荷頃', 'キタニゴロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市一之貝', '15', '15202', '9400242', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '一之貝', 'イチノカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市軽井沢', '15', '15202', '9400243', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '軽井沢', 'カルイザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市比礼', '15', '15202', '9400244', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '比礼', 'ヒレイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市本津川', '15', '15202', '9400245', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '本津川', 'ホンツガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別市上藻別', '01', '01219', '0940025', '北海道', 'ホッカイドウ', '紋別市', 'モンベツシ', '上藻別', 'カミモベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市田之口', '15', '15202', '9400251', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '田之口', 'タノクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市西野俣', '15', '15202', '9400252', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '西野俣', 'ニシノマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市中', '15', '15202', '9400253', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '中', 'ナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市木山沢', '15', '15202', '9400254', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '木山沢', 'キヤマザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市東中野俣', '15', '15202', '9400255', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '東中野俣', 'ヒガシナカノマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市西中野俣', '15', '15202', '9400256', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '西中野俣', 'ニシナカノマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市森上', '15', '15202', '9400257', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '森上', 'モリアゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市半蔵金', '15', '15202', '9400258', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '半蔵金', 'ハンゾウガネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別市鴻之舞', '01', '01219', '0940026', '北海道', 'ホッカイドウ', '紋別市', 'モンベツシ', '鴻之舞', 'コウノマイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別市上鴻之舞', '01', '01219', '0940027', '北海道', 'ホッカイドウ', '紋別市', 'モンベツシ', '上鴻之舞', 'カミコウノマイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別市海洋公園', '01', '01219', '0940031', '北海道', 'ホッカイドウ', '紋別市', 'モンベツシ', '海洋公園', 'カイヨウコウエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市亀崎町', '15', '15202', '9400801', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '亀崎町', 'カメザキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市桂町', '15', '15202', '9400802', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '桂町', 'カツラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市加津保町', '15', '15202', '9400803', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '加津保町', 'カツボマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市水穴町', '15', '15202', '9400804', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '水穴町', 'ミズアナマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市浦瀬町', '15', '15202', '9400805', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '浦瀬町', 'ウラセマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市麻生田町', '15', '15202', '9400806', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '麻生田町', 'アソウダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市宮路町', '15', '15202', '9400811', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '宮路町', 'ミヤジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市乙吉町', '15', '15202', '9400812', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '乙吉町', 'オトヨシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市成願寺町', '15', '15202', '9400814', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '成願寺町', 'ジョウガンジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市東片貝町', '15', '15202', '9400816', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '東片貝町', 'ヒガシカタカイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市西片貝町', '15', '15202', '9400817', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '西片貝町', 'ニシカタカイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市千代栄町', '15', '15202', '9400819', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '千代栄町', 'チヨエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市栖吉町', '15', '15202', '9400821', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '栖吉町', 'スヨシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市柿町', '15', '15202', '9400822', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '柿町', 'カギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市高町', '15', '15202', '9400824', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '高町', 'タカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市高畑町', '15', '15202', '9400825', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '高畑町', 'タカバタケマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市長倉町', '15', '15202', '9400826', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '長倉町', 'ナガクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市悠久町', '15', '15202', '9400827', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '悠久町', 'ユウキュウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市御山町', '15', '15202', '9400828', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '御山町', 'オヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市上条町', '15', '15202', '9400831', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '上条町', 'ジョウジョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市曙', '15', '15202', '9400832', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '曙', 'アケボノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市笹崎', '15', '15202', '9400833', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '笹崎', 'ササザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市末広', '15', '15202', '9400834', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '末広', 'スエヒロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市錦', '15', '15202', '9400835', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '錦', 'ニシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市豊田町', '15', '15202', '9400836', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '豊田町', 'トヨダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市鉢伏町', '15', '15202', '9400842', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '鉢伏町', 'ハチブセマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市大町', '15', '15202', '9400844', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '大町', 'オオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市花園', '15', '15202', '9400845', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '花園', 'ハナゾノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市花園東', '15', '15202', '9400846', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '花園東', 'ハナゾノヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市土合町', '15', '15202', '9400847', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '土合町', 'ドアイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市若草町', '15', '15202', '9400851', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '若草町', 'ワカクサマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市中貫町', '15', '15202', '9400852', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '中貫町', 'ナカヌキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市中沢', '15', '15202', '9400853', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '中沢', 'ナカザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市中沢町', '15', '15202', '9400854', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '中沢町', 'ナカザワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市美沢', '15', '15202', '9400856', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '美沢', 'ミサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市川崎町', '15', '15202', '9400861', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '川崎町', 'カワサキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市川崎', '15', '15202', '9400864', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '川崎', 'カワサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市四郎丸町', '15', '15202', '9400865', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '四郎丸町', 'シロウマルマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市美園', '15', '15202', '9400866', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '美園', 'ミソノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市豊', '15', '15202', '9400867', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '豊', 'ユタカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市堀金', '15', '15202', '9400868', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '堀金', 'ホリガネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市北陽', '15', '15202', '9400871', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '北陽', 'ホクヨウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市稲葉町', '15', '15202', '9400872', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '稲葉町', 'イナバマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市永田町', '15', '15202', '9400873', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '永田町', 'ナガタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市永田', '15', '15202', '9400874', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '永田', 'ナガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市新保', '15', '15202', '9400875', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '新保', 'ニイボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市新保町', '15', '15202', '9400876', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '新保町', 'ニイボマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市稲保', '15', '15202', '9400877', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '稲保', 'イナホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市富島町', '15', '15202', '9400881', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '富島町', 'トミジママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市宮下町', '15', '15202', '9400882', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '宮下町', 'ミヤシタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市小曽根町', '15', '15202', '9400883', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '小曽根町', 'コゾネマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市亀貝町', '15', '15202', '9400884', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '亀貝町', 'カメガイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市四ツ屋町', '15', '15202', '9400891', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '四ツ屋町', 'ヨツヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市百束町', '15', '15202', '9400892', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '百束町', 'ヒャクソクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市福井町', '15', '15202', '9400893', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '福井町', 'フクイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市七軒町', '15', '15202', '9400894', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '七軒町', 'シチケンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市大黒町', '15', '15202', '9400895', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '大黒町', 'ダイコクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市福島町', '15', '15202', '9400896', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '福島町', 'フクシママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市新組町', '15', '15202', '9400897', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '新組町', 'シングミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市沢田', '15', '15202', '9401101', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '沢田', 'サワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市東宮内町', '15', '15202', '9401102', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '東宮内町', 'ヒガシミヤウチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市曲新町', '15', '15202', '9401103', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '曲新町', 'マガリアラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市摂田屋町', '15', '15202', '9401104', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '摂田屋町', 'セッタヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市摂田屋', '15', '15202', '9401105', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '摂田屋', 'セッタヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市宮内', '15', '15202', '9401106', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '宮内', 'ミヤウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市町田町', '15', '15202', '9401111', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '町田町', 'マチダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市青木町', '15', '15202', '9401112', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '青木町', 'アオキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市鷺巣町', '15', '15202', '9401113', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '鷺巣町', 'サギノスマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市釜沢町', '15', '15202', '9401114', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '釜沢町', 'カマザワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市村松町', '15', '15202', '9401115', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '村松町', 'ムラマツマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市竹町', '15', '15202', '9401116', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '竹町', 'タケマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市横枕町', '15', '15202', '9401117', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '横枕町', 'ヨコマクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市濁沢町', '15', '15202', '9401121', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '濁沢町', 'ニゴリサワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市蓬平町', '15', '15202', '9401122', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '蓬平町', 'ヨモギヒラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市竹之高地町', '15', '15202', '9401123', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '竹之高地町', 'タケノコウチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市十日町', '15', '15202', '9401131', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '十日町', 'トオカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市渡沢町', '15', '15202', '9401132', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '渡沢町', 'ワタザワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市六日市町', '15', '15202', '9401133', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '六日市町', 'ムイカイチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市妙見町', '15', '15202', '9401134', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '妙見町', 'ミョウケンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市中潟町', '15', '15202', '9401135', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '中潟町', 'ナカガタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市三俵野町', '15', '15202', '9401136', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '三俵野町', 'サンビョウノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市大川原町', '15', '15202', '9401137', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '大川原町', 'オオガワラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市滝谷町', '15', '15202', '9401138', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '滝谷町', 'タキヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市高島町', '15', '15202', '9401139', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '高島町', 'タカシママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市定明町', '15', '15202', '9401141', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '定明町', 'ジョウミョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市豊詰町', '15', '15202', '9401142', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '豊詰町', 'トヨヅメマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市片田町', '15', '15202', '9401143', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '片田町', 'カタダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市上前島町', '15', '15202', '9401144', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '上前島町', 'カミマエジママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市青島町', '15', '15202', '9401145', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '青島町', 'アオシママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市下条町', '15', '15202', '9401146', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '下条町', 'ゲジョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市前島町', '15', '15202', '9401147', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '前島町', 'マエジママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市青山町', '15', '15202', '9401148', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '青山町', 'アオヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市青山新町', '15', '15202', '9401149', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '青山新町', 'アオヤマシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市三和', '15', '15202', '9401151', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '三和', 'サンワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市三和町', '15', '15202', '9401152', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '三和町', 'サンワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市要町', '15', '15202', '9401153', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '要町', 'カナメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市宮栄', '15', '15202', '9401154', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '宮栄', 'ミヤサカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市宮内町', '15', '15202', '9401155', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '宮内町', 'ミヤウチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市左近', '15', '15202', '9401161', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '左近', 'サコン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市左近町', '15', '15202', '9401161', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '左近町', 'サコンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市西宮内', '15', '15202', '9401162', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '西宮内', 'ニシミヤウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市平島', '15', '15202', '9401163', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '平島', 'ヘイジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市平島町', '15', '15202', '9401163', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '平島町', 'ヘイジママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市南陽', '15', '15202', '9401164', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '南陽', 'ナンヨウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市水梨町', '15', '15202', '9401165', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '水梨町', 'ミズナシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市今井', '15', '15202', '9401166', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '今井', 'イマイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市大宮町', '15', '15202', '9401167', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '大宮町', 'オオミヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市岩野仲島', '15', '15202', '9401171', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '岩野', 'イワノ', null, null, '仲島', 'ナカジマ');
INSERT INTO `ms_addresses` VALUES ('129686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市釜ケ島', '15', '15202', '9401172', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '釜ケ島', 'カマガシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市槇下町', '15', '15202', '9402001', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '槇下町', 'マキシタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市槇山町', '15', '15202', '9402002', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '槇山町', 'マキヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市渡場町', '15', '15202', '9402003', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '渡場町', 'ワタリバマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市上野町', '15', '15202', '9402004', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '上野町', 'カミノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市巻島', '15', '15202', '9402005', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '巻島', 'マキジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市藤沢', '15', '15202', '9402011', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '藤沢', 'フジサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市荻野', '15', '15202', '9402012', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '荻野', 'オギノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市下柳', '15', '15202', '9402013', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '下柳', 'シモヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市堤町', '15', '15202', '9402014', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '堤町', 'ツツミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市江陽', '15', '15202', '9402015', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '江陽', 'コウヨウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市宮関', '15', '15202', '9402021', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '宮関', 'ミヤゼキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市鉄工町', '15', '15202', '9402022', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '鉄工町', 'テッコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市蓮潟', '15', '15202', '9402023', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '蓮潟', 'ハスガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市堺町', '15', '15202', '9402024', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '堺町', 'サカイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市高瀬町', '15', '15202', '9402025', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '高瀬町', 'タカセマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市堺東町', '15', '15202', '9402026', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '堺東町', 'サカイヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市宝地町', '15', '15202', '9402031', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '宝地町', 'ホウジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市石動町', '15', '15202', '9402032', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '石動町', 'イスルギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市上除町', '15', '15202', '9402033', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '上除町', 'カミノゾキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市上除町西', '15', '15202', '9402034', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '上除町西', 'カミノゾキマチニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市関原町', '15', '15202', '9402035', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '関原町', 'セキハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市五反田町', '15', '15202', '9402036', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '五反田町', 'ゴタンダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市関原西町', '15', '15202', '9402037', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '関原西町', 'セキハラニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市関原東町', '15', '15202', '9402038', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '関原東町', 'セキハラヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市関原南', '15', '15202', '9402039', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '関原南', 'セキハラミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市白鳥町', '15', '15202', '9402041', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '白鳥町', 'シロトリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市宮本町', '15', '15202', '9402042', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '宮本町', 'ミヤモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市宮本東方町', '15', '15202', '9402043', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '宮本東方町', 'ミヤモトヒガシカタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市宮本堀之内町', '15', '15202', '9402044', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '宮本堀之内町', 'ミヤモトホリノウチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市西陵町', '15', '15202', '9402045', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '西陵町', 'セイリョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市雲出町', '15', '15202', '9402046', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '雲出町', 'クモイデマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市高野町', '15', '15202', '9402051', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '高野町', 'タカノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市福戸町', '15', '15202', '9402052', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '福戸町', 'フクトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市福道町', '15', '15202', '9402053', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '福道町', 'フクミチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市南新保町', '15', '15202', '9402054', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '南新保町', 'ミナミシンボマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市雨池町', '15', '15202', '9402055', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '雨池町', 'アマイケマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市王番田町', '15', '15202', '9402056', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '王番田町', 'オウバデンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市寺宝町', '15', '15202', '9402057', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '寺宝町', 'ジホウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市河根川町', '15', '15202', '9402058', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '河根川町', 'カワネガワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市大荒戸町', '15', '15202', '9402059', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '大荒戸町', 'オオアラトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市寺島町', '15', '15202', '9402101', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '寺島町', 'テラジママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市小沢町', '15', '15202', '9402102', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '小沢町', 'コザワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市古正寺町', '15', '15202', '9402103', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '古正寺町', 'コショウジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市大島新町', '15', '15202', '9402104', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '大島新町', 'オオジマシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市緑町', '15', '15202', '9402105', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '緑町', 'ミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市古正寺', '15', '15202', '9402106', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '古正寺', 'コショウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市千秋', '15', '15202', '9402108', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '千秋', 'センシュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市三ツ郷屋', '15', '15202', '9402111', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '三ツ郷屋', 'ミツゴウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市大島本町', '15', '15202', '9402112', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '大島本町', 'オオジマホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市大山', '15', '15202', '9402113', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '大山', 'オオヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市北山', '15', '15202', '9402114', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '北山', 'キタヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市下山', '15', '15202', '9402115', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '下山', 'シモヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市南七日町', '15', '15202', '9402116', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '南七日町', 'ミナミナノカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市石動南町', '15', '15202', '9402117', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '石動南町', 'イスルギミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市喜多町', '15', '15202', '9402121', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '喜多町', 'キタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市福山町', '15', '15202', '9402122', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '福山町', 'フクヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市七日町', '15', '15202', '9402123', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '七日町', 'ナノカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市希望が丘', '15', '15202', '9402124', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '希望が丘', 'キボウガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市希望が丘南', '15', '15202', '9402125', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '希望が丘南', 'キボウガオカミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市西津町', '15', '15202', '9402126', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '西津町', 'ニシヅマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市新産', '15', '15202', '9402127', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '新産', 'シンサン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市新産東町', '15', '15202', '9402128', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '新産東町', 'シンサンヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市才津東町', '15', '15202', '9402131', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '才津東町', 'サイヅヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市才津南町', '15', '15202', '9402132', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '才津南町', 'サイヅミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市才津西町', '15', '15202', '9402133', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '才津西町', 'サイヅニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市親沢町', '15', '15202', '9402134', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '親沢町', 'オヤザワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市深沢町', '15', '15202', '9402135', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '深沢町', 'フカサワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市上富岡', '15', '15202', '9402136', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '上富岡', 'カミトミオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市上富岡町', '15', '15202', '9402137', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '上富岡町', 'カミトミオカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市日越', '15', '15202', '9402138', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '日越', 'ヒゴシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市藤橋', '15', '15202', '9402141', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '藤橋', 'フジハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市長峰町', '15', '15202', '9402142', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '長峰町', 'ナガミネマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市高寺町', '15', '15202', '9402143', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '高寺町', 'タカテラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市高頭町', '15', '15202', '9402144', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '高頭町', 'タカトウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市青葉台', '15', '15202', '9402145', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '青葉台', 'アオバダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市大積町', '15', '15202', '9402146', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '大積町', 'オオヅミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市新陽', '15', '15202', '9402147', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '新陽', 'シンヨウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市陽光台', '15', '15202', '9402148', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '陽光台', 'ヨウコウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市大積灰下町', '15', '15202', '9402151', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '大積灰下町', 'オオヅミハイゲマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市大積高鳥町', '15', '15202', '9402152', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '大積高鳥町', 'オオヅミタカトリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市大積千本町', '15', '15202', '9402153', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '大積千本町', 'オオヅミセンボンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市大積田代町', '15', '15202', '9402154', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '大積田代町', 'オオヅミタシロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市大積熊上町', '15', '15202', '9402155', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '大積熊上町', 'オオヅミクマガミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市大積折渡町', '15', '15202', '9402156', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '大積折渡町', 'オオヅミオリワタリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市大積三島谷町', '15', '15202', '9402157', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '大積三島谷町', 'オオヅミミシマダニマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市大積善間町', '15', '15202', '9402158', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '大積善間町', 'オオヅミゼンママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市宮沢', '15', '15202', '9402301', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '宮沢', 'ミヤザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市藤川', '15', '15202', '9402302', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '藤川', 'フジカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市瓜生', '15', '15202', '9402303', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '瓜生', 'ウリュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市下河根川', '15', '15202', '9402304', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '下河根川', 'シモカワネガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市大野', '15', '15202', '9402305', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '大野', 'オオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市脇野町', '15', '15202', '9402306', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '脇野町', 'ワキノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市三島新保', '15', '15202', '9402311', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '三島新保', 'ミシマシンボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市三島中条', '15', '15202', '9402312', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '三島中条', 'ミシマナカジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市吉崎', '15', '15202', '9402313', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '吉崎', 'ヨシザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市上岩井', '15', '15202', '9402314', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '上岩井', 'カミイワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市七日市', '15', '15202', '9402315', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '七日市', 'ナノカイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市鳥越', '15', '15202', '9402316', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '鳥越', 'トリゴエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市逆谷', '15', '15202', '9402321', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '逆谷', 'サカシダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市気比宮', '15', '15202', '9402322', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '気比宮', 'キイノミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市三島上条', '15', '15202', '9402323', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '三島上条', 'ミシマジョウジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市中永', '15', '15202', '9402324', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '中永', 'チュウエイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市蓮花寺', '15', '15202', '9402325', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '蓮花寺', 'レンゲジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市与板町東与板', '15', '15202', '9402401', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '与板町東与板', 'ヨイタマチヒガシヨイタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市与板町与板', '15', '15202', '9402402', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '与板町与板', 'ヨイタマチヨイタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市与板町本与板', '15', '15202', '9402403', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '与板町本与板', 'ヨイタマチモトヨイタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市与板町馬越', '15', '15202', '9402404', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '与板町馬越', 'ヨイタマチマゴシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市与板町岩方', '15', '15202', '9402405', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '与板町岩方', 'ヨイタマチイワカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市与板町江西', '15', '15202', '9402406', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '与板町江西', 'ヨイタマチエニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市与板町城山', '15', '15202', '9402407', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '与板町城山', 'ヨイタマチシロヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市与板町蔦都', '15', '15202', '9402411', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '与板町蔦都', 'ヨイタマチツタイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市与板町広野', '15', '15202', '9402412', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '与板町広野', 'ヨイタマチヒロノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市与板町吉津', '15', '15202', '9402413', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '与板町吉津', 'ヨイタマチヨシヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市与板町中田', '15', '15202', '9402414', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '与板町中田', 'ヨイタマチナカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市与板町南中', '15', '15202', '9402415', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '与板町南中', 'ヨイタマチミナミナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市与板町槇原', '15', '15202', '9402416', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '与板町槇原', 'ヨイタマチマキハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市与板町山沢', '15', '15202', '9402417', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '与板町山沢', 'ヨイタマチヤマザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市脇川新田町', '15', '15202', '9402461', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '脇川新田町', 'ワキガワシンデンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市李崎町', '15', '15202', '9402462', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '李崎町', 'スモンザキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市川袋町', '15', '15202', '9402463', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '川袋町', 'カワブクロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市新開町', '15', '15202', '9402464', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '新開町', 'シンカイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市成沢町', '15', '15202', '9402465', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '成沢町', 'ナリサワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市上柳町', '15', '15202', '9402471', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '上柳町', 'カミヤナギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市三之宮町', '15', '15202', '9402472', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '三之宮町', 'サンノミヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市芹川町', '15', '15202', '9402473', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '芹川町', 'セリカワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市雁島町', '15', '15202', '9402474', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '雁島町', 'ガンジママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市花井町', '15', '15202', '9402475', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '花井町', 'ハナイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市寺泊野積', '15', '15202', '9402501', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '寺泊野積', 'テラドマリノヅミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市寺泊', '15', '15202', '9402502', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '寺泊', 'テラドマリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市寺泊大地', '15', '15202', '9402503', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '寺泊大地', 'テラドマリオオジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市寺泊弁才天', '15', '15202', '9402504', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '寺泊弁才天', 'テラドマリベンザイテン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市寺泊本弁', '15', '15202', '9402505', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '寺泊本弁', 'テラドマリモトベン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市寺泊本山', '15', '15202', '9402506', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '寺泊本山', 'テラドマリモトヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市寺泊吉', '15', '15202', '9402507', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '寺泊吉', 'テラドマリヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市寺泊引岡', '15', '15202', '9402508', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '寺泊引岡', 'テラドマリヒキオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市寺泊円上寺', '15', '15202', '9402511', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '寺泊円上寺', 'テラドマリエンジョウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市寺泊京ケ入', '15', '15202', '9402512', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '寺泊京ケ入', 'テラドマリキョウガイリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市寺泊当新田', '15', '15202', '9402513', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '寺泊当新田', 'テラドマリトウシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市寺泊蛇塚', '15', '15202', '9402514', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '寺泊蛇塚', 'テラドマリヘビツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市寺泊中曽根', '15', '15202', '9402515', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '寺泊中曽根', 'テラドマリナカゾネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市寺泊下曽根', '15', '15202', '9402516', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '寺泊下曽根', 'テラドマリシモゾネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市寺泊川崎', '15', '15202', '9402517', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '寺泊川崎', 'テラドマリカワサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市寺泊戸崎', '15', '15202', '9402518', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '寺泊戸崎', 'テラドマリトザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市寺泊年友', '15', '15202', '9402521', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '寺泊年友', 'テラドマリトシトモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市寺泊夏戸', '15', '15202', '9402522', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '寺泊夏戸', 'テラドマリナツド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市寺泊田頭', '15', '15202', '9402523', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '寺泊田頭', 'テラドマリタガシラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市寺泊松田', '15', '15202', '9402524', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '寺泊松田', 'テラドマリマツダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市寺泊明ケ谷', '15', '15202', '9402525', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '寺泊明ケ谷', 'テラドマリミョウガダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市寺泊山田', '15', '15202', '9402526', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '寺泊山田', 'テラドマリヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市寺泊志戸橋', '15', '15202', '9402527', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '寺泊志戸橋', 'テラドマリシトバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市寺泊郷本', '15', '15202', '9402528', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '寺泊郷本', 'テラドマリゴウモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市寺泊大和田', '15', '15202', '9402529', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '寺泊大和田', 'テラドマリオオワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市', '15', '15216', '9410000', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('129904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市間脇', '15', '15216', '9410001', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '間脇', 'マワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市中浜', '15', '15216', '9410002', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '中浜', 'ナカハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市中宿', '15', '15216', '9410003', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '中宿', 'ナカシュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市梶屋敷', '15', '15216', '9410004', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '梶屋敷', 'カジヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市厚田', '15', '15216', '9410005', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '厚田', 'アツダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市竹ケ花', '15', '15216', '9410006', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '竹ケ花', 'タケガハナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市大和川', '15', '15216', '9410007', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '大和川', 'ヤマトガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市田伏', '15', '15216', '9410008', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '田伏', 'タブセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市滝川原', '15', '15216', '9410011', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '滝川原', 'タキカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市上出', '15', '15216', '9410012', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '上出', 'カミイデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市下出', '15', '15216', '9410013', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '下出', 'シモイデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市日光寺', '15', '15216', '9410014', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '日光寺', 'ニッコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市清水山', '15', '15216', '9410015', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '清水山', 'シミズヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市四ツ屋', '15', '15216', '9410016', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '四ツ屋', 'ヨツヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市道明', '15', '15216', '9410019', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '道明', 'ドウミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市東海', '15', '15216', '9410021', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '東海', 'ヒガシウミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市新町', '15', '15216', '9410022', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '新町', 'アラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市上覚', '15', '15216', '9410023', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '上覚', 'ジョウカク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市西谷内', '15', '15216', '9410024', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '西谷内', 'ニシヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市堀切', '15', '15216', '9410025', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '堀切', 'ホリキリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市田屋', '15', '15216', '9410026', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '田屋', 'タヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市東川原', '15', '15216', '9410027', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '東川原', 'ヒガシカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市粟倉', '15', '15216', '9410031', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '粟倉', 'アワクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市来海沢', '15', '15216', '9410032', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '来海沢', 'クルミザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市御前山', '15', '15216', '9410033', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '御前山', 'ゴゼンヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市市野々', '15', '15216', '9410034', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '市野々', 'イチノノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市真木', '15', '15216', '9410035', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '真木', 'マキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市釜沢', '15', '15216', '9410036', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '釜沢', 'カマザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市道平', '15', '15216', '9410037', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '道平', 'ドウタイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市真光寺', '15', '15216', '9410041', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '真光寺', 'シンコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市川島', '15', '15216', '9410042', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '川島', 'カワシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市田中', '15', '15216', '9410043', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '田中', 'タナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市水保', '15', '15216', '9410044', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '水保', 'ミズホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市成沢', '15', '15216', '9410045', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '成沢', 'ナリサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市羽生', '15', '15216', '9410046', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '羽生', 'ハニュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市平牛', '15', '15216', '9410047', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '平牛', 'ヒラウシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市押上', '15', '15216', '9410051', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '押上', 'オシアゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市南押上', '15', '15216', '9410052', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '南押上', 'ミナミオシアゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市東寺町', '15', '15216', '9410053', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '東寺町', 'ヒガシテラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市京ケ峰', '15', '15216', '9410054', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '京ケ峰', 'キョウガミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市蓮台寺', '15', '15216', '9410055', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '蓮台寺', 'レンダイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市一の宮', '15', '15216', '9410056', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '一の宮', 'イチノミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市南寺町', '15', '15216', '9410057', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '南寺町', 'ミナミテラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市寺町', '15', '15216', '9410058', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '寺町', 'テラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市大町', '15', '15216', '9410061', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '大町', 'オオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市中央', '15', '15216', '9410062', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市清崎', '15', '15216', '9410063', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '清崎', 'キヨサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市上刈', '15', '15216', '9410064', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '上刈', 'ウエカリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市新鉄', '15', '15216', '9410065', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '新鉄', 'シンテツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市寺島', '15', '15216', '9410066', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '寺島', 'テラジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市横町', '15', '15216', '9410067', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '横町', 'ヨコマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市本町', '15', '15216', '9410068', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市南寺島', '15', '15216', '9410069', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '南寺島', 'ミナミテラジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市大野', '15', '15216', '9410071', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '大野', 'オオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市山本', '15', '15216', '9410072', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '山本', 'ヤマモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市西川原', '15', '15216', '9410073', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '西川原', 'ニシガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市大谷内', '15', '15216', '9410074', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '大谷内', 'オオヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市中谷内', '15', '15216', '9410075', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '中谷内', 'ナカヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市西中', '15', '15216', '9410076', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '西中', 'ニシナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市頭山', '15', '15216', '9410077', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '頭山', 'ツムリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市岩木', '15', '15216', '9410078', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '岩木', 'イワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市中央', '15', '15222', '9420001', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市住吉町', '15', '15222', '9420002', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '住吉町', 'スミヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市東町', '15', '15222', '9420003', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '東町', 'アズマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市西本町', '15', '15222', '9420004', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '西本町', 'ニシホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市港町', '15', '15222', '9420011', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '港町', 'ミナトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市高崎新田', '15', '15222', '9420012', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '高崎新田', 'タカサキシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市黒井', '15', '15222', '9420013', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '黒井', 'クロイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市上荒浜', '15', '15222', '9420021', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '上荒浜', 'カミアラハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市下荒浜', '15', '15222', '9420022', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '下荒浜', 'シモアラハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市石橋新田', '15', '15222', '9420023', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '石橋新田', 'イシバシシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市遊光寺浜', '15', '15222', '9420024', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '遊光寺浜', 'ユウコウジハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市夷浜', '15', '15222', '9420025', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '夷浜', 'エビスハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市西ケ窪浜', '15', '15222', '9420026', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '西ケ窪浜', 'ニシガクボハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市八千浦', '15', '15222', '9420027', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '八千浦', 'ヤチホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市佐内', '15', '15222', '9420031', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '佐内', 'サナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市佐内町', '15', '15222', '9420031', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '佐内町', 'サナイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市福田', '15', '15222', '9420032', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '福田', 'フクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市福橋', '15', '15222', '9420033', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '福橋', 'フクハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市下真砂', '15', '15222', '9420034', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '下真砂', 'シモマナゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市上千原', '15', '15222', '9420035', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '上千原', 'カミチハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市東中島', '15', '15222', '9420036', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '東中島', 'ヒガシナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市中真砂', '15', '15222', '9420037', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '中真砂', 'ナカマナゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市川端', '15', '15222', '9420038', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '川端', 'カワバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市飯塚', '15', '15222', '9420039', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '飯塚', 'イイヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市安江', '15', '15222', '9420041', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '安江', 'ヤスエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市三ツ屋町', '15', '15222', '9420042', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '三ツ屋町', 'ミツヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市三ツ橋', '15', '15222', '9420043', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '三ツ橋', 'ミツハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市三ツ橋新田', '15', '15222', '9420044', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '三ツ橋新田', 'ミツハシシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市横曾根', '15', '15222', '9420045', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '横曾根', 'ヨコゾネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('129999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市田園', '15', '15222', '9420046', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '田園', 'デンエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市下源入', '15', '15222', '9420051', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '下源入', 'シモゲンニュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市上源入', '15', '15222', '9420052', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '上源入', 'カミゲンニュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市三田新田', '15', '15222', '9420053', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '三田新田', 'サンダシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市三田', '15', '15222', '9420054', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '三田', 'サンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市小猿屋', '15', '15222', '9420055', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '小猿屋', 'コザルヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市小猿屋新田', '15', '15222', '9420056', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '小猿屋新田', 'コザルヤシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市春日新田', '15', '15222', '9420061', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '春日新田', 'カスガシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市松村新田', '15', '15222', '9420062', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '松村新田', 'マツムラシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市下門前', '15', '15222', '9420063', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '下門前', 'シモモンゼン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市塩屋新田', '15', '15222', '9420064', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '塩屋新田', 'シオヤシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市川原町', '15', '15222', '9420065', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '川原町', 'カワラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市東雲町', '15', '15222', '9420071', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '東雲町', 'トウウンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市栄町1丁目', '15', '15222', '9420072', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '栄町', 'サカエチョウ', '（－チョウ）', null, '1丁目', '01チョウメ');
INSERT INTO `ms_addresses` VALUES ('130013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市栄町2丁目', '15', '15222', '9420072', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '栄町', 'サカエチョウ', '（－チョウ）', null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('130014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市石橋', '15', '15222', '9420074', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '石橋', 'イシバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市五智', '15', '15222', '9420081', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '五智', 'ゴチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市国府', '15', '15222', '9420082', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '国府', 'コクフ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市大豆', '15', '15222', '9420083', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '大豆', 'ダイズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市五智新町', '15', '15222', '9420084', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '五智新町', 'ゴチシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市五智国分', '15', '15222', '9420085', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '五智国分', 'ゴチコクブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市加賀町', '15', '15222', '9420086', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '加賀町', 'カガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市虫生岩戸', '15', '15222', '9420087', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '虫生岩戸', 'ムシュウイワト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市毘沙門国分寺', '15', '15222', '9420088', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '毘沙門国分寺', 'ビシャモンコクブンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市大場', '15', '15222', '9420089', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '大場', 'オオバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市頸城区西福島', '15', '15222', '9420091', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '頸城区西福島', 'クビキクニシフクジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市頸城区柳町新田', '15', '15222', '9420101', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '頸城区柳町新田', 'クビキクヤナギマチシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市頸城区岡田', '15', '15222', '9420102', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '頸城区岡田', 'クビキクオカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市頸城区富田', '15', '15222', '9420103', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '頸城区富田', 'クビキクトミタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市頸城区下池田', '15', '15222', '9420104', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '頸城区下池田', 'クビキクシモイケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市頸城区戸口野', '15', '15222', '9420105', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '頸城区戸口野', 'クビキクトグチノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市頸城区上柳町', '15', '15222', '9420106', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '頸城区上柳町', 'クビキクカミヤナギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市頸城区中柳町', '15', '15222', '9420107', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '頸城区中柳町', 'クビキクナカヤナギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市頸城区下柳町', '15', '15222', '9420108', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '頸城区下柳町', 'クビキクシモヤナギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市頸城区寺田', '15', '15222', '9420109', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '頸城区寺田', 'クビキクテラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市頸城区片津', '15', '15222', '9420111', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '頸城区片津', 'クビキクカタヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市頸城区姥谷内', '15', '15222', '9420112', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '頸城区姥谷内', 'クビキクバヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市頸城区中城', '15', '15222', '9420113', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '頸城区中城', 'クビキクナカジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市頸城区柿野', '15', '15222', '9420114', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '頸城区柿野', 'クビキクカキノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市頸城区田中', '15', '15222', '9420115', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '頸城区田中', 'クビキクタナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市頸城区大坂井', '15', '15222', '9420116', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '頸城区大坂井', 'クビキクオオサカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市頸城区西湊', '15', '15222', '9420117', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '頸城区西湊', 'クビキクニシミナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市頸城区鵜ノ木', '15', '15222', '9420121', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '頸城区鵜ノ木', 'クビキクウノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市頸城区川袋', '15', '15222', '9420122', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '頸城区川袋', 'クビキクカワブクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市頸城区下中村', '15', '15222', '9420123', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '頸城区下中村', 'クビキクシモナカムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市頸城区東俣', '15', '15222', '9420124', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '頸城区東俣', 'クビキクヒガシマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市頸城区飯田', '15', '15222', '9420125', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '頸城区飯田', 'クビキクイイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市頸城区宮原', '15', '15222', '9420126', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '頸城区宮原', 'クビキクミヤハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市頸城区百間町', '15', '15222', '9420127', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '頸城区百間町', 'クビキクヒャクケンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市頸城区諏訪', '15', '15222', '9420128', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '頸城区諏訪', 'クビキクスワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市頸城区立崎', '15', '15222', '9420129', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '頸城区立崎', 'クビキクタテサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市頸城区千原', '15', '15222', '9420131', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '頸城区千原', 'クビキクチハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市頸城区北福崎', '15', '15222', '9420132', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '頸城区北福崎', 'クビキクキタフクザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市頸城区上神原', '15', '15222', '9420133', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '頸城区上神原', 'クビキクカミカナハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市頸城区下神原', '15', '15222', '9420134', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '頸城区下神原', 'クビキクシモカナハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市頸城区五十嵐', '15', '15222', '9420135', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '頸城区五十嵐', 'クビキクイガラシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市頸城区島田', '15', '15222', '9420136', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '頸城区島田', 'クビキクシマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市頸城区下千原', '15', '15222', '9420137', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '頸城区下千原', 'クビキクシモチハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市頸城区望ケ丘', '15', '15222', '9420138', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '頸城区望ケ丘', 'クビキクノゾミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市頸城区美しが丘', '15', '15222', '9420139', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '頸城区美しが丘', 'クビキクウツクシガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市頸城区市村', '15', '15222', '9420141', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '頸城区市村', 'クビキクイチムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市頸城区上三分一', '15', '15222', '9420142', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '頸城区上三分一', 'クビキクカミサンブイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市頸城区下三分一', '15', '15222', '9420143', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '頸城区下三分一', 'クビキクシモサンブイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市頸城区松本', '15', '15222', '9420144', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '頸城区松本', 'クビキクマツモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市頸城区上吉', '15', '15222', '9420145', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '頸城区上吉', 'クビキクカミヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市頸城区下吉', '15', '15222', '9420146', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '頸城区下吉', 'クビキクシモヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市頸城区西福島', '15', '15222', '9420147', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '頸城区西福島', 'クビキクニシフクジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市頸城区北四ツ屋', '15', '15222', '9420151', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '頸城区北四ツ屋', 'クビキクキタヨツヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市頸城区浮島', '15', '15222', '9420152', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '頸城区浮島', 'クビキクウキシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市頸城区下米岡', '15', '15222', '9420153', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '頸城区下米岡', 'クビキクシモヨネオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市頸城区榎井', '15', '15222', '9420154', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '頸城区榎井', 'クビキクエノイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市頸城区下中島', '15', '15222', '9420155', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '頸城区下中島', 'クビキクシモナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市頸城区松橋', '15', '15222', '9420156', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '頸城区松橋', 'クビキクマツハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市頸城区城野腰', '15', '15222', '9420157', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '頸城区城野腰', 'クビキクジョウノコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市頸城区松橋新田', '15', '15222', '9420158', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '頸城区松橋新田', 'クビキクマツハシシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市頸城区手宮', '15', '15222', '9420161', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '頸城区手宮', 'クビキクテミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市頸城区森下', '15', '15222', '9420162', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '頸城区森下', 'クビキクモリシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市頸城区大谷内', '15', '15222', '9420163', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '頸城区大谷内', 'クビキクオオヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市頸城区潟口', '15', '15222', '9420164', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '頸城区潟口', 'クビキクカタグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市頸城区青野', '15', '15222', '9420165', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '頸城区青野', 'クビキクアオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市頸城区北方', '15', '15222', '9420171', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '頸城区北方', 'クビキクキタカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市頸城区宮本', '15', '15222', '9420172', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '頸城区宮本', 'クビキクミヤモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市頸城区舟津', '15', '15222', '9420173', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '頸城区舟津', 'クビキクフナツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市大潟区潟守新田', '15', '15222', '9420181', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '大潟区潟守新田', 'オオガタクカタモリシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市頸城区大潟', '15', '15222', '9420201', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '頸城区大潟', 'クビキクオオガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市頸城区上池田', '15', '15222', '9420202', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '頸城区上池田', 'クビキクカミイケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市頸城区上増田', '15', '15222', '9420203', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '頸城区上増田', 'クビキクカミマスダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市頸城区両毛', '15', '15222', '9420204', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '頸城区両毛', 'クビキクリョウケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市頸城区中増田', '15', '15222', '9420205', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '頸城区中増田', 'クビキクナカマスダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市頸城区下増田', '15', '15222', '9420206', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '頸城区下増田', 'クビキクシモマスダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市頸城区手島', '15', '15222', '9420207', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '頸城区手島', 'クビキクテシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市頸城区畑ケ崎', '15', '15222', '9420211', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '頸城区畑ケ崎', 'クビキクハタケサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市頸城区矢住', '15', '15222', '9420212', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '頸城区矢住', 'クビキクヤズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市頸城区中島', '15', '15222', '9420213', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '頸城区中島', 'クビキクナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市頸城区大蒲生田', '15', '15222', '9420214', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '頸城区大蒲生田', 'クビキクオオカモダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市頸城区玄僧', '15', '15222', '9420215', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '頸城区玄僧', 'クビキクゲンゾウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市頸城区日根津', '15', '15222', '9420216', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '頸城区日根津', 'クビキクヒネヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市頸城区石神', '15', '15222', '9420221', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '頸城区石神', 'クビキクイシガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市頸城区花ケ崎', '15', '15222', '9420222', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '頸城区花ケ崎', 'クビキクハナガサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市頸城区森本', '15', '15222', '9420223', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '頸城区森本', 'クビキクモリモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市頸城区仁野分', '15', '15222', '9420224', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '頸城区仁野分', 'クビキクニノブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市頸城区天ケ崎', '15', '15222', '9420225', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '頸城区天ケ崎', 'クビキクアマガサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市下吉野', '15', '15222', '9420231', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '下吉野', 'シモヨシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市福岡新田', '15', '15222', '9420232', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '福岡新田', 'フクオカシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市岡崎新田', '15', '15222', '9420233', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '岡崎新田', 'オカザキシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市田沢新田', '15', '15222', '9420234', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '田沢新田', 'タザワシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市青野', '15', '15222', '9420238', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '青野', 'アオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市上吉野', '15', '15222', '9420241', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '上吉野', 'カミヨシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市石川', '15', '15222', '9420242', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '石川', 'イシカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市五野井', '15', '15222', '9420243', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '五野井', 'ゴノイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市長岡新田', '15', '15222', '9420244', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '長岡新田', 'ナオカシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市長岡', '15', '15222', '9420245', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '長岡', 'ナオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市駒林', '15', '15222', '9420246', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '駒林', 'コマバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市下百々', '15', '15222', '9420247', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '下百々', 'シモドウドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市小泉', '15', '15222', '9420251', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '小泉', 'コイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市上名柄', '15', '15222', '9420252', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '上名柄', 'カミナガラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市下名柄', '15', '15222', '9420253', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '下名柄', 'シモナガラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市上五貫野', '15', '15222', '9420254', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '上五貫野', 'カミゴカンノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市下五貫野', '15', '15222', '9420255', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '下五貫野', 'シモゴカンノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市三和区末野新田', '15', '15222', '9420261', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '三和区末野新田', 'サンワクスエノシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市三和区末野', '15', '15222', '9420262', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '三和区末野', 'サンワクスエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市三和区山腰新田', '15', '15222', '9420263', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '三和区山腰新田', 'サンワクヤマノコシシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市三和区塔ノ輪', '15', '15222', '9420264', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '三和区塔ノ輪', 'サンワクトウノワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市三和区神田', '15', '15222', '9420265', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '三和区神田', 'サンワクカンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市三和区越柳', '15', '15222', '9420266', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '三和区越柳', 'サンワクコシヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市三和区沖柳', '15', '15222', '9420267', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '三和区沖柳', 'サンワクオキヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市三和区本郷', '15', '15222', '9420268', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '三和区本郷', 'サンワクホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市三和区錦', '15', '15222', '9420271', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '三和区錦', 'サンワクニシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市三和区柳林', '15', '15222', '9420272', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '三和区柳林', 'サンワクヤナギバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市三和区上広田', '15', '15222', '9420273', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '三和区上広田', 'サンワクカミヒロタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市三和区下広田', '15', '15222', '9420274', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '三和区下広田', 'サンワクシモヒロタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市三和区岡木', '15', '15222', '9420275', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '三和区岡木', 'サンワクオカギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市三和区米子', '15', '15222', '9420276', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '三和区米子', 'サンワクコメコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市三和区広井', '15', '15222', '9420277', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '三和区広井', 'サンワクヒロイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市浦川原区上猪子田', '15', '15222', '9420301', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '浦川原区上猪子田', 'ウラガワラクカミイノコダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市浦川原区小谷島', '15', '15222', '9420302', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '浦川原区小谷島', 'ウラガワラクコヤジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市浦川原区下猪子田', '15', '15222', '9420303', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '浦川原区下猪子田', 'ウラガワラクシモイノコダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市浦川原区中猪子田', '15', '15222', '9420304', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '浦川原区中猪子田', 'ウラガワラクナカイノコダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市浦川原区虫川', '15', '15222', '9420305', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '浦川原区虫川', 'ウラガワラクムシガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市浦川原区有島', '15', '15222', '9420306', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '浦川原区有島', 'ウラガワラクアリシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市浦川原区釜淵', '15', '15222', '9420307', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '浦川原区釜淵', 'ウラガワラクカマブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市浦川原区小蒲生田', '15', '15222', '9420308', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '浦川原区小蒲生田', 'ウラガワラクコガモダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市浦川原区上柿野', '15', '15222', '9420311', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '浦川原区上柿野', 'ウラガワラクカミガキノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市浦川原区大栃山', '15', '15222', '9420312', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '浦川原区大栃山', 'ウラガワラクオオトチヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市浦川原区下柿野', '15', '15222', '9420313', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '浦川原区下柿野', 'ウラガワラクシモガキノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市浦川原区顕聖寺', '15', '15222', '9420314', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '浦川原区顕聖寺', 'ウラガワラクケンショウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市浦川原区横川', '15', '15222', '9420315', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '浦川原区横川', 'ウラガワラクヨコカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市浦川原区六日町', '15', '15222', '9420316', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '浦川原区六日町', 'ウラガワラクムイカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市浦川原区杉坪', '15', '15222', '9420317', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '浦川原区杉坪', 'ウラガワラクスギツボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市浦川原区上岡', '15', '15222', '9420318', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '浦川原区上岡', 'ウラガワラクカミオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市浦川原区東俣', '15', '15222', '9420319', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '浦川原区東俣', 'ウラガワラクヒガシマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市浦川原区熊沢', '15', '15222', '9420321', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '浦川原区熊沢', 'ウラガワラククマザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市浦川原区横住', '15', '15222', '9420322', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '浦川原区横住', 'ウラガワラクヨコズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市浦川原区真光寺', '15', '15222', '9420323', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '浦川原区真光寺', 'ウラガワラクシンコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市浦川原区谷', '15', '15222', '9420324', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '浦川原区谷', 'ウラガワラクタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市浦川原区坪野', '15', '15222', '9420325', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '浦川原区坪野', 'ウラガワラクツボノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市浦川原区法定寺', '15', '15222', '9420326', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '浦川原区法定寺', 'ウラガワラクホウジョウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市浦川原区菱田', '15', '15222', '9420327', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '浦川原区菱田', 'ウラガワラクヒシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市浦川原区長走', '15', '15222', '9420331', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '浦川原区長走', 'ウラガワラクナガハシリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市浦川原区岩室', '15', '15222', '9420332', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '浦川原区岩室', 'ウラガワラクイワムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市浦川原区桜島', '15', '15222', '9420333', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '浦川原区桜島', 'ウラガワラクサクラシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市浦川原区山本', '15', '15222', '9420334', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '浦川原区山本', 'ウラガワラクヤマモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市浦川原区今熊', '15', '15222', '9420335', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '浦川原区今熊', 'ウラガワラクイマグマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市浦川原区飯室', '15', '15222', '9420336', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '浦川原区飯室', 'ウラガワラクイイムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市浦川原区山印内', '15', '15222', '9420337', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '浦川原区山印内', 'ウラガワラクヤマインナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市浦川原区印内', '15', '15222', '9420338', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '浦川原区印内', 'ウラガワラクインナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市浦川原区日向', '15', '15222', '9420339', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '浦川原区日向', 'ウラガワラクヒナタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市安塚区細野', '15', '15222', '9420401', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '安塚区細野', 'ヤスヅカクホソノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市安塚区坊金', '15', '15222', '9420402', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '安塚区坊金', 'ヤスヅカクボウガネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市安塚区本郷', '15', '15222', '9420403', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '安塚区本郷', 'ヤスヅカクホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市安塚区石橋', '15', '15222', '9420404', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '安塚区石橋', 'ヤスヅカクイシバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市安塚区上方', '15', '15222', '9420405', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '安塚区上方', 'ヤスヅカクカミガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市安塚区安塚', '15', '15222', '9420411', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '安塚区安塚', 'ヤスヅカクヤスヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市安塚区牧野', '15', '15222', '9420412', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '安塚区牧野', 'ヤスヅカクマキノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市安塚区板尾', '15', '15222', '9420413', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '安塚区板尾', 'ヤスヅカクイタオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市安塚区袖山', '15', '15222', '9420414', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '安塚区袖山', 'ヤスヅカクソデヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市安塚区松崎', '15', '15222', '9420415', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '安塚区松崎', 'ヤスヅカクマツザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市安塚区行野', '15', '15222', '9420521', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '安塚区行野', 'ヤスヅカクユクノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市安塚区大原', '15', '15222', '9420522', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '安塚区大原', 'ヤスヅカクオオハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市安塚区戸沢', '15', '15222', '9420523', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '安塚区戸沢', 'ヤスヅカクトザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市安塚区芹田', '15', '15222', '9420524', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '安塚区芹田', 'ヤスヅカクセリダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市安塚区和田', '15', '15222', '9420525', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '安塚区和田', 'ヤスヅカクワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市安塚区樽田', '15', '15222', '9420531', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '安塚区樽田', 'ヤスヅカクタルダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市安塚区下船倉', '15', '15222', '9420532', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '安塚区下船倉', 'ヤスヅカクシモフナクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市安塚区上船倉', '15', '15222', '9420533', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '安塚区上船倉', 'ヤスヅカクカミフナクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市安塚区須川', '15', '15222', '9420534', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '安塚区須川', 'ヤスヅカクスガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市安塚区真荻平', '15', '15222', '9420535', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '安塚区真荻平', 'ヤスヅカクモオギタイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市安塚区信濃坂', '15', '15222', '9420536', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '安塚区信濃坂', 'ヤスヅカクシナノザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市安塚区二本木', '15', '15222', '9420537', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '安塚区二本木', 'ヤスヅカクニホンギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市安塚区高沢', '15', '15222', '9420538', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '安塚区高沢', 'ヤスヅカクタカサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市安塚区円平坊', '15', '15222', '9420539', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '安塚区円平坊', 'ヤスヅカクエンタイラボウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市安塚区小黒', '15', '15222', '9420541', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '安塚区小黒', 'ヤスヅカクコグロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市安塚区切越', '15', '15222', '9420542', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '安塚区切越', 'ヤスヅカクキリコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市安塚区菅沼', '15', '15222', '9420543', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '安塚区菅沼', 'ヤスヅカクスガヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市安塚区朴ノ木', '15', '15222', '9420544', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '安塚区朴ノ木', 'ヤスヅカクホオノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市大島区嶺', '15', '15222', '9421101', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '大島区嶺', 'オオシマクミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市大島区田麦', '15', '15222', '9421102', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '大島区田麦', 'オオシマクタムギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市大島区大平', '15', '15222', '9421103', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '大島区大平', 'オオシマクオオダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市大島区下達', '15', '15222', '9421104', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '大島区下達', 'オオシマクシモタテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市大島区上達', '15', '15222', '9421105', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '大島区上達', 'オオシマクカミタテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市大島区岡', '15', '15222', '9421106', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '大島区岡', 'オオシマクオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市大島区板山', '15', '15222', '9421107', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '大島区板山', 'オオシマクイタヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市大島区大島', '15', '15222', '9421211', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '大島区大島', 'オオシマクオオシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市大島区中野', '15', '15222', '9421212', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '大島区中野', 'オオシマクナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市大島区棚岡', '15', '15222', '9421213', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '大島区棚岡', 'オオシマクタナオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市大島区仁上', '15', '15222', '9421214', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '大島区仁上', 'オオシマクニガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市大島区牛ケ鼻', '15', '15222', '9421215', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '大島区牛ケ鼻', 'オオシマクウシガハナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市大島区菖蒲', '15', '15222', '9421216', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '大島区菖蒲', 'オオシマクショウブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市松之山黒倉', '15', '15210', '9421341', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '松之山黒倉', 'マツノヤマクロクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市浦田', '15', '15210', '9421342', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '浦田', 'ウラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市峠', '15', '15210', '9421351', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '峠', 'トウゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市木和田原', '15', '15210', '9421352', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '木和田原', 'キワダハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市室野', '15', '15210', '9421353', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '室野', 'ムロノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市福島', '15', '15210', '9421354', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '福島', 'フクジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市奈良立', '15', '15210', '9421355', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '奈良立', 'ナラダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市竹所', '15', '15210', '9421356', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '竹所', 'タケトコロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市松之山水梨', '15', '15210', '9421401', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '松之山水梨', 'マツノヤマミズナシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市松之山小谷', '15', '15210', '9421402', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '松之山小谷', 'マツノヤマコタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市松之山大荒戸', '15', '15210', '9421403', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '松之山大荒戸', 'マツノヤマオオアラト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市松之山新山', '15', '15210', '9421404', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '松之山新山', 'マツノヤマアラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市松之山光間', '15', '15210', '9421405', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '松之山光間', 'マツノヤマヒカルマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市松之山', '15', '15210', '9421406', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '松之山', 'マツノヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市松之山松口', '15', '15210', '9421411', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '松之山松口', 'マツノヤママツグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市松之山三桶', '15', '15210', '9421412', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '松之山三桶', 'マツノヤマミオケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市松之山沢口', '15', '15210', '9421413', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '松之山沢口', 'マツノヤマサワグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市松之山古戸', '15', '15210', '9421414', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '松之山古戸', 'マツノヤマフルト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市松之山観音寺', '15', '15210', '9421415', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '松之山観音寺', 'マツノヤマカンノンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市松之山坂下', '15', '15210', '9421416', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '松之山坂下', 'マツノヤマサカノシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市松之山猪之名', '15', '15210', '9421417', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '松之山猪之名', 'マツノヤマイノミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市松之山藤内名', '15', '15210', '9421418', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '松之山藤内名', 'マツノヤマトナイミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市松之山橋詰', '15', '15210', '9421419', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '松之山橋詰', 'マツノヤマハシヅメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市松之山五十子平', '15', '15210', '9421421', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '松之山五十子平', 'マツノヤマイガゴダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市松之山坪野', '15', '15210', '9421422', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '松之山坪野', 'マツノヤマツボノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市松之山赤倉', '15', '15210', '9421423', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '松之山赤倉', 'マツノヤマアカクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市松之山東山', '15', '15210', '9421424', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '松之山東山', 'マツノヤマヒガシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市松之山下鰕池', '15', '15210', '9421425', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '松之山下鰕池', 'マツノヤマシモエビイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市松之山上鰕池', '15', '15210', '9421426', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '松之山上鰕池', 'マツノヤマカミエビイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市松之山東川', '15', '15210', '9421427', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '松之山東川', 'マツノヤマヒガシカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市松之山中尾', '15', '15210', '9421428', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '松之山中尾', 'マツノヤマナカオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市松之山藤倉', '15', '15210', '9421429', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '松之山藤倉', 'マツノヤマフジクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市松之山湯山', '15', '15210', '9421431', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '松之山湯山', 'マツノヤマユヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市松之山湯本', '15', '15210', '9421432', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '松之山湯本', 'マツノヤマユモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市松之山天水島', '15', '15210', '9421434', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '松之山天水島', 'マツノヤマアマミズシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市松之山天水越', '15', '15210', '9421435', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '松之山天水越', 'マツノヤマアマミズコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市滝沢', '15', '15210', '9421501', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '滝沢', 'タキザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市片桐山', '15', '15210', '9421502', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '片桐山', 'カタギリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市孟地', '15', '15210', '9421503', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '孟地', 'モウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市犬伏', '15', '15210', '9421504', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '犬伏', 'イヌブシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市苧島', '15', '15210', '9421505', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '苧島', 'オノシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市中子', '15', '15210', '9421506', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '中子', 'ナカゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市海老', '15', '15210', '9421511', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '海老', 'カイロウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市松代東山', '15', '15210', '9421512', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '松代東山', 'マツダイヒガシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市松代下山', '15', '15210', '9421513', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '松代下山', 'マツダイシモヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市小屋丸', '15', '15210', '9421514', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '小屋丸', 'コヤマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市池之畑', '15', '15210', '9421515', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '池之畑', 'イケノハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市菅刈', '15', '15210', '9421521', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '菅刈', 'スガカリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市松代田沢', '15', '15210', '9421522', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '松代田沢', 'マツダイタザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市小荒戸', '15', '15210', '9421523', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '小荒戸', 'コアラト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市千年', '15', '15210', '9421524', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '千年', 'チトセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市池尻', '15', '15210', '9421525', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '池尻', 'イケジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市松代', '15', '15210', '9421526', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '松代', 'マツダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市太平', '15', '15210', '9421527', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '太平', 'タイヘイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市莇平', '15', '15210', '9421531', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '莇平', 'アザミヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市仙納', '15', '15210', '9421532', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '仙納', 'センノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市田野倉', '15', '15210', '9421533', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '田野倉', 'タノクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市蒲生', '15', '15210', '9421534', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '蒲生', 'カモウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市名平', '15', '15210', '9421535', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '名平', 'ナビロウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市儀明', '15', '15210', '9421536', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '儀明', 'ギミヨウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市寺田', '15', '15210', '9421537', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '寺田', 'テラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市小池', '15', '15210', '9421538', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '小池', 'コイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市桐山', '15', '15210', '9421541', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '桐山', 'キリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市清水', '15', '15210', '9421542', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '清水', 'シミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市会沢', '15', '15210', '9421543', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '会沢', 'アイサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市蓬平', '15', '15210', '9421544', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '蓬平', 'ヨモギヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市', '15', '15222', '9430000', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('130292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市上真砂', '15', '15222', '9430101', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '上真砂', 'カミマナゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市杉野袋', '15', '15222', '9430102', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '杉野袋', 'スギノフクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市米岡', '15', '15222', '9430103', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '米岡', 'ヨネオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市鶴町', '15', '15222', '9430104', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '鶴町', 'ツルマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市東原', '15', '15222', '9430105', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '東原', 'ヒガシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市北田中', '15', '15222', '9430106', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '北田中', 'キタタナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市諏訪', '15', '15222', '9430107', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '諏訪', 'スワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市南新保', '15', '15222', '9430108', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '南新保', 'ミナミシンボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市北新保', '15', '15222', '9430109', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '北新保', 'キタシンボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市下野田', '15', '15222', '9430111', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '下野田', 'シモノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市上野田', '15', '15222', '9430112', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '上野田', 'カミノタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市上池部', '15', '15222', '9430113', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '上池部', 'カミイケベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市吉岡', '15', '15222', '9430114', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '吉岡', 'ヨシオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市劔', '15', '15222', '9430115', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '劔', 'ツルギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市野尻', '15', '15222', '9430116', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '野尻', 'ノジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市稲', '15', '15222', '9430117', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '稲', 'イナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市東市野口', '15', '15222', '9430118', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '東市野口', 'ヒガシイチノクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市下池部', '15', '15222', '9430119', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '下池部', 'シモイケベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市藤塚', '15', '15222', '9430121', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '藤塚', 'フジヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市新保古新田', '15', '15222', '9430122', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '新保古新田', 'シンボコシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市本新保', '15', '15222', '9430123', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '本新保', 'ホンシンボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市上雲寺', '15', '15222', '9430124', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '上雲寺', 'ジョウウンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市下富川', '15', '15222', '9430125', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '下富川', 'シモトミガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市上富川', '15', '15222', '9430126', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '上富川', 'カミトミガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市熊塚', '15', '15222', '9430127', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '熊塚', 'クマヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市池', '15', '15222', '9430128', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '池', 'イケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市茨沢', '15', '15222', '9430129', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '茨沢', 'イバラサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市薮野', '15', '15222', '9430131', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '薮野', 'ヤブノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市辰尾新田', '15', '15222', '9430132', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '辰尾新田', 'タツオシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市東稲塚新田', '15', '15222', '9430133', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '東稲塚新田', 'ヒガシイナヅカシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市下稲塚', '15', '15222', '9430134', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '下稲塚', 'シモイナヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市下四ツ屋', '15', '15222', '9430135', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '下四ツ屋', 'シモヨツヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市西松野木', '15', '15222', '9430136', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '西松野木', 'ニシマツノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市長者町', '15', '15222', '9430137', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '長者町', 'チョウジャマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市本長者原', '15', '15222', '9430138', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '本長者原', 'モトチョウジャハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市天野原新田', '15', '15222', '9430139', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '天野原新田', 'アマノハラシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市子安', '15', '15222', '9430141', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '子安', 'コヤス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市下新町', '15', '15222', '9430142', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '下新町', 'シモシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市上新町', '15', '15222', '9430143', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '上新町', 'カミシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市桜町', '15', '15222', '9430144', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '桜町', 'サクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市今池', '15', '15222', '9430145', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '今池', 'イマイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市樋場', '15', '15222', '9430146', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '樋場', 'トヨバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市新南町', '15', '15222', '9430147', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '新南町', 'シンナンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市子安新田', '15', '15222', '9430148', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '子安新田', 'コヤスシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市平成町', '15', '15222', '9430151', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '平成町', 'ヘイセイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市西市野口', '15', '15222', '9430152', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '西市野口', 'ニシイチノクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市鴨島', '15', '15222', '9430153', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '鴨島', 'カモジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市稲田', '15', '15222', '9430154', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '稲田', 'イナダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市四ケ所', '15', '15222', '9430155', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '四ケ所', 'シカショ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市北田屋新田', '15', '15222', '9430161', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '北田屋新田', 'キタタヤシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市南田屋新田', '15', '15222', '9430162', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '南田屋新田', 'ミナミタヤシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市平岡', '15', '15222', '9430163', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '平岡', 'ヒラオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市中々村新田', '15', '15222', '9430164', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '中々村新田', 'ナカナカムラシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市上島', '15', '15222', '9430165', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '上島', 'カミジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市寺', '15', '15222', '9430166', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '寺', 'テラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市下稲田', '15', '15222', '9430167', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '下稲田', 'シモイナダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市上稲田', '15', '15222', '9430168', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '上稲田', 'カミイナダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市藤野新田', '15', '15222', '9430171', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '藤野新田', 'フジノシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市大道福田', '15', '15222', '9430172', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '大道福田', 'ダイドウフクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市富岡', '15', '15222', '9430173', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '富岡', 'トミオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市中田新田', '15', '15222', '9430174', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '中田新田', 'ナカダシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市大日', '15', '15222', '9430175', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '大日', 'ダイニチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市戸野目古新田', '15', '15222', '9430176', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '戸野目古新田', 'トノメコシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市門田新田', '15', '15222', '9430177', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '門田新田', 'モンデンシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市戸野目', '15', '15222', '9430178', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '戸野目', 'トノメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市虫川', '15', '15222', '9430181', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '虫川', 'ムシカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市高森', '15', '15222', '9430182', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '高森', 'タカモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市桐原', '15', '15222', '9430183', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '桐原', 'キリハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市本道', '15', '15222', '9430184', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '本道', 'ホンドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市長面', '15', '15222', '9430185', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '長面', 'ナガオモテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市市野江', '15', '15222', '9430186', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '市野江', 'イチノエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市荒屋', '15', '15222', '9430187', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '荒屋', 'アラヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市四辻町', '15', '15222', '9430201', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '四辻町', 'ヨツジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市三和区稲原', '15', '15222', '9430221', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '三和区稲原', 'サンワクイナハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市三和区下中', '15', '15222', '9430222', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '三和区下中', 'サンワクシモナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市三和区田', '15', '15222', '9430223', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '三和区田', 'サンワクタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市三和区川浦', '15', '15222', '9430224', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '三和区川浦', 'サンワクカワウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市三和区野', '15', '15222', '9430225', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '三和区野', 'サンワクノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市三和区日和町', '15', '15222', '9430226', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '三和区日和町', 'サンワクヒヨリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市三和区番町', '15', '15222', '9430227', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '三和区番町', 'サンワクバンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市三和区神明町', '15', '15222', '9430228', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '三和区神明町', 'サンワクシンメイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市三和区鴨井', '15', '15222', '9430231', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '三和区鴨井', 'サンワクカモイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市三和区水吉', '15', '15222', '9430232', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '三和区水吉', 'サンワクミズヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市三和区水科', '15', '15222', '9430233', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '三和区水科', 'サンワクミズシナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市三和区法花寺', '15', '15222', '9430234', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '三和区法花寺', 'サンワクホッケイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市三和区窪', '15', '15222', '9430235', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '三和区窪', 'サンワククボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市三和区中野', '15', '15222', '9430236', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '三和区中野', 'サンワクナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市三和区北代', '15', '15222', '9430301', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '三和区北代', 'サンワクキタダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市三和区払沢', '15', '15222', '9430302', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '三和区払沢', 'サンワクハライザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市三和区山高津', '15', '15222', '9430303', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '三和区山高津', 'サンワクヤマタカツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市三和区桑曽根', '15', '15222', '9430304', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '三和区桑曽根', 'サンワククワゾネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市三和区岡田', '15', '15222', '9430305', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '三和区岡田', 'サンワクオカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市三和区所山田', '15', '15222', '9430306', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '三和区所山田', 'サンワクショヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市三和区下新保', '15', '15222', '9430307', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '三和区下新保', 'サンワクシモシンボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市三和区島倉', '15', '15222', '9430311', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '三和区島倉', 'サンワクシマクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市三和区下田島', '15', '15222', '9430312', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '三和区下田島', 'サンワクシモタジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市三和区今保', '15', '15222', '9430313', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '三和区今保', 'サンワクイマポ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市三和区大', '15', '15222', '9430314', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '三和区大', 'サンワクオオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市三和区三村新田', '15', '15222', '9430315', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '三和区三村新田', 'サンワクミムラシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市三和区井ノ口', '15', '15222', '9430316', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '三和区井ノ口', 'サンワクイノクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市三和区浮島', '15', '15222', '9430317', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '三和区浮島', 'サンワクウキシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市三和区宮崎新田', '15', '15222', '9430318', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '三和区宮崎新田', 'サンワクミヤザキシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市妙油', '15', '15222', '9430411', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '妙油', 'ミョウユ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市北方', '15', '15222', '9430412', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '北方', 'キタガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市南方', '15', '15222', '9430413', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '南方', 'ミナミガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市大口', '15', '15222', '9430414', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '大口', 'オオクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市東京田', '15', '15222', '9430415', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '東京田', 'ヒガシキョウデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市十二ノ木', '15', '15222', '9430416', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '十二ノ木', 'ジュウニノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市森田', '15', '15222', '9430417', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '森田', 'モリタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市高和町', '15', '15222', '9430421', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '高和町', 'コウワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市飯田', '15', '15222', '9430422', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '飯田', 'イイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市高津', '15', '15222', '9430423', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '高津', 'タカツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市上曾根', '15', '15222', '9430424', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '上曾根', 'カミゾネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市稲谷', '15', '15222', '9430425', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '稲谷', 'イナダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市下曾根', '15', '15222', '9430426', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '下曾根', 'シモゾネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市元屋敷', '15', '15222', '9430427', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '元屋敷', 'モトヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市清里区岡野町', '15', '15222', '9430501', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '清里区岡野町', 'キヨサトクオカノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市清里区荒牧', '15', '15222', '9430502', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '清里区荒牧', 'キヨサトクアラマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市清里区上深沢', '15', '15222', '9430503', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '清里区上深沢', 'キヨサトクカミフカサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市清里区上田島', '15', '15222', '9430504', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '清里区上田島', 'キヨサトクカミタジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市清里区東福島', '15', '15222', '9430505', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '清里区東福島', 'キヨサトクヒガシフクシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市清里区菅原', '15', '15222', '9430506', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '清里区菅原', 'キヨサトクスガハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市清里区岡嶺新田', '15', '15222', '9430507', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '清里区岡嶺新田', 'キヨサトクオカミネシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市清里区平成', '15', '15222', '9430508', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '清里区平成', 'キヨサトクヘイセイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市清里区弥生', '15', '15222', '9430509', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '清里区弥生', 'キヨサトクヤヨイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市清里区みらい', '15', '15222', '9430510', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '清里区みらい', 'キヨサトクミライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市清里区塩曽根', '15', '15222', '9430511', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '清里区塩曽根', 'キヨサトクシオゾネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市清里区馬屋', '15', '15222', '9430512', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '清里区馬屋', 'キヨサトクマヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市清里区今曽根', '15', '15222', '9430513', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '清里区今曽根', 'キヨサトクイマゾネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市清里区南田中', '15', '15222', '9430514', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '清里区南田中', 'キヨサトクミナミタナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市清里区武士', '15', '15222', '9430515', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '清里区武士', 'キヨサトクモノノフ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市清里区上稲塚', '15', '15222', '9430516', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '清里区上稲塚', 'キヨサトクカミイナヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市清里区寺脇', '15', '15222', '9430521', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '清里区寺脇', 'キヨサトクテラワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市清里区東戸野', '15', '15222', '9430522', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '清里区東戸野', 'キヨサトクヒガシトノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市清里区棚田', '15', '15222', '9430523', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '清里区棚田', 'キヨサトクタナダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市清里区水草', '15', '15222', '9430524', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '清里区水草', 'キヨサトクミズクサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市清里区北野', '15', '15222', '9430525', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '清里区北野', 'キヨサトクキタノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市清里区梨平', '15', '15222', '9430526', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '清里区梨平', 'キヨサトクナシダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市清里区赤池', '15', '15222', '9430527', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '清里区赤池', 'キヨサトクアカイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市清里区青柳', '15', '15222', '9430531', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '清里区青柳', 'キヨサトクアオヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市清里区梨窪', '15', '15222', '9430532', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '清里区梨窪', 'キヨサトクナシクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市清里区鶯沢', '15', '15222', '9430533', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '清里区鶯沢', 'キヨサトクウグイスサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市清里区上中条', '15', '15222', '9430534', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '清里区上中条', 'キヨサトクカミナカジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市清里区鈴倉', '15', '15222', '9430535', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '清里区鈴倉', 'キヨサトクスズクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市牧区坪山', '15', '15222', '9430601', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '牧区坪山', 'マキクツボヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市牧区平方', '15', '15222', '9430602', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '牧区平方', 'マキクヒラカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市牧区平山', '15', '15222', '9430603', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '牧区平山', 'マキクタイラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市牧区七森', '15', '15222', '9430604', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '牧区七森', 'マキクナナモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市牧区神谷', '15', '15222', '9430605', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '牧区神谷', 'マキクカミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市牧区大月', '15', '15222', '9430606', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '牧区大月', 'マキクオオツキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市牧区川井沢', '15', '15222', '9430607', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '牧区川井沢', 'マキクカワイザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市牧区片町', '15', '15222', '9430611', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '牧区片町', 'マキクカタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市牧区吉坪', '15', '15222', '9430612', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '牧区吉坪', 'マキクヨシツボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市牧区高谷', '15', '15222', '9430613', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '牧区高谷', 'マキクタカタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市牧区切光', '15', '15222', '9430614', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '牧区切光', 'マキクセッコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市牧区今清水', '15', '15222', '9430615', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '牧区今清水', 'マキクイマシミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市牧区樫谷', '15', '15222', '9430616', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '牧区樫谷', 'マキクカシダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市牧区泉', '15', '15222', '9430617', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '牧区泉', 'マキクイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市牧区高尾', '15', '15222', '9430621', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '牧区高尾', 'マキクタカオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市牧区棚広新田', '15', '15222', '9430622', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '牧区棚広新田', 'マキクタナヒロシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市牧区宇津俣', '15', '15222', '9430623', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '牧区宇津俣', 'マキクウツノマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市牧区府殿', '15', '15222', '9430624', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '牧区府殿', 'マキクフドノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市牧区上牧', '15', '15222', '9430625', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '牧区上牧', 'マキクカミマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市牧区倉下', '15', '15222', '9430626', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '牧区倉下', 'マキククラシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市牧区原', '15', '15222', '9430627', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '牧区原', 'マキクハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市牧区棚広', '15', '15222', '9430628', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '牧区棚広', 'マキクタナヒロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市牧区下湯谷', '15', '15222', '9430631', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '牧区下湯谷', 'マキクシモユウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市牧区上昆子', '15', '15222', '9430632', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '牧区上昆子', 'マキクカミビリゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市牧区下昆子', '15', '15222', '9430633', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '牧区下昆子', 'マキクシモビリゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市牧区田島', '15', '15222', '9430634', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '牧区田島', 'マキクタジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市牧区岩神', '15', '15222', '9430635', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '牧区岩神', 'マキクイワガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市牧区国川', '15', '15222', '9430636', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '牧区国川', 'マキクコクガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市牧区桜滝', '15', '15222', '9430637', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '牧区桜滝', 'マキクサクラタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市牧区東松ノ木', '15', '15222', '9430641', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '牧区東松ノ木', 'マキクヒガシマツノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市牧区荒井', '15', '15222', '9430642', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '牧区荒井', 'マキクアライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市牧区山口', '15', '15222', '9430643', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '牧区山口', 'マキクヤマグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市牧区宮口', '15', '15222', '9430644', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '牧区宮口', 'マキクミヤグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市牧区池舟', '15', '15222', '9430645', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '牧区池舟', 'マキクイケフネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市牧区落田', '15', '15222', '9430646', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '牧区落田', 'マキクオチダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市牧区柳島', '15', '15222', '9430647', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '牧区柳島', 'マキクヤナギシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市牧区小川', '15', '15222', '9430648', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '牧区小川', 'マキクオガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市中門前', '15', '15222', '9430801', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '中門前', 'ナカモンゼン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市大豆', '15', '15222', '9430802', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '大豆', 'ダイズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市春日野', '15', '15222', '9430803', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '春日野', 'カスガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市新光町', '15', '15222', '9430804', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '新光町', 'シンコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市木田', '15', '15222', '9430805', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '木田', 'キダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市木田新田', '15', '15222', '9430806', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '木田新田', 'キダシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市春日山町', '15', '15222', '9430807', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '春日山町', 'カスガヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市宮野尾', '15', '15222', '9430808', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '宮野尾', 'ミヤノオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市春日', '15', '15222', '9430809', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '春日', 'カスガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市大学前', '15', '15222', '9430810', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '大学前', 'ダイガクマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市上正善寺', '15', '15222', '9430811', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '上正善寺', 'カミショウゼンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市中正善寺', '15', '15222', '9430812', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '中正善寺', 'ナカショウゼンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市下正善寺', '15', '15222', '9430813', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '下正善寺', 'シモショウゼンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市岩木', '15', '15222', '9430814', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '岩木', 'イワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市山屋敷町', '15', '15222', '9430815', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '山屋敷町', 'ヤマヤシキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市藤新田', '15', '15222', '9430816', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '藤新田', 'フジシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市藤巻', '15', '15222', '9430817', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '藤巻', 'フジマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市宇津尾', '15', '15222', '9430818', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '宇津尾', 'ウツオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市中屋敷', '15', '15222', '9430819', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '中屋敷', 'ナカヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市土橋', '15', '15222', '9430821', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '土橋', 'ツチハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市新町', '15', '15222', '9430822', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市高土町', '15', '15222', '9430823', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '高土町', 'コウドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市北城町', '15', '15222', '9430824', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '北城町', 'キタシロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市東本町', '15', '15222', '9430825', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '東本町', 'ヒガシホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市幸町', '15', '15222', '9430826', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市栄町', '15', '15222', '9430827', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '栄町', 'サカエマチ', '（－マチ）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('130503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市北本町', '15', '15222', '9430828', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '北本町', 'キタホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市薄袋', '15', '15222', '9430829', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '薄袋', 'ススキブクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市仲町', '15', '15222', '9430831', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '仲町', 'ナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市本町', '15', '15222', '9430832', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市大町', '15', '15222', '9430833', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '大町', 'オオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市西城町', '15', '15222', '9430834', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '西城町', 'ニシシロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市本城町', '15', '15222', '9430835', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '本城町', 'モトシロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市東城町', '15', '15222', '9430836', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '東城町', 'ヒガシシロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市南城町', '15', '15222', '9430837', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '南城町', 'ミナミシロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市大手町', '15', '15222', '9430838', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '大手町', 'オオテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市上湯谷', '15', '15222', '9430839', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '上湯谷', 'カミユダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市南本町', '15', '15222', '9430841', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '南本町', 'ミナミホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市五ケ所新田', '15', '15222', '9430842', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '五ケ所新田', 'ゴカショシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市下新田', '15', '15222', '9430843', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '下新田', 'シモシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市丸山新田', '15', '15222', '9430844', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '丸山新田', 'マルヤマシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市高田新田', '15', '15222', '9430845', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '高田新田', 'タカダシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市南高田町', '15', '15222', '9430846', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '南高田町', 'ミナミタカダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市南新町', '15', '15222', '9430847', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '南新町', 'ミナミシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市儀明', '15', '15222', '9430848', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '儀明', 'ギミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市塩荷谷', '15', '15222', '9430849', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '塩荷谷', 'シオニダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市下箱井', '15', '15222', '9430851', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '下箱井', 'シモハコイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市島田下新田', '15', '15222', '9430852', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '島田下新田', 'シマダシモシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市島田', '15', '15222', '9430853', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '島田', 'シマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市島田上新田', '15', '15222', '9430854', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '島田上新田', 'シマダカミシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市木島', '15', '15222', '9430855', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '木島', 'キジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市上箱井', '15', '15222', '9430856', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '上箱井', 'カミハコイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市中箱井', '15', '15222', '9430857', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '中箱井', 'ナカハコイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市岡原', '15', '15222', '9430858', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '岡原', 'オカバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市寺町', '15', '15222', '9430859', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '寺町', 'テラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市大和', '15', '15222', '9430861', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '大和', 'ヤマト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市荒町', '15', '15222', '9430862', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '荒町', 'アラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市脇野田', '15', '15222', '9430863', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '脇野田', 'ワキノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市今泉', '15', '15222', '9430864', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '今泉', 'イマイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市七ケ所新田', '15', '15222', '9430865', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '七ケ所新田', 'シチカショシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市土合', '15', '15222', '9430866', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '土合', 'ドアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市青木', '15', '15222', '9430871', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '青木', 'アオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市石沢', '15', '15222', '9430872', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '石沢', 'イシザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市西田中', '15', '15222', '9430873', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '西田中', 'ニシタナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市稲荷', '15', '15222', '9430874', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '稲荷', 'イナリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市地頭方', '15', '15222', '9430875', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '地頭方', 'ジトウガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市上門前', '15', '15222', '9430876', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '上門前', 'カミモンゼン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市小滝', '15', '15222', '9430877', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '小滝', 'コタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市下馬場', '15', '15222', '9430878', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '下馬場', 'シモババ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市京田', '15', '15222', '9430881', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '京田', 'キョウデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市中田原', '15', '15222', '9430882', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '中田原', 'ナカダハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市中通町', '15', '15222', '9430883', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '中通町', 'ナカドオリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市上中田', '15', '15222', '9430884', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '上中田', 'カミナカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市黒田', '15', '15222', '9430885', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '黒田', 'クロダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市朝日', '15', '15222', '9430886', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '朝日', 'アサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市灰塚', '15', '15222', '9430887', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '灰塚', 'ハイヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市向橋', '15', '15222', '9430888', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '向橋', 'ムカバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市後谷', '15', '15222', '9430889', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '後谷', 'ウシロダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市昭和町', '15', '15222', '9430891', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '昭和町', 'ショウワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市寺町', '15', '15222', '9430892', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '寺町', 'テラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市大貫', '15', '15222', '9430893', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '大貫', 'オオヌキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市上昭和町', '15', '15222', '9430894', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '上昭和町', 'カミショウワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市御殿山町', '15', '15222', '9430895', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '御殿山町', 'ゴテンヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市飯', '15', '15222', '9430896', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '飯', 'イイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市滝寺', '15', '15222', '9430897', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '滝寺', 'タキデラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市塚田新田', '15', '15222', '9430898', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '塚田新田', 'ツカダシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市下中田', '15', '15222', '9430899', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '下中田', 'シモナカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市', '15', '15217', '9440000', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('130590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市上百々', '15', '15217', '9440001', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '上百々', 'カミドウドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市広島', '15', '15217', '9440002', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '広島', 'ヒロシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市月岡', '15', '15217', '9440003', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '月岡', 'ツキオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市国賀', '15', '15217', '9440004', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '国賀', 'コクカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市新栄町', '15', '15217', '9440005', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '新栄町', 'シンサカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市中川', '15', '15217', '9440005', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '中川', 'ナカガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市稲塚', '15', '15217', '9440006', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '稲塚', 'イナヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市大崎町', '15', '15217', '9440006', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '大崎町', 'オオサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市栗原', '15', '15217', '9440007', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '栗原', 'クリバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市柳井田町', '15', '15217', '9440008', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '柳井田町', 'ヤナイダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市東陽町', '15', '15217', '9440009', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '東陽町', 'トウヨウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市石塚町', '15', '15217', '9440011', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '石塚町', 'イシヅカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市高柳', '15', '15217', '9440013', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '高柳', 'タカヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市関川町', '15', '15217', '9440014', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '関川町', 'セキガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市美守', '15', '15217', '9440016', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '美守', 'ヒダノモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市中央町', '15', '15217', '9440017', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '中央町', 'チュウオウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市諏訪町', '15', '15217', '9440018', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '諏訪町', 'スワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市新工町', '15', '15217', '9440019', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '新工町', 'シンコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市工団町', '15', '15217', '9440020', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '工団町', 'コウダンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市北条', '15', '15217', '9440021', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '北条', 'キタジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市吉木', '15', '15217', '9440022', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '吉木', 'ヨシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市西条', '15', '15217', '9440023', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '西条', 'ニシジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市吉木新田', '15', '15217', '9440024', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '吉木新田', 'ヨシキシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市上新保', '15', '15217', '9440025', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '上新保', 'カミシンボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市川上', '15', '15217', '9440026', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '川上', 'カワカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市中宿', '15', '15217', '9440027', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '中宿', 'ナカジク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市姫川原', '15', '15217', '9440028', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '姫川原', 'ヒメカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市田町', '15', '15217', '9440031', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '田町', 'タマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市小出雲', '15', '15217', '9440032', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '小出雲', 'オイズモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市広田町', '15', '15217', '9440033', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '広田町', 'ヒロタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市経塚町', '15', '15217', '9440034', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '経塚町', 'キョウヅカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市渋江町', '15', '15217', '9440035', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '渋江町', 'シブエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市末広町', '15', '15217', '9440036', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '末広町', 'スエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市学校町', '15', '15217', '9440037', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '学校町', 'ガッコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市新井', '15', '15217', '9440041', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '新井', 'アライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市東雲町', '15', '15217', '9440042', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '東雲町', 'シノノメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市朝日町', '15', '15217', '9440043', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '朝日町', 'アサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市栄町', '15', '15217', '9440044', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '栄町', 'サカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市中町', '15', '15217', '9440045', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '中町', 'ナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市上町', '15', '15217', '9440046', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '上町', 'カミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市白山町', '15', '15217', '9440047', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '白山町', 'ハクサンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市下町', '15', '15217', '9440048', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '下町', 'シモマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市錦町', '15', '15217', '9440051', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '錦町', 'ニシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市上中', '15', '15217', '9440052', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '上中', 'カミナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市三本木新田', '15', '15217', '9440053', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '三本木新田', 'サンボンギシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市新井新田', '15', '15217', '9440054', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '新井新田', 'アライシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市東志', '15', '15217', '9440055', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '東志', 'ヒガシシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市志', '15', '15217', '9440056', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '志', 'シ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市菅沼', '15', '15217', '9440057', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '菅沼', 'スガヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市西菅沼新田', '15', '15217', '9440058', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '西菅沼新田', 'ニシスガヌマシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市窪松原', '15', '15217', '9440061', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '窪松原', 'クボマツバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市両善寺', '15', '15217', '9440062', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '両善寺', 'リョウゼンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市西野谷新田', '15', '15217', '9440063', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '西野谷新田', 'ニシノヤシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市西野谷', '15', '15217', '9440064', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '西野谷', 'ニシノヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市藤塚新田', '15', '15217', '9440071', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '藤塚新田', 'フジヅカシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市小丸山新田', '15', '15217', '9440072', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '小丸山新田', 'コマルヤマシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市長森', '15', '15217', '9440073', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '長森', 'ナガモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市三ツ俣', '15', '15217', '9440074', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '三ツ俣', 'ミツマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市猪野山', '15', '15217', '9440075', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '猪野山', 'イノヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市土田', '15', '15217', '9440076', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '土田', 'ドダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市梨木', '15', '15217', '9440077', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '梨木', 'ナシノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市籠町', '15', '15217', '9440081', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '籠町', 'カゴマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市乙吉', '15', '15217', '9440082', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '乙吉', 'オトヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市上四ツ屋', '15', '15217', '9440083', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '上四ツ屋', 'カミヨツヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市五日市', '15', '15217', '9440084', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '五日市', 'イツカイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市谷内林新田', '15', '15217', '9440085', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '谷内林新田', 'ヤチバヤシシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市坂井新田', '15', '15217', '9440086', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '坂井新田', 'サカイシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市新保新田', '15', '15217', '9440087', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '新保新田', 'シンボシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市上八幡新田', '15', '15217', '9440088', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '上八幡新田', 'カミハチマンシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市青田', '15', '15217', '9440091', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '青田', 'アオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市飛田', '15', '15217', '9440092', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '飛田', 'ヒダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市飛田新田', '15', '15217', '9440093', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '飛田新田', 'ヒダシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市岡崎新田', '15', '15217', '9440094', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '岡崎新田', 'オカザキシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市十日市', '15', '15217', '9440095', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '十日市', 'トオカイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市神宮寺', '15', '15217', '9440096', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '神宮寺', 'ジングウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市宮内', '15', '15217', '9440097', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '宮内', 'ミヤウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市雪森', '15', '15217', '9440098', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '雪森', 'ユキモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市板倉区稲増', '15', '15222', '9440101', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '板倉区稲増', 'イタクラクイナマス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市板倉区上福田新田', '15', '15222', '9440102', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '板倉区上福田新田', 'イタクラクカミフクダシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市板倉区南四ツ屋新田', '15', '15222', '9440103', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '板倉区南四ツ屋新田', 'イタクラクミナミヨツヤシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市板倉区長塚', '15', '15222', '9440104', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '板倉区長塚', 'イタクラクナガツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市板倉区田屋', '15', '15222', '9440105', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '板倉区田屋', 'イタクラクタヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市板倉区沢田', '15', '15222', '9440106', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '板倉区沢田', 'イタクラクサワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市板倉区坂井', '15', '15222', '9440107', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '板倉区坂井', 'イタクラクサカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市板倉区長嶺', '15', '15222', '9440108', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '板倉区長嶺', 'イタクラクナガミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市板倉区戸狩', '15', '15222', '9440109', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '板倉区戸狩', 'イタクラクトガリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市板倉区宮島', '15', '15222', '9440111', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '板倉区宮島', 'イタクラクミヤジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市板倉区中四ツ屋', '15', '15222', '9440112', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '板倉区中四ツ屋', 'イタクラクナカヨツヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市板倉区別所', '15', '15222', '9440113', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '板倉区別所', 'イタクラクベッショ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市板倉区達野', '15', '15222', '9440114', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '板倉区達野', 'イタクラクタテノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市板倉区玄藤寺新田', '15', '15222', '9440115', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '板倉区玄藤寺新田', 'イタクラクゲンドウジシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市板倉区関田', '15', '15222', '9440116', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '板倉区関田', 'イタクラクセキダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市板倉区筒方', '15', '15222', '9440117', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '板倉区筒方', 'イタクラクドウガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市板倉区栗沢', '15', '15222', '9440118', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '板倉区栗沢', 'イタクラククリザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市板倉区大野新田', '15', '15222', '9440119', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '板倉区大野新田', 'イタクラクオオノシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市板倉区山部', '15', '15222', '9440121', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '板倉区山部', 'イタクラクヤマベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市板倉区中之宮', '15', '15222', '9440122', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '板倉区中之宮', 'イタクラクナカノミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市板倉区釜塚', '15', '15222', '9440123', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '板倉区釜塚', 'イタクラクカマヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市板倉区久々野', '15', '15222', '9440124', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '板倉区久々野', 'イタクラククグノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市板倉区猿供養寺', '15', '15222', '9440125', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '板倉区猿供養寺', 'イタクラクサルクヨウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市板倉区東山寺', '15', '15222', '9440126', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '板倉区東山寺', 'イタクラクヒガシヤマデラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市板倉区不動新田', '15', '15222', '9440127', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '板倉区不動新田', 'イタクラクフドウシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市板倉区機織', '15', '15222', '9440128', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '板倉区機織', 'イタクラクハタオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市板倉区菰立', '15', '15222', '9440129', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '板倉区菰立', 'イタクラクコモダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市板倉区針', '15', '15222', '9440131', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '板倉区針', 'イタクラクハリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市板倉区曽根田', '15', '15222', '9440132', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '板倉区曽根田', 'イタクラクソネダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市板倉区国川', '15', '15222', '9440133', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '板倉区国川', 'イタクラクコクガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市板倉区福王寺', '15', '15222', '9440134', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '板倉区福王寺', 'イタクラクフクオウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市板倉区米増', '15', '15222', '9440135', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '板倉区米増', 'イタクラクヨネマス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市板倉区山越', '15', '15222', '9440136', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '板倉区山越', 'イタクラクヤマゴシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市板倉区吉増', '15', '15222', '9440137', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '板倉区吉増', 'イタクラクヨシマス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市板倉区熊川新田', '15', '15222', '9440138', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '板倉区熊川新田', 'イタクラククマガワシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市板倉区熊川', '15', '15222', '9440139', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '板倉区熊川', 'イタクラククマガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市板倉区田井', '15', '15222', '9440141', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '板倉区田井', 'イタクラクタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市板倉区高野', '15', '15222', '9440142', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '板倉区高野', 'イタクラクタカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市板倉区関根', '15', '15222', '9440143', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '板倉区関根', 'イタクラクセキネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市板倉区下米沢', '15', '15222', '9440144', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '板倉区下米沢', 'イタクラクシモヨネザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市板倉区南中島', '15', '15222', '9440145', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '板倉区南中島', 'イタクラクミナミナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市板倉区小石原', '15', '15222', '9440146', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '板倉区小石原', 'イタクラクコイシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市板倉区上中島新田', '15', '15222', '9440147', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '板倉区上中島新田', 'イタクラクカミナカジマシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市板倉区横町', '15', '15222', '9440148', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '板倉区横町', 'イタクラクヨコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市板倉区下田屋', '15', '15222', '9440149', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '板倉区下田屋', 'イタクラクシモタヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市板倉区青葉', '15', '15222', '9440150', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '板倉区青葉', 'イタクラクアオバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市板倉区緑ケ丘', '15', '15222', '9440151', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '板倉区緑ケ丘', 'イタクラクミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市姫川原', '15', '15217', '9440201', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '姫川原', 'ヒメカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市巻淵', '15', '15217', '9440202', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '巻淵', 'マキブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市下濁川', '15', '15217', '9440203', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '下濁川', 'シモニゴリカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市除戸', '15', '15217', '9440204', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '除戸', 'ノゾキド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市上堀之内', '15', '15217', '9440205', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '上堀之内', 'カミホリノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市和屋', '15', '15217', '9440211', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '和屋', 'ワヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市上濁川', '15', '15217', '9440212', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '上濁川', 'カミニゴリカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市小局', '15', '15217', '9440213', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '小局', 'コツボネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市東菅沼', '15', '15217', '9440214', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '東菅沼', 'ヒガシスガヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市大貝', '15', '15217', '9440215', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '大貝', 'オオガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市大下', '15', '15217', '9440216', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '大下', 'オオシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市中横山', '15', '15217', '9440217', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '中横山', 'ナカヨコヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市小濁', '15', '15217', '9440221', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '小濁', 'コニゴリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市坪山', '15', '15217', '9440222', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '坪山', 'ツボヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市上小沢', '15', '15217', '9440223', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '上小沢', 'カミコザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市大濁', '15', '15217', '9440224', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '大濁', 'オオニゴリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市上馬場', '15', '15217', '9440225', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '上馬場', 'カミババ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市木成', '15', '15217', '9440226', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '木成', 'コナリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市小原新田', '15', '15217', '9440331', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '小原新田', 'コバラシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市大原新田', '15', '15217', '9440332', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '大原新田', 'オオハラシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市大沢新田', '15', '15217', '9440333', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '大沢新田', 'オオサワシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市楡島', '15', '15217', '9440334', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '楡島', 'ニレシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市東関', '15', '15217', '9440335', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '東関', 'ヒガシセキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市猿橋', '15', '15217', '9440341', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '猿橋', 'サルハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市長沢原', '15', '15217', '9440342', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '長沢原', 'ナガサワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市下平丸', '15', '15217', '9440343', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '下平丸', 'シモヒラマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市上平丸', '15', '15217', '9440344', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '上平丸', 'カミヒラマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市長沢', '15', '15217', '9440345', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '長沢', 'ナガサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市', '15', '15205', '9450000', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('130750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市松波', '15', '15205', '9450011', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '松波', 'マツナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市橋場', '15', '15205', '9450012', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '橋場', 'ハシバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市山本', '15', '15205', '9450013', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '山本', 'ヤマモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市橋場町', '15', '15205', '9450014', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '橋場町', 'ハシバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市槇原町', '15', '15205', '9450015', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '槇原町', 'マキハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市青山町', '15', '15205', '9450016', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '青山町', 'アオヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市荒浜', '15', '15205', '9450017', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '荒浜', 'アラハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市上原', '15', '15205', '9450021', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '上原', 'カミハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市東原町', '15', '15205', '9450022', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '東原町', 'ヒガシハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市原町', '15', '15205', '9450023', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '原町', 'ハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市小金町', '15', '15205', '9450024', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '小金町', 'コガネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市柳田町', '15', '15205', '9450025', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '柳田町', 'ヤナギダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市藤元町', '15', '15205', '9450026', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '藤元町', 'フジモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市北斗町', '15', '15205', '9450027', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '北斗町', 'ホクトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市新田畑', '15', '15205', '9450031', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '新田畑', 'シンデンハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市田塚', '15', '15205', '9450032', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '田塚', 'タツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市東長浜町', '15', '15205', '9450033', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '東長浜町', 'ヒガシナガハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市三和町', '15', '15205', '9450034', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '三和町', 'サンワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市北半田', '15', '15205', '9450035', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '北半田', 'キタハンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市東柳田', '15', '15205', '9450036', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '東柳田', 'ヒガシヤナギダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市松美', '15', '15205', '9450041', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '松美', 'マツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市長浜町', '15', '15205', '9450042', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '長浜町', 'ナガハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市日吉町', '15', '15205', '9450043', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '日吉町', 'ヒヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市扇町', '15', '15205', '9450044', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '扇町', 'オウギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市豊町', '15', '15205', '9450045', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '豊町', 'ユタカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市四谷', '15', '15205', '9450046', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '四谷', 'ヨツヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市比角', '15', '15205', '9450047', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '比角', 'ヒスミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市東本町', '15', '15205', '9450051', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '東本町', 'ヒガシホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市錦町', '15', '15205', '9450052', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '錦町', 'ニシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市鏡町', '15', '15205', '9450053', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '鏡町', 'カガミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市日石町', '15', '15205', '9450054', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '日石町', 'ニツセキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市駅前', '15', '15205', '9450055', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '駅前', 'エキマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市新橋', '15', '15205', '9450056', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '新橋', 'シンバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市栄町', '15', '15205', '9450061', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '栄町', 'サカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市新花町', '15', '15205', '9450062', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '新花町', 'シンハナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市諏訪町', '15', '15205', '9450063', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '諏訪町', 'スワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市中央町', '15', '15205', '9450064', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '中央町', 'チュウオウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市学校町', '15', '15205', '9450065', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '学校町', 'ガッコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市西本町', '15', '15205', '9450066', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '西本町', 'ニシホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市西港町', '15', '15205', '9450067', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '西港町', 'ニシミナトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市東港町', '15', '15205', '9450068', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '東港町', 'ヒガシミナトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市安政町', '15', '15205', '9450071', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '安政町', 'アンセイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市北園町', '15', '15205', '9450072', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '北園町', 'キタゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市桜木町', '15', '15205', '9450073', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '桜木町', 'サクラギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市春日', '15', '15205', '9450074', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '春日', 'カスガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市大和町', '15', '15205', '9450075', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '大和町', 'ヤマトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市小倉町', '15', '15205', '9450076', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '小倉町', 'オクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市長崎', '15', '15205', '9450101', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '長崎', 'ナガサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市長崎新田', '15', '15205', '9450102', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '長崎新田', 'ナガサキシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市下大新田', '15', '15205', '9450103', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '下大新田', 'シモオオシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市土合新田', '15', '15205', '9450104', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '土合新田', 'ドアイシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市剣', '15', '15205', '9450105', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '剣', 'ツルギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市土合', '15', '15205', '9450106', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '土合', 'ドアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市与三', '15', '15205', '9450111', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '与三', 'ヨソウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市畔屋', '15', '15205', '9450112', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '畔屋', 'アゼヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市中田', '15', '15205', '9450113', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '中田', 'ナカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市藤井', '15', '15205', '9450114', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '藤井', 'フジイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市小黒須', '15', '15205', '9450211', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '小黒須', 'コグロス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市五十土', '15', '15205', '9450212', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '五十土', 'イカヅチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市成沢', '15', '15205', '9450213', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '成沢', 'ナリサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市曾地', '15', '15205', '9450214', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '曾地', 'ソチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市矢田', '15', '15205', '9450215', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '矢田', 'ヤタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市吉井', '15', '15205', '9450216', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '吉井', 'ヨシイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市曾地新田', '15', '15205', '9450217', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '曾地新田', 'ソチシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市花田', '15', '15205', '9450218', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '花田', 'ハナダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市飯塚', '15', '15205', '9450219', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '飯塚', 'イイヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県刈羽郡刈羽村', '15', '15504', '9450300', '新潟県', 'ニイガタケン', '刈羽郡刈羽村', 'カリワグンカリワムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('130820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県刈羽郡刈羽村入和田', '15', '15504', '9450301', '新潟県', 'ニイガタケン', '刈羽郡刈羽村', 'カリワグンカリワムラ', '入和田', 'イリワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県刈羽郡刈羽村滝谷新田', '15', '15504', '9450302', '新潟県', 'ニイガタケン', '刈羽郡刈羽村', 'カリワグンカリワムラ', '滝谷新田', 'タキヤシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県刈羽郡刈羽村滝谷', '15', '15504', '9450303', '新潟県', 'ニイガタケン', '刈羽郡刈羽村', 'カリワグンカリワムラ', '滝谷', 'タキヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県刈羽郡刈羽村寺尾', '15', '15504', '9450304', '新潟県', 'ニイガタケン', '刈羽郡刈羽村', 'カリワグンカリワムラ', '寺尾', 'テラオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県刈羽郡刈羽村西元寺', '15', '15504', '9450305', '新潟県', 'ニイガタケン', '刈羽郡刈羽村', 'カリワグンカリワムラ', '西元寺', 'サイゲンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県刈羽郡刈羽村十日市', '15', '15504', '9450306', '新潟県', 'ニイガタケン', '刈羽郡刈羽村', 'カリワグンカリワムラ', '十日市', 'トオカイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県刈羽郡刈羽村刈羽', '15', '15504', '9450307', '新潟県', 'ニイガタケン', '刈羽郡刈羽村', 'カリワグンカリワムラ', '刈羽', 'カリワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県刈羽郡刈羽村割町新田', '15', '15504', '9450308', '新潟県', 'ニイガタケン', '刈羽郡刈羽村', 'カリワグンカリワムラ', '割町新田', 'ワリマチシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県刈羽郡刈羽村井岡', '15', '15504', '9450311', '新潟県', 'ニイガタケン', '刈羽郡刈羽村', 'カリワグンカリワムラ', '井岡', 'イノオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県刈羽郡刈羽村西谷', '15', '15504', '9450312', '新潟県', 'ニイガタケン', '刈羽郡刈羽村', 'カリワグンカリワムラ', '西谷', 'ニシダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県刈羽郡刈羽村大塚', '15', '15504', '9450313', '新潟県', 'ニイガタケン', '刈羽郡刈羽村', 'カリワグンカリワムラ', '大塚', 'オオツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県刈羽郡刈羽村新屋敷', '15', '15504', '9450314', '新潟県', 'ニイガタケン', '刈羽郡刈羽村', 'カリワグンカリワムラ', '新屋敷', 'アラヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県刈羽郡刈羽村上高町', '15', '15504', '9450315', '新潟県', 'ニイガタケン', '刈羽郡刈羽村', 'カリワグンカリワムラ', '上高町', 'カミタカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県刈羽郡刈羽村下高町', '15', '15504', '9450316', '新潟県', 'ニイガタケン', '刈羽郡刈羽村', 'カリワグンカリワムラ', '下高町', 'シモタカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県刈羽郡刈羽村正明寺', '15', '15504', '9450317', '新潟県', 'ニイガタケン', '刈羽郡刈羽村', 'カリワグンカリワムラ', '正明寺', 'ショウミョウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県刈羽郡刈羽村油田', '15', '15504', '9450321', '新潟県', 'ニイガタケン', '刈羽郡刈羽村', 'カリワグンカリワムラ', '油田', 'アブラデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県刈羽郡刈羽村黒川', '15', '15504', '9450322', '新潟県', 'ニイガタケン', '刈羽郡刈羽村', 'カリワグンカリワムラ', '黒川', 'クロカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県刈羽郡刈羽村赤田町方', '15', '15504', '9450323', '新潟県', 'ニイガタケン', '刈羽郡刈羽村', 'カリワグンカリワムラ', '赤田町方', 'アカダマチガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県刈羽郡刈羽村枯木', '15', '15504', '9450324', '新潟県', 'ニイガタケン', '刈羽郡刈羽村', 'カリワグンカリワムラ', '枯木', 'カレキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県刈羽郡刈羽村赤田北方', '15', '15504', '9450325', '新潟県', 'ニイガタケン', '刈羽郡刈羽村', 'カリワグンカリワムラ', '赤田北方', 'アカダキタガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市椎谷', '15', '15205', '9450401', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '椎谷', 'シイヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市宮川', '15', '15205', '9450402', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '宮川', 'ミヤガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市大湊', '15', '15205', '9450403', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '大湊', 'オオミナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市岩上', '15', '15205', '9450811', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '岩上', 'イワカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市半田', '15', '15205', '9450812', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '半田', 'ハンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市南半田', '15', '15205', '9450813', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '南半田', 'ミナミハンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市朝日が丘', '15', '15205', '9450814', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '朝日が丘', 'アサヒガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市希望が丘', '15', '15205', '9450815', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '希望が丘', 'キボウガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市田中', '15', '15205', '9450816', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '田中', 'タナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市宝町', '15', '15205', '9450817', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '宝町', 'タカラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市幸町', '15', '15205', '9450821', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市穂波町', '15', '15205', '9450822', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '穂波町', 'ホナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市南光町', '15', '15205', '9450823', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '南光町', 'ナンコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市枇杷島', '15', '15205', '9450824', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '枇杷島', 'ビワジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市城東', '15', '15205', '9450825', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '城東', 'ジョウトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市元城町', '15', '15205', '9450826', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '元城町', 'モトシロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市宮場町', '15', '15205', '9450827', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '宮場町', 'ミヤバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市柳橋町', '15', '15205', '9450831', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '柳橋町', 'ヤナギバシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市関町', '15', '15205', '9450832', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '関町', 'セキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市若葉町', '15', '15205', '9450833', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '若葉町', 'ワカバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市常盤台', '15', '15205', '9450834', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '常盤台', 'トキワダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市剣野町', '15', '15205', '9450835', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '剣野町', 'ケンノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市剣野', '15', '15205', '9450836', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '剣野', 'ケンノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市三島町', '15', '15205', '9450837', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '三島町', 'ミシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市三島西', '15', '15205', '9450838', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '三島西', 'ミシマニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市緑町', '15', '15205', '9450841', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '緑町', 'ミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市米山台', '15', '15205', '9450842', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '米山台', 'ヨネヤマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市米山台東', '15', '15205', '9450843', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '米山台東', 'ヨネヤマダイヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市米山台西', '15', '15205', '9450844', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '米山台西', 'ヨネヤマダイニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市新赤坂', '15', '15205', '9450845', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '新赤坂', 'シンアカサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市寿町', '15', '15205', '9450846', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '寿町', 'コトブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市赤坂町', '15', '15205', '9450847', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '赤坂町', 'アカサカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市大久保', '15', '15205', '9450851', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '大久保', 'オオクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市中浜', '15', '15205', '9450852', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '中浜', 'ナカハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市番神', '15', '15205', '9450853', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '番神', 'バンジン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市東の輪町', '15', '15205', '9450854', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '東の輪町', 'トウノワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市鯨波', '15', '15205', '9450855', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '鯨波', 'クジラナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市谷根', '15', '15205', '9450857', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '谷根', 'タンネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市小杉', '15', '15205', '9450858', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '小杉', 'コスギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市横山', '15', '15205', '9451101', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '横山', 'ヨコヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市向陽町', '15', '15205', '9451102', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '向陽町', 'コウヨウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市藤橋', '15', '15205', '9451103', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '藤橋', 'フジハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市下方', '15', '15205', '9451104', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '下方', 'シモガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市長峰町', '15', '15205', '9451105', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '長峰町', 'ナガミネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市ゆりが丘', '15', '15205', '9451106', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', 'ゆりが丘', 'ユリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市堀', '15', '15205', '9451111', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '堀', 'ホリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市南下', '15', '15205', '9451112', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '南下', 'ノウゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市古町', '15', '15205', '9451113', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '古町', 'フルマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市芋川', '15', '15205', '9451114', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '芋川', 'イモガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市佐水', '15', '15205', '9451115', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '佐水', 'サミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市山口', '15', '15205', '9451116', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '山口', 'ヤマグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市宮之窪', '15', '15205', '9451117', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '宮之窪', 'ミヤノクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市上条', '15', '15205', '9451118', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '上条', 'ジョウジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市上方', '15', '15205', '9451121', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '上方', 'カミガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市新道', '15', '15205', '9451122', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '新道', 'シンドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市貝渕', '15', '15205', '9451123', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '貝渕', 'カイブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市黒滝', '15', '15205', '9451124', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '黒滝', 'クロタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市小田山新田', '15', '15205', '9451125', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '小田山新田', 'コダヤマシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市大河内新田', '15', '15205', '9451126', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '大河内新田', 'オオコウチシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市野田', '15', '15205', '9451241', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '野田', 'ノタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市細越', '15', '15205', '9451242', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '細越', 'ホソゴエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市久米', '15', '15205', '9451243', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '久米', 'クンメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市水上', '15', '15205', '9451244', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '水上', 'ミズカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市宮川新田', '15', '15205', '9451245', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '宮川新田', 'ミヤガワシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市清水谷', '15', '15205', '9451246', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '清水谷', 'シミズタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市木沢', '15', '15205', '9451247', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '木沢', 'キザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市田屋', '15', '15205', '9451248', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '田屋', 'タヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市市野新田', '15', '15205', '9451251', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '市野新田', 'イチノシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市女谷', '15', '15205', '9451252', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '女谷', 'オナダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市折居', '15', '15205', '9451253', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '折居', 'オリイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市茨目', '15', '15205', '9451341', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '茨目', 'イバラメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市三和町', '15', '15205', '9451342', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '三和町', 'サンワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市城塚', '15', '15205', '9451343', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '城塚', 'ジョウヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市両田尻', '15', '15205', '9451344', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '両田尻', 'リョウタジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市下田尻', '15', '15205', '9451345', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '下田尻', 'シモタジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市上田尻', '15', '15205', '9451351', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '上田尻', 'カミタジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市安田', '15', '15205', '9451352', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '安田', 'ヤスダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市平井', '15', '15205', '9451353', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '平井', 'ヒライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市佐藤池新田', '15', '15205', '9451354', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '佐藤池新田', 'サトウガイケシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市軽井川', '15', '15205', '9451355', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '軽井川', 'カルイガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市加納', '15', '15205', '9451431', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '加納', 'カノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市善根', '15', '15205', '9451432', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '善根', 'ゼゴン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市与板', '15', '15205', '9451433', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '与板', 'ヨイタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市宮平', '15', '15205', '9451434', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '宮平', 'ミヤダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市森近', '15', '15205', '9451435', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '森近', 'モリチカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市石曾根', '15', '15205', '9451436', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '石曾根', 'イシゾネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市山室', '15', '15205', '9451437', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '山室', 'ヤマムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市大沢', '15', '15205', '9451438', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '大沢', 'オオサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市高柳町岡田', '15', '15205', '9451501', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '高柳町岡田', 'タカヤナギチョウオカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市高柳町岡野町', '15', '15205', '9451502', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '高柳町岡野町', 'タカヤナギチョウオカノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市高柳町山中', '15', '15205', '9451503', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '高柳町山中', 'タカヤナギチョウヤマナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市高柳町栃ケ原', '15', '15205', '9451504', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '高柳町栃ケ原', 'タカヤナギチョウトチガハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市高柳町高尾', '15', '15205', '9451505', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '高柳町高尾', 'タカヤナギチョウタカオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市高柳町漆島', '15', '15205', '9451511', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '高柳町漆島', 'タカヤナギチョウウルシジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市高柳町荻ノ島', '15', '15205', '9451512', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '高柳町荻ノ島', 'タカヤナギチョウオギノシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市高柳町門出', '15', '15205', '9451513', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '高柳町門出', 'タカヤナギチョウカドイデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市高柳町田代', '15', '15205', '9451514', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '高柳町田代', 'タカヤナギチョウタシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市高柳町石黒', '15', '15205', '9451515', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '高柳町石黒', 'タカヤナギチョウイシグロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市', '15', '15225', '9460000', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('130958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市日渡新田', '15', '15225', '9460001', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '日渡新田', 'ヒワタシシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市稲荷町', '15', '15225', '9460002', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '稲荷町', 'イナリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市諏訪町', '15', '15225', '9460003', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '諏訪町', 'スワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市大塚新田', '15', '15225', '9460004', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '大塚新田', 'オオヅカシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市横町', '15', '15225', '9460005', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '横町', 'ヨコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市中之島', '15', '15225', '9460006', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '中之島', 'ナカノシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市四日町', '15', '15225', '9460007', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '四日町', 'ヨッカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市小出島', '15', '15225', '9460011', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '小出島', 'コイデジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市浦町', '15', '15225', '9460012', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '浦町', 'ウラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市佐梨', '15', '15225', '9460021', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '佐梨', 'サナシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市上原', '15', '15225', '9460022', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '上原', 'カミハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市干溝', '15', '15225', '9460023', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '干溝', 'ヒミゾ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市中原', '15', '15225', '9460024', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '中原', 'ナカハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市古新田', '15', '15225', '9460025', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '古新田', 'コシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市原虫野', '15', '15225', '9460031', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '原虫野', 'ハラムシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市板木', '15', '15225', '9460032', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '板木', 'イタギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市大浦', '15', '15225', '9460033', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '大浦', 'オオウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市大浦新田', '15', '15225', '9460034', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '大浦新田', 'オオウラシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市十日町', '15', '15225', '9460035', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '十日町', 'トオカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市岡新田', '15', '15225', '9460036', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '岡新田', 'オカシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市虫野', '15', '15225', '9460037', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '虫野', 'ムシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市伊勢島', '15', '15225', '9460038', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '伊勢島', 'イセジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市本町', '15', '15225', '9460041', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市柳原', '15', '15225', '9460042', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '柳原', 'ヤナギハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市青島', '15', '15225', '9460043', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '青島', 'アオシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市今泉', '15', '15225', '9460051', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '今泉', 'イマイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市江口', '15', '15225', '9460052', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '江口', 'エグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市江口新田', '15', '15225', '9460052', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '江口新田', 'エグチシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市長松', '15', '15225', '9460053', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '長松', 'ナガマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市米沢', '15', '15225', '9460054', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '米沢', 'ヨネザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市山田', '15', '15225', '9460055', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '山田', 'ヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市山田下', '15', '15225', '9460056', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '山田下', 'ヤマダシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市中島', '15', '15225', '9460057', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '中島', 'ナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市中島新田', '15', '15225', '9460058', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '中島新田', 'ナカジマシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市新保', '15', '15225', '9460061', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '新保', 'シンボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市新保新田', '15', '15225', '9460061', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '新保新田', 'シンボシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市一日市', '15', '15225', '9460062', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '一日市', 'ヒトイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市中家', '15', '15225', '9460063', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '中家', 'チュウカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市中家新田', '15', '15225', '9460063', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '中家新田', 'チュウカシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市池平', '15', '15225', '9460064', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '池平', 'イケダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市池平新田', '15', '15225', '9460064', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '池平新田', 'イケダイラシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('130999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市中子沢', '15', '15225', '9460065', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '中子沢', 'チュウシザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市三ツ又', '15', '15225', '9460066', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '三ツ又', 'ミツマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市七日市', '15', '15225', '9460071', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '七日市', 'ナノカイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市七日市新田', '15', '15225', '9460072', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '七日市新田', 'ナノカイチシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市大沢', '15', '15225', '9460073', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '大沢', 'オオサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市吉田', '15', '15225', '9460075', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '吉田', 'ヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市井口新田', '15', '15225', '9460076', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '井口新田', 'イノクチシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市葎沢', '15', '15225', '9460081', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '葎沢', 'ムグラザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市湯之谷芋川', '15', '15225', '9460082', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '湯之谷芋川', 'ユノタニイモガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市蓑和田', '15', '15225', '9460083', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '蓑和田', 'ミノワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市宇津野', '15', '15225', '9460084', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '宇津野', 'ウツノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市下折立', '15', '15225', '9460085', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '下折立', 'シモオリタテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市折立又新田', '15', '15225', '9460086', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '折立又新田', 'オリタテマタシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市上折立', '15', '15225', '9460087', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '上折立', 'カミオリタテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市大湯温泉', '15', '15225', '9460088', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '大湯温泉', 'オオユオンセン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市小平尾', '15', '15225', '9460101', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '小平尾', 'オビロオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市外山', '15', '15225', '9460102', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '外山', 'ソデヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市滝之又', '15', '15225', '9460103', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '滝之又', 'タキノマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市栗山', '15', '15225', '9460104', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '栗山', 'クリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市金ケ沢', '15', '15225', '9460105', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '金ケ沢', 'カネガサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市宮沢新田', '15', '15225', '9460105', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '宮沢新田', 'ミヤザワシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市田中', '15', '15225', '9460106', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '田中', 'タナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市雁坂下', '15', '15225', '9460107', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '雁坂下', 'ガンザカシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市清本', '15', '15225', '9460107', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '清本', 'キヨモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市下田', '15', '15225', '9460107', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '下田', 'シモダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市長堀新田', '15', '15225', '9460107', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '長堀新田', 'ナガホリシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市横瀬', '15', '15225', '9460107', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '横瀬', 'ヨコゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市親柄', '15', '15225', '9460108', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '親柄', 'オヤガラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市和田', '15', '15225', '9460109', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '和田', 'ワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市並柳', '15', '15225', '9460111', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '並柳', 'ナミヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市田尻', '15', '15225', '9460112', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '田尻', 'タジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市東中', '15', '15225', '9460113', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '東中', 'ヒガシナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市泉沢', '15', '15225', '9460114', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '泉沢', 'イズミサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市山口', '15', '15225', '9460115', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '山口', 'ヤマグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市小庭名', '15', '15225', '9460121', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '小庭名', 'コテンミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市小庭名新田', '15', '15225', '9460121', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '小庭名新田', 'コテンミョウシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市吉平', '15', '15225', '9460121', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '吉平', 'ヨシダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市連日', '15', '15225', '9460121', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '連日', 'レンニチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市吉原', '15', '15225', '9460122', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '吉原', 'ヨシワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市水沢', '15', '15225', '9460123', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '水沢', 'ミズサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市茂沢', '15', '15225', '9460123', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '茂沢', 'モサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市大芋川', '15', '15225', '9460124', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '大芋川', 'オオイモガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市越又', '15', '15225', '9460125', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '越又', 'コシマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市高倉', '15', '15225', '9460201', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '高倉', 'タカクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市東野名', '15', '15225', '9460202', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '東野名', 'ヒガシノミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市渋川', '15', '15225', '9460203', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '渋川', 'シブカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市西名', '15', '15225', '9460204', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '西名', 'ニシミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市宮椿新田', '15', '15225', '9460205', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '宮椿新田', 'ミヤツバキシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市西名新田', '15', '15225', '9460206', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '西名新田', 'ニシミョウシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市福山新田', '15', '15225', '9460207', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '福山新田', 'フクヤマシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市上長鳥新田', '15', '15225', '9460211', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '上長鳥新田', 'カミナガトリシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市長鳥', '15', '15225', '9460212', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '長鳥', 'ナガトリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市細野', '15', '15225', '9460213', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '細野', 'ホソノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市松川', '15', '15225', '9460214', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '松川', 'マツカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市大原新田', '15', '15225', '9460215', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '大原新田', 'オオハラシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市須原', '15', '15225', '9460216', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '須原', 'スハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市須川', '15', '15225', '9460221', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '須川', 'スガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市福田新田', '15', '15225', '9460222', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '福田新田', 'フクダシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市大倉沢', '15', '15225', '9460223', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '大倉沢', 'オオクラサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市赤土', '15', '15225', '9460224', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '赤土', 'アカツチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市三渕沢', '15', '15225', '9460225', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '三渕沢', 'ミフチサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市大倉', '15', '15225', '9460226', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '大倉', 'オオクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市田小屋', '15', '15225', '9460301', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '田小屋', 'タゴヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市芋鞘', '15', '15225', '9460302', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '芋鞘', 'イモザヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市大白川', '15', '15225', '9460303', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '大白川', 'オオシラカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市穴沢', '15', '15225', '9460304', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '穴沢', 'アナザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市大栃山', '15', '15225', '9460305', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '大栃山', 'オオトチヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市平野又', '15', '15225', '9460306', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '平野又', 'ヒラノマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市横根', '15', '15225', '9460307', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '横根', 'ヨコネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県小千谷市', '15', '15208', '9470000', '新潟県', 'ニイガタケン', '小千谷市', 'オヂヤシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('131074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県小千谷市浦柄', '15', '15208', '9470001', '新潟県', 'ニイガタケン', '小千谷市', 'オヂヤシ', '浦柄', 'ウラガラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県小千谷市横渡', '15', '15208', '9470002', '新潟県', 'ニイガタケン', '小千谷市', 'オヂヤシ', '横渡', 'ヨコワタシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県小千谷市ひ生', '15', '15208', '9470003', '新潟県', 'ニイガタケン', '小千谷市', 'オヂヤシ', 'ひ生', 'ヒウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県小千谷市東栄', '15', '15208', '9470004', '新潟県', 'ニイガタケン', '小千谷市', 'オヂヤシ', '東栄', 'トウエイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県小千谷市旭町', '15', '15208', '9470005', '新潟県', 'ニイガタケン', '小千谷市', 'オヂヤシ', '旭町', 'アサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県小千谷市栄町', '15', '15208', '9470011', '新潟県', 'ニイガタケン', '小千谷市', 'オヂヤシ', '栄町', 'サカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県小千谷市山本', '15', '15208', '9470012', '新潟県', 'ニイガタケン', '小千谷市', 'オヂヤシ', '山本', 'ヤマモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県小千谷市上片貝', '15', '15208', '9470013', '新潟県', 'ニイガタケン', '小千谷市', 'オヂヤシ', '上片貝', 'カミガタカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県小千谷市西中', '15', '15208', '9470014', '新潟県', 'ニイガタケン', '小千谷市', 'オヂヤシ', '西中', 'ニシナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県小千谷市谷内', '15', '15208', '9470015', '新潟県', 'ニイガタケン', '小千谷市', 'オヂヤシ', '谷内', 'ヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県小千谷市四ツ子', '15', '15208', '9470016', '新潟県', 'ニイガタケン', '小千谷市', 'オヂヤシ', '四ツ子', 'ヨツコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県小千谷市東吉谷', '15', '15208', '9470017', '新潟県', 'ニイガタケン', '小千谷市', 'オヂヤシ', '東吉谷', 'ヒガシヨシダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県小千谷市西吉谷', '15', '15208', '9470018', '新潟県', 'ニイガタケン', '小千谷市', 'オヂヤシ', '西吉谷', 'ニシヨシダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県小千谷市本町', '15', '15208', '9470021', '新潟県', 'ニイガタケン', '小千谷市', 'オヂヤシ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県小千谷市元町', '15', '15208', '9470022', '新潟県', 'ニイガタケン', '小千谷市', 'オヂヤシ', '元町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県小千谷市日吉', '15', '15208', '9470023', '新潟県', 'ニイガタケン', '小千谷市', 'オヂヤシ', '日吉', 'ヒヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県小千谷市船岡', '15', '15208', '9470024', '新潟県', 'ニイガタケン', '小千谷市', 'オヂヤシ', '船岡', 'フナオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県小千谷市稲荷町', '15', '15208', '9470025', '新潟県', 'ニイガタケン', '小千谷市', 'オヂヤシ', '稲荷町', 'イナリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県小千谷市上ノ山', '15', '15208', '9470026', '新潟県', 'ニイガタケン', '小千谷市', 'オヂヤシ', '上ノ山', 'ウエノヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県小千谷市平成', '15', '15208', '9470027', '新潟県', 'ニイガタケン', '小千谷市', 'オヂヤシ', '平成', 'ヘイセイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県小千谷市城内', '15', '15208', '9470028', '新潟県', 'ニイガタケン', '小千谷市', 'オヂヤシ', '城内', 'ジョウナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県小千谷市土川', '15', '15208', '9470031', '新潟県', 'ニイガタケン', '小千谷市', 'オヂヤシ', '土川', 'ツチカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県小千谷市薮川', '15', '15208', '9470032', '新潟県', 'ニイガタケン', '小千谷市', 'オヂヤシ', '薮川', 'ヤブカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県小千谷市時水', '15', '15208', '9470033', '新潟県', 'ニイガタケン', '小千谷市', 'オヂヤシ', '時水', 'トキミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県小千谷市両新田', '15', '15208', '9470034', '新潟県', 'ニイガタケン', '小千谷市', 'オヂヤシ', '両新田', 'リョウシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県小千谷市桜町', '15', '15208', '9470035', '新潟県', 'ニイガタケン', '小千谷市', 'オヂヤシ', '桜町', 'サクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県小千谷市小粟田', '15', '15208', '9470041', '新潟県', 'ニイガタケン', '小千谷市', 'オヂヤシ', '小粟田', 'コワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県小千谷市平沢', '15', '15208', '9470042', '新潟県', 'ニイガタケン', '小千谷市', 'オヂヤシ', '平沢', 'ヒラサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県小千谷市平沢新田', '15', '15208', '9470042', '新潟県', 'ニイガタケン', '小千谷市', 'オヂヤシ', '平沢新田', 'ヒラサワシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県小千谷市山谷', '15', '15208', '9470043', '新潟県', 'ニイガタケン', '小千谷市', 'オヂヤシ', '山谷', 'ヤマヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県小千谷市坪野', '15', '15208', '9470044', '新潟県', 'ニイガタケン', '小千谷市', 'オヂヤシ', '坪野', 'ツボノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県小千谷市鴻巣町', '15', '15208', '9470045', '新潟県', 'ニイガタケン', '小千谷市', 'オヂヤシ', '鴻巣町', 'コウノスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県小千谷市三仏生', '15', '15208', '9470051', '新潟県', 'ニイガタケン', '小千谷市', 'オヂヤシ', '三仏生', 'サンブショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県小千谷市千谷', '15', '15208', '9470052', '新潟県', 'ニイガタケン', '小千谷市', 'オヂヤシ', '千谷', 'チヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県小千谷市千谷川', '15', '15208', '9470053', '新潟県', 'ニイガタケン', '小千谷市', 'オヂヤシ', '千谷川', 'チヤガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県小千谷市若葉', '15', '15208', '9470054', '新潟県', 'ニイガタケン', '小千谷市', 'オヂヤシ', '若葉', 'ワカバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県小千谷市片貝町', '15', '15208', '9470101', '新潟県', 'ニイガタケン', '小千谷市', 'オヂヤシ', '片貝町', 'カタカイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県小千谷市高梨町', '15', '15208', '9470102', '新潟県', 'ニイガタケン', '小千谷市', 'オヂヤシ', '高梨町', 'タカナシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県小千谷市片貝山屋町', '15', '15208', '9470103', '新潟県', 'ニイガタケン', '小千谷市', 'オヂヤシ', '片貝山屋町', 'カタカイヤマヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市山古志種苧原', '15', '15202', '9470201', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '山古志種苧原', 'ヤマコシタネスハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市山古志南平', '15', '15202', '9470202', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '山古志南平', 'ヤマコシナンペイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市山古志東竹沢', '15', '15202', '9470203', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '山古志東竹沢', 'ヤマコシヒガシタケザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市山古志竹沢', '15', '15202', '9470204', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '山古志竹沢', 'ヤマコシタケザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市山古志虫亀', '15', '15202', '9470205', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '山古志虫亀', 'ヤマコシムシガメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県小千谷市小栗山', '15', '15208', '9470211', '新潟県', 'ニイガタケン', '小千谷市', 'オヂヤシ', '小栗山', 'コグリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県小千谷市南荷頃', '15', '15208', '9470212', '新潟県', 'ニイガタケン', '小千谷市', 'オヂヤシ', '南荷頃', 'ミナミニゴロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県小千谷市塩谷', '15', '15208', '9470213', '新潟県', 'ニイガタケン', '小千谷市', 'オヂヤシ', '塩谷', 'シオダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市', '15', '15210', '9480000', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('131133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市五軒新田', '15', '15210', '9480001', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '五軒新田', 'ゴケンシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市三和町', '15', '15210', '9480002', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '三和町', 'サンワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市本町6丁目', '15', '15210', '9480003', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '本町', 'ホンチョウ', null, null, '6丁目', '06チョウメ');
INSERT INTO `ms_addresses` VALUES ('131136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市本町7丁目', '15', '15210', '9480003', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '本町', 'ホンチョウ', null, null, '7丁目', '07チョウメ');
INSERT INTO `ms_addresses` VALUES ('131137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市下川原町', '15', '15210', '9480004', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '下川原町', 'シモガワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市南新田町', '15', '15210', '9480005', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '南新田町', 'ミナミシンデンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市四日町', '15', '15210', '9480006', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '四日町', 'ヨッカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市四日町新田', '15', '15210', '9480007', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '四日町新田', 'ヨッカマチシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市尾崎', '15', '15210', '9480008', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '尾崎', 'オサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市新座', '15', '15210', '9480011', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '新座', 'シンザ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市新座', '15', '15210', '9480012', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '新座', 'シンザ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市川原町', '15', '15210', '9480013', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '川原町', 'カワハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市江道', '15', '15210', '9480014', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '江道', 'エドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市猿倉', '15', '15210', '9480015', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '猿倉', 'サルクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市津池', '15', '15210', '9480016', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '津池', 'ツイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市菅沼', '15', '15210', '9480017', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '菅沼', 'スガヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市大池', '15', '15210', '9480018', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '大池', 'オオイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市十日町赤倉', '15', '15210', '9480019', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '十日町赤倉', 'トオカマチアカクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市田川町', '15', '15210', '9480021', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '田川町', 'タガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市学校町', '15', '15210', '9480022', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '学校町', 'ガッコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市宮下町', '15', '15210', '9480023', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '宮下町', 'ミヤシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市諏訪町', '15', '15210', '9480024', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '諏訪町', 'スワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市神明町', '15', '15210', '9480025', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '神明町', 'シンメイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市水野町', '15', '15210', '9480026', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '水野町', 'ミズノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市若宮町', '15', '15210', '9480027', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '若宮町', 'ワカミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市田中町', '15', '15210', '9480028', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '田中町', 'タナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市上川町', '15', '15210', '9480029', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '上川町', 'カミカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市山本町', '15', '15210', '9480031', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '山本町', 'ヤマモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市関根', '15', '15210', '9480032', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '関根', 'セキネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市八箇', '15', '15210', '9480033', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '八箇', 'ハッカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市二ツ屋', '15', '15210', '9480034', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '二ツ屋', 'フタツヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市川治下町', '15', '15210', '9480035', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '川治下町', 'カワジシモチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市川治', '15', '15210', '9480036', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '川治', 'カワジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市妻有町', '15', '15210', '9480037', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '妻有町', 'ツマアリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市河内町', '15', '15210', '9480038', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '河内町', 'カワウチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市塩ノ又', '15', '15210', '9480039', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '塩ノ又', 'シオノマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市北新田', '15', '15210', '9480041', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '北新田', 'キタシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市中村', '15', '15210', '9480042', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '中村', 'ナカムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市六箇山谷', '15', '15210', '9480043', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '六箇山谷', 'ロッカヤマヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市田麦', '15', '15210', '9480044', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '田麦', 'タムギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市麻畑', '15', '15210', '9480045', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '麻畑', 'アサバタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市明石町', '15', '15210', '9480046', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '明石町', 'アカシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市城之古', '15', '15210', '9480047', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '城之古', 'タテノコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市谷内丑', '15', '15210', '9480048', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '谷内丑', 'ヤチウシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市船坂', '15', '15210', '9480049', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '船坂', 'フナザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市寿町', '15', '15210', '9480051', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '寿町', 'コトブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市美雪町', '15', '15210', '9480052', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '美雪町', 'ミユキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市錦町', '15', '15210', '9480053', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '錦町', 'ニシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市塚原町', '15', '15210', '9480054', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '塚原町', 'ツカハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市高山', '15', '15210', '9480055', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '高山', 'タカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市高田町4丁目', '15', '15210', '9480056', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '高田町', 'タカダチョウ', null, null, '4丁目', '04チョウメ');
INSERT INTO `ms_addresses` VALUES ('131184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市高田町5丁目', '15', '15210', '9480056', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '高田町', 'タカダチョウ', null, null, '5丁目', '05チョウメ');
INSERT INTO `ms_addresses` VALUES ('131185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市高田町6丁目', '15', '15210', '9480056', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '高田町', 'タカダチョウ', null, null, '6丁目', '06チョウメ');
INSERT INTO `ms_addresses` VALUES ('131186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市春日町', '15', '15210', '9480057', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '春日町', 'カスガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市桜木町', '15', '15210', '9480058', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '桜木町', 'サクラギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市昭和町', '15', '15210', '9480061', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '昭和町', 'ショウワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市泉町', '15', '15210', '9480062', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '泉町', 'イズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市高田町1丁目', '15', '15210', '9480063', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '高田町', 'タカダチョウ', null, null, '1丁目', '01チョウメ');
INSERT INTO `ms_addresses` VALUES ('131191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市高田町2丁目', '15', '15210', '9480064', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '高田町', 'タカダチョウ', null, null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('131192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市高田町3丁目', '15', '15210', '9480065', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '高田町', 'タカダチョウ', null, null, '3丁目', '03チョウメ');
INSERT INTO `ms_addresses` VALUES ('131193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市袋町', '15', '15210', '9480066', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '袋町', 'フクロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市千歳町', '15', '15210', '9480067', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '千歳町', 'チトセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市十日町栄町', '15', '15210', '9480068', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '十日町栄町', 'トオカマチサカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市八幡田町', '15', '15210', '9480071', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '八幡田町', 'ハチマンダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市西本町', '15', '15210', '9480072', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '西本町', 'ニシホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市稲荷町', '15', '15210', '9480073', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '稲荷町', 'イナリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市西浦町', '15', '15210', '9480074', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '西浦町', 'ニシウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市丸山町', '15', '15210', '9480075', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '丸山町', 'マルヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市住吉町', '15', '15210', '9480076', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '住吉町', 'スミヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市島', '15', '15210', '9480077', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '島', 'シマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市千代田町', '15', '15210', '9480078', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '千代田町', 'チヨダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市本町5丁目', '15', '15210', '9480081', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '本町', 'ホンチョウ', null, null, '5丁目', '05チョウメ');
INSERT INTO `ms_addresses` VALUES ('131205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市本町2丁目', '15', '15210', '9480082', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '本町', 'ホンチョウ', null, null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('131206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市本町3丁目', '15', '15210', '9480082', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '本町', 'ホンチョウ', null, null, '3丁目', '03チョウメ');
INSERT INTO `ms_addresses` VALUES ('131207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市本町4丁目', '15', '15210', '9480082', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '本町', 'ホンチョウ', null, null, '4丁目', '04チョウメ');
INSERT INTO `ms_addresses` VALUES ('131208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市本町1丁目', '15', '15210', '9480083', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '本町', 'ホンチョウ', null, null, '1丁目', '01チョウメ');
INSERT INTO `ms_addresses` VALUES ('131209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市本町西1丁目', '15', '15210', '9480083', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '本町西', 'ホンチョウニシ', null, null, '1丁目', '01チョウメ');
INSERT INTO `ms_addresses` VALUES ('131210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市本町東1丁目', '15', '15210', '9480083', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '本町東', 'ホンチョウヒガシ', null, null, '1丁目', '01チョウメ');
INSERT INTO `ms_addresses` VALUES ('131211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市七軒町', '15', '15210', '9480084', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '七軒町', 'シチケンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市西寺町', '15', '15210', '9480085', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '西寺町', 'ニシデラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市加賀糸屋町', '15', '15210', '9480086', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '加賀糸屋町', 'カガイトヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市関口樋口町', '15', '15210', '9480087', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '関口樋口町', 'セキグチヒグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市駅通り', '15', '15210', '9480088', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '駅通り', 'エキドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市稲葉', '15', '15210', '9480101', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '稲葉', 'イナバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市山谷', '15', '15210', '9480102', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '山谷', 'ヤマヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市小泉', '15', '15210', '9480103', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '小泉', 'コイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市樽沢', '15', '15210', '9480104', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '樽沢', 'タルサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市北鐙坂', '15', '15210', '9480105', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '北鐙坂', 'キタアブザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市南鐙坂', '15', '15210', '9480106', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '南鐙坂', 'ミナミアブザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市高島', '15', '15210', '9480107', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '高島', 'タカシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市真田甲', '15', '15210', '9480111', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '真田甲', 'サナダコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市真田乙', '15', '15210', '9480112', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '真田乙', 'サナダオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市真田丁', '15', '15210', '9480113', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '真田丁', 'サナダテイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市真田丙', '15', '15210', '9480114', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '真田丙', 'サナダヘイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市新町新田', '15', '15210', '9480121', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '新町新田', 'アラマチシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市上野', '15', '15210', '9480122', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '上野', 'ウエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市下平新田', '15', '15210', '9480123', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '下平新田', 'シタダイラシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市三領', '15', '15210', '9480124', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '三領', 'サンリョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市小根岸', '15', '15210', '9480125', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '小根岸', 'コネギシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市伊勢平治', '15', '15210', '9480131', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '伊勢平治', 'イセヘイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市友重', '15', '15210', '9480132', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '友重', 'トモシゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市沖立', '15', '15210', '9480133', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '沖立', 'オキダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市上新井', '15', '15210', '9480134', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '上新井', 'カミアライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市中屋敷', '15', '15210', '9480135', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '中屋敷', 'ナカヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市高原田', '15', '15210', '9480136', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '高原田', 'タカハラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市霜条', '15', '15210', '9480141', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '霜条', 'シモジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市東善寺', '15', '15210', '9480142', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '東善寺', 'トウゼンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市山野田', '15', '15210', '9480143', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '山野田', 'ヤマノタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市水口沢', '15', '15210', '9480144', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '水口沢', 'ミナクチザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市坪山', '15', '15210', '9480145', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '坪山', 'ツボヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市鶴吉', '15', '15210', '9480146', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '鶴吉', 'ツルヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市大倉', '15', '15210', '9480211', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '大倉', 'オオクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市岩瀬', '15', '15210', '9480212', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '岩瀬', 'イワセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市赤谷', '15', '15210', '9480213', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '赤谷', 'アカタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市中仙田', '15', '15210', '9480214', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '中仙田', 'ナカセンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市田戸', '15', '15210', '9480215', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '田戸', 'タド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市室島', '15', '15210', '9480216', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '室島', 'ムロジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市高倉', '15', '15210', '9480217', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '高倉', 'タカクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市小脇', '15', '15210', '9480218', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '小脇', 'コワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市越ケ沢', '15', '15210', '9480219', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '越ケ沢', 'コシガサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市野口', '15', '15210', '9480301', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '野口', 'ノグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市仁田', '15', '15210', '9480302', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '仁田', 'ニタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市寺ケ崎', '15', '15210', '9480303', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '寺ケ崎', 'テラガサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市木落', '15', '15210', '9480304', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '木落', 'キオトシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市大白倉', '15', '15210', '9480305', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '大白倉', 'オオジラクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市小白倉', '15', '15210', '9480306', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '小白倉', 'コジラクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市市振', '15', '15216', '9490111', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '市振', 'イチブリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市上路', '15', '15216', '9490112', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '上路', 'アゲロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市須沢', '15', '15216', '9490301', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '須沢', 'スザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市今村新田', '15', '15216', '9490302', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '今村新田', 'イマムラシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市田海', '15', '15216', '9490303', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '田海', 'トウミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市寺地', '15', '15216', '9490304', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '寺地', 'テラジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市青海', '15', '15216', '9490305', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '青海', 'オウミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市橋立', '15', '15216', '9490306', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '橋立', 'ハシダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市歌', '15', '15216', '9490307', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '歌', 'ウタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市外波', '15', '15216', '9490308', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '外波', 'トナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市西山大前', '15', '15216', '9490461', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '西山', 'ニシヤマ', null, null, '大前', 'オオマエ');
INSERT INTO `ms_addresses` VALUES ('131310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市小滝', '15', '15216', '9490462', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '小滝', 'コタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市山之坊', '15', '15216', '9490463', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '山之坊', 'ヤマノボウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市大所', '15', '15216', '9490464', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '大所', 'オオトコロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市東中', '15', '15216', '9490531', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '東中', 'ヒガシナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市上野', '15', '15216', '9490532', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '上野', 'ウワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市大工屋敷', '15', '15216', '9490533', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '大工屋敷', 'ダイクヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市和泉', '15', '15216', '9490534', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '和泉', 'イズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市栗山', '15', '15216', '9490535', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '栗山', 'クリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市根小屋', '15', '15216', '9490536', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '根小屋', 'ネゴヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市上沢', '15', '15216', '9490541', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '上沢', 'カミザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市大神堂', '15', '15216', '9490542', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '大神堂', 'ダイジンドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市山寺', '15', '15216', '9490543', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '山寺', 'ヤマデラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市梶山', '15', '15216', '9490544', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '梶山', 'カジヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市大久保', '15', '15216', '9490545', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '大久保', 'オオクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市上野山', '15', '15216', '9490551', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '上野山', 'ウエノヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市蒲池', '15', '15216', '9490552', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '蒲池', 'ガマイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市上横', '15', '15216', '9490553', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '上横', 'ウエヨコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市山口', '15', '15216', '9490554', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '山口', 'ヤマグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市別所', '15', '15216', '9490555', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '別所', 'ベッショ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市杉之当', '15', '15216', '9490556', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '杉之当', 'スギノトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市西山', '15', '15216', '9490557', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '西山', 'ニシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市余所', '15', '15216', '9490558', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '余所', 'ヨショ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市越', '15', '15216', '9491201', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '越', 'コシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市宮平', '15', '15216', '9491202', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '宮平', 'ミヤダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市中野', '15', '15216', '9491203', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '中野', 'ナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市中林', '15', '15216', '9491204', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '中林', 'ナカバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市土塩', '15', '15216', '9491205', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '土塩', 'ツチシオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市猿倉', '15', '15216', '9491206', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '猿倉', 'サルクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市吹原', '15', '15216', '9491207', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '吹原', 'フキハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市坪野', '15', '15216', '9491208', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '坪野', 'ツボノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市五十原', '15', '15216', '9491211', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '五十原', 'イカハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市東塚', '15', '15216', '9491212', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '東塚', 'ヒガシツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市西塚', '15', '15216', '9491213', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '西塚', 'ニシツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市見滝', '15', '15216', '9491214', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '見滝', 'ミタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市谷根', '15', '15216', '9491215', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '谷根', 'タンネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市大平', '15', '15216', '9491221', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '大平', 'オオダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市土倉', '15', '15216', '9491222', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '土倉', 'ツチクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市中川原新田', '15', '15216', '9491223', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '中川原新田', 'ナカガワラシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市砂場', '15', '15216', '9491224', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '砂場', 'スナバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市角間', '15', '15216', '9491225', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '角間', 'カクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市北山', '15', '15216', '9491226', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '北山', 'キタヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市徳合', '15', '15216', '9491301', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '徳合', 'トクアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市仙納', '15', '15216', '9491302', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '仙納', 'センノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市大洞', '15', '15216', '9491303', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '大洞', 'オオホラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市百川', '15', '15216', '9491304', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '百川', 'モモガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市藤崎', '15', '15216', '9491305', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '藤崎', 'トウザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市筒石', '15', '15216', '9491306', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '筒石', 'ツツイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市高倉', '15', '15216', '9491311', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '高倉', 'タカクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市槇', '15', '15216', '9491312', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '槇', 'マキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市下倉', '15', '15216', '9491313', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '下倉', 'シタクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市中野口', '15', '15216', '9491314', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '中野口', 'ナカノクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市指塩', '15', '15216', '9491315', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '指塩', 'サシオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市柱道', '15', '15216', '9491316', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '柱道', 'ハシラミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市大道寺', '15', '15216', '9491317', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '大道寺', 'ダイドウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市鷲尾', '15', '15216', '9491318', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '鷲尾', 'ワシオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市大王', '15', '15216', '9491319', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '大王', 'タイオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市東谷内', '15', '15216', '9491321', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '東谷内', 'ヒガシタニウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市西飛山', '15', '15216', '9491322', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '西飛山', 'ニシヒヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市田麦平', '15', '15216', '9491323', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '田麦平', 'タムギダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市柵口', '15', '15216', '9491324', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '柵口', 'マセグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市崩', '15', '15216', '9491325', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '崩', 'クズレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市物出', '15', '15216', '9491326', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '物出', 'モノイデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市須川', '15', '15216', '9491327', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '須川', 'スガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市溝尾', '15', '15216', '9491328', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '溝尾', 'ミゾオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市川詰', '15', '15216', '9491329', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '川詰', 'カワヅメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市大沢', '15', '15216', '9491331', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '大沢', 'オオサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市藤後', '15', '15216', '9491332', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '藤後', 'トウゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市島道', '15', '15216', '9491333', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '島道', 'シマミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市平', '15', '15216', '9491334', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '平', 'タイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市小見', '15', '15216', '9491335', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '小見', 'オミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市鶉石', '15', '15216', '9491336', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '鶉石', 'ウズライシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市桂', '15', '15216', '9491337', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '桂', 'カツラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市寺山', '15', '15216', '9491338', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '寺山', 'テラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市大平寺', '15', '15216', '9491341', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '大平寺', 'タイヘイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市木浦', '15', '15216', '9491342', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '木浦', 'コノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市鬼伏', '15', '15216', '9491343', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '鬼伏', 'オニブシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市鬼舞', '15', '15216', '9491344', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '鬼舞', 'キブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市能生小泊', '15', '15216', '9491351', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '能生小泊', 'ノウコドマリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市能生', '15', '15216', '9491352', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '能生', 'ノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市栄', '15', '15216', '9491353', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '栄', 'サカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県糸魚川市桜木', '15', '15216', '9491354', '新潟県', 'ニイガタケン', '糸魚川市', 'イトイガワシ', '桜木', 'サクラギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市名立区名立小泊', '15', '15222', '9491601', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '名立区名立小泊', 'ナダチクナダチコドマリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市名立区名立大町', '15', '15222', '9491602', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '名立区名立大町', 'ナダチクナダチオオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市名立区坪山', '15', '15222', '9491603', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '名立区坪山', 'ナダチクツボヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市名立区赤野俣', '15', '15222', '9491604', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '名立区赤野俣', 'ナダチクアカノマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市名立区大菅', '15', '15222', '9491605', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '名立区大菅', 'ナダチクオオスガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市名立区谷口', '15', '15222', '9491606', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '名立区谷口', 'ナダチクタニグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市名立区車路', '15', '15222', '9491607', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '名立区車路', 'ナダチククルマジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市名立区躰畑', '15', '15222', '9491608', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '名立区躰畑', 'ナダチクタイバタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市名立区田野上', '15', '15222', '9491609', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '名立区田野上', 'ナダチクタノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市名立区杉野瀬', '15', '15222', '9491611', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '名立区杉野瀬', 'ナダチクスギノセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市名立区丸田', '15', '15222', '9491612', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '名立区丸田', 'ナダチクマルダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市名立区濁沢', '15', '15222', '9491613', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '名立区濁沢', 'ナダチクニゴリサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市名立区折居', '15', '15222', '9491614', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '名立区折居', 'ナダチクオリイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市名立区峠', '15', '15222', '9491615', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '名立区峠', 'ナダチクトウゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市名立区池田', '15', '15222', '9491616', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '名立区池田', 'ナダチクイケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市名立区森', '15', '15222', '9491617', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '名立区森', 'ナダチクモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市名立区桂谷', '15', '15222', '9491618', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '名立区桂谷', 'ナダチクカツラダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市名立区平谷', '15', '15222', '9491619', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '名立区平谷', 'ナダチクヒラタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市名立区折戸', '15', '15222', '9491621', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '名立区折戸', 'ナダチクオリト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市名立区小田島', '15', '15222', '9491622', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '名立区小田島', 'ナダチクオダジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市名立区東蒲生田', '15', '15222', '9491623', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '名立区東蒲生田', 'ナダチクヒガシカモウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市名立区西蒲生田', '15', '15222', '9491624', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '名立区西蒲生田', 'ナダチクニシカモウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市名立区瀬戸', '15', '15222', '9491625', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '名立区瀬戸', 'ナダチクセト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市名立区東飛山', '15', '15222', '9491626', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '名立区東飛山', 'ナダチクヒガシヒヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市長浜', '15', '15222', '9491701', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '長浜', 'ナガハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市有間川', '15', '15222', '9491702', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '有間川', 'アリマガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市丹原', '15', '15222', '9491703', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '丹原', 'タンバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市鍋ケ浦', '15', '15222', '9491704', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '鍋ケ浦', 'ナベガウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市吉浦', '15', '15222', '9491705', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '吉浦', 'ヨシウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市茶屋ケ原', '15', '15222', '9491706', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '茶屋ケ原', 'チャヤガハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市西戸野', '15', '15222', '9491711', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '西戸野', 'ニシトノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市鍛冶免分', '15', '15222', '9491712', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '鍛冶免分', 'カジメンブン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市花立', '15', '15222', '9491713', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '花立', 'ハナタテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市三伝', '15', '15222', '9491714', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '三伝', 'サンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市中桑取', '15', '15222', '9491715', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '中桑取', 'ナカクワドリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市高住', '15', '15222', '9491716', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '高住', 'タカスミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市下綱子', '15', '15222', '9491721', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '下綱子', 'シモツナゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市西山寺', '15', '15222', '9491722', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '西山寺', 'ニシヤマデラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市小池', '15', '15222', '9491723', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '小池', 'オイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市小池新田', '15', '15222', '9491724', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '小池新田', 'オイケシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市西鳥越', '15', '15222', '9491725', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '西鳥越', 'ニシトリゴエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市諏訪分', '15', '15222', '9491726', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '諏訪分', 'スワブン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市西横山', '15', '15222', '9491727', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '西横山', 'ニシヨコヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市西吉尾', '15', '15222', '9491731', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '西吉尾', 'ニシヨシオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市東吉尾', '15', '15222', '9491732', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '東吉尾', 'ヒガシヨシオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市大渕', '15', '15222', '9491733', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '大渕', 'オオブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市増沢', '15', '15222', '9491734', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '増沢', 'マスザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市土口', '15', '15222', '9491735', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '土口', 'ドグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市北谷', '15', '15222', '9491736', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '北谷', 'キタダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市西谷内', '15', '15222', '9491737', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '西谷内', 'ニシヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市皆口', '15', '15222', '9491738', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '皆口', 'ミナクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市横畑', '15', '15222', '9491739', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '横畑', 'ヨコバタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市上綱子', '15', '15222', '9491741', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '上綱子', 'カミツナゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市中ノ俣', '15', '15222', '9491742', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '中ノ俣', 'ナカノマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市二俣', '15', '15217', '9492101', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '二俣', 'フタマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市田切', '15', '15217', '9492102', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '田切', 'タギリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市蔵々', '15', '15217', '9492103', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '蔵々', 'ゾウゾウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市兼俣', '15', '15217', '9492104', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '兼俣', 'カネマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市毛祝坂', '15', '15217', '9492105', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '毛祝坂', 'ケワイザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市田口', '15', '15217', '9492106', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '田口', 'タグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市赤倉', '15', '15217', '9492111', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '赤倉', 'アカクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市関川', '15', '15217', '9492112', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '関川', 'セキガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市杉野澤', '15', '15217', '9492113', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '杉野澤', 'スギノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市関山熊堂山', '15', '15217', '9492141', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '関山', 'セキヤマ', null, null, '熊堂山', 'クマドウヤマ');
INSERT INTO `ms_addresses` VALUES ('131455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市関山妙高山国有林第28班', '15', '15217', '9492141', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '関山', 'セキヤマ', null, null, '妙高山国有林第28班', 'ミョウコウサンコクユウリンダイ28ハン');
INSERT INTO `ms_addresses` VALUES ('131456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市寺尾', '15', '15217', '9492201', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '寺尾', 'テラオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市坂下新田', '15', '15217', '9492202', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '坂下新田', 'サカシタシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市北田屋新田', '15', '15217', '9492203', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '北田屋新田', 'キタタヤシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市中原新田', '15', '15217', '9492204', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '中原新田', 'ナカバラシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市上大塚新田', '15', '15217', '9492205', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '上大塚新田', 'カミオオツカシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市西田屋新田', '15', '15217', '9492206', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '西田屋新田', 'ニシタヤシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市窪田新田', '15', '15217', '9492207', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '窪田新田', 'クボタシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市今府', '15', '15217', '9492208', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '今府', 'イマブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市祖父竹', '15', '15217', '9492209', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '祖父竹', 'ソフタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市田中村新田', '15', '15217', '9492211', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '田中村新田', 'タナカムラシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市岡新田', '15', '15217', '9492212', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '岡新田', 'オカシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市東田屋新田', '15', '15217', '9492213', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '東田屋新田', 'ヒガシタヤシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市中島新田', '15', '15217', '9492214', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '中島新田', 'ナカジマシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市橋本新田', '15', '15217', '9492215', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '橋本新田', 'ハシモトシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市東四ツ屋新田', '15', '15217', '9492216', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '東四ツ屋新田', 'ヒガシヨツヤシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市東福田新田', '15', '15217', '9492217', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '東福田新田', 'ヒガシフクダシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市花房', '15', '15217', '9492218', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '花房', 'ハナブサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市原通', '15', '15217', '9492219', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '原通', 'ハラドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市大鹿', '15', '15217', '9492221', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '大鹿', 'オオシカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市土路', '15', '15217', '9492222', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '土路', 'ドロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市樽本', '15', '15217', '9492223', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '樽本', 'タルモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市桶海', '15', '15217', '9492224', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '桶海', 'オケミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市大谷', '15', '15217', '9492225', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '大谷', 'オオタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市住吉', '15', '15217', '9492226', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '住吉', 'スミヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市米島新田', '15', '15217', '9492231', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '米島新田', 'ヨネジマシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市葎生', '15', '15217', '9492232', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '葎生', 'モグロウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市上中村新田', '15', '15217', '9492233', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '上中村新田', 'カミナカムラシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市坂口新田', '15', '15217', '9492234', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '坂口新田', 'サカグチシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県妙高市関山', '15', '15217', '9492235', '新潟県', 'ニイガタケン', '妙高市', 'ミョウコウシ', '関山', 'セキヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市中郷区板橋', '15', '15222', '9492301', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '中郷区板橋', 'ナカゴウクイタバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市中郷区藤沢', '15', '15222', '9492302', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '中郷区藤沢', 'ナカゴウクフジサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市中郷区坂本', '15', '15222', '9492303', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '中郷区坂本', 'ナカゴウクサカモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市中郷区二本木', '15', '15222', '9492304', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '中郷区二本木', 'ナカゴウクニホンギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市中郷区四ツ屋', '15', '15222', '9492305', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '中郷区四ツ屋', 'ナカゴウクヨツヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市中郷区八斗蒔', '15', '15222', '9492306', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '中郷区八斗蒔', 'ナカゴウクハツトウマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市中郷区松崎', '15', '15222', '9492311', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '中郷区松崎', 'ナカゴウクマツザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市中郷区片貝', '15', '15222', '9492312', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '中郷区片貝', 'ナカゴウクカタカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市中郷区福崎', '15', '15222', '9492313', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '中郷区福崎', 'ナカゴウクフクザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市中郷区宮野原', '15', '15222', '9492314', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '中郷区宮野原', 'ナカゴウクミヤノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市中郷区稲荷山', '15', '15222', '9492315', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '中郷区稲荷山', 'ナカゴウクイナリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市中郷区江口', '15', '15222', '9492316', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '中郷区江口', 'ナカゴウクエグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市中郷区市屋', '15', '15222', '9492317', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '中郷区市屋', 'ナカゴウクイチヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市中郷区岡川', '15', '15222', '9492318', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '中郷区岡川', 'ナカゴウクオカカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市中郷区福田', '15', '15222', '9492321', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '中郷区福田', 'ナカゴウクフクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市中郷区岡沢', '15', '15222', '9492322', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '中郷区岡沢', 'ナカゴウクオカザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市大潟区雁子浜', '15', '15222', '9493101', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '大潟区雁子浜', 'オオガタクガンコハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市大潟区九戸浜', '15', '15222', '9493102', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '大潟区九戸浜', 'オオガタククドハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市大潟区潟町', '15', '15222', '9493103', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '大潟区潟町', 'オオガタクカタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市大潟区四ツ屋浜', '15', '15222', '9493111', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '大潟区四ツ屋浜', 'オオガタクヨツヤハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市大潟区土底浜', '15', '15222', '9493112', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '大潟区土底浜', 'オオガタクドソコハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市大潟区下小船津浜', '15', '15222', '9493113', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '大潟区下小船津浜', 'オオガタクシモコブナツハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市大潟区上小船津浜', '15', '15222', '9493114', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '大潟区上小船津浜', 'オオガタクカミコブナツハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市大潟区渋柿浜', '15', '15222', '9493115', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '大潟区渋柿浜', 'オオガタクシブカキハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市大潟区犀潟', '15', '15222', '9493116', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '大潟区犀潟', 'オオガタクサイガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市大潟区蜘ケ池', '15', '15222', '9493117', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '大潟区蜘ケ池', 'オオガタククモガイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市大潟区潟田', '15', '15222', '9493121', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '大潟区潟田', 'オオガタクカタダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市大潟区岩野古新田', '15', '15222', '9493122', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '大潟区岩野古新田', 'オオガタクイワノコシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市大潟区長崎', '15', '15222', '9493123', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '大潟区長崎', 'オオガタクナガサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市大潟区吉崎新田', '15', '15222', '9493124', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '大潟区吉崎新田', 'オオガタクヨシザキシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市大潟区山鵜島新田', '15', '15222', '9493125', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '大潟区山鵜島新田', 'オオガタクヤマウジマシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市大潟区里鵜島新田', '15', '15222', '9493131', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '大潟区里鵜島新田', 'オオガタクサトウジマシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市大潟区米倉新田', '15', '15222', '9493132', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '大潟区米倉新田', 'オオガタクヨネグラシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市大潟区高橋新田', '15', '15222', '9493133', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '大潟区高橋新田', 'オオガタクタカハシシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市大潟区和泉新田', '15', '15222', '9493134', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '大潟区和泉新田', 'オオガタクイズミシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市大潟区内雁子', '15', '15222', '9493135', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '大潟区内雁子', 'オオガタクウチガンゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市大潟区内雁子新田', '15', '15222', '9493136', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '大潟区内雁子新田', 'オオガタクウチガンゴシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市大潟区潟守新田', '15', '15222', '9493137', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '大潟区潟守新田', 'オオガタクカタモリシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市柿崎区竹鼻', '15', '15222', '9493201', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '柿崎区竹鼻', 'カキザキクタケガハナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市柿崎区法音寺', '15', '15222', '9493211', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '柿崎区法音寺', 'カキザキクホウオンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市柿崎区山谷', '15', '15222', '9493212', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '柿崎区山谷', 'カキザキクヤマヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市柿崎区川井', '15', '15222', '9493213', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '柿崎区川井', 'カキザキクカワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市柿崎区馬正面', '15', '15222', '9493214', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '柿崎区馬正面', 'カキザキクバショウメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市柿崎区直海浜', '15', '15222', '9493215', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '柿崎区直海浜', 'カキザキクノウミハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市柿崎区柿崎', '15', '15222', '9493216', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '柿崎区柿崎', 'カキザキクカキザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市柿崎区小萱', '15', '15222', '9493221', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '柿崎区小萱', 'カキザキクオガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市柿崎区栃窪', '15', '15222', '9493222', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '柿崎区栃窪', 'カキザキクトチクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市柿崎区雁海', '15', '15222', '9493223', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '柿崎区雁海', 'カキザキクガンカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市柿崎区東谷内', '15', '15222', '9493224', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '柿崎区東谷内', 'カキザキクヒガシヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市柿崎区金谷', '15', '15222', '9493225', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '柿崎区金谷', 'カキザキクカナヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市柿崎区下中山', '15', '15222', '9493226', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '柿崎区下中山', 'カキザキクシモナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市柿崎区上小野', '15', '15222', '9493231', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '柿崎区上小野', 'カキザキクカミオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市柿崎区下小野', '15', '15222', '9493232', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '柿崎区下小野', 'カキザキクシモオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市柿崎区柳ケ崎', '15', '15222', '9493233', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '柿崎区柳ケ崎', 'カキザキクヤナガサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市柿崎区高寺', '15', '15222', '9493234', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '柿崎区高寺', 'カキザキクタカテラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市柿崎区荻谷', '15', '15222', '9493235', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '柿崎区荻谷', 'カキザキクオギノタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市柿崎区阿弥陀瀬', '15', '15222', '9493236', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '柿崎区阿弥陀瀬', 'カキザキクアミダセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市柿崎区川田', '15', '15222', '9493237', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '柿崎区川田', 'カキザキクカワタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市柿崎区百木', '15', '15222', '9493241', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '柿崎区百木', 'カキザキクモモキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市柿崎区桜町新田', '15', '15222', '9493242', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '柿崎区桜町新田', 'カキザキクサクラマチシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市柿崎区上金原', '15', '15222', '9493243', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '柿崎区上金原', 'カキザキクカミカナハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市柿崎区下金原', '15', '15222', '9493244', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '柿崎区下金原', 'カキザキクシモカナハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市柿崎区行法', '15', '15222', '9493245', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '柿崎区行法', 'カキザキクギョウホウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市柿崎区落合', '15', '15222', '9493246', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '柿崎区落合', 'カキザキクオチアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市柿崎区角取', '15', '15222', '9493247', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '柿崎区角取', 'カキザキクツノドリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市柿崎区下条', '15', '15222', '9493251', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '柿崎区下条', 'カキザキクゲジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市柿崎区上直海', '15', '15222', '9493252', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '柿崎区上直海', 'カキザキクカミノウミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市柿崎区江島新田', '15', '15222', '9493253', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '柿崎区江島新田', 'カキザキクエジマシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市柿崎区坂田新田', '15', '15222', '9493254', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '柿崎区坂田新田', 'カキザキクサカタシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市柿崎区上下浜', '15', '15222', '9493255', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '柿崎区上下浜', 'カキザキクジョウゲハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市柿崎区三ツ屋浜', '15', '15222', '9493256', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '柿崎区三ツ屋浜', 'カキザキクミツヤハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市柿崎区城腰', '15', '15222', '9493361', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '柿崎区城腰', 'カキザキクジョウノコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市柿崎区黒岩', '15', '15222', '9493362', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '柿崎区黒岩', 'カキザキククロイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市柿崎区旭平', '15', '15222', '9493363', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '柿崎区旭平', 'カキザキクアサヒダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市柿崎区東横山', '15', '15222', '9493364', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '柿崎区東横山', 'カキザキクヒガシヨコヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市柿崎区松留', '15', '15222', '9493365', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '柿崎区松留', 'カキザキクマツドメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市柿崎区上中山', '15', '15222', '9493366', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '柿崎区上中山', 'カキザキクカミナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市柿崎区猿毛', '15', '15222', '9493367', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '柿崎区猿毛', 'カキザキクサルゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市柿崎区下牧', '15', '15222', '9493371', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '柿崎区下牧', 'カキザキクシモマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市柿崎区水野', '15', '15222', '9493372', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '柿崎区水野', 'カキザキクミズノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市柿崎区米山寺', '15', '15222', '9493373', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '柿崎区米山寺', 'カキザキクベイサンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市柿崎区芋島', '15', '15222', '9493374', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '柿崎区芋島', 'カキザキクイモノシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市柿崎区下灰庭新田', '15', '15222', '9493375', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '柿崎区下灰庭新田', 'カキザキクシモハイニワシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市柿崎区岩手', '15', '15222', '9493376', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '柿崎区岩手', 'カキザキクイワデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市柿崎区高畑', '15', '15222', '9493377', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '柿崎区高畑', 'カキザキクタカバタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市柿崎区岩野', '15', '15222', '9493378', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '柿崎区岩野', 'カキザキクイワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市柿崎区平沢', '15', '15222', '9493379', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '柿崎区平沢', 'カキザキクヒラサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市吉川区後生寺', '15', '15222', '9493401', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '吉川区後生寺', 'ヨシカワクゴショウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市吉川区伯母ケ沢', '15', '15222', '9493402', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '吉川区伯母ケ沢', 'ヨシカワクオバガサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市吉川区平等寺', '15', '15222', '9493403', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '吉川区平等寺', 'ヨシカワクビョウドウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市吉川区東寺', '15', '15222', '9493404', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '吉川区東寺', 'ヨシカワクトウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市吉川区吉井', '15', '15222', '9493405', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '吉川区吉井', 'ヨシカワクヨシイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市吉川区下小沢', '15', '15222', '9493406', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '吉川区下小沢', 'ヨシカワクシモオザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市吉川区下中条', '15', '15222', '9493407', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '吉川区下中条', 'ヨシカワクシモチュウジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市吉川区赤沢', '15', '15222', '9493408', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '吉川区赤沢', 'ヨシカワクアカサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市吉川区泉', '15', '15222', '9493409', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '吉川区泉', 'ヨシカワクイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市吉川区川崎', '15', '15222', '9493411', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '吉川区川崎', 'ヨシカワクカワサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市吉川区泉谷', '15', '15222', '9493412', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '吉川区泉谷', 'ヨシカワクイズミダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市吉川区土尻', '15', '15222', '9493413', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '吉川区土尻', 'ヨシカワクドジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市吉川区天林寺', '15', '15222', '9493414', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '吉川区天林寺', 'ヨシカワクテンリンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市吉川区山口', '15', '15222', '9493415', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '吉川区山口', 'ヨシカワクヤマグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市吉川区中谷内', '15', '15222', '9493416', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '吉川区中谷内', 'ヨシカワクナカヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市吉川区下深沢', '15', '15222', '9493417', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '吉川区下深沢', 'ヨシカワクシモフカサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市吉川区片田', '15', '15222', '9493418', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '吉川区片田', 'ヨシカワクカタタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市吉川区東鳥越', '15', '15222', '9493419', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '吉川区東鳥越', 'ヨシカワクヒガシトリゴエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市吉川区入河沢', '15', '15222', '9493421', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '吉川区入河沢', 'ヨシカワクイリコウゾウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市吉川区国田', '15', '15222', '9493422', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '吉川区国田', 'ヨシカワクコクタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市吉川区東田中', '15', '15222', '9493423', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '吉川区東田中', 'ヨシカワクヒガシタナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市吉川区福平', '15', '15222', '9493424', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '吉川区福平', 'ヨシカワクフクダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市吉川区長坂', '15', '15222', '9493425', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '吉川区長坂', 'ヨシカワクナガサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市吉川区道之下', '15', '15222', '9493426', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '吉川区道之下', 'ヨシカワクドウノシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市吉川区顕法寺', '15', '15222', '9493427', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '吉川区顕法寺', 'ヨシカワクケンポウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市吉川区十町歩', '15', '15222', '9493428', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '吉川区十町歩', 'ヨシカワクジッチョウブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市吉川区河沢', '15', '15222', '9493429', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '吉川区河沢', 'ヨシカワクコウゾウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市吉川区田尻', '15', '15222', '9493431', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '吉川区田尻', 'ヨシカワクタジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市吉川区六万部', '15', '15222', '9493432', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '吉川区六万部', 'ヨシカワクロクマンブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市吉川区町田', '15', '15222', '9493433', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '吉川区町田', 'ヨシカワクマチダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市吉川区西野島', '15', '15222', '9493434', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '吉川区西野島', 'ヨシカワクニシノシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市吉川区下八幡', '15', '15222', '9493435', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '吉川区下八幡', 'ヨシカワクシモハチマン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市吉川区坪野内', '15', '15222', '9493436', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '吉川区坪野内', 'ヨシカワクツボノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市吉川区梶', '15', '15222', '9493437', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '吉川区梶', 'ヨシカワクカジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市吉川区神田町', '15', '15222', '9493438', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '吉川区神田町', 'ヨシカワクカンダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市吉川区長沢', '15', '15222', '9493439', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '吉川区長沢', 'ヨシカワクナガサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市吉川区代石', '15', '15222', '9493441', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '吉川区代石', 'ヨシカワクタイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市吉川区小苗代', '15', '15222', '9493442', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '吉川区小苗代', 'ヨシカワクオナワシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市吉川区下町', '15', '15222', '9493443', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '吉川区下町', 'ヨシカワクシタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市吉川区大乗寺', '15', '15222', '9493444', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '吉川区大乗寺', 'ヨシカワクダイジョウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市吉川区原之町', '15', '15222', '9493445', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '吉川区原之町', 'ヨシカワクハラノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市吉川区山方', '15', '15222', '9493446', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '吉川区山方', 'ヨシカワクヤマガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市吉川区竹直', '15', '15222', '9493447', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '吉川区竹直', 'ヨシカワクタケナオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市吉川区長峰', '15', '15222', '9493448', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '吉川区長峰', 'ヨシカワクナガミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市吉川区杜氏の郷', '15', '15222', '9493449', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '吉川区杜氏の郷', 'ヨシカワクトウジノサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市吉川区坪野', '15', '15222', '9493551', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '吉川区坪野', 'ヨシカワクツボノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市吉川区尾神', '15', '15222', '9493552', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '吉川区尾神', 'ヨシカワクオカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市吉川区川谷', '15', '15222', '9493553', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '吉川区川谷', 'ヨシカワクカワダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市吉川区石谷', '15', '15222', '9493554', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '吉川区石谷', 'ヨシカワクイシダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市吉川区上名木', '15', '15222', '9493555', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '吉川区上名木', 'ヨシカワクカミナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市吉川区名木山', '15', '15222', '9493556', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '吉川区名木山', 'ヨシカワクナギヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市吉川区高沢入', '15', '15222', '9493557', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '吉川区高沢入', 'ヨシカワクタカサワイリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市吉川区山中', '15', '15222', '9493561', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '吉川区山中', 'ヨシカワクヤマナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市吉川区山直海', '15', '15222', '9493562', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '吉川区山直海', 'ヨシカワクヤマノウミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市吉川区大賀', '15', '15222', '9493563', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '吉川区大賀', 'ヨシカワクオオガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市吉川区岩沢', '15', '15222', '9493564', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '吉川区岩沢', 'ヨシカワクイワサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県上越市吉川区米山', '15', '15222', '9493565', '新潟県', 'ニイガタケン', '上越市', 'ジョウエツシ', '吉川区米山', 'ヨシカワクコメヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市青海川', '15', '15205', '9493661', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '青海川', 'オウミガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市笠島', '15', '15205', '9493662', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '笠島', 'カサシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市上輪新田', '15', '15205', '9493663', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '上輪新田', 'アゲワシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市上輪', '15', '15205', '9493664', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '上輪', 'アゲワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市蕨野', '15', '15205', '9493671', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '蕨野', 'ワラビノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市大平', '15', '15205', '9493672', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '大平', 'オオダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市高畔', '15', '15205', '9493673', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '高畔', 'タカゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市大清水', '15', '15205', '9493674', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '大清水', 'オオシミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市米山町', '15', '15205', '9493675', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '米山町', 'ヨネヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市吉井黒川', '15', '15205', '9493721', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '吉井黒川', 'ヨシイクロカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市東長鳥', '15', '15205', '9493722', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '東長鳥', 'ヒガシナガトリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市西長鳥', '15', '15205', '9493723', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '西長鳥', 'ニシナガトリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市大広田', '15', '15205', '9493724', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '大広田', 'オオヒロタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市旧広田', '15', '15205', '9493725', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '旧広田', 'キュウヒロタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市山澗', '15', '15205', '9493726', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '山澗', 'ヤマダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市東条', '15', '15205', '9493731', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '東条', 'トウジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市北条', '15', '15205', '9493732', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '北条', 'キタジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市本条', '15', '15205', '9493733', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '本条', 'ホンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市南条', '15', '15205', '9493734', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '南条', 'ミナミジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市小島', '15', '15205', '9493735', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '小島', 'コジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市西山町別山', '15', '15205', '9494111', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '西山町別山', 'ニシヤマチョウベツヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市西山町尾野内', '15', '15205', '9494112', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '西山町尾野内', 'ニシヤマチョウオノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市西山町上山田', '15', '15205', '9494113', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '西山町上山田', 'ニシヤマチョウカミヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市西山町灰爪', '15', '15205', '9494114', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '西山町灰爪', 'ニシヤマチョウハイヅメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市西山町田沢', '15', '15205', '9494121', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '西山町田沢', 'ニシヤマチョウタザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市西山町藤掛', '15', '15205', '9494122', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '西山町藤掛', 'ニシヤマチョウフジカケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市西山町池浦', '15', '15205', '9494123', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '西山町池浦', 'ニシヤマチョウイケウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市西山町礼拝', '15', '15205', '9494124', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '西山町礼拝', 'ニシヤマチョウライハイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市西山町中央台', '15', '15205', '9494125', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '西山町中央台', 'ニシヤマチョウチュウオウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市西山町下山田', '15', '15205', '9494126', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '西山町下山田', 'ニシヤマチョウシモヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市西山町鎌田', '15', '15205', '9494127', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '西山町鎌田', 'ニシヤマチョウカマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市西山町伊毛', '15', '15205', '9494128', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '西山町伊毛', 'ニシヤマチョウイモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市西山町後谷', '15', '15205', '9494131', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '西山町後谷', 'ニシヤマチョウウシロダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市西山町長嶺', '15', '15205', '9494132', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '西山町長嶺', 'ニシヤマチョウナガミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市西山町鬼王', '15', '15205', '9494133', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '西山町鬼王', 'ニシヤマチョウオニオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市西山町二田', '15', '15205', '9494134', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '西山町二田', 'ニシヤマチョウフタダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市西山町坂田', '15', '15205', '9494135', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '西山町坂田', 'ニシヤマチョウサカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市西山町緑が丘', '15', '15205', '9494136', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '西山町緑が丘', 'ニシヤマチョウミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市西山町西山', '15', '15205', '9494141', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '西山町西山', 'ニシヤマチョウニシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市西山町黒部', '15', '15205', '9494142', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '西山町黒部', 'ニシヤマチョウクロベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市西山町和田', '15', '15205', '9494143', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '西山町和田', 'ニシヤマチョウワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市西山町新保', '15', '15205', '9494144', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '西山町新保', 'ニシヤマチョウシンボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市西山町北野', '15', '15205', '9494145', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '西山町北野', 'ニシヤマチョウキタノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市西山町妙法寺', '15', '15205', '9494146', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '西山町妙法寺', 'ニシヤマチョウミョウホウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市西山町大坪', '15', '15205', '9494147', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '西山町大坪', 'ニシヤマチョウオオツボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市西山町内方', '15', '15205', '9494148', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '西山町内方', 'ニシヤマチョウウチカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市西山町五日市', '15', '15205', '9494149', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '西山町五日市', 'ニシヤマチョウイツカイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市西山町石地', '15', '15205', '9494201', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '西山町石地', 'ニシヤマチョウイシジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市西山町尾町', '15', '15205', '9494202', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '西山町尾町', 'ニシヤマチョウオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市西山町大津', '15', '15205', '9494203', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '西山町大津', 'ニシヤマチョウオオヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市西山町大崎', '15', '15205', '9494204', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '西山町大崎', 'ニシヤマチョウオオサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市西山町浜忠', '15', '15205', '9494205', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '西山町浜忠', 'ニシヤマチョウハマツダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県柏崎市西山町甲田', '15', '15205', '9494206', '新潟県', 'ニイガタケン', '柏崎市', 'カシワザキシ', '西山町甲田', 'ニシヤマチョウコウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三島郡出雲崎町', '15', '15405', '9494300', '新潟県', 'ニイガタケン', '三島郡出雲崎町', 'サントウグンイズモザキマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('131697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三島郡出雲崎町久田', '15', '15405', '9494301', '新潟県', 'ニイガタケン', '三島郡出雲崎町', 'サントウグンイズモザキマチ', '久田', 'クッタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三島郡出雲崎町井鼻', '15', '15405', '9494302', '新潟県', 'ニイガタケン', '三島郡出雲崎町', 'サントウグンイズモザキマチ', '井鼻', 'イノハナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三島郡出雲崎町木折町', '15', '15405', '9494303', '新潟県', 'ニイガタケン', '三島郡出雲崎町', 'サントウグンイズモザキマチ', '木折町', 'キオリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三島郡出雲崎町鳴滝町', '15', '15405', '9494304', '新潟県', 'ニイガタケン', '三島郡出雲崎町', 'サントウグンイズモザキマチ', '鳴滝町', 'ナルタキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三島郡出雲崎町羽黒町', '15', '15405', '9494305', '新潟県', 'ニイガタケン', '三島郡出雲崎町', 'サントウグンイズモザキマチ', '羽黒町', 'ハグロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三島郡出雲崎町石井町', '15', '15405', '9494306', '新潟県', 'ニイガタケン', '三島郡出雲崎町', 'サントウグンイズモザキマチ', '石井町', 'イシイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三島郡出雲崎町住吉町', '15', '15405', '9494307', '新潟県', 'ニイガタケン', '三島郡出雲崎町', 'サントウグンイズモザキマチ', '住吉町', 'スミヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三島郡出雲崎町尼瀬', '15', '15405', '9494308', '新潟県', 'ニイガタケン', '三島郡出雲崎町', 'サントウグンイズモザキマチ', '尼瀬', 'アマゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三島郡出雲崎町勝見', '15', '15405', '9494309', '新潟県', 'ニイガタケン', '三島郡出雲崎町', 'サントウグンイズモザキマチ', '勝見', 'カツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三島郡出雲崎町乙茂', '15', '15405', '9494311', '新潟県', 'ニイガタケン', '三島郡出雲崎町', 'サントウグンイズモザキマチ', '乙茂', 'オトモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三島郡出雲崎町大寺', '15', '15405', '9494312', '新潟県', 'ニイガタケン', '三島郡出雲崎町', 'サントウグンイズモザキマチ', '大寺', 'オオテラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三島郡出雲崎町馬草', '15', '15405', '9494313', '新潟県', 'ニイガタケン', '三島郡出雲崎町', 'サントウグンイズモザキマチ', '馬草', 'マグサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三島郡出雲崎町藤巻', '15', '15405', '9494314', '新潟県', 'ニイガタケン', '三島郡出雲崎町', 'サントウグンイズモザキマチ', '藤巻', 'フジマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三島郡出雲崎町柿木', '15', '15405', '9494315', '新潟県', 'ニイガタケン', '三島郡出雲崎町', 'サントウグンイズモザキマチ', '柿木', 'カキノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三島郡出雲崎町滝谷', '15', '15405', '9494316', '新潟県', 'ニイガタケン', '三島郡出雲崎町', 'サントウグンイズモザキマチ', '滝谷', 'タキヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三島郡出雲崎町吉川', '15', '15405', '9494317', '新潟県', 'ニイガタケン', '三島郡出雲崎町', 'サントウグンイズモザキマチ', '吉川', 'ヨシカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三島郡出雲崎町神条', '15', '15405', '9494318', '新潟県', 'ニイガタケン', '三島郡出雲崎町', 'サントウグンイズモザキマチ', '神条', 'カミジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三島郡出雲崎町松本', '15', '15405', '9494321', '新潟県', 'ニイガタケン', '三島郡出雲崎町', 'サントウグンイズモザキマチ', '松本', 'マツモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三島郡出雲崎町小釜谷', '15', '15405', '9494322', '新潟県', 'ニイガタケン', '三島郡出雲崎町', 'サントウグンイズモザキマチ', '小釜谷', 'コガマヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三島郡出雲崎町大釜谷', '15', '15405', '9494323', '新潟県', 'ニイガタケン', '三島郡出雲崎町', 'サントウグンイズモザキマチ', '大釜谷', 'オオガマヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三島郡出雲崎町吉水', '15', '15405', '9494324', '新潟県', 'ニイガタケン', '三島郡出雲崎町', 'サントウグンイズモザキマチ', '吉水', 'ヨシミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三島郡出雲崎町相田', '15', '15405', '9494325', '新潟県', 'ニイガタケン', '三島郡出雲崎町', 'サントウグンイズモザキマチ', '相田', 'アイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三島郡出雲崎町桂沢', '15', '15405', '9494326', '新潟県', 'ニイガタケン', '三島郡出雲崎町', 'サントウグンイズモザキマチ', '桂沢', 'カツラサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三島郡出雲崎町別ケ谷', '15', '15405', '9494327', '新潟県', 'ニイガタケン', '三島郡出雲崎町', 'サントウグンイズモザキマチ', '別ケ谷', 'ベツガタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三島郡出雲崎町山谷', '15', '15405', '9494328', '新潟県', 'ニイガタケン', '三島郡出雲崎町', 'サントウグンイズモザキマチ', '山谷', 'ヤマヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三島郡出雲崎町稲川', '15', '15405', '9494331', '新潟県', 'ニイガタケン', '三島郡出雲崎町', 'サントウグンイズモザキマチ', '稲川', 'イナガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三島郡出雲崎町小木', '15', '15405', '9494332', '新潟県', 'ニイガタケン', '三島郡出雲崎町', 'サントウグンイズモザキマチ', '小木', 'オギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三島郡出雲崎町常楽寺', '15', '15405', '9494333', '新潟県', 'ニイガタケン', '三島郡出雲崎町', 'サントウグンイズモザキマチ', '常楽寺', 'ジョウラクジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三島郡出雲崎町豊橋', '15', '15405', '9494334', '新潟県', 'ニイガタケン', '三島郡出雲崎町', 'サントウグンイズモザキマチ', '豊橋', 'トヨバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三島郡出雲崎町市野坪', '15', '15405', '9494335', '新潟県', 'ニイガタケン', '三島郡出雲崎町', 'サントウグンイズモザキマチ', '市野坪', 'イチノツボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三島郡出雲崎町船橋', '15', '15405', '9494336', '新潟県', 'ニイガタケン', '三島郡出雲崎町', 'サントウグンイズモザキマチ', '船橋', 'フナバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三島郡出雲崎町田中', '15', '15405', '9494337', '新潟県', 'ニイガタケン', '三島郡出雲崎町', 'サントウグンイズモザキマチ', '田中', 'タナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三島郡出雲崎町上中条', '15', '15405', '9494341', '新潟県', 'ニイガタケン', '三島郡出雲崎町', 'サントウグンイズモザキマチ', '上中条', 'カミナカジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三島郡出雲崎町米田', '15', '15405', '9494342', '新潟県', 'ニイガタケン', '三島郡出雲崎町', 'サントウグンイズモザキマチ', '米田', 'コメダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三島郡出雲崎町立石', '15', '15405', '9494343', '新潟県', 'ニイガタケン', '三島郡出雲崎町', 'サントウグンイズモザキマチ', '立石', 'タテイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三島郡出雲崎町小竹', '15', '15405', '9494344', '新潟県', 'ニイガタケン', '三島郡出雲崎町', 'サントウグンイズモザキマチ', '小竹', 'コダケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三島郡出雲崎町中山', '15', '15405', '9494345', '新潟県', 'ニイガタケン', '三島郡出雲崎町', 'サントウグンイズモザキマチ', '中山', 'ナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三島郡出雲崎町上野山', '15', '15405', '9494346', '新潟県', 'ニイガタケン', '三島郡出雲崎町', 'サントウグンイズモザキマチ', '上野山', 'ウエノヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三島郡出雲崎町沢田', '15', '15405', '9494351', '新潟県', 'ニイガタケン', '三島郡出雲崎町', 'サントウグンイズモザキマチ', '沢田', 'サワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三島郡出雲崎町大門', '15', '15405', '9494352', '新潟県', 'ニイガタケン', '三島郡出雲崎町', 'サントウグンイズモザキマチ', '大門', 'ダイモン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三島郡出雲崎町川西', '15', '15405', '9494353', '新潟県', 'ニイガタケン', '三島郡出雲崎町', 'サントウグンイズモザキマチ', '川西', 'カワニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市上桐', '15', '15202', '9494501', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '上桐', 'カミギリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市黒坂', '15', '15202', '9494502', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '黒坂', 'クロサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市和島北野', '15', '15202', '9494503', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '和島北野', 'ワシマキタノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市三瀬ケ谷', '15', '15202', '9494504', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '三瀬ケ谷', 'サンゼガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市根小屋', '15', '15202', '9494505', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '根小屋', 'ネゴヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市荒巻', '15', '15202', '9494506', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '荒巻', 'アラマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市下富岡', '15', '15202', '9494507', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '下富岡', 'シモトミオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市小島谷', '15', '15202', '9494511', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '小島谷', 'オジマヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市若野浦', '15', '15202', '9494512', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '若野浦', 'ワカノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市阿弥陀瀬', '15', '15202', '9494513', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '阿弥陀瀬', 'アミダセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市日野浦', '15', '15202', '9494514', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '日野浦', 'ヒノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市和島高畑', '15', '15202', '9494515', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '和島高畑', 'ワシマタカバタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市和島中沢', '15', '15202', '9494516', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '和島中沢', 'ワシマナカサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市梅田', '15', '15202', '9494517', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '梅田', 'ウメダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市東保内', '15', '15202', '9494521', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '東保内', 'ヒガシホナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市村田', '15', '15202', '9494522', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '村田', 'ムラタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市城之丘', '15', '15202', '9494523', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '城之丘', 'ジョウノオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市両高', '15', '15202', '9494524', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '両高', 'リョウタカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市島崎', '15', '15202', '9494525', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '島崎', 'シマザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市西谷', '15', '15202', '9495121', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '西谷', 'ニシダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市東谷', '15', '15202', '9495122', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '東谷', 'ヒガシダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市塚野山', '15', '15202', '9495123', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '塚野山', 'ツカノヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市千谷沢', '15', '15202', '9495124', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '千谷沢', 'チヤザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市小国町千谷沢', '15', '15202', '9495201', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '小国町千谷沢', 'オグニマチチヤザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市小国町七日町', '15', '15202', '9495211', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '小国町七日町', 'オグニマチナノカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市小国町桐沢', '15', '15202', '9495212', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '小国町桐沢', 'オグニマチキリサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市小国町法坂', '15', '15202', '9495213', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '小国町法坂', 'オグニマチホウザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市小国町上谷内新田', '15', '15202', '9495214', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '小国町上谷内新田', 'オグニマチカミヤウチシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市小国町新町', '15', '15202', '9495215', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '小国町新町', 'オグニマチアラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市小国町相野原', '15', '15202', '9495216', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '小国町相野原', 'オグニマチアイノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市小国町二本柳', '15', '15202', '9495217', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '小国町二本柳', 'オグニマチニホンヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市小国町武石', '15', '15202', '9495221', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '小国町武石', 'オグニマチタケイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市小国町横沢', '15', '15202', '9495222', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '小国町横沢', 'オグニマチヨコサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市小国町八王子', '15', '15202', '9495223', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '小国町八王子', 'オグニマチハチオウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市小国町楢沢', '15', '15202', '9495331', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '小国町楢沢', 'オグニマチナラサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市小国町上岩田', '15', '15202', '9495332', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '小国町上岩田', 'オグニマチカミイワタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市小国町小国沢', '15', '15202', '9495333', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '小国町小国沢', 'オグニマチオグニサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市小国町法末', '15', '15202', '9495334', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '小国町法末', 'オグニマチホウスエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市小国町太郎丸', '15', '15202', '9495335', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '小国町太郎丸', 'オグニマチタロウマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市小国町諏訪井', '15', '15202', '9495336', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '小国町諏訪井', 'オグニマチスワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市小国町小栗山', '15', '15202', '9495341', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '小国町小栗山', 'オグニマチコグリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市小国町森光', '15', '15202', '9495342', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '小国町森光', 'オグニマチモリミツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市小国町原', '15', '15202', '9495343', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '小国町原', 'オグニマチハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市小国町苔野島', '15', '15202', '9495344', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '小国町苔野島', 'オグニマチコケノシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市小国町三桶', '15', '15202', '9495345', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '小国町三桶', 'オグニマチミオケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市小国町大貝', '15', '15202', '9495346', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '小国町大貝', 'オグニマチオオガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市小国町山野田', '15', '15202', '9495347', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '小国町山野田', 'オグニマチヤマノタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市飯島', '15', '15202', '9495401', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '飯島', 'イイジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市篠花', '15', '15202', '9495402', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '篠花', 'ササバナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市越路中島', '15', '15202', '9495403', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '越路中島', 'コシジナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市釜ケ島', '15', '15202', '9495404', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '釜ケ島', 'カマガシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市岩野', '15', '15202', '9495405', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '岩野', 'イワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市浦', '15', '15202', '9495406', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '浦', 'ウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市神谷', '15', '15202', '9495407', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '神谷', 'カミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市越路中沢', '15', '15202', '9495408', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '越路中沢', 'コシジナカザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市西野', '15', '15202', '9495409', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '西野', 'ニシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市来迎寺', '15', '15202', '9495411', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '来迎寺', 'ライコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市朝日', '15', '15202', '9495412', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '朝日', 'アサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市沢下条', '15', '15202', '9495413', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '沢下条', 'サワゲイジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市飯塚', '15', '15202', '9495414', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '飯塚', 'イイヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市岩田', '15', '15202', '9495415', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '岩田', 'イワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市不動沢', '15', '15202', '9495416', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '不動沢', 'フドウサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼郡湯沢町', '15', '15461', '9496100', '新潟県', 'ニイガタケン', '南魚沼郡湯沢町', 'ミナミウオヌマグンユザワマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('131806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼郡湯沢町湯沢', '15', '15461', '9496101', '新潟県', 'ニイガタケン', '南魚沼郡湯沢町', 'ミナミウオヌマグンユザワマチ', '湯沢', 'ユザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼郡湯沢町神立', '15', '15461', '9496102', '新潟県', 'ニイガタケン', '南魚沼郡湯沢町', 'ミナミウオヌマグンユザワマチ', '神立', 'カンダツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼郡湯沢町土樽', '15', '15461', '9496103', '新潟県', 'ニイガタケン', '南魚沼郡湯沢町', 'ミナミウオヌマグンユザワマチ', '土樽', 'ツチダル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼郡湯沢町三俣', '15', '15461', '9496211', '新潟県', 'ニイガタケン', '南魚沼郡湯沢町', 'ミナミウオヌマグンユザワマチ', '三俣', 'ミツマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼郡湯沢町三国', '15', '15461', '9496212', '新潟県', 'ニイガタケン', '南魚沼郡湯沢町', 'ミナミウオヌマグンユザワマチ', '三国', 'ミクニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市大沢', '15', '15226', '9496361', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '大沢', 'オオサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市南田中', '15', '15226', '9496362', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '南田中', 'ミナミタナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市下一日市', '15', '15226', '9496363', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '下一日市', 'シモヒトイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市上一日市', '15', '15226', '9496364', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '上一日市', 'カミヒトイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市宮野下', '15', '15226', '9496365', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '宮野下', 'ミヤノシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市君沢', '15', '15226', '9496366', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '君沢', 'キミザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市関', '15', '15226', '9496371', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '関', 'セキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市石打', '15', '15226', '9496372', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '石打', 'イシウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市上野', '15', '15226', '9496373', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '上野', 'ウワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市栃窪', '15', '15226', '9496401', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '栃窪', 'トチクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市吉里', '15', '15226', '9496402', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '吉里', 'ヨシザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市思川', '15', '15226', '9496403', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '思川', 'オモイガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市片田', '15', '15226', '9496404', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '片田', 'カタタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市竹俣', '15', '15226', '9496405', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '竹俣', 'タケマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市竹俣新田', '15', '15226', '9496406', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '竹俣新田', 'タケマタシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市島新田', '15', '15226', '9496407', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '島新田', 'シマシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市塩沢', '15', '15226', '9496408', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '塩沢', 'シオザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市上十日町', '15', '15226', '9496411', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '上十日町', 'カミトオカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市大里', '15', '15226', '9496412', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '大里', 'オオザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市小木六', '15', '15226', '9496413', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '小木六', 'コギロク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市八竜新田', '15', '15226', '9496414', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '八竜新田', 'ハチリュウシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市小杉新田', '15', '15226', '9496415', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '小杉新田', 'コスギシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市大木六', '15', '15226', '9496416', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '大木六', 'オオギロク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市吉山新田', '15', '15226', '9496417', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '吉山新田', 'ヨシヤマシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市仙石', '15', '15226', '9496418', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '仙石', 'センゴク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市中子新田甲', '15', '15226', '9496421', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '中子新田甲', 'ナカゴシンデンコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市徳田新田', '15', '15226', '9496422', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '徳田新田', 'トクダシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市舞子', '15', '15226', '9496423', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '舞子', 'マイゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市万条新田', '15', '15226', '9496424', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '万条新田', 'マンジョウシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市姥島新田', '15', '15226', '9496425', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '姥島新田', 'ウバシマシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市丸池新田', '15', '15226', '9496426', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '丸池新田', 'マルイケシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市中子新田乙', '15', '15226', '9496427', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '中子新田乙', 'ナカゴシンデンオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市五郎丸', '15', '15226', '9496428', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '五郎丸', 'ゴロウマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市樺野沢', '15', '15226', '9496431', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '樺野沢', 'カバノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市樺野沢新田', '15', '15226', '9496432', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '樺野沢新田', 'カバノサワシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市泉盛寺', '15', '15226', '9496433', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '泉盛寺', 'センジョウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市天野沢', '15', '15226', '9496434', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '天野沢', 'アマノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市目来田', '15', '15226', '9496435', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '目来田', 'モクライデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市中', '15', '15226', '9496436', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '中', 'ナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市中野', '15', '15226', '9496437', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '中野', 'ナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市大木六新田', '15', '15226', '9496438', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '大木六新田', 'オオギロクシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市三郎丸', '15', '15226', '9496541', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '三郎丸', 'サブロウマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市雲洞', '15', '15226', '9496542', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '雲洞', 'ウントウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市早川', '15', '15226', '9496543', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '早川', 'ハヤカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市枝吉', '15', '15226', '9496544', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '枝吉', 'エダヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市長崎', '15', '15226', '9496545', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '長崎', 'ナガサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市姥沢新田', '15', '15226', '9496551', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '姥沢新田', 'ウバサワシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市蟹沢新田', '15', '15226', '9496552', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '蟹沢新田', 'カニサワシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市清水', '15', '15226', '9496553', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '清水', 'シミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市一之沢', '15', '15226', '9496554', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '一之沢', 'イチノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市滝谷', '15', '15226', '9496555', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '滝谷', 'タキヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市大木六小松沢', '15', '15226', '9496556', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '大木六', 'オオギロク', null, null, '小松沢', 'コマツザワ');
INSERT INTO `ms_addresses` VALUES ('131866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市台上', '15', '15226', '9496557', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '台上', 'ダイウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市', '15', '15226', '9496600', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('131868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市君帰', '15', '15226', '9496601', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '君帰', 'キミガエリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市欠之上', '15', '15226', '9496602', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '欠之上', 'カケノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市川窪', '15', '15226', '9496603', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '川窪', 'カワクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市庄之又', '15', '15226', '9496604', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '庄之又', 'ショウノマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市青木新田', '15', '15226', '9496605', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '青木新田', 'アオキシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市宇津野新田', '15', '15226', '9496607', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '宇津野新田', 'ウツノシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市美佐島', '15', '15226', '9496608', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '美佐島', 'ミサシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市八幡', '15', '15226', '9496609', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '八幡', 'ヤワタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市坂戸', '15', '15226', '9496611', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '坂戸', 'サカド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市東泉田', '15', '15226', '9496612', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '東泉田', 'ヒガシイズミダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市下大月', '15', '15226', '9496613', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '下大月', 'シモオオツキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市上大月', '15', '15226', '9496614', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '上大月', 'カミオオヅキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市西泉田', '15', '15226', '9496615', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '西泉田', 'ニシイズミダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市沖町', '15', '15226', '9496616', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '沖町', 'オキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市田中町', '15', '15226', '9496621', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '田中町', 'タナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市仲町', '15', '15226', '9496622', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '仲町', 'ナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市上町', '15', '15226', '9496623', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '上町', 'カンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市大和町', '15', '15226', '9496624', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '大和町', 'ヤマトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市伊勢町', '15', '15226', '9496625', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '伊勢町', 'イセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市旭町', '15', '15226', '9496626', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '旭町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市飯綱町', '15', '15226', '9496631', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '飯綱町', 'イイヅナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市余川本町', '15', '15226', '9496632', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '余川本町', 'ヨカワホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市学校町', '15', '15226', '9496633', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '学校町', 'ガッコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市緑町', '15', '15226', '9496634', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '緑町', 'ミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市栄町', '15', '15226', '9496635', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市小栗山', '15', '15226', '9496636', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '小栗山', 'コグリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市上ノ原', '15', '15226', '9496637', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '上ノ原', 'ウエノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市北辰', '15', '15226', '9496641', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '北辰', 'ホクシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市清水瀬', '15', '15226', '9496741', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '清水瀬', 'シミズセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市野中', '15', '15226', '9496742', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '野中', 'ノナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市舞台', '15', '15226', '9496743', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '舞台', 'ブタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市土沢', '15', '15226', '9496744', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '土沢', 'ツチサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市小川', '15', '15226', '9496745', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '小川', 'オガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市畔地', '15', '15226', '9496746', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '畔地', 'アゼチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市畔地新田', '15', '15226', '9496751', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '畔地新田', 'アゼチシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市日の出町', '15', '15226', '9496752', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '日の出町', 'ヒノデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市蛭窪', '15', '15226', '9496753', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '蛭窪', 'ヒルクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市永松', '15', '15226', '9496754', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '永松', 'ナガマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市原', '15', '15226', '9496755', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '原', 'ハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市京岡', '15', '15226', '9496756', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '京岡', 'キョウオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市京岡新田', '15', '15226', '9496757', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '京岡新田', 'キョウオカシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市中川', '15', '15226', '9496761', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '中川', 'ナカガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市中川新田', '15', '15226', '9496762', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '中川新田', 'ナカガワシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市山谷', '15', '15226', '9496763', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '山谷', 'ヤマヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市宮村下新田', '15', '15226', '9496764', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '宮村下新田', 'ミヤムラシモシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市岩崎', '15', '15226', '9496765', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '岩崎', 'イワサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市津久野上新田', '15', '15226', '9496766', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '津久野上新田', 'ツクノカミシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市津久野', '15', '15226', '9496771', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '津久野', 'ツクノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市二日町', '15', '15226', '9496772', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '二日町', 'フツカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市津久野下新田', '15', '15226', '9496773', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '津久野下新田', 'ツクノシモシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市深沢', '15', '15226', '9496774', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '深沢', 'フカサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市宮', '15', '15226', '9496775', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '宮', 'ミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市五日町', '15', '15226', '9497101', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '五日町', 'イツカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市奥', '15', '15226', '9497102', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '奥', 'オク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市大杉新田', '15', '15226', '9497103', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '大杉新田', 'オオスギシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市寺尾', '15', '15226', '9497104', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '寺尾', 'テラオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市麓', '15', '15226', '9497111', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '麓', 'フモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市長森', '15', '15226', '9497112', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '長森', 'ナガモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市下原', '15', '15226', '9497113', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '下原', 'シモハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市泉', '15', '15226', '9497114', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '泉', 'イズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市泉新田', '15', '15226', '9497115', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '泉新田', 'イズミシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市下原新田', '15', '15226', '9497116', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '下原新田', 'シモハラシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市長森新田', '15', '15226', '9497117', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '長森新田', 'ナガモリシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市山口', '15', '15226', '9497121', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '山口', 'ヤマグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市岡', '15', '15226', '9497122', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '岡', 'オカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市妙音寺', '15', '15226', '9497123', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '妙音寺', 'ミョウオンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市上薬師堂', '15', '15226', '9497124', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '上薬師堂', 'カミヤクシドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市下薬師堂', '15', '15226', '9497125', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '下薬師堂', 'シモヤクシドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市上出浦', '15', '15226', '9497126', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '上出浦', 'カミイズナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市下出浦', '15', '15226', '9497127', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '下出浦', 'シモイズナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市野際', '15', '15226', '9497131', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '野際', 'ノギワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市藤原', '15', '15226', '9497132', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '藤原', 'フジハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市法音寺', '15', '15226', '9497133', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '法音寺', 'ホウオンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市田崎', '15', '15226', '9497134', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '田崎', 'タザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市新堀新田', '15', '15226', '9497135', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '新堀新田', 'ニイボリシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市新堀', '15', '15226', '9497136', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '新堀', 'ニイボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市上原', '15', '15226', '9497137', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '上原', 'カミハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市上原新田', '15', '15226', '9497138', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '上原新田', 'カミハラシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市青木新田', '15', '15226', '9497141', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '青木新田', 'アオキシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市宇津野新田', '15', '15226', '9497142', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '宇津野新田', 'ウツノシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市北田中', '15', '15226', '9497143', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '北田中', 'キタタナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市野田', '15', '15226', '9497144', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '野田', 'ノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市四十日', '15', '15226', '9497145', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '四十日', 'シトカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市湯谷', '15', '15226', '9497221', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '湯谷', 'ユヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市芋赤', '15', '15226', '9497222', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '芋赤', 'イモアカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市門前', '15', '15226', '9497223', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '門前', 'モンゼン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市大桑原', '15', '15226', '9497224', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '大桑原', 'オオクワバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市山崎', '15', '15226', '9497225', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '山崎', 'ヤマザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市山崎新田', '15', '15226', '9497226', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '山崎新田', 'ヤマザキシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市雷土新田', '15', '15226', '9497227', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '雷土新田', 'イカヅチシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市雷土', '15', '15226', '9497228', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '雷土', 'イカヅチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市前原町', '15', '15226', '9497229', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '前原町', 'マエハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市茗荷沢', '15', '15226', '9497231', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '茗荷沢', 'ミョウガサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市堂島新田', '15', '15226', '9497232', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '堂島新田', 'ドウジマシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市桐沢', '15', '15226', '9497233', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '桐沢', 'キリサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市荒山', '15', '15226', '9497234', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '荒山', 'アラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市荒金', '15', '15226', '9497235', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '荒金', 'アラカネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市茗荷沢新田', '15', '15226', '9497236', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '茗荷沢新田', 'ミョウガサワシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市黒土新田', '15', '15226', '9497241', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '黒土新田', 'クロツチシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市黒土', '15', '15226', '9497242', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '黒土', 'クロツチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市大倉', '15', '15226', '9497243', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '大倉', 'オオクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市船ケ沢新田', '15', '15226', '9497244', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '船ケ沢新田', 'フネガサワシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市穴地', '15', '15226', '9497245', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '穴地', 'アナジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市穴地新田', '15', '15226', '9497246', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '穴地新田', 'アナジシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市八色原', '15', '15226', '9497247', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '八色原', 'ヤイロハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市国際町', '15', '15226', '9497248', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '国際町', 'コクサイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市大崎', '15', '15226', '9497251', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '大崎', 'オオサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市水尾', '15', '15226', '9497252', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '水尾', 'ミズオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市水尾新田', '15', '15226', '9497253', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '水尾新田', 'ミズオシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市今町新田', '15', '15226', '9497254', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '今町新田', 'イママチシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市柳古新田', '15', '15226', '9497255', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '柳古新田', 'リュウコシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市海士ケ島新田', '15', '15226', '9497256', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '海士ケ島新田', 'アマガシマシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市五箇', '15', '15226', '9497301', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '五箇', 'ゴカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市浦佐', '15', '15226', '9497302', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '浦佐', 'ウラサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市芹田', '15', '15226', '9497311', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '芹田', 'セリダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市九日町', '15', '15226', '9497312', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '九日町', 'ココノカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市今町', '15', '15226', '9497313', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '今町', 'イママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市城山新田', '15', '15226', '9497314', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '城山新田', 'ジョウヤマシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市名木沢', '15', '15226', '9497315', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '名木沢', 'ナギサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市一村尾', '15', '15226', '9497316', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '一村尾', 'ヒトムラオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市市野江甲', '15', '15226', '9497317', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '市野江甲', 'イチノエコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('131994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市市野江乙後山', '15', '15226', '9497318', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '市野江乙', 'イチノエオツ', null, null, '後山', 'ウシロヤマ');
INSERT INTO `ms_addresses` VALUES ('131995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南魚沼市市野江丙辻又', '15', '15226', '9497319', '新潟県', 'ニイガタケン', '南魚沼市', 'ミナミウオヌマシ', '市野江丙', 'イチノエヘイ', null, null, '辻又', 'ツジマタ');
INSERT INTO `ms_addresses` VALUES ('131999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市下倉', '15', '15225', '9497401', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '下倉', 'シタグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市田戸', '15', '15225', '9497402', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '田戸', 'タド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市根小屋', '15', '15225', '9497403', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '根小屋', 'ネゴヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市竜光', '15', '15225', '9497404', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '竜光', 'リュウコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市新道島', '15', '15225', '9497405', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '新道島', 'シンドウジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市大石', '15', '15225', '9497411', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '大石', 'オオイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市与五郎新田', '15', '15225', '9497412', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '与五郎新田', 'ヨゴロウシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市堀之内', '15', '15225', '9497413', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '堀之内', 'ホリノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市和長島', '15', '15225', '9497414', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '和長島', 'ワナガシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市田川', '15', '15225', '9497415', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '田川', 'タガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市下島', '15', '15225', '9497416', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '下島', 'シモジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市下新田', '15', '15225', '9497417', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '下新田', 'シモシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市徳田', '15', '15225', '9497418', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '徳田', 'トクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市吉水', '15', '15225', '9497421', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '吉水', 'ヨシミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市原', '15', '15225', '9497422', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '原', 'ハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市魚野地', '15', '15225', '9497423', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '魚野地', 'ウオノジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県魚沼市明神', '15', '15225', '9497424', '新潟県', 'ニイガタケン', '魚沼市', 'ウオヌマシ', '明神', 'ミョウジン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県北魚沼郡川口町', '15', '15441', '9497500', '新潟県', 'ニイガタケン', '北魚沼郡川口町', 'キタウオヌマグンカワグチマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('132021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県北魚沼郡川口町峠', '15', '15441', '9497501', '新潟県', 'ニイガタケン', '北魚沼郡川口町', 'キタウオヌマグンカワグチマチ', '峠', 'トウゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県北魚沼郡川口町木沢', '15', '15441', '9497502', '新潟県', 'ニイガタケン', '北魚沼郡川口町', 'キタウオヌマグンカワグチマチ', '木沢', 'キザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県北魚沼郡川口町中山', '15', '15441', '9497503', '新潟県', 'ニイガタケン', '北魚沼郡川口町', 'キタウオヌマグンカワグチマチ', '中山', 'ナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県北魚沼郡川口町川口', '15', '15441', '9497504', '新潟県', 'ニイガタケン', '北魚沼郡川口町', 'キタウオヌマグンカワグチマチ', '川口', 'カワグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県北魚沼郡川口町牛ケ島', '15', '15441', '9497505', '新潟県', 'ニイガタケン', '北魚沼郡川口町', 'キタウオヌマグンカワグチマチ', '牛ケ島', 'ウシガシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県北魚沼郡川口町武道窪', '15', '15441', '9497506', '新潟県', 'ニイガタケン', '北魚沼郡川口町', 'キタウオヌマグンカワグチマチ', '武道窪', 'ブドウクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県北魚沼郡川口町相川', '15', '15441', '9497507', '新潟県', 'ニイガタケン', '北魚沼郡川口町', 'キタウオヌマグンカワグチマチ', '相川', 'アイカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県北魚沼郡川口町荒谷', '15', '15441', '9497508', '新潟県', 'ニイガタケン', '北魚沼郡川口町', 'キタウオヌマグンカワグチマチ', '荒谷', 'アラヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県北魚沼郡川口町和南津', '15', '15441', '9497511', '新潟県', 'ニイガタケン', '北魚沼郡川口町', 'キタウオヌマグンカワグチマチ', '和南津', 'ワナヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県北魚沼郡川口町田麦山', '15', '15441', '9497512', '新潟県', 'ニイガタケン', '北魚沼郡川口町', 'キタウオヌマグンカワグチマチ', '田麦山', 'タムギヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県北魚沼郡川口町西川口', '15', '15441', '9497513', '新潟県', 'ニイガタケン', '北魚沼郡川口町', 'キタウオヌマグンカワグチマチ', '西川口', 'ニシカワグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県中魚沼郡津南町上郷上田乙', '15', '15482', '9498121', '新潟県', 'ニイガタケン', '中魚沼郡津南町', 'ナカウオヌマグンツナンマチ', '上郷上田乙', 'カミゴウウエダオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県中魚沼郡津南町上郷上田甲', '15', '15482', '9498122', '新潟県', 'ニイガタケン', '中魚沼郡津南町', 'ナカウオヌマグンツナンマチ', '上郷上田甲', 'カミゴウウエダコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県中魚沼郡津南町上郷大井平', '15', '15482', '9498123', '新潟県', 'ニイガタケン', '中魚沼郡津南町', 'ナカウオヌマグンツナンマチ', '上郷大井平', 'カミゴウオオイダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県中魚沼郡津南町上郷子種新田', '15', '15482', '9498124', '新潟県', 'ニイガタケン', '中魚沼郡津南町', 'ナカウオヌマグンツナンマチ', '上郷子種新田', 'カミゴウコタネシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県中魚沼郡津南町上郷宮野原', '15', '15482', '9498125', '新潟県', 'ニイガタケン', '中魚沼郡津南町', 'ナカウオヌマグンツナンマチ', '上郷宮野原', 'カミゴウミヤノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県中魚沼郡津南町上郷寺石', '15', '15482', '9498126', '新潟県', 'ニイガタケン', '中魚沼郡津南町', 'ナカウオヌマグンツナンマチ', '上郷寺石', 'カミゴウテライシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県中魚沼郡津南町結東', '15', '15482', '9498127', '新潟県', 'ニイガタケン', '中魚沼郡津南町', 'ナカウオヌマグンツナンマチ', '結東', 'ケットウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県中魚沼郡津南町', '15', '15482', '9498200', '新潟県', 'ニイガタケン', '中魚沼郡津南町', 'ナカウオヌマグンツナンマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('132042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県中魚沼郡津南町下船渡', '15', '15482', '9498201', '新潟県', 'ニイガタケン', '中魚沼郡津南町', 'ナカウオヌマグンツナンマチ', '下船渡', 'シモフナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県中魚沼郡津南町芦ケ崎', '15', '15482', '9498202', '新潟県', 'ニイガタケン', '中魚沼郡津南町', 'ナカウオヌマグンツナンマチ', '芦ケ崎', 'アシガサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県中魚沼郡津南町赤沢', '15', '15482', '9498203', '新潟県', 'ニイガタケン', '中魚沼郡津南町', 'ナカウオヌマグンツナンマチ', '赤沢', 'アカサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県中魚沼郡津南町谷内', '15', '15482', '9498204', '新潟県', 'ニイガタケン', '中魚沼郡津南町', 'ナカウオヌマグンツナンマチ', '谷内', 'ヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県中魚沼郡津南町上郷上田乙', '15', '15482', '9498205', '新潟県', 'ニイガタケン', '中魚沼郡津南町', 'ナカウオヌマグンツナンマチ', '上郷上田乙', 'カミゴウウエダオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県中魚沼郡津南町外丸', '15', '15482', '9498206', '新潟県', 'ニイガタケン', '中魚沼郡津南町', 'ナカウオヌマグンツナンマチ', '外丸', 'トマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県中魚沼郡津南町三箇', '15', '15482', '9498207', '新潟県', 'ニイガタケン', '中魚沼郡津南町', 'ナカウオヌマグンツナンマチ', '三箇', 'サンガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県中魚沼郡津南町中深見', '15', '15482', '9498311', '新潟県', 'ニイガタケン', '中魚沼郡津南町', 'ナカウオヌマグンツナンマチ', '中深見', 'ナカフカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県中魚沼郡津南町米原', '15', '15482', '9498312', '新潟県', 'ニイガタケン', '中魚沼郡津南町', 'ナカウオヌマグンツナンマチ', '米原', 'マイバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県中魚沼郡津南町秋成', '15', '15482', '9498313', '新潟県', 'ニイガタケン', '中魚沼郡津南町', 'ナカウオヌマグンツナンマチ', '秋成', 'アキナリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県中魚沼郡津南町芦ケ崎石坂', '15', '15482', '9498314', '新潟県', 'ニイガタケン', '中魚沼郡津南町', 'ナカウオヌマグンツナンマチ', '芦ケ崎', 'アシガサキ', null, null, '石坂', 'イシザカ');
INSERT INTO `ms_addresses` VALUES ('132053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県中魚沼郡津南町穴藤', '15', '15482', '9498315', '新潟県', 'ニイガタケン', '中魚沼郡津南町', 'ナカウオヌマグンツナンマチ', '穴藤', 'ケットウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県中魚沼郡津南町結東', '15', '15482', '9498316', '新潟県', 'ニイガタケン', '中魚沼郡津南町', 'ナカウオヌマグンツナンマチ', '結東', 'ケットウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県中魚沼郡津南町大赤沢', '15', '15482', '9498317', '新潟県', 'ニイガタケン', '中魚沼郡津南町', 'ナカウオヌマグンツナンマチ', '大赤沢', 'オオアカサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '長野県下水内郡栄村堺', '20', '20602', '9498321', '長野県', 'ナガノケン', '下水内郡栄村', 'シモミノチグンサカエムラ', '堺', 'サカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市上山', '15', '15210', '9498401', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '上山', 'ウワヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市桂', '15', '15210', '9498402', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '桂', 'カツラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市田沢本村', '15', '15210', '9498403', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '田沢本村', 'タザワホンソン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市如来寺', '15', '15210', '9498404', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '如来寺', 'ニョライジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市芋沢', '15', '15210', '9498405', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '芋沢', 'イモザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市山崎', '15', '15210', '9498406', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '山崎', 'ヤマザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市田中', '15', '15210', '9498407', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '田中', 'タナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市干溝', '15', '15210', '9498408', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '干溝', 'ヒミゾ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市小原', '15', '15210', '9498409', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '小原', 'コハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市倉俣', '15', '15210', '9498412', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '倉俣', 'クラマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市田代', '15', '15210', '9498413', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '田代', 'タシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市荒屋', '15', '15210', '9498414', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '荒屋', 'アラヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市通り山', '15', '15210', '9498415', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '通り山', 'トオリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市高道山', '15', '15210', '9498416', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '高道山', 'コウミチヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市朴木沢', '15', '15210', '9498417', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '朴木沢', 'ホキザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市宮沢', '15', '15210', '9498418', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '宮沢', 'ミヤザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市桔梗原', '15', '15210', '9498419', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '桔梗原', 'キキョウハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市芋川新田', '15', '15210', '9498421', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '芋川新田', 'イモガワシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市市之越', '15', '15210', '9498422', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '市之越', 'イチノコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市鷹羽', '15', '15210', '9498423', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '鷹羽', 'タカバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市東田沢', '15', '15210', '9498424', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '東田沢', 'ヒガシタザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市東田尻', '15', '15210', '9498425', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '東田尻', 'ヒガシタジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市程島', '15', '15210', '9498426', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '程島', 'ホトジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市白羽毛', '15', '15210', '9498427', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '白羽毛', 'シラハケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市土倉', '15', '15210', '9498431', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '土倉', 'ツチクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市倉下', '15', '15210', '9498432', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '倉下', 'クラシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市小出', '15', '15210', '9498433', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '小出', 'コイデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市葎沢', '15', '15210', '9498434', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '葎沢', 'ムグラサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市角間', '15', '15210', '9498435', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '角間', 'カクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市西方', '15', '15210', '9498436', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '西方', 'サイホウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市西田尻', '15', '15210', '9498437', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '西田尻', 'ニシタジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市芋川', '15', '15210', '9498441', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '芋川', 'イモガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市重地', '15', '15210', '9498442', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '重地', 'ジュウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市中里下山', '15', '15210', '9498443', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '中里下山', 'ナカサトシモヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市清田山', '15', '15210', '9498444', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '清田山', 'セイダヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市新里', '15', '15210', '9498445', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '新里', 'アラサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市原町', '15', '15210', '9498446', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '原町', 'ハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市新屋敷', '15', '15210', '9498502', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '新屋敷', 'アラヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市本屋敷', '15', '15210', '9498503', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '本屋敷', 'モトヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市堀之内', '15', '15210', '9498504', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '堀之内', 'ホリノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市宮中', '15', '15210', '9498505', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '宮中', 'ミヤナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市大黒沢', '15', '15210', '9498521', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '大黒沢', 'オオグロサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市伊達', '15', '15210', '9498522', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '伊達', 'ダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市土市', '15', '15210', '9498523', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '土市', 'ドイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市太田島', '15', '15210', '9498524', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '太田島', 'オオタジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市幸町', '15', '15210', '9498525', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市新宮', '15', '15210', '9498526', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '新宮', 'シンミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市小黒沢', '15', '15210', '9498527', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '小黒沢', 'コグロサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市天池', '15', '15210', '9498531', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '天池', 'アマイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市池之尻', '15', '15210', '9498532', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '池之尻', 'イケノシリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市漆島', '15', '15210', '9498533', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '漆島', 'ウルシジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市細尾', '15', '15210', '9498534', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '細尾', 'ホソオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市池沢', '15', '15210', '9498541', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '池沢', 'イケザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市源田', '15', '15210', '9498542', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '源田', 'ゲンタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市鍬柄沢', '15', '15210', '9498543', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '鍬柄沢', 'クワガラザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市当間', '15', '15210', '9498544', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '当間', 'アテマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市野中', '15', '15210', '9498545', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '野中', 'ノナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市馬場', '15', '15210', '9498551', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '馬場', 'ババ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市中在家', '15', '15210', '9498552', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '中在家', 'ナカザイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市南雲', '15', '15210', '9498554', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '南雲', 'ナグモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市大石', '15', '15210', '9498555', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '大石', 'オオイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市珠川', '15', '15210', '9498556', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '珠川', 'タマガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市水沢市之沢', '15', '15210', '9498557', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '水沢市之沢', 'ミズサワイチノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市水沢', '15', '15210', '9498558', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '水沢', 'ミズサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市姿', '15', '15210', '9498561', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '姿', 'スガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市安養寺', '15', '15210', '9498562', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '安養寺', 'アンヨウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市東下組', '15', '15210', '9498601', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '東下組', 'ヒガシシモグミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市上組', '15', '15210', '9498602', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '上組', 'カミグミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市下条', '15', '15210', '9498603', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '下条', 'ゲジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市下組', '15', '15210', '9498604', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '下組', 'シモグミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市中条丁', '15', '15210', '9498611', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '中条丁', 'ナカジョウテイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市新座乙', '15', '15210', '9498612', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '新座乙', 'シンザオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市中条庚', '15', '15210', '9498613', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '中条庚', 'ナカジョウカノエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市中条丙', '15', '15210', '9498614', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '中条丙', 'ナカジョウヘイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市中条甲', '15', '15210', '9498615', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '中条甲', 'ナカジョウコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市中条乙', '15', '15210', '9498616', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '中条乙', 'ナカジョウオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市中条己', '15', '15210', '9498617', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '中条己', 'ナカジョウキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県十日町市中条戊', '15', '15210', '9498618', '新潟県', 'ニイガタケン', '十日町市', 'トオカマチシ', '中条戊', 'ナカジョウボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県小千谷市塩殿', '15', '15208', '9498721', '新潟県', 'ニイガタケン', '小千谷市', 'オヂヤシ', '塩殿', 'シオドノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県小千谷市川井', '15', '15208', '9498722', '新潟県', 'ニイガタケン', '小千谷市', 'オヂヤシ', '川井', 'カワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県小千谷市川井新田', '15', '15208', '9498723', '新潟県', 'ニイガタケン', '小千谷市', 'オヂヤシ', '川井新田', 'カワイシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県小千谷市岩沢', '15', '15208', '9498724', '新潟県', 'ニイガタケン', '小千谷市', 'オヂヤシ', '岩沢', 'イワサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県小千谷市豊久新田', '15', '15208', '9498725', '新潟県', 'ニイガタケン', '小千谷市', 'オヂヤシ', '豊久新田', 'ホウキュウシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県小千谷市真人町', '15', '15208', '9498726', '新潟県', 'ニイガタケン', '小千谷市', 'オヂヤシ', '真人町', 'マットチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県小千谷市池中新田', '15', '15208', '9498727', '新潟県', 'ニイガタケン', '小千谷市', 'オヂヤシ', '池中新田', 'イケナカシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県小千谷市池ケ原', '15', '15208', '9498728', '新潟県', 'ニイガタケン', '小千谷市', 'オヂヤシ', '池ケ原', 'イケガハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県北魚沼郡川口町牛ケ島鷲巣', '15', '15441', '9498731', '新潟県', 'ニイガタケン', '北魚沼郡川口町', 'キタウオヌマグンカワグチマチ', '牛ケ島', 'ウシガシマ', null, null, '鷲巣', 'ワシズ');
INSERT INTO `ms_addresses` VALUES ('132145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道士別市', '01', '01220', '0950000', '北海道', 'ホッカイドウ', '士別市', 'シベツシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('132146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市北区', '15', '15101', '9500000', '新潟県', 'ニイガタケン', '新潟市北区', 'ニイガタシキタク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('132147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市東区', '15', '15102', '9500000', '新潟県', 'ニイガタケン', '新潟市東区', 'ニイガタシヒガシク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('132148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区', '15', '15103', '9500000', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('132149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市江南区', '15', '15104', '9500000', '新潟県', 'ニイガタケン', '新潟市江南区', 'ニイガタシコウナンク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('132150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区', '15', '15107', '9500000', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('132151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区', '15', '15108', '9500000', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('132152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市東区松浜町', '15', '15102', '9500001', '新潟県', 'ニイガタケン', '新潟市東区', 'ニイガタシヒガシク', '松浜町', 'マツハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市東区根室新町', '15', '15102', '9500002', '新潟県', 'ニイガタケン', '新潟市東区', 'ニイガタシヒガシク', '根室新町', 'ネムロシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市東区下山', '15', '15102', '9500003', '新潟県', 'ニイガタケン', '新潟市東区', 'ニイガタシヒガシク', '下山', 'シタヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市東区新川町', '15', '15102', '9500004', '新潟県', 'ニイガタケン', '新潟市東区', 'ニイガタシヒガシク', '新川町', 'シンカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市東区太平', '15', '15102', '9500005', '新潟県', 'ニイガタケン', '新潟市東区', 'ニイガタシヒガシク', '太平', 'タイヘイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道士別市東1条北', '01', '01220', '0950001', '北海道', 'ホッカイドウ', '士別市', 'シベツシ', '東1条北', 'ヒガシ01ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市東区向陽', '15', '15102', '9500011', '新潟県', 'ニイガタケン', '新潟市東区', 'ニイガタシヒガシク', '向陽', 'コウヨウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市東区有楽', '15', '15102', '9500012', '新潟県', 'ニイガタケン', '新潟市東区', 'ニイガタシヒガシク', '有楽', 'ユウラク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市東区白銀', '15', '15102', '9500013', '新潟県', 'ニイガタケン', '新潟市東区', 'ニイガタシヒガシク', '白銀', 'シロガネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市東区松崎', '15', '15102', '9500014', '新潟県', 'ニイガタケン', '新潟市東区', 'ニイガタシヒガシク', '松崎', 'マツサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市東区河渡庚', '15', '15102', '9500015', '新潟県', 'ニイガタケン', '新潟市東区', 'ニイガタシヒガシク', '河渡庚', 'コウドカノエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市東区河渡本町', '15', '15102', '9500016', '新潟県', 'ニイガタケン', '新潟市東区', 'ニイガタシヒガシク', '河渡本町', 'コウドホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市東区新松崎', '15', '15102', '9500017', '新潟県', 'ニイガタケン', '新潟市東区', 'ニイガタシヒガシク', '新松崎', 'シンマツサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道士別市東2条北', '01', '01220', '0950002', '北海道', 'ホッカイドウ', '士別市', 'シベツシ', '東2条北', 'ヒガシ02ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市東区物見山', '15', '15102', '9500021', '新潟県', 'ニイガタケン', '新潟市東区', 'ニイガタシヒガシク', '物見山', 'モノミヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市東区幸栄', '15', '15102', '9500022', '新潟県', 'ニイガタケン', '新潟市東区', 'ニイガタシヒガシク', '幸栄', 'コウエイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市東区松園', '15', '15102', '9500023', '新潟県', 'ニイガタケン', '新潟市東区', 'ニイガタシヒガシク', '松園', 'マツゾノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市東区河渡', '15', '15102', '9500024', '新潟県', 'ニイガタケン', '新潟市東区', 'ニイガタシヒガシク', '河渡', 'コウド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市東区藤見町', '15', '15102', '9500025', '新潟県', 'ニイガタケン', '新潟市東区', 'ニイガタシヒガシク', '藤見町', 'フジミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市東区小金町', '15', '15102', '9500026', '新潟県', 'ニイガタケン', '新潟市東区', 'ニイガタシヒガシク', '小金町', 'コガネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市東区松和町', '15', '15102', '9500027', '新潟県', 'ニイガタケン', '新潟市東区', 'ニイガタシヒガシク', '松和町', 'マツワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市東区小金台', '15', '15102', '9500028', '新潟県', 'ニイガタケン', '新潟市東区', 'ニイガタシヒガシク', '小金台', 'コガネダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道士別市東3条北', '01', '01220', '0950003', '北海道', 'ホッカイドウ', '士別市', 'シベツシ', '東3条北', 'ヒガシ03ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市東区船江町', '15', '15102', '9500031', '新潟県', 'ニイガタケン', '新潟市東区', 'ニイガタシヒガシク', '船江町', 'フナエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市東区河渡甲', '15', '15102', '9500032', '新潟県', 'ニイガタケン', '新潟市東区', 'ニイガタシヒガシク', '河渡甲', 'コウドコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市東区河渡新町', '15', '15102', '9500033', '新潟県', 'ニイガタケン', '新潟市東区', 'ニイガタシヒガシク', '河渡新町', 'コウドシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市東区浜谷町', '15', '15102', '9500034', '新潟県', 'ニイガタケン', '新潟市東区', 'ニイガタシヒガシク', '浜谷町', 'ハマヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市東区平和町', '15', '15102', '9500035', '新潟県', 'ニイガタケン', '新潟市東区', 'ニイガタシヒガシク', '平和町', 'ヘイワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市東区空港西', '15', '15102', '9500036', '新潟県', 'ニイガタケン', '新潟市東区', 'ニイガタシヒガシク', '空港西', 'クウコウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道士別市東4条北', '01', '01220', '0950004', '北海道', 'ホッカイドウ', '士別市', 'シベツシ', '東4条北', 'ヒガシ04ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市東区臨港町', '15', '15102', '9500041', '新潟県', 'ニイガタケン', '新潟市東区', 'ニイガタシヒガシク', '臨港町', 'リンコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市東区東臨港町', '15', '15102', '9500042', '新潟県', 'ニイガタケン', '新潟市東区', 'ニイガタシヒガシク', '東臨港町', 'ヒガシリンコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市東区臨港', '15', '15102', '9500043', '新潟県', 'ニイガタケン', '新潟市東区', 'ニイガタシヒガシク', '臨港', 'リンコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市東区古湊町', '15', '15102', '9500044', '新潟県', 'ニイガタケン', '新潟市東区', 'ニイガタシヒガシク', '古湊町', 'フルミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市東区神明町', '15', '15102', '9500045', '新潟県', 'ニイガタケン', '新潟市東区', 'ニイガタシヒガシク', '神明町', 'シンメイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市東区浜町', '15', '15102', '9500046', '新潟県', 'ニイガタケン', '新潟市東区', 'ニイガタシヒガシク', '浜町', 'ハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市東区臨海町', '15', '15102', '9500047', '新潟県', 'ニイガタケン', '新潟市東区', 'ニイガタシヒガシク', '臨海町', 'リンカイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道士別市東5条北', '01', '01220', '0950005', '北海道', 'ホッカイドウ', '士別市', 'シベツシ', '東5条北', 'ヒガシ05ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市東区桃山町', '15', '15102', '9500051', '新潟県', 'ニイガタケン', '新潟市東区', 'ニイガタシヒガシク', '桃山町', 'モモヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市東区秋葉通', '15', '15102', '9500052', '新潟県', 'ニイガタケン', '新潟市東区', 'ニイガタシヒガシク', '秋葉通', 'アキバドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市東区宝町', '15', '15102', '9500053', '新潟県', 'ニイガタケン', '新潟市東区', 'ニイガタシヒガシク', '宝町', 'タカラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市東区秋葉', '15', '15102', '9500054', '新潟県', 'ニイガタケン', '新潟市東区', 'ニイガタシヒガシク', '秋葉', 'アキバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市東区北葉町', '15', '15102', '9500055', '新潟県', 'ニイガタケン', '新潟市東区', 'ニイガタシヒガシク', '北葉町', 'キタバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市東区古川町', '15', '15102', '9500056', '新潟県', 'ニイガタケン', '新潟市東区', 'ニイガタシヒガシク', '古川町', 'フルカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市東区山の下町', '15', '15102', '9500057', '新潟県', 'ニイガタケン', '新潟市東区', 'ニイガタシヒガシク', '山の下町', 'ヤマノシタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道士別市東6条北', '01', '01220', '0950006', '北海道', 'ホッカイドウ', '士別市', 'シベツシ', '東6条北', 'ヒガシ06ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市東区月見町', '15', '15102', '9500061', '新潟県', 'ニイガタケン', '新潟市東区', 'ニイガタシヒガシク', '月見町', 'ツキミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市東区錦町', '15', '15102', '9500062', '新潟県', 'ニイガタケン', '新潟市東区', 'ニイガタシヒガシク', '錦町', 'ニシキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市東区上王瀬町', '15', '15102', '9500063', '新潟県', 'ニイガタケン', '新潟市東区', 'ニイガタシヒガシク', '上王瀬町', 'カミオウセマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市東区松島', '15', '15102', '9500064', '新潟県', 'ニイガタケン', '新潟市東区', 'ニイガタシヒガシク', '松島', 'マツシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市東区東新町', '15', '15102', '9500065', '新潟県', 'ニイガタケン', '新潟市東区', 'ニイガタシヒガシク', '東新町', 'トウシンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市東区長者町', '15', '15102', '9500066', '新潟県', 'ニイガタケン', '新潟市東区', 'ニイガタシヒガシク', '長者町', 'チョウジャマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市東区大山', '15', '15102', '9500067', '新潟県', 'ニイガタケン', '新潟市東区', 'ニイガタシヒガシク', '大山', 'オオヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道士別市東7条北', '01', '01220', '0950007', '北海道', 'ホッカイドウ', '士別市', 'シベツシ', '東7条北', 'ヒガシ07ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市東区末広町', '15', '15102', '9500071', '新潟県', 'ニイガタケン', '新潟市東区', 'ニイガタシヒガシク', '末広町', 'スエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区竜が島', '15', '15103', '9500072', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '竜が島', 'リュウガシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区日の出', '15', '15103', '9500073', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '日の出', 'ヒノデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区鏡が岡', '15', '15103', '9500074', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '鏡が岡', 'カガミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区沼垂東', '15', '15103', '9500075', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '沼垂東', 'ヌッタリヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区沼垂西', '15', '15103', '9500076', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '沼垂西', 'ヌッタリニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区天明町', '15', '15103', '9500077', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '天明町', 'テンメイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区万代島', '15', '15103', '9500078', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '万代島', 'バンダイジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道士別市東8条北', '01', '01220', '0950008', '北海道', 'ホッカイドウ', '士別市', 'シベツシ', '東8条北', 'ヒガシ08ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区三和町', '15', '15103', '9500081', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '三和町', 'サンワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区東万代町', '15', '15103', '9500082', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '東万代町', 'ヒガシバンダイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区蒲原町', '15', '15103', '9500083', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '蒲原町', 'カンバラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区明石', '15', '15103', '9500084', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '明石', 'アカシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区長嶺町', '15', '15103', '9500085', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '長嶺町', 'ナガミネマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区花園', '15', '15103', '9500086', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '花園', 'ハナゾノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区東大通', '15', '15103', '9500087', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '東大通', 'ヒガシオオドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区万代', '15', '15103', '9500088', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '万代', 'バンダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市東区江口', '15', '15102', '9500101', '新潟県', 'ニイガタケン', '新潟市東区', 'ニイガタシヒガシク', '江口', 'エグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市江南区江口', '15', '15104', '9500101', '新潟県', 'ニイガタケン', '新潟市江南区', 'ニイガタシコウナンク', '江口', 'エグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市北区細山', '15', '15101', '9500102', '新潟県', 'ニイガタケン', '新潟市北区', 'ニイガタシキタク', '細山', 'ホソヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市江南区細山', '15', '15104', '9500102', '新潟県', 'ニイガタケン', '新潟市江南区', 'ニイガタシコウナンク', '細山', 'ホソヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市江南区蔵岡', '15', '15104', '9500103', '新潟県', 'ニイガタケン', '新潟市江南区', 'ニイガタシコウナンク', '蔵岡', 'クラオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市江南区笹山', '15', '15104', '9500104', '新潟県', 'ニイガタケン', '新潟市江南区', 'ニイガタシコウナンク', '笹山', 'ササヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市江南区大淵', '15', '15104', '9500105', '新潟県', 'ニイガタケン', '新潟市江南区', 'ニイガタシコウナンク', '大淵', 'オオブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市東区西野', '15', '15102', '9500106', '新潟県', 'ニイガタケン', '新潟市東区', 'ニイガタシヒガシク', '西野', 'ニシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市江南区西野', '15', '15104', '9500106', '新潟県', 'ニイガタケン', '新潟市江南区', 'ニイガタシコウナンク', '西野', 'ニシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市江南区三百地', '15', '15104', '9500107', '新潟県', 'ニイガタケン', '新潟市江南区', 'ニイガタシコウナンク', '三百地', 'サンビャクジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道士別市東1条', '01', '01220', '0950011', '北海道', 'ホッカイドウ', '士別市', 'シベツシ', '東1条', 'ヒガシ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市江南区直り山', '15', '15104', '9500111', '新潟県', 'ニイガタケン', '新潟市江南区', 'ニイガタシコウナンク', '直り山', 'ナオリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市江南区松山', '15', '15104', '9500112', '新潟県', 'ニイガタケン', '新潟市江南区', 'ニイガタシコウナンク', '松山', 'マツヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市江南区西山', '15', '15104', '9500113', '新潟県', 'ニイガタケン', '新潟市江南区', 'ニイガタシコウナンク', '西山', 'ニシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市江南区茗荷谷', '15', '15104', '9500114', '新潟県', 'ニイガタケン', '新潟市江南区', 'ニイガタシコウナンク', '茗荷谷', 'ミョウガダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市江南区丸山', '15', '15104', '9500115', '新潟県', 'ニイガタケン', '新潟市江南区', 'ニイガタシコウナンク', '丸山', 'マルヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市東区北山', '15', '15102', '9500116', '新潟県', 'ニイガタケン', '新潟市東区', 'ニイガタシヒガシク', '北山', 'キタヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市江南区北山', '15', '15104', '9500116', '新潟県', 'ニイガタケン', '新潟市江南区', 'ニイガタシコウナンク', '北山', 'キタヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道士別市東2条', '01', '01220', '0950012', '北海道', 'ホッカイドウ', '士別市', 'シベツシ', '東2条', 'ヒガシ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市江南区亀田向陽', '15', '15104', '9500121', '新潟県', 'ニイガタケン', '新潟市江南区', 'ニイガタシコウナンク', '亀田向陽', 'カメダコウヨウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市江南区稲葉', '15', '15104', '9500122', '新潟県', 'ニイガタケン', '新潟市江南区', 'ニイガタシコウナンク', '稲葉', 'イナバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市江南区亀田水道町', '15', '15104', '9500123', '新潟県', 'ニイガタケン', '新潟市江南区', 'ニイガタシコウナンク', '亀田水道町', 'カメダスイドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市江南区亀田東町', '15', '15104', '9500124', '新潟県', 'ニイガタケン', '新潟市江南区', 'ニイガタシコウナンク', '亀田東町', 'カメダアヅマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市江南区亀田新明町', '15', '15104', '9500125', '新潟県', 'ニイガタケン', '新潟市江南区', 'ニイガタシコウナンク', '亀田新明町', 'カメダシンメイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市江南区東本町', '15', '15104', '9500126', '新潟県', 'ニイガタケン', '新潟市江南区', 'ニイガタシコウナンク', '東本町', 'ヒガシホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市江南区諏訪', '15', '15104', '9500127', '新潟県', 'ニイガタケン', '新潟市江南区', 'ニイガタシコウナンク', '諏訪', 'スワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市江南区三條岡', '15', '15104', '9500129', '新潟県', 'ニイガタケン', '新潟市江南区', 'ニイガタシコウナンク', '三條岡', 'サンジョウオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道士別市東3条', '01', '01220', '0950013', '北海道', 'ホッカイドウ', '士別市', 'シベツシ', '東3条', 'ヒガシ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市江南区砂山', '15', '15104', '9500130', '新潟県', 'ニイガタケン', '新潟市江南区', 'ニイガタシコウナンク', '砂山', 'スナヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市江南区袋津', '15', '15104', '9500131', '新潟県', 'ニイガタケン', '新潟市江南区', 'ニイガタシコウナンク', '袋津', 'フクロヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市江南区砂岡', '15', '15104', '9500132', '新潟県', 'ニイガタケン', '新潟市江南区', 'ニイガタシコウナンク', '砂岡', 'スナオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市江南区砂崩', '15', '15104', '9500133', '新潟県', 'ニイガタケン', '新潟市江南区', 'ニイガタシコウナンク', '砂崩', 'スナクズレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市江南区曙町', '15', '15104', '9500134', '新潟県', 'ニイガタケン', '新潟市江南区', 'ニイガタシコウナンク', '曙町', 'アケボノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市江南区所島', '15', '15104', '9500135', '新潟県', 'ニイガタケン', '新潟市江南区', 'ニイガタシコウナンク', '所島', 'トコロジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市江南区城所', '15', '15104', '9500136', '新潟県', 'ニイガタケン', '新潟市江南区', 'ニイガタシコウナンク', '城所', 'ジョウショ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市江南区城山', '15', '15104', '9500137', '新潟県', 'ニイガタケン', '新潟市江南区', 'ニイガタシコウナンク', '城山', 'ジョウヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市江南区日水', '15', '15104', '9500138', '新潟県', 'ニイガタケン', '新潟市江南区', 'ニイガタシコウナンク', '日水', 'ヒミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市江南区手代山', '15', '15104', '9500139', '新潟県', 'ニイガタケン', '新潟市江南区', 'ニイガタシコウナンク', '手代山', 'テシロヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道士別市東4条', '01', '01220', '0950014', '北海道', 'ホッカイドウ', '士別市', 'シベツシ', '東4条', 'ヒガシ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市江南区梅見台', '15', '15104', '9500140', '新潟県', 'ニイガタケン', '新潟市江南区', 'ニイガタシコウナンク', '梅見台', 'ウメミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市江南区亀田工業団地', '15', '15104', '9500141', '新潟県', 'ニイガタケン', '新潟市江南区', 'ニイガタシコウナンク', '亀田工業団地', 'カメダコウギョウダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市江南区泥潟', '15', '15104', '9500142', '新潟県', 'ニイガタケン', '新潟市江南区', 'ニイガタシコウナンク', '泥潟', 'ドロガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市江南区元町', '15', '15104', '9500143', '新潟県', 'ニイガタケン', '新潟市江南区', 'ニイガタシコウナンク', '元町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市江南区茅野山', '15', '15104', '9500144', '新潟県', 'ニイガタケン', '新潟市江南区', 'ニイガタシコウナンク', '茅野山', 'チノヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区亀田早通', '15', '15103', '9500145', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '亀田早通', 'カメダハヤドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市江南区亀田早通', '15', '15104', '9500145', '新潟県', 'ニイガタケン', '新潟市江南区', 'ニイガタシコウナンク', '亀田早通', 'カメダハヤドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市江南区丸潟', '15', '15104', '9500146', '新潟県', 'ニイガタケン', '新潟市江南区', 'ニイガタシコウナンク', '丸潟', 'マルガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市江南区長潟', '15', '15104', '9500147', '新潟県', 'ニイガタケン', '新潟市江南区', 'ニイガタシコウナンク', '長潟', 'ナガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市江南区東早通', '15', '15104', '9500148', '新潟県', 'ニイガタケン', '新潟市江南区', 'ニイガタシコウナンク', '東早通', 'ヒガシハヤドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市江南区下早通', '15', '15104', '9500149', '新潟県', 'ニイガタケン', '新潟市江南区', 'ニイガタシコウナンク', '下早通', 'シモハヤドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道士別市東5条', '01', '01220', '0950015', '北海道', 'ホッカイドウ', '士別市', 'シベツシ', '東5条', 'ヒガシ05ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市江南区下早通柳田', '15', '15104', '9500150', '新潟県', 'ニイガタケン', '新潟市江南区', 'ニイガタシコウナンク', '下早通柳田', 'シモハヤドオリヤナギダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市江南区亀田四ツ興野', '15', '15104', '9500151', '新潟県', 'ニイガタケン', '新潟市江南区', 'ニイガタシコウナンク', '亀田四ツ興野', 'カメダヨツゴヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市江南区亀田緑町', '15', '15104', '9500152', '新潟県', 'ニイガタケン', '新潟市江南区', 'ニイガタシコウナンク', '亀田緑町', 'カメダミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市江南区船戸山', '15', '15104', '9500153', '新潟県', 'ニイガタケン', '新潟市江南区', 'ニイガタシコウナンク', '船戸山', 'フナトヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市江南区荻曽根', '15', '15104', '9500154', '新潟県', 'ニイガタケン', '新潟市江南区', 'ニイガタシコウナンク', '荻曽根', 'オギゾネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市江南区泉町', '15', '15104', '9500155', '新潟県', 'ニイガタケン', '新潟市江南区', 'ニイガタシコウナンク', '泉町', 'イズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市江南区早苗', '15', '15104', '9500156', '新潟県', 'ニイガタケン', '新潟市江南区', 'ニイガタシコウナンク', '早苗', 'サナエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区鵜ノ子', '15', '15103', '9500157', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '鵜ノ子', 'ウノコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市江南区鵜ノ子', '15', '15104', '9500157', '新潟県', 'ニイガタケン', '新潟市江南区', 'ニイガタシコウナンク', '鵜ノ子', 'ウノコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道士別市東6条', '01', '01220', '0950016', '北海道', 'ホッカイドウ', '士別市', 'シベツシ', '東6条', 'ヒガシ06ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市東区亀田中島', '15', '15102', '9500161', '新潟県', 'ニイガタケン', '新潟市東区', 'ニイガタシヒガシク', '亀田中島', 'カメダナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市江南区亀田中島', '15', '15104', '9500161', '新潟県', 'ニイガタケン', '新潟市江南区', 'ニイガタシコウナンク', '亀田中島', 'カメダナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市江南区亀田大月', '15', '15104', '9500162', '新潟県', 'ニイガタケン', '新潟市江南区', 'ニイガタシコウナンク', '亀田大月', 'カメダオオツキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市江南区東船場', '15', '15104', '9500163', '新潟県', 'ニイガタケン', '新潟市江南区', 'ニイガタシコウナンク', '東船場', 'ヒガシフナバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市江南区亀田本町', '15', '15104', '9500164', '新潟県', 'ニイガタケン', '新潟市江南区', 'ニイガタシコウナンク', '亀田本町', 'カメダホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市江南区西町', '15', '15104', '9500165', '新潟県', 'ニイガタケン', '新潟市江南区', 'ニイガタシコウナンク', '西町', 'ニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市江南区旭', '15', '15104', '9500166', '新潟県', 'ニイガタケン', '新潟市江南区', 'ニイガタシコウナンク', '旭', 'アサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市江南区五月町', '15', '15104', '9500167', '新潟県', 'ニイガタケン', '新潟市江南区', 'ニイガタシコウナンク', '五月町', 'サツキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市江南区早通', '15', '15104', '9500168', '新潟県', 'ニイガタケン', '新潟市江南区', 'ニイガタシコウナンク', '早通', 'ハヤドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市江南区亀田長潟', '15', '15104', '9500169', '新潟県', 'ニイガタケン', '新潟市江南区', 'ニイガタシコウナンク', '亀田長潟', 'カメダナガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道士別市東7条', '01', '01220', '0950017', '北海道', 'ホッカイドウ', '士別市', 'シベツシ', '東7条', 'ヒガシ07ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道士別市東8条', '01', '01220', '0950018', '北海道', 'ホッカイドウ', '士別市', 'シベツシ', '東8条', 'ヒガシ08ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道士別市大通東', '01', '01220', '0950019', '北海道', 'ホッカイドウ', '士別市', 'シベツシ', '大通東', 'オオドオリヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市江南区駒込', '15', '15104', '9500201', '新潟県', 'ニイガタケン', '新潟市江南区', 'ニイガタシコウナンク', '駒込', 'コマゴメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市江南区藤山', '15', '15104', '9500202', '新潟県', 'ニイガタケン', '新潟市江南区', 'ニイガタシコウナンク', '藤山', 'フジヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市北区小杉', '15', '15101', '9500203', '新潟県', 'ニイガタケン', '新潟市北区', 'ニイガタシキタク', '小杉', 'コスギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市江南区小杉', '15', '15104', '9500203', '新潟県', 'ニイガタケン', '新潟市江南区', 'ニイガタシコウナンク', '小杉', 'コスギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市北区横越', '15', '15101', '9500204', '新潟県', 'ニイガタケン', '新潟市北区', 'ニイガタシキタク', '横越', 'ヨコゴシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市江南区横越', '15', '15104', '9500204', '新潟県', 'ニイガタケン', '新潟市江南区', 'ニイガタシコウナンク', '横越', 'ヨコゴシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市江南区沢海', '15', '15104', '9500205', '新潟県', 'ニイガタケン', '新潟市江南区', 'ニイガタシコウナンク', '沢海', 'ソウミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市江南区木津', '15', '15104', '9500206', '新潟県', 'ニイガタケン', '新潟市江南区', 'ニイガタシコウナンク', '木津', 'キツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市江南区二本木', '15', '15104', '9500207', '新潟県', 'ニイガタケン', '新潟市江南区', 'ニイガタシコウナンク', '二本木', 'ニホンギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市江南区横越中央', '15', '15104', '9500208', '新潟県', 'ニイガタケン', '新潟市江南区', 'ニイガタシコウナンク', '横越中央', 'ヨコゴシチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市江南区横越東町', '15', '15104', '9500209', '新潟県', 'ニイガタケン', '新潟市江南区', 'ニイガタシコウナンク', '横越東町', 'ヨコゴシヒガシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道士別市西1条', '01', '01220', '0950021', '北海道', 'ホッカイドウ', '士別市', 'シベツシ', '西1条', 'ニシ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市江南区横越上町', '15', '15104', '9500210', '新潟県', 'ニイガタケン', '新潟市江南区', 'ニイガタシコウナンク', '横越上町', 'ヨコゴシカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市江南区横越川根町', '15', '15104', '9500211', '新潟県', 'ニイガタケン', '新潟市江南区', 'ニイガタシコウナンク', '横越川根町', 'ヨコゴシカワネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市江南区茜ケ丘', '15', '15104', '9500212', '新潟県', 'ニイガタケン', '新潟市江南区', 'ニイガタシコウナンク', '茜ケ丘', 'アカネガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市江南区木津工業団地', '15', '15104', '9500213', '新潟県', 'ニイガタケン', '新潟市江南区', 'ニイガタシコウナンク', '木津工業団地', 'キツコウギョウダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市江南区うぐいす', '15', '15104', '9500214', '新潟県', 'ニイガタケン', '新潟市江南区', 'ニイガタシコウナンク', 'うぐいす', 'ウグイス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市江南区平山', '15', '15104', '9500215', '新潟県', 'ニイガタケン', '新潟市江南区', 'ニイガタシコウナンク', '平山', 'ヒラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市北区十二前', '15', '15101', '9500216', '新潟県', 'ニイガタケン', '新潟市北区', 'ニイガタシキタク', '十二前', 'ジュウニマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市江南区阿賀野', '15', '15104', '9500217', '新潟県', 'ニイガタケン', '新潟市江南区', 'ニイガタシコウナンク', '阿賀野', 'アガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市江南区いぶき野', '15', '15104', '9500218', '新潟県', 'ニイガタケン', '新潟市江南区', 'ニイガタシコウナンク', 'いぶき野', 'イブキノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道士別市西2条', '01', '01220', '0950022', '北海道', 'ホッカイドウ', '士別市', 'シベツシ', '西2条', 'ニシ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道士別市西3条', '01', '01220', '0950023', '北海道', 'ホッカイドウ', '士別市', 'シベツシ', '西3条', 'ニシ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道士別市西4条', '01', '01220', '0950024', '北海道', 'ホッカイドウ', '士別市', 'シベツシ', '西4条', 'ニシ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道士別市西5条', '01', '01220', '0950025', '北海道', 'ホッカイドウ', '士別市', 'シベツシ', '西5条', 'ニシ05ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道士別市大通西', '01', '01220', '0950029', '北海道', 'ホッカイドウ', '士別市', 'シベツシ', '大通西', 'オオドオリニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道士別市西1条北', '01', '01220', '0950031', '北海道', 'ホッカイドウ', '士別市', 'シベツシ', '西1条北', 'ニシ01ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道士別市西2条北', '01', '01220', '0950032', '北海道', 'ホッカイドウ', '士別市', 'シベツシ', '西2条北', 'ニシ02ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市江南区割野', '15', '15104', '9500321', '新潟県', 'ニイガタケン', '新潟市江南区', 'ニイガタシコウナンク', '割野', 'ワリノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市江南区両川', '15', '15104', '9500322', '新潟県', 'ニイガタケン', '新潟市江南区', 'ニイガタシコウナンク', '両川', 'リョウカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市江南区嘉瀬', '15', '15104', '9500323', '新潟県', 'ニイガタケン', '新潟市江南区', 'ニイガタシコウナンク', '嘉瀬', 'カセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市江南区酒屋町', '15', '15104', '9500324', '新潟県', 'ニイガタケン', '新潟市江南区', 'ニイガタシコウナンク', '酒屋町', 'サカヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市江南区花ノ牧', '15', '15104', '9500325', '新潟県', 'ニイガタケン', '新潟市江南区', 'ニイガタシコウナンク', '花ノ牧', 'ハナノマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市江南区上和田', '15', '15104', '9500326', '新潟県', 'ニイガタケン', '新潟市江南区', 'ニイガタシコウナンク', '上和田', 'カミワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市江南区和田', '15', '15104', '9500327', '新潟県', 'ニイガタケン', '新潟市江南区', 'ニイガタシコウナンク', '和田', 'ワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市江南区舞潟', '15', '15104', '9500328', '新潟県', 'ニイガタケン', '新潟市江南区', 'ニイガタシコウナンク', '舞潟', 'マイガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市江南区平賀', '15', '15104', '9500329', '新潟県', 'ニイガタケン', '新潟市江南区', 'ニイガタシコウナンク', '平賀', 'ヒラガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道士別市西3条北', '01', '01220', '0950033', '北海道', 'ホッカイドウ', '士別市', 'シベツシ', '西3条北', 'ニシ03ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道士別市西4条北', '01', '01220', '0950034', '北海道', 'ホッカイドウ', '士別市', 'シベツシ', '西4条北', 'ニシ04ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道士別市西5条北', '01', '01220', '0950035', '北海道', 'ホッカイドウ', '士別市', 'シベツシ', '西5条北', 'ニシ05ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道士別市大通北', '01', '01220', '0950039', '北海道', 'ホッカイドウ', '士別市', 'シベツシ', '大通北', 'オオドオリキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道士別市東9条', '01', '01220', '0950041', '北海道', 'ホッカイドウ', '士別市', 'シベツシ', '東9条', 'ヒガシ09ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道士別市東10条', '01', '01220', '0950042', '北海道', 'ホッカイドウ', '士別市', 'シベツシ', '東10条', 'ヒガシ10ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道士別市九十九町', '01', '01220', '0950043', '北海道', 'ホッカイドウ', '士別市', 'シベツシ', '九十九町', 'ツクモチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道士別市東山町', '01', '01220', '0950044', '北海道', 'ホッカイドウ', '士別市', 'シベツシ', '東山町', 'ヒガシヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道士別市東丘', '01', '01220', '0950045', '北海道', 'ホッカイドウ', '士別市', 'シベツシ', '東丘', 'ヒガシオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道士別市南町東', '01', '01220', '0950046', '北海道', 'ホッカイドウ', '士別市', 'シベツシ', '南町東', 'ミナミマチヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道士別市南町西', '01', '01220', '0950047', '北海道', 'ホッカイドウ', '士別市', 'シベツシ', '南町西', 'ミナミマチニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道士別市東11条', '01', '01220', '0950048', '北海道', 'ホッカイドウ', '士別市', 'シベツシ', '東11条', 'ヒガシ11ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道士別市北町', '01', '01220', '0950051', '北海道', 'ホッカイドウ', '士別市', 'シベツシ', '北町', 'キタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道士別市学田', '01', '01220', '0950052', '北海道', 'ホッカイドウ', '士別市', 'シベツシ', '学田', 'ガクデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道士別市新学田', '01', '01220', '0950053', '北海道', 'ホッカイドウ', '士別市', 'シベツシ', '新学田', 'シンガクデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道士別市不動町', '01', '01220', '0950054', '北海道', 'ホッカイドウ', '士別市', 'シベツシ', '不動町', 'フドウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道士別市南士別町', '01', '01220', '0950055', '北海道', 'ホッカイドウ', '士別市', 'シベツシ', '南士別町', 'ミナミシベツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道士別市西士別町', '01', '01220', '0950056', '北海道', 'ホッカイドウ', '士別市', 'シベツシ', '西士別町', 'ニシシベツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道士別市下士別町', '01', '01220', '0950061', '北海道', 'ホッカイドウ', '士別市', 'シベツシ', '下士別町', 'シモシベツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道士別市武徳町', '01', '01220', '0950062', '北海道', 'ホッカイドウ', '士別市', 'シベツシ', '武徳町', 'ブトクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道士別市中士別町', '01', '01220', '0950063', '北海道', 'ホッカイドウ', '士別市', 'シベツシ', '中士別町', 'ナカシベツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道士別市川西町', '01', '01220', '0950064', '北海道', 'ホッカイドウ', '士別市', 'シベツシ', '川西町', 'カワニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市東区津島屋', '15', '15102', '9500801', '新潟県', 'ニイガタケン', '新潟市東区', 'ニイガタシヒガシク', '津島屋', 'ツシマヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市東区一日市', '15', '15102', '9500802', '新潟県', 'ニイガタケン', '新潟市東区', 'ニイガタシヒガシク', '一日市', 'ヒトイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市東区中興野', '15', '15102', '9500803', '新潟県', 'ニイガタケン', '新潟市東区', 'ニイガタシヒガシク', '中興野', 'ナカゴウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市東区本所', '15', '15102', '9500804', '新潟県', 'ニイガタケン', '新潟市東区', 'ニイガタシヒガシク', '本所', 'ホンジョ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市東区石動', '15', '15102', '9500805', '新潟県', 'ニイガタケン', '新潟市東区', 'ニイガタシヒガシク', '石動', 'イスルギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市東区海老ケ瀬', '15', '15102', '9500806', '新潟県', 'ニイガタケン', '新潟市東区', 'ニイガタシヒガシク', '海老ケ瀬', 'エビガセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市東区木工新町', '15', '15102', '9500807', '新潟県', 'ニイガタケン', '新潟市東区', 'ニイガタシヒガシク', '木工新町', 'モッコウシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市東区海老ケ瀬新町', '15', '15102', '9500808', '新潟県', 'ニイガタケン', '新潟市東区', 'ニイガタシヒガシク', '海老ケ瀬新町', 'エビガセシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市東区柳ケ丘', '15', '15102', '9500809', '新潟県', 'ニイガタケン', '新潟市東区', 'ニイガタシヒガシク', '柳ケ丘', 'ヤナギガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市東区材木町', '15', '15102', '9500811', '新潟県', 'ニイガタケン', '新潟市東区', 'ニイガタシヒガシク', '材木町', 'ザイモクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市東区豊', '15', '15102', '9500812', '新潟県', 'ニイガタケン', '新潟市東区', 'ニイガタシヒガシク', '豊', 'ユタカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市東区大形本町', '15', '15102', '9500813', '新潟県', 'ニイガタケン', '新潟市東区', 'ニイガタシヒガシク', '大形本町', 'オオガタホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市東区逢谷内', '15', '15102', '9500814', '新潟県', 'ニイガタケン', '新潟市東区', 'ニイガタシヒガシク', '逢谷内', 'オウヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市東区岡山', '15', '15102', '9500821', '新潟県', 'ニイガタケン', '新潟市東区', 'ニイガタシヒガシク', '岡山', 'オカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市東区新岡山', '15', '15102', '9500822', '新潟県', 'ニイガタケン', '新潟市東区', 'ニイガタシヒガシク', '新岡山', 'シンオカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市東区東中島', '15', '15102', '9500823', '新潟県', 'ニイガタケン', '新潟市東区', 'ニイガタシヒガシク', '東中島', 'ヒガシナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市東区中島', '15', '15102', '9500824', '新潟県', 'ニイガタケン', '新潟市東区', 'ニイガタシヒガシク', '中島', 'ナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市東区児池', '15', '15102', '9500825', '新潟県', 'ニイガタケン', '新潟市東区', 'ニイガタシヒガシク', '児池', 'チゴイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市東区下場', '15', '15102', '9500831', '新潟県', 'ニイガタケン', '新潟市東区', 'ニイガタシヒガシク', '下場', 'ゲバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市東区下場新町', '15', '15102', '9500832', '新潟県', 'ニイガタケン', '新潟市東区', 'ニイガタシヒガシク', '下場新町', 'ゲバシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市東区下場本町', '15', '15102', '9500833', '新潟県', 'ニイガタケン', '新潟市東区', 'ニイガタシヒガシク', '下場本町', 'ゲバホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市東区石山団地', '15', '15102', '9500834', '新潟県', 'ニイガタケン', '新潟市東区', 'ニイガタシヒガシク', '石山団地', 'イシヤマダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市東区猿ケ馬場', '15', '15102', '9500835', '新潟県', 'ニイガタケン', '新潟市東区', 'ニイガタシヒガシク', '猿ケ馬場', 'サルガババ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市東区東中野山', '15', '15102', '9500836', '新潟県', 'ニイガタケン', '新潟市東区', 'ニイガタシヒガシク', '東中野山', 'ヒガシナカノヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市東区中野山', '15', '15102', '9500841', '新潟県', 'ニイガタケン', '新潟市東区', 'ニイガタシヒガシク', '中野山', 'ナカノヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市江南区中野山', '15', '15104', '9500841', '新潟県', 'ニイガタケン', '新潟市江南区', 'ニイガタシコウナンク', '中野山', 'ナカノヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市東区もえぎ野', '15', '15102', '9500842', '新潟県', 'ニイガタケン', '新潟市東区', 'ニイガタシヒガシク', 'もえぎ野', 'モエギノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市東区粟山', '15', '15102', '9500843', '新潟県', 'ニイガタケン', '新潟市東区', 'ニイガタシヒガシク', '粟山', 'アワヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市江南区粟山', '15', '15104', '9500843', '新潟県', 'ニイガタケン', '新潟市江南区', 'ニイガタシコウナンク', '粟山', 'アワヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市東区新石山', '15', '15102', '9500851', '新潟県', 'ニイガタケン', '新潟市東区', 'ニイガタシヒガシク', '新石山', 'シンイシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市東区石山', '15', '15102', '9500852', '新潟県', 'ニイガタケン', '新潟市東区', 'ニイガタシヒガシク', '石山', 'イシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市東区東明', '15', '15102', '9500853', '新潟県', 'ニイガタケン', '新潟市東区', 'ニイガタシヒガシク', '東明', 'トウメイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市東区南紫竹', '15', '15102', '9500854', '新潟県', 'ニイガタケン', '新潟市東区', 'ニイガタシヒガシク', '南紫竹', 'ミナミシチク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市東区江南', '15', '15102', '9500855', '新潟県', 'ニイガタケン', '新潟市東区', 'ニイガタシヒガシク', '江南', 'コウナン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市東区中山', '15', '15102', '9500861', '新潟県', 'ニイガタケン', '新潟市東区', 'ニイガタシヒガシク', '中山', 'ナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市東区竹尾', '15', '15102', '9500862', '新潟県', 'ニイガタケン', '新潟市東区', 'ニイガタシヒガシク', '竹尾', 'タケオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市東区卸新町', '15', '15102', '9500863', '新潟県', 'ニイガタケン', '新潟市東区', 'ニイガタシヒガシク', '卸新町', 'オロシシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市東区紫竹', '15', '15102', '9500864', '新潟県', 'ニイガタケン', '新潟市東区', 'ニイガタシヒガシク', '紫竹', 'シチク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区紫竹', '15', '15103', '9500864', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '紫竹', 'シチク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区本馬越', '15', '15103', '9500865', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '本馬越', 'モトウマコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区西馬越', '15', '15103', '9500866', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '西馬越', 'ニシウマコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市東区竹尾卸新町', '15', '15102', '9500867', '新潟県', 'ニイガタケン', '新潟市東区', 'ニイガタシヒガシク', '竹尾卸新町', 'タケオオロシシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市東区紫竹卸新町', '15', '15102', '9500868', '新潟県', 'ニイガタケン', '新潟市東区', 'ニイガタシヒガシク', '紫竹卸新町', 'シチクオロシシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市東区山木戸', '15', '15102', '9500871', '新潟県', 'ニイガタケン', '新潟市東区', 'ニイガタシヒガシク', '山木戸', 'ヤマキド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区山木戸', '15', '15103', '9500871', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '山木戸', 'ヤマキド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市東区牡丹山', '15', '15102', '9500872', '新潟県', 'ニイガタケン', '新潟市東区', 'ニイガタシヒガシク', '牡丹山', 'ボタンヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市東区榎町', '15', '15102', '9500881', '新潟県', 'ニイガタケン', '新潟市東区', 'ニイガタシヒガシク', '榎町', 'エノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市東区王瀬新町', '15', '15102', '9500882', '新潟県', 'ニイガタケン', '新潟市東区', 'ニイガタシヒガシク', '王瀬新町', 'オウセシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市東区鴎島町', '15', '15102', '9500883', '新潟県', 'ニイガタケン', '新潟市東区', 'ニイガタシヒガシク', '鴎島町', 'カモメジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市東区榎', '15', '15102', '9500884', '新潟県', 'ニイガタケン', '新潟市東区', 'ニイガタシヒガシク', '榎', 'エノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市東区下木戸', '15', '15102', '9500885', '新潟県', 'ニイガタケン', '新潟市東区', 'ニイガタシヒガシク', '下木戸', 'シモキド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市東区中木戸', '15', '15102', '9500886', '新潟県', 'ニイガタケン', '新潟市東区', 'ニイガタシヒガシク', '中木戸', 'ナカキド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市東区上木戸', '15', '15102', '9500891', '新潟県', 'ニイガタケン', '新潟市東区', 'ニイガタシヒガシク', '上木戸', 'カミキド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市東区寺山', '15', '15102', '9500892', '新潟県', 'ニイガタケン', '新潟市東区', 'ニイガタシヒガシク', '寺山', 'テラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市東区はなみずき', '15', '15102', '9500893', '新潟県', 'ニイガタケン', '新潟市東区', 'ニイガタシヒガシク', 'はなみずき', 'ハナミズキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区弁天', '15', '15103', '9500901', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '弁天', 'ベンテン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区南万代町', '15', '15103', '9500902', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '南万代町', 'ミナミバンダイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区春日町', '15', '15103', '9500903', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '春日町', 'カスガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区水島町', '15', '15103', '9500904', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '水島町', 'ミズシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区天神尾', '15', '15103', '9500905', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '天神尾', 'テンジンオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区東幸町', '15', '15103', '9500906', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '東幸町', 'ヒガシサイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区幸町', '15', '15103', '9500907', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区幸西', '15', '15103', '9500908', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '幸西', 'サイワイニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区八千代', '15', '15103', '9500909', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '八千代', 'ヤチヨ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区笹口', '15', '15103', '9500911', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '笹口', 'ササグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区南笹口', '15', '15103', '9500912', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '南笹口', 'ミナミササグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区鐙', '15', '15103', '9500913', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '鐙', 'アブミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市東区紫竹山', '15', '15102', '9500914', '新潟県', 'ニイガタケン', '新潟市東区', 'ニイガタシヒガシク', '紫竹山', 'シチクヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区紫竹山', '15', '15103', '9500914', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '紫竹山', 'シチクヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区鐙西', '15', '15103', '9500915', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '鐙西', 'アブミニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区米山', '15', '15103', '9500916', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '米山', 'ヨネヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区天神', '15', '15103', '9500917', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '天神', 'テンジン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区京王', '15', '15103', '9500921', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '京王', 'ケイオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区山二ツ', '15', '15103', '9500922', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '山二ツ', 'ヤマフタツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市江南区山二ツ', '15', '15104', '9500922', '新潟県', 'ニイガタケン', '新潟市江南区', 'ニイガタシコウナンク', '山二ツ', 'ヤマフタツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区姥ケ山', '15', '15103', '9500923', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '姥ケ山', 'ウバガヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市江南区姥ケ山', '15', '15104', '9500923', '新潟県', 'ニイガタケン', '新潟市江南区', 'ニイガタシコウナンク', '姥ケ山', 'ウバガヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区美の里', '15', '15103', '9500924', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '美の里', 'ミノリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区弁天橋通', '15', '15103', '9500925', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '弁天橋通', 'ベンテンバシドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区高志', '15', '15103', '9500926', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '高志', 'コウシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区南長潟', '15', '15103', '9500931', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '南長潟', 'ミナミナガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区長潟', '15', '15103', '9500932', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '長潟', 'ナガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市江南区長潟', '15', '15104', '9500932', '新潟県', 'ニイガタケン', '新潟市江南区', 'ニイガタシコウナンク', '長潟', 'ナガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区清五郎', '15', '15103', '9500933', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '清五郎', 'セイゴロウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市江南区清五郎', '15', '15104', '9500933', '新潟県', 'ニイガタケン', '新潟市江南区', 'ニイガタシコウナンク', '清五郎', 'セイゴロウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区女池', '15', '15103', '9500941', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '女池', 'メイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区小張木', '15', '15103', '9500942', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '小張木', 'コバリノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区女池神明', '15', '15103', '9500943', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '女池神明', 'メイケシンメイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区愛宕', '15', '15103', '9500944', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '愛宕', 'アタゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区女池上山', '15', '15103', '9500945', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '女池上山', 'メイケカミヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区女池西', '15', '15103', '9500946', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '女池西', 'メイケニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区女池北', '15', '15103', '9500947', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '女池北', 'メイケキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区女池南', '15', '15103', '9500948', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '女池南', 'メイケミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区桜木町', '15', '15103', '9500949', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '桜木町', 'サクラギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区鳥屋野', '15', '15103', '9500951', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '鳥屋野', 'トヤノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区親松', '15', '15103', '9500952', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '親松', 'オヤマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区大島', '15', '15103', '9500953', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '大島', 'オオジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区美咲町', '15', '15103', '9500954', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '美咲町', 'ミサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区東出来島', '15', '15103', '9500961', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '東出来島', 'ヒガシデキジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区出来島', '15', '15103', '9500962', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '出来島', 'デキジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区南出来島', '15', '15103', '9500963', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '南出来島', 'ミナミデキジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区網川原', '15', '15103', '9500964', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '網川原', 'アミガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区新光町', '15', '15103', '9500965', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '新光町', 'シンコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区近江', '15', '15103', '9500971', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '近江', 'オウミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区新和', '15', '15103', '9500972', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '新和', 'シンワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区上近江', '15', '15103', '9500973', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '上近江', 'カミオウミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区堀之内', '15', '15103', '9500981', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '堀之内', 'ホリノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区堀之内南', '15', '15103', '9500982', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '堀之内南', 'ホリノウチミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区神道寺', '15', '15103', '9500983', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '神道寺', 'カンドウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区女池東', '15', '15103', '9500984', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '女池東', 'メイケヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区和合町', '15', '15103', '9500985', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '和合町', 'ワゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区神道寺南', '15', '15103', '9500986', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '神道寺南', 'カンドウジミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区下所島', '15', '15103', '9500991', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '下所島', 'シモトコロジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区上所上', '15', '15103', '9500992', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '上所上', 'カミトコロカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区上所中', '15', '15103', '9500993', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '上所中', 'カミトコロナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区上所', '15', '15103', '9500994', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '上所', 'カミトコロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区山田', '15', '15107', '9501101', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '山田', 'ヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区善久', '15', '15107', '9501102', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '善久', 'ゼンク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区立仏', '15', '15107', '9501103', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '立仏', 'タチボトケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区寺地', '15', '15107', '9501104', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '寺地', 'テラジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区ときめき東', '15', '15107', '9501105', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', 'ときめき東', 'トキメキヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区ときめき西', '15', '15107', '9501106', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', 'ときめき西', 'トキメキニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区大野町', '15', '15107', '9501111', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '大野町', 'オオノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区金巻', '15', '15107', '9501112', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '金巻', 'カネマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区鳥原新田', '15', '15107', '9501113', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '鳥原新田', 'トッパラシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区小平方', '15', '15107', '9501114', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '小平方', 'コヒラカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区鳥原', '15', '15107', '9501115', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '鳥原', 'トッパラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区板井', '15', '15107', '9501121', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '板井', 'イタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区木場', '15', '15107', '9501122', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '木場', 'キバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区黒鳥', '15', '15107', '9501123', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '黒鳥', 'クロトリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区緒立流通', '15', '15107', '9501124', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '緒立流通', 'オタテリュウツウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区流通', '15', '15107', '9501125', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '流通', 'リュウツウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区北場', '15', '15107', '9501126', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '北場', 'キタバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区大潟', '15', '15107', '9501127', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '大潟', 'オオガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区鍋潟新田', '15', '15103', '9501131', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '鍋潟新田', 'ナベガタシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市江南区鍋潟新田', '15', '15104', '9501131', '新潟県', 'ニイガタケン', '新潟市江南区', 'ニイガタシコウナンク', '鍋潟新田', 'ナベガタシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区丸潟新田', '15', '15103', '9501132', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '丸潟新田', 'マルガタシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市江南区丸潟新田', '15', '15104', '9501132', '新潟県', 'ニイガタケン', '新潟市江南区', 'ニイガタシコウナンク', '丸潟新田', 'マルガタシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区嘉木', '15', '15103', '9501133', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '嘉木', 'カギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市江南区嘉木', '15', '15104', '9501133', '新潟県', 'ニイガタケン', '新潟市江南区', 'ニイガタシコウナンク', '嘉木', 'カギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市江南区天野', '15', '15104', '9501134', '新潟県', 'ニイガタケン', '新潟市江南区', 'ニイガタシコウナンク', '天野', 'アマノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区天野', '15', '15106', '9501134', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '天野', 'アマノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市江南区曽野木', '15', '15104', '9501135', '新潟県', 'ニイガタケン', '新潟市江南区', 'ニイガタシコウナンク', '曽野木', 'ソノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区曽川', '15', '15103', '9501136', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '曽川', 'ソガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市江南区曽川', '15', '15104', '9501136', '新潟県', 'ニイガタケン', '新潟市江南区', 'ニイガタシコウナンク', '曽川', 'ソガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区鐘木', '15', '15103', '9501141', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '鐘木', 'シュモク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市江南区鐘木', '15', '15104', '9501141', '新潟県', 'ニイガタケン', '新潟市江南区', 'ニイガタシコウナンク', '鐘木', 'シュモク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市江南区楚川', '15', '15104', '9501142', '新潟県', 'ニイガタケン', '新潟市江南区', 'ニイガタシコウナンク', '楚川', 'ソガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区俵柳', '15', '15103', '9501143', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '俵柳', 'タワラヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市江南区俵柳', '15', '15104', '9501143', '新潟県', 'ニイガタケン', '新潟市江南区', 'ニイガタシコウナンク', '俵柳', 'タワラヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区祖父興野', '15', '15103', '9501144', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '祖父興野', 'オジゴヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市江南区祖父興野', '15', '15104', '9501144', '新潟県', 'ニイガタケン', '新潟市江南区', 'ニイガタシコウナンク', '祖父興野', 'オジゴヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区久蔵興野', '15', '15103', '9501145', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '久蔵興野', 'キュウゾウゴヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市江南区久蔵興野', '15', '15104', '9501145', '新潟県', 'ニイガタケン', '新潟市江南区', 'ニイガタシコウナンク', '久蔵興野', 'キュウゾウゴヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区太右エ門新田', '15', '15103', '9501146', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '太右エ門新田', 'タウエモンシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市江南区太右エ門新田', '15', '15104', '9501146', '新潟県', 'ニイガタケン', '新潟市江南区', 'ニイガタシコウナンク', '太右エ門新田', 'タウエモンシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区高美町', '15', '15103', '9501147', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '高美町', 'タカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区上沼', '15', '15103', '9501148', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '上沼', 'ウワヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区', '15', '15106', '9501200', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('132534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区大通', '15', '15106', '9501201', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '大通', 'オオドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区大通南', '15', '15106', '9501202', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '大通南', 'オオドオリミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区大通黄金', '15', '15106', '9501203', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '大通黄金', 'オオドオリコガネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区大通西', '15', '15106', '9501204', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '大通西', 'オオドオリニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区杉菜', '15', '15106', '9501208', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '杉菜', 'スギナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区親和町', '15', '15106', '9501209', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '親和町', 'シンワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区白根古川', '15', '15106', '9501211', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '白根古川', 'シロネフルカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区七軒', '15', '15106', '9501212', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '七軒', 'シチケン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区能登', '15', '15106', '9501213', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '能登', 'ノト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区上下諏訪木', '15', '15106', '9501214', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '上下諏訪木', 'ジョウゲスワノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区助次右エ門組', '15', '15106', '9501215', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '助次右エ門組', 'スケジウエモングミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区白根ノ内七軒', '15', '15106', '9501216', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '白根ノ内七軒', 'シロネノウチシチケン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区白根', '15', '15106', '9501217', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '白根', 'シロネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区白根魚町', '15', '15106', '9501218', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '白根魚町', 'シロネサカナマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区神屋', '15', '15106', '9501221', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '神屋', 'カミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区白根東町', '15', '15106', '9501222', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '白根東町', 'シロネアズマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区白根日の出町', '15', '15106', '9501223', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '白根日の出町', 'シロネヒノデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区白根水道町', '15', '15106', '9501224', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '白根水道町', 'シロネスイドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区七軒町', '15', '15106', '9501225', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '七軒町', 'シチケンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区白根四ツ興野', '15', '15106', '9501226', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '白根四ツ興野', 'シロネヨツゴウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区鰺潟', '15', '15106', '9501227', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '鰺潟', 'アジガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区小坂', '15', '15106', '9501231', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '小坂', 'コサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区十五間', '15', '15106', '9501232', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '十五間', 'ジュウゴケン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区保坂', '15', '15106', '9501233', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '保坂', 'ホサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区根岸', '15', '15106', '9501234', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '根岸', 'ネギシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区高井興野', '15', '15106', '9501235', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '高井興野', 'タカイコウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区高井東', '15', '15106', '9501236', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '高井東', 'タカイヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区北田中', '15', '15106', '9501237', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '北田中', 'キタタナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区下塩俵', '15', '15106', '9501241', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '下塩俵', 'シモシオダワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区中塩俵', '15', '15106', '9501242', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '中塩俵', 'ナカシオダワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区松橋', '15', '15106', '9501243', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '松橋', 'マツハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区上塩俵', '15', '15106', '9501244', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '上塩俵', 'カミシオダワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区新山崎町', '15', '15106', '9501245', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '新山崎町', 'シンヤマザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区下山崎', '15', '15106', '9501246', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '下山崎', 'シモヤマザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区山崎興野', '15', '15106', '9501247', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '山崎興野', 'ヤマザキコウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区居宿', '15', '15106', '9501251', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '居宿', 'イシュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区大倉', '15', '15106', '9501252', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '大倉', 'オオクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区大倉新田', '15', '15106', '9501253', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '大倉新田', 'オオクラシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区七穂', '15', '15106', '9501254', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '七穂', 'ナナホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区山王', '15', '15106', '9501255', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '山王', 'サンノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区山王新田', '15', '15106', '9501256', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '山王新田', 'サンノウシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区吉田新田', '15', '15106', '9501257', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '吉田新田', 'ヨシダシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区吉江', '15', '15106', '9501258', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '吉江', 'ヨシエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区味方', '15', '15106', '9501261', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '味方', 'アジカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区味方', '15', '15108', '9501261', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '味方', 'アジカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区西白根', '15', '15106', '9501262', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '西白根', 'ニシシロネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区下曲通', '15', '15106', '9501301', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '下曲通', 'シモマガリドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区上曲通', '15', '15106', '9501302', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '上曲通', 'カミマガリドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区西萱場', '15', '15106', '9501303', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '西萱場', 'ニシカヤバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区月潟', '15', '15106', '9501304', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '月潟', 'ツキガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区大別當', '15', '15106', '9501305', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '大別當', 'オオベツトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区木滑', '15', '15106', '9501311', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '木滑', 'キナメリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区釣寄新', '15', '15106', '9501312', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '釣寄新', 'ツリヨセシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区釣寄新', '15', '15108', '9501312', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '釣寄新', 'ツリヨセシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区釣寄', '15', '15106', '9501313', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '釣寄', 'ツリヨセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区釣寄', '15', '15108', '9501313', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '釣寄', 'ツリヨセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区東長嶋', '15', '15106', '9501314', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '東長嶋', 'ヒガシナガシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区針ケ曽根', '15', '15108', '9501321', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '針ケ曽根', 'ハリガソネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区六分', '15', '15108', '9501322', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '六分', 'ロクブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区東小吉', '15', '15108', '9501323', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '東小吉', 'ヒガシコヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区高野宮', '15', '15108', '9501324', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '高野宮', 'コウノミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区小吉', '15', '15108', '9501325', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '小吉', 'コヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区東船越', '15', '15108', '9501326', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '東船越', 'ヒガシフナコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区中之口', '15', '15108', '9501327', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '中之口', 'ナカノクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区門田', '15', '15108', '9501328', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '門田', 'モンタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区東中', '15', '15108', '9501331', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '東中', 'ヒガシナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区長場', '15', '15108', '9501332', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '長場', 'ナガバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区潟浦新', '15', '15108', '9501333', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '潟浦新', 'カタウラシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区上小吉', '15', '15108', '9501334', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '上小吉', 'カミコヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区道上', '15', '15108', '9501341', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '道上', 'ドウジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区河間', '15', '15108', '9501342', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '河間', 'コウマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区三ツ門', '15', '15108', '9501343', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '三ツ門', 'ミツカド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区福島', '15', '15106', '9501344', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '福島', 'フクジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区福島', '15', '15108', '9501344', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '福島', 'フクジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区羽黒', '15', '15108', '9501345', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '羽黒', 'ハグロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区真木', '15', '15108', '9501346', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '真木', 'マキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区姥島', '15', '15108', '9501347', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '姥島', 'ウバジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区打越', '15', '15108', '9501348', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '打越', 'ウチコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区牧ケ島', '15', '15108', '9501349', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '牧ケ島', 'マキガシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区獺ヶ通', '15', '15106', '9501401', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '獺ヶ通', 'ウスガドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区西酒屋', '15', '15106', '9501402', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '西酒屋', 'ニシサカヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区犬帰新田', '15', '15106', '9501403', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '犬帰新田', 'イヌカエリシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区大郷', '15', '15106', '9501404', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '大郷', 'ダイゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区東笠巻', '15', '15106', '9501405', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '東笠巻', 'ヒガシカサマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区東笠巻新田', '15', '15106', '9501406', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '東笠巻新田', 'ヒガシカサマキシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区鷲ノ木新田', '15', '15106', '9501407', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '鷲ノ木新田', 'ワシノキシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区赤渋', '15', '15106', '9501411', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '赤渋', 'アカシブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区臼井', '15', '15106', '9501412', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '臼井', 'ウスイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区朝捲', '15', '15106', '9501413', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '朝捲', 'アサマクリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区小蔵子', '15', '15106', '9501414', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '小蔵子', 'コゾウス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区引越', '15', '15106', '9501415', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '引越', 'ヒッコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区西笠巻', '15', '15106', '9501416', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '西笠巻', 'ニシカサマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区西笠巻新田', '15', '15106', '9501417', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '西笠巻新田', 'ニシカサマキシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区中山', '15', '15106', '9501421', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '中山', 'ナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区堀掛', '15', '15106', '9501422', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '堀掛', 'ホッカケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区中小見', '15', '15106', '9501423', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '中小見', 'ナカオミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区下八枚', '15', '15106', '9501424', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '下八枚', 'シモハチマイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区戸石', '15', '15106', '9501425', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '戸石', 'トイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区新生町', '15', '15106', '9501426', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '新生町', 'シンセイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区上浦', '15', '15106', '9501428', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '上浦', 'カミウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区上八枚', '15', '15106', '9501431', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '上八枚', 'カミハチマイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区十二道島', '15', '15106', '9501432', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '十二道島', 'ジュウニドウシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区次郎右エ門興野', '15', '15106', '9501433', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '次郎右エ門興野', 'ジロウウエモンコウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区櫛笥', '15', '15106', '9501434', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '櫛笥', 'クシゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区万年', '15', '15106', '9501435', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '万年', 'マンネン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区田尾', '15', '15106', '9501436', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '田尾', 'ダオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区鍋潟', '15', '15106', '9501437', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '鍋潟', 'ナベガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区蜘手興野', '15', '15106', '9501441', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '蜘手興野', 'クモデコウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区鋳物師興野', '15', '15106', '9501442', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '鋳物師興野', 'イモノシゴウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区菱潟', '15', '15106', '9501443', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '菱潟', 'ヒシガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区牛崎', '15', '15106', '9501444', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '牛崎', 'ウシザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区菱潟新田', '15', '15106', '9501445', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '菱潟新田', 'ヒシガタシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区庄瀬', '15', '15106', '9501446', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '庄瀬', 'ショウゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区飯島', '15', '15106', '9501447', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '飯島', 'イイジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区真木', '15', '15106', '9501451', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '真木', 'マキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区古川新田', '15', '15106', '9501452', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '古川新田', 'フルカワシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区兎新田', '15', '15106', '9501453', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '兎新田', 'ウサギシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区上新田', '15', '15106', '9501454', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '上新田', 'カミシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区新飯田', '15', '15106', '9501455', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '新飯田', 'ニイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区茨曽根', '15', '15106', '9501456', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '茨曽根', 'イバラソネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区清水', '15', '15106', '9501457', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '清水', 'シミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区平潟', '15', '15106', '9501461', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '平潟', 'ヒラカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区蔵主', '15', '15106', '9501462', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '蔵主', 'ゾウス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区平潟新田', '15', '15106', '9501463', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '平潟新田', 'ヒラカタシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区下道潟', '15', '15106', '9501464', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '下道潟', 'シモドウガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区上道潟', '15', '15106', '9501465', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '上道潟', 'カミドウガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区沖新保', '15', '15106', '9501466', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '沖新保', 'オキシンボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区東萱場', '15', '15106', '9501467', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '東萱場', 'ヒガシカヤバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区和泉', '15', '15106', '9501471', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '和泉', 'イズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区浦梨', '15', '15106', '9501472', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '浦梨', 'ウラナシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区下木山', '15', '15106', '9501473', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '下木山', 'シモキヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区上木山', '15', '15106', '9501474', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '上木山', 'カミキヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区戸頭', '15', '15106', '9501475', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '戸頭', 'トガシラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区平成町', '15', '15106', '9501476', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '平成町', 'ヘイセイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市南区田中', '15', '15106', '9501477', '新潟県', 'ニイガタケン', '新潟市南区', 'ニイガタシミナミク', '田中', 'タナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道士別市温根別町', '01', '01220', '0950181', '北海道', 'ホッカイドウ', '士別市', 'シベツシ', '温根別町', 'オンネベツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道士別市温根別町伊文', '01', '01220', '0950182', '北海道', 'ホッカイドウ', '士別市', 'シベツシ', '温根別町伊文', 'オンネベツチョウイブン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道士別市温根別町北静川', '01', '01220', '0950183', '北海道', 'ホッカイドウ', '士別市', 'シベツシ', '温根別町北静川', 'オンネベツチョウキタシズカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区浦山', '15', '15107', '9502001', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '浦山', 'ウラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区青山', '15', '15107', '9502002', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '青山', 'アオヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区東青山', '15', '15107', '9502003', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '東青山', 'ヒガシアオヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区平島', '15', '15107', '9502004', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '平島', 'ヘイジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区青山水道', '15', '15107', '9502005', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '青山水道', 'アオヤマスイドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区青山新町', '15', '15107', '9502006', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '青山新町', 'アオヤマシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区小針上山', '15', '15107', '9502011', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '小針上山', 'コバリカミヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区小針台', '15', '15107', '9502012', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '小針台', 'コバリダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区小針が丘', '15', '15107', '9502013', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '小針が丘', 'コバリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区小針西', '15', '15107', '9502014', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '小針西', 'コバリニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区西小針台', '15', '15107', '9502015', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '西小針台', 'ニシコバリダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区小針藤山', '15', '15107', '9502021', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '小針藤山', 'コバリフジヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区小針', '15', '15107', '9502022', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '小針', 'コバリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区小新', '15', '15107', '9502023', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '小新', 'コシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区小新西', '15', '15107', '9502024', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '小新西', 'コシンニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区小針南', '15', '15107', '9502025', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '小針南', 'コバリミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区小針南台', '15', '15107', '9502026', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '小針南台', 'コバリミナミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区小新大通', '15', '15107', '9502027', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '小新大通', 'コシンオオドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区小新南', '15', '15107', '9502028', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '小新南', 'コシンミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区流通センター', '15', '15107', '9502031', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '流通センター', 'リュウツウセンター', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区的場流通', '15', '15107', '9502032', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '的場流通', 'マトバリュウツウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区亀貝', '15', '15107', '9502033', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '亀貝', 'カメガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区新田', '15', '15107', '9502034', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '新田', 'シンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区新通', '15', '15107', '9502035', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '新通', 'シンドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区新通西', '15', '15107', '9502036', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '新通西', 'シンドオリニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区大野', '15', '15107', '9502037', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '大野', 'オオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区新通南', '15', '15107', '9502038', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '新通南', 'シンドオリミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区坂井東', '15', '15107', '9502041', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '坂井東', 'サカイヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区坂井', '15', '15107', '9502042', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '坂井', 'サカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区須賀', '15', '15107', '9502043', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '須賀', 'スガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区坂井砂山', '15', '15107', '9502044', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '坂井砂山', 'サカイスナヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区五十嵐東', '15', '15107', '9502045', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '五十嵐東', 'イカラシヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区寺尾朝日通', '15', '15107', '9502051', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '寺尾朝日通', 'テラオアサヒドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区寺尾', '15', '15107', '9502052', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '寺尾', 'テラオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区寺尾前通', '15', '15107', '9502053', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '寺尾前通', 'テラオマエドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区寺尾東', '15', '15107', '9502054', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '寺尾東', 'テラオヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区寺尾上', '15', '15107', '9502055', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '寺尾上', 'テラオカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区寺尾北', '15', '15107', '9502061', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '寺尾北', 'テラオキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区寺尾中央公園', '15', '15107', '9502062', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '寺尾中央公園', 'テラオチュウオウコウエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区寺尾台', '15', '15107', '9502063', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '寺尾台', 'テラオダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区寺尾西', '15', '15107', '9502064', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '寺尾西', 'テラオニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区西有明町', '15', '15107', '9502071', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '西有明町', 'ニシアリアケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区松美台', '15', '15107', '9502072', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '松美台', 'マツミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区有明町', '15', '15107', '9502073', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '有明町', 'アリアケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区真砂', '15', '15107', '9502074', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '真砂', 'マサゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区松海が丘', '15', '15107', '9502075', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '松海が丘', 'マツミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区上新栄町', '15', '15107', '9502076', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '上新栄町', 'カミシンエイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区五十嵐一の町', '15', '15107', '9502101', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '五十嵐一の町', 'イカラシ01ノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区五十嵐二の町', '15', '15107', '9502102', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '五十嵐二の町', 'イカラシ02ノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区大学南', '15', '15107', '9502111', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '大学南', 'ダイガクミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区内野町', '15', '15107', '9502112', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '内野町', 'ウチノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区内野山手', '15', '15107', '9502113', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '内野山手', 'ウチノヤマテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区槇尾', '15', '15107', '9502121', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '槇尾', 'マキオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区高山', '15', '15107', '9502122', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '高山', 'タカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区笠木', '15', '15107', '9502123', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '笠木', 'カサギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区田潟', '15', '15107', '9502124', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '田潟', 'タガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区中野小屋', '15', '15107', '9502125', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '中野小屋', 'ナカノコヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区大友', '15', '15107', '9502126', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '大友', 'オオトモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区早潟', '15', '15107', '9502131', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '早潟', 'ハヤガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区小瀬', '15', '15107', '9502132', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '小瀬', 'コゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区前野外新田', '15', '15107', '9502133', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '前野外新田', 'マエノソトシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区保古野木', '15', '15107', '9502134', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '保古野木', 'ホコノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区明田', '15', '15107', '9502135', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '明田', 'ミョウデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区勘助郷屋', '15', '15107', '9502136', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '勘助郷屋', 'カンスケゴウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区小見郷屋', '15', '15107', '9502137', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '小見郷屋', 'オミゴウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区藤野木', '15', '15107', '9502138', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '藤野木', 'フジノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区内野潟端', '15', '15107', '9502141', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '内野潟端', 'ウチノカタバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区内野戸中才', '15', '15107', '9502142', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '内野戸中才', 'ウチノドナカサイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区内野早角', '15', '15107', '9502143', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '内野早角', 'ウチノハヤツノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区曽和', '15', '15107', '9502144', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '曽和', 'ソワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区田島', '15', '15107', '9502145', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '田島', 'タジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区金巻新田', '15', '15107', '9502146', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '金巻新田', 'カネマキシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区道河原', '15', '15107', '9502147', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '道河原', 'ドウガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区内野西', '15', '15107', '9502151', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '内野西', 'ウチノニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区五十嵐下崎山', '15', '15107', '9502152', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '五十嵐下崎山', 'イカラシシモサキヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区内野崎山', '15', '15107', '9502153', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '内野崎山', 'ウチノサキヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区内野潟向', '15', '15107', '9502154', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '内野潟向', 'ウチノカタムカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区五十嵐上崎山', '15', '15107', '9502155', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '五十嵐上崎山', 'イカラシカミサキヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区内野関場', '15', '15107', '9502156', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '内野関場', 'ウチノセキバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区五十嵐西', '15', '15107', '9502161', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '五十嵐西', 'イカラシニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区五十嵐中島', '15', '15107', '9502162', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '五十嵐中島', 'イカラシナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区新中浜', '15', '15107', '9502163', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '新中浜', 'シンナカハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区内野中浜', '15', '15107', '9502164', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '内野中浜', 'ウチノナカハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区五十嵐三の町', '15', '15107', '9502171', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '五十嵐三の町', 'イカラシ03ノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区内野上新町', '15', '15107', '9502172', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '内野上新町', 'ウチノカミシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区五十嵐三の町東', '15', '15107', '9502173', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '五十嵐三の町東', 'イカラシ03ノチョウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区五十嵐三の町西', '15', '15107', '9502174', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '五十嵐三の町西', 'イカラシ03ノチョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区五十嵐三の町南', '15', '15107', '9502175', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '五十嵐三の町南', 'イカラシ03ノチョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区五十嵐三の町北', '15', '15107', '9502176', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '五十嵐三の町北', 'イカラシ03ノチョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区五十嵐三の町中', '15', '15107', '9502177', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '五十嵐三の町中', 'イカラシ03ノチョウナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区四ツ郷屋', '15', '15107', '9502201', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '四ツ郷屋', 'ヨツゴウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区中権寺', '15', '15107', '9502251', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '中権寺', 'チュウゴンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区谷内', '15', '15107', '9502252', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '谷内', 'ヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区木山', '15', '15107', '9502253', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '木山', 'キヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区東山', '15', '15107', '9502254', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '東山', 'ヒガシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区神山', '15', '15107', '9502255', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '神山', 'カミヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区山崎', '15', '15107', '9502256', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '山崎', 'ヤマザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区赤塚', '15', '15107', '9502261', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '赤塚', 'アカツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区藤蔵新田', '15', '15107', '9502262', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '藤蔵新田', 'トウゾウシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区坂田', '15', '15107', '9502263', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '坂田', 'サカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区みずき野', '15', '15107', '9502264', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', 'みずき野', 'ミズキノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市北区太郎代', '15', '15101', '9503101', '新潟県', 'ニイガタケン', '新潟市北区', 'ニイガタシキタク', '太郎代', 'タロウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市北区島見町', '15', '15101', '9503102', '新潟県', 'ニイガタケン', '新潟市北区', 'ニイガタシキタク', '島見町', 'シマミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市北区白勢町', '15', '15101', '9503103', '新潟県', 'ニイガタケン', '新潟市北区', 'ニイガタシキタク', '白勢町', 'シロセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市北区東栄町', '15', '15101', '9503104', '新潟県', 'ニイガタケン', '新潟市北区', 'ニイガタシキタク', '東栄町', 'ヒガシサカエマチ', '（ヒガシサカエマチ）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('132806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市北区新富町', '15', '15101', '9503105', '新潟県', 'ニイガタケン', '新潟市北区', 'ニイガタシキタク', '新富町', 'シントミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市北区太夫浜新町', '15', '15101', '9503111', '新潟県', 'ニイガタケン', '新潟市北区', 'ニイガタシキタク', '太夫浜新町', 'タユウハマシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市北区太夫浜', '15', '15101', '9503112', '新潟県', 'ニイガタケン', '新潟市北区', 'ニイガタシキタク', '太夫浜', 'タユウハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市北区松栄町', '15', '15101', '9503113', '新潟県', 'ニイガタケン', '新潟市北区', 'ニイガタシキタク', '松栄町', 'マツエイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市北区名目所', '15', '15101', '9503114', '新潟県', 'ニイガタケン', '新潟市北区', 'ニイガタシキタク', '名目所', 'ナメトコロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市北区松浜新町', '15', '15101', '9503115', '新潟県', 'ニイガタケン', '新潟市北区', 'ニイガタシキタク', '松浜新町', 'マツハマシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市北区神谷内', '15', '15101', '9503116', '新潟県', 'ニイガタケン', '新潟市北区', 'ニイガタシキタク', '神谷内', 'カミヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市北区松浜町', '15', '15101', '9503121', '新潟県', 'ニイガタケン', '新潟市北区', 'ニイガタシキタク', '松浜町', 'マツハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市北区西名目所', '15', '15101', '9503122', '新潟県', 'ニイガタケン', '新潟市北区', 'ニイガタシキタク', '西名目所', 'ニシナメトコロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市北区新元島町', '15', '15101', '9503123', '新潟県', 'ニイガタケン', '新潟市北区', 'ニイガタシキタク', '新元島町', 'シンモトジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市北区三軒屋町', '15', '15101', '9503124', '新潟県', 'ニイガタケン', '新潟市北区', 'ニイガタシキタク', '三軒屋町', 'サンゲンヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市北区松浜本町', '15', '15101', '9503125', '新潟県', 'ニイガタケン', '新潟市北区', 'ニイガタシキタク', '松浜本町', 'マツハマホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市北区松浜', '15', '15101', '9503126', '新潟県', 'ニイガタケン', '新潟市北区', 'ニイガタシキタク', '松浜', 'マツハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市北区松浜みなと', '15', '15101', '9503127', '新潟県', 'ニイガタケン', '新潟市北区', 'ニイガタシキタク', '松浜みなと', 'マツハマミナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市北区松浜東町', '15', '15101', '9503128', '新潟県', 'ニイガタケン', '新潟市北区', 'ニイガタシキタク', '松浜東町', 'マツハマヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市北区濁川', '15', '15101', '9503131', '新潟県', 'ニイガタケン', '新潟市北区', 'ニイガタシキタク', '濁川', 'ニゴリカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市北区松潟', '15', '15101', '9503132', '新潟県', 'ニイガタケン', '新潟市北区', 'ニイガタシキタク', '松潟', 'マツカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市北区すみれ野', '15', '15101', '9503133', '新潟県', 'ニイガタケン', '新潟市北区', 'ニイガタシキタク', 'すみれ野', 'スミレノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市北区新崎', '15', '15101', '9503134', '新潟県', 'ニイガタケン', '新潟市北区', 'ニイガタシキタク', '新崎', 'ニイザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市北区つくし野', '15', '15101', '9503135', '新潟県', 'ニイガタケン', '新潟市北区', 'ニイガタシキタク', 'つくし野', 'ツクシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市北区笹山', '15', '15101', '9503301', '新潟県', 'ニイガタケン', '新潟市北区', 'ニイガタシキタク', '笹山', 'ササヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市北区浜浦', '15', '15101', '9503302', '新潟県', 'ニイガタケン', '新潟市北区', 'ニイガタシキタク', '浜浦', 'ハマウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市北区横土居', '15', '15101', '9503303', '新潟県', 'ニイガタケン', '新潟市北区', 'ニイガタシキタク', '横土居', 'ヨコドイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市北区木崎', '15', '15101', '9503304', '新潟県', 'ニイガタケン', '新潟市北区', 'ニイガタシキタク', '木崎', 'キザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市北区浦ノ入', '15', '15101', '9503305', '新潟県', 'ニイガタケン', '新潟市北区', 'ニイガタシキタク', '浦ノ入', 'ウラノイリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市北区内島見', '15', '15101', '9503306', '新潟県', 'ニイガタケン', '新潟市北区', 'ニイガタシキタク', '内島見', 'ウチシマミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市北区樋ノ入', '15', '15101', '9503307', '新潟県', 'ニイガタケン', '新潟市北区', 'ニイガタシキタク', '樋ノ入', 'ドノイリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市北区下大谷内', '15', '15101', '9503308', '新潟県', 'ニイガタケン', '新潟市北区', 'ニイガタシキタク', '下大谷内', 'シモオオヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市北区北陽', '15', '15101', '9503309', '新潟県', 'ニイガタケン', '新潟市北区', 'ニイガタシキタク', '北陽', 'ホクヨウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市北区横井', '15', '15101', '9503311', '新潟県', 'ニイガタケン', '新潟市北区', 'ニイガタシキタク', '横井', 'ヨコイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市北区笠柳', '15', '15101', '9503312', '新潟県', 'ニイガタケン', '新潟市北区', 'ニイガタシキタク', '笠柳', 'カサヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市北区太田', '15', '15101', '9503313', '新潟県', 'ニイガタケン', '新潟市北区', 'ニイガタシキタク', '太田', 'オオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市北区村新田', '15', '15101', '9503314', '新潟県', 'ニイガタケン', '新潟市北区', 'ニイガタシキタク', '村新田', 'ムラシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市北区朝日町', '15', '15101', '9503315', '新潟県', 'ニイガタケン', '新潟市北区', 'ニイガタシキタク', '朝日町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市北区鳥屋', '15', '15101', '9503316', '新潟県', 'ニイガタケン', '新潟市北区', 'ニイガタシキタク', '鳥屋', 'トヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市北区かぶとやま', '15', '15101', '9503317', '新潟県', 'ニイガタケン', '新潟市北区', 'ニイガタシキタク', 'かぶとやま', 'カブトヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市北区葛塚', '15', '15101', '9503321', '新潟県', 'ニイガタケン', '新潟市北区', 'ニイガタシキタク', '葛塚', 'クズツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市北区嘉山', '15', '15101', '9503322', '新潟県', 'ニイガタケン', '新潟市北区', 'ニイガタシキタク', '嘉山', 'カヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市北区東栄町', '15', '15101', '9503323', '新潟県', 'ニイガタケン', '新潟市北区', 'ニイガタシキタク', '東栄町', 'トウエイチョウ', '（トウエイチョウ）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('132846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市北区前新田', '15', '15101', '9503324', '新潟県', 'ニイガタケン', '新潟市北区', 'ニイガタシキタク', '前新田', 'マエシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市北区白新町', '15', '15101', '9503325', '新潟県', 'ニイガタケン', '新潟市北区', 'ニイガタシキタク', '白新町', 'ハクシンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市北区柳原', '15', '15101', '9503326', '新潟県', 'ニイガタケン', '新潟市北区', 'ニイガタシキタク', '柳原', 'ヤナギハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市北区石動', '15', '15101', '9503327', '新潟県', 'ニイガタケン', '新潟市北区', 'ニイガタシキタク', '石動', 'イスルギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市北区前新田沖', '15', '15101', '9503328', '新潟県', 'ニイガタケン', '新潟市北区', 'ニイガタシキタク', '前新田沖', 'マエシンデンオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市北区新鼻', '15', '15101', '9503331', '新潟県', 'ニイガタケン', '新潟市北区', 'ニイガタシキタク', '新鼻', 'シンバナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市北区新鼻甲', '15', '15101', '9503332', '新潟県', 'ニイガタケン', '新潟市北区', 'ニイガタシキタク', '新鼻甲', 'シンバナコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市北区内沼', '15', '15101', '9503333', '新潟県', 'ニイガタケン', '新潟市北区', 'ニイガタシキタク', '内沼', 'ウチヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市北区大月', '15', '15101', '9503334', '新潟県', 'ニイガタケン', '新潟市北区', 'ニイガタシキタク', '大月', 'オオヅキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市北区上大月', '15', '15101', '9503335', '新潟県', 'ニイガタケン', '新潟市北区', 'ニイガタシキタク', '上大月', 'カミオオヅキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市北区岡新田', '15', '15101', '9503336', '新潟県', 'ニイガタケン', '新潟市北区', 'ニイガタシキタク', '岡新田', 'オカシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市北区里飯野', '15', '15101', '9503337', '新潟県', 'ニイガタケン', '新潟市北区', 'ニイガタシキタク', '里飯野', 'サトイイノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市北区長場', '15', '15101', '9503338', '新潟県', 'ニイガタケン', '新潟市北区', 'ニイガタシキタク', '長場', 'ナガバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市北区新鼻乙', '15', '15101', '9503339', '新潟県', 'ニイガタケン', '新潟市北区', 'ニイガタシキタク', '新鼻乙', 'シンバナオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市北区川西', '15', '15101', '9503341', '新潟県', 'ニイガタケン', '新潟市北区', 'ニイガタシキタク', '川西', 'カワニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市北区美里', '15', '15101', '9503342', '新潟県', 'ニイガタケン', '新潟市北区', 'ニイガタシキタク', '美里', 'ミサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市北区上土地亀', '15', '15101', '9503343', '新潟県', 'ニイガタケン', '新潟市北区', 'ニイガタシキタク', '上土地亀', 'カミドチガメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市北区浦木', '15', '15101', '9503344', '新潟県', 'ニイガタケン', '新潟市北区', 'ニイガタシキタク', '浦木', 'ウラギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市北区長戸', '15', '15101', '9503345', '新潟県', 'ニイガタケン', '新潟市北区', 'ニイガタシキタク', '長戸', 'ナガト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市北区下土地亀', '15', '15101', '9503346', '新潟県', 'ニイガタケン', '新潟市北区', 'ニイガタシキタク', '下土地亀', 'シモドチガメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市北区大瀬柳', '15', '15101', '9503351', '新潟県', 'ニイガタケン', '新潟市北区', 'ニイガタシキタク', '大瀬柳', 'オオセヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市北区長戸呂新田', '15', '15101', '9503352', '新潟県', 'ニイガタケン', '新潟市北区', 'ニイガタシキタク', '長戸呂新田', 'ナガトロシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市北区長戸呂', '15', '15101', '9503353', '新潟県', 'ニイガタケン', '新潟市北区', 'ニイガタシキタク', '長戸呂', 'ナガトロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市北区十二', '15', '15101', '9503354', '新潟県', 'ニイガタケン', '新潟市北区', 'ニイガタシキタク', '十二', 'ジュウニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市北区上堀田', '15', '15101', '9503355', '新潟県', 'ニイガタケン', '新潟市北区', 'ニイガタシキタク', '上堀田', 'カミホリダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市北区山飯野', '15', '15101', '9503356', '新潟県', 'ニイガタケン', '新潟市北区', 'ニイガタシキタク', '山飯野', 'ヤマイイノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市北区平林', '15', '15101', '9503357', '新潟県', 'ニイガタケン', '新潟市北区', 'ニイガタシキタク', '平林', 'ヒラバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市北区灰塚', '15', '15101', '9503358', '新潟県', 'ニイガタケン', '新潟市北区', 'ニイガタシキタク', '灰塚', 'ハイズカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市北区新井郷', '15', '15101', '9503361', '新潟県', 'ニイガタケン', '新潟市北区', 'ニイガタシキタク', '新井郷', 'ニイゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市北区高森新田', '15', '15101', '9503362', '新潟県', 'ニイガタケン', '新潟市北区', 'ニイガタシキタク', '高森新田', 'タカモリシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市北区大久保', '15', '15101', '9503363', '新潟県', 'ニイガタケン', '新潟市北区', 'ニイガタシキタク', '大久保', 'オオクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市北区大迎', '15', '15101', '9503364', '新潟県', 'ニイガタケン', '新潟市北区', 'ニイガタシキタク', '大迎', 'オオムカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市北区太子堂', '15', '15101', '9503365', '新潟県', 'ニイガタケン', '新潟市北区', 'ニイガタシキタク', '太子堂', 'タイシドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市北区三ツ屋', '15', '15101', '9503366', '新潟県', 'ニイガタケン', '新潟市北区', 'ニイガタシキタク', '三ツ屋', 'ミツヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市北区高森', '15', '15101', '9503367', '新潟県', 'ニイガタケン', '新潟市北区', 'ニイガタシキタク', '高森', 'タカモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市北区森下', '15', '15101', '9503368', '新潟県', 'ニイガタケン', '新潟市北区', 'ニイガタシキタク', '森下', 'モリシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市北区三ツ森川原', '15', '15101', '9503369', '新潟県', 'ニイガタケン', '新潟市北区', 'ニイガタシキタク', '三ツ森川原', 'ミツモリカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市北区下早通', '15', '15101', '9503371', '新潟県', 'ニイガタケン', '新潟市北区', 'ニイガタシキタク', '下早通', 'シモハヤドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市北区早通', '15', '15101', '9503372', '新潟県', 'ニイガタケン', '新潟市北区', 'ニイガタシキタク', '早通', 'ハヤドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市北区須戸', '15', '15101', '9503373', '新潟県', 'ニイガタケン', '新潟市北区', 'ニイガタシキタク', '須戸', 'スド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市北区仏伝', '15', '15101', '9503374', '新潟県', 'ニイガタケン', '新潟市北区', 'ニイガタシキタク', '仏伝', 'ブツデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市北区早通南', '15', '15101', '9503375', '新潟県', 'ニイガタケン', '新潟市北区', 'ニイガタシキタク', '早通南', 'ハヤドオリミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市北区早通北', '15', '15101', '9503376', '新潟県', 'ニイガタケン', '新潟市北区', 'ニイガタシキタク', '早通北', 'ハヤドオリキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市北区彩野', '15', '15101', '9503377', '新潟県', 'ニイガタケン', '新潟市北区', 'ニイガタシキタク', '彩野', 'アヤノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市北区内沼沖', '15', '15101', '9503381', '新潟県', 'ニイガタケン', '新潟市北区', 'ニイガタシキタク', '内沼沖', 'ウチヌマオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道士別市上士別町', '01', '01220', '0950371', '北海道', 'ホッカイドウ', '士別市', 'シベツシ', '上士別町', 'カミシベツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道士別市朝日町中央', '01', '01220', '0950401', '北海道', 'ホッカイドウ', '士別市', 'シベツシ', '朝日町中央', 'アサヒチョウチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道士別市朝日町登和里', '01', '01220', '0950402', '北海道', 'ホッカイドウ', '士別市', 'シベツシ', '朝日町登和里', 'アサヒチョウトワリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道士別市朝日町岩尾内', '01', '01220', '0950403', '北海道', 'ホッカイドウ', '士別市', 'シベツシ', '朝日町岩尾内', 'アサヒチョウイワオナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道士別市朝日町茂志利', '01', '01220', '0950404', '北海道', 'ホッカイドウ', '士別市', 'シベツシ', '朝日町茂志利', 'アサヒチョウモシリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道士別市朝日町三栄', '01', '01220', '0950405', '北海道', 'ホッカイドウ', '士別市', 'シベツシ', '朝日町三栄', 'アサヒチョウサンエイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('132898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道士別市朝日町南朝日', '01', '01220', '0950406', '北海道', 'ホッカイドウ', '士別市', 'シベツシ', '朝日町南朝日', 'アサヒチョウミナミアサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区海辺町', '15', '15103', '9518001', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '海辺町', 'ウミベチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区船見町', '15', '15103', '9518002', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '船見町', 'フナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区雲雀町', '15', '15103', '9518003', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '雲雀町', 'ヒバリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区山田町', '15', '15103', '9518004', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '山田町', 'ヤマダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区室町', '15', '15103', '9518005', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '室町', 'ムロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区附船町', '15', '15103', '9518006', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '附船町', 'ツケフネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区忠蔵町', '15', '15103', '9518007', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '忠蔵町', 'チュウゾウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区窪田町', '15', '15103', '9518008', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '窪田町', 'クボタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区入船町', '15', '15103', '9518011', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '入船町', 'イリフネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区東入船町', '15', '15103', '9518012', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '東入船町', 'ヒガシイリフネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区柳島町', '15', '15103', '9518013', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '柳島町', 'ヤナギシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区緑町', '15', '15103', '9518014', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '緑町', 'ミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区松岡町', '15', '15103', '9518015', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '松岡町', 'マツオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区田町', '15', '15103', '9518016', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '田町', 'タマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区艀川岸町', '15', '15103', '9518017', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '艀川岸町', 'ハシケカワギシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区稲荷町', '15', '15103', '9518018', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '稲荷町', 'イナリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区曙町', '15', '15103', '9518021', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '曙町', 'アケボノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区横六番町', '15', '15103', '9518022', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '横六番町', 'ヨコロクバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区夕栄町', '15', '15103', '9518023', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '夕栄町', 'ユウエイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区早川町', '15', '15103', '9518024', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '早川町', 'ハヤカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区赤坂町', '15', '15103', '9518025', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '赤坂町', 'アカサカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区西湊町通', '15', '15103', '9518026', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '西湊町通', 'ニシミナトマチドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区湊町通', '15', '15103', '9518027', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '湊町通', 'ミナトマチドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区東湊町通', '15', '15103', '9518028', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '東湊町通', 'ヒガシミナトマチドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区北毘沙門町', '15', '15103', '9518031', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '北毘沙門町', 'キタビシャモンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区見方町', '15', '15103', '9518032', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '見方町', 'ミカタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区豊照町', '15', '15103', '9518033', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '豊照町', 'トヨテルチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区魁町', '15', '15103', '9518034', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '魁町', 'サキガケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区船場町', '15', '15103', '9518035', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '船場町', 'フナバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区芳町', '15', '15103', '9518036', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '芳町', 'ヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区相生町', '15', '15103', '9518037', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '相生町', 'アイオイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区南毘沙門町', '15', '15103', '9518038', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '南毘沙門町', 'ミナミビシャモンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区本間町', '15', '15103', '9518041', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '本間町', 'ホンマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区住吉町', '15', '15103', '9518042', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '住吉町', 'スミヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区西厩島町', '15', '15103', '9518043', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '西厩島町', 'ニシウマヤジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区東厩島町', '15', '15103', '9518044', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '東厩島町', 'ヒガシウマヤジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区並木町', '15', '15103', '9518045', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '並木町', 'ナミキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区秣川岸通', '15', '15103', '9518046', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '秣川岸通', 'マグサカワギシドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区南多門町', '15', '15103', '9518047', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '南多門町', 'ミナミタモンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区北多門町', '15', '15103', '9518048', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '北多門町', 'キタタモンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区新島町通', '15', '15103', '9518051', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '新島町通', 'シンシマチョウドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区下大川前通', '15', '15103', '9518052', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '下大川前通', 'シモオオカワマエドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区川端町', '15', '15103', '9518053', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '川端町', 'カワバタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区礎町通上一ノ町', '15', '15103', '9518054', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '礎町通上一ノ町', 'イシズエチョウドオリカミイチノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区礎町通', '15', '15103', '9518055', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '礎町通', 'イシズエチョウドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区花町', '15', '15103', '9518056', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '花町', 'ハナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区月町', '15', '15103', '9518057', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '月町', 'ツキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区雪町', '15', '15103', '9518058', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '雪町', 'ユキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区西堀通', '15', '15103', '9518061', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '西堀通', 'ニシボリドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区西堀前通', '15', '15103', '9518062', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '西堀前通', 'ニシボリマエドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区古町通', '15', '15103', '9518063', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '古町通', 'フルマチドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区横一番町', '15', '15103', '9518064', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '横一番町', 'ヨコイチバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区東堀通', '15', '15103', '9518065', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '東堀通', 'ヒガシボリドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区東堀前通', '15', '15103', '9518066', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '東堀前通', 'ヒガシボリマエドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区本町通', '15', '15103', '9518067', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '本町通', 'ホンチョウドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区上大川前通', '15', '15103', '9518068', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '上大川前通', 'カミオオカワマエドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区栄町', '15', '15103', '9518071', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区浮洲町', '15', '15103', '9518072', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '浮洲町', 'ウキスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区寿町', '15', '15103', '9518073', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '寿町', 'コトブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区祝町', '15', '15103', '9518074', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '祝町', 'イワイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区元祝町', '15', '15103', '9518075', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '元祝町', 'モトイワイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区翁町', '15', '15103', '9518076', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '翁町', 'オキナマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区烏帽子町', '15', '15103', '9518077', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '烏帽子町', 'エボシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区四ツ屋町', '15', '15103', '9518078', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '四ツ屋町', 'ヨツヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区寄附町', '15', '15103', '9518081', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '寄附町', 'キフチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区西受地町', '15', '15103', '9518082', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '西受地町', 'ニシウケチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区横七番町通', '15', '15103', '9518083', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '横七番町通', 'ヨコシチバンチョウドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区元下島町', '15', '15103', '9518084', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '元下島町', 'モトシモシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区寺山町', '15', '15103', '9518085', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '寺山町', 'テラヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区寄合町', '15', '15103', '9518086', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '寄合町', 'ヨリアイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区東受地町', '15', '15103', '9518087', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '東受地町', 'ヒガシウケチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区菅根町', '15', '15103', '9518088', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '菅根町', 'スガネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区西船見町', '15', '15103', '9518101', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '西船見町', 'ニシフナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区二葉町', '15', '15103', '9518102', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '二葉町', 'フタバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区田中町', '15', '15103', '9518103', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '田中町', 'タナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区西大畑町', '15', '15103', '9518104', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '西大畑町', 'ニシオオハタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区北大畑町', '15', '15103', '9518105', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '北大畑町', 'キタオオハタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区東大畑通', '15', '15103', '9518106', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '東大畑通', 'ヒガシオオハタドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区南大畑町', '15', '15103', '9518107', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '南大畑町', 'ミナミオオハタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区中大畑町', '15', '15103', '9518108', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '中大畑町', 'ナカオオハタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区北浜通', '15', '15103', '9518111', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '北浜通', 'キタハマドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区南浜通', '15', '15103', '9518112', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '南浜通', 'ミナミハマドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区寄居町', '15', '15103', '9518113', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '寄居町', 'ヨリイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区営所通', '15', '15103', '9518114', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '営所通', 'エイショドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区寺裏通', '15', '15103', '9518115', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '寺裏通', 'テラウラドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区東中通', '15', '15103', '9518116', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '東中通', 'ヒガシナカドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区南横堀町', '15', '15103', '9518117', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '南横堀町', 'ミナミヨコボリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区西中町', '15', '15103', '9518118', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '西中町', 'ニシナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区水道町', '15', '15103', '9518121', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '水道町', 'スイドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区旭町通', '15', '15103', '9518122', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '旭町通', 'アサヒマチドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区下旭町', '15', '15103', '9518123', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '下旭町', 'シモアサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区医学町通', '15', '15103', '9518124', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '医学町通', 'イガクチョウドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区学校裏町', '15', '15103', '9518125', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '学校裏町', 'ガッコウウラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区学校町通', '15', '15103', '9518126', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '学校町通', 'ガッコウチョウドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区関屋下川原町', '15', '15103', '9518127', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '関屋下川原町', 'セキヤシモカワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区白山浦', '15', '15103', '9518131', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '白山浦', 'ハクサンウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区一番堀通町', '15', '15103', '9518132', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '一番堀通町', 'イチバンボリドオリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区川岸町', '15', '15103', '9518133', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '川岸町', 'カワギシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区関屋', '15', '15103', '9518134', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '関屋', 'セキヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区関屋', '15', '15107', '9518134', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '関屋', 'セキヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区関屋新町通', '15', '15103', '9518135', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '関屋新町通', 'セキヤシンマチドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区関屋田町', '15', '15103', '9518136', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '関屋田町', 'セキヤタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区白山浦新町通', '15', '15103', '9518137', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '白山浦新町通', 'ハクサンウラシンマチドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区関新', '15', '15103', '9518141', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '関新', 'セキシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区関屋大川前', '15', '15103', '9518142', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '関屋大川前', 'セキヤオオカワマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区関屋恵町', '15', '15103', '9518143', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '関屋恵町', 'セキヤメグミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区関南町', '15', '15103', '9518144', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '関南町', 'セキナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区有明台', '15', '15103', '9518145', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '有明台', 'アリアケダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区有明大橋町', '15', '15103', '9518146', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '有明大橋町', 'アリアケオオハシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区弥生町', '15', '15103', '9518147', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '弥生町', 'ヤヨイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区浜浦町', '15', '15103', '9518151', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '浜浦町', 'ハマウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区信濃町', '15', '15103', '9518152', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '信濃町', 'シナノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区文京町', '15', '15103', '9518153', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '文京町', 'ブンキョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区堀割町', '15', '15103', '9518154', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '堀割町', 'ホリワリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区関屋堀割町', '15', '15107', '9518155', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '関屋堀割町', 'セキヤホリワリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区汐見台', '15', '15103', '9518156', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '汐見台', 'シオミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区関屋松波町', '15', '15103', '9518161', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '関屋松波町', 'セキヤマツナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区関屋本村町', '15', '15103', '9518162', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '関屋本村町', 'セキヤホンソンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区関屋御船蔵町', '15', '15103', '9518163', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '関屋御船蔵町', 'セキヤオフナグラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区関屋昭和町', '15', '15103', '9518164', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '関屋昭和町', 'セキヤショウワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区関屋金鉢山町', '15', '15103', '9518165', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '関屋金鉢山町', 'セキヤカナバチヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区関屋浜松町', '15', '15103', '9518166', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '関屋浜松町', 'セキヤハママツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市中央区関屋金衛町', '15', '15103', '9518167', '新潟県', 'ニイガタケン', '新潟市中央区', 'ニイガタシチュウオウク', '関屋金衛町', 'セキヤキンエイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市', '15', '15224', '9520000', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('133197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市白瀬', '15', '15224', '9520001', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '白瀬', 'シロセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市北五十里', '15', '15224', '9520002', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '北五十里', 'キタイカリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市椿', '15', '15224', '9520003', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '椿', 'ツバキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市羽吉', '15', '15224', '9520004', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '羽吉', 'ハヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市梅津', '15', '15224', '9520005', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '梅津', 'ウメヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市春日', '15', '15224', '9520006', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '春日', 'カスガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市浜田', '15', '15224', '9520007', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '浜田', 'ハマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市両津夷', '15', '15224', '9520011', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '両津夷', 'リョウツエビス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市両津夷新', '15', '15224', '9520012', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '両津夷新', 'リョウツエビスシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市両津福浦', '15', '15224', '9520013', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '両津福浦', 'リョウツフクウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市両津湊', '15', '15224', '9520014', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '両津湊', 'リョウツミナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市住吉', '15', '15224', '9520015', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '住吉', 'スミヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市原黒', '15', '15224', '9520016', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '原黒', 'ハラクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市秋津', '15', '15224', '9520021', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '秋津', 'アキツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市旭', '15', '15224', '9520022', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '旭', 'アサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市潟端', '15', '15224', '9520023', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '潟端', 'カタバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市上横山', '15', '15224', '9520024', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '上横山', 'カミヨコヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市下横山', '15', '15224', '9520025', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '下横山', 'シモヨコヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市立野', '15', '15224', '9520026', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '立野', 'タテノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市長江', '15', '15224', '9520027', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '長江', 'ナガエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市加茂歌代', '15', '15224', '9520028', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '加茂歌代', 'カモウタシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市新穂長畝', '15', '15224', '9520101', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '新穂長畝', 'ニイボナガウネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市新穂青木', '15', '15224', '9520102', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '新穂青木', 'ニイボアオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市新穂潟上', '15', '15224', '9520103', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '新穂潟上', 'ニイボカタガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市新穂田野沢', '15', '15224', '9520104', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '新穂田野沢', 'ニイボタノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市新穂正明寺', '15', '15224', '9520105', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '新穂正明寺', 'ニイボショウミョウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市新穂瓜生屋', '15', '15224', '9520106', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '新穂瓜生屋', 'ニイボウリュウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市新穂井内', '15', '15224', '9520107', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '新穂井内', 'ニイボイナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市上新穂', '15', '15224', '9520108', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '上新穂', 'カミニイボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市新穂大野', '15', '15224', '9520109', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '新穂大野', 'ニイボオオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市新穂武井', '15', '15224', '9520111', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '新穂武井', 'ニイボタケイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市新穂舟下', '15', '15224', '9520112', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '新穂舟下', 'ニイボフナシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市新穂皆川', '15', '15224', '9520113', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '新穂皆川', 'ニイボミナガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市下新穂', '15', '15224', '9520114', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '下新穂', 'シモニイボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市新穂北方', '15', '15224', '9520115', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '新穂北方', 'ニイボキタガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市新穂', '15', '15224', '9520116', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '新穂', 'ニイボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市目黒町', '15', '15224', '9520201', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '目黒町', 'メグロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市栗野江', '15', '15224', '9520202', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '栗野江', 'クリノエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市坊ケ浦', '15', '15224', '9520203', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '坊ケ浦', 'ボウガウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市長谷', '15', '15224', '9520204', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '長谷', 'ハセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市小倉', '15', '15224', '9520205', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '小倉', 'オグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市畑野', '15', '15224', '9520206', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '畑野', 'ハタノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市寺田', '15', '15224', '9520207', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '寺田', 'テラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市畉田', '15', '15224', '9520211', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '畉田', 'フタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市宮川', '15', '15224', '9520212', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '宮川', 'ミヤカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市飯持', '15', '15224', '9520213', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '飯持', 'イイモチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市大久保', '15', '15224', '9520214', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '大久保', 'オオクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市猿八', '15', '15224', '9520215', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '猿八', 'サルハチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市三宮', '15', '15224', '9520216', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '三宮', 'サングウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市真野大川', '15', '15224', '9520301', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '真野大川', 'マノオオカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市竹田', '15', '15224', '9520302', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '竹田', 'タケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市阿仏坊', '15', '15224', '9520303', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '阿仏坊', 'アブツボウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市国分寺', '15', '15224', '9520304', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '国分寺', 'コクブンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市長石', '15', '15224', '9520305', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '長石', 'ナガイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市四日町', '15', '15224', '9520306', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '四日町', 'ヨッカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市金丸', '15', '15224', '9520307', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '金丸', 'カナマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市名古屋', '15', '15224', '9520311', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '名古屋', 'ナゴヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市吉岡', '15', '15224', '9520312', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '吉岡', 'ヨシオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市真野', '15', '15224', '9520313', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '真野', 'マノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市滝脇', '15', '15224', '9520314', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '滝脇', 'タキワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市大須', '15', '15224', '9520315', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '大須', 'オオズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市背合', '15', '15224', '9520316', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '背合', 'セナゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市豊田', '15', '15224', '9520317', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '豊田', 'トヨタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市真野新町', '15', '15224', '9520318', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '真野新町', 'マノシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市静平', '15', '15224', '9520321', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '静平', 'シズダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市下黒山', '15', '15224', '9520322', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '下黒山', 'シモクロヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市羽茂小泊', '15', '15224', '9520421', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '羽茂小泊', 'ハモチコドマリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市羽茂亀脇', '15', '15224', '9520422', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '羽茂亀脇', 'ハモチカメワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市大小', '15', '15224', '9520431', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '大小', 'ダイショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市大倉谷', '15', '15224', '9520432', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '大倉谷', 'オオクラタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市田切須', '15', '15224', '9520433', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '田切須', 'タギリス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市西三川', '15', '15224', '9520434', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '西三川', 'ニシミカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市椿尾', '15', '15224', '9520435', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '椿尾', 'ツバキオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市羽茂滝平', '15', '15224', '9520501', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '羽茂滝平', 'ハモチタキダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市羽茂大崎', '15', '15224', '9520502', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '羽茂大崎', 'ハモチオオサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市羽茂飯岡', '15', '15224', '9520503', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '羽茂飯岡', 'ハモチイイオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市羽茂本郷', '15', '15224', '9520504', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '羽茂本郷', 'ハモチホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市羽茂三瀬', '15', '15224', '9520505', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '羽茂三瀬', 'ハモチサンセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市羽茂大石', '15', '15224', '9520511', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '羽茂大石', 'ハモチオオイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市羽茂大橋', '15', '15224', '9520512', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '羽茂大橋', 'ハモチオオハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市羽茂村山', '15', '15224', '9520513', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '羽茂村山', 'ハモチムラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市羽茂小泊', '15', '15224', '9520514', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '羽茂小泊', 'ハモチコドマリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市羽茂上山田', '15', '15224', '9520515', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '羽茂上山田', 'ハモチカミヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市小木堂釜', '15', '15224', '9520601', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '小木堂釜', 'オギドウノカマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市小比叡', '15', '15224', '9520602', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '小比叡', 'コビエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市小木木野浦', '15', '15224', '9520603', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '小木木野浦', 'オギキノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市小木町', '15', '15224', '9520604', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '小木町', 'オギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市小木', '15', '15224', '9520605', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '小木', 'オギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市琴浦', '15', '15224', '9520606', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '琴浦', 'コトウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市小木金田新田', '15', '15224', '9520611', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '小木金田新田', 'オギカネタシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市宿根木', '15', '15224', '9520612', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '宿根木', 'シュクネギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市小木強清水', '15', '15224', '9520613', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '小木強清水', 'オギコワシミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市犬神平', '15', '15224', '9520614', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '犬神平', 'イヌカミダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市深浦', '15', '15224', '9520615', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '深浦', 'フカウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市沢崎', '15', '15224', '9520621', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '沢崎', 'サワサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市江積', '15', '15224', '9520622', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '江積', 'エッツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市田野浦', '15', '15224', '9520623', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '田野浦', 'タノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市木流', '15', '15224', '9520624', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '木流', 'コナガセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市小木大浦', '15', '15224', '9520625', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '小木大浦', 'オギオオウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市井坪', '15', '15224', '9520626', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '井坪', 'イツボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市下川茂', '15', '15224', '9520701', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '下川茂', 'シモカワモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市上川茂', '15', '15224', '9520702', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '上川茂', 'カミカワモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市外山', '15', '15224', '9520703', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '外山', 'トヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市莚場', '15', '15224', '9520704', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '莚場', 'ムシロバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市三川', '15', '15224', '9520705', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '三川', 'ミカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市徳和', '15', '15224', '9520706', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '徳和', 'トクワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市赤泊', '15', '15224', '9520711', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '赤泊', 'アカドマリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市真浦', '15', '15224', '9520712', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '真浦', 'マウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市柳沢', '15', '15224', '9520713', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '柳沢', 'ヤナギサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市南新保', '15', '15224', '9520714', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '南新保', 'ミナミシンボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市杉野浦', '15', '15224', '9520715', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '杉野浦', 'スギノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市大杉', '15', '15224', '9520716', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '大杉', 'オオスギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市松ケ崎', '15', '15224', '9520821', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '松ケ崎', 'マツガサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市多田', '15', '15224', '9520822', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '多田', 'オオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市浜河内', '15', '15224', '9520823', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '浜河内', 'ハマカワチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市丸山', '15', '15224', '9520824', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '丸山', 'マルヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市蚫', '15', '15224', '9520851', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '蚫', 'アワビ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市赤玉', '15', '15224', '9520852', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '赤玉', 'アカダマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市立間', '15', '15224', '9520853', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '立間', 'タツマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市豊岡', '15', '15224', '9520854', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '豊岡', 'トヨオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市柿野浦', '15', '15224', '9520855', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '柿野浦', 'カキノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市東鵜島', '15', '15224', '9520856', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '東鵜島', 'ヒガシウシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市岩首', '15', '15224', '9520857', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '岩首', 'イワクビ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市安養寺', '15', '15224', '9521201', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '安養寺', 'アンヨウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市吉井本郷', '15', '15224', '9521202', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '吉井本郷', 'ヨシイホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市吉井', '15', '15224', '9521203', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '吉井', 'ヨシイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市三瀬川', '15', '15224', '9521204', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '三瀬川', 'サンセガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市水渡田', '15', '15224', '9521205', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '水渡田', 'ミトダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市大和', '15', '15224', '9521206', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '大和', 'ヤマト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市貝塚', '15', '15224', '9521207', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '貝塚', 'カイヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市金井新保', '15', '15224', '9521208', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '金井新保', 'カナイシンボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市千種', '15', '15224', '9521209', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '千種', 'チグサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市中興', '15', '15224', '9521211', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '中興', 'ナカオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市泉', '15', '15224', '9521212', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '泉', 'イズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市平清水', '15', '15224', '9521213', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '平清水', 'ヒラシミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市真光寺', '15', '15224', '9521301', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '真光寺', 'シンコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市市野沢', '15', '15224', '9521302', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '市野沢', 'イチノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市上矢馳', '15', '15224', '9521303', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '上矢馳', 'カミヤバセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市下長木', '15', '15224', '9521304', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '下長木', 'シモナガキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市上長木', '15', '15224', '9521305', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '上長木', 'カミナガキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市長木', '15', '15224', '9521306', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '長木', 'ナガキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市東大通', '15', '15224', '9521307', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '東大通', 'ヒガシオオドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市二宮', '15', '15224', '9521308', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '二宮', 'ニクウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市八幡', '15', '15224', '9521311', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '八幡', 'ヤハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市八幡新町', '15', '15224', '9521312', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '八幡新町', 'ヤハタシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市八幡町', '15', '15224', '9521313', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '八幡町', 'ヤハタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市河原田本町', '15', '15224', '9521314', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '河原田本町', 'カワハラダホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市河原田諏訪町', '15', '15224', '9521315', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '河原田諏訪町', 'カワハラダスワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市山田', '15', '15224', '9521321', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '山田', 'ヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市石田', '15', '15224', '9521322', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '石田', 'イシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市鍛冶町', '15', '15224', '9521323', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '鍛冶町', 'カジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市中原', '15', '15224', '9521324', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '中原', 'ナカハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市窪田', '15', '15224', '9521325', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '窪田', 'クボタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市青野', '15', '15224', '9521326', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '青野', 'アオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市沢根炭屋町', '15', '15224', '9521431', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '沢根炭屋町', 'サワネスミヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市沢根五十里', '15', '15224', '9521432', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '沢根五十里', 'サワネイカリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市沢根篭町', '15', '15224', '9521433', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '沢根篭町', 'サワネカゴマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市沢根町', '15', '15224', '9521434', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '沢根町', 'サワネマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市沢根', '15', '15224', '9521435', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '沢根', 'サワネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市下相川', '15', '15224', '9521501', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '下相川', 'シモアイカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市相川水金町', '15', '15224', '9521502', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '相川水金町', 'アイカワミズカネマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市相川柴町', '15', '15224', '9521503', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '相川柴町', 'アイカワシバマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市相川下山之神町', '15', '15224', '9521504', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '相川下山之神町', 'アイカワシモヤマノカミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市相川坂下町', '15', '15224', '9521505', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '相川坂下町', 'アイカワサカシタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市相川炭屋町', '15', '15224', '9521506', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '相川炭屋町', 'アイカワスミヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市相川紙屋町', '15', '15224', '9521507', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '相川紙屋町', 'アイカワカミヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市相川大間町', '15', '15224', '9521508', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '相川大間町', 'アイカワオオママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市相川栄町', '15', '15224', '9521511', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '相川栄町', 'アイカワサカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市相川板町', '15', '15224', '9521512', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '相川板町', 'アイカワイタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市相川濁川町', '15', '15224', '9521513', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '相川濁川町', 'アイカワニゴリカワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市相川小六町', '15', '15224', '9521514', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '相川小六町', 'アイカワコロクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市相川新西坂町', '15', '15224', '9521515', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '相川新西坂町', 'アイカワシンニシザカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市相川西坂町', '15', '15224', '9521516', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '相川西坂町', 'アイカワニシザカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市相川石扣町', '15', '15224', '9521517', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '相川石扣町', 'アイカワイシハタキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市相川材木町', '15', '15224', '9521518', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '相川材木町', 'アイカワザイモクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市相川夕白町', '15', '15224', '9521521', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '相川夕白町', 'アイカワユウハクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市相川上京町', '15', '15224', '9521522', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '相川上京町', 'アイカワカミキョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市相川新五郎町', '15', '15224', '9521523', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '相川新五郎町', 'アイカワシンゴロウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市相川大工町', '15', '15224', '9521524', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '相川大工町', 'アイカワダイクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市相川諏訪町', '15', '15224', '9521525', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '相川諏訪町', 'アイカワスワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市相川中寺町', '15', '15224', '9521526', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '相川中寺町', 'アイカワナカテラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市相川左門町', '15', '15224', '9521527', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '相川左門町', 'アイカワサモンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市相川六右衛門町', '15', '15224', '9521528', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '相川六右衛門町', 'アイカワロクウエモンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市相川広間町', '15', '15224', '9521531', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '相川広間町', 'アイカワヒロママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市相川弥十郎町', '15', '15224', '9521532', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '相川弥十郎町', 'アイカワヤジュウロウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市相川米屋町', '15', '15224', '9521533', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '相川米屋町', 'アイカワコメヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市相川大床屋町', '15', '15224', '9521534', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '相川大床屋町', 'アイカワオオトコヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市相川中京町', '15', '15224', '9521535', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '相川中京町', 'アイカワナカキョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市相川下京町', '15', '15224', '9521536', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '相川下京町', 'アイカワシモキョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市相川会津町', '15', '15224', '9521537', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '相川会津町', 'アイカワアイヅマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市相川四十物町', '15', '15224', '9521538', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '相川四十物町', 'アイカワアイモノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市相川北沢町', '15', '15224', '9521539', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '相川北沢町', 'アイカワキタザワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市相川新材木町', '15', '15224', '9521541', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '相川新材木町', 'アイカワシンザイモクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市相川塩屋町', '15', '15224', '9521542', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '相川塩屋町', 'アイカワシオヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市相川長坂町', '15', '15224', '9521543', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '相川長坂町', 'アイカワナガサカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市相川味噌屋町', '15', '15224', '9521544', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '相川味噌屋町', 'アイカワミソヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市相川八百屋町', '15', '15224', '9521545', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '相川八百屋町', 'アイカワヤオヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市相川南沢町', '15', '15224', '9521546', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '相川南沢町', 'アイカワミナミザワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市相川江戸沢町', '15', '15224', '9521547', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '相川江戸沢町', 'アイカワエドザワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市相川羽田町', '15', '15224', '9521548', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '相川羽田町', 'アイカワハネダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市相川下寺町', '15', '15224', '9521551', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '相川下寺町', 'アイカワシモテラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市相川一町目裏町', '15', '15224', '9521552', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '相川一町目裏町', 'アイカワイッチョウメウラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市相川五郎左衛門町', '15', '15224', '9521553', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '相川五郎左衛門町', 'アイカワゴロウザエモンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市相川二町目新浜町', '15', '15224', '9521554', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '相川二町目新浜町', 'アイカワニチョウメシンハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市相川二町目浜町', '15', '15224', '9521555', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '相川二町目浜町', 'アイカワニチョウメハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市相川一町目浜町', '15', '15224', '9521556', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '相川一町目浜町', 'アイカワイッチョウメハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市相川一町目', '15', '15224', '9521557', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '相川一町目', 'アイカワイッチョウメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市相川二町目', '15', '15224', '9521558', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '相川二町目', 'アイカワニチョウメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市相川三町目新浜町', '15', '15224', '9521561', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '相川三町目新浜町', 'アイカワサンチョウメシンハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市相川三町目浜町', '15', '15224', '9521562', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '相川三町目浜町', 'アイカワサンチョウメハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市相川三町目', '15', '15224', '9521563', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '相川三町目', 'アイカワサンチョウメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市相川四町目', '15', '15224', '9521564', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '相川四町目', 'アイカワヨンチョウメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市相川馬町', '15', '15224', '9521565', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '相川馬町', 'アイカワウママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市相川市町', '15', '15224', '9521566', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '相川市町', 'アイカワイチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市相川四町目浜町', '15', '15224', '9521567', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '相川四町目浜町', 'アイカワヨンチョウメハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市相川新浜町', '15', '15224', '9521568', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '相川新浜町', 'アイカワシンハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市相川下戸浜町', '15', '15224', '9521571', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '相川下戸浜町', 'アイカワオリトハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市相川羽田村', '15', '15224', '9521572', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '相川羽田村', 'アイカワハネダムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市相川下戸炭屋裏町', '15', '15224', '9521573', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '相川下戸炭屋裏町', 'アイカワオリトスミヤウラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市相川海士町', '15', '15224', '9521574', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '相川海士町', 'アイカワアママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市相川下戸町', '15', '15224', '9521575', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '相川下戸町', 'アイカワオリトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市相川下戸炭屋町', '15', '15224', '9521581', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '相川下戸炭屋町', 'アイカワオリトスミヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市相川下戸村', '15', '15224', '9521582', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '相川下戸村', 'アイカワオリトムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市相川鹿伏', '15', '15224', '9521583', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '相川鹿伏', 'アイカワカブセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市相川下戸炭屋浜町', '15', '15224', '9521584', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '相川下戸炭屋浜町', 'アイカワオリトスミヤハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市二見', '15', '15224', '9521641', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '二見', 'フタミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市米郷', '15', '15224', '9521642', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '米郷', 'ヨナゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市稲鯨', '15', '15224', '9521643', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '稲鯨', 'イナクジラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市橘', '15', '15224', '9521644', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '橘', 'タチバナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市高瀬', '15', '15224', '9521645', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '高瀬', 'タコセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市相川大浦', '15', '15224', '9521646', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '相川大浦', 'アイカワオオウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市戸中', '15', '15224', '9522131', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '戸中', 'トチュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市戸地', '15', '15224', '9522132', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '戸地', 'トジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市北狄', '15', '15224', '9522133', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '北狄', 'キタエビス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市姫津', '15', '15224', '9522134', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '姫津', 'ヒメヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市達者', '15', '15224', '9522135', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '達者', 'タッシャ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市小川', '15', '15224', '9522136', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '小川', 'オガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市岩谷口', '15', '15224', '9522201', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '岩谷口', 'イワヤグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市五十浦', '15', '15224', '9522202', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '五十浦', 'イカウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市関', '15', '15224', '9522203', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '関', 'セキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市矢柄', '15', '15224', '9522204', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '矢柄', 'ヤガラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市大倉', '15', '15224', '9522205', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '大倉', 'オオクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市小田', '15', '15224', '9522206', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '小田', 'コダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市石名', '15', '15224', '9522211', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '石名', 'イシナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市小野見', '15', '15224', '9522212', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '小野見', 'オノミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市北田野浦', '15', '15224', '9522213', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '北田野浦', 'キタタノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市高千', '15', '15224', '9522214', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '高千', 'タカチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市入川', '15', '15224', '9522215', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '入川', 'ニュウガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市北立島', '15', '15224', '9522221', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '北立島', 'キタタツシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市北川内', '15', '15224', '9522222', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '北川内', 'キタカワチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市後尾', '15', '15224', '9522223', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '後尾', 'ウシロオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市石花', '15', '15224', '9522224', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '石花', 'イシゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市北片辺', '15', '15224', '9522225', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '北片辺', 'キタカタベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市南片辺', '15', '15224', '9522226', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '南片辺', 'ミナミカタベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市虫崎', '15', '15224', '9523111', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '虫崎', 'ムシザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市黒姫', '15', '15224', '9523112', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '黒姫', 'クロヒメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市歌見', '15', '15224', '9523113', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '歌見', 'ウタミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市浦川', '15', '15224', '9523114', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '浦川', 'ウラガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市平松', '15', '15224', '9523115', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '平松', 'ヒラマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市北松ケ崎', '15', '15224', '9523116', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '北松ケ崎', 'キタマツガサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市馬首', '15', '15224', '9523117', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '馬首', 'ウマクビ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市和木', '15', '15224', '9523118', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '和木', 'ワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市玉崎', '15', '15224', '9523119', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '玉崎', 'タマサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市真更川', '15', '15224', '9523201', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '真更川', 'マサラガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市北鵜島', '15', '15224', '9523202', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '北鵜島', 'キタウシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市願', '15', '15224', '9523203', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '願', 'ネガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市藻浦', '15', '15224', '9523204', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '藻浦', 'モウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市鷲崎', '15', '15224', '9523205', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '鷲崎', 'ワシザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市見立', '15', '15224', '9523206', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '見立', 'ミタテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市北小浦', '15', '15224', '9523207', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '北小浦', 'キタコウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市吾潟', '15', '15224', '9523421', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '吾潟', 'アガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市城腰', '15', '15224', '9523422', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '城腰', 'ジョウノコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市久知河内', '15', '15224', '9523423', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '久知河内', 'クヂカワチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市下久知', '15', '15224', '9523424', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '下久知', 'シモクヂ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市河崎', '15', '15224', '9523425', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '河崎', 'カワサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市真木', '15', '15224', '9523431', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '真木', 'マキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市椎泊', '15', '15224', '9523432', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '椎泊', 'シイドマリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市両尾', '15', '15224', '9523433', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '両尾', 'モロオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市羽二生', '15', '15224', '9523434', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '羽二生', 'ハニウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市両津大川', '15', '15224', '9523435', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '両津大川', 'リョウツオオガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市水津', '15', '15224', '9523541', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '水津', 'スイヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市片野尾', '15', '15224', '9523542', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '片野尾', 'カタノオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市月布施', '15', '15224', '9523543', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '月布施', 'ツキフセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市野浦', '15', '15224', '9523544', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '野浦', 'ノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市東強清水', '15', '15224', '9523545', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '東強清水', 'ヒガシコワシミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県佐渡市東立島', '15', '15224', '9523546', '新潟県', 'ニイガタケン', '佐渡市', 'サドシ', '東立島', 'ヒガシタツシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区角田浜', '15', '15108', '9530011', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '角田浜', 'カクダハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区越前浜', '15', '15108', '9530012', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '越前浜', 'エチゼンハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区巻大原', '15', '15108', '9530013', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '巻大原', 'マキオオハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区新保', '15', '15108', '9530014', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '新保', 'シンボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区松野尾', '15', '15108', '9530015', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '松野尾', 'マツノオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区松山', '15', '15108', '9530016', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '松山', 'マツヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区布目', '15', '15108', '9530021', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '布目', 'ヌノメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区仁箇', '15', '15108', '9530022', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '仁箇', 'ニカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区竹野町', '15', '15108', '9530023', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '竹野町', 'タケノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区平沢', '15', '15108', '9530024', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '平沢', 'ヒラサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区松郷屋', '15', '15108', '9530025', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '松郷屋', 'マツゴウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区伏部', '15', '15108', '9530026', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '伏部', 'フスベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区稲島', '15', '15108', '9530027', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '稲島', 'トウジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区羽田', '15', '15108', '9530031', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '羽田', 'ハネダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区東汰上', '15', '15108', '9530032', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '東汰上', 'ヒガシヨリアゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区中郷屋', '15', '15108', '9530033', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '中郷屋', 'ナカゴウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区葉萱場', '15', '15108', '9530034', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '葉萱場', 'ハガヤバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区割前', '15', '15108', '9530035', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '割前', 'ワリマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区前田', '15', '15108', '9530036', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '前田', 'マエタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区巻甲', '15', '15108', '9530041', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '巻甲', 'マキコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区赤鏥', '15', '15108', '9530042', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '赤鏥', 'アカサビ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区堀山新田', '15', '15108', '9530043', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '堀山新田', 'ホリヤマシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区巻乙', '15', '15108', '9530044', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '巻乙', 'マキオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区桔梗ケ丘', '15', '15108', '9530045', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '桔梗ケ丘', 'キキョウガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区河井', '15', '15108', '9530051', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '河井', 'カワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区山島', '15', '15108', '9530052', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '山島', 'ヤマジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区巻東町', '15', '15108', '9530053', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '巻東町', 'マキアズマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区漆山', '15', '15108', '9530054', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '漆山', 'ウルシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区柿島', '15', '15108', '9530055', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '柿島', 'カキジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区馬堀', '15', '15108', '9530061', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '馬堀', 'マボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区並岡', '15', '15108', '9530062', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '並岡', 'ナミオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区栄町', '15', '15108', '9530063', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '栄町', 'サカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区桜林', '15', '15108', '9530064', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '桜林', 'サクラバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区下和納', '15', '15108', '9530065', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '下和納', 'シモワノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区安尻', '15', '15108', '9530066', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '安尻', 'アジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区潟頭', '15', '15108', '9530067', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '潟頭', 'ガタガシラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区下木島', '15', '15108', '9530071', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '下木島', 'シモキジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区鷲ノ木', '15', '15108', '9530072', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '鷲ノ木', 'ワシノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区上木島', '15', '15108', '9530073', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '上木島', 'カミキジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区舟戸', '15', '15108', '9530074', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '舟戸', 'フナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区峰岡', '15', '15108', '9530075', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '峰岡', 'ミネオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区福井', '15', '15108', '9530076', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '福井', 'フクイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区角海浜', '15', '15108', '9530077', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '角海浜', 'カクミハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区五ケ浜', '15', '15108', '9530078', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '五ケ浜', 'ゴカハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区樋曽', '15', '15108', '9530101', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '樋曽', 'ヒソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区栄', '15', '15108', '9530102', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '栄', 'サカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区橋本', '15', '15108', '9530103', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '橋本', 'ハシモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区岩室温泉', '15', '15108', '9530104', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '岩室温泉', 'イワムロオンセン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区間瀬', '15', '15108', '9530105', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '間瀬', 'マゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区油島', '15', '15108', '9530111', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '油島', 'アブラジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区高畑', '15', '15108', '9530112', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '高畑', 'タカバタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区西船越', '15', '15108', '9530113', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '西船越', 'ニシフナコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区潟上', '15', '15108', '9530114', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '潟上', 'カタガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区横曽根', '15', '15108', '9530115', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '横曽根', 'ヨコゾネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区新谷', '15', '15108', '9530116', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '新谷', 'アラヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区植野新田', '15', '15108', '9530117', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '植野新田', 'ウエノシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区高橋', '15', '15108', '9530121', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '高橋', 'タカハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区富岡', '15', '15108', '9530122', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '富岡', 'トミオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区津雲田', '15', '15108', '9530123', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '津雲田', 'ツクモダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区原', '15', '15108', '9530124', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '原', 'ハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区和納', '15', '15108', '9530125', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '和納', 'ワノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区西長島', '15', '15108', '9530131', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '西長島', 'ニシナガシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区西中', '15', '15108', '9530132', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '西中', 'ニシナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区夏井', '15', '15108', '9530133', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '夏井', 'ナツイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区北野', '15', '15108', '9530134', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '北野', 'キタノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区南谷内', '15', '15108', '9530135', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '南谷内', 'ミナミヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区白鳥', '15', '15108', '9530136', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '白鳥', 'シロトリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区石瀬', '15', '15108', '9530141', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '石瀬', 'イシゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区久保田', '15', '15108', '9530142', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '久保田', 'クボタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区猿ケ瀬', '15', '15108', '9530143', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '猿ケ瀬', 'サルガセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区金池', '15', '15108', '9530144', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '金池', 'カナイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県見附市', '15', '15211', '9540000', '新潟県', 'ニイガタケン', '見附市', 'ミツケシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('133567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県見附市指出町', '15', '15211', '9540001', '新潟県', 'ニイガタケン', '見附市', 'ミツケシ', '指出町', 'サシデマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県見附市小栗山町', '15', '15211', '9540002', '新潟県', 'ニイガタケン', '見附市', 'ミツケシ', '小栗山町', 'コグリヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県見附市元町', '15', '15211', '9540004', '新潟県', 'ニイガタケン', '見附市', 'ミツケシ', '元町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県見附市戸代新田町', '15', '15211', '9540005', '新潟県', 'ニイガタケン', '見附市', 'ミツケシ', '戸代新田町', 'トダイシンデンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県見附市新潟町', '15', '15211', '9540006', '新潟県', 'ニイガタケン', '見附市', 'ミツケシ', '新潟町', 'ニイガタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県見附市下鳥町', '15', '15211', '9540007', '新潟県', 'ニイガタケン', '見附市', 'ミツケシ', '下鳥町', 'シモドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県見附市内町', '15', '15211', '9540008', '新潟県', 'ニイガタケン', '見附市', 'ミツケシ', '内町', 'ウチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県見附市山崎興野町', '15', '15211', '9540011', '新潟県', 'ニイガタケン', '見附市', 'ミツケシ', '山崎興野町', 'ヤマザキゴウヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県見附市島切窪町', '15', '15211', '9540012', '新潟県', 'ニイガタケン', '見附市', 'ミツケシ', '島切窪町', 'シマキリクボマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県見附市石地町', '15', '15211', '9540013', '新潟県', 'ニイガタケン', '見附市', 'ミツケシ', '石地町', 'イシジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県見附市堀溝町', '15', '15211', '9540014', '新潟県', 'ニイガタケン', '見附市', 'ミツケシ', '堀溝町', 'ホリミゾマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県見附市庄川町', '15', '15211', '9540016', '新潟県', 'ニイガタケン', '見附市', 'ミツケシ', '庄川町', 'ショウガワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県見附市庄川平町', '15', '15211', '9540017', '新潟県', 'ニイガタケン', '見附市', 'ミツケシ', '庄川平町', 'ショウガワダイラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県見附市池之島町', '15', '15211', '9540021', '新潟県', 'ニイガタケン', '見附市', 'ミツケシ', '池之島町', 'イケノシママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県見附市杉澤町', '15', '15211', '9540022', '新潟県', 'ニイガタケン', '見附市', 'ミツケシ', '杉澤町', 'スギサワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県見附市宮之原町', '15', '15211', '9540023', '新潟県', 'ニイガタケン', '見附市', 'ミツケシ', '宮之原町', 'ミヤノハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県見附市河野町', '15', '15211', '9540024', '新潟県', 'ニイガタケン', '見附市', 'ミツケシ', '河野町', 'ガワノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県見附市牛ケ嶺町', '15', '15211', '9540025', '新潟県', 'ニイガタケン', '見附市', 'ミツケシ', '牛ケ嶺町', 'ウシガミネマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県見附市神保町', '15', '15211', '9540026', '新潟県', 'ニイガタケン', '見附市', 'ミツケシ', '神保町', 'シンボマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県見附市栃窪町', '15', '15211', '9540027', '新潟県', 'ニイガタケン', '見附市', 'ミツケシ', '栃窪町', 'トチクボマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県見附市太田町', '15', '15211', '9540031', '新潟県', 'ニイガタケン', '見附市', 'ミツケシ', '太田町', 'オオダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県見附市本明町', '15', '15211', '9540032', '新潟県', 'ニイガタケン', '見附市', 'ミツケシ', '本明町', 'ホンミョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県見附市明晶町', '15', '15211', '9540033', '新潟県', 'ニイガタケン', '見附市', 'ミツケシ', '明晶町', 'ミョウショウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県見附市月見台', '15', '15211', '9540034', '新潟県', 'ニイガタケン', '見附市', 'ミツケシ', '月見台', 'ツキミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県見附市名木野町', '15', '15211', '9540035', '新潟県', 'ニイガタケン', '見附市', 'ミツケシ', '名木野町', 'ナギノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県見附市田井町', '15', '15211', '9540036', '新潟県', 'ニイガタケン', '見附市', 'ミツケシ', '田井町', 'タイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県見附市椿澤町', '15', '15211', '9540037', '新潟県', 'ニイガタケン', '見附市', 'ミツケシ', '椿澤町', 'ツバキザワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県見附市池之内町', '15', '15211', '9540038', '新潟県', 'ニイガタケン', '見附市', 'ミツケシ', '池之内町', 'イケノウチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県見附市栃栄町', '15', '15211', '9540041', '新潟県', 'ニイガタケン', '見附市', 'ミツケシ', '栃栄町', 'トチサカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県見附市山崎町', '15', '15211', '9540042', '新潟県', 'ニイガタケン', '見附市', 'ミツケシ', '山崎町', 'ヤマザキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県見附市耳取町', '15', '15211', '9540043', '新潟県', 'ニイガタケン', '見附市', 'ミツケシ', '耳取町', 'ミミトリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県見附市鳥屋脇町', '15', '15211', '9540044', '新潟県', 'ニイガタケン', '見附市', 'ミツケシ', '鳥屋脇町', 'トヤワキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県見附市緑町', '15', '15211', '9540045', '新潟県', 'ニイガタケン', '見附市', 'ミツケシ', '緑町', 'ミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県見附市双葉町', '15', '15211', '9540046', '新潟県', 'ニイガタケン', '見附市', 'ミツケシ', '双葉町', 'フタバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県見附市本所', '15', '15211', '9540051', '新潟県', 'ニイガタケン', '見附市', 'ミツケシ', '本所', 'ホンジョ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県見附市学校町', '15', '15211', '9540052', '新潟県', 'ニイガタケン', '見附市', 'ミツケシ', '学校町', 'ガッコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県見附市本町', '15', '15211', '9540053', '新潟県', 'ニイガタケン', '見附市', 'ミツケシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県見附市細越', '15', '15211', '9540054', '新潟県', 'ニイガタケン', '見附市', 'ミツケシ', '細越', 'ホソゴエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県見附市嶺崎', '15', '15211', '9540055', '新潟県', 'ニイガタケン', '見附市', 'ミツケシ', '嶺崎', 'ミネザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県見附市南本町', '15', '15211', '9540056', '新潟県', 'ニイガタケン', '見附市', 'ミツケシ', '南本町', 'ミナミホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県見附市新町', '15', '15211', '9540057', '新潟県', 'ニイガタケン', '見附市', 'ミツケシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県見附市葛巻', '15', '15211', '9540058', '新潟県', 'ニイガタケン', '見附市', 'ミツケシ', '葛巻', 'クズマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県見附市昭和町', '15', '15211', '9540059', '新潟県', 'ニイガタケン', '見附市', 'ミツケシ', '昭和町', 'ショウワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県見附市熱田町', '15', '15211', '9540061', '新潟県', 'ニイガタケン', '見附市', 'ミツケシ', '熱田町', 'アツタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県見附市下新町', '15', '15211', '9540062', '新潟県', 'ニイガタケン', '見附市', 'ミツケシ', '下新町', 'シモアラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県見附市漆山町', '15', '15211', '9540063', '新潟県', 'ニイガタケン', '見附市', 'ミツケシ', '漆山町', 'ウルシヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県見附市鹿熊町', '15', '15211', '9540064', '新潟県', 'ニイガタケン', '見附市', 'ミツケシ', '鹿熊町', 'カクママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県見附市葛巻町', '15', '15211', '9540067', '新潟県', 'ニイガタケン', '見附市', 'ミツケシ', '葛巻町', 'クズマキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県見附市仁嘉町', '15', '15211', '9540068', '新潟県', 'ニイガタケン', '見附市', 'ミツケシ', '仁嘉町', 'ニカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県見附市傍所町', '15', '15211', '9540071', '新潟県', 'ニイガタケン', '見附市', 'ミツケシ', '傍所町', 'ホウジョマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県見附市北野町', '15', '15211', '9540072', '新潟県', 'ニイガタケン', '見附市', 'ミツケシ', '北野町', 'キタノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県見附市青木町', '15', '15211', '9540073', '新潟県', 'ニイガタケン', '見附市', 'ミツケシ', '青木町', 'アオキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県見附市山吉町', '15', '15211', '9540074', '新潟県', 'ニイガタケン', '見附市', 'ミツケシ', '山吉町', 'ヤマヨシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県見附市速水町', '15', '15211', '9540075', '新潟県', 'ニイガタケン', '見附市', 'ミツケシ', '速水町', 'ハヤミズマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県見附市新幸町', '15', '15211', '9540076', '新潟県', 'ニイガタケン', '見附市', 'ミツケシ', '新幸町', 'シンコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県見附市葛巻西町', '15', '15211', '9540077', '新潟県', 'ニイガタケン', '見附市', 'ミツケシ', '葛巻西町', 'クズマキニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県見附市葛巻東町', '15', '15211', '9540078', '新潟県', 'ニイガタケン', '見附市', 'ミツケシ', '葛巻東町', 'クズマキヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県見附市葛巻南町', '15', '15211', '9540079', '新潟県', 'ニイガタケン', '見附市', 'ミツケシ', '葛巻南町', 'クズマキミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県見附市片桐町', '15', '15211', '9540081', '新潟県', 'ニイガタケン', '見附市', 'ミツケシ', '片桐町', 'カタギリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県見附市柳橋町', '15', '15211', '9540082', '新潟県', 'ニイガタケン', '見附市', 'ミツケシ', '柳橋町', 'ヤナギバシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県見附市市野坪町', '15', '15211', '9540083', '新潟県', 'ニイガタケン', '見附市', 'ミツケシ', '市野坪町', 'イチノツボマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県見附市加坪川町', '15', '15211', '9540084', '新潟県', 'ニイガタケン', '見附市', 'ミツケシ', '加坪川町', 'カツボガワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県見附市反田町', '15', '15211', '9540085', '新潟県', 'ニイガタケン', '見附市', 'ミツケシ', '反田町', 'ソリダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県見附市福島町', '15', '15211', '9540086', '新潟県', 'ニイガタケン', '見附市', 'ミツケシ', '福島町', 'フクジママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県見附市芝野町', '15', '15211', '9540087', '新潟県', 'ニイガタケン', '見附市', 'ミツケシ', '芝野町', 'シバノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県見附市新潟東町', '15', '15211', '9540088', '新潟県', 'ニイガタケン', '見附市', 'ミツケシ', '新潟東町', 'ニイガタヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県見附市新潟西町', '15', '15211', '9540089', '新潟県', 'ニイガタケン', '見附市', 'ミツケシ', '新潟西町', 'ニイガタニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県見附市三林町', '15', '15211', '9540101', '新潟県', 'ニイガタケン', '見附市', 'ミツケシ', '三林町', 'サンバヤシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県見附市釈迦塚町', '15', '15211', '9540102', '新潟県', 'ニイガタケン', '見附市', 'ミツケシ', '釈迦塚町', 'シャカヅカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県見附市田之尻町', '15', '15211', '9540103', '新潟県', 'ニイガタケン', '見附市', 'ミツケシ', '田之尻町', 'タノシリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県見附市坂井町', '15', '15211', '9540104', '新潟県', 'ニイガタケン', '見附市', 'ミツケシ', '坂井町', 'サカイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県見附市下関町', '15', '15211', '9540105', '新潟県', 'ニイガタケン', '見附市', 'ミツケシ', '下関町', 'シモセキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県見附市東今町', '15', '15211', '9540106', '新潟県', 'ニイガタケン', '見附市', 'ミツケシ', '東今町', 'ヒガシイママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県見附市西今町', '15', '15211', '9540107', '新潟県', 'ニイガタケン', '見附市', 'ミツケシ', '西今町', 'ニシイママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県見附市今町', '15', '15211', '9540111', '新潟県', 'ニイガタケン', '見附市', 'ミツケシ', '今町', 'イママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県見附市上新田町', '15', '15211', '9540112', '新潟県', 'ニイガタケン', '見附市', 'ミツケシ', '上新田町', 'カミシンデンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市野口', '15', '15202', '9540121', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '野口', 'ノグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市真弓', '15', '15202', '9540122', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '真弓', 'マユミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市猫興野', '15', '15202', '9540123', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '猫興野', 'ネコゴウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市中之島', '15', '15202', '9540124', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '中之島', 'ナカノシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市藤山', '15', '15202', '9540125', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '藤山', 'フジヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市五百刈', '15', '15202', '9540126', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '五百刈', 'ゴヒャッカリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市中興野', '15', '15202', '9540131', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '中興野', 'ナカゴウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市新栄', '15', '15202', '9540132', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '新栄', 'シンエイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市大曲戸新田', '15', '15202', '9540133', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '大曲戸新田', 'オオマガトシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市大曲戸', '15', '15202', '9540134', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '大曲戸', 'オオマガト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市幸南', '15', '15202', '9540135', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '幸南', 'コウナン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市思川新田', '15', '15202', '9540136', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '思川新田', 'オモイガワシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市押切新田', '15', '15202', '9540137', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '押切新田', 'オシキリシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市押切川原町', '15', '15202', '9540138', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '押切川原町', 'オシキリカワラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市粕島', '15', '15202', '9540141', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '粕島', 'カスジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市灰島新田', '15', '15202', '9540142', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '灰島新田', 'ハイジマシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市池之島', '15', '15202', '9540143', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '池之島', 'イケノシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市坪根', '15', '15202', '9540144', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '坪根', 'ツボネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市大口', '15', '15202', '9540145', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '大口', 'オオクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市大保', '15', '15202', '9540146', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '大保', 'ダイボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市品之木', '15', '15202', '9540147', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '品之木', 'ボンノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市杉之森', '15', '15202', '9540151', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '杉之森', 'スギノモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市中之島高畑', '15', '15202', '9540152', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '中之島高畑', 'ナカノシマタカバタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市横山', '15', '15202', '9540153', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '横山', 'ヨコヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市関根', '15', '15202', '9540154', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '関根', 'セキネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市島田', '15', '15202', '9540155', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '島田', 'シマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市長呂', '15', '15202', '9540156', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '長呂', 'ナガロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市中之島宮内', '15', '15202', '9540157', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '中之島宮内', 'ナカノシマミヤウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市興野', '15', '15202', '9540161', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '興野', 'コウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市狐興野', '15', '15202', '9540162', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '狐興野', 'キツネゴウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市並木新田', '15', '15202', '9540163', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '並木新田', 'ナミキシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市末宝', '15', '15202', '9540164', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '末宝', 'マッポウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市福原', '15', '15202', '9540165', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '福原', 'フクハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市海老島勇次新田', '15', '15202', '9540166', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '海老島勇次新田', 'エビジマユウジシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市稲島', '15', '15202', '9540171', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '稲島', 'イナジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市鶴ケ曽根', '15', '15202', '9540172', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '鶴ケ曽根', 'ツルガソネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市中野東', '15', '15202', '9540173', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '中野東', 'ナカノヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市中野中', '15', '15202', '9540174', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '中野中', 'ナカノナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市中野西', '15', '15202', '9540175', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '中野西', 'ナカノニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市横野', '15', '15202', '9540176', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '横野', 'ヨコノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市亀ケ谷新田', '15', '15202', '9540177', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '亀ケ谷新田', 'カメガヤシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市脇川新田町', '15', '15202', '9540181', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '脇川新田町', 'ワキガワシンデンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市大沼新田', '15', '15202', '9540201', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '大沼新田', 'オオヌマシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市赤沼', '15', '15202', '9540202', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '赤沼', 'アカヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市小沼新田', '15', '15202', '9540203', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '小沼新田', 'コヌマシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市中西', '15', '15202', '9540204', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '中西', 'ナカサイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市西高山新田', '15', '15202', '9540205', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '西高山新田', 'ニシタカヤマシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市六所', '15', '15202', '9540206', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '六所', 'ロクショ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市上沼新田', '15', '15202', '9540207', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '上沼新田', 'ウワヌマシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市西野新田', '15', '15202', '9540211', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '西野新田', 'ニシノシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市中之島西野', '15', '15202', '9540212', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '中之島西野', 'ナカノシマニシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市下沼新田', '15', '15202', '9540213', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '下沼新田', 'シタヌマシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市中条新田', '15', '15202', '9540214', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '中条新田', 'チュウジョウシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市真野代新田', '15', '15202', '9540215', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '真野代新田', 'マノシロシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市中之島中条', '15', '15202', '9540216', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '中之島中条', 'ナカノシマチュウジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市松ケ崎新田', '15', '15202', '9540217', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '松ケ崎新田', 'マツガサキシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市信条南', '15', '15202', '9540218', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '信条南', 'シンジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市', '15', '15204', '9550000', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('133705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市三貫地新田', '15', '15204', '9550001', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '三貫地新田', 'サンガンジシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市柳川新田', '15', '15204', '9550002', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '柳川新田', 'ヤナガワシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市柳場新田', '15', '15204', '9550003', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '柳場新田', 'ヤナギバシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市須戸新田', '15', '15204', '9550004', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '須戸新田', 'スドシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市白山新田', '15', '15204', '9550011', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '白山新田', 'シラヤマシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市北野新田', '15', '15204', '9550012', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '北野新田', 'キタノシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市井栗', '15', '15204', '9550013', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '井栗', 'イグリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市西潟', '15', '15204', '9550014', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '西潟', 'ニシカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市三柳', '15', '15204', '9550015', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '三柳', 'ミツヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市牛ケ島', '15', '15204', '9550016', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '牛ケ島', 'ウシガシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市下保内', '15', '15204', '9550021', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '下保内', 'シモホナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市上保内', '15', '15204', '9550022', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '上保内', 'カミホナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市みずほ', '15', '15204', '9550022', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', 'みずほ', 'ミズホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市柳沢', '15', '15204', '9550024', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '柳沢', 'ヤナギサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市上野原', '15', '15204', '9550025', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '上野原', 'ウエノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市松ノ木町', '15', '15204', '9550031', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '松ノ木町', 'マツノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市東大崎', '15', '15204', '9550032', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '東大崎', 'ヒガシオオサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市西大崎', '15', '15204', '9550033', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '西大崎', 'ニシオオサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市麻布', '15', '15204', '9550034', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '麻布', 'アザブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市中新', '15', '15204', '9550035', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '中新', 'チュウシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市篭場', '15', '15204', '9550036', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '篭場', 'カゴバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市三竹', '15', '15204', '9550041', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '三竹', 'サンチク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市下坂井', '15', '15204', '9550042', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '下坂井', 'シモサカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市北中', '15', '15204', '9550043', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '北中', 'キタナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市田島', '15', '15204', '9550044', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '田島', 'タジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市一ノ門', '15', '15204', '9550045', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '一ノ門', 'イチノモン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市興野', '15', '15204', '9550046', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '興野', 'コウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市東三条', '15', '15204', '9550047', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '東三条', 'ヒガシサンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市鶴田', '15', '15204', '9550051', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '鶴田', 'ツルダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市北入蔵', '15', '15204', '9550053', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '北入蔵', 'キタニュウグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市大宮新田', '15', '15204', '9550054', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '大宮新田', 'オオミヤシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市塚野目', '15', '15204', '9550055', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '塚野目', 'ツカノメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市嘉坪川', '15', '15204', '9550056', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '嘉坪川', 'カツボガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市新光町', '15', '15204', '9550057', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '新光町', 'ニッコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市林町', '15', '15204', '9550061', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '林町', 'ハヤシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市仲之町', '15', '15204', '9550062', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '仲之町', 'ナカノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市神明町', '15', '15204', '9550063', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '神明町', 'シンメイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市横町', '15', '15204', '9550064', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '横町', 'ヨコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市旭町', '15', '15204', '9550065', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '旭町', 'アサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市居島', '15', '15204', '9550066', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '居島', 'イジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市本町', '15', '15204', '9550071', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市元町', '15', '15204', '9550072', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '元町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市八幡町', '15', '15204', '9550073', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '八幡町', 'ハチマンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市東裏館', '15', '15204', '9550081', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '東裏館', 'ヒガシウラダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市西裏館', '15', '15204', '9550082', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '西裏館', 'ニシウラダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市荒町', '15', '15204', '9550083', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '荒町', 'アラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市石上', '15', '15204', '9550084', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '石上', 'イシガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市栗林', '15', '15204', '9550085', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '栗林', 'クリバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市上須頃', '15', '15204', '9550091', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '上須頃', 'カミスゴロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市須頃', '15', '15204', '9550092', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '須頃', 'スゴロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市下須頃', '15', '15204', '9550093', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '下須頃', 'シモスゴロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市大島', '15', '15204', '9550094', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '大島', 'オオジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市代官島', '15', '15204', '9550095', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '代官島', 'ダイカンジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市井戸場', '15', '15204', '9550096', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '井戸場', 'イドバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市荻島', '15', '15204', '9550097', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '荻島', 'オギジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市曲谷', '15', '15204', '9550101', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '曲谷', 'マガリタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市牛ケ首', '15', '15204', '9550102', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '牛ケ首', 'ウシガクビ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市落合', '15', '15204', '9550103', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '落合', 'オチアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市江口', '15', '15204', '9550104', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '江口', 'エグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市島川原', '15', '15204', '9550105', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '島川原', 'シマガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市南中', '15', '15204', '9550106', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '南中', 'ミナミナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市飯田', '15', '15204', '9550107', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '飯田', 'イイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市鹿峠', '15', '15204', '9550108', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '鹿峠', 'カトウゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市上谷地', '15', '15204', '9550111', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '上谷地', 'カミヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市蝶名林', '15', '15204', '9550112', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '蝶名林', 'チョウナバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市中浦', '15', '15204', '9550113', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '中浦', 'ナカウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市鹿熊', '15', '15204', '9550114', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '鹿熊', 'カクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市院内', '15', '15204', '9550115', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '院内', 'インナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市森町', '15', '15204', '9550116', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '森町', 'モリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市田屋', '15', '15204', '9550117', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '田屋', 'タヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市新屋', '15', '15204', '9550118', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '新屋', 'アラヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市北五百川', '15', '15204', '9550121', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '北五百川', 'キタイモガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市大谷地', '15', '15204', '9550122', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '大谷地', 'オオヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市笠堀', '15', '15204', '9550123', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '笠堀', 'カサボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市大谷', '15', '15204', '9550124', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '大谷', 'オオタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市塩野渕', '15', '15204', '9550125', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '塩野渕', 'シオノフチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市栗山', '15', '15204', '9550126', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '栗山', 'クリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市名下', '15', '15204', '9550127', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '名下', 'ミョウゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市南五百川', '15', '15204', '9550128', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '南五百川', 'ミナミイモガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市庭月', '15', '15204', '9550131', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '庭月', 'ニワヅキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市長野', '15', '15204', '9550132', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '長野', 'ナガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市牛野尾', '15', '15204', '9550133', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '牛野尾', 'ウシノオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市濁沢', '15', '15204', '9550134', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '濁沢', 'ニゴリサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市早水', '15', '15204', '9550135', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '早水', 'ハヤミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市葎谷', '15', '15204', '9550136', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '葎谷', 'モグラダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市遅場', '15', '15204', '9550137', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '遅場', 'オソバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市荒沢', '15', '15204', '9550141', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '荒沢', 'アラサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市小長沢', '15', '15204', '9550142', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '小長沢', 'コナガサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市棚鱗', '15', '15204', '9550143', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '棚鱗', 'タナヒレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市楢山', '15', '15204', '9550144', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '楢山', 'ナラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市大沢', '15', '15204', '9550145', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '大沢', 'オオサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市笹巻', '15', '15204', '9550146', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '笹巻', 'ササマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市中野原', '15', '15204', '9550147', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '中野原', 'ナカノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市花渕', '15', '15204', '9550148', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '花渕', 'ハナブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市荻堀', '15', '15204', '9550151', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '荻堀', 'オギボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市笹岡', '15', '15204', '9550152', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '笹岡', 'ササオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市桑切', '15', '15204', '9550153', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '桑切', 'クワキリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市大平', '15', '15204', '9550154', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '大平', 'オオダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市広手', '15', '15204', '9550155', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '広手', 'ヒロテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市駒込', '15', '15204', '9550156', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '駒込', 'コマゴミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市長沢', '15', '15204', '9550157', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '長沢', 'ナガサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市原', '15', '15204', '9550158', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '原', 'ハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市高岡', '15', '15204', '9550161', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '高岡', 'タカオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市福岡', '15', '15204', '9550162', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '福岡', 'フクオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市島潟', '15', '15204', '9550163', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '島潟', 'シマガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市滝谷', '15', '15204', '9550164', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '滝谷', 'タキヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市高屋敷', '15', '15204', '9550165', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '高屋敷', 'タカヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市上大浦', '15', '15204', '9550166', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '上大浦', 'カミオオウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市馬場', '15', '15204', '9550167', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '馬場', 'ババ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市下大浦', '15', '15204', '9550168', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '下大浦', 'シモオオウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市諏訪', '15', '15204', '9550801', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '諏訪', 'スワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市月岡', '15', '15204', '9550803', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '月岡', 'ツキオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市如法寺', '15', '15204', '9550804', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '如法寺', 'ニョホウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市吉田', '15', '15204', '9550805', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '吉田', 'ヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市長嶺', '15', '15204', '9550806', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '長嶺', 'ナガミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市片口', '15', '15204', '9550807', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '片口', 'カタクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市新保', '15', '15204', '9550808', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '新保', 'シンボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市南入蔵', '15', '15204', '9550811', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '南入蔵', 'ミナミニュウグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市入蔵新田', '15', '15204', '9550812', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '入蔵新田', 'ニュウグラシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市袋', '15', '15204', '9550813', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '袋', 'フクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市金子新田', '15', '15204', '9550814', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '金子新田', 'カネコシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市西鱈田', '15', '15204', '9550815', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '西鱈田', 'ニシタラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市東鱈田', '15', '15204', '9550816', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '東鱈田', 'ヒガシタラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市枝郷', '15', '15204', '9550818', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '枝郷', 'エダゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市五明', '15', '15204', '9550821', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '五明', 'ゴミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市西中', '15', '15204', '9550822', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '西中', 'ニシナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市東本成寺', '15', '15204', '9550823', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '東本成寺', 'ヒガシホンジョウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市下新田', '15', '15204', '9550824', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '下新田', 'シモシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市土場', '15', '15204', '9550831', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '土場', 'ドバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市直江町', '15', '15204', '9550832', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '直江町', 'スグエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市大野畑', '15', '15204', '9550833', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '大野畑', 'オオノハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市由利', '15', '15204', '9550841', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '由利', 'ユリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市島田', '15', '15204', '9550842', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '島田', 'シマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市条南町', '15', '15204', '9550843', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '条南町', 'ジョウナンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市桜木町', '15', '15204', '9550844', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '桜木町', 'サクラギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市西本成寺', '15', '15204', '9550845', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '西本成寺', 'ニシホンジョウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市緑ケ丘', '15', '15204', '9550845', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '緑ケ丘', 'ミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市西四日町', '15', '15204', '9550851', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '西四日町', 'ニシヨッカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市南四日町', '15', '15204', '9550852', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '南四日町', 'ミナミヨッカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市北四日町', '15', '15204', '9550853', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '北四日町', 'キタヨッカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市四日町', '15', '15204', '9550854', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '四日町', 'ヨッカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市北新保', '15', '15204', '9550861', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '北新保', 'キタシンボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市南新保', '15', '15204', '9550862', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '南新保', 'ミナミシンボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市東新保', '15', '15204', '9550863', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '東新保', 'ヒガシシンボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市曲渕', '15', '15204', '9550864', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '曲渕', 'マガリフチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市秋葉区', '15', '15105', '9560000', '新潟県', 'ニイガタケン', '新潟市秋葉区', 'ニイガタシアキハク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('133880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市秋葉区覚路津', '15', '15105', '9560001', '新潟県', 'ニイガタケン', '新潟市秋葉区', 'ニイガタシアキハク', '覚路津', 'カクロヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市秋葉区市之瀬', '15', '15105', '9560002', '新潟県', 'ニイガタケン', '新潟市秋葉区', 'ニイガタシアキハク', '市之瀬', 'イチノセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市秋葉区長割', '15', '15105', '9560003', '新潟県', 'ニイガタケン', '新潟市秋葉区', 'ニイガタシアキハク', '長割', 'オサワリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市秋葉区大鹿', '15', '15105', '9560004', '新潟県', 'ニイガタケン', '新潟市秋葉区', 'ニイガタシアキハク', '大鹿', 'オオジカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市秋葉区栗宮', '15', '15105', '9560005', '新潟県', 'ニイガタケン', '新潟市秋葉区', 'ニイガタシアキハク', '栗宮', 'クリミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市秋葉区小戸上組', '15', '15105', '9560006', '新潟県', 'ニイガタケン', '新潟市秋葉区', 'ニイガタシアキハク', '小戸上組', 'コドカミグミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市秋葉区小戸下組', '15', '15105', '9560007', '新潟県', 'ニイガタケン', '新潟市秋葉区', 'ニイガタシアキハク', '小戸下組', 'コドシモグミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市秋葉区車場', '15', '15105', '9560011', '新潟県', 'ニイガタケン', '新潟市秋葉区', 'ニイガタシアキハク', '車場', 'クルマバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市秋葉区荻野町', '15', '15105', '9560012', '新潟県', 'ニイガタケン', '新潟市秋葉区', 'ニイガタシアキハク', '荻野町', 'オギノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市秋葉区田島', '15', '15105', '9560013', '新潟県', 'ニイガタケン', '新潟市秋葉区', 'ニイガタシアキハク', '田島', 'タジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市秋葉区福島', '15', '15105', '9560014', '新潟県', 'ニイガタケン', '新潟市秋葉区', 'ニイガタシアキハク', '福島', 'フクジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市秋葉区川口', '15', '15105', '9560015', '新潟県', 'ニイガタケン', '新潟市秋葉区', 'ニイガタシアキハク', '川口', 'カワグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市秋葉区こがね町', '15', '15105', '9560016', '新潟県', 'ニイガタケン', '新潟市秋葉区', 'ニイガタシアキハク', 'こがね町', 'コガネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市秋葉区あおば通', '15', '15105', '9560017', '新潟県', 'ニイガタケン', '新潟市秋葉区', 'ニイガタシアキハク', 'あおば通', 'アオバドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市秋葉区北上新田', '15', '15105', '9560021', '新潟県', 'ニイガタケン', '新潟市秋葉区', 'ニイガタシアキハク', '北上新田', 'キタカミシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市秋葉区さつき野', '15', '15105', '9560022', '新潟県', 'ニイガタケン', '新潟市秋葉区', 'ニイガタシアキハク', 'さつき野', 'サツキノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市秋葉区美幸町', '15', '15105', '9560023', '新潟県', 'ニイガタケン', '新潟市秋葉区', 'ニイガタシアキハク', '美幸町', 'ミユキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市秋葉区山谷町', '15', '15105', '9560024', '新潟県', 'ニイガタケン', '新潟市秋葉区', 'ニイガタシアキハク', '山谷町', 'ヤマヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市秋葉区古田', '15', '15105', '9560025', '新潟県', 'ニイガタケン', '新潟市秋葉区', 'ニイガタシアキハク', '古田', 'コダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市秋葉区北潟', '15', '15105', '9560026', '新潟県', 'ニイガタケン', '新潟市秋葉区', 'ニイガタシアキハク', '北潟', 'キタガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市秋葉区美善', '15', '15105', '9560027', '新潟県', 'ニイガタケン', '新潟市秋葉区', 'ニイガタシアキハク', '美善', 'ミヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市秋葉区新津', '15', '15105', '9560031', '新潟県', 'ニイガタケン', '新潟市秋葉区', 'ニイガタシアキハク', '新津', 'ニイツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市秋葉区南町', '15', '15105', '9560032', '新潟県', 'ニイガタケン', '新潟市秋葉区', 'ニイガタシアキハク', '南町', 'ミナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市秋葉区新栄町', '15', '15105', '9560033', '新潟県', 'ニイガタケン', '新潟市秋葉区', 'ニイガタシアキハク', '新栄町', 'シンエイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市秋葉区新津緑町', '15', '15105', '9560034', '新潟県', 'ニイガタケン', '新潟市秋葉区', 'ニイガタシアキハク', '新津緑町', 'ニイツミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市秋葉区程島', '15', '15105', '9560035', '新潟県', 'ニイガタケン', '新潟市秋葉区', 'ニイガタシアキハク', '程島', 'ホドジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市秋葉区中村', '15', '15105', '9560036', '新潟県', 'ニイガタケン', '新潟市秋葉区', 'ニイガタシアキハク', '中村', 'ナカムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市秋葉区西古津', '15', '15105', '9560037', '新潟県', 'ニイガタケン', '新潟市秋葉区', 'ニイガタシアキハク', '西古津', 'ニシフルツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市秋葉区小屋場', '15', '15105', '9560041', '新潟県', 'ニイガタケン', '新潟市秋葉区', 'ニイガタシアキハク', '小屋場', 'コヤバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市秋葉区梅ノ木', '15', '15105', '9560043', '新潟県', 'ニイガタケン', '新潟市秋葉区', 'ニイガタシアキハク', '梅ノ木', 'ウメノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市秋葉区浦興野', '15', '15105', '9560044', '新潟県', 'ニイガタケン', '新潟市秋葉区', 'ニイガタシアキハク', '浦興野', 'ウラゴヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市秋葉区子成場', '15', '15105', '9560045', '新潟県', 'ニイガタケン', '新潟市秋葉区', 'ニイガタシアキハク', '子成場', 'コナシバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市秋葉区出戸', '15', '15105', '9560046', '新潟県', 'ニイガタケン', '新潟市秋葉区', 'ニイガタシアキハク', '出戸', 'デト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市秋葉区三枚潟', '15', '15105', '9560051', '新潟県', 'ニイガタケン', '新潟市秋葉区', 'ニイガタシアキハク', '三枚潟', 'サンマイガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市秋葉区三津屋', '15', '15105', '9560052', '新潟県', 'ニイガタケン', '新潟市秋葉区', 'ニイガタシアキハク', '三津屋', 'ミツヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市秋葉区野方', '15', '15105', '9560053', '新潟県', 'ニイガタケン', '新潟市秋葉区', 'ニイガタシアキハク', '野方', 'ノガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市秋葉区大秋', '15', '15105', '9560054', '新潟県', 'ニイガタケン', '新潟市秋葉区', 'ニイガタシアキハク', '大秋', 'オオアキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市秋葉区川根', '15', '15105', '9560055', '新潟県', 'ニイガタケン', '新潟市秋葉区', 'ニイガタシアキハク', '川根', 'カワネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市秋葉区蕨曽根', '15', '15105', '9560056', '新潟県', 'ニイガタケン', '新潟市秋葉区', 'ニイガタシアキハク', '蕨曽根', 'ワラビソネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市秋葉区新津四ツ興野', '15', '15105', '9560057', '新潟県', 'ニイガタケン', '新潟市秋葉区', 'ニイガタシアキハク', '新津四ツ興野', 'ニイツヨツゴヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市秋葉区小須戸', '15', '15105', '9560101', '新潟県', 'ニイガタケン', '新潟市秋葉区', 'ニイガタシアキハク', '小須戸', 'コスド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市秋葉区竜玄', '15', '15105', '9560111', '新潟県', 'ニイガタケン', '新潟市秋葉区', 'ニイガタシアキハク', '竜玄', 'リュウゲン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市秋葉区新保', '15', '15105', '9560112', '新潟県', 'ニイガタケン', '新潟市秋葉区', 'ニイガタシアキハク', '新保', 'シンボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市秋葉区矢代田', '15', '15105', '9560113', '新潟県', 'ニイガタケン', '新潟市秋葉区', 'ニイガタシアキハク', '矢代田', 'ヤシロダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市秋葉区天ヶ沢', '15', '15105', '9560114', '新潟県', 'ニイガタケン', '新潟市秋葉区', 'ニイガタシアキハク', '天ヶ沢', 'アマガサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市秋葉区鎌倉', '15', '15105', '9560115', '新潟県', 'ニイガタケン', '新潟市秋葉区', 'ニイガタシアキハク', '鎌倉', 'カマクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市秋葉区舟戸', '15', '15105', '9560116', '新潟県', 'ニイガタケン', '新潟市秋葉区', 'ニイガタシアキハク', '舟戸', 'フナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市秋葉区松ヶ丘', '15', '15105', '9560117', '新潟県', 'ニイガタケン', '新潟市秋葉区', 'ニイガタシアキハク', '松ヶ丘', 'マツガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市秋葉区横川浜', '15', '15105', '9560121', '新潟県', 'ニイガタケン', '新潟市秋葉区', 'ニイガタシアキハク', '横川浜', 'ヨコガワハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市秋葉区小向', '15', '15105', '9560122', '新潟県', 'ニイガタケン', '新潟市秋葉区', 'ニイガタシアキハク', '小向', 'コムカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市秋葉区水田', '15', '15105', '9560123', '新潟県', 'ニイガタケン', '新潟市秋葉区', 'ニイガタシアキハク', '水田', 'スイタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市秋葉区大蔵', '15', '15105', '9560801', '新潟県', 'ニイガタケン', '新潟市秋葉区', 'ニイガタシアキハク', '大蔵', 'ダイゾウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市秋葉区七日町', '15', '15105', '9560802', '新潟県', 'ニイガタケン', '新潟市秋葉区', 'ニイガタシアキハク', '七日町', 'ナノカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市秋葉区結', '15', '15105', '9560803', '新潟県', 'ニイガタケン', '新潟市秋葉区', 'ニイガタシアキハク', '結', 'ムスブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市秋葉区荻島', '15', '15105', '9560804', '新潟県', 'ニイガタケン', '新潟市秋葉区', 'ニイガタシアキハク', '荻島', 'オギジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市秋葉区中野', '15', '15105', '9560805', '新潟県', 'ニイガタケン', '新潟市秋葉区', 'ニイガタシアキハク', '中野', 'ナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市秋葉区みそら野', '15', '15105', '9560806', '新潟県', 'ニイガタケン', '新潟市秋葉区', 'ニイガタシアキハク', 'みそら野', 'ミソラノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市秋葉区満願寺', '15', '15105', '9560811', '新潟県', 'ニイガタケン', '新潟市秋葉区', 'ニイガタシアキハク', '満願寺', 'マンガンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市秋葉区中新田', '15', '15105', '9560812', '新潟県', 'ニイガタケン', '新潟市秋葉区', 'ニイガタシアキハク', '中新田', 'ナカシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市秋葉区大安寺', '15', '15105', '9560813', '新潟県', 'ニイガタケン', '新潟市秋葉区', 'ニイガタシアキハク', '大安寺', 'ダイアンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市秋葉区東金沢', '15', '15105', '9560814', '新潟県', 'ニイガタケン', '新潟市秋葉区', 'ニイガタシアキハク', '東金沢', 'ヒガシカナザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市秋葉区新金沢町', '15', '15105', '9560815', '新潟県', 'ニイガタケン', '新潟市秋葉区', 'ニイガタシアキハク', '新金沢町', 'シンカナザワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市秋葉区新津東町', '15', '15105', '9560816', '新潟県', 'ニイガタケン', '新潟市秋葉区', 'ニイガタシアキハク', '新津東町', 'ニイツヒガシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市秋葉区古田ノ内大野開', '15', '15105', '9560817', '新潟県', 'ニイガタケン', '新潟市秋葉区', 'ニイガタシアキハク', '古田ノ内大野開', 'コダノウチオオノビラキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市秋葉区西金沢', '15', '15105', '9560818', '新潟県', 'ニイガタケン', '新潟市秋葉区', 'ニイガタシアキハク', '西金沢', 'ニシカナザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市秋葉区六郷', '15', '15105', '9560821', '新潟県', 'ニイガタケン', '新潟市秋葉区', 'ニイガタシアキハク', '六郷', 'ロクゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市秋葉区新郷屋', '15', '15105', '9560822', '新潟県', 'ニイガタケン', '新潟市秋葉区', 'ニイガタシアキハク', '新郷屋', 'シンゴヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市秋葉区金屋', '15', '15105', '9560823', '新潟県', 'ニイガタケン', '新潟市秋葉区', 'ニイガタシアキハク', '金屋', 'カナヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市秋葉区市新', '15', '15105', '9560824', '新潟県', 'ニイガタケン', '新潟市秋葉区', 'ニイガタシアキハク', '市新', 'イチシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市秋葉区下新', '15', '15105', '9560825', '新潟県', 'ニイガタケン', '新潟市秋葉区', 'ニイガタシアキハク', '下新', 'シモシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市秋葉区岡田', '15', '15105', '9560826', '新潟県', 'ニイガタケン', '新潟市秋葉区', 'ニイガタシアキハク', '岡田', 'オカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市秋葉区大関', '15', '15105', '9560827', '新潟県', 'ニイガタケン', '新潟市秋葉区', 'ニイガタシアキハク', '大関', 'オオセキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市秋葉区北', '15', '15105', '9560828', '新潟県', 'ニイガタケン', '新潟市秋葉区', 'ニイガタシアキハク', '北', 'キタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市秋葉区中沢町', '15', '15105', '9560831', '新潟県', 'ニイガタケン', '新潟市秋葉区', 'ニイガタシアキハク', '中沢町', 'ナカザワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市秋葉区秋葉', '15', '15105', '9560832', '新潟県', 'ニイガタケン', '新潟市秋葉区', 'ニイガタシアキハク', '秋葉', 'アキハ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市秋葉区草水町', '15', '15105', '9560833', '新潟県', 'ニイガタケン', '新潟市秋葉区', 'ニイガタシアキハク', '草水町', 'クソウズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市秋葉区小口', '15', '15105', '9560834', '新潟県', 'ニイガタケン', '新潟市秋葉区', 'ニイガタシアキハク', '小口', 'コグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市秋葉区朝日', '15', '15105', '9560835', '新潟県', 'ニイガタケン', '新潟市秋葉区', 'ニイガタシアキハク', '朝日', 'アサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市秋葉区田家', '15', '15105', '9560836', '新潟県', 'ニイガタケン', '新潟市秋葉区', 'ニイガタシアキハク', '田家', 'タイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市秋葉区吉岡町', '15', '15105', '9560837', '新潟県', 'ニイガタケン', '新潟市秋葉区', 'ニイガタシアキハク', '吉岡町', 'ヨシオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市秋葉区東島', '15', '15105', '9560841', '新潟県', 'ニイガタケン', '新潟市秋葉区', 'ニイガタシアキハク', '東島', 'ヒガシジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市秋葉区西島', '15', '15105', '9560842', '新潟県', 'ニイガタケン', '新潟市秋葉区', 'ニイガタシアキハク', '西島', 'ニシジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市秋葉区割町', '15', '15105', '9560843', '新潟県', 'ニイガタケン', '新潟市秋葉区', 'ニイガタシアキハク', '割町', 'ワリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市秋葉区塩谷', '15', '15105', '9560844', '新潟県', 'ニイガタケン', '新潟市秋葉区', 'ニイガタシアキハク', '塩谷', 'シオダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市秋葉区金津', '15', '15105', '9560845', '新潟県', 'ニイガタケン', '新潟市秋葉区', 'ニイガタシアキハク', '金津', 'カナヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市秋葉区蒲ヶ沢', '15', '15105', '9560846', '新潟県', 'ニイガタケン', '新潟市秋葉区', 'ニイガタシアキハク', '蒲ヶ沢', 'ガワケサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市秋葉区古津', '15', '15105', '9560847', '新潟県', 'ニイガタケン', '新潟市秋葉区', 'ニイガタシアキハク', '古津', 'フルツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市秋葉区金沢町', '15', '15105', '9560851', '新潟県', 'ニイガタケン', '新潟市秋葉区', 'ニイガタシアキハク', '金沢町', 'カナザワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市秋葉区柄目木', '15', '15105', '9560852', '新潟県', 'ニイガタケン', '新潟市秋葉区', 'ニイガタシアキハク', '柄目木', 'ガラメキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市秋葉区飯柳', '15', '15105', '9560853', '新潟県', 'ニイガタケン', '新潟市秋葉区', 'ニイガタシアキハク', '飯柳', 'イヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市秋葉区滝谷町', '15', '15105', '9560854', '新潟県', 'ニイガタケン', '新潟市秋葉区', 'ニイガタシアキハク', '滝谷町', 'タキヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市秋葉区滝谷本町', '15', '15105', '9560855', '新潟県', 'ニイガタケン', '新潟市秋葉区', 'ニイガタシアキハク', '滝谷本町', 'タキヤホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市秋葉区北上', '15', '15105', '9560861', '新潟県', 'ニイガタケン', '新潟市秋葉区', 'ニイガタシアキハク', '北上', 'キタカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市秋葉区新町', '15', '15105', '9560862', '新潟県', 'ニイガタケン', '新潟市秋葉区', 'ニイガタシアキハク', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市秋葉区日宝町', '15', '15105', '9560863', '新潟県', 'ニイガタケン', '新潟市秋葉区', 'ニイガタシアキハク', '日宝町', 'ニッポウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市秋葉区新津本町', '15', '15105', '9560864', '新潟県', 'ニイガタケン', '新潟市秋葉区', 'ニイガタシアキハク', '新津本町', 'ニイツホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市秋葉区善道町', '15', '15105', '9560865', '新潟県', 'ニイガタケン', '新潟市秋葉区', 'ニイガタシアキハク', '善道町', 'ゼンドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市秋葉区下興野町', '15', '15105', '9560866', '新潟県', 'ニイガタケン', '新潟市秋葉区', 'ニイガタシアキハク', '下興野町', 'シモゴヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市', '15', '15206', '9570000', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('133983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市道賀', '15', '15206', '9570001', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '道賀', 'ドウガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市中谷内', '15', '15206', '9570002', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '中谷内', 'ナカヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市桑ノ口', '15', '15206', '9570003', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '桑ノ口', 'クワノグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市西名柄', '15', '15206', '9570004', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '西名柄', 'ニシナガラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市長畑', '15', '15206', '9570005', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '長畑', 'ナガバタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市中田町', '15', '15206', '9570006', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '中田町', 'ナカタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市小舟町', '15', '15206', '9570007', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '小舟町', 'コフネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市島潟', '15', '15206', '9570011', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '島潟', 'シマガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市東塚ノ目', '15', '15206', '9570012', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '東塚ノ目', 'ヒガシツカノメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市板敷', '15', '15206', '9570013', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '板敷', 'イタジキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市金谷', '15', '15206', '9570014', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '金谷', 'カナヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市東新町', '15', '15206', '9570015', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '東新町', 'トウシンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市豊町', '15', '15206', '9570016', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '豊町', 'ユタカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市新富町', '15', '15206', '9570017', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '新富町', 'シントミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市緑町', '15', '15206', '9570018', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '緑町', 'ミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市五十公野', '15', '15206', '9570021', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '五十公野', 'イジミノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('133999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市古寺', '15', '15206', '9570022', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '古寺', 'フルテラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市下新保', '15', '15206', '9570023', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '下新保', 'シモシンボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市上新保', '15', '15206', '9570024', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '上新保', 'カミシンボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市上内竹', '15', '15206', '9570025', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '上内竹', 'カミナイダケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市下内竹', '15', '15206', '9570026', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '下内竹', 'シモナイダケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市六日町', '15', '15206', '9570027', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '六日町', 'ムイカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市山崎', '15', '15206', '9570028', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '山崎', 'ヤマザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市小友', '15', '15206', '9570031', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '小友', 'オドモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市八幡新田', '15', '15206', '9570032', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '八幡新田', 'ヤワタシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市八幡', '15', '15206', '9570033', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '八幡', 'ヤワタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市小見', '15', '15206', '9570034', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '小見', 'オミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市丑首', '15', '15206', '9570035', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '丑首', 'ウシクビ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市米倉', '15', '15206', '9570036', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '米倉', 'ヨネクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市江口', '15', '15206', '9570037', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '江口', 'エグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市浦新田', '15', '15206', '9570041', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '浦新田', 'ウラシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市浦', '15', '15206', '9570042', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '浦', 'ウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市大崎', '15', '15206', '9570043', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '大崎', 'オオサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市松岡', '15', '15206', '9570044', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '松岡', 'マツオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市荒川', '15', '15206', '9570045', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '荒川', 'アラカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市上中山', '15', '15206', '9570046', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '上中山', 'カミナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市法正橋', '15', '15206', '9570047', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '法正橋', 'ホウジョウバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市瑞波', '15', '15206', '9570048', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '瑞波', 'ミズナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市城北町', '15', '15206', '9570051', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '城北町', 'ジョウホクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市大手町', '15', '15206', '9570052', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '大手町', 'オオテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市中央町', '15', '15206', '9570053', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '中央町', 'チュウオウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市本町', '15', '15206', '9570054', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市諏訪町', '15', '15206', '9570055', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '諏訪町', 'スワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市大栄町', '15', '15206', '9570056', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '大栄町', 'ダイエイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市御幸町', '15', '15206', '9570057', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '御幸町', 'ミユキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市西園町', '15', '15206', '9570058', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '西園町', 'ニシゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市住吉町', '15', '15206', '9570061', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '住吉町', 'スミヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市富塚町', '15', '15206', '9570062', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '富塚町', 'トミツカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市新栄町', '15', '15206', '9570063', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '新栄町', 'シンエイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市奥山新保', '15', '15206', '9570064', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '奥山新保', 'オクヤマシンボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市舟入町', '15', '15206', '9570065', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '舟入町', 'フネイリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市舟入', '15', '15206', '9570066', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '舟入', 'フナイリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市中曽根町', '15', '15206', '9570067', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '中曽根町', 'ナカゾネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市曽根', '15', '15206', '9570071', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '曽根', 'ソネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市日渡', '15', '15206', '9570072', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '日渡', 'ヒワタシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市弓越', '15', '15206', '9570073', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '弓越', 'ミコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市北蓑口', '15', '15206', '9570074', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '北蓑口', 'キタミノグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市西蓑口', '15', '15206', '9570075', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '西蓑口', 'ニシミノグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市西宮内', '15', '15206', '9570076', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '西宮内', 'ニシミヤウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市則清', '15', '15206', '9570077', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '則清', 'ノリキヨ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市則清新田', '15', '15206', '9570078', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '則清新田', 'ノリキヨシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市上中沢', '15', '15206', '9570081', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '上中沢', 'カミナカザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市佐々木', '15', '15206', '9570082', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '佐々木', 'ササキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市下興野', '15', '15206', '9570083', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '下興野', 'シモゴヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市飯島甲', '15', '15206', '9570084', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '飯島甲', 'イイジマコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市飯島乙', '15', '15206', '9570085', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '飯島乙', 'イイジマオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市飯島新田', '15', '15206', '9570086', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '飯島新田', 'イイジマシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市砂山', '15', '15206', '9570087', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '砂山', 'スナヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市太田新田', '15', '15206', '9570091', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '太田新田', 'オオタシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市鳥穴', '15', '15206', '9570092', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '鳥穴', 'トリアナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県北蒲原郡聖籠町', '15', '15307', '9570100', '新潟県', 'ニイガタケン', '北蒲原郡聖籠町', 'キタカンバラグンセイロウマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('134054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県北蒲原郡聖籠町東港', '15', '15307', '9570101', '新潟県', 'ニイガタケン', '北蒲原郡聖籠町', 'キタカンバラグンセイロウマチ', '東港', 'ヒガシコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県北蒲原郡聖籠町位守町', '15', '15307', '9570102', '新潟県', 'ニイガタケン', '北蒲原郡聖籠町', 'キタカンバラグンセイロウマチ', '位守町', 'イモリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県北蒲原郡聖籠町網代浜', '15', '15307', '9570103', '新潟県', 'ニイガタケン', '北蒲原郡聖籠町', 'キタカンバラグンセイロウマチ', '網代浜', 'アジロハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県北蒲原郡聖籠町亀塚', '15', '15307', '9570104', '新潟県', 'ニイガタケン', '北蒲原郡聖籠町', 'キタカンバラグンセイロウマチ', '亀塚', 'カメヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県北蒲原郡聖籠町次第浜', '15', '15307', '9570105', '新潟県', 'ニイガタケン', '北蒲原郡聖籠町', 'キタカンバラグンセイロウマチ', '次第浜', 'シダイハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県北蒲原郡聖籠町蓮潟', '15', '15307', '9570106', '新潟県', 'ニイガタケン', '北蒲原郡聖籠町', 'キタカンバラグンセイロウマチ', '蓮潟', 'ハスガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県北蒲原郡聖籠町真野', '15', '15307', '9570111', '新潟県', 'ニイガタケン', '北蒲原郡聖籠町', 'キタカンバラグンセイロウマチ', '真野', 'マノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県北蒲原郡聖籠町道賀新田', '15', '15307', '9570112', '新潟県', 'ニイガタケン', '北蒲原郡聖籠町', 'キタカンバラグンセイロウマチ', '道賀新田', 'ドウガシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県北蒲原郡聖籠町上大谷内', '15', '15307', '9570113', '新潟県', 'ニイガタケン', '北蒲原郡聖籠町', 'キタカンバラグンセイロウマチ', '上大谷内', 'カミオオヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県北蒲原郡聖籠町丸潟', '15', '15307', '9570114', '新潟県', 'ニイガタケン', '北蒲原郡聖籠町', 'キタカンバラグンセイロウマチ', '丸潟', 'マルガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県北蒲原郡聖籠町桃山', '15', '15307', '9570115', '新潟県', 'ニイガタケン', '北蒲原郡聖籠町', 'キタカンバラグンセイロウマチ', '桃山', 'モモヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県北蒲原郡聖籠町山倉', '15', '15307', '9570116', '新潟県', 'ニイガタケン', '北蒲原郡聖籠町', 'キタカンバラグンセイロウマチ', '山倉', 'ヤマグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県北蒲原郡聖籠町諏訪山', '15', '15307', '9570117', '新潟県', 'ニイガタケン', '北蒲原郡聖籠町', 'キタカンバラグンセイロウマチ', '諏訪山', 'スワヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県北蒲原郡聖籠町大夫', '15', '15307', '9570121', '新潟県', 'ニイガタケン', '北蒲原郡聖籠町', 'キタカンバラグンセイロウマチ', '大夫', 'ダイブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県北蒲原郡聖籠町三賀', '15', '15307', '9570122', '新潟県', 'ニイガタケン', '北蒲原郡聖籠町', 'キタカンバラグンセイロウマチ', '三賀', 'サンガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県北蒲原郡聖籠町二本松', '15', '15307', '9570123', '新潟県', 'ニイガタケン', '北蒲原郡聖籠町', 'キタカンバラグンセイロウマチ', '二本松', 'ニホンマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県北蒲原郡聖籠町蓮野', '15', '15307', '9570124', '新潟県', 'ニイガタケン', '北蒲原郡聖籠町', 'キタカンバラグンセイロウマチ', '蓮野', 'ハスノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県北蒲原郡聖籠町別條', '15', '15307', '9570125', '新潟県', 'ニイガタケン', '北蒲原郡聖籠町', 'キタカンバラグンセイロウマチ', '別條', 'ベッジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県北蒲原郡聖籠町大夫興野', '15', '15307', '9570126', '新潟県', 'ニイガタケン', '北蒲原郡聖籠町', 'キタカンバラグンセイロウマチ', '大夫興野', 'ダイブコウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県北蒲原郡聖籠町藤寄', '15', '15307', '9570127', '新潟県', 'ニイガタケン', '北蒲原郡聖籠町', 'キタカンバラグンセイロウマチ', '藤寄', 'フジヨセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市真中', '15', '15206', '9570201', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '真中', 'マナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市古田', '15', '15206', '9570202', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '古田', 'コダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市下中沢', '15', '15206', '9570203', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '下中沢', 'シモナカザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市稲荷岡', '15', '15206', '9570204', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '稲荷岡', 'イナリオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市関井', '15', '15206', '9570205', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '関井', 'セキイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市福岡', '15', '15206', '9570206', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '福岡', 'フクオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市富島', '15', '15206', '9570207', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '富島', 'トミジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市片桐', '15', '15206', '9570212', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '片桐', 'カタギリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市高島', '15', '15206', '9570213', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '高島', 'タカシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市中島', '15', '15206', '9570214', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '中島', 'ナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市住吉', '15', '15206', '9570215', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '住吉', 'スミヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市南成田', '15', '15206', '9570216', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '南成田', 'ミナミナリタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市大中島', '15', '15206', '9570217', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '大中島', 'オオナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市長者舘', '15', '15206', '9570221', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '長者舘', 'チョウジャダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市中野', '15', '15206', '9570222', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '中野', 'ナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市長島', '15', '15206', '9570223', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '長島', 'ナガシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市小川', '15', '15206', '9570224', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '小川', 'オガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市米子', '15', '15206', '9570225', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '米子', 'ヨネコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市宮吉', '15', '15206', '9570226', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '宮吉', 'ミヤヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市藤塚浜', '15', '15206', '9570231', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '藤塚浜', 'フジツカハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市真野原外', '15', '15206', '9570232', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '真野原外', 'マノハラソト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市真野原', '15', '15206', '9570233', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '真野原', 'マノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市二ツ山', '15', '15206', '9570234', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '二ツ山', 'フタツヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市人橋', '15', '15206', '9570235', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '人橋', 'ヒトバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市元郷', '15', '15206', '9570236', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '元郷', 'モトゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市上三光', '15', '15206', '9570331', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '上三光', 'カミサンコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市虎丸', '15', '15206', '9570332', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '虎丸', 'トラマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市田貝', '15', '15206', '9570333', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '田貝', 'タガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市上楠川', '15', '15206', '9570334', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '上楠川', 'カミクスガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市下楠川', '15', '15206', '9570335', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '下楠川', 'シモクスガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市下三光', '15', '15206', '9570336', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '下三光', 'シモサンコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市下羽津', '15', '15206', '9570341', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '下羽津', 'シモハネヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市本間新田', '15', '15206', '9570342', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '本間新田', 'ホンマシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市上羽津', '15', '15206', '9570343', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '上羽津', 'カミハネヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市板山', '15', '15206', '9570344', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '板山', 'イタヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市小戸', '15', '15206', '9570345', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '小戸', 'オド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市宮古木', '15', '15206', '9570346', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '宮古木', 'ミヤコギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市大友', '15', '15206', '9570347', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '大友', 'オオドモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市東姫田', '15', '15206', '9570351', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '東姫田', 'ヒガシヒメダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市南楯', '15', '15206', '9570352', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '南楯', 'ミナミタテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市石喜', '15', '15206', '9570353', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '石喜', 'イシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市下高関', '15', '15206', '9570354', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '下高関', 'シモタカセキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市敦賀', '15', '15206', '9570355', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '敦賀', 'ツルガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市岡田', '15', '15206', '9570356', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '岡田', 'オカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市西姫田', '15', '15206', '9570357', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '西姫田', 'ニシヒメダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市中々山', '15', '15206', '9570461', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '中々山', 'ナカナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市滝谷', '15', '15206', '9570462', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '滝谷', 'タキダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市東赤谷', '15', '15206', '9570463', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '東赤谷', 'ヒガシアカタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市上赤谷', '15', '15206', '9570464', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '上赤谷', 'カミアカタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市大槻', '15', '15206', '9570465', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '大槻', 'オオツキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市山内', '15', '15206', '9570466', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '山内', 'ヤマウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市', '15', '15212', '9580000', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('134152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市馬下', '15', '15212', '9580001', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '馬下', 'マオロシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市早川', '15', '15212', '9580002', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '早川', 'ハヤカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市吉浦', '15', '15212', '9580003', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '吉浦', 'ヨシウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市柏尾', '15', '15212', '9580004', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '柏尾', 'カシオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市間島', '15', '15212', '9580005', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '間島', 'マジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市野潟', '15', '15212', '9580006', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '野潟', 'ノガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市大月', '15', '15212', '9580007', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '大月', 'オオヅキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市岩ケ崎', '15', '15212', '9580008', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '岩ケ崎', 'イワガサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市滝の前', '15', '15212', '9580011', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '滝の前', 'タキノマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市大平', '15', '15212', '9580012', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '大平', 'オオダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市羽下ケ渕', '15', '15212', '9580013', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '羽下ケ渕', 'ハゲガフチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市下渡', '15', '15212', '9580014', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '下渡', 'ゲド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市瀬波新田町', '15', '15212', '9580021', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '瀬波新田町', 'セナミシンデンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市瀬波横町', '15', '15212', '9580022', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '瀬波横町', 'セナミヨコマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市瀬波上町', '15', '15212', '9580023', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '瀬波上町', 'セナミカンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市瀬波中町', '15', '15212', '9580024', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '瀬波中町', 'セナミナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市松波町', '15', '15212', '9580025', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '松波町', 'マツナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市瀬波浜町', '15', '15212', '9580026', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '瀬波浜町', 'セナミハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市学校町', '15', '15212', '9580031', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '学校町', 'ガッコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市松原町', '15', '15212', '9580032', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '松原町', 'マツバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市緑町', '15', '15212', '9580033', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '緑町', 'ミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市松山', '15', '15212', '9580034', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '松山', 'マツヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市三面', '15', '15212', '9580035', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '三面', 'ミオモテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市浦田', '15', '15212', '9580036', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '浦田', 'ウラタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市瀬波温泉', '15', '15212', '9580037', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '瀬波温泉', 'セナミオンセン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市浜新田', '15', '15212', '9580038', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '浜新田', 'ハマシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市岩船三日市', '15', '15212', '9580041', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '岩船三日市', 'イワフネミッカイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市岩船北浜町', '15', '15212', '9580042', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '岩船北浜町', 'イワフネキタハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市岩船下大町', '15', '15212', '9580043', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '岩船下大町', 'イワフネシモオオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市岩船上大町', '15', '15212', '9580044', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '岩船上大町', 'イワフネカミオオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市岩船上浜町', '15', '15212', '9580045', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '岩船上浜町', 'イワフネカミハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市岩船下浜町', '15', '15212', '9580046', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '岩船下浜町', 'イワフネシモハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市岩船岸見寺町', '15', '15212', '9580047', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '岩船岸見寺町', 'イワフネガンゲンジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市岩船地蔵町', '15', '15212', '9580048', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '岩船地蔵町', 'イワフネジゾウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市岩船上町', '15', '15212', '9580051', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '岩船上町', 'イワフネカンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市八日市', '15', '15212', '9580052', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '八日市', 'ヨウカイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市上の山', '15', '15212', '9580053', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '上の山', 'カミノヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市岩船新田町', '15', '15212', '9580054', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '岩船新田町', 'イワフネシンデンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市岩船縦新町', '15', '15212', '9580055', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '岩船縦新町', 'イワフネタテシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市岩船中新町', '15', '15212', '9580056', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '岩船中新町', 'イワフネナカシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市岩船横新町', '15', '15212', '9580057', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '岩船横新町', 'イワフネヨコシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市岩船港町', '15', '15212', '9580058', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '岩船港町', 'イワフネミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県岩船郡粟島浦村', '15', '15586', '9580061', '新潟県', 'ニイガタケン', '岩船郡粟島浦村', 'イワフネグンアワシマウラムラ', null, '　', '（全域）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('134195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市蒲萄', '15', '15212', '9580201', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '蒲萄', 'ブドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市大須戸', '15', '15212', '9580202', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '大須戸', 'オオスド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市荒沢', '15', '15212', '9580203', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '荒沢', 'アラサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市小須戸', '15', '15212', '9580204', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '小須戸', 'コスド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市塩野町', '15', '15212', '9580205', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '塩野町', 'シオノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市松岡', '15', '15212', '9580206', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '松岡', 'マツオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市高根', '15', '15212', '9580211', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '高根', 'タカネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市北大平', '15', '15212', '9580212', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '北大平', 'キタオオダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市早稲田', '15', '15212', '9580213', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '早稲田', 'ワセダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市板屋越', '15', '15212', '9580214', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '板屋越', 'イタヤゴシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市檜原', '15', '15212', '9580215', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '檜原', 'ヒバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市薦川', '15', '15212', '9580221', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '薦川', 'コモガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市猿田', '15', '15212', '9580222', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '猿田', 'サルタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市中原', '15', '15212', '9580223', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '中原', 'ナカハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市黒田', '15', '15212', '9580224', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '黒田', 'クロダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市関口', '15', '15212', '9580225', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '関口', 'セキグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市朝日中野', '15', '15212', '9580226', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '朝日中野', 'アサヒナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市布部', '15', '15212', '9580231', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '布部', 'ヌノベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市新屋', '15', '15212', '9580232', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '新屋', 'アラヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市中新保', '15', '15212', '9580233', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '中新保', 'ナカシンボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市堀野', '15', '15212', '9580234', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '堀野', 'ホリノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市石住', '15', '15212', '9580235', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '石住', 'イシズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市上中島', '15', '15212', '9580236', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '上中島', 'カミナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市岩崩', '15', '15212', '9580241', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '岩崩', 'イワクズレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市茎太', '15', '15212', '9580242', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '茎太', 'クキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市千縄', '15', '15212', '9580243', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '千縄', 'チナワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市小揚', '15', '15212', '9580244', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '小揚', 'コアゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市釜杭', '15', '15212', '9580245', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '釜杭', 'カマグイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市笹平', '15', '15212', '9580246', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '笹平', 'ササダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市岩沢', '15', '15212', '9580251', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '岩沢', 'イワサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市下新保', '15', '15212', '9580252', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '下新保', 'シモシンボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市大場沢', '15', '15212', '9580253', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '大場沢', 'オオバザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市十川', '15', '15212', '9580254', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '十川', 'ソガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市熊登', '15', '15212', '9580255', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '熊登', 'クマト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市猿沢', '15', '15212', '9580261', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '猿沢', 'サルサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市上野', '15', '15212', '9580262', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '上野', 'ウエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市川端', '15', '15212', '9580263', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '川端', 'カワバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市鵜渡路', '15', '15212', '9580264', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '鵜渡路', 'ウノトロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市下中島', '15', '15212', '9580265', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '下中島', 'シモナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市宮ノ下', '15', '15212', '9580266', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '宮ノ下', 'ミヤノシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市寺尾', '15', '15212', '9580267', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '寺尾', 'テラオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市小川', '15', '15212', '9580268', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '小川', 'オガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市古渡路', '15', '15212', '9580269', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '古渡路', 'フルトロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市あけぼの', '15', '15212', '9580270', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', 'あけぼの', 'アケボノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市西興屋', '15', '15212', '9580801', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '西興屋', 'ニシコウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市四日市', '15', '15212', '9580802', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '四日市', 'ヨッカイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市天神岡', '15', '15212', '9580803', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '天神岡', 'テンジンオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市下山田', '15', '15212', '9580804', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '下山田', 'シモヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市上山田', '15', '15212', '9580805', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '上山田', 'カミヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市小谷', '15', '15212', '9580806', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '小谷', 'オダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市日下', '15', '15212', '9580807', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '日下', 'クサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市上相川', '15', '15212', '9580808', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '上相川', 'カミアイカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市下相川', '15', '15212', '9580809', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '下相川', 'シモアイカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市高平', '15', '15212', '9580811', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '高平', 'タカダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市大関', '15', '15212', '9580812', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '大関', 'オオセキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市鋳物師', '15', '15212', '9580813', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '鋳物師', 'イモジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市門前', '15', '15212', '9580814', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '門前', 'モンゼン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市大栗田', '15', '15212', '9580815', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '大栗田', 'オオクリダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市赤沢', '15', '15212', '9580816', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '赤沢', 'アカサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市菅沼', '15', '15212', '9580817', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '菅沼', 'スガヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市袋', '15', '15212', '9580818', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '袋', 'フクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市山辺里', '15', '15212', '9580821', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '山辺里', 'サベリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市坪根', '15', '15212', '9580822', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '坪根', 'ツボネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市仲間町', '15', '15212', '9580823', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '仲間町', 'チュウゲンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市本町', '15', '15212', '9580824', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '本町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市杉原', '15', '15212', '9580831', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '杉原', 'スギワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市石原', '15', '15212', '9580832', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '石原', 'イシワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市堀片', '15', '15212', '9580833', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '堀片', 'ホリカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市新町', '15', '15212', '9580834', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市二之町', '15', '15212', '9580835', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '二之町', 'ニノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市羽黒口', '15', '15212', '9580836', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '羽黒口', 'ハグログチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市三之町', '15', '15212', '9580837', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '三之町', 'サンノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市小町', '15', '15212', '9580841', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '小町', 'コマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市大町', '15', '15212', '9580842', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '大町', 'オオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市上町', '15', '15212', '9580843', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '上町', 'カンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市長井町', '15', '15212', '9580844', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '長井町', 'ナガイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市細工町', '15', '15212', '9580845', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '細工町', 'サイクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市安良町', '15', '15212', '9580846', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '安良町', 'アラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市大工町', '15', '15212', '9580847', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '大工町', 'ダイクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市小国町', '15', '15212', '9580848', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '小国町', 'オグニマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市寺町', '15', '15212', '9580849', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '寺町', 'テラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市羽黒町', '15', '15212', '9580851', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '羽黒町', 'ハグロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市南町', '15', '15212', '9580852', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '南町', 'ミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市山居町', '15', '15212', '9580853', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '山居町', 'サンキョマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市田端町', '15', '15212', '9580854', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '田端町', 'タバタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市飯野西', '15', '15212', '9580855', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '飯野西', 'イイノニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市飯野桜ケ丘', '15', '15212', '9580856', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '飯野桜ケ丘', 'イイノサクラガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市飯野', '15', '15212', '9580857', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '飯野', 'イイノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市中川原団地', '15', '15212', '9580861', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '中川原団地', 'ナカガワラダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市若葉町', '15', '15212', '9580862', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '若葉町', 'ワカバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市鍛冶町', '15', '15212', '9580863', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '鍛冶町', 'カジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市肴町', '15', '15212', '9580864', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '肴町', 'サカナマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市幸町', '15', '15212', '9580865', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市村上', '15', '15212', '9580866', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '村上', 'ムラカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市大欠', '15', '15212', '9580867', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '大欠', 'オオガキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市久保多町', '15', '15212', '9580871', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '久保多町', 'クボタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市片町', '15', '15212', '9580872', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '片町', 'カタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市上片町', '15', '15212', '9580873', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '上片町', 'カミカタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市庄内町', '15', '15212', '9580874', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '庄内町', 'ショウナイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市加賀町', '15', '15212', '9580875', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '加賀町', 'カガマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市塩町', '15', '15212', '9580876', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '塩町', 'シオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市泉町', '15', '15212', '9580877', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '泉町', 'イズミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市佐善', '15', '15213', '9590101', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '佐善', 'サゼン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市牧ケ花', '15', '15213', '9590102', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '牧ケ花', 'マキガハナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市砂子塚', '15', '15213', '9590103', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '砂子塚', 'スナコツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市分水弥生町', '15', '15213', '9590104', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '分水弥生町', 'ブンスイヤヨイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市中島', '15', '15213', '9590105', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '中島', 'ナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市分水東学校町', '15', '15213', '9590106', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '分水東学校町', 'ブンスイヒガシガッコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市分水旭町', '15', '15213', '9590107', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '分水旭町', 'ブンスイアサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市太田', '15', '15213', '9590108', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '太田', 'オオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市分水向陽', '15', '15213', '9590109', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '分水向陽', 'ブンスイコウヨウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市横田', '15', '15213', '9590111', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '横田', 'ヨコタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市熊森', '15', '15213', '9590112', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '熊森', 'クマノモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市笈ケ島', '15', '15213', '9590113', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '笈ケ島', 'オイガシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市一ノ山', '15', '15213', '9590114', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '一ノ山', 'イチノヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市分水学校町', '15', '15213', '9590115', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '分水学校町', 'ブンスイガッコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市新興野', '15', '15213', '9590116', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '新興野', 'シンコウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市笹曲', '15', '15213', '9590117', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '笹曲', 'ササマガリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市分水向山', '15', '15213', '9590118', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '分水向山', 'ブンスイムコウヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市分水大武', '15', '15213', '9590119', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '分水大武', 'ブンスイオオタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市分水栄町', '15', '15213', '9590120', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '分水栄町', 'ブンスイサカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市地蔵堂', '15', '15213', '9590121', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '地蔵堂', 'ジゾウドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市大武新田', '15', '15213', '9590122', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '大武新田', 'オオタケシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市大川津', '15', '15213', '9590123', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '大川津', 'オオカワヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市五千石', '15', '15213', '9590124', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '五千石', 'ゴセンゴク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市新長', '15', '15213', '9590125', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '新長', 'シンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市野中才', '15', '15213', '9590126', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '野中才', 'ノナカサイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市分水文京町', '15', '15213', '9590127', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '分水文京町', 'ブンスイブンキョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市分水新町', '15', '15213', '9590128', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '分水新町', 'ブンスイシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市地蔵堂本町', '15', '15213', '9590129', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '地蔵堂本町', 'ジゾウドウホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市分水桜町', '15', '15213', '9590130', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '分水桜町', 'ブンスイサクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市泉新', '15', '15213', '9590131', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '泉新', 'イズミシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市分水あけぼの', '15', '15213', '9590132', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '分水あけぼの', 'ブンスイアケボノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市新堀', '15', '15213', '9590133', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '新堀', 'ニイボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市真木山', '15', '15213', '9590134', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '真木山', 'マギヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市渡部', '15', '15213', '9590135', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '渡部', 'ワタベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市国上', '15', '15213', '9590136', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '国上', 'クガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市源八新田', '15', '15213', '9590137', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '源八新田', 'ゲンパチシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市幕島', '15', '15213', '9590138', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '幕島', 'マクジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市長辰', '15', '15213', '9590139', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '長辰', 'チョウシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市寺泊敦ケ曽根', '15', '15202', '9590141', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '寺泊敦ケ曽根', 'テラドマリツルガソネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市寺泊万善寺', '15', '15202', '9590142', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '寺泊万善寺', 'テラドマリバンゼンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市寺泊高内', '15', '15202', '9590143', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '寺泊高内', 'テラドマリタカウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市寺泊町軽井', '15', '15202', '9590144', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '寺泊町軽井', 'テラドマリマチカルイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市寺泊平野新村新田', '15', '15202', '9590145', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '寺泊平野新村新田', 'テラドマリヒラノシンムラシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市寺泊田尻', '15', '15202', '9590146', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '寺泊田尻', 'テラドマリタジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市寺泊岩方', '15', '15202', '9590147', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '寺泊岩方', 'テラドマリイワカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市寺泊矢田', '15', '15202', '9590148', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '寺泊矢田', 'テラドマリヤダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市寺泊入軽井', '15', '15202', '9590149', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '寺泊入軽井', 'テラドマリイリカルイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市寺泊求草', '15', '15202', '9590151', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '寺泊求草', 'テラドマリモトメグサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市寺泊下桐', '15', '15202', '9590152', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '寺泊下桐', 'テラドマリシモギリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市寺泊硲田', '15', '15202', '9590153', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '寺泊硲田', 'テラドマリハザマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市寺泊五分一', '15', '15202', '9590154', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '寺泊五分一', 'テラドマリゴブイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市寺泊有信', '15', '15202', '9590155', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '寺泊有信', 'テラドマリアリノブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市寺泊木島', '15', '15202', '9590156', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '寺泊木島', 'テラドマリキジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市寺泊鰐口', '15', '15202', '9590157', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '寺泊鰐口', 'テラドマリワニクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市寺泊竹森', '15', '15202', '9590161', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '寺泊竹森', 'テラドマリタケモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市寺泊小豆曽根', '15', '15202', '9590162', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '寺泊小豆曽根', 'テラドマリアズキソネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市寺泊新長', '15', '15202', '9590163', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '寺泊新長', 'テラドマリシンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市寺泊下中条', '15', '15202', '9590164', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '寺泊下中条', 'テラドマリシモナカジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県長岡市寺泊北曽根', '15', '15202', '9590165', '新潟県', 'ニイガタケン', '長岡市', 'ナガオカシ', '寺泊北曽根', 'テラドマリキタゾネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市溝古新', '15', '15213', '9590171', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '溝古新', 'ミゾコシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市溝', '15', '15213', '9590172', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '溝', 'ミゾ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市上諏訪', '15', '15213', '9590181', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '上諏訪', 'カミスワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市中諏訪', '15', '15213', '9590182', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '中諏訪', 'ナカスワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市下諏訪', '15', '15213', '9590183', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '下諏訪', 'シモスワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市西槇', '15', '15213', '9590201', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '西槇', 'ニシマギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市佐渡山', '15', '15213', '9590202', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '佐渡山', 'サドヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市小島', '15', '15213', '9590203', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '小島', 'コジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市雀森', '15', '15213', '9590205', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '雀森', 'スズメモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市米納津', '15', '15213', '9590206', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '米納津', 'ヨノウヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市庚塚', '15', '15213', '9590207', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '庚塚', 'カネヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市大保', '15', '15213', '9590208', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '大保', 'ダイボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市富永', '15', '15213', '9590211', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '富永', 'トミナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市富永十兵衛新田', '15', '15213', '9590212', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '富永十兵衛新田', 'トミナガジュウベエシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市吉田吉栄', '15', '15213', '9590213', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '吉田吉栄', 'ヨシダヨシエイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市吉田法花堂', '15', '15213', '9590214', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '吉田法花堂', 'ヨシダホッケドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市吉田下中野', '15', '15213', '9590215', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '吉田下中野', 'ヨシダシモナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市吉田春日町', '15', '15213', '9590216', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '吉田春日町', 'ヨシダカスガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市吉田曙町', '15', '15213', '9590217', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '吉田曙町', 'ヨシダアケボノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市吉田西太田', '15', '15213', '9590221', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '吉田西太田', 'ヨシダニシオオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市下粟生津', '15', '15213', '9590222', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '下粟生津', 'シモアオウヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市田中新', '15', '15213', '9590223', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '田中新', 'タナカシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市野本', '15', '15213', '9590224', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '野本', 'ノモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市上河原', '15', '15213', '9590225', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '上河原', 'カミガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市粟生津', '15', '15213', '9590227', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '粟生津', 'アオウヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市高木', '15', '15213', '9590228', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '高木', 'タカキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市吉田日之出町', '15', '15213', '9590231', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '吉田日之出町', 'ヨシダヒノデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市吉田東栄町', '15', '15213', '9590232', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '吉田東栄町', 'ヨシダヒガシサカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市吉田栄町', '15', '15213', '9590233', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '吉田栄町', 'ヨシダサカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市吉田水道町', '15', '15213', '9590234', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '吉田水道町', 'ヨシダスイドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市吉田旭町', '15', '15213', '9590235', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '吉田旭町', 'ヨシダアサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市吉田松岡町', '15', '15213', '9590236', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '吉田松岡町', 'ヨシダマツオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市吉田堤町', '15', '15213', '9590237', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '吉田堤町', 'ヨシダツツミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市吉田神田町', '15', '15213', '9590241', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '吉田神田町', 'ヨシダカンダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市吉田大保町', '15', '15213', '9590242', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '吉田大保町', 'ヨシダダイボチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市吉田松岡新田', '15', '15213', '9590243', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '吉田松岡新田', 'ヨシダマツオカシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市吉田中町', '15', '15213', '9590244', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '吉田中町', 'ヨシダナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市吉田上町', '15', '15213', '9590245', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '吉田上町', 'ヨシダカンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市吉田新町', '15', '15213', '9590246', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '吉田新町', 'ヨシダシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市吉田新田町', '15', '15213', '9590247', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '吉田新田町', 'ヨシダシンデンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市吉田浜首町', '15', '15213', '9590248', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '吉田浜首町', 'ヨシダハマクビチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市吉田矢作', '15', '15213', '9590250', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '吉田矢作', 'ヨシダヤハギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市吉田本所', '15', '15213', '9590251', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '吉田本所', 'ヨシダホンジョ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市吉田学校町', '15', '15213', '9590252', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '吉田学校町', 'ヨシダガッコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市吉田下町', '15', '15213', '9590253', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '吉田下町', 'ヨシダシモマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市吉田神明町', '15', '15213', '9590254', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '吉田神明町', 'ヨシダシンメイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市吉田弥生町', '15', '15213', '9590255', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '吉田弥生町', 'ヨシダヤヨイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市吉田寿町', '15', '15213', '9590256', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '吉田寿町', 'ヨシダコトブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市吉田幸町', '15', '15213', '9590257', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '吉田幸町', 'ヨシダサイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市吉田鴻巣', '15', '15213', '9590261', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '吉田鴻巣', 'ヨシダコウノス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市吉田若生町', '15', '15213', '9590262', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '吉田若生町', 'ヨシダワコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市吉田吉田桃山町', '15', '15213', '9590263', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '吉田', 'ヨシダ', null, null, '吉田桃山町', 'ヨシダモモヤマチョウ');
INSERT INTO `ms_addresses` VALUES ('134422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市吉田', '15', '15213', '9590264', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '吉田', 'ヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市吉田東町', '15', '15213', '9590265', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '吉田東町', 'ヨシダアヅマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市吉田文京町', '15', '15213', '9590266', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '吉田文京町', 'ヨシダブンキョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市吉田宮小路', '15', '15213', '9590267', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '吉田宮小路', 'ヨシダミヤコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市吉田本町', '15', '15213', '9590268', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '吉田本町', 'ヨシダモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県西蒲原郡弥彦村', '15', '15342', '9590300', '新潟県', 'ニイガタケン', '西蒲原郡弥彦村', 'ニシカンバラグンヤヒコムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('134433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県西蒲原郡弥彦村えび穴', '15', '15342', '9590301', '新潟県', 'ニイガタケン', '西蒲原郡弥彦村', 'ニシカンバラグンヤヒコムラ', 'えび穴', 'エビアナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県西蒲原郡弥彦村田中新田', '15', '15342', '9590302', '新潟県', 'ニイガタケン', '西蒲原郡弥彦村', 'ニシカンバラグンヤヒコムラ', '田中新田', 'タナカシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県西蒲原郡弥彦村平野', '15', '15342', '9590303', '新潟県', 'ニイガタケン', '西蒲原郡弥彦村', 'ニシカンバラグンヤヒコムラ', '平野', 'ヒラノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県西蒲原郡弥彦村荻野', '15', '15342', '9590304', '新潟県', 'ニイガタケン', '西蒲原郡弥彦村', 'ニシカンバラグンヤヒコムラ', '荻野', 'オギノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県西蒲原郡弥彦村矢作', '15', '15342', '9590305', '新潟県', 'ニイガタケン', '西蒲原郡弥彦村', 'ニシカンバラグンヤヒコムラ', '矢作', 'ヤハギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県西蒲原郡弥彦村浜首', '15', '15342', '9590306', '新潟県', 'ニイガタケン', '西蒲原郡弥彦村', 'ニシカンバラグンヤヒコムラ', '浜首', 'ハマクビ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県西蒲原郡弥彦村川崎', '15', '15342', '9590307', '新潟県', 'ニイガタケン', '西蒲原郡弥彦村', 'ニシカンバラグンヤヒコムラ', '川崎', 'カワサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県西蒲原郡弥彦村大戸', '15', '15342', '9590308', '新潟県', 'ニイガタケン', '西蒲原郡弥彦村', 'ニシカンバラグンヤヒコムラ', '大戸', 'オオド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県西蒲原郡弥彦村峰見', '15', '15342', '9590309', '新潟県', 'ニイガタケン', '西蒲原郡弥彦村', 'ニシカンバラグンヤヒコムラ', '峰見', 'ミネミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県西蒲原郡弥彦村美山', '15', '15342', '9590310', '新潟県', 'ニイガタケン', '西蒲原郡弥彦村', 'ニシカンバラグンヤヒコムラ', '美山', 'ミヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県西蒲原郡弥彦村井田', '15', '15342', '9590311', '新潟県', 'ニイガタケン', '西蒲原郡弥彦村', 'ニシカンバラグンヤヒコムラ', '井田', 'イダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県西蒲原郡弥彦村中山', '15', '15342', '9590312', '新潟県', 'ニイガタケン', '西蒲原郡弥彦村', 'ニシカンバラグンヤヒコムラ', '中山', 'ナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県西蒲原郡弥彦村山崎', '15', '15342', '9590313', '新潟県', 'ニイガタケン', '西蒲原郡弥彦村', 'ニシカンバラグンヤヒコムラ', '山崎', 'ヤマザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県西蒲原郡弥彦村山岸', '15', '15342', '9590314', '新潟県', 'ニイガタケン', '西蒲原郡弥彦村', 'ニシカンバラグンヤヒコムラ', '山岸', 'ヤマギシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県西蒲原郡弥彦村麓村新田', '15', '15342', '9590315', '新潟県', 'ニイガタケン', '西蒲原郡弥彦村', 'ニシカンバラグンヤヒコムラ', '麓村新田', 'フモトムラシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県西蒲原郡弥彦村村山', '15', '15342', '9590316', '新潟県', 'ニイガタケン', '西蒲原郡弥彦村', 'ニシカンバラグンヤヒコムラ', '村山', 'ムラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県西蒲原郡弥彦村境江', '15', '15342', '9590317', '新潟県', 'ニイガタケン', '西蒲原郡弥彦村', 'ニシカンバラグンヤヒコムラ', '境江', 'サカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県西蒲原郡弥彦村麓', '15', '15342', '9590318', '新潟県', 'ニイガタケン', '西蒲原郡弥彦村', 'ニシカンバラグンヤヒコムラ', '麓', 'フモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県西蒲原郡弥彦村観音寺', '15', '15342', '9590319', '新潟県', 'ニイガタケン', '西蒲原郡弥彦村', 'ニシカンバラグンヤヒコムラ', '観音寺', 'カンオンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県西蒲原郡弥彦村上泉', '15', '15342', '9590321', '新潟県', 'ニイガタケン', '西蒲原郡弥彦村', 'ニシカンバラグンヤヒコムラ', '上泉', 'カミイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県西蒲原郡弥彦村走出', '15', '15342', '9590322', '新潟県', 'ニイガタケン', '西蒲原郡弥彦村', 'ニシカンバラグンヤヒコムラ', '走出', 'ハシリデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県西蒲原郡弥彦村弥彦', '15', '15342', '9590323', '新潟県', 'ニイガタケン', '西蒲原郡弥彦村', 'ニシカンバラグンヤヒコムラ', '弥彦', 'ヤヒコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西区與兵衛野新田', '15', '15107', '9590401', '新潟県', 'ニイガタケン', '新潟市西区', 'ニイガタシニシク', '與兵衛野新田', 'ヨヘエノシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区與兵衛野新田', '15', '15108', '9590401', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '與兵衛野新田', 'ヨヘエノシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区三角野新田', '15', '15108', '9590402', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '三角野新田', 'サンカクノシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区貝柄', '15', '15108', '9590403', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '貝柄', 'カイガラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区貝柄新田', '15', '15108', '9590404', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '貝柄新田', 'カイガラシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区堀上新田', '15', '15108', '9590405', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '堀上新田', 'ホリアゲシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区善光寺村受', '15', '15108', '9590406', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '善光寺村受', 'ゼンコウジムラウケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区旗屋村受', '15', '15108', '9590407', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '旗屋村受', 'ハタヤムラウケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区善光寺', '15', '15108', '9590411', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '善光寺', 'ゼンコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区桑山', '15', '15108', '9590412', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '桑山', 'クワヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区升潟', '15', '15108', '9590413', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '升潟', 'マスガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区兵右衛門新田', '15', '15108', '9590414', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '兵右衛門新田', 'ヒョウウエモンシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区大潟', '15', '15108', '9590415', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '大潟', 'オオカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区浦村', '15', '15108', '9590416', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '浦村', 'ウラムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区大関', '15', '15108', '9590417', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '大関', 'オオセキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区升岡', '15', '15108', '9590418', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '升岡', 'マスオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区鱸', '15', '15108', '9590421', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '鱸', 'スズキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区曽根', '15', '15108', '9590422', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '曽根', 'ソネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区旗屋', '15', '15108', '9590423', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '旗屋', 'ハタヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区松崎', '15', '15108', '9590424', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '松崎', 'マツサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区押付', '15', '15108', '9590425', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '押付', 'オシツケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区矢島', '15', '15108', '9590426', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '矢島', 'ヤジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区平野', '15', '15108', '9590431', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '平野', 'ヒラノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区川崎', '15', '15108', '9590432', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '川崎', 'カワサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区槇島', '15', '15108', '9590433', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '槇島', 'マキジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区天竺堂', '15', '15108', '9590434', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '天竺堂', 'テンジクドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区真田', '15', '15108', '9590435', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '真田', 'サナダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区西汰上', '15', '15108', '9590436', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '西汰上', 'ニシヨリアゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区中島', '15', '15108', '9590437', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '中島', 'ナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区下山', '15', '15108', '9590438', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '下山', 'シモヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区井随', '15', '15108', '9590501', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '井随', 'イズイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区熊谷', '15', '15108', '9590502', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '熊谷', 'クマガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区山口新田', '15', '15108', '9590503', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '山口新田', 'ヤマクチシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区横戸', '15', '15108', '9590504', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '横戸', 'ヨコド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区三方', '15', '15108', '9590505', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '三方', 'サンボウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区遠藤', '15', '15108', '9590506', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '遠藤', 'エンドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区卯八郎受', '15', '15108', '9590507', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '卯八郎受', 'ウハチロウウケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区五之上', '15', '15108', '9590508', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '五之上', 'ゴノカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区大原', '15', '15108', '9590511', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '大原', 'オオハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区番屋', '15', '15108', '9590512', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '番屋', 'バンヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区茨島', '15', '15108', '9590513', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '茨島', 'イバラシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区称名', '15', '15108', '9590514', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '称名', 'ショウミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区今井', '15', '15108', '9590515', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '今井', 'イマイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区国見', '15', '15108', '9590516', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '国見', 'クニミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区大曽根', '15', '15108', '9590517', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '大曽根', 'オオゾネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区南', '15', '15108', '9590518', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '南', 'ミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区美里', '15', '15108', '9590519', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '美里', 'ミサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新潟市西蒲区鎧潟', '15', '15108', '9590521', '新潟県', 'ニイガタケン', '新潟市西蒲区', 'ニイガタシニシカンク', '鎧潟', 'ヨロイガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市福島新田甲', '15', '15204', '9591101', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '福島新田甲', 'フクジマシンデンコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市福島新田乙', '15', '15204', '9591102', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '福島新田乙', 'フクジマシンデンオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市福島新田戊', '15', '15204', '9591103', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '福島新田戊', 'フクジマシンデンボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市東光寺', '15', '15204', '9591104', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '東光寺', 'トウコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市若宮新田', '15', '15204', '9591105', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '若宮新田', 'ワカミヤシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市吉野屋', '15', '15204', '9591106', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '吉野屋', 'ヨシノヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市矢田', '15', '15204', '9591107', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '矢田', 'ヤダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市北潟', '15', '15204', '9591108', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '北潟', 'キタガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市蔵内', '15', '15204', '9591109', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '蔵内', 'クラウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市茅原', '15', '15204', '9591111', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '茅原', 'チハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市安代', '15', '15204', '9591112', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '安代', 'ヤスシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市大面', '15', '15204', '9591113', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '大面', 'オオモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市高安寺', '15', '15204', '9591114', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '高安寺', 'コウアンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市小滝', '15', '15204', '9591115', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '小滝', 'コダキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市前谷内', '15', '15204', '9591116', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '前谷内', 'マエヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市帯織', '15', '15204', '9591117', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '帯織', 'オビオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市山王', '15', '15204', '9591118', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '山王', 'サンノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市戸口', '15', '15204', '9591119', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '戸口', 'トグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市善久寺', '15', '15204', '9591121', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '善久寺', 'ゼンキュウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市栄荻島', '15', '15204', '9591122', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '栄荻島', 'サカエオギジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市九之曽根', '15', '15204', '9591123', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '九之曽根', 'クノソネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市千把野新田', '15', '15204', '9591124', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '千把野新田', 'センバノシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市中島', '15', '15204', '9591125', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '中島', 'ナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市小古瀬', '15', '15204', '9591126', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '小古瀬', 'オゴセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市芹山', '15', '15204', '9591131', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '芹山', 'セリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市渡前', '15', '15204', '9591132', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '渡前', 'ワタリマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市中曽根新田', '15', '15204', '9591133', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '中曽根新田', 'ナカゾネシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市鬼木新田', '15', '15204', '9591134', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '鬼木新田', 'オニギシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市鬼木', '15', '15204', '9591135', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '鬼木', 'オニギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市川通中町', '15', '15204', '9591136', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '川通中町', 'カワドオリナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市今井', '15', '15204', '9591141', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '今井', 'イマイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市今井野新田', '15', '15204', '9591142', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '今井野新田', 'イマイノシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市泉新田', '15', '15204', '9591143', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '泉新田', 'イズミシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市貝喰新田', '15', '15204', '9591144', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '貝喰新田', 'カイバミシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市福島新田丙', '15', '15204', '9591145', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '福島新田丙', 'フクジマシンデンヘイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市半ノ木', '15', '15204', '9591146', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '半ノ木', 'ハンノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市岡野新田', '15', '15204', '9591147', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '岡野新田', 'オカノシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市尾崎', '15', '15204', '9591148', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '尾崎', 'オサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市猪子場新田', '15', '15204', '9591151', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '猪子場新田', 'イノコバシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市一ツ屋敷新田', '15', '15204', '9591152', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '一ツ屋敷新田', 'ヒトツヤシキシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市新堀', '15', '15204', '9591153', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '新堀', 'ニイボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市岩淵', '15', '15204', '9591154', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '岩淵', 'イワフチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市福島新田丁', '15', '15204', '9591155', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '福島新田丁', 'フクジマシンデンテイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県三条市福島新田', '15', '15204', '9591156', '新潟県', 'ニイガタケン', '三条市', 'サンジョウシ', '福島新田', 'フクジマシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市', '15', '15213', '9591200', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('134554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市灰方', '15', '15213', '9591201', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '灰方', 'ハイガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市松橋', '15', '15213', '9591202', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '松橋', 'マツハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市舘野', '15', '15213', '9591203', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '舘野', 'タテノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市長所', '15', '15213', '9591204', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '長所', 'チョウショ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市長渡', '15', '15213', '9591205', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '長渡', 'ナガワタリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市関崎', '15', '15213', '9591206', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '関崎', 'セキサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市三王渕', '15', '15213', '9591207', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '三王渕', 'サンノウフチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市小中川', '15', '15213', '9591211', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '小中川', 'コナカガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市大船渡', '15', '15213', '9591212', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '大船渡', 'オオフナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市小古津新', '15', '15213', '9591213', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '小古津新', 'コフルツシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市新生町', '15', '15213', '9591214', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '新生町', 'シンセイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市又新', '15', '15213', '9591215', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '又新', 'マタシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市二階堂', '15', '15213', '9591216', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '二階堂', 'ニカイドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市勘新', '15', '15213', '9591217', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '勘新', 'カンシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市花園町', '15', '15213', '9591221', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '花園町', 'ハナゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市次新', '15', '15213', '9591222', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '次新', 'ツギシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市児ノ木', '15', '15213', '9591223', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '児ノ木', 'チゴノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市四ツ屋', '15', '15213', '9591224', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '四ツ屋', 'ヨツヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市中川', '15', '15213', '9591225', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '中川', 'ナカガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市小牧', '15', '15213', '9591226', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '小牧', 'コマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市栄町', '15', '15213', '9591227', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '栄町', 'サカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市佐渡', '15', '15213', '9591228', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '佐渡', 'サワタリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市東町', '15', '15213', '9591231', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '東町', 'アズマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市井土巻', '15', '15213', '9591232', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '井土巻', 'イドマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市殿島', '15', '15213', '9591233', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '殿島', 'トノシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市南', '15', '15213', '9591234', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '南', 'ミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市小高', '15', '15213', '9591241', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '小高', 'コタカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市日之出町', '15', '15213', '9591242', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '日之出町', 'ヒノデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市朝日町', '15', '15213', '9591243', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '朝日町', 'アサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市中央通', '15', '15213', '9591244', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '中央通', 'チュウオウドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市下太田', '15', '15213', '9591245', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '下太田', 'シモオオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市新栄町', '15', '15213', '9591246', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '新栄町', 'シンエイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市寺郷屋', '15', '15213', '9591247', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '寺郷屋', 'テラゴウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市前郷屋', '15', '15213', '9591248', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '前郷屋', 'マエゴウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市白山町', '15', '15213', '9591251', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '白山町', 'ハクサンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市寿町', '15', '15213', '9591252', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '寿町', 'コトブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市本町', '15', '15213', '9591253', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市幸町', '15', '15213', '9591254', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市新町', '15', '15213', '9591255', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市穀町', '15', '15213', '9591256', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '穀町', 'コクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市宮町', '15', '15213', '9591257', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '宮町', 'ミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市仲町', '15', '15213', '9591258', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '仲町', 'ナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市秋葉町', '15', '15213', '9591261', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '秋葉町', 'アキバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市水道町', '15', '15213', '9591262', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '水道町', 'スイドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市大曲', '15', '15213', '9591263', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '大曲', 'オオマガリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市八王寺', '15', '15213', '9591264', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '八王寺', 'ハチオウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市道金', '15', '15213', '9591265', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '道金', 'ドウキン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市蔵関', '15', '15213', '9591271', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '蔵関', 'クラセキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市杉柳', '15', '15213', '9591272', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '杉柳', 'スギヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市杉名', '15', '15213', '9591273', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '杉名', 'スギナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市柳山', '15', '15213', '9591274', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '柳山', 'ヤナギヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市小池新町', '15', '15213', '9591275', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '小池新町', 'コイケシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市小池', '15', '15213', '9591276', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '小池', 'コイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市物流センター', '15', '15213', '9591277', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '物流センター', 'ブツリュウセンター', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市桜町', '15', '15213', '9591281', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '桜町', 'サクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市西燕町', '15', '15213', '9591282', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '西燕町', 'ニシツバメマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市廿六木', '15', '15213', '9591283', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '廿六木', 'トドロキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市杣木', '15', '15213', '9591284', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '杣木', 'ソマギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市緑町', '15', '15213', '9591285', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '緑町', 'ミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市小関', '15', '15213', '9591286', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '小関', 'コセキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県燕市大関', '15', '15213', '9591287', '新潟県', 'ニイガタケン', '燕市', 'ツバメシ', '大関', 'オオセキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県加茂市', '15', '15209', '9591300', '新潟県', 'ニイガタケン', '加茂市', 'カモシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('134621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県加茂市北潟', '15', '15209', '9591301', '新潟県', 'ニイガタケン', '加茂市', 'カモシ', '北潟', 'キタガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県加茂市五反田', '15', '15209', '9591302', '新潟県', 'ニイガタケン', '加茂市', 'カモシ', '五反田', 'ゴタンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県加茂市後須田', '15', '15209', '9591303', '新潟県', 'ニイガタケン', '加茂市', 'カモシ', '後須田', 'ウラスダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県加茂市前須田', '15', '15209', '9591304', '新潟県', 'ニイガタケン', '加茂市', 'カモシ', '前須田', 'マエスダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県加茂市砂押新田', '15', '15209', '9591305', '新潟県', 'ニイガタケン', '加茂市', 'カモシ', '砂押新田', 'スナオシシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県加茂市鵜森', '15', '15209', '9591306', '新潟県', 'ニイガタケン', '加茂市', 'カモシ', '鵜森', 'ウノモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県加茂市田中新田', '15', '15209', '9591307', '新潟県', 'ニイガタケン', '加茂市', 'カモシ', '田中新田', 'タナカシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県加茂市加茂新田', '15', '15209', '9591311', '新潟県', 'ニイガタケン', '加茂市', 'カモシ', '加茂新田', 'カモシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県加茂市石川', '15', '15209', '9591312', '新潟県', 'ニイガタケン', '加茂市', 'カモシ', '石川', 'イシカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県加茂市幸町', '15', '15209', '9591313', '新潟県', 'ニイガタケン', '加茂市', 'カモシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県加茂市番田', '15', '15209', '9591314', '新潟県', 'ニイガタケン', '加茂市', 'カモシ', '番田', 'バンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県加茂市天神林', '15', '15209', '9591315', '新潟県', 'ニイガタケン', '加茂市', 'カモシ', '天神林', 'テンジンバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県加茂市山島新田', '15', '15209', '9591316', '新潟県', 'ニイガタケン', '加茂市', 'カモシ', '山島新田', 'ヤマジマシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県加茂市希望ケ丘', '15', '15209', '9591321', '新潟県', 'ニイガタケン', '加茂市', 'カモシ', '希望ケ丘', 'キボウガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県加茂市学校町', '15', '15209', '9591322', '新潟県', 'ニイガタケン', '加茂市', 'カモシ', '学校町', 'ガッコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県加茂市都ケ丘', '15', '15209', '9591323', '新潟県', 'ニイガタケン', '加茂市', 'カモシ', '都ケ丘', 'ミヤコガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県加茂市赤谷', '15', '15209', '9591324', '新潟県', 'ニイガタケン', '加茂市', 'カモシ', '赤谷', 'アカタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県加茂市神明町', '15', '15209', '9591325', '新潟県', 'ニイガタケン', '加茂市', 'カモシ', '神明町', 'シンメイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県加茂市青海町', '15', '15209', '9591326', '新潟県', 'ニイガタケン', '加茂市', 'カモシ', '青海町', 'アオミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県加茂市千刈', '15', '15209', '9591327', '新潟県', 'ニイガタケン', '加茂市', 'カモシ', '千刈', 'センガリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県加茂市陣ケ峰', '15', '15209', '9591328', '新潟県', 'ニイガタケン', '加茂市', 'カモシ', '陣ケ峰', 'ジンガミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県加茂市皆川', '15', '15209', '9591331', '新潟県', 'ニイガタケン', '加茂市', 'カモシ', '皆川', 'ミナガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県加茂市上条', '15', '15209', '9591332', '新潟県', 'ニイガタケン', '加茂市', 'カモシ', '上条', 'ジョウジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県加茂市八幡', '15', '15209', '9591333', '新潟県', 'ニイガタケン', '加茂市', 'カモシ', '八幡', 'ヤワタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県加茂市狭口', '15', '15209', '9591334', '新潟県', 'ニイガタケン', '加茂市', 'カモシ', '狭口', 'セバグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県加茂市長谷', '15', '15209', '9591335', '新潟県', 'ニイガタケン', '加茂市', 'カモシ', '長谷', 'ナガタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県加茂市黒水', '15', '15209', '9591336', '新潟県', 'ニイガタケン', '加茂市', 'カモシ', '黒水', 'クロミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県加茂市西山', '15', '15209', '9591337', '新潟県', 'ニイガタケン', '加茂市', 'カモシ', '西山', 'ニシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県加茂市下土倉', '15', '15209', '9591341', '新潟県', 'ニイガタケン', '加茂市', 'カモシ', '下土倉', 'シモツチクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県加茂市上土倉', '15', '15209', '9591342', '新潟県', 'ニイガタケン', '加茂市', 'カモシ', '上土倉', 'カミツチクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県加茂市上大谷', '15', '15209', '9591343', '新潟県', 'ニイガタケン', '加茂市', 'カモシ', '上大谷', 'カミオオタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県加茂市下大谷', '15', '15209', '9591344', '新潟県', 'ニイガタケン', '加茂市', 'カモシ', '下大谷', 'シモオオタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県加茂市中大谷', '15', '15209', '9591345', '新潟県', 'ニイガタケン', '加茂市', 'カモシ', '中大谷', 'ナカオオタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県加茂市下高柳', '15', '15209', '9591346', '新潟県', 'ニイガタケン', '加茂市', 'カモシ', '下高柳', 'シモタカヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県加茂市上高柳', '15', '15209', '9591347', '新潟県', 'ニイガタケン', '加茂市', 'カモシ', '上高柳', 'カミタカヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県加茂市宮寄上', '15', '15209', '9591348', '新潟県', 'ニイガタケン', '加茂市', 'カモシ', '宮寄上', 'ミヤヨリカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県加茂市仲町', '15', '15209', '9591351', '新潟県', 'ニイガタケン', '加茂市', 'カモシ', '仲町', 'ナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県加茂市上町', '15', '15209', '9591352', '新潟県', 'ニイガタケン', '加茂市', 'カモシ', '上町', 'カミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県加茂市五番町', '15', '15209', '9591353', '新潟県', 'ニイガタケン', '加茂市', 'カモシ', '五番町', 'ゴバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県加茂市新町', '15', '15209', '9591354', '新潟県', 'ニイガタケン', '加茂市', 'カモシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県加茂市若宮町', '15', '15209', '9591355', '新潟県', 'ニイガタケン', '加茂市', 'カモシ', '若宮町', 'ワカミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県加茂市秋房', '15', '15209', '9591356', '新潟県', 'ニイガタケン', '加茂市', 'カモシ', '秋房', 'アキフサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県加茂市桜沢', '15', '15209', '9591357', '新潟県', 'ニイガタケン', '加茂市', 'カモシ', '桜沢', 'サクラザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県加茂市下条', '15', '15209', '9591361', '新潟県', 'ニイガタケン', '加茂市', 'カモシ', '下条', 'ゲジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県加茂市横江', '15', '15209', '9591362', '新潟県', 'ニイガタケン', '加茂市', 'カモシ', '横江', 'ヨコエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県加茂市芝野', '15', '15209', '9591363', '新潟県', 'ニイガタケン', '加茂市', 'カモシ', '芝野', 'シバノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県加茂市穀町', '15', '15209', '9591371', '新潟県', 'ニイガタケン', '加茂市', 'カモシ', '穀町', 'コクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県加茂市本町', '15', '15209', '9591372', '新潟県', 'ニイガタケン', '加茂市', 'カモシ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県加茂市松坂町', '15', '15209', '9591373', '新潟県', 'ニイガタケン', '加茂市', 'カモシ', '松坂町', 'マツサカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県加茂市矢立', '15', '15209', '9591374', '新潟県', 'ニイガタケン', '加茂市', 'カモシ', '矢立', 'ヤタテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県加茂市小橋', '15', '15209', '9591375', '新潟県', 'ニイガタケン', '加茂市', 'カモシ', '小橋', 'コバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県加茂市中村', '15', '15209', '9591376', '新潟県', 'ニイガタケン', '加茂市', 'カモシ', '中村', 'ナカムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県加茂市岡ノ町', '15', '15209', '9591377', '新潟県', 'ニイガタケン', '加茂市', 'カモシ', '岡ノ町', 'オカノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県加茂市駅前', '15', '15209', '9591378', '新潟県', 'ニイガタケン', '加茂市', 'カモシ', '駅前', 'エキマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県加茂市新栄町', '15', '15209', '9591381', '新潟県', 'ニイガタケン', '加茂市', 'カモシ', '新栄町', 'シンエイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県加茂市栄町', '15', '15209', '9591382', '新潟県', 'ニイガタケン', '加茂市', 'カモシ', '栄町', 'サカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県加茂市旭町', '15', '15209', '9591383', '新潟県', 'ニイガタケン', '加茂市', 'カモシ', '旭町', 'アサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県加茂市寿町', '15', '15209', '9591384', '新潟県', 'ニイガタケン', '加茂市', 'カモシ', '寿町', 'コトブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県加茂市大郷町', '15', '15209', '9591385', '新潟県', 'ニイガタケン', '加茂市', 'カモシ', '大郷町', 'ダイゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県加茂市柳町', '15', '15209', '9591386', '新潟県', 'ニイガタケン', '加茂市', 'カモシ', '柳町', 'ヤナギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県加茂市高須町', '15', '15209', '9591387', '新潟県', 'ニイガタケン', '加茂市', 'カモシ', '高須町', 'タカスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南蒲原郡田上町', '15', '15361', '9591500', '新潟県', 'ニイガタケン', '南蒲原郡田上町', 'ミナミカンバラグンタガミマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('134687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南蒲原郡田上町湯川', '15', '15361', '9591501', '新潟県', 'ニイガタケン', '南蒲原郡田上町', 'ミナミカンバラグンタガミマチ', '湯川', 'ユガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南蒲原郡田上町田上', '15', '15361', '9591502', '新潟県', 'ニイガタケン', '南蒲原郡田上町', 'ミナミカンバラグンタガミマチ', '田上', 'タガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南蒲原郡田上町原ケ崎新田', '15', '15361', '9591503', '新潟県', 'ニイガタケン', '南蒲原郡田上町', 'ミナミカンバラグンタガミマチ', '原ケ崎新田', 'ハラガサキシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南蒲原郡田上町吉田新田', '15', '15361', '9591511', '新潟県', 'ニイガタケン', '南蒲原郡田上町', 'ミナミカンバラグンタガミマチ', '吉田新田', 'ヨシダシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南蒲原郡田上町羽生田', '15', '15361', '9591512', '新潟県', 'ニイガタケン', '南蒲原郡田上町', 'ミナミカンバラグンタガミマチ', '羽生田', 'ハニュウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南蒲原郡田上町川船河', '15', '15361', '9591513', '新潟県', 'ニイガタケン', '南蒲原郡田上町', 'ミナミカンバラグンタガミマチ', '川船河', 'カワフネガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南蒲原郡田上町坂田', '15', '15361', '9591514', '新潟県', 'ニイガタケン', '南蒲原郡田上町', 'ミナミカンバラグンタガミマチ', '坂田', 'サカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南蒲原郡田上町石田新田', '15', '15361', '9591521', '新潟県', 'ニイガタケン', '南蒲原郡田上町', 'ミナミカンバラグンタガミマチ', '石田新田', 'イシダシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南蒲原郡田上町千苅新田', '15', '15361', '9591522', '新潟県', 'ニイガタケン', '南蒲原郡田上町', 'ミナミカンバラグンタガミマチ', '千苅新田', 'センガリシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南蒲原郡田上町保明新田', '15', '15361', '9591523', '新潟県', 'ニイガタケン', '南蒲原郡田上町', 'ミナミカンバラグンタガミマチ', '保明新田', 'ホミョウシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南蒲原郡田上町横場新田', '15', '15361', '9591524', '新潟県', 'ニイガタケン', '南蒲原郡田上町', 'ミナミカンバラグンタガミマチ', '横場新田', 'ヨコバシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県南蒲原郡田上町曽根新田', '15', '15361', '9591525', '新潟県', 'ニイガタケン', '南蒲原郡田上町', 'ミナミカンバラグンタガミマチ', '曽根新田', 'ソネシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市', '15', '15218', '9591600', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('134700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市一本杉', '15', '15218', '9591601', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '一本杉', 'イッポンスギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市高山', '15', '15218', '9591602', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '高山', 'タカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市荻野島', '15', '15218', '9591603', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '荻野島', 'オギノシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市論瀬', '15', '15218', '9591604', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '論瀬', 'ロンゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市笹堀', '15', '15218', '9591611', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '笹堀', 'ササボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市小搦', '15', '15218', '9591612', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '小搦', 'コガラミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市小流', '15', '15218', '9591613', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '小流', 'コナガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市馬下', '15', '15218', '9591614', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '馬下', 'マオロシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市佐取', '15', '15218', '9591615', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '佐取', 'サドリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市尾白', '15', '15218', '9591621', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '尾白', 'オジロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市小栗山', '15', '15218', '9591622', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '小栗山', 'コグリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市大谷', '15', '15218', '9591623', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '大谷', 'オオタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市小山田', '15', '15218', '9591624', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '小山田', 'オヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市切畑', '15', '15218', '9591625', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '切畑', 'キリハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市猿和田', '15', '15218', '9591631', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '猿和田', 'サルワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市中川新', '15', '15218', '9591632', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '中川新', 'ナカガワシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市大須郷', '15', '15218', '9591633', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '大須郷', 'オオスゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市不動堂', '15', '15218', '9591634', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '不動堂', 'フドウドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市柄沢', '15', '15218', '9591635', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '柄沢', 'カラサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市大蔵', '15', '15218', '9591636', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '大蔵', 'オオクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市菅出', '15', '15218', '9591637', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '菅出', 'スガイデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市赤羽', '15', '15218', '9591641', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '赤羽', 'アカハネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市四ツ屋新', '15', '15218', '9591642', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '四ツ屋新', 'ヨツヤシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市土堀', '15', '15218', '9591643', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '土堀', 'ツチボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市東四ツ屋', '15', '15218', '9591644', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '東四ツ屋', 'ヒガシヨツヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市石曽根', '15', '15218', '9591701', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '石曽根', 'イシゾネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市矢津', '15', '15218', '9591703', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '矢津', 'ヤヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市村松甲', '15', '15218', '9591704', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '村松甲', 'ムラマツコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市村松乙', '15', '15218', '9591705', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '村松乙', 'ムラマツオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市村松丙', '15', '15218', '9591706', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '村松丙', 'ムラマツヘイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市村松', '15', '15218', '9591707', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '村松', 'ムラマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市上木越', '15', '15218', '9591708', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '上木越', 'カミキゴシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市木越荒屋', '15', '15218', '9591709', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '木越荒屋', 'キゴシアラヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市川内', '15', '15218', '9591711', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '川内', 'カワチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市土淵', '15', '15218', '9591712', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '土淵', 'ドフチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市水戸野', '15', '15218', '9591713', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '水戸野', 'ミトノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市仙見谷', '15', '15218', '9591714', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '仙見谷', 'センミダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市夏針', '15', '15218', '9591715', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '夏針', 'ナツハリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市熊沢', '15', '15218', '9591716', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '熊沢', 'クマサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市阿弥陀瀬', '15', '15218', '9591717', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '阿弥陀瀬', 'アミダセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市下阿弥陀瀬', '15', '15218', '9591718', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '下阿弥陀瀬', 'シモアミダセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市暮坪', '15', '15218', '9591721', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '暮坪', 'クレツボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市松野', '15', '15218', '9591722', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '松野', 'マツノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市横渡', '15', '15218', '9591723', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '横渡', 'ヨコワタシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市笹目', '15', '15218', '9591724', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '笹目', 'ササメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市小面谷', '15', '15218', '9591725', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '小面谷', 'コツラダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市上杉川', '15', '15218', '9591726', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '上杉川', 'カミスギカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市下杉川', '15', '15218', '9591727', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '下杉川', 'シモスギカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市大口', '15', '15218', '9591731', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '大口', 'オオクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市中島', '15', '15218', '9591732', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '中島', 'ナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市安出', '15', '15218', '9591733', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '安出', 'ヤスイデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市大原', '15', '15218', '9591734', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '大原', 'オオハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市蛭野', '15', '15218', '9591735', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '蛭野', 'ヒルノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市山谷', '15', '15218', '9591736', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '山谷', 'ヤマヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市新屋', '15', '15218', '9591737', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '新屋', 'アラヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市別所', '15', '15218', '9591738', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '別所', 'ベッショ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市村松工業団地', '15', '15218', '9591739', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '村松工業団地', 'ムラマツコウギョウダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市南田中', '15', '15218', '9591741', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '南田中', 'ミナミタナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市寺田', '15', '15218', '9591742', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '寺田', 'テラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市下大蒲原', '15', '15218', '9591743', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '下大蒲原', 'シモオオカンバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市上大蒲原', '15', '15218', '9591744', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '上大蒲原', 'カミオオカンバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市下戸倉', '15', '15218', '9591745', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '下戸倉', 'シモトグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市上戸倉', '15', '15218', '9591746', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '上戸倉', 'カミトグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市高松', '15', '15218', '9591747', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '高松', 'タカマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市牧', '15', '15218', '9591748', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '牧', 'マキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市上野', '15', '15218', '9591749', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '上野', 'ウエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市中名沢', '15', '15218', '9591751', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '中名沢', 'チュウナザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市千原', '15', '15218', '9591752', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '千原', 'チワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市笹野町', '15', '15218', '9591753', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '笹野町', 'ササノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市中野橋', '15', '15218', '9591754', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '中野橋', 'ナカノハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市青橋', '15', '15218', '9591755', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '青橋', 'アオハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市刈羽', '15', '15218', '9591756', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '刈羽', 'カリワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市長橋', '15', '15218', '9591757', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '長橋', 'ナガハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市城下', '15', '15218', '9591758', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '城下', 'シロシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市美郷', '15', '15218', '9591759', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '美郷', 'ミサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市本田屋', '15', '15218', '9591761', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '本田屋', 'モトダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市東石曽根', '15', '15218', '9591762', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '東石曽根', 'ヒガシイシゾネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市熊野堂', '15', '15218', '9591763', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '熊野堂', 'クマノドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市宮野下', '15', '15218', '9591764', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '宮野下', 'ミヤノシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市愛宕', '15', '15218', '9591765', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '愛宕', 'アタゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市番坂', '15', '15218', '9591766', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '番坂', 'バンザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市新田町', '15', '15218', '9591767', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '新田町', 'シンデンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市羽下', '15', '15218', '9591801', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '羽下', 'ハガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市下新', '15', '15218', '9591802', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '下新', 'シモシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市下条', '15', '15218', '9591803', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '下条', 'シモジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市田屋', '15', '15218', '9591804', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '田屋', 'タヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市船越', '15', '15218', '9591805', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '船越', 'フナコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市猿橋', '15', '15218', '9591806', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '猿橋', 'サルハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市次屋', '15', '15218', '9591807', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '次屋', 'ツギヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市三本木', '15', '15218', '9591811', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '三本木', 'サンボンギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市水島町', '15', '15218', '9591812', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '水島町', 'ミズシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市伊勢の川', '15', '15218', '9591813', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '伊勢の川', 'イセノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市北五泉駅前', '15', '15218', '9591814', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '北五泉駅前', 'キタゴセンエキマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市赤海', '15', '15218', '9591821', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '赤海', 'アコウミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市緑町', '15', '15218', '9591822', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '緑町', 'ミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市駅前', '15', '15218', '9591823', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '駅前', 'エキマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市吉沢', '15', '15218', '9591824', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '吉沢', 'ヨシザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市太田', '15', '15218', '9591825', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '太田', 'オオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市曙町', '15', '15218', '9591831', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '曙町', 'アケボノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市川瀬', '15', '15218', '9591832', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '川瀬', 'カワゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市五十嵐新田', '15', '15218', '9591833', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '五十嵐新田', 'イガラシシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市木越', '15', '15218', '9591834', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '木越', 'キゴシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市今泉', '15', '15218', '9591835', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '今泉', 'イマイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市南本町', '15', '15218', '9591836', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '南本町', 'ミナミホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市寺沢', '15', '15218', '9591837', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '寺沢', 'テラザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市二ツ柳', '15', '15218', '9591841', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '二ツ柳', 'フタツヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市能代', '15', '15218', '9591842', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '能代', 'ノウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市町屋', '15', '15218', '9591843', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '町屋', 'マチヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市西四ツ屋', '15', '15218', '9591844', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '西四ツ屋', 'ニシヨツヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市大沢', '15', '15218', '9591845', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '大沢', 'オオサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市尻上', '15', '15218', '9591846', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '尻上', 'シリアガリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市菅沢', '15', '15218', '9591847', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '菅沢', 'スゲサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市橋田', '15', '15218', '9591848', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '橋田', 'ハシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市五泉', '15', '15218', '9591851', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '五泉', 'ゴセン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市荻曽根', '15', '15218', '9591852', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '荻曽根', 'オギソネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市土深', '15', '15218', '9591853', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '土深', 'ドブケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市丸田', '15', '15218', '9591854', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '丸田', 'マルタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市小熊', '15', '15218', '9591855', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '小熊', 'オグマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市山崎', '15', '15218', '9591856', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '山崎', 'ヤマザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市石倉', '15', '15218', '9591857', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '石倉', 'イシクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市粟島', '15', '15218', '9591861', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '粟島', 'アワシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市旭町', '15', '15218', '9591862', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '旭町', 'アサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市東本町', '15', '15218', '9591863', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '東本町', 'ヒガシホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市郷屋川', '15', '15218', '9591864', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '郷屋川', 'コウヤガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市本町', '15', '15218', '9591865', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市学校町', '15', '15218', '9591866', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '学校町', 'ガッコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市大川前', '15', '15218', '9591867', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '大川前', 'オオカワマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市白山', '15', '15218', '9591871', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '白山', 'ハクサン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市宮町', '15', '15218', '9591872', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '宮町', 'ミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市錦町', '15', '15218', '9591873', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '錦町', 'ニシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市横町', '15', '15218', '9591874', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '横町', 'ヨコマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市馬場町', '15', '15218', '9591875', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '馬場町', 'ババチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県五泉市泉町', '15', '15218', '9591876', '新潟県', 'ニイガタケン', '五泉市', 'ゴセンシ', '泉町', 'イズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市中ノ通', '15', '15223', '9591901', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '中ノ通', 'ナカノトオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市飯山新', '15', '15223', '9591902', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '飯山新', 'イイヤマシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市藤屋', '15', '15223', '9591903', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '藤屋', 'フジヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市上西野', '15', '15223', '9591904', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '上西野', 'カミニシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市滝沢', '15', '15223', '9591905', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '滝沢', 'タキサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市村岡', '15', '15223', '9591906', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '村岡', 'ムラオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市熊堂', '15', '15223', '9591907', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '熊堂', 'クマドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市上蔵野', '15', '15223', '9591908', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '上蔵野', 'カミクラノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市上高関', '15', '15223', '9591909', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '上高関', 'カミタカセキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市向中ノ通', '15', '15223', '9591910', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '向中ノ通', 'ムカイナカノトオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市長起', '15', '15223', '9591911', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '長起', 'ナガオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市下一分', '15', '15223', '9591912', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '下一分', 'シモイチブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市沢口', '15', '15223', '9591913', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '沢口', 'サワグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市女堂', '15', '15223', '9591914', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '女堂', 'オンナドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市上一分', '15', '15223', '9591915', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '上一分', 'カミイチブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市小栗山', '15', '15223', '9591916', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '小栗山', 'コグリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市堤', '15', '15223', '9591917', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '堤', 'ツツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市笹岡', '15', '15223', '9591918', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '笹岡', 'ササオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市山崎', '15', '15223', '9591919', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '山崎', 'ヤマザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市折居', '15', '15223', '9591921', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '折居', 'オリイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市上西山', '15', '15223', '9591921', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '上西山', 'カミニシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市湯沢', '15', '15223', '9591922', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '湯沢', 'ユサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市勝屋', '15', '15223', '9591923', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '勝屋', 'カツヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市畑江', '15', '15223', '9591924', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '畑江', 'ハタエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市真光寺ヴィレッジ', '15', '15223', '9591925', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '真光寺ヴィレッジ', 'シンコウジヴィレッジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市出湯', '15', '15223', '9591926', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '出湯', 'デユ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市今板', '15', '15223', '9591927', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '今板', 'イマイタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市村杉', '15', '15223', '9591928', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '村杉', 'ムラスギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市大日', '15', '15223', '9591929', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '大日', 'ダイニチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市大宮', '15', '15223', '9591930', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '大宮', 'オオミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市山寺', '15', '15223', '9591931', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '山寺', 'ヤマデラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市上山田', '15', '15223', '9591932', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '上山田', 'カミヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市上小中山', '15', '15223', '9591933', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '上小中山', 'カミコナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市七浦', '15', '15223', '9591934', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '七浦', 'ナナウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市大室', '15', '15223', '9591935', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '大室', 'オオムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市十二神', '15', '15223', '9591936', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '十二神', 'ジュウニシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市福井', '15', '15223', '9591937', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '福井', 'フクイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市貝喰', '15', '15223', '9591938', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '貝喰', 'カイバミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市羽黒', '15', '15223', '9591941', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '羽黒', 'ハグロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市上坂町', '15', '15223', '9591942', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '上坂町', 'カミサカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市次郎丸', '15', '15223', '9591943', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '次郎丸', 'ジロウマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市金屋', '15', '15223', '9591944', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '金屋', 'カナヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市上山屋', '15', '15223', '9591945', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '上山屋', 'カミヤマヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市押切', '15', '15223', '9591946', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '押切', 'オシキリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市宮下', '15', '15223', '9591947', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '宮下', 'ミヤノシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市宮島', '15', '15223', '9591948', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '宮島', 'ミヤジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市川崎', '15', '15223', '9591949', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '川崎', 'カワサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市下福岡', '15', '15223', '9591951', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '下福岡', 'シモフクオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市下山屋', '15', '15223', '9591952', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '下山屋', 'シモヤマヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市発久', '15', '15223', '9591953', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '発久', 'ホッキュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市蒔田', '15', '15223', '9591954', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '蒔田', 'マイタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市赤水', '15', '15223', '9591955', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '赤水', 'アカミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市須走', '15', '15223', '9591956', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '須走', 'スバシリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市横山', '15', '15223', '9591957', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '横山', 'ヨコヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市野村', '15', '15223', '9591958', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '野村', 'ノムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市泉', '15', '15223', '9591959', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '泉', 'イズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市山倉', '15', '15223', '9591961', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '山倉', 'ヤマクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市上関口', '15', '15223', '9591962', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '上関口', 'カミセキグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市南沖山', '15', '15223', '9591963', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '南沖山', 'ミナミオキヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市沖', '15', '15223', '9591964', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '沖', 'オキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市島田', '15', '15223', '9591965', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '島田', 'シマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市塚田', '15', '15223', '9591966', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '塚田', 'ツカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市本明', '15', '15223', '9591967', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '本明', 'ホンミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市榎船渡', '15', '15223', '9591968', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '榎船渡', 'エノキフナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市高田', '15', '15223', '9591971', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '高田', 'タカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市山倉新田', '15', '15223', '9591972', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '山倉新田', 'ヤマクラシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市上高田', '15', '15223', '9591973', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '上高田', 'カミタカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市榎', '15', '15223', '9591974', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '榎', 'エノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市荻島', '15', '15223', '9591975', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '荻島', 'オギシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市上飯塚', '15', '15223', '9591975', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '上飯塚', 'カミイイヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市船居', '15', '15223', '9591976', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '船居', 'フナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市沖ノ館', '15', '15223', '9591977', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '沖ノ館', 'オキノタテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市', '15', '15223', '9592000', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('134912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市沖通', '15', '15223', '9592001', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '沖通', 'オキドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市下条', '15', '15223', '9592002', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '下条', 'ゲジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市安野町', '15', '15223', '9592003', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '安野町', 'アンノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市南安野町', '15', '15223', '9592004', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '南安野町', 'ミナミアンノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市山口町', '15', '15223', '9592005', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '山口町', 'ヤマグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市みそら野町', '15', '15223', '9592006', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', 'みそら野町', 'ミソラノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市山口', '15', '15223', '9592007', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '山口', 'ヤマグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市千原', '15', '15223', '9592011', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '千原', 'チワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市天神堂', '15', '15223', '9592012', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '天神堂', 'テンジンドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市水原', '15', '15223', '9592013', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '水原', 'スイバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市北園町', '15', '15223', '9592014', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '北園町', 'キタゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市北本町', '15', '15223', '9592015', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '北本町', 'キタホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市中央町', '15', '15223', '9592021', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '中央町', 'チュウオウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市外城町', '15', '15223', '9592022', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '外城町', 'トジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市日の出町', '15', '15223', '9592023', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '日の出町', 'ヒノデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市中島', '15', '15223', '9592024', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '中島', 'ナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市中島町', '15', '15223', '9592024', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '中島町', 'ナカジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市岡山町', '15', '15223', '9592025', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '岡山町', 'オカヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市下条町', '15', '15223', '9592026', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '下条町', 'ゲジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市金田町', '15', '15223', '9592031', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '金田町', 'カネダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市学校町', '15', '15223', '9592032', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '学校町', 'ガッコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市百津町', '15', '15223', '9592033', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '百津町', 'モモヅチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市緑町', '15', '15223', '9592034', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '緑町', 'ミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市稲荷町', '15', '15223', '9592035', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '稲荷町', 'イナリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市若葉町', '15', '15223', '9592036', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '若葉町', 'ワカバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市百津', '15', '15223', '9592037', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '百津', 'モモヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市原', '15', '15223', '9592041', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '原', 'ハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市境新田', '15', '15223', '9592042', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '境新田', 'サカイシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市大野地', '15', '15223', '9592043', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '大野地', 'オオヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市金沢', '15', '15223', '9592044', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '金沢', 'カナザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市里', '15', '15223', '9592045', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '里', 'サト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市庄ケ宮', '15', '15223', '9592046', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '庄ケ宮', 'ショウガミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市上中', '15', '15223', '9592047', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '上中', 'カミナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市上中野目', '15', '15223', '9592048', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '上中野目', 'カミナカノメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市深町', '15', '15223', '9592049', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '深町', 'フカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市七石', '15', '15223', '9592051', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '七石', 'シチコク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市田中', '15', '15223', '9592052', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '田中', 'タナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市境新', '15', '15223', '9592053', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '境新', 'サカイシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市越御堂', '15', '15223', '9592054', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '越御堂', 'コシミドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市堀越', '15', '15223', '9592055', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '堀越', 'ホリコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市牧島', '15', '15223', '9592056', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '牧島', 'マキシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市野地城', '15', '15223', '9592057', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '野地城', 'ヤチジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市荒屋', '15', '15223', '9592061', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '荒屋', 'アラヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市市野山', '15', '15223', '9592062', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '市野山', 'イチノヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市土橋', '15', '15223', '9592063', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '土橋', 'ドバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市福田', '15', '15223', '9592064', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '福田', 'フクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市小境', '15', '15223', '9592065', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '小境', 'コザカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市中潟', '15', '15223', '9592066', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '中潟', 'ナカガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市水ケ曽根', '15', '15223', '9592071', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '水ケ曽根', 'ミズガソネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市西岡', '15', '15223', '9592072', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '西岡', 'ニシオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市上福岡', '15', '15223', '9592073', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '上福岡', 'カミフクオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市分田', '15', '15223', '9592074', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '分田', 'ブンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市東町', '15', '15223', '9592075', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '東町', 'ヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市上江端', '15', '15223', '9592081', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '上江端', 'カミエバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市切梅新田', '15', '15223', '9592082', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '切梅新田', 'キリウメシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市熊居新田', '15', '15223', '9592083', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '熊居新田', 'クマイシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市山本新', '15', '15223', '9592085', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '山本新', 'ヤマモトシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市新座', '15', '15223', '9592086', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '新座', 'シンザ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市駒林', '15', '15223', '9592101', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '駒林', 'コマバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市五郎巻', '15', '15223', '9592102', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '五郎巻', 'ゴロウマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市金渕甲', '15', '15223', '9592103', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '金渕甲', 'カネブチコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市法柳新田', '15', '15223', '9592104', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '法柳新田', 'ホウヤギシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市金渕乙', '15', '15223', '9592105', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '金渕乙', 'カネブチオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市法柳', '15', '15223', '9592106', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '法柳', 'ホウヤギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市深堀', '15', '15223', '9592107', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '深堀', 'フカホリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市猫山', '15', '15223', '9592111', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '猫山', 'ネコヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市曽郷', '15', '15223', '9592112', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '曽郷', 'ソウゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市緑岡', '15', '15223', '9592113', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '緑岡', 'ミドリオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市城', '15', '15223', '9592114', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '城', 'ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市田山', '15', '15223', '9592115', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '田山', 'タヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市上黒瀬', '15', '15223', '9592116', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '上黒瀬', 'カミクロセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市下黒瀬', '15', '15223', '9592117', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '下黒瀬', 'シモクロセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市小里', '15', '15223', '9592121', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '小里', 'オサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市飯森杉', '15', '15223', '9592122', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '飯森杉', 'イイモリスギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市姥ケ橋', '15', '15223', '9592123', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '姥ケ橋', 'ウバガハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市下ノ橋', '15', '15223', '9592124', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '下ノ橋', 'シモノハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市京ケ島', '15', '15223', '9592125', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '京ケ島', 'キョウガシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市窪川原', '15', '15223', '9592126', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '窪川原', 'クボガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市六日野', '15', '15223', '9592130', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '六日野', 'ムイカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市月崎', '15', '15223', '9592131', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '月崎', 'ツキザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市前山', '15', '15223', '9592132', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '前山', 'マエヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市関屋', '15', '15223', '9592133', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '関屋', 'セキヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市小河原', '15', '15223', '9592134', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '小河原', 'コガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市下里', '15', '15223', '9592135', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '下里', 'サガリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市京ケ瀬工業団地', '15', '15223', '9592136', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '京ケ瀬工業団地', 'キョウガセコウギョウダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('134999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市七島', '15', '15223', '9592141', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '七島', 'ナナシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市箸木免', '15', '15223', '9592142', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '箸木免', 'ハシキメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市川前', '15', '15223', '9592143', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '川前', 'カワマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市清野', '15', '15223', '9592144', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '清野', 'セイノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市寺社新', '15', '15223', '9592145', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '寺社新', 'ジシャシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市小島', '15', '15223', '9592146', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '小島', 'コジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市粕島', '15', '15223', '9592147', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '粕島', 'カスジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市嘉瀬島', '15', '15223', '9592148', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '嘉瀬島', 'カセジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市羽多屋', '15', '15223', '9592201', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '羽多屋', 'ハタヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市籠田', '15', '15223', '9592202', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '籠田', 'カゴタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市丸山', '15', '15223', '9592203', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '丸山', 'マルヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市福永', '15', '15223', '9592204', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '福永', 'フクナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市寺社', '15', '15223', '9592205', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '寺社', 'ジシャ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市かがやき', '15', '15223', '9592206', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', 'かがやき', 'カガヤキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市沢田', '15', '15223', '9592211', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '沢田', 'サワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市久保', '15', '15223', '9592212', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '久保', 'クボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市小松', '15', '15223', '9592213', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '小松', 'コマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市草水', '15', '15223', '9592214', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '草水', 'クソウズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市六野瀬', '15', '15223', '9592215', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '六野瀬', 'ロクノセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市渡場', '15', '15223', '9592216', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '渡場', 'ワタリバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市新保', '15', '15223', '9592217', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '新保', 'シンボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市保田', '15', '15223', '9592221', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '保田', 'ヤスダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市小浮', '15', '15223', '9592222', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '小浮', 'コウケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市布目', '15', '15223', '9592223', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '布目', 'ヌノメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市千唐仁', '15', '15223', '9592224', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '千唐仁', 'セントウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市嶋瀬', '15', '15223', '9592225', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '嶋瀬', 'シマゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県阿賀野市野田', '15', '15223', '9592226', '新潟県', 'ニイガタケン', '阿賀野市', 'アガノシ', '野田', 'ノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市竹ケ花', '15', '15206', '9592301', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '竹ケ花', 'タケガハナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市二ツ堂', '15', '15206', '9592302', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '二ツ堂', 'フタツドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市切梅', '15', '15206', '9592303', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '切梅', 'キリウメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市大伝', '15', '15206', '9592304', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '大伝', 'ダイデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市戸板沢', '15', '15206', '9592305', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '戸板沢', 'トイタザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市荒町', '15', '15206', '9592311', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '荒町', 'アラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市太斎', '15', '15206', '9592312', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '太斎', 'ダサイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市藤掛', '15', '15206', '9592313', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '藤掛', 'フジカケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市赤橋', '15', '15206', '9592314', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '赤橋', 'アカイバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市小坂', '15', '15206', '9592315', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '小坂', 'コサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市池ノ端', '15', '15206', '9592321', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '池ノ端', 'イケノハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市下中ノ目', '15', '15206', '9592322', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '下中ノ目', 'シモナカノメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市乙次', '15', '15206', '9592323', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '乙次', 'オトジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市吉浦', '15', '15206', '9592324', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '吉浦', 'ヨシウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市天王', '15', '15206', '9592325', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '天王', 'テンノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市三ツ椡', '15', '15206', '9592326', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '三ツ椡', 'ミツクヌギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市福島', '15', '15206', '9592327', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '福島', 'フクジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市乗廻', '15', '15206', '9592328', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '乗廻', 'ノリマワシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市中ノ目新田', '15', '15206', '9592329', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '中ノ目新田', 'ナカノメシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市下飯塚', '15', '15206', '9592331', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '下飯塚', 'シモイイヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市万代', '15', '15206', '9592332', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '万代', 'バンダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市岡屋敷', '15', '15206', '9592333', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '岡屋敷', 'オカヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市月岡', '15', '15206', '9592334', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '月岡', 'ツキオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市本田', '15', '15206', '9592335', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '本田', 'ホンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市加治万代', '15', '15206', '9592336', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '加治万代', 'カジバンダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市竹俣万代', '15', '15206', '9592337', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '竹俣万代', 'タケマタバンダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市月岡温泉', '15', '15206', '9592338', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '月岡温泉', 'ツキオカオンセン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市滝沢', '15', '15206', '9592381', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '滝沢', 'タキザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市湖南', '15', '15206', '9592401', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '湖南', 'コナン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市小島', '15', '15206', '9592402', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '小島', 'オジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市塚田', '15', '15206', '9592403', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '塚田', 'ツカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市下城', '15', '15206', '9592404', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '下城', 'シモジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市野中', '15', '15206', '9592405', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '野中', 'ノナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市稲荷', '15', '15206', '9592406', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '稲荷', 'イナリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市川口', '15', '15206', '9592407', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '川口', 'カワグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市吉田', '15', '15206', '9592408', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '吉田', 'ヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市古楯', '15', '15206', '9592409', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '古楯', 'フルタテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市横岡', '15', '15206', '9592411', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '横岡', 'ヨコオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市平山', '15', '15206', '9592412', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '平山', 'ヒラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市箱岩', '15', '15206', '9592413', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '箱岩', 'ハコイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市下山田', '15', '15206', '9592414', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '下山田', 'シモヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市住田', '15', '15206', '9592415', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '住田', 'スミダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市西浦', '15', '15206', '9592416', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '西浦', 'ニシウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市下西山', '15', '15206', '9592417', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '下西山', 'シモニシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市上今泉', '15', '15206', '9592421', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '上今泉', 'カミイマイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市関妻', '15', '15206', '9592422', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '関妻', 'セキヅマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市高田', '15', '15206', '9592425', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '高田', 'タカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市向中条', '15', '15206', '9592426', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '向中条', 'ムカイナカジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市釜杭', '15', '15206', '9592431', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '釜杭', 'カマグイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市二本木', '15', '15206', '9592432', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '二本木', 'ニホンギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市古川', '15', '15206', '9592433', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '古川', 'フルカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市押廻', '15', '15206', '9592434', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '押廻', 'オシマワシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市川尻', '15', '15206', '9592435', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '川尻', 'カワシリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市草荷', '15', '15206', '9592436', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '草荷', 'ソウカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市高山寺', '15', '15206', '9592437', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '高山寺', 'コウサンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市金津', '15', '15206', '9592441', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '金津', 'カナヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市茗荷谷', '15', '15206', '9592442', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '茗荷谷', 'ミョウガタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市新屋敷', '15', '15206', '9592443', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '新屋敷', 'アラヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市新保小路', '15', '15206', '9592444', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '新保小路', 'シンホコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市館野小路', '15', '15206', '9592445', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '館野小路', 'タテノコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市下中', '15', '15206', '9592451', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '下中', 'シモナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市上館', '15', '15206', '9592452', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '上館', 'カミタテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市三日市', '15', '15206', '9592453', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '三日市', 'ミッカイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市早道場', '15', '15206', '9592454', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '早道場', 'ハヤミチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市上小松', '15', '15206', '9592455', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '上小松', 'カミコマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市下小松', '15', '15206', '9592456', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '下小松', 'シモコマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市下今泉', '15', '15206', '9592457', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '下今泉', 'シモイマイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市大野', '15', '15206', '9592461', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '大野', 'オオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市戸野港', '15', '15206', '9592462', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '戸野港', 'トノミナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市岡島', '15', '15206', '9592463', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '岡島', 'オカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市金塚', '15', '15206', '9592464', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '金塚', 'カナヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市相馬', '15', '15206', '9592465', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '相馬', 'ソウマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市中俵', '15', '15206', '9592468', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '中俵', 'ナカタワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市小国谷', '15', '15206', '9592471', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '小国谷', 'オグニダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市貝屋', '15', '15206', '9592472', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '貝屋', 'カイヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市金山', '15', '15206', '9592473', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '金山', 'カナヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市境', '15', '15206', '9592474', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '境', 'サカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市寺尾', '15', '15206', '9592475', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '寺尾', 'テラオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市貝塚', '15', '15206', '9592476', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '貝塚', 'カイヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市下小中山', '15', '15206', '9592477', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '下小中山', 'シモコナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市下坂町', '15', '15206', '9592478', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '下坂町', 'シモサカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市金沢', '15', '15206', '9592479', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '金沢', 'カナザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市上荒沢', '15', '15206', '9592501', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '上荒沢', 'カミアラサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市熊出', '15', '15206', '9592502', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '熊出', 'クマイデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市下中山', '15', '15206', '9592503', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '下中山', 'シモナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市上寺内', '15', '15206', '9592504', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '上寺内', 'カミジナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市下寺内', '15', '15206', '9592505', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '下寺内', 'シモジナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市横山', '15', '15206', '9592506', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '横山', 'ヨコヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市溝足', '15', '15206', '9592507', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '溝足', 'ミズオシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市菅谷', '15', '15206', '9592511', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '菅谷', 'スガタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市小出', '15', '15206', '9592512', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '小出', 'コイデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市繁山', '15', '15206', '9592513', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '繁山', 'シゲヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市上石川', '15', '15206', '9592514', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '上石川', 'カミイシカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市中川', '15', '15206', '9592515', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '中川', 'ナカガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市下石川', '15', '15206', '9592516', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '下石川', 'シモイシカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市麓', '15', '15206', '9592517', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '麓', 'フモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市滝', '15', '15206', '9592518', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '滝', 'タキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市蔵光', '15', '15206', '9592521', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '蔵光', 'クラミツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市北中江', '15', '15206', '9592522', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '北中江', 'キタナカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市上中江', '15', '15206', '9592523', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '上中江', 'カミナカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市下中江', '15', '15206', '9592524', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '下中江', 'シモナカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市中倉', '15', '15206', '9592525', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '中倉', 'ナカクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市中妻', '15', '15206', '9592526', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '中妻', 'ナカヅマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市黒岩', '15', '15206', '9592527', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '黒岩', 'クロイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県新発田市東宮内', '15', '15206', '9592528', '新潟県', 'ニイガタケン', '新発田市', 'シバタシ', '東宮内', 'ヒガシミヤウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市', '15', '15227', '9592600', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('135136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市桃崎浜', '15', '15227', '9592601', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '桃崎浜', 'モモザキハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市乙', '15', '15227', '9592602', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '乙', 'キノト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市菅田', '15', '15227', '9592603', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '菅田', 'スゲタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市大出', '15', '15227', '9592604', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '大出', 'オオイデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市江尻', '15', '15227', '9592605', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '江尻', 'エジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市八幡', '15', '15227', '9592606', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '八幡', 'ハチマン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市地本', '15', '15227', '9592607', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '地本', 'ジモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市富岡', '15', '15227', '9592608', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '富岡', 'トミオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市荒井浜', '15', '15227', '9592609', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '荒井浜', 'アライハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市山屋', '15', '15227', '9592611', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '山屋', 'ヤマヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市小地谷', '15', '15227', '9592612', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '小地谷', 'オジヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市平木田駅前', '15', '15227', '9592613', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '平木田駅前', 'ヒラキダエキマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市平木田', '15', '15227', '9592614', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '平木田', 'ヒラキダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市横道', '15', '15227', '9592615', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '横道', 'ヨコミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市土作', '15', '15227', '9592616', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '土作', 'ツチヅクリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市高野村新田', '15', '15227', '9592617', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '高野村新田', 'タカノムラシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市高野', '15', '15227', '9592618', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '高野', 'タカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市十二天', '15', '15227', '9592619', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '十二天', 'ジュウニテン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市並槻', '15', '15227', '9592621', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '並槻', 'ナミツキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市追分', '15', '15227', '9592622', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '追分', 'オイワケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市仁谷野', '15', '15227', '9592623', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '仁谷野', 'ニイダノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市羽黒', '15', '15227', '9592624', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '羽黒', 'ハグロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市半山', '15', '15227', '9592625', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '半山', 'ハンヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市飯角', '15', '15227', '9592626', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '飯角', 'イイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市野中', '15', '15227', '9592627', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '野中', 'ノナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市二葉町', '15', '15227', '9592628', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '二葉町', 'フタバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市中条', '15', '15227', '9592629', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '中条', 'ナカジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市表町', '15', '15227', '9592631', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '表町', 'オモテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市新栄町', '15', '15227', '9592632', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '新栄町', 'シンエイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市関沢', '15', '15227', '9592633', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '関沢', 'セキザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市小牧台', '15', '15227', '9592634', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '小牧台', 'コマキダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市つつじが丘', '15', '15227', '9592635', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', 'つつじが丘', 'ツツジガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市星の宮町', '15', '15227', '9592636', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '星の宮町', 'ホシノミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市長橋', '15', '15227', '9592637', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '長橋', 'ナガハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市水沢町', '15', '15227', '9592638', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '水沢町', 'ミズサワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市若松町', '15', '15227', '9592641', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '若松町', 'ワカマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市新和町', '15', '15227', '9592642', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '新和町', 'シンワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市東本町', '15', '15227', '9592643', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '東本町', 'ヒガシホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市大川町', '15', '15227', '9592644', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '大川町', 'オオカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市本町', '15', '15227', '9592645', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市西栄町', '15', '15227', '9592646', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '西栄町', 'ニシサカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市北本町', '15', '15227', '9592647', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '北本町', 'キタホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市住吉町', '15', '15227', '9592648', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '住吉町', 'スミヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市西条町', '15', '15227', '9592651', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '西条町', 'ニシジョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市協和町', '15', '15227', '9592652', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '協和町', 'キョウワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市倉敷町', '15', '15227', '9592653', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '倉敷町', 'クラシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市本郷町', '15', '15227', '9592654', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '本郷町', 'ホンゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市本郷', '15', '15227', '9592655', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '本郷', 'ホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市西本町', '15', '15227', '9592656', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '西本町', 'ニシホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市江上', '15', '15227', '9592657', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '江上', 'エガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市西条', '15', '15227', '9592658', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '西条', 'ニシジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市あかね町', '15', '15227', '9592659', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', 'あかね町', 'アカネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市赤川', '15', '15227', '9592661', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '赤川', 'アカガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市鷹ノ巣', '15', '15227', '9592662', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '鷹ノ巣', 'タカノス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市草野', '15', '15227', '9592663', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '草野', 'クサノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市柴橋', '15', '15227', '9592664', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '柴橋', 'シバハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市大塚', '15', '15227', '9592665', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '大塚', 'オオツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市新舘', '15', '15227', '9592666', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '新舘', 'シンダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市西川内', '15', '15227', '9592667', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '西川内', 'ニシカワウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市弥彦岡', '15', '15227', '9592668', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '弥彦岡', 'ヤヒコオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市塩津', '15', '15227', '9592669', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '塩津', 'シオヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市東川内', '15', '15227', '9592671', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '東川内', 'ヒガシカワウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市八田', '15', '15227', '9592672', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '八田', 'ハッタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市寅田', '15', '15227', '9592673', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '寅田', 'トラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市小舟戸', '15', '15227', '9592674', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '小舟戸', 'コブナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市船戸', '15', '15227', '9592675', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '船戸', 'フナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市上城塚', '15', '15227', '9592676', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '上城塚', 'カミジョウヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市下城塚', '15', '15227', '9592677', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '下城塚', 'シモジョウヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市笹口浜', '15', '15227', '9592701', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '笹口浜', 'ササグチハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市平根台', '15', '15227', '9592702', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '平根台', 'ヒラネダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市高畑', '15', '15227', '9592703', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '高畑', 'タカバタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市宮瀬', '15', '15227', '9592704', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '宮瀬', 'ミヤゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市鴻ノ巣', '15', '15227', '9592705', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '鴻ノ巣', 'コウノス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市山王', '15', '15227', '9592706', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '山王', 'サンノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市下高田', '15', '15227', '9592707', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '下高田', 'シモタカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市中村浜', '15', '15227', '9592708', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '中村浜', 'ナカムラハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市村松浜', '15', '15227', '9592709', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '村松浜', 'ムラマツハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市築地', '15', '15227', '9592712', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '築地', 'ツイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市築地新', '15', '15227', '9592713', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '築地新', 'ツイジシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市堀口', '15', '15227', '9592714', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '堀口', 'ホリグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市高橋', '15', '15227', '9592715', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '高橋', 'タカハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市中倉', '15', '15227', '9592716', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '中倉', 'ナカクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市苔実', '15', '15227', '9592721', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '苔実', 'コケノミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市竹島', '15', '15227', '9592722', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '竹島', 'タケシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市宮川', '15', '15227', '9592723', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '宮川', 'ミヤガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市北成田', '15', '15227', '9592724', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '北成田', 'キタナリタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市近江新', '15', '15227', '9592801', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '近江新', 'オウミシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市切田', '15', '15227', '9592802', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '切田', 'キッタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市蔵王', '15', '15227', '9592803', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '蔵王', 'ザオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市塩沢', '15', '15227', '9592804', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '塩沢', 'シオザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市下館', '15', '15227', '9592805', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '下館', 'シモタテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市下赤谷', '15', '15227', '9592806', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '下赤谷', 'シモアカダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市黒川', '15', '15227', '9592807', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '黒川', 'クロカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市東牧', '15', '15227', '9592808', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '東牧', 'トウボク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市下江端', '15', '15227', '9592809', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '下江端', 'シモエバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市鍬江', '15', '15227', '9592811', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '鍬江', 'クワエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市小長谷', '15', '15227', '9592812', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '小長谷', 'コナガタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市大長谷', '15', '15227', '9592813', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '大長谷', 'オオナガタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市黒俣', '15', '15227', '9592814', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '黒俣', 'クロマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市持倉', '15', '15227', '9592815', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '持倉', 'モチクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市下荒沢', '15', '15227', '9592816', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '下荒沢', 'シモアラサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市須巻', '15', '15227', '9592817', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '須巻', 'スマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市坪穴', '15', '15227', '9592821', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '坪穴', 'ツボアナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市夏井', '15', '15227', '9592822', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '夏井', 'ナツイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市熱田坂', '15', '15227', '9592823', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '熱田坂', 'アツタザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市宮久', '15', '15227', '9592824', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '宮久', 'ミヤヒサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市坂井', '15', '15227', '9592825', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '坂井', 'サカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市鼓岡', '15', '15227', '9592826', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '鼓岡', 'ツヅミオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県胎内市栗木野新田', '15', '15227', '9592827', '新潟県', 'ニイガタケン', '胎内市', 'タイナイシ', '栗木野新田', 'クリキノシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市花立', '15', '15212', '9593101', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '花立', 'ハナダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市貝附', '15', '15212', '9593102', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '貝附', 'カイツケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市荒島', '15', '15212', '9593103', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '荒島', 'アラシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市春木山', '15', '15212', '9593104', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '春木山', 'ハルキヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市梨木', '15', '15212', '9593105', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '梨木', 'ナシノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市切田', '15', '15212', '9593106', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '切田', 'キッタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市下鍜冶屋', '15', '15212', '9593107', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '下鍜冶屋', 'シモカジヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市上鍜冶屋', '15', '15212', '9593108', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '上鍜冶屋', 'カミカジヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市長政', '15', '15212', '9593111', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '長政', 'ナガマサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市中野', '15', '15212', '9593112', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '中野', 'ナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市名割', '15', '15212', '9593113', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '名割', 'ナワリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市南新保', '15', '15212', '9593114', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '南新保', 'ミナミシンボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市新光寺', '15', '15212', '9593115', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '新光寺', 'シンコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市荒屋', '15', '15212', '9593116', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '荒屋', 'アラヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市海老江', '15', '15212', '9593117', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '海老江', 'エビエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市佐々木', '15', '15212', '9593121', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '佐々木', 'ササキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市大津', '15', '15212', '9593122', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '大津', 'オオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市中倉', '15', '15212', '9593123', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '中倉', 'ナカクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市金屋', '15', '15212', '9593124', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '金屋', 'カナヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市荒川縁新田', '15', '15212', '9593125', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '荒川縁新田', 'アラカワベリシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市鳥屋', '15', '15212', '9593126', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '鳥屋', 'トリヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市藤沢', '15', '15212', '9593131', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '藤沢', 'フジサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市坂町', '15', '15212', '9593132', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '坂町', 'サカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市山口', '15', '15212', '9593133', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '山口', 'ヤマグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市羽ヶ榎', '15', '15212', '9593134', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '羽ヶ榎', 'ハガエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県岩船郡関川村', '15', '15581', '9593200', '新潟県', 'ニイガタケン', '岩船郡関川村', 'イワフネグンセキカワムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('135278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県岩船郡関川村朴坂', '15', '15581', '9593201', '新潟県', 'ニイガタケン', '岩船郡関川村', 'イワフネグンセキカワムラ', '朴坂', 'ホウサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県岩船郡関川村宮前', '15', '15581', '9593202', '新潟県', 'ニイガタケン', '岩船郡関川村', 'イワフネグンセキカワムラ', '宮前', 'ミヤノマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県岩船郡関川村南中', '15', '15581', '9593203', '新潟県', 'ニイガタケン', '岩船郡関川村', 'イワフネグンセキカワムラ', '南中', 'ミナミナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県岩船郡関川村蛇喰', '15', '15581', '9593204', '新潟県', 'ニイガタケン', '岩船郡関川村', 'イワフネグンセキカワムラ', '蛇喰', 'ジャバミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県岩船郡関川村上新保', '15', '15581', '9593205', '新潟県', 'ニイガタケン', '岩船郡関川村', 'イワフネグンセキカワムラ', '上新保', 'カミシンボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県岩船郡関川村中束', '15', '15581', '9593206', '新潟県', 'ニイガタケン', '岩船郡関川村', 'イワフネグンセキカワムラ', '中束', 'ナカマルケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県岩船郡関川村蕨野', '15', '15581', '9593207', '新潟県', 'ニイガタケン', '岩船郡関川村', 'イワフネグンセキカワムラ', '蕨野', 'ワラビノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県岩船郡関川村田麦千刈', '15', '15581', '9593208', '新潟県', 'ニイガタケン', '岩船郡関川村', 'イワフネグンセキカワムラ', '田麦千刈', 'タムギチガリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県岩船郡関川村小和田', '15', '15581', '9593211', '新潟県', 'ニイガタケン', '岩船郡関川村', 'イワフネグンセキカワムラ', '小和田', 'コワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県岩船郡関川村若山', '15', '15581', '9593212', '新潟県', 'ニイガタケン', '岩船郡関川村', 'イワフネグンセキカワムラ', '若山', 'ワカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県岩船郡関川村上野', '15', '15581', '9593213', '新潟県', 'ニイガタケン', '岩船郡関川村', 'イワフネグンセキカワムラ', '上野', 'ウエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県岩船郡関川村上野新', '15', '15581', '9593214', '新潟県', 'ニイガタケン', '岩船郡関川村', 'イワフネグンセキカワムラ', '上野新', 'ウエノシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県岩船郡関川村深沢', '15', '15581', '9593215', '新潟県', 'ニイガタケン', '岩船郡関川村', 'イワフネグンセキカワムラ', '深沢', 'フカザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県岩船郡関川村上野原', '15', '15581', '9593216', '新潟県', 'ニイガタケン', '岩船郡関川村', 'イワフネグンセキカワムラ', '上野原', 'ウエノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県岩船郡関川村下川口', '15', '15581', '9593221', '新潟県', 'ニイガタケン', '岩船郡関川村', 'イワフネグンセキカワムラ', '下川口', 'シモカワグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県岩船郡関川村荒川台', '15', '15581', '9593222', '新潟県', 'ニイガタケン', '岩船郡関川村', 'イワフネグンセキカワムラ', '荒川台', 'アラカワダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県岩船郡関川村大内淵', '15', '15581', '9593223', '新潟県', 'ニイガタケン', '岩船郡関川村', 'イワフネグンセキカワムラ', '大内淵', 'オウチブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県岩船郡関川村聞出', '15', '15581', '9593224', '新潟県', 'ニイガタケン', '岩船郡関川村', 'イワフネグンセキカワムラ', '聞出', 'キケイデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県岩船郡関川村沼', '15', '15581', '9593225', '新潟県', 'ニイガタケン', '岩船郡関川村', 'イワフネグンセキカワムラ', '沼', 'ヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県岩船郡関川村片貝', '15', '15581', '9593226', '新潟県', 'ニイガタケン', '岩船郡関川村', 'イワフネグンセキカワムラ', '片貝', 'カタカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県岩船郡関川村八ツ口', '15', '15581', '9593227', '新潟県', 'ニイガタケン', '岩船郡関川村', 'イワフネグンセキカワムラ', '八ツ口', 'ヤツクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県岩船郡関川村金丸', '15', '15581', '9593228', '新潟県', 'ニイガタケン', '岩船郡関川村', 'イワフネグンセキカワムラ', '金丸', 'カナマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県岩船郡関川村上川口', '15', '15581', '9593231', '新潟県', 'ニイガタケン', '岩船郡関川村', 'イワフネグンセキカワムラ', '上川口', 'カミカワクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県岩船郡関川村蔵田島', '15', '15581', '9593232', '新潟県', 'ニイガタケン', '岩船郡関川村', 'イワフネグンセキカワムラ', '蔵田島', 'ソウダシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県岩船郡関川村久保', '15', '15581', '9593233', '新潟県', 'ニイガタケン', '岩船郡関川村', 'イワフネグンセキカワムラ', '久保', 'クボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県岩船郡関川村鮖谷', '15', '15581', '9593234', '新潟県', 'ニイガタケン', '岩船郡関川村', 'イワフネグンセキカワムラ', '鮖谷', 'カジカダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県岩船郡関川村安角', '15', '15581', '9593235', '新潟県', 'ニイガタケン', '岩船郡関川村', 'イワフネグンセキカワムラ', '安角', 'アズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県岩船郡関川村大石', '15', '15581', '9593236', '新潟県', 'ニイガタケン', '岩船郡関川村', 'イワフネグンセキカワムラ', '大石', 'オオイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県岩船郡関川村金俣', '15', '15581', '9593237', '新潟県', 'ニイガタケン', '岩船郡関川村', 'イワフネグンセキカワムラ', '金俣', 'カネマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県岩船郡関川村大島', '15', '15581', '9593241', '新潟県', 'ニイガタケン', '岩船郡関川村', 'イワフネグンセキカワムラ', '大島', 'オオシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県岩船郡関川村下土沢', '15', '15581', '9593242', '新潟県', 'ニイガタケン', '岩船郡関川村', 'イワフネグンセキカワムラ', '下土沢', 'シモツチザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県岩船郡関川村鍬江沢', '15', '15581', '9593243', '新潟県', 'ニイガタケン', '岩船郡関川村', 'イワフネグンセキカワムラ', '鍬江沢', 'クワエザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県岩船郡関川村山本', '15', '15581', '9593244', '新潟県', 'ニイガタケン', '岩船郡関川村', 'イワフネグンセキカワムラ', '山本', 'ヤマモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県岩船郡関川村幾地', '15', '15581', '9593245', '新潟県', 'ニイガタケン', '岩船郡関川村', 'イワフネグンセキカワムラ', '幾地', 'イクジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県岩船郡関川村上土沢', '15', '15581', '9593246', '新潟県', 'ニイガタケン', '岩船郡関川村', 'イワフネグンセキカワムラ', '上土沢', 'カミツチザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県岩船郡関川村桂', '15', '15581', '9593251', '新潟県', 'ニイガタケン', '岩船郡関川村', 'イワフネグンセキカワムラ', '桂', 'カツラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県岩船郡関川村高田', '15', '15581', '9593252', '新潟県', 'ニイガタケン', '岩船郡関川村', 'イワフネグンセキカワムラ', '高田', 'タカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県岩船郡関川村平内新', '15', '15581', '9593253', '新潟県', 'ニイガタケン', '岩船郡関川村', 'イワフネグンセキカワムラ', '平内新', 'ヘイナイシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県岩船郡関川村小見前新田', '15', '15581', '9593254', '新潟県', 'ニイガタケン', '岩船郡関川村', 'イワフネグンセキカワムラ', '小見前新田', 'オウミマエシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県岩船郡関川村松ケ丘', '15', '15581', '9593255', '新潟県', 'ニイガタケン', '岩船郡関川村', 'イワフネグンセキカワムラ', '松ケ丘', 'マツガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県岩船郡関川村小見', '15', '15581', '9593256', '新潟県', 'ニイガタケン', '岩船郡関川村', 'イワフネグンセキカワムラ', '小見', 'オウミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県岩船郡関川村上野山', '15', '15581', '9593257', '新潟県', 'ニイガタケン', '岩船郡関川村', 'イワフネグンセキカワムラ', '上野山', 'ウエノヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県岩船郡関川村滝原', '15', '15581', '9593258', '新潟県', 'ニイガタケン', '岩船郡関川村', 'イワフネグンセキカワムラ', '滝原', 'タキバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県岩船郡関川村松平', '15', '15581', '9593259', '新潟県', 'ニイガタケン', '岩船郡関川村', 'イワフネグンセキカワムラ', '松平', 'マツダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県岩船郡関川村湯沢', '15', '15581', '9593261', '新潟県', 'ニイガタケン', '岩船郡関川村', 'イワフネグンセキカワムラ', '湯沢', 'ユサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県岩船郡関川村沢', '15', '15581', '9593262', '新潟県', 'ニイガタケン', '岩船郡関川村', 'イワフネグンセキカワムラ', '沢', 'サワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県岩船郡関川村高瀬', '15', '15581', '9593263', '新潟県', 'ニイガタケン', '岩船郡関川村', 'イワフネグンセキカワムラ', '高瀬', 'タカセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県岩船郡関川村上関', '15', '15581', '9593264', '新潟県', 'ニイガタケン', '岩船郡関川村', 'イワフネグンセキカワムラ', '上関', 'カミセキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県岩船郡関川村下関', '15', '15581', '9593265', '新潟県', 'ニイガタケン', '岩船郡関川村', 'イワフネグンセキカワムラ', '下関', 'シモセキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県岩船郡関川村辰田新', '15', '15581', '9593271', '新潟県', 'ニイガタケン', '岩船郡関川村', 'イワフネグンセキカワムラ', '辰田新', 'タツタシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県岩船郡関川村打上', '15', '15581', '9593272', '新潟県', 'ニイガタケン', '岩船郡関川村', 'イワフネグンセキカワムラ', '打上', 'ウチアゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県岩船郡関川村勝蔵', '15', '15581', '9593273', '新潟県', 'ニイガタケン', '岩船郡関川村', 'イワフネグンセキカワムラ', '勝蔵', 'ショウゾウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県岩船郡関川村南赤谷', '15', '15581', '9593274', '新潟県', 'ニイガタケン', '岩船郡関川村', 'イワフネグンセキカワムラ', '南赤谷', 'ミナミアカダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県岩船郡関川村内須川', '15', '15581', '9593275', '新潟県', 'ニイガタケン', '岩船郡関川村', 'イワフネグンセキカワムラ', '内須川', 'ウチスガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市七湊', '15', '15212', '9593401', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '七湊', 'ナナミナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市志田平', '15', '15212', '9593402', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '志田平', 'シダノヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市上助渕', '15', '15212', '9593403', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '上助渕', 'カミスケブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市山屋', '15', '15212', '9593404', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '山屋', 'ヤマヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市里本庄', '15', '15212', '9593405', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '里本庄', 'サトホンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市下助渕', '15', '15212', '9593406', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '下助渕', 'シモスケブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市殿岡', '15', '15212', '9593407', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '殿岡', 'トノオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市南大平', '15', '15212', '9593411', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '南大平', 'ミナミオオダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市指合', '15', '15212', '9593412', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '指合', 'サシアワセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市小出', '15', '15212', '9593413', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '小出', 'コイデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市有明', '15', '15212', '9593414', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '有明', 'アリアケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市大塚', '15', '15212', '9593415', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '大塚', 'オオツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市今宿', '15', '15212', '9593416', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '今宿', 'イマジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市河内', '15', '15212', '9593417', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '河内', 'カワウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市桃川', '15', '15212', '9593421', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '桃川', 'モモカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市飯岡', '15', '15212', '9593422', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '飯岡', 'イイオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市九日市', '15', '15212', '9593423', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '九日市', 'ココノカイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市牧目', '15', '15212', '9593424', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '牧目', 'マキノメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市山田', '15', '15212', '9593425', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '山田', 'ヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市岩野沢', '15', '15212', '9593426', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '岩野沢', 'イワノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市松沢', '15', '15212', '9593427', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '松沢', 'マツザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市松喜和', '15', '15212', '9593428', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '松喜和', 'マツキワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市平林', '15', '15212', '9593431', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '平林', 'ヒラバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市葛籠山', '15', '15212', '9593432', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '葛籠山', 'ツヅラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市川部', '15', '15212', '9593433', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '川部', 'カワベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市小岩内', '15', '15212', '9593434', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '小岩内', 'コイワウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市宿田', '15', '15212', '9593435', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '宿田', 'ヤズタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市牛屋', '15', '15212', '9593436', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '牛屋', 'ウシヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市福田', '15', '15212', '9593437', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '福田', 'フクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市塩谷', '15', '15212', '9593441', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '塩谷', 'シオヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市長松', '15', '15212', '9593442', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '長松', 'ナガマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市北新保', '15', '15212', '9593443', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '北新保', 'キタシンボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市南田中', '15', '15212', '9593444', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '南田中', 'ミナミタナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市新飯田', '15', '15212', '9593445', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '新飯田', 'ニイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市小口川', '15', '15212', '9593446', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '小口川', 'コクチガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市高御堂', '15', '15212', '9593447', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '高御堂', 'タカミドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市潟端', '15', '15212', '9593448', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '潟端', 'カタバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市芦谷', '15', '15212', '9593651', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '芦谷', 'アシダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市越沢', '15', '15212', '9593652', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '越沢', 'コエサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市寒川', '15', '15212', '9593653', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '寒川', 'カンガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市脇川', '15', '15212', '9593661', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '脇川', 'ワキガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市今川', '15', '15212', '9593662', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '今川', 'イマガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市板貝', '15', '15212', '9593663', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '板貝', 'イタガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市笹川', '15', '15212', '9593664', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '笹川', 'ササガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市桑川', '15', '15212', '9593665', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '桑川', 'クワガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市浜新保', '15', '15212', '9593666', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '浜新保', 'ハマシンボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市伊呉野', '15', '15212', '9593901', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '伊呉野', 'イグレノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市中浜', '15', '15212', '9593902', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '中浜', 'ナカハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市岩崎', '15', '15212', '9593903', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '岩崎', 'イワサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市温出', '15', '15212', '9593904', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '温出', 'ヌクイデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市堀ノ内', '15', '15212', '9593905', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '堀ノ内', 'ホリノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市大谷沢', '15', '15212', '9593906', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '大谷沢', 'オオタニザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市府屋', '15', '15212', '9593907', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '府屋', 'フヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市杉平', '15', '15212', '9593911', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '杉平', 'スギタイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市遅郷', '15', '15212', '9593912', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '遅郷', 'オソノゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市岩石', '15', '15212', '9593913', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '岩石', 'ガンジキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市小俣', '15', '15212', '9593914', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '小俣', 'オマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市大代', '15', '15212', '9593915', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '大代', 'オオダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市雷', '15', '15212', '9593916', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '雷', 'イカヅチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市山熊田', '15', '15212', '9593917', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '山熊田', 'ヤマクマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市中継', '15', '15212', '9593918', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '中継', 'ナカツギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市塔下', '15', '15212', '9593919', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '塔下', 'トウノシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市荒川口', '15', '15212', '9593921', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '荒川口', 'アラカワグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市朴平', '15', '15212', '9593922', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '朴平', 'ホウダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市荒川', '15', '15212', '9593923', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '荒川', 'アラカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市北黒川', '15', '15212', '9593924', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '北黒川', 'キタクロカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市大沢', '15', '15212', '9593925', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '大沢', 'オオサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市大毎', '15', '15212', '9593926', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '大毎', 'オオゴト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市北中', '15', '15212', '9593927', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '北中', 'キタナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市中津原', '15', '15212', '9593928', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '中津原', 'ナカツハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市長坂', '15', '15212', '9593931', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '長坂', 'ナガサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市垣之内', '15', '15212', '9593932', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '垣之内', 'カキノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市下大鳥', '15', '15212', '9593933', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '下大鳥', 'シモオオトリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市上大鳥', '15', '15212', '9593934', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '上大鳥', 'カミオオトリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市北田中', '15', '15212', '9593935', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '北田中', 'キタタナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市北赤谷', '15', '15212', '9593936', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '北赤谷', 'キタアカタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市板屋沢', '15', '15212', '9593937', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '板屋沢', 'イタヤサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市遠矢崎', '15', '15212', '9593938', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '遠矢崎', 'トオヤサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市碁石', '15', '15212', '9593941', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '碁石', 'ゴイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市勝木', '15', '15212', '9593942', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '勝木', 'ガツギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市下大蔵', '15', '15212', '9593943', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '下大蔵', 'シモオオクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市立島', '15', '15212', '9593944', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '立島', 'タテシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市間瀬', '15', '15212', '9593945', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '間瀬', 'マゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市寝屋', '15', '15212', '9593946', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '寝屋', 'ネヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市鵜泊', '15', '15212', '9593947', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '鵜泊', 'ウドマリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県村上市上大蔵', '15', '15212', '9593948', '新潟県', 'ニイガタケン', '村上市', 'ムラカミシ', '上大蔵', 'カミオオクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県東蒲原郡阿賀町向鹿瀬', '15', '15385', '9594301', '新潟県', 'ニイガタケン', '東蒲原郡阿賀町', 'ヒガシカンバラグンアガマチ', '向鹿瀬', 'ムカイカノセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県東蒲原郡阿賀町鹿瀬', '15', '15385', '9594302', '新潟県', 'ニイガタケン', '東蒲原郡阿賀町', 'ヒガシカンバラグンアガマチ', '鹿瀬', 'カノセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県東蒲原郡阿賀町日出谷', '15', '15385', '9594303', '新潟県', 'ニイガタケン', '東蒲原郡阿賀町', 'ヒガシカンバラグンアガマチ', '日出谷', 'ヒデヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県東蒲原郡阿賀町豊実', '15', '15385', '9594304', '新潟県', 'ニイガタケン', '東蒲原郡阿賀町', 'ヒガシカンバラグンアガマチ', '豊実', 'トヨミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県東蒲原郡阿賀町', '15', '15385', '9594400', '新潟県', 'ニイガタケン', '東蒲原郡阿賀町', 'ヒガシカンバラグンアガマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('135428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県東蒲原郡阿賀町角島', '15', '15385', '9594401', '新潟県', 'ニイガタケン', '東蒲原郡阿賀町', 'ヒガシカンバラグンアガマチ', '角島', 'ツノシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県東蒲原郡阿賀町津川', '15', '15385', '9594402', '新潟県', 'ニイガタケン', '東蒲原郡阿賀町', 'ヒガシカンバラグンアガマチ', '津川', 'ツガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県東蒲原郡阿賀町平堀', '15', '15385', '9594403', '新潟県', 'ニイガタケン', '東蒲原郡阿賀町', 'ヒガシカンバラグンアガマチ', '平堀', 'ヒラボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県東蒲原郡阿賀町広沢', '15', '15385', '9594404', '新潟県', 'ニイガタケン', '東蒲原郡阿賀町', 'ヒガシカンバラグンアガマチ', '広沢', 'ヒロサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県東蒲原郡阿賀町上ノ山', '15', '15385', '9594405', '新潟県', 'ニイガタケン', '東蒲原郡阿賀町', 'ヒガシカンバラグンアガマチ', '上ノ山', 'ウエノヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県東蒲原郡阿賀町雲和田', '15', '15385', '9594406', '新潟県', 'ニイガタケン', '東蒲原郡阿賀町', 'ヒガシカンバラグンアガマチ', '雲和田', 'クモワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県東蒲原郡阿賀町西', '15', '15385', '9594407', '新潟県', 'ニイガタケン', '東蒲原郡阿賀町', 'ヒガシカンバラグンアガマチ', '西', 'ニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県東蒲原郡阿賀町赤岩', '15', '15385', '9594408', '新潟県', 'ニイガタケン', '東蒲原郡阿賀町', 'ヒガシカンバラグンアガマチ', '赤岩', 'アカイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県東蒲原郡阿賀町京ノ瀬', '15', '15385', '9594409', '新潟県', 'ニイガタケン', '東蒲原郡阿賀町', 'ヒガシカンバラグンアガマチ', '京ノ瀬', 'キョウノセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県東蒲原郡阿賀町大牧', '15', '15385', '9594410', '新潟県', 'ニイガタケン', '東蒲原郡阿賀町', 'ヒガシカンバラグンアガマチ', '大牧', 'オオマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県東蒲原郡阿賀町天満', '15', '15385', '9594411', '新潟県', 'ニイガタケン', '東蒲原郡阿賀町', 'ヒガシカンバラグンアガマチ', '天満', 'テンマン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県東蒲原郡阿賀町花立', '15', '15385', '9594412', '新潟県', 'ニイガタケン', '東蒲原郡阿賀町', 'ヒガシカンバラグンアガマチ', '花立', 'ハナダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県東蒲原郡阿賀町倉ノ平', '15', '15385', '9594413', '新潟県', 'ニイガタケン', '東蒲原郡阿賀町', 'ヒガシカンバラグンアガマチ', '倉ノ平', 'クラノヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県東蒲原郡阿賀町福取', '15', '15385', '9594414', '新潟県', 'ニイガタケン', '東蒲原郡阿賀町', 'ヒガシカンバラグンアガマチ', '福取', 'フクトリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県東蒲原郡阿賀町八ツ田', '15', '15385', '9594415', '新潟県', 'ニイガタケン', '東蒲原郡阿賀町', 'ヒガシカンバラグンアガマチ', '八ツ田', 'ヤツダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県東蒲原郡阿賀町田沢', '15', '15385', '9594416', '新潟県', 'ニイガタケン', '東蒲原郡阿賀町', 'ヒガシカンバラグンアガマチ', '田沢', 'タザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県東蒲原郡阿賀町八木山', '15', '15385', '9594417', '新潟県', 'ニイガタケン', '東蒲原郡阿賀町', 'ヒガシカンバラグンアガマチ', '八木山', 'ヤキヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県東蒲原郡阿賀町野村', '15', '15385', '9594418', '新潟県', 'ニイガタケン', '東蒲原郡阿賀町', 'ヒガシカンバラグンアガマチ', '野村', 'ノムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県東蒲原郡阿賀町払川', '15', '15385', '9594441', '新潟県', 'ニイガタケン', '東蒲原郡阿賀町', 'ヒガシカンバラグンアガマチ', '払川', 'ハライガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県東蒲原郡阿賀町九島', '15', '15385', '9594501', '新潟県', 'ニイガタケン', '東蒲原郡阿賀町', 'ヒガシカンバラグンアガマチ', '九島', 'クシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県東蒲原郡阿賀町小出', '15', '15385', '9594502', '新潟県', 'ニイガタケン', '東蒲原郡阿賀町', 'ヒガシカンバラグンアガマチ', '小出', 'コイデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県東蒲原郡阿賀町豊川乙', '15', '15385', '9594503', '新潟県', 'ニイガタケン', '東蒲原郡阿賀町', 'ヒガシカンバラグンアガマチ', '豊川乙', 'トヨカワオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県東蒲原郡阿賀町豊川丙', '15', '15385', '9594504', '新潟県', 'ニイガタケン', '東蒲原郡阿賀町', 'ヒガシカンバラグンアガマチ', '豊川丙', 'トヨカワヘイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県東蒲原郡阿賀町豊川甲', '15', '15385', '9594505', '新潟県', 'ニイガタケン', '東蒲原郡阿賀町', 'ヒガシカンバラグンアガマチ', '豊川甲', 'トヨカワコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県東蒲原郡阿賀町両郷乙', '15', '15385', '9594506', '新潟県', 'ニイガタケン', '東蒲原郡阿賀町', 'ヒガシカンバラグンアガマチ', '両郷乙', 'リョウゴウオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県東蒲原郡阿賀町両郷甲', '15', '15385', '9594507', '新潟県', 'ニイガタケン', '東蒲原郡阿賀町', 'ヒガシカンバラグンアガマチ', '両郷甲', 'リョウゴウコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県東蒲原郡阿賀町東山', '15', '15385', '9594511', '新潟県', 'ニイガタケン', '東蒲原郡阿賀町', 'ヒガシカンバラグンアガマチ', '東山', 'ヒガシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県東蒲原郡阿賀町大倉乙', '15', '15385', '9594512', '新潟県', 'ニイガタケン', '東蒲原郡阿賀町', 'ヒガシカンバラグンアガマチ', '大倉乙', 'ダイクラオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県東蒲原郡阿賀町大倉甲', '15', '15385', '9594513', '新潟県', 'ニイガタケン', '東蒲原郡阿賀町', 'ヒガシカンバラグンアガマチ', '大倉甲', 'ダイクラコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県東蒲原郡阿賀町七名乙', '15', '15385', '9594514', '新潟県', 'ニイガタケン', '東蒲原郡阿賀町', 'ヒガシカンバラグンアガマチ', '七名乙', 'ナナメオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県東蒲原郡阿賀町七名甲', '15', '15385', '9594515', '新潟県', 'ニイガタケン', '東蒲原郡阿賀町', 'ヒガシカンバラグンアガマチ', '七名甲', 'ナナメコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県東蒲原郡阿賀町三宝分甲', '15', '15385', '9594521', '新潟県', 'ニイガタケン', '東蒲原郡阿賀町', 'ヒガシカンバラグンアガマチ', '三宝分甲', 'サンポウブンコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県東蒲原郡阿賀町三宝分乙', '15', '15385', '9594522', '新潟県', 'ニイガタケン', '東蒲原郡阿賀町', 'ヒガシカンバラグンアガマチ', '三宝分乙', 'サンポウブンオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県東蒲原郡阿賀町三宝分丙', '15', '15385', '9594523', '新潟県', 'ニイガタケン', '東蒲原郡阿賀町', 'ヒガシカンバラグンアガマチ', '三宝分丙', 'サンポウブンヘイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県東蒲原郡阿賀町三方乙', '15', '15385', '9594524', '新潟県', 'ニイガタケン', '東蒲原郡阿賀町', 'ヒガシカンバラグンアガマチ', '三方乙', 'ミカタオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県東蒲原郡阿賀町小手茂', '15', '15385', '9594525', '新潟県', 'ニイガタケン', '東蒲原郡阿賀町', 'ヒガシカンバラグンアガマチ', '小手茂', 'オテモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県東蒲原郡阿賀町三方甲', '15', '15385', '9594526', '新潟県', 'ニイガタケン', '東蒲原郡阿賀町', 'ヒガシカンバラグンアガマチ', '三方甲', 'ミカタコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県東蒲原郡阿賀町日野川甲', '15', '15385', '9594531', '新潟県', 'ニイガタケン', '東蒲原郡阿賀町', 'ヒガシカンバラグンアガマチ', '日野川甲', 'ヒノカワコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県東蒲原郡阿賀町広谷丙', '15', '15385', '9594532', '新潟県', 'ニイガタケン', '東蒲原郡阿賀町', 'ヒガシカンバラグンアガマチ', '広谷丙', 'ヒロタニヘイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県東蒲原郡阿賀町神谷丙', '15', '15385', '9594533', '新潟県', 'ニイガタケン', '東蒲原郡阿賀町', 'ヒガシカンバラグンアガマチ', '神谷丙', 'カミタニヘイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県東蒲原郡阿賀町神谷乙', '15', '15385', '9594534', '新潟県', 'ニイガタケン', '東蒲原郡阿賀町', 'ヒガシカンバラグンアガマチ', '神谷乙', 'カミタニオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県東蒲原郡阿賀町神谷甲', '15', '15385', '9594535', '新潟県', 'ニイガタケン', '東蒲原郡阿賀町', 'ヒガシカンバラグンアガマチ', '神谷甲', 'カミタニコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県東蒲原郡阿賀町広谷甲', '15', '15385', '9594536', '新潟県', 'ニイガタケン', '東蒲原郡阿賀町', 'ヒガシカンバラグンアガマチ', '広谷甲', 'ヒロタニコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県東蒲原郡阿賀町広谷乙', '15', '15385', '9594537', '新潟県', 'ニイガタケン', '東蒲原郡阿賀町', 'ヒガシカンバラグンアガマチ', '広谷乙', 'ヒロタニオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県東蒲原郡阿賀町日野川丙', '15', '15385', '9594538', '新潟県', 'ニイガタケン', '東蒲原郡阿賀町', 'ヒガシカンバラグンアガマチ', '日野川丙', 'ヒノカワヘイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県東蒲原郡阿賀町日野川乙', '15', '15385', '9594539', '新潟県', 'ニイガタケン', '東蒲原郡阿賀町', 'ヒガシカンバラグンアガマチ', '日野川乙', 'ヒノカワオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県東蒲原郡阿賀町綱木', '15', '15385', '9594601', '新潟県', 'ニイガタケン', '東蒲原郡阿賀町', 'ヒガシカンバラグンアガマチ', '綱木', 'ツナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県東蒲原郡阿賀町古岐', '15', '15385', '9594602', '新潟県', 'ニイガタケン', '東蒲原郡阿賀町', 'ヒガシカンバラグンアガマチ', '古岐', 'フルマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県東蒲原郡阿賀町新谷', '15', '15385', '9594603', '新潟県', 'ニイガタケン', '東蒲原郡阿賀町', 'ヒガシカンバラグンアガマチ', '新谷', 'アラヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県東蒲原郡阿賀町行地', '15', '15385', '9594604', '新潟県', 'ニイガタケン', '東蒲原郡阿賀町', 'ヒガシカンバラグンアガマチ', '行地', 'ユクジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県東蒲原郡阿賀町細越', '15', '15385', '9594605', '新潟県', 'ニイガタケン', '東蒲原郡阿賀町', 'ヒガシカンバラグンアガマチ', '細越', 'ホソゴエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県東蒲原郡阿賀町五十沢', '15', '15385', '9594606', '新潟県', 'ニイガタケン', '東蒲原郡阿賀町', 'ヒガシカンバラグンアガマチ', '五十沢', 'イカザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県東蒲原郡阿賀町小花地', '15', '15385', '9594608', '新潟県', 'ニイガタケン', '東蒲原郡阿賀町', 'ヒガシカンバラグンアガマチ', '小花地', 'コバナチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県東蒲原郡阿賀町中ノ沢', '15', '15385', '9594611', '新潟県', 'ニイガタケン', '東蒲原郡阿賀町', 'ヒガシカンバラグンアガマチ', '中ノ沢', 'ナカノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県東蒲原郡阿賀町岡沢', '15', '15385', '9594612', '新潟県', 'ニイガタケン', '東蒲原郡阿賀町', 'ヒガシカンバラグンアガマチ', '岡沢', 'オカザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県東蒲原郡阿賀町五十島', '15', '15385', '9594614', '新潟県', 'ニイガタケン', '東蒲原郡阿賀町', 'ヒガシカンバラグンアガマチ', '五十島', 'イガシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県東蒲原郡阿賀町上島', '15', '15385', '9594617', '新潟県', 'ニイガタケン', '東蒲原郡阿賀町', 'ヒガシカンバラグンアガマチ', '上島', 'カミシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県東蒲原郡阿賀町川口', '15', '15385', '9594618', '新潟県', 'ニイガタケン', '東蒲原郡阿賀町', 'ヒガシカンバラグンアガマチ', '川口', 'カワグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県東蒲原郡阿賀町あが野北', '15', '15385', '9594621', '新潟県', 'ニイガタケン', '東蒲原郡阿賀町', 'ヒガシカンバラグンアガマチ', 'あが野北', 'アガノキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県東蒲原郡阿賀町白崎', '15', '15385', '9594622', '新潟県', 'ニイガタケン', '東蒲原郡阿賀町', 'ヒガシカンバラグンアガマチ', '白崎', 'シロサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県東蒲原郡阿賀町黒岩', '15', '15385', '9594623', '新潟県', 'ニイガタケン', '東蒲原郡阿賀町', 'ヒガシカンバラグンアガマチ', '黒岩', 'クロイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県東蒲原郡阿賀町谷沢', '15', '15385', '9594624', '新潟県', 'ニイガタケン', '東蒲原郡阿賀町', 'ヒガシカンバラグンアガマチ', '谷沢', 'ヤザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県東蒲原郡阿賀町吉津', '15', '15385', '9594625', '新潟県', 'ニイガタケン', '東蒲原郡阿賀町', 'ヒガシカンバラグンアガマチ', '吉津', 'ヨシヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県東蒲原郡阿賀町あが野南', '15', '15385', '9594626', '新潟県', 'ニイガタケン', '東蒲原郡阿賀町', 'ヒガシカンバラグンアガマチ', 'あが野南', 'アガノミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県東蒲原郡阿賀町岩谷', '15', '15385', '9594627', '新潟県', 'ニイガタケン', '東蒲原郡阿賀町', 'ヒガシカンバラグンアガマチ', '岩谷', 'イワヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県東蒲原郡阿賀町取上', '15', '15385', '9594631', '新潟県', 'ニイガタケン', '東蒲原郡阿賀町', 'ヒガシカンバラグンアガマチ', '取上', 'トリアゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県東蒲原郡阿賀町石戸', '15', '15385', '9594632', '新潟県', 'ニイガタケン', '東蒲原郡阿賀町', 'ヒガシカンバラグンアガマチ', '石戸', 'イシト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県東蒲原郡阿賀町長谷', '15', '15385', '9594633', '新潟県', 'ニイガタケン', '東蒲原郡阿賀町', 'ヒガシカンバラグンアガマチ', '長谷', 'ナガタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県東蒲原郡阿賀町熊渡', '15', '15385', '9594634', '新潟県', 'ニイガタケン', '東蒲原郡阿賀町', 'ヒガシカンバラグンアガマチ', '熊渡', 'クマワタリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県東蒲原郡阿賀町釣浜', '15', '15385', '9594635', '新潟県', 'ニイガタケン', '東蒲原郡阿賀町', 'ヒガシカンバラグンアガマチ', '釣浜', 'ツリハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '新潟県東蒲原郡阿賀町石間', '15', '15385', '9594636', '新潟県', 'ニイガタケン', '東蒲原郡阿賀町', 'ヒガシカンバラグンアガマチ', '石間', 'イシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道名寄市', '01', '01221', '0960000', '北海道', 'ホッカイドウ', '名寄市', 'ナヨロシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('135502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市', '07', '07201', '9600000', '福島県', 'フクシマケン', '福島市', 'フクシマシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('135503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道名寄市東1条南', '01', '01221', '0960001', '北海道', 'ホッカイドウ', '名寄市', 'ナヨロシ', '東1条南', 'ヒガシ01ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道名寄市東2条南', '01', '01221', '0960002', '北海道', 'ホッカイドウ', '名寄市', 'ナヨロシ', '東2条南', 'ヒガシ02ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道名寄市東3条南', '01', '01221', '0960003', '北海道', 'ホッカイドウ', '名寄市', 'ナヨロシ', '東3条南', 'ヒガシ03ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道名寄市東4条南', '01', '01221', '0960004', '北海道', 'ホッカイドウ', '名寄市', 'ナヨロシ', '東4条南', 'ヒガシ04ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道名寄市東5条南', '01', '01221', '0960005', '北海道', 'ホッカイドウ', '名寄市', 'ナヨロシ', '東5条南', 'ヒガシ05ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道名寄市東6条南', '01', '01221', '0960006', '北海道', 'ホッカイドウ', '名寄市', 'ナヨロシ', '東6条南', 'ヒガシ06ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道名寄市東7条南', '01', '01221', '0960007', '北海道', 'ホッカイドウ', '名寄市', 'ナヨロシ', '東7条南', 'ヒガシ07ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道名寄市東8条南', '01', '01221', '0960008', '北海道', 'ホッカイドウ', '名寄市', 'ナヨロシ', '東8条南', 'ヒガシ08ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道名寄市東9条南', '01', '01221', '0960009', '北海道', 'ホッカイドウ', '名寄市', 'ナヨロシ', '東9条南', 'ヒガシ09ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道名寄市大通南', '01', '01221', '0960010', '北海道', 'ホッカイドウ', '名寄市', 'ナヨロシ', '大通南', 'オオドオリミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市瀬上町', '07', '07201', '9600101', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '瀬上町', 'セノウエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市鎌田', '07', '07201', '9600102', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '鎌田', 'カマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市本内', '07', '07201', '9600103', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '本内', 'モトウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道名寄市西1条南', '01', '01221', '0960011', '北海道', 'ホッカイドウ', '名寄市', 'ナヨロシ', '西1条南', 'ニシ01ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市丸子', '07', '07201', '9600111', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '丸子', 'マリコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市南矢野目', '07', '07201', '9600112', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '南矢野目', 'ミナミヤノメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市北矢野目', '07', '07201', '9600113', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '北矢野目', 'キタヤノメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市沖高', '07', '07201', '9600114', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '沖高', 'オキダカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市下飯坂', '07', '07201', '9600115', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '下飯坂', 'シモイイザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市宮代', '07', '07201', '9600116', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '宮代', 'ミヤシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道名寄市西2条南', '01', '01221', '0960012', '北海道', 'ホッカイドウ', '名寄市', 'ナヨロシ', '西2条南', 'ニシ02ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道名寄市西3条南', '01', '01221', '0960013', '北海道', 'ホッカイドウ', '名寄市', 'ナヨロシ', '西3条南', 'ニシ03ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道名寄市西4条南', '01', '01221', '0960014', '北海道', 'ホッカイドウ', '名寄市', 'ナヨロシ', '西4条南', 'ニシ04ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道名寄市西5条南', '01', '01221', '0960015', '北海道', 'ホッカイドウ', '名寄市', 'ナヨロシ', '西5条南', 'ニシ05ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道名寄市西6条南', '01', '01221', '0960016', '北海道', 'ホッカイドウ', '名寄市', 'ナヨロシ', '西6条南', 'ニシ06ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道名寄市西7条南', '01', '01221', '0960017', '北海道', 'ホッカイドウ', '名寄市', 'ナヨロシ', '西7条南', 'ニシ07ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道名寄市西8条南', '01', '01221', '0960018', '北海道', 'ホッカイドウ', '名寄市', 'ナヨロシ', '西8条南', 'ニシ08ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道名寄市西9条南', '01', '01221', '0960019', '北海道', 'ホッカイドウ', '名寄市', 'ナヨロシ', '西9条南', 'ニシ09ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道名寄市西10条南', '01', '01221', '0960020', '北海道', 'ホッカイドウ', '名寄市', 'ナヨロシ', '西10条南', 'ニシ10ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市飯坂町', '07', '07201', '9600201', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '飯坂町', 'イイザカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道名寄市西11条南', '01', '01221', '0960021', '北海道', 'ホッカイドウ', '名寄市', 'ナヨロシ', '西11条南', 'ニシ11ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市飯坂町湯野', '07', '07201', '9600211', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '飯坂町湯野', 'イイザカマチユノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道名寄市西12条南', '01', '01221', '0960022', '北海道', 'ホッカイドウ', '名寄市', 'ナヨロシ', '西12条南', 'ニシ12ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市飯坂町東湯野', '07', '07201', '9600221', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '飯坂町東湯野', 'イイザカマチヒガシユノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道名寄市西13条南', '01', '01221', '0960023', '北海道', 'ホッカイドウ', '名寄市', 'ナヨロシ', '西13条南', 'ニシ13ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市飯坂町平野', '07', '07201', '9600231', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '飯坂町平野', 'イイザカマチヒラノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道名寄市西14条南', '01', '01221', '0960024', '北海道', 'ホッカイドウ', '名寄市', 'ナヨロシ', '西14条南', 'ニシ14ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市笹谷', '07', '07201', '9600241', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '笹谷', 'ササヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道名寄市西15条南', '01', '01221', '0960025', '北海道', 'ホッカイドウ', '名寄市', 'ナヨロシ', '西15条南', 'ニシ15ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市大笹生', '07', '07201', '9600251', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '大笹生', 'オオザソウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市李平', '07', '07201', '9600252', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '李平', 'スモモダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市飯坂町中野', '07', '07201', '9600261', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '飯坂町中野', 'イイザカマチナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市飯坂町茂庭', '07', '07201', '9600271', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '飯坂町茂庭', 'イイザカマチモニワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道名寄市大通北', '01', '01221', '0960030', '北海道', 'ホッカイドウ', '名寄市', 'ナヨロシ', '大通北', 'オオドオリキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道名寄市西1条北', '01', '01221', '0960031', '北海道', 'ホッカイドウ', '名寄市', 'ナヨロシ', '西1条北', 'ニシ01ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道名寄市西2条北', '01', '01221', '0960032', '北海道', 'ホッカイドウ', '名寄市', 'ナヨロシ', '西2条北', 'ニシ02ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道名寄市西3条北', '01', '01221', '0960033', '北海道', 'ホッカイドウ', '名寄市', 'ナヨロシ', '西3条北', 'ニシ03ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道名寄市西4条北', '01', '01221', '0960034', '北海道', 'ホッカイドウ', '名寄市', 'ナヨロシ', '西4条北', 'ニシ04ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道名寄市西5条北', '01', '01221', '0960035', '北海道', 'ホッカイドウ', '名寄市', 'ナヨロシ', '西5条北', 'ニシ05ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道名寄市西6条北', '01', '01221', '0960036', '北海道', 'ホッカイドウ', '名寄市', 'ナヨロシ', '西6条北', 'ニシ06ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道名寄市西7条北', '01', '01221', '0960037', '北海道', 'ホッカイドウ', '名寄市', 'ナヨロシ', '西7条北', 'ニシ07ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道名寄市西8条北', '01', '01221', '0960038', '北海道', 'ホッカイドウ', '名寄市', 'ナヨロシ', '西8条北', 'ニシ08ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道名寄市西9条北', '01', '01221', '0960039', '北海道', 'ホッカイドウ', '名寄市', 'ナヨロシ', '西9条北', 'ニシ09ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道名寄市西10条北', '01', '01221', '0960040', '北海道', 'ホッカイドウ', '名寄市', 'ナヨロシ', '西10条北', 'ニシ10ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市下川原', '07', '07213', '9600401', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '下川原', 'シモカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市水抜', '07', '07213', '9600402', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '水抜', 'ミズヌキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市前川原', '07', '07213', '9600403', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '前川原', 'マエカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市原島', '07', '07213', '9600404', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '原島', 'ハラジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市一本木', '07', '07213', '9600405', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '一本木', 'イッポンギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市堂ノ内', '07', '07213', '9600406', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '堂ノ内', 'ドウノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市日照', '07', '07213', '9600407', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '日照', 'ヒデリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市岡沼', '07', '07213', '9600408', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '岡沼', 'オカヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道名寄市西11条北', '01', '01221', '0960041', '北海道', 'ホッカイドウ', '名寄市', 'ナヨロシ', '西11条北', 'ニシ11ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市梨子木町', '07', '07213', '9600411', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '梨子木町', 'ナシノキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市雪車町', '07', '07213', '9600412', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '雪車町', 'ソリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市宮前', '07', '07213', '9600413', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '宮前', 'ミヤマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市長岡', '07', '07213', '9600414', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '長岡', 'ナガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市右城', '07', '07213', '9600415', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '右城', 'ウシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市中畑', '07', '07213', '9600416', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '中畑', 'ナカハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市北畑', '07', '07213', '9600417', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '北畑', 'キタハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市岡前', '07', '07213', '9600418', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '岡前', 'オカマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市広前', '07', '07213', '9600419', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '広前', 'ヒロマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道名寄市西12条北', '01', '01221', '0960042', '北海道', 'ホッカイドウ', '名寄市', 'ナヨロシ', '西12条北', 'ニシ12ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市一本杉', '07', '07213', '9600421', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '一本杉', 'イッポンスギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市川原田', '07', '07213', '9600422', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '川原田', 'カワラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市荒町', '07', '07213', '9600423', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '荒町', 'アラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市姥ケ懐', '07', '07213', '9600424', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '姥ケ懐', 'ウバガフトコロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市姥川', '07', '07213', '9600425', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '姥川', 'ウバガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市坂ノ下', '07', '07213', '9600426', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '坂ノ下', 'サカノシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市鍛治屋川', '07', '07213', '9600427', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '鍛治屋川', 'カジヤガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市坂ノ上', '07', '07213', '9600428', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '坂ノ上', 'サカノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市塚畑', '07', '07213', '9600429', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '塚畑', 'ツカハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道名寄市西13条北', '01', '01221', '0960043', '北海道', 'ホッカイドウ', '名寄市', 'ナヨロシ', '西13条北', 'ニシ13ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市川原町', '07', '07213', '9600431', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '川原町', 'カワラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市長川原', '07', '07213', '9600432', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '長川原', 'ナガカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市上川原', '07', '07213', '9600433', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '上川原', 'カミカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市堰下', '07', '07213', '9600434', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '堰下', 'セキシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市堰上', '07', '07213', '9600435', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '堰上', 'セキウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市前田', '07', '07213', '9600436', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '前田', 'マエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市一本松', '07', '07213', '9600437', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '一本松', 'イッポンマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市雷田', '07', '07213', '9600438', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '雷田', 'ライデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市新町', '07', '07213', '9600441', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市菅田', '07', '07213', '9600442', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '菅田', 'スガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市諏訪西', '07', '07213', '9600443', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '諏訪西', 'スワニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市諏訪前', '07', '07213', '9600444', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '諏訪前', 'スワマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市神明前', '07', '07213', '9600445', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '神明前', 'シンメイマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市諏訪野', '07', '07213', '9600446', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '諏訪野', 'スワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市寺前', '07', '07213', '9600447', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '寺前', 'テラマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市屋敷間', '07', '07213', '9600448', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '屋敷間', 'ヤシキマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市下志和田', '07', '07213', '9600451', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '下志和田', 'シモシワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市中志和田', '07', '07213', '9600452', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '中志和田', 'ナカシワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市上志和田', '07', '07213', '9600453', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '上志和田', 'カミシワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市志和田前', '07', '07213', '9600454', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '志和田前', 'シワダマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市姥石', '07', '07213', '9600455', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '姥石', 'ウバイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市中道', '07', '07213', '9600456', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '中道', 'ナカミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市江向', '07', '07213', '9600457', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '江向', 'エムカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市扇田', '07', '07213', '9600458', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '扇田', 'オウギダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市片町', '07', '07213', '9600461', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '片町', 'カタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市本町', '07', '07213', '9600462', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '本町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市田町', '07', '07213', '9600463', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '田町', 'タマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市南堀', '07', '07213', '9600464', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '南堀', 'ミナミボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市久根妻', '07', '07213', '9600465', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '久根妻', 'クネツマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市根岸', '07', '07213', '9600466', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '根岸', 'ネギシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市舘ノ内', '07', '07213', '9600467', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '舘ノ内', 'タテノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市北後', '07', '07213', '9600468', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '北後', 'キタウシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市長町', '07', '07213', '9600471', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '長町', 'ナガマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市根田', '07', '07213', '9600472', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '根田', 'ネダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市沢田', '07', '07213', '9600473', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '沢田', 'サワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市沓形', '07', '07213', '9600474', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '沓形', 'クツガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市干供田', '07', '07213', '9600475', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '干供田', 'ホシクデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市鶴巻', '07', '07213', '9600476', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '鶴巻', 'ツルマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市柏木町', '07', '07213', '9600477', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '柏木町', 'カシワギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市細谷', '07', '07213', '9600478', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '細谷', 'ホソヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市野崎', '07', '07213', '9600479', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '野崎', 'ノザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市堀切端', '07', '07213', '9600481', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '堀切端', 'ホリキリハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市鶴田', '07', '07213', '9600482', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '鶴田', 'ツルタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市柳内', '07', '07213', '9600483', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '柳内', 'ヤナギウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市馬場口', '07', '07213', '9600484', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '馬場口', 'ババグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市篭田', '07', '07213', '9600485', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '篭田', 'カゴタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市六角', '07', '07213', '9600486', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '六角', 'ロッカク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市高田', '07', '07213', '9600487', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '高田', 'タカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市上台', '07', '07213', '9600488', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '上台', 'ウワダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市瀬戸場', '07', '07213', '9600489', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '瀬戸場', 'セトバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市伏黒', '07', '07213', '9600501', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '伏黒', 'フシグロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市箱崎', '07', '07213', '9600502', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '箱崎', 'ハコザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道名寄市東1条北', '01', '01221', '0960051', '北海道', 'ホッカイドウ', '名寄市', 'ナヨロシ', '東1条北', 'ヒガシ01ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道名寄市東2条北', '01', '01221', '0960052', '北海道', 'ホッカイドウ', '名寄市', 'ナヨロシ', '東2条北', 'ヒガシ02ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道名寄市東3条北', '01', '01221', '0960053', '北海道', 'ホッカイドウ', '名寄市', 'ナヨロシ', '東3条北', 'ヒガシ03ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道名寄市東4条北', '01', '01221', '0960054', '北海道', 'ホッカイドウ', '名寄市', 'ナヨロシ', '東4条北', 'ヒガシ04ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道名寄市東5条北', '01', '01221', '0960055', '北海道', 'ホッカイドウ', '名寄市', 'ナヨロシ', '東5条北', 'ヒガシ05ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道名寄市東6条北', '01', '01221', '0960056', '北海道', 'ホッカイドウ', '名寄市', 'ナヨロシ', '東6条北', 'ヒガシ06ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市', '07', '07213', '9600600', '福島県', 'フクシマケン', '伊達市', 'ダテシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('135662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市保原町栄町', '07', '07213', '9600601', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '保原町栄町', 'ホバラマチサカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市保原町久保', '07', '07213', '9600602', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '保原町久保', 'ホバラマチクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市保原町古町', '07', '07213', '9600603', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '保原町古町', 'ホバラマチフルマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市保原町元木', '07', '07213', '9600604', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '保原町元木', 'ホバラマチモトキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市保原町元町', '07', '07213', '9600605', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '保原町元町', 'ホバラマチモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市保原町鉄炮町', '07', '07213', '9600606', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '保原町鉄炮町', 'ホバラマチテッポウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市保原町10丁目', '07', '07213', '9600607', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '保原町10丁目', 'ホバラマチ10チョウメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市保原町11丁目', '07', '07213', '9600608', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '保原町11丁目', 'ホバラマチ11チョウメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市保原町12丁目', '07', '07213', '9600609', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '保原町12丁目', 'ホバラマチ12チョウメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道名寄市朝日', '01', '01221', '0960061', '北海道', 'ホッカイドウ', '名寄市', 'ナヨロシ', '朝日', 'アサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市保原町城ノ内', '07', '07213', '9600611', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '保原町城ノ内', 'ホバラマチシロノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市保原町宮下', '07', '07213', '9600612', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '保原町宮下', 'ホバラマチミヤシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市保原町内町', '07', '07213', '9600613', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '保原町内町', 'ホバラマチウチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市保原町磐前通', '07', '07213', '9600614', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '保原町磐前通', 'ホバラマチイワマエドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市保原町5丁目', '07', '07213', '9600615', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '保原町5丁目', 'ホバラマチ05チョウメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市保原町6丁目', '07', '07213', '9600616', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '保原町6丁目', 'ホバラマチ06チョウメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市保原町7丁目', '07', '07213', '9600617', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '保原町7丁目', 'ホバラマチ07チョウメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市保原町8丁目', '07', '07213', '9600618', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '保原町8丁目', 'ホバラマチ08チョウメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市保原町9丁目', '07', '07213', '9600619', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '保原町9丁目', 'ホバラマチ09チョウメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道名寄市日彰', '01', '01221', '0960062', '北海道', 'ホッカイドウ', '名寄市', 'ナヨロシ', '日彰', 'ニッショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市保原町中村町', '07', '07213', '9600621', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '保原町中村町', 'ホバラマチナカムラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市保原町市柳町', '07', '07213', '9600622', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '保原町市柳町', 'ホバラマチイチヤナギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市保原町前田町', '07', '07213', '9600623', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '保原町前田町', 'ホバラマチマエダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市保原町1丁目', '07', '07213', '9600624', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '保原町1丁目', 'ホバラマチ01チョウメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市保原町2丁目', '07', '07213', '9600625', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '保原町2丁目', 'ホバラマチ02チョウメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市保原町3丁目', '07', '07213', '9600626', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '保原町3丁目', 'ホバラマチ03チョウメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市保原町4丁目', '07', '07213', '9600627', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '保原町4丁目', 'ホバラマチ04チョウメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市保原町実町', '07', '07213', '9600628', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '保原町実町', 'ホバラマチミノルマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市保原町弥生町', '07', '07213', '9600629', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '保原町弥生町', 'ホバラマチヤヨイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道名寄市緑丘', '01', '01221', '0960063', '北海道', 'ホッカイドウ', '名寄市', 'ナヨロシ', '緑丘', 'ミドリオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市保原町中瀬', '07', '07213', '9600631', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '保原町中瀬', 'ホバラマチナカゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市保原町大立目', '07', '07213', '9600632', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '保原町大立目', 'ホバラマチオオダツメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市保原町二井田', '07', '07213', '9600633', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '保原町二井田', 'ホバラマチニイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市保原町大泉', '07', '07213', '9600634', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '保原町大泉', 'ホバラマチオオイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市保原町半道', '07', '07213', '9600635', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '保原町半道', 'ホバラマチハンドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市保原町大和', '07', '07213', '9600636', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '保原町大和', 'ホバラマチヤマト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市保原町将監', '07', '07213', '9600637', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '保原町将監', 'ホバラマチショウカン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市保原町北河原', '07', '07213', '9600638', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '保原町北河原', 'ホバラマチキタカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市保原町六万坊', '07', '07213', '9600639', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '保原町六万坊', 'ホバラマチロクマンボウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道名寄市旭東', '01', '01221', '0960064', '北海道', 'ホッカイドウ', '名寄市', 'ナヨロシ', '旭東', 'キョクトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市保原町西猫川', '07', '07213', '9600641', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '保原町西猫川', 'ホバラマチニシネコガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市保原町東猫川', '07', '07213', '9600642', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '保原町東猫川', 'ホバラマチヒガシネコガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市保原町下河原', '07', '07213', '9600643', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '保原町下河原', 'ホバラマチシモカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市保原町豊田', '07', '07213', '9600644', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '保原町豊田', 'ホバラマチトヨタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市保原町豊町', '07', '07213', '9600644', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '保原町豊町', 'ホバラマチユタカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市保原町台後', '07', '07213', '9600645', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '保原町台後', 'ホバラマチダイゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市保原町東台後', '07', '07213', '9600646', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '保原町東台後', 'ホバラマチヒガシダイゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市保原町小蓋', '07', '07213', '9600647', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '保原町小蓋', 'ホバラマチコブタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市保原町東小蓋', '07', '07213', '9600648', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '保原町東小蓋', 'ホバラマチヒガシコブタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市保原町清水町', '07', '07213', '9600649', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '保原町清水町', 'ホバラマチシミズマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道名寄市大橋', '01', '01221', '0960065', '北海道', 'ホッカイドウ', '名寄市', 'ナヨロシ', '大橋', 'オオハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市保原町西新田', '07', '07213', '9600650', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '保原町西新田', 'ホバラマチニシシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市保原町柏町', '07', '07213', '9600651', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '保原町柏町', 'ホバラマチカシワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市保原町西町', '07', '07213', '9600652', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '保原町西町', 'ホバラマチニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市保原町泉町', '07', '07213', '9600653', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '保原町泉町', 'ホバラマチイズミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市保原町小幡町', '07', '07213', '9600654', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '保原町小幡町', 'ホバラマチオバタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市保原町宮内町', '07', '07213', '9600655', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '保原町宮内町', 'ホバラマチミヤウチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市保原町八幡町', '07', '07213', '9600656', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '保原町八幡町', 'ホバラマチヤハタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市保原町中瀬町', '07', '07213', '9600657', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '保原町中瀬町', 'ホバラマチナカゼマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市保原町古川端', '07', '07213', '9600658', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '保原町古川端', 'ホバラマチフルカワバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市保原町西ノ内', '07', '07213', '9600659', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '保原町西ノ内', 'ホバラマチニシノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道名寄市日進', '01', '01221', '0960066', '北海道', 'ホッカイドウ', '名寄市', 'ナヨロシ', '日進', 'ニッシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市保原町金原田', '07', '07213', '9600661', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '保原町金原田', 'ホバラマチカナハラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市保原町柱田', '07', '07213', '9600662', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '保原町柱田', 'ホバラマチハシラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市保原町舟橋', '07', '07213', '9600663', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '保原町舟橋', 'ホバラマチフナバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市保原町太田中', '07', '07213', '9600664', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '保原町太田中', 'ホバラマチオオタナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市保原町岡代', '07', '07213', '9600665', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '保原町岡代', 'ホバラマチオカシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市保原町村岡', '07', '07213', '9600666', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '保原町村岡', 'ホバラマチムラオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市保原町八幡台', '07', '07213', '9600667', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '保原町八幡台', 'ホバラマチハチマンダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市保原町烏内', '07', '07213', '9600668', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '保原町烏内', 'ホバラマチカラスウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市保原町赤橋', '07', '07213', '9600669', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '保原町赤橋', 'ホバラマチアカバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市保原町東野崎', '07', '07213', '9600671', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '保原町東野崎', 'ホバラマチヒガシノザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市保原町下野崎', '07', '07213', '9600672', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '保原町下野崎', 'ホバラマチシモノザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市保原町野崎', '07', '07213', '9600673', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '保原町野崎', 'ホバラマチノザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市保原町上野崎', '07', '07213', '9600674', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '保原町上野崎', 'ホバラマチカミノザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市保原町大柳', '07', '07213', '9600675', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '保原町大柳', 'ホバラマチオオヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市保原町千刈', '07', '07213', '9600676', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '保原町千刈', 'ホバラマチセンガリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市保原町早稲田', '07', '07213', '9600677', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '保原町早稲田', 'ホバラマチワセダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市保原町京門', '07', '07213', '9600678', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '保原町京門', 'ホバラマチキョウモン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市保原町油谷地', '07', '07213', '9600679', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '保原町油谷地', 'ホバラマチアブラヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市保原町所沢', '07', '07213', '9600681', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '保原町所沢', 'ホバラマチトコロザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市保原町富沢', '07', '07213', '9600682', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '保原町富沢', 'ホバラマチトミザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市保原町高成田', '07', '07213', '9600683', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '保原町高成田', 'ホバラマチタカナリタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市保原町上保原', '07', '07213', '9600684', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '保原町上保原', 'ホバラマチカミホバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市保原町黄金町', '07', '07213', '9600685', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '保原町黄金町', 'ホバラマチコガネマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市保原町竹内町', '07', '07213', '9600686', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '保原町竹内町', 'ホバラマチタケウチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市保原町旭町', '07', '07213', '9600687', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '保原町旭町', 'ホバラマチアサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市保原町みずほ', '07', '07213', '9600688', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '保原町みずほ', 'ホバラマチミズホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市梁川町五十沢', '07', '07213', '9600701', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '梁川町五十沢', 'ヤナガワマチイサザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市梁川町東大枝', '07', '07213', '9600702', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '梁川町東大枝', 'ヤナガワマチヒガシオオエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市梁川町山舟生', '07', '07213', '9600703', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '梁川町山舟生', 'ヤナガワマチヤマフニュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市梁川町舟生', '07', '07213', '9600704', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '梁川町舟生', 'ヤナガワマチフニュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市梁川町元舟場', '07', '07213', '9600705', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '梁川町元舟場', 'ヤナガワマチモトフナバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市梁川町北町谷川', '07', '07213', '9600706', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '梁川町北町谷川', 'ヤナガワマチキタマチヤガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市梁川町南町谷川', '07', '07213', '9600707', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '梁川町南町谷川', 'ヤナガワマチミナミマチヤガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市梁川町東塩野川', '07', '07213', '9600708', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '梁川町東塩野川', 'ヤナガワマチヒガシシオノガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市梁川町西塩野川', '07', '07213', '9600709', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '梁川町西塩野川', 'ヤナガワマチニシシオノガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道名寄市徳田', '01', '01221', '0960071', '北海道', 'ホッカイドウ', '名寄市', 'ナヨロシ', '徳田', 'トクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市梁川町粟野', '07', '07213', '9600711', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '梁川町粟野', 'ヤナガワマチアワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市梁川町下川原', '07', '07213', '9600711', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '梁川町下川原', 'ヤナガワマチシモガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市梁川町御八郎', '07', '07213', '9600712', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '梁川町御八郎', 'ヤナガワマチオハチロウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市梁川町八筋', '07', '07213', '9600713', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '梁川町八筋', 'ヤナガワマチヤスジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市梁川町大舘', '07', '07213', '9600715', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '梁川町大舘', 'ヤナガワマチオオダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市梁川町白川田', '07', '07213', '9600716', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '梁川町白川田', 'ヤナガワマチシラカワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市梁川町向川原', '07', '07213', '9600717', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '梁川町向川原', 'ヤナガワマチムコウガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市梁川町二野袋', '07', '07213', '9600718', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '梁川町二野袋', 'ヤナガワマチニノフクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市梁川町やながわ工業団地', '07', '07213', '9600719', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '梁川町やながわ工業団地', 'ヤナガワマチヤナガワコウギョウダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道名寄市豊栄', '01', '01221', '0960072', '北海道', 'ホッカイドウ', '名寄市', 'ナヨロシ', '豊栄', 'ホウエイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市梁川町白根', '07', '07213', '9600721', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '梁川町白根', 'ヤナガワマチシラネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市梁川町八幡', '07', '07213', '9600722', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '梁川町八幡', 'ヤナガワマチヤワタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市梁川町足駄木', '07', '07213', '9600723', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '梁川町足駄木', 'ヤナガワマチアシナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市梁川町内山', '07', '07213', '9600723', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '梁川町内山', 'ヤナガワマチウチヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市梁川町上足駄木', '07', '07213', '9600723', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '梁川町上足駄木', 'ヤナガワマチカミアシナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市梁川町里見山', '07', '07213', '9600723', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '梁川町里見山', 'ヤナガワマチサトミヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市梁川町北新井', '07', '07213', '9600724', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '梁川町北新井', 'ヤナガワマチキタアライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市梁川町赤五輪', '07', '07213', '9600725', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '梁川町赤五輪', 'ヤナガワマチアカゴリン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市梁川町北町頭', '07', '07213', '9600726', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '梁川町北町頭', 'ヤナガワマチキタマチガシラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市梁川町上町', '07', '07213', '9600727', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '梁川町上町', 'ヤナガワマチウワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市梁川町天神前', '07', '07213', '9600728', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '梁川町天神前', 'ヤナガワマチテンジンマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市梁川町希望ケ丘', '07', '07213', '9600729', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '梁川町希望ケ丘', 'ヤナガワマチキボウガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道名寄市共和', '01', '01221', '0960073', '北海道', 'ホッカイドウ', '名寄市', 'ナヨロシ', '共和', 'キョウワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市梁川町天神町', '07', '07213', '9600731', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '梁川町天神町', 'ヤナガワマチテンジンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市梁川町南町頭', '07', '07213', '9600732', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '梁川町南町頭', 'ヤナガワマチミナミマチガシラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市梁川町菖蒲沢', '07', '07213', '9600733', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '梁川町菖蒲沢', 'ヤナガワマチショウブサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市梁川町茶臼山', '07', '07213', '9600734', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '梁川町茶臼山', 'ヤナガワマチチャウスヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市梁川町鶴ケ岡', '07', '07213', '9600735', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '梁川町鶴ケ岡', 'ヤナガワマチツルガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市梁川町桜岳', '07', '07213', '9600736', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '梁川町桜岳', 'ヤナガワマチサクラガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道名寄市弥生', '01', '01221', '0960074', '北海道', 'ホッカイドウ', '名寄市', 'ナヨロシ', '弥生', 'ヤヨイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市梁川町大町', '07', '07213', '9600741', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '梁川町大町', 'ヤナガワマチオオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市梁川町清水町', '07', '07213', '9600742', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '梁川町清水町', 'ヤナガワマチシミズマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市梁川町元陣内', '07', '07213', '9600743', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '梁川町元陣内', 'ヤナガワマチモトジンナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市梁川町内町', '07', '07213', '9600744', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '梁川町内町', 'ヤナガワマチウチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市梁川町右城町', '07', '07213', '9600745', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '梁川町右城町', 'ヤナガワマチウシロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市梁川町大清水', '07', '07213', '9600746', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '梁川町大清水', 'ヤナガワマチオオシミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市梁川町町裏', '07', '07213', '9600747', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '梁川町町裏', 'ヤナガワマチマチウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道名寄市曙', '01', '01221', '0960075', '北海道', 'ホッカイドウ', '名寄市', 'ナヨロシ', '曙', 'アケボノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市梁川町古町', '07', '07213', '9600751', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '梁川町古町', 'ヤナガワマチフルマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市梁川町四日市', '07', '07213', '9600752', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '梁川町四日市', 'ヤナガワマチヨッカイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市梁川町上川原', '07', '07213', '9600753', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '梁川町上川原', 'ヤナガワマチカミガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市梁川町栄町', '07', '07213', '9600754', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '梁川町栄町', 'ヤナガワマチサカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市梁川町中久保', '07', '07213', '9600755', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '梁川町中久保', 'ヤナガワマチナカクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市梁川町青葉町', '07', '07213', '9600756', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '梁川町青葉町', 'ヤナガワマチアオバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市梁川町幸町', '07', '07213', '9600757', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '梁川町幸町', 'ヤナガワマチサイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市梁川町桜町', '07', '07213', '9600758', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '梁川町桜町', 'ヤナガワマチサクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市梁川町広瀬町', '07', '07213', '9600759', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '梁川町広瀬町', 'ヤナガワマチヒロセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道名寄市砺波', '01', '01221', '0960076', '北海道', 'ホッカイドウ', '名寄市', 'ナヨロシ', '砺波', 'トナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市梁川町陽光台', '07', '07213', '9600760', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '梁川町陽光台', 'ヤナガワマチヨウコウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市梁川町丹波塚', '07', '07213', '9600762', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '梁川町丹波塚', 'ヤナガワマチタンバヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市梁川町大門道', '07', '07213', '9600763', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '梁川町大門道', 'ヤナガワマチダイモンミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市梁川町壱丁田', '07', '07213', '9600764', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '梁川町壱丁田', 'ヤナガワマチイッチョウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市梁川町大関', '07', '07213', '9600765', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '梁川町大関', 'ヤナガワマチオオゼキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市梁川町細谷', '07', '07213', '9600766', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '梁川町細谷', 'ヤナガワマチホソヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市梁川町新田', '07', '07213', '9600767', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '梁川町新田', 'ヤナガワマチニッタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市梁川町柳田', '07', '07213', '9600768', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '梁川町柳田', 'ヤナガワマチヤナギダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市梁川町舟橋', '07', '07213', '9600769', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '梁川町舟橋', 'ヤナガワマチフナバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道名寄市瑞穂', '01', '01221', '0960077', '北海道', 'ホッカイドウ', '名寄市', 'ナヨロシ', '瑞穂', 'ミズホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市梁川町上割田', '07', '07213', '9600772', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '梁川町上割田', 'ヤナガワマチカミワリダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市梁川町五反田', '07', '07213', '9600773', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '梁川町五反田', 'ヤナガワマチゴタンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市梁川町石井戸', '07', '07213', '9600774', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '梁川町石井戸', 'ヤナガワマチイシイド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市梁川町四石蒔', '07', '07213', '9600775', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '梁川町四石蒔', 'ヤナガワマチシコクマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市梁川町東土橋', '07', '07213', '9600776', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '梁川町東土橋', 'ヤナガワマチヒガシドバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市梁川町西土橋', '07', '07213', '9600777', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '梁川町西土橋', 'ヤナガワマチニシドバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市梁川町伝樋', '07', '07213', '9600778', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '梁川町伝樋', 'ヤナガワマチデンピ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道名寄市内淵', '01', '01221', '0960078', '北海道', 'ホッカイドウ', '名寄市', 'ナヨロシ', '内淵', 'ナイブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市梁川町北本町', '07', '07213', '9600781', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '梁川町北本町', 'ヤナガワマチキタモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市梁川町中町', '07', '07213', '9600782', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '梁川町中町', 'ヤナガワマチナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市梁川町本町', '07', '07213', '9600783', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '梁川町本町', 'ヤナガワマチモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市梁川町田町', '07', '07213', '9600784', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '梁川町田町', 'ヤナガワマチタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市梁川町小梁川', '07', '07213', '9600785', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '梁川町小梁川', 'ヤナガワマチコヤナガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市梁川町南本町', '07', '07213', '9600786', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '梁川町南本町', 'ヤナガワマチミナミモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市梁川町山城舘', '07', '07213', '9600787', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '梁川町山城舘', 'ヤナガワマチヤマシロダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市霊山町掛田', '07', '07213', '9600801', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '霊山町掛田', 'リョウゼンマチカケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市霊山町山野川', '07', '07213', '9600802', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '霊山町山野川', 'リョウゼンマチヤマノガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市霊山町泉原', '07', '07213', '9600803', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '霊山町泉原', 'リョウゼンマチイズミハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市霊山町大石', '07', '07213', '9600804', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '霊山町大石', 'リョウゼンマチオオイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市霊山町中川', '07', '07213', '9600805', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '霊山町中川', 'リョウゼンマチナカガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市霊山町山戸田', '07', '07213', '9600806', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '霊山町山戸田', 'リョウゼンマチヤマトダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市霊山町石田', '07', '07213', '9600807', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '霊山町石田', 'リョウゼンマチイシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市霊山町下小国', '07', '07213', '9600808', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '霊山町下小国', 'リョウゼンマチシモオグニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市霊山町上小国', '07', '07213', '9600809', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '霊山町上小国', 'リョウゼンマチカミオグニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市大波', '07', '07201', '9600811', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '大波', 'オオナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市月舘町布川', '07', '07213', '9600901', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '月舘町布川', 'ツキダテマチヌノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市月舘町月舘', '07', '07213', '9600902', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '月舘町月舘', 'ツキダテマチツキダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市月舘町下手渡', '07', '07213', '9600903', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '月舘町下手渡', 'ツキダテマチシモテド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市月舘町上手渡', '07', '07213', '9600904', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '月舘町上手渡', 'ツキダテマチカミテド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市月舘町糠田', '07', '07213', '9600905', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '月舘町糠田', 'ツキダテマチヌカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達市月舘町御代田', '07', '07213', '9600906', '福島県', 'フクシマケン', '伊達市', 'ダテシ', '月舘町御代田', 'ツキダテマチミヨダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市大森', '07', '07201', '9601101', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '大森', 'オオモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市永井川', '07', '07201', '9601102', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '永井川', 'ナガイカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市平石', '07', '07201', '9601103', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '平石', 'ヒライシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市小田', '07', '07201', '9601104', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '小田', 'オダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市山田', '07', '07201', '9601105', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '山田', 'ヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市下鳥渡', '07', '07201', '9601106', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '下鳥渡', 'シモトリワタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市上鳥渡', '07', '07201', '9601107', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '上鳥渡', 'カミトリワタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市成川', '07', '07201', '9601108', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '成川', 'ナリカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市松川町沼袋', '07', '07201', '9601231', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '松川町沼袋', 'マツカワマチヌマブクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市松川町下川崎', '07', '07201', '9601232', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '松川町下川崎', 'マツカワマチシモカワサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市松川町', '07', '07201', '9601241', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '松川町', 'マツカワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市松川町美郷', '07', '07201', '9601242', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '松川町美郷', 'マツカワマチミサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市松川町水原', '07', '07201', '9601243', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '松川町水原', 'マツカワマチミズハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市松川町関谷', '07', '07201', '9601244', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '松川町関谷', 'マツカワマチセキヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市松川町浅川', '07', '07201', '9601245', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '松川町浅川', 'マツカワマチアサカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市松川町金沢', '07', '07201', '9601246', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '松川町金沢', 'マツカワマチカネザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市光が丘', '07', '07201', '9601247', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '光が丘', 'ヒカリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市金谷川', '07', '07201', '9601248', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '金谷川', 'カナヤガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市飯野町', '07', '07201', '9601301', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '飯野町', 'イイノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市飯野町明治', '07', '07201', '9601302', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '飯野町明治', 'イイノマチメイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市飯野町青木', '07', '07201', '9601303', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '飯野町青木', 'イイノマチアオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市飯野町大久保', '07', '07201', '9601304', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '飯野町大久保', 'イイノマチオオクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市立子山', '07', '07201', '9601321', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '立子山', 'タツゴヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡川俣町', '07', '07308', '9601400', '福島県', 'フクシマケン', '伊達郡川俣町', 'ダテグンカワマタマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('135890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡川俣町飯坂', '07', '07308', '9601401', '福島県', 'フクシマケン', '伊達郡川俣町', 'ダテグンカワマタマチ', '飯坂', 'イイザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡川俣町小綱木', '07', '07308', '9601402', '福島県', 'フクシマケン', '伊達郡川俣町', 'ダテグンカワマタマチ', '小綱木', 'コツナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡川俣町大綱木', '07', '07308', '9601403', '福島県', 'フクシマケン', '伊達郡川俣町', 'ダテグンカワマタマチ', '大綱木', 'オオツナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡川俣町西福沢', '07', '07308', '9601404', '福島県', 'フクシマケン', '伊達郡川俣町', 'ダテグンカワマタマチ', '西福沢', 'ニシフクザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡川俣町東福沢', '07', '07308', '9601405', '福島県', 'フクシマケン', '伊達郡川俣町', 'ダテグンカワマタマチ', '東福沢', 'ヒガシフクザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡川俣町鶴沢', '07', '07308', '9601406', '福島県', 'フクシマケン', '伊達郡川俣町', 'ダテグンカワマタマチ', '鶴沢', 'ツルサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡川俣町小神', '07', '07308', '9601407', '福島県', 'フクシマケン', '伊達郡川俣町', 'ダテグンカワマタマチ', '小神', 'コガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡川俣町羽田', '07', '07308', '9601408', '福島県', 'フクシマケン', '伊達郡川俣町', 'ダテグンカワマタマチ', '羽田', 'ハネダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡川俣町秋山', '07', '07308', '9601409', '福島県', 'フクシマケン', '伊達郡川俣町', 'ダテグンカワマタマチ', '秋山', 'アキヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡川俣町細田', '07', '07308', '9601411', '福島県', 'フクシマケン', '伊達郡川俣町', 'ダテグンカワマタマチ', '細田', 'ホソダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡川俣町仲ノ内', '07', '07308', '9601412', '福島県', 'フクシマケン', '伊達郡川俣町', 'ダテグンカワマタマチ', '仲ノ内', 'ナカノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡川俣町広畑', '07', '07308', '9601413', '福島県', 'フクシマケン', '伊達郡川俣町', 'ダテグンカワマタマチ', '広畑', 'ヒロハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡川俣町上桜', '07', '07308', '9601414', '福島県', 'フクシマケン', '伊達郡川俣町', 'ダテグンカワマタマチ', '上桜', 'ウエザクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡川俣町仁井町', '07', '07308', '9601415', '福島県', 'フクシマケン', '伊達郡川俣町', 'ダテグンカワマタマチ', '仁井町', 'ニイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡川俣町舘ノ腰', '07', '07308', '9601416', '福島県', 'フクシマケン', '伊達郡川俣町', 'ダテグンカワマタマチ', '舘ノ腰', 'タテノコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡川俣町橋本', '07', '07308', '9601417', '福島県', 'フクシマケン', '伊達郡川俣町', 'ダテグンカワマタマチ', '橋本', 'ハシモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡川俣町鉄炮町', '07', '07308', '9601421', '福島県', 'フクシマケン', '伊達郡川俣町', 'ダテグンカワマタマチ', '鉄炮町', 'テッポウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡川俣町新中町', '07', '07308', '9601422', '福島県', 'フクシマケン', '伊達郡川俣町', 'ダテグンカワマタマチ', '新中町', 'シンナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡川俣町池ノ入', '07', '07308', '9601423', '福島県', 'フクシマケン', '伊達郡川俣町', 'ダテグンカワマタマチ', '池ノ入', 'イケノイリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡川俣町寺久保', '07', '07308', '9601424', '福島県', 'フクシマケン', '伊達郡川俣町', 'ダテグンカワマタマチ', '寺久保', 'テラクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡川俣町新宮', '07', '07308', '9601425', '福島県', 'フクシマケン', '伊達郡川俣町', 'ダテグンカワマタマチ', '新宮', 'シンミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡川俣町日和田', '07', '07308', '9601426', '福島県', 'フクシマケン', '伊達郡川俣町', 'ダテグンカワマタマチ', '日和田', 'ヒワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡川俣町段ノ腰', '07', '07308', '9601427', '福島県', 'フクシマケン', '伊達郡川俣町', 'ダテグンカワマタマチ', '段ノ腰', 'ダンノコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡川俣町五百田', '07', '07308', '9601428', '福島県', 'フクシマケン', '伊達郡川俣町', 'ダテグンカワマタマチ', '五百田', 'ゴヒャクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡川俣町柏崎', '07', '07308', '9601429', '福島県', 'フクシマケン', '伊達郡川俣町', 'ダテグンカワマタマチ', '柏崎', 'カシワザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡川俣町大清水', '07', '07308', '9601431', '福島県', 'フクシマケン', '伊達郡川俣町', 'ダテグンカワマタマチ', '大清水', 'オオシミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡川俣町東大清水', '07', '07308', '9601432', '福島県', 'フクシマケン', '伊達郡川俣町', 'ダテグンカワマタマチ', '東大清水', 'ヒガシオオシミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡川俣町賤ノ田', '07', '07308', '9601433', '福島県', 'フクシマケン', '伊達郡川俣町', 'ダテグンカワマタマチ', '賤ノ田', 'シツノタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡川俣町小作', '07', '07308', '9601434', '福島県', 'フクシマケン', '伊達郡川俣町', 'ダテグンカワマタマチ', '小作', 'コサク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡川俣町大作', '07', '07308', '9601435', '福島県', 'フクシマケン', '伊達郡川俣町', 'ダテグンカワマタマチ', '大作', 'オオサク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡川俣町川原田', '07', '07308', '9601436', '福島県', 'フクシマケン', '伊達郡川俣町', 'ダテグンカワマタマチ', '川原田', 'カワハラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡川俣町道内', '07', '07308', '9601441', '福島県', 'フクシマケン', '伊達郡川俣町', 'ダテグンカワマタマチ', '道内', 'ミチウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡川俣町後庵', '07', '07308', '9601442', '福島県', 'フクシマケン', '伊達郡川俣町', 'ダテグンカワマタマチ', '後庵', 'ゴアン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡川俣町大内', '07', '07308', '9601443', '福島県', 'フクシマケン', '伊達郡川俣町', 'ダテグンカワマタマチ', '大内', 'オオウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡川俣町根本', '07', '07308', '9601444', '福島県', 'フクシマケン', '伊達郡川俣町', 'ダテグンカワマタマチ', '根本', 'ネモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡川俣町中島', '07', '07308', '9601445', '福島県', 'フクシマケン', '伊達郡川俣町', 'ダテグンカワマタマチ', '中島', 'ナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡川俣町舘', '07', '07308', '9601446', '福島県', 'フクシマケン', '伊達郡川俣町', 'ダテグンカワマタマチ', '舘', 'タテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡川俣町本町', '07', '07308', '9601451', '福島県', 'フクシマケン', '伊達郡川俣町', 'ダテグンカワマタマチ', '本町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡川俣町後田', '07', '07308', '9601452', '福島県', 'フクシマケン', '伊達郡川俣町', 'ダテグンカワマタマチ', '後田', 'ウシロダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡川俣町瓦町', '07', '07308', '9601453', '福島県', 'フクシマケン', '伊達郡川俣町', 'ダテグンカワマタマチ', '瓦町', 'カワラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡川俣町八反田', '07', '07308', '9601454', '福島県', 'フクシマケン', '伊達郡川俣町', 'ダテグンカワマタマチ', '八反田', 'ハッタンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡川俣町竹ノ内', '07', '07308', '9601455', '福島県', 'フクシマケン', '伊達郡川俣町', 'ダテグンカワマタマチ', '竹ノ内', 'タケノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡川俣町中丁', '07', '07308', '9601456', '福島県', 'フクシマケン', '伊達郡川俣町', 'ダテグンカワマタマチ', '中丁', 'ナカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡川俣町宮町', '07', '07308', '9601461', '福島県', 'フクシマケン', '伊達郡川俣町', 'ダテグンカワマタマチ', '宮町', 'ミヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡川俣町寺前', '07', '07308', '9601462', '福島県', 'フクシマケン', '伊達郡川俣町', 'ダテグンカワマタマチ', '寺前', 'テラマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡川俣町樋ノ口', '07', '07308', '9601463', '福島県', 'フクシマケン', '伊達郡川俣町', 'ダテグンカワマタマチ', '樋ノ口', 'トイノクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡川俣町宮ノ脇', '07', '07308', '9601464', '福島県', 'フクシマケン', '伊達郡川俣町', 'ダテグンカワマタマチ', '宮ノ脇', 'ミヤノワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡川俣町赤坂', '07', '07308', '9601465', '福島県', 'フクシマケン', '伊達郡川俣町', 'ダテグンカワマタマチ', '赤坂', 'アカサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡川俣町宮前', '07', '07308', '9601466', '福島県', 'フクシマケン', '伊達郡川俣町', 'ダテグンカワマタマチ', '宮前', 'ミヤマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡川俣町宮ノ入', '07', '07308', '9601467', '福島県', 'フクシマケン', '伊達郡川俣町', 'ダテグンカワマタマチ', '宮ノ入', 'ミヤノイリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡川俣町天神入', '07', '07308', '9601468', '福島県', 'フクシマケン', '伊達郡川俣町', 'ダテグンカワマタマチ', '天神入', 'テンジンイリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡川俣町道場', '07', '07308', '9601469', '福島県', 'フクシマケン', '伊達郡川俣町', 'ダテグンカワマタマチ', '道場', 'ドウジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡川俣町西戸ノ内', '07', '07308', '9601471', '福島県', 'フクシマケン', '伊達郡川俣町', 'ダテグンカワマタマチ', '西戸ノ内', 'ニシトノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡川俣町草ケ入', '07', '07308', '9601472', '福島県', 'フクシマケン', '伊達郡川俣町', 'ダテグンカワマタマチ', '草ケ入', 'クサガイリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡川俣町桜ケ作', '07', '07308', '9601473', '福島県', 'フクシマケン', '伊達郡川俣町', 'ダテグンカワマタマチ', '桜ケ作', 'サクラガサク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡川俣町七曲', '07', '07308', '9601474', '福島県', 'フクシマケン', '伊達郡川俣町', 'ダテグンカワマタマチ', '七曲', 'ナナマガリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡川俣町早坂', '07', '07308', '9601475', '福島県', 'フクシマケン', '伊達郡川俣町', 'ダテグンカワマタマチ', '早坂', 'ハヤサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡川俣町石川', '07', '07308', '9601476', '福島県', 'フクシマケン', '伊達郡川俣町', 'ダテグンカワマタマチ', '石川', 'イシカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡川俣町倉ケ作', '07', '07308', '9601477', '福島県', 'フクシマケン', '伊達郡川俣町', 'ダテグンカワマタマチ', '倉ケ作', 'クラガサク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡川俣町壁沢', '07', '07308', '9601478', '福島県', 'フクシマケン', '伊達郡川俣町', 'ダテグンカワマタマチ', '壁沢', 'カベサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡川俣町七窪', '07', '07308', '9601481', '福島県', 'フクシマケン', '伊達郡川俣町', 'ダテグンカワマタマチ', '七窪', 'ナナクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡川俣町元屋敷', '07', '07308', '9601482', '福島県', 'フクシマケン', '伊達郡川俣町', 'ダテグンカワマタマチ', '元屋敷', 'モトヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡川俣町壺ケ作', '07', '07308', '9601483', '福島県', 'フクシマケン', '伊達郡川俣町', 'ダテグンカワマタマチ', '壺ケ作', 'ツボガサク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡川俣町延命神', '07', '07308', '9601484', '福島県', 'フクシマケン', '伊達郡川俣町', 'ダテグンカワマタマチ', '延命神', 'エンメイジン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡川俣町海老ケ作', '07', '07308', '9601485', '福島県', 'フクシマケン', '伊達郡川俣町', 'ダテグンカワマタマチ', '海老ケ作', 'エビガサク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡川俣町下拍子', '07', '07308', '9601486', '福島県', 'フクシマケン', '伊達郡川俣町', 'ダテグンカワマタマチ', '下拍子', 'シタビョウシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡川俣町三百田', '07', '07308', '9601487', '福島県', 'フクシマケン', '伊達郡川俣町', 'ダテグンカワマタマチ', '三百田', 'サンビャクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡川俣町新田', '07', '07308', '9601488', '福島県', 'フクシマケン', '伊達郡川俣町', 'ダテグンカワマタマチ', '新田', 'シンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡川俣町小島', '07', '07308', '9601489', '福島県', 'フクシマケン', '伊達郡川俣町', 'ダテグンカワマタマチ', '小島', 'オジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡川俣町山木屋', '07', '07308', '9601501', '福島県', 'フクシマケン', '伊達郡川俣町', 'ダテグンカワマタマチ', '山木屋', 'ヤマキヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県相馬郡飯舘村', '07', '07564', '9601600', '福島県', 'フクシマケン', '相馬郡飯舘村', 'ソウマグンイイタテムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('135962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県相馬郡飯舘村松塚', '07', '07564', '9601631', '福島県', 'フクシマケン', '相馬郡飯舘村', 'ソウマグンイイタテムラ', '松塚', 'マツヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県相馬郡飯舘村関根', '07', '07564', '9601632', '福島県', 'フクシマケン', '相馬郡飯舘村', 'ソウマグンイイタテムラ', '関根', 'セキネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県相馬郡飯舘村臼石', '07', '07564', '9601633', '福島県', 'フクシマケン', '相馬郡飯舘村', 'ソウマグンイイタテムラ', '臼石', 'ウスイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県相馬郡飯舘村二枚橋', '07', '07564', '9601634', '福島県', 'フクシマケン', '相馬郡飯舘村', 'ソウマグンイイタテムラ', '二枚橋', 'ニマイバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県相馬郡飯舘村須萱', '07', '07564', '9601635', '福島県', 'フクシマケン', '相馬郡飯舘村', 'ソウマグンイイタテムラ', '須萱', 'スガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県相馬郡飯舘村前田', '07', '07564', '9601636', '福島県', 'フクシマケン', '相馬郡飯舘村', 'ソウマグンイイタテムラ', '前田', 'マエタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県相馬郡飯舘村飯樋', '07', '07564', '9601721', '福島県', 'フクシマケン', '相馬郡飯舘村', 'ソウマグンイイタテムラ', '飯樋', 'イイトイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県相馬郡飯舘村比曽', '07', '07564', '9601722', '福島県', 'フクシマケン', '相馬郡飯舘村', 'ソウマグンイイタテムラ', '比曽', 'ヒソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県相馬郡飯舘村長泥', '07', '07564', '9601723', '福島県', 'フクシマケン', '相馬郡飯舘村', 'ソウマグンイイタテムラ', '長泥', 'ナガドロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県相馬郡飯舘村蕨平', '07', '07564', '9601724', '福島県', 'フクシマケン', '相馬郡飯舘村', 'ソウマグンイイタテムラ', '蕨平', 'ワラビダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県相馬郡飯舘村草野', '07', '07564', '9601801', '福島県', 'フクシマケン', '相馬郡飯舘村', 'ソウマグンイイタテムラ', '草野', 'クサノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県相馬郡飯舘村深谷', '07', '07564', '9601802', '福島県', 'フクシマケン', '相馬郡飯舘村', 'ソウマグンイイタテムラ', '深谷', 'フカヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県相馬郡飯舘村伊丹沢', '07', '07564', '9601803', '福島県', 'フクシマケン', '相馬郡飯舘村', 'ソウマグンイイタテムラ', '伊丹沢', 'イタミザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県相馬郡飯舘村関沢', '07', '07564', '9601804', '福島県', 'フクシマケン', '相馬郡飯舘村', 'ソウマグンイイタテムラ', '関沢', 'セキサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県相馬郡飯舘村小宮', '07', '07564', '9601811', '福島県', 'フクシマケン', '相馬郡飯舘村', 'ソウマグンイイタテムラ', '小宮', 'コミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県相馬郡飯舘村芦原', '07', '07564', '9601812', '福島県', 'フクシマケン', '相馬郡飯舘村', 'ソウマグンイイタテムラ', '芦原', 'アシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県相馬郡飯舘村八木沢', '07', '07564', '9601813', '福島県', 'フクシマケン', '相馬郡飯舘村', 'ソウマグンイイタテムラ', '八木沢', 'ヤギサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県相馬郡飯舘村大倉', '07', '07564', '9601814', '福島県', 'フクシマケン', '相馬郡飯舘村', 'ソウマグンイイタテムラ', '大倉', 'オオクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県相馬郡飯舘村佐須', '07', '07564', '9601815', '福島県', 'フクシマケン', '相馬郡飯舘村', 'ソウマグンイイタテムラ', '佐須', 'サス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市さくら', '07', '07201', '9602101', '福島県', 'フクシマケン', '福島市', 'フクシマシ', 'さくら', 'サクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市荒井北', '07', '07201', '9602102', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '荒井北', 'アライキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市桜本', '07', '07201', '9602151', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '桜本', 'サクラモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市土船', '07', '07201', '9602152', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '土船', 'ツチフネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市庄野', '07', '07201', '9602153', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '庄野', 'ショウノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市佐倉下', '07', '07201', '9602154', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '佐倉下', 'サクラシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市上名倉', '07', '07201', '9602155', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '上名倉', 'カミナグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市荒井', '07', '07201', '9602156', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '荒井', 'アライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市土湯温泉町', '07', '07201', '9602157', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '土湯温泉町', 'ツチユオンセンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市佐原', '07', '07201', '9602158', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '佐原', 'サバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市桜本木通沢', '07', '07201', '9602251', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '桜本', 'サクラモト', null, null, '木通沢', 'アケビザワ');
INSERT INTO `ms_addresses` VALUES ('135997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市町庭坂', '07', '07201', '9602261', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '町庭坂', 'マチニワサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市在庭坂', '07', '07201', '9602262', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '在庭坂', 'ザイニワサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('135999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市二子塚', '07', '07201', '9602263', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '二子塚', 'フタゴヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市天神町', '07', '07201', '9608001', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '天神町', 'テンジンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市森合町', '07', '07201', '9608002', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '森合町', 'モリアイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市森合', '07', '07201', '9608003', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '森合', 'モリアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市宮下町', '07', '07201', '9608011', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '宮下町', 'ミヤシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市御山町', '07', '07201', '9608012', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '御山町', 'オヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市南平', '07', '07201', '9608013', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '南平', 'ナンペイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市大平山', '07', '07201', '9608014', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '大平山', 'オオヒラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市児石', '07', '07201', '9608014', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '児石', 'コイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市狐山', '07', '07201', '9608015', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '狐山', 'キツネヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市狐塚畑', '07', '07201', '9608016', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '狐塚畑', 'キツネヅカハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市狐塚', '07', '07201', '9608017', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '狐塚', 'キツネヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市松木町', '07', '07201', '9608018', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '松木町', 'マツキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市霞町', '07', '07201', '9608021', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '霞町', 'カスミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市新浜町', '07', '07201', '9608022', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '新浜町', 'シンハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市大明神', '07', '07201', '9608023', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '大明神', 'ダイミョウジン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市堂殿', '07', '07201', '9608024', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '堂殿', 'ドウデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市駒山', '07', '07201', '9608025', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '駒山', 'コマヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市狩野', '07', '07201', '9608026', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '狩野', 'カリノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市栄町', '07', '07201', '9608031', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市陣場町', '07', '07201', '9608032', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '陣場町', 'ジンバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市万世町', '07', '07201', '9608033', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '万世町', 'バンセイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市置賜町', '07', '07201', '9608034', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '置賜町', 'オキタマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市本町', '07', '07201', '9608035', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '本町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市新町', '07', '07201', '9608036', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市大町', '07', '07201', '9608041', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '大町', 'オオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市荒町', '07', '07201', '9608042', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '荒町', 'アラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市中町', '07', '07201', '9608043', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '中町', 'ナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市早稲町', '07', '07201', '9608044', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '早稲町', 'ワセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市曾根田町', '07', '07201', '9608051', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '曾根田町', 'ソネダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市公事田', '07', '07201', '9608052', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '公事田', 'コウジダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市三河南町', '07', '07201', '9608053', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '三河南町', 'ミカワミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市三河北町', '07', '07201', '9608054', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '三河北町', 'ミカワキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市野田町', '07', '07201', '9608055', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '野田町', 'ノダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市八島田', '07', '07201', '9608056', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '八島田', 'ヤシマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市笹木野', '07', '07201', '9608057', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '笹木野', 'ササキノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市五月町', '07', '07201', '9608061', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '五月町', 'サツキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市清明町', '07', '07201', '9608062', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '清明町', 'セイメイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市柳町', '07', '07201', '9608063', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '柳町', 'ヤナギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市御倉町', '07', '07201', '9608064', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '御倉町', 'オグラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市杉妻町', '07', '07201', '9608065', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '杉妻町', 'スギツマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市矢剣町', '07', '07201', '9608066', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '矢剣町', 'ヤツルギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市須川町', '07', '07201', '9608067', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '須川町', 'スカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市太田町', '07', '07201', '9608068', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '太田町', 'オオタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市東中央', '07', '07201', '9608071', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '東中央', 'ヒガシチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市北中央', '07', '07201', '9608072', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '北中央', 'キタチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市南中央', '07', '07201', '9608073', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '南中央', 'ミナミチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市西中央', '07', '07201', '9608074', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '西中央', 'ニシチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市下野寺', '07', '07201', '9608075', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '下野寺', 'シモノデラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市上野寺', '07', '07201', '9608076', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '上野寺', 'カミノデラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市上町', '07', '07201', '9608101', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '上町', 'ウワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市北町', '07', '07201', '9608102', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '北町', 'キタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市舟場町', '07', '07201', '9608103', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '舟場町', 'フナバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市豊田町', '07', '07201', '9608104', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '豊田町', 'トヨダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市仲間町', '07', '07201', '9608105', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '仲間町', 'チュウゲンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市宮町', '07', '07201', '9608106', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '宮町', 'ミヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市浜田町', '07', '07201', '9608107', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '浜田町', 'ハマダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市五老内町', '07', '07201', '9608111', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '五老内町', 'ゴロウウチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市花園町', '07', '07201', '9608112', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '花園町', 'ハナゾノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市旭町', '07', '07201', '9608113', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '旭町', 'アサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市松浪町', '07', '07201', '9608114', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '松浪町', 'マツナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市山下町', '07', '07201', '9608115', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '山下町', 'ヤマシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市春日町', '07', '07201', '9608116', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '春日町', 'カスガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市入江町', '07', '07201', '9608117', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '入江町', 'イリエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市小金山', '07', '07201', '9608121', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '小金山', 'コガネヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市清水山', '07', '07201', '9608122', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '清水山', 'シミズヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市所窪', '07', '07201', '9608123', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '所窪', 'トコロクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市山居上', '07', '07201', '9608124', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '山居上', 'サンキョウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市鴇頭森', '07', '07201', '9608125', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '鴇頭森', 'トキトウモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市北五老内町', '07', '07201', '9608131', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '北五老内町', 'キタゴロウウチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市東浜町', '07', '07201', '9608132', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '東浜町', 'ヒガシハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市桜木町', '07', '07201', '9608133', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '桜木町', 'サクラギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市上浜町', '07', '07201', '9608134', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '上浜町', 'カミハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市腰浜町', '07', '07201', '9608135', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '腰浜町', 'コシハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市八島町', '07', '07201', '9608136', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '八島町', 'ヤシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市堀河町', '07', '07201', '9608137', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '堀河町', 'ホリカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市渡利', '07', '07201', '9608141', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '渡利', 'ワタリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市小倉寺', '07', '07201', '9608142', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '小倉寺', 'オグラジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市南向台', '07', '07201', '9608143', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '南向台', 'ナンコウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市太平寺', '07', '07201', '9608151', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '太平寺', 'タイヘイジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市鳥谷野', '07', '07201', '9608152', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '鳥谷野', 'トヤノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市黒岩', '07', '07201', '9608153', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '黒岩', 'クロイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市伏拝', '07', '07201', '9608154', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '伏拝', 'フシオガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市清水町', '07', '07201', '9608155', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '清水町', 'シミズマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市田沢', '07', '07201', '9608156', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '田沢', 'タザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市蓬莱町', '07', '07201', '9608157', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '蓬莱町', 'ホウライチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市郷野目', '07', '07201', '9608161', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '郷野目', 'ゴウノメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市南町', '07', '07201', '9608162', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '南町', 'ミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市方木田', '07', '07201', '9608163', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '方木田', 'ホウキダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市八木田', '07', '07201', '9608164', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '八木田', 'ヤギタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市吉倉', '07', '07201', '9608165', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '吉倉', 'ヨシクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市仁井田', '07', '07201', '9608166', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '仁井田', 'ニイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市岡島', '07', '07201', '9608201', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '岡島', 'オカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市山口', '07', '07201', '9608202', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '山口', 'ヤマグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市本内南下釜', '07', '07201', '9608203', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '本内', 'モトウチ', null, null, '南下釜', 'ミナミシモガマ');
INSERT INTO `ms_addresses` VALUES ('136095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市岡部', '07', '07201', '9608204', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '岡部', 'オカベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市茶屋下', '07', '07201', '9608211', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '茶屋下', 'チャヤシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市道前', '07', '07201', '9608212', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '道前', 'ミチマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市遠瀬戸', '07', '07201', '9608213', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '遠瀬戸', 'トオセト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市古川', '07', '07201', '9608214', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '古川', 'フルカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市下荒子', '07', '07201', '9608215', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '下荒子', 'シモアラコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市中荒子', '07', '07201', '9608216', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '中荒子', 'ナカアラコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市上荒子', '07', '07201', '9608217', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '上荒子', 'カミアラコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市高野河原下', '07', '07201', '9608218', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '高野河原下', 'コウヤカワハラシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市北中川原', '07', '07201', '9608221', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '北中川原', 'キタナカカワハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市蝦貫', '07', '07201', '9608222', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '蝦貫', 'エゾヌキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市矢倉下', '07', '07201', '9608223', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '矢倉下', 'ヤグラシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市舘ノ前', '07', '07201', '9608224', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '舘ノ前', 'タテノマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市舘ノ内', '07', '07201', '9608225', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '舘ノ内', 'タテノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市北ノ前', '07', '07201', '9608226', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '北ノ前', 'キタノマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市田中島', '07', '07201', '9608227', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '田中島', 'タナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市松山町', '07', '07201', '9608228', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '松山町', 'マツヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市北原', '07', '07201', '9608231', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '北原', 'キタハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市立石', '07', '07201', '9608232', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '立石', 'タテイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市猫渕', '07', '07201', '9608233', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '猫渕', 'ネコブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市山居', '07', '07201', '9608234', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '山居', 'サンキョ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市滝元', '07', '07201', '9608235', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '滝元', 'タキモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市山際', '07', '07201', '9608236', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '山際', 'ヤマギワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市大森', '07', '07201', '9608237', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '大森', 'オオモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市岩ノ前', '07', '07201', '9608241', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '岩ノ前', 'イワノマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市坂登', '07', '07201', '9608242', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '坂登', 'サカノボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市岩谷', '07', '07201', '9608243', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '岩谷', 'イワヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市石田', '07', '07201', '9608244', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '石田', 'イシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市北沢又', '07', '07201', '9608251', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '北沢又', 'キタサワマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市御山', '07', '07201', '9608252', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '御山', 'オヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市泉', '07', '07201', '9608253', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '泉', 'イズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県福島市南沢又', '07', '07201', '9608254', '福島県', 'フクシマケン', '福島市', 'フクシマシ', '南沢又', 'ミナミサワマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市', '07', '07205', '9610000', '福島県', 'フクシマケン', '白河市', 'シラカワシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('136186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡西郷村', '07', '07461', '9610000', '福島県', 'フクシマケン', '西白河郡西郷村', 'ニシシラカワグンニシゴウムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('136187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市小田川', '07', '07205', '9610001', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '小田川', 'コタガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市大和田', '07', '07205', '9610002', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '大和田', 'オオワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市泉田', '07', '07205', '9610003', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '泉田', 'イズミダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市萱根', '07', '07205', '9610004', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '萱根', 'カヤネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市豊地', '07', '07205', '9610005', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '豊地', 'トヨチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市久田野', '07', '07205', '9610011', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '久田野', 'クタノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市本沼', '07', '07205', '9610012', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '本沼', 'モトヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市舟田', '07', '07205', '9610013', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '舟田', 'フナダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市借宿', '07', '07205', '9610014', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '借宿', 'カリヤド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市田島', '07', '07205', '9610015', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '田島', 'タジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市板橋', '07', '07205', '9610016', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '板橋', 'イタバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市双石', '07', '07205', '9610017', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '双石', 'クラベイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市関辺', '07', '07205', '9610021', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '関辺', 'セキベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市南池下', '07', '07205', '9610022', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '南池下', 'ミナミイケシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市亀石', '07', '07205', '9610023', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '亀石', 'カメイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市新夏梨', '07', '07205', '9610024', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '新夏梨', 'シンナツナシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市夏梨', '07', '07205', '9610025', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '夏梨', 'ナツナシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市上ノ原', '07', '07205', '9610026', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '上ノ原', 'ウエノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市十文字', '07', '07205', '9610027', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '十文字', 'ジュウモンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市道東', '07', '07205', '9610031', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '道東', 'ミチヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市家ノ前', '07', '07205', '9610032', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '家ノ前', 'イエノマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市八幡山', '07', '07205', '9610033', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '八幡山', 'ハチマンヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市屋敷添', '07', '07205', '9610034', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '屋敷添', 'ヤシキゾエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市南家ノ前', '07', '07205', '9610035', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '南家ノ前', 'ミナミイエノマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市裏山', '07', '07205', '9610036', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '裏山', 'ウラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市新道', '07', '07205', '9610037', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '新道', 'シンミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市旗宿', '07', '07205', '9610038', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '旗宿', 'ハタジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市結城', '07', '07205', '9610041', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '結城', 'ユウキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市金鈴', '07', '07205', '9610042', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '金鈴', 'キンレイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市藤沢', '07', '07205', '9610043', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '藤沢', 'フジサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市藤沢山', '07', '07205', '9610044', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '藤沢山', 'フジサワヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市合戦坂', '07', '07205', '9610045', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '合戦坂', 'コウセンザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市土武塚', '07', '07205', '9610046', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '土武塚', 'ドブヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市八竜神', '07', '07205', '9610047', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '八竜神', 'ハチリュウジン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市大', '07', '07205', '9610051', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '大', 'ダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市南中川原', '07', '07205', '9610052', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '南中川原', 'ミナミナカガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市中田', '07', '07205', '9610053', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '中田', 'ナカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市北中川原', '07', '07205', '9610054', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '北中川原', 'キタナカガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市田中山', '07', '07205', '9610061', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '田中山', 'タナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市外薄葉', '07', '07205', '9610062', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '外薄葉', 'ソトウスバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市薄葉', '07', '07205', '9610063', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '薄葉', 'ウスバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市女石', '07', '07205', '9610064', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '女石', 'オンナイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市向寺', '07', '07205', '9610065', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '向寺', 'ムカイデラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市羅漢前', '07', '07205', '9610066', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '羅漢前', 'ラカンマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市士多町東', '07', '07205', '9610071', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '士多町東', 'シタマチヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市士多町', '07', '07205', '9610072', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '士多町', 'シタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市田町', '07', '07205', '9610073', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '田町', 'タマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市郭内', '07', '07205', '9610074', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '郭内', 'カクナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市会津町', '07', '07205', '9610075', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '会津町', 'アイヅマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市五番町川原', '07', '07205', '9610076', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '五番町川原', 'ゴバンチョウガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市仁井町', '07', '07205', '9610077', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '仁井町', 'ニイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市米村道北', '07', '07205', '9610078', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '米村道北', 'ヨネムラミチキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市飯沢山', '07', '07205', '9610081', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '飯沢山', 'イイザワヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市飯沢', '07', '07205', '9610082', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '飯沢', 'イイザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市金勝寺', '07', '07205', '9610083', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '金勝寺', 'キンショウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市金勝寺東', '07', '07205', '9610084', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '金勝寺東', 'キンショウジヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市町田', '07', '07205', '9610085', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '町田', 'マチダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市鶴巻山', '07', '07205', '9610086', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '鶴巻山', 'ツルマキヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市鶴巻', '07', '07205', '9610087', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '鶴巻', 'ツルマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市弥次郎窪', '07', '07205', '9610091', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '弥次郎窪', 'ヤジロウクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市六反山', '07', '07205', '9610092', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '六反山', 'ロクタンヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市葉ノ木平', '07', '07205', '9610093', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '葉ノ木平', 'ハノキダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市追廻', '07', '07205', '9610094', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '追廻', 'オイマワシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡中島村', '07', '07465', '9610100', '福島県', 'フクシマケン', '西白河郡中島村', 'ニシシラカワグンナカジマムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('136251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡中島村松崎', '07', '07465', '9610101', '福島県', 'フクシマケン', '西白河郡中島村', 'ニシシラカワグンナカジマムラ', '松崎', 'マツザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡中島村滑津', '07', '07465', '9610102', '福島県', 'フクシマケン', '西白河郡中島村', 'ニシシラカワグンナカジマムラ', '滑津', 'ナメツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡中島村中島', '07', '07465', '9610103', '福島県', 'フクシマケン', '西白河郡中島村', 'ニシシラカワグンナカジマムラ', '中島', 'ナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡中島村吉岡', '07', '07465', '9610104', '福島県', 'フクシマケン', '西白河郡中島村', 'ニシシラカワグンナカジマムラ', '吉岡', 'ヨシオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡中島村川原田', '07', '07465', '9610105', '福島県', 'フクシマケン', '西白河郡中島村', 'ニシシラカワグンナカジマムラ', '川原田', 'カワハラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡中島村二子塚', '07', '07465', '9610106', '福島県', 'フクシマケン', '西白河郡中島村', 'ニシシラカワグンナカジマムラ', '二子塚', 'フタゴツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市東下野出島', '07', '07205', '9610301', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '東下野出島', 'ヒガシシモノデジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市東上野出島', '07', '07205', '9610302', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '東上野出島', 'ヒガシカミノデジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市東釜子', '07', '07205', '9610303', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '東釜子', 'ヒガシカマコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市東工業団地', '07', '07205', '9610304', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '東工業団地', 'ヒガシコウギョウダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市東千田', '07', '07205', '9610305', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '東千田', 'ヒガシセンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市東形見', '07', '07205', '9610306', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '東形見', 'ヒガシカタミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市東栃本', '07', '07205', '9610307', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '東栃本', 'ヒガシトチモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市東蕪内', '07', '07205', '9610308', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '東蕪内', 'ヒガシカブウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市東深仁井田', '07', '07205', '9610309', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '東深仁井田', 'ヒガシフカニイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市表郷中野', '07', '07205', '9610401', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '表郷中野', 'オモテゴウナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市表郷内松', '07', '07205', '9610402', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '表郷内松', 'オモテゴウナイマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市表郷番沢', '07', '07205', '9610403', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '表郷番沢', 'オモテゴウバンザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市表郷社田', '07', '07205', '9610404', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '表郷社田', 'オモテゴウヤシロダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市表郷小松', '07', '07205', '9610405', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '表郷小松', 'オモテゴウコマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市表郷八幡', '07', '07205', '9610406', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '表郷八幡', 'オモテゴウヤワタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市表郷中寺', '07', '07205', '9610407', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '表郷中寺', 'オモテゴウナカデラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市表郷堀之内', '07', '07205', '9610408', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '表郷堀之内', 'オモテゴウホリノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市表郷河東田', '07', '07205', '9610409', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '表郷河東田', 'オモテゴウカトウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市表郷深渡戸', '07', '07205', '9610411', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '表郷深渡戸', 'オモテゴウフカアド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市表郷下羽原', '07', '07205', '9610412', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '表郷下羽原', 'オモテゴウシモハバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市表郷三森', '07', '07205', '9610413', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '表郷三森', 'オモテゴウミモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市表郷高木', '07', '07205', '9610414', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '表郷高木', 'オモテゴウタカギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市表郷梁森', '07', '07205', '9610415', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '表郷梁森', 'オモテゴウヤナモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市表郷金山', '07', '07205', '9610416', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '表郷金山', 'オモテゴウカネヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市豊年', '07', '07205', '9610801', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '豊年', 'ホウネン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市関川窪', '07', '07205', '9610802', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '関川窪', 'カンセンクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市栄町', '07', '07205', '9610803', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市蛇石', '07', '07205', '9610804', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '蛇石', 'ヘビイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市文珠山', '07', '07205', '9610805', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '文珠山', 'モンジュヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市菅生舘', '07', '07205', '9610811', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '菅生舘', 'スゴウダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市南湖', '07', '07205', '9610812', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '南湖', 'ナンコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市東大沼', '07', '07205', '9610813', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '東大沼', 'ヒガシオオヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市三本松山', '07', '07205', '9610814', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '三本松山', 'サンボンマツヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市五郎窪', '07', '07205', '9610815', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '五郎窪', 'ゴロウクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市西大沼', '07', '07205', '9610816', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '西大沼', 'ニシオオヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市北裏', '07', '07205', '9610821', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '北裏', 'キタウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市瀬戸原', '07', '07205', '9610822', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '瀬戸原', 'セトハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市中島', '07', '07205', '9610823', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '中島', 'ナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市丸小山', '07', '07205', '9610824', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '丸小山', 'マルコヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市池下向山', '07', '07205', '9610825', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '池下向山', 'イケシタムカイヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市池下裏', '07', '07205', '9610826', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '池下裏', 'イケシタウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市池下', '07', '07205', '9610827', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '池下', 'イケシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市老久保', '07', '07205', '9610831', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '老久保', 'オイクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市西小丸山', '07', '07205', '9610832', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '西小丸山', 'ニシコマルヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市東三坂山', '07', '07205', '9610833', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '東三坂山', 'ヒガシミサカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市西三坂', '07', '07205', '9610834', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '西三坂', 'ニシミサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市白坂', '07', '07205', '9610835', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '白坂', 'シラサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市みさか', '07', '07205', '9610836', '福島県', 'フクシマケン', '白河市', 'シラカワシ', 'みさか', 'ミサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市西三坂山', '07', '07205', '9610837', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '西三坂山', 'ニシミサカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市老久保山', '07', '07205', '9610838', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '老久保山', 'オイクボヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市古高山', '07', '07205', '9610841', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '古高山', 'フルタカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市新池', '07', '07205', '9610842', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '新池', 'シンイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市古池', '07', '07205', '9610843', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '古池', 'フルイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市中野山', '07', '07205', '9610844', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '中野山', 'ナカノヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市大坂山', '07', '07205', '9610845', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '大坂山', 'オオサカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市大暮矢見山', '07', '07205', '9610846', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '大暮矢見山', 'オオクレヤミヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市南登リ町', '07', '07205', '9610851', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '南登リ町', 'ミナミノボリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市転坂', '07', '07205', '9610852', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '転坂', 'コロビザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市新高山', '07', '07205', '9610853', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '新高山', 'シンタカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市高山', '07', '07205', '9610854', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '高山', 'タカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市高山西', '07', '07205', '9610855', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '高山西', 'タカヤマニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市新白河', '07', '07205', '9610856', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '新白河', 'シンシラカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市南堀切', '07', '07205', '9610857', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '南堀切', 'ミナミホリキリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市風神下', '07', '07205', '9610861', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '風神下', 'フウジンシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市三番町', '07', '07205', '9610862', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '三番町', 'サンバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市七番町', '07', '07205', '9610863', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '七番町', 'シチバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市風神山東', '07', '07205', '9610864', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '風神山東', 'フウジンヤマヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市花見坂', '07', '07205', '9610865', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '花見坂', 'ハナミザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市鶴芝', '07', '07205', '9610866', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '鶴芝', 'ツルシバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市石切場', '07', '07205', '9610867', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '石切場', 'イシキリバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市米山越', '07', '07205', '9610871', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '米山越', 'ヨネヤマゴエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市三本松', '07', '07205', '9610872', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '三本松', 'サンボンマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市松並', '07', '07205', '9610873', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '松並', 'マツナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市九番町西裏', '07', '07205', '9610874', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '九番町西裏', 'クバンチョウニシウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市九番町', '07', '07205', '9610875', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '九番町', 'クバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市与惣小屋', '07', '07205', '9610881', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '与惣小屋', 'ヨソウゴヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市与惣小屋山', '07', '07205', '9610882', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '与惣小屋山', 'ヨソウゴヤヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市東小丸山', '07', '07205', '9610883', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '東小丸山', 'ヒガシコマルヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市鬼越道下', '07', '07205', '9610884', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '鬼越道下', 'オニゴエミチシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市鬼越', '07', '07205', '9610885', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '鬼越', 'オニゴエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市影鬼越', '07', '07205', '9610886', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '影鬼越', 'カゲオニゴエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市鬼越山', '07', '07205', '9610887', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '鬼越山', 'オニゴエヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市十三原', '07', '07205', '9610888', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '十三原', 'ジュウサンパラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市明戸', '07', '07205', '9610901', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '明戸', 'アケド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市番士小路', '07', '07205', '9610902', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '番士小路', 'バンシコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市年貢町', '07', '07205', '9610903', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '年貢町', 'ネングマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市馬町裏', '07', '07205', '9610904', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '馬町裏', 'ウママチウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市本町', '07', '07205', '9610905', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '本町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市本町北裏', '07', '07205', '9610906', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '本町北裏', 'モトマチキタウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市横町', '07', '07205', '9610907', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '横町', 'ヨコマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市大手町', '07', '07205', '9610908', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '大手町', 'オオテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市桜町', '07', '07205', '9610911', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '桜町', 'サクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市旭町', '07', '07205', '9610912', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '旭町', 'アサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市鍛冶町', '07', '07205', '9610913', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '鍛冶町', 'カジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市寺小路', '07', '07205', '9610914', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '寺小路', 'テラコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市馬町下', '07', '07205', '9610915', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '馬町下', 'ウママチシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市束前町', '07', '07205', '9610916', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '束前町', 'ソクゼンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市八百屋町', '07', '07205', '9610917', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '八百屋町', 'ヤオヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市円明寺', '07', '07205', '9610921', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '円明寺', 'エンミョウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市菖蒲沢', '07', '07205', '9610922', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '菖蒲沢', 'ショウブザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市白井掛下', '07', '07205', '9610923', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '白井掛下', 'シライガケシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市白井掛', '07', '07205', '9610924', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '白井掛', 'シライガケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市向新蔵', '07', '07205', '9610925', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '向新蔵', 'ムカイシンクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市友月山', '07', '07205', '9610926', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '友月山', 'ユウゲツザン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市馬町', '07', '07205', '9610931', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '馬町', 'ウママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市南町', '07', '07205', '9610932', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '南町', 'ミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市新蔵町', '07', '07205', '9610933', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '新蔵町', 'シンクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市袋町', '07', '07205', '9610934', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '袋町', 'フクロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市手代町', '07', '07205', '9610935', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '手代町', 'テダイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市大工町', '07', '07205', '9610936', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '大工町', 'ダイクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市上ノ台', '07', '07205', '9610937', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '上ノ台', 'ウエノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市八幡小路', '07', '07205', '9610941', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '八幡小路', 'ハチマンコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市愛宕町', '07', '07205', '9610942', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '愛宕町', 'アタゴマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市金屋町', '07', '07205', '9610943', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '金屋町', 'カナヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市宰領町', '07', '07205', '9610944', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '宰領町', 'サイリョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市巡り矢', '07', '07205', '9610945', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '巡り矢', 'メグリヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市二番町', '07', '07205', '9610946', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '二番町', 'ニバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市一番町', '07', '07205', '9610947', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '一番町', 'イチバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市中町', '07', '07205', '9610951', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '中町', 'ナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市中町北裏', '07', '07205', '9610952', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '中町北裏', 'ナカマチキタウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市鷹匠町', '07', '07205', '9610953', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '鷹匠町', 'タカジョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市天神町', '07', '07205', '9610954', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '天神町', 'テンジンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市道場町', '07', '07205', '9610955', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '道場町', 'ドウジョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市勘定町', '07', '07205', '9610956', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '勘定町', 'カンジョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市道場小路', '07', '07205', '9610957', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '道場小路', 'ドウジョウコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市四ツ谷', '07', '07205', '9610961', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '四ツ谷', 'ヨツヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市登リ町', '07', '07205', '9610962', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '登リ町', 'ノボリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市日影', '07', '07205', '9610963', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '日影', 'ヒカゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市日向', '07', '07205', '9610964', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '日向', 'ヒナタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市細工町', '07', '07205', '9610965', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '細工町', 'サイクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市昭和町', '07', '07205', '9610971', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '昭和町', 'ショウワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市立石', '07', '07205', '9610972', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '立石', 'タテイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市北登リ町', '07', '07205', '9610973', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '北登リ町', 'キタノボリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市北堀切', '07', '07205', '9610974', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '北堀切', 'キタホリキリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市立石山', '07', '07205', '9610975', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '立石山', 'タテイシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市北真舟', '07', '07205', '9610981', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '北真舟', 'キタマブネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市南真舟', '07', '07205', '9610982', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '南真舟', 'ミナミマブネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市真舟', '07', '07205', '9610983', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '真舟', 'マブネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市和尚壇山', '07', '07205', '9610984', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '和尚壇山', 'オショウダンヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市和尚壇', '07', '07205', '9610985', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '和尚壇', 'オショウダン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市塩路山', '07', '07205', '9610986', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '塩路山', 'シオジヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市中山東', '07', '07205', '9610991', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '中山東', 'ナカヤマヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市南堀川端', '07', '07205', '9610992', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '南堀川端', 'ミナミホリカワバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市中山南', '07', '07205', '9610993', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '中山南', 'ナカヤマミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市中山下', '07', '07205', '9610994', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '中山下', 'ナカヤマシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市中山', '07', '07205', '9610995', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '中山', 'ナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡西郷村羽太', '07', '07461', '9618001', '福島県', 'フクシマケン', '西白河郡西郷村', 'ニシシラカワグンニシゴウムラ', '羽太', 'ハブト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市大信隈戸北小萱', '07', '07205', '9618002', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '大信隈戸', 'タイシンクマド', null, null, '北小萱', 'キタコガヤ');
INSERT INTO `ms_addresses` VALUES ('136408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡西郷村柏野', '07', '07461', '9618011', '福島県', 'フクシマケン', '西白河郡西郷村', 'ニシシラカワグンニシゴウムラ', '柏野', 'カシワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡西郷村長坂', '07', '07461', '9618021', '福島県', 'フクシマケン', '西白河郡西郷村', 'ニシシラカワグンニシゴウムラ', '長坂', 'ナガサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡西郷村米', '07', '07461', '9618031', '福島県', 'フクシマケン', '西白河郡西郷村', 'ニシシラカワグンニシゴウムラ', '米', 'ヨネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡西郷村豊作東', '07', '07461', '9618041', '福島県', 'フクシマケン', '西白河郡西郷村', 'ニシシラカワグンニシゴウムラ', '豊作東', 'トヨサクヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡西郷村豊作西', '07', '07461', '9618042', '福島県', 'フクシマケン', '西白河郡西郷村', 'ニシシラカワグンニシゴウムラ', '豊作西', 'トヨサクニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡西郷村石塚南', '07', '07461', '9618043', '福島県', 'フクシマケン', '西白河郡西郷村', 'ニシシラカワグンニシゴウムラ', '石塚南', 'イシヅカミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡西郷村石塚北', '07', '07461', '9618044', '福島県', 'フクシマケン', '西白河郡西郷村', 'ニシシラカワグンニシゴウムラ', '石塚北', 'イシヅカキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡西郷村屋敷裏西', '07', '07461', '9618045', '福島県', 'フクシマケン', '西白河郡西郷村', 'ニシシラカワグンニシゴウムラ', '屋敷裏西', 'ヤシキウラニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡西郷村屋敷裏東', '07', '07461', '9618046', '福島県', 'フクシマケン', '西白河郡西郷村', 'ニシシラカワグンニシゴウムラ', '屋敷裏東', 'ヤシキウラヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡西郷村裏山南', '07', '07461', '9618047', '福島県', 'フクシマケン', '西白河郡西郷村', 'ニシシラカワグンニシゴウムラ', '裏山南', 'ウラヤマミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡西郷村下前田東', '07', '07461', '9618051', '福島県', 'フクシマケン', '西白河郡西郷村', 'ニシシラカワグンニシゴウムラ', '下前田東', 'シモマエダヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡西郷村道南東', '07', '07461', '9618052', '福島県', 'フクシマケン', '西白河郡西郷村', 'ニシシラカワグンニシゴウムラ', '道南東', 'ドウナンヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡西郷村前山東', '07', '07461', '9618053', '福島県', 'フクシマケン', '西白河郡西郷村', 'ニシシラカワグンニシゴウムラ', '前山東', 'マエヤマヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡西郷村前山西', '07', '07461', '9618054', '福島県', 'フクシマケン', '西白河郡西郷村', 'ニシシラカワグンニシゴウムラ', '前山西', 'マエヤマニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡西郷村道南西', '07', '07461', '9618055', '福島県', 'フクシマケン', '西白河郡西郷村', 'ニシシラカワグンニシゴウムラ', '道南西', 'ドウナンニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡西郷村下前田西', '07', '07461', '9618056', '福島県', 'フクシマケン', '西白河郡西郷村', 'ニシシラカワグンニシゴウムラ', '下前田西', 'シモマエダニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡西郷村小田倉', '07', '07461', '9618061', '福島県', 'フクシマケン', '西白河郡西郷村', 'ニシシラカワグンニシゴウムラ', '小田倉', 'オダクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡西郷村真船', '07', '07461', '9618071', '福島県', 'フクシマケン', '西白河郡西郷村', 'ニシシラカワグンニシゴウムラ', '真船', 'マブネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡西郷村鶴生', '07', '07461', '9618081', '福島県', 'フクシマケン', '西白河郡西郷村', 'ニシシラカワグンニシゴウムラ', '鶴生', 'ツリュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡西郷村熊倉', '07', '07461', '9618091', '福島県', 'フクシマケン', '西白河郡西郷村', 'ニシシラカワグンニシゴウムラ', '熊倉', 'クマグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市', '07', '07207', '9620000', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('136440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市森宿', '07', '07207', '9620001', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '森宿', 'モリジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市上人坦', '07', '07207', '9620002', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '上人坦', 'ショウニンダン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市岩瀬森', '07', '07207', '9620003', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '岩瀬森', 'イワセモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市中山', '07', '07207', '9620004', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '中山', 'ナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市台', '07', '07207', '9620005', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '台', 'ダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市山寺道', '07', '07207', '9620006', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '山寺道', 'ヤマデラミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市下宿町', '07', '07207', '9620007', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '下宿町', 'シモジュクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市坂の上町', '07', '07207', '9620011', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '坂の上町', 'サカノウエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市陣場町', '07', '07207', '9620012', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '陣場町', 'ジンバマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市岡東町', '07', '07207', '9620013', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '岡東町', 'オカヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市西川町', '07', '07207', '9620014', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '西川町', 'ニシカワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市日向町', '07', '07207', '9620015', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '日向町', 'ヒナタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市西田町', '07', '07207', '9620016', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '西田町', 'ニシダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市西の内町', '07', '07207', '9620017', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '西の内町', 'ニシノウチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市館取町', '07', '07207', '9620021', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '館取町', 'タテトリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市丸田町', '07', '07207', '9620022', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '丸田町', 'マルタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市大黒町', '07', '07207', '9620023', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '大黒町', 'ダイコクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市稲荷町', '07', '07207', '9620024', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '稲荷町', 'イナリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市八幡山', '07', '07207', '9620025', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '八幡山', 'ハチマンヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市岩崎', '07', '07207', '9620026', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '岩崎', 'イワサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市堀底町', '07', '07207', '9620027', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '堀底町', 'ホリソコマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市茶畑町', '07', '07207', '9620028', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '茶畑町', 'チャバタケマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市影沼町', '07', '07207', '9620031', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '影沼町', 'カゲヌママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市大袋町', '07', '07207', '9620032', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '大袋町', 'オオブクロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市岩作', '07', '07207', '9620033', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '岩作', 'イワサク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市一里坦', '07', '07207', '9620034', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '一里坦', 'イチリダン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市五月雨', '07', '07207', '9620035', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '五月雨', 'サミダレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市芹沢町', '07', '07207', '9620036', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '芹沢町', 'セリザワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市横山町', '07', '07207', '9620041', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '横山町', 'ヨコヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市稲', '07', '07207', '9620042', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '稲', 'イナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市岩渕', '07', '07207', '9620043', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '岩渕', 'イワブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市池下', '07', '07207', '9620044', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '池下', 'イケシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市保土原', '07', '07207', '9620045', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '保土原', 'ホドワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市泉田', '07', '07207', '9620046', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '泉田', 'イズミダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市松塚', '07', '07207', '9620047', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '松塚', 'マツヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市越久', '07', '07207', '9620051', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '越久', 'オッキュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市西川', '07', '07207', '9620052', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '西川', 'ニシカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市卸町', '07', '07207', '9620053', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '卸町', 'オロシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市牛袋町', '07', '07207', '9620054', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '牛袋町', 'ウシブクロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市新町', '07', '07207', '9620055', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市大桑原', '07', '07207', '9620056', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '大桑原', 'オオカンバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市袋田', '07', '07207', '9620057', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '袋田', 'フクロダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市池ノ下町', '07', '07207', '9620058', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '池ノ下町', 'イケノシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市吉美根', '07', '07207', '9620059', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '吉美根', 'ヨシミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市横田', '07', '07207', '9620121', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '横田', 'ヨコタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市木之崎', '07', '07207', '9620122', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '木之崎', 'キノサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市矢田野', '07', '07207', '9620123', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '矢田野', 'ヤタノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市桙衝', '07', '07207', '9620124', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '桙衝', 'ホコツキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市堀込', '07', '07207', '9620125', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '堀込', 'ホリゴメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市花の里', '07', '07207', '9620126', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '花の里', 'ハナノサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市志茂', '07', '07207', '9620201', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '志茂', 'シモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市小中', '07', '07207', '9620202', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '小中', 'コナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市長沼', '07', '07207', '9620203', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '長沼', 'ナガヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市江花', '07', '07207', '9620204', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '江花', 'エバナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市勢至堂', '07', '07207', '9620205', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '勢至堂', 'セイシドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市滝赤土', '07', '07207', '9620211', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '滝', 'タキ', null, null, '赤土', 'アカツチ');
INSERT INTO `ms_addresses` VALUES ('136496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市滝雁田', '07', '07207', '9620211', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '滝', 'タキ', null, null, '雁田', 'ガンダ');
INSERT INTO `ms_addresses` VALUES ('136497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市滝北久保', '07', '07207', '9620211', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '滝', 'タキ', null, null, '北久保', 'キタクボ');
INSERT INTO `ms_addresses` VALUES ('136498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市滝白砂', '07', '07207', '9620211', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '滝', 'タキ', null, null, '白砂', 'シラスナ');
INSERT INTO `ms_addresses` VALUES ('136499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市滝白砂山', '07', '07207', '9620211', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '滝', 'タキ', null, null, '白砂山', 'シラスナヤマ');
INSERT INTO `ms_addresses` VALUES ('136500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市滝大新畑', '07', '07207', '9620211', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '滝', 'タキ', null, null, '大新畑', 'ダイシンバタ');
INSERT INTO `ms_addresses` VALUES ('136501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市滝大日前', '07', '07207', '9620211', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '滝', 'タキ', null, null, '大日前', 'ダイニチマエ');
INSERT INTO `ms_addresses` VALUES ('136502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市滝滝西', '07', '07207', '9620211', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '滝', 'タキ', null, null, '滝西', 'タキニシ');
INSERT INTO `ms_addresses` VALUES ('136503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市滝チャクの下', '07', '07207', '9620211', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '滝', 'タキ', null, null, 'チャクの下', 'チャクノシタ');
INSERT INTO `ms_addresses` VALUES ('136504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市滝日向前', '07', '07207', '9620211', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '滝', 'タキ', null, null, '日向前', 'ヒナタマエ');
INSERT INTO `ms_addresses` VALUES ('136505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市滝本郷', '07', '07207', '9620211', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '滝', 'タキ', null, null, '本郷', 'ホンゴウ');
INSERT INTO `ms_addresses` VALUES ('136506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市滝前田', '07', '07207', '9620211', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '滝', 'タキ', null, null, '前田', 'マエタ');
INSERT INTO `ms_addresses` VALUES ('136507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市今泉', '07', '07207', '9620301', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '今泉', 'イマイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市柱田', '07', '07207', '9620302', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '柱田', 'ハシラタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市梅田', '07', '07207', '9620303', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '梅田', 'ウメタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市滝', '07', '07207', '9620304', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '滝', 'タキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市守屋', '07', '07207', '9620305', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '守屋', 'モリヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市矢沢', '07', '07207', '9620311', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '矢沢', 'ヤザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市大久保', '07', '07207', '9620312', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '大久保', 'オオクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市北横田', '07', '07207', '9620313', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '北横田', 'キタヨコタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市深渡戸', '07', '07207', '9620314', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '深渡戸', 'フカワタリド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市畑田', '07', '07207', '9620315', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '畑田', 'ハタダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市向陽町', '07', '07207', '9620401', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '向陽町', 'コウヨウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市仁井田', '07', '07207', '9620402', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '仁井田', 'ニイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市滑川', '07', '07207', '9620403', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '滑川', 'ナメガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市舘ケ岡', '07', '07207', '9620404', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '舘ケ岡', 'タテガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市季の郷', '07', '07207', '9620405', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '季の郷', 'キノサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市宮の杜', '07', '07207', '9620406', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '宮の杜', 'ミヤノモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県岩瀬郡天栄村', '07', '07344', '9620500', '福島県', 'フクシマケン', '岩瀬郡天栄村', 'イワセグンテンエイムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('136525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県岩瀬郡天栄村牧之内', '07', '07344', '9620501', '福島県', 'フクシマケン', '岩瀬郡天栄村', 'イワセグンテンエイムラ', '牧之内', 'マキノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県岩瀬郡天栄村上松本', '07', '07344', '9620502', '福島県', 'フクシマケン', '岩瀬郡天栄村', 'イワセグンテンエイムラ', '上松本', 'カミマツモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県岩瀬郡天栄村下松本', '07', '07344', '9620503', '福島県', 'フクシマケン', '岩瀬郡天栄村', 'イワセグンテンエイムラ', '下松本', 'シモマツモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県岩瀬郡天栄村大里', '07', '07344', '9620504', '福島県', 'フクシマケン', '岩瀬郡天栄村', 'イワセグンテンエイムラ', '大里', 'オオサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県岩瀬郡天栄村白子', '07', '07344', '9620511', '福島県', 'フクシマケン', '岩瀬郡天栄村', 'イワセグンテンエイムラ', '白子', 'シロコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県岩瀬郡天栄村飯豊', '07', '07344', '9620512', '福島県', 'フクシマケン', '岩瀬郡天栄村', 'イワセグンテンエイムラ', '飯豊', 'イイトヨ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県岩瀬郡天栄村沖内', '07', '07344', '9620513', '福島県', 'フクシマケン', '岩瀬郡天栄村', 'イワセグンテンエイムラ', '沖内', 'オキウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県岩瀬郡天栄村柿之内', '07', '07344', '9620514', '福島県', 'フクシマケン', '岩瀬郡天栄村', 'イワセグンテンエイムラ', '柿之内', 'カキノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県岩瀬郡天栄村高林', '07', '07344', '9620515', '福島県', 'フクシマケン', '岩瀬郡天栄村', 'イワセグンテンエイムラ', '高林', 'タカハヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県岩瀬郡天栄村小川', '07', '07344', '9620516', '福島県', 'フクシマケン', '岩瀬郡天栄村', 'イワセグンテンエイムラ', '小川', 'オガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県岩瀬郡天栄村湯本', '07', '07344', '9620621', '福島県', 'フクシマケン', '岩瀬郡天栄村', 'イワセグンテンエイムラ', '湯本', 'ユモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県岩瀬郡天栄村田良尾', '07', '07344', '9620622', '福島県', 'フクシマケン', '岩瀬郡天栄村', 'イワセグンテンエイムラ', '田良尾', 'タラオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県岩瀬郡天栄村羽鳥', '07', '07344', '9620623', '福島県', 'フクシマケン', '岩瀬郡天栄村', 'イワセグンテンエイムラ', '羽鳥', 'ハトリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市塩田', '07', '07207', '9620711', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '塩田', 'シオダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市小倉', '07', '07207', '9620712', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '小倉', 'オグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市上小山田', '07', '07207', '9620713', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '上小山田', 'カミオヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市下小山田', '07', '07207', '9620714', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '下小山田', 'シモオヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市雨田', '07', '07207', '9620721', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '雨田', 'アメダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市大栗', '07', '07207', '9620722', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '大栗', 'オオグリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市狸森', '07', '07207', '9620723', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '狸森', 'ムジナモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市田中', '07', '07207', '9620724', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '田中', 'タナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市日照田', '07', '07207', '9620725', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '日照田', 'ヒデリダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市市野関', '07', '07207', '9620726', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '市野関', 'イチノセキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市小作田', '07', '07207', '9620727', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '小作田', 'コサクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市虹の台', '07', '07207', '9620728', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '虹の台', 'ニジノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市江持', '07', '07207', '9620801', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '江持', 'エモチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市堤', '07', '07207', '9620802', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '堤', 'ツツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市古河', '07', '07207', '9620803', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '古河', 'フルカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市中曽根', '07', '07207', '9620804', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '中曽根', 'ナカソネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市崩免', '07', '07207', '9620805', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '崩免', 'クズレメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市下宿前', '07', '07207', '9620806', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '下宿前', 'シモジュクマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市境免', '07', '07207', '9620807', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '境免', 'サカイメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市あおば町', '07', '07207', '9620811', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', 'あおば町', 'アオバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市浜尾', '07', '07207', '9620812', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '浜尾', 'ハマオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市和田', '07', '07207', '9620813', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '和田', 'ワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市前田川', '07', '07207', '9620814', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '前田川', 'マエダガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市牡丹園', '07', '07207', '9620815', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '牡丹園', 'ボタンエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市朝日田', '07', '07207', '9620816', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '朝日田', 'アサヒダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市南上町', '07', '07207', '9620817', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '南上町', 'ミナミウワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市和田道', '07', '07207', '9620818', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '和田道', 'ワダミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市桜岡', '07', '07207', '9620821', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '桜岡', 'サクラガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市東作', '07', '07207', '9620822', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '東作', 'ヒガシサク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市花岡', '07', '07207', '9620823', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '花岡', 'ハナオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市新田', '07', '07207', '9620824', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '新田', 'シンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市六軒', '07', '07207', '9620825', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '六軒', 'ロッケン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市広表', '07', '07207', '9620826', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '広表', 'ヒロオモテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市寺田', '07', '07207', '9620827', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '寺田', 'テラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市八幡町', '07', '07207', '9620831', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '八幡町', 'ハチマンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市本町', '07', '07207', '9620832', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '本町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市馬町', '07', '07207', '9620833', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '馬町', 'ウママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市旭町', '07', '07207', '9620834', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '旭町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市千日堂', '07', '07207', '9620835', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '千日堂', 'センニチドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市並木町', '07', '07207', '9620836', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '並木町', 'ナミキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市高久田境', '07', '07207', '9620837', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '高久田境', 'タカクダサカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市南町', '07', '07207', '9620838', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '南町', 'ミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市大町', '07', '07207', '9620839', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '大町', 'オオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市上北町', '07', '07207', '9620841', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '上北町', 'カミキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市宮先町', '07', '07207', '9620842', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '宮先町', 'ミヤザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市池上町', '07', '07207', '9620843', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '池上町', 'イケガミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市東町', '07', '07207', '9620844', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '東町', 'ヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市中町', '07', '07207', '9620845', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '中町', 'ナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市加治町', '07', '07207', '9620846', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '加治町', 'カジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市諏訪町', '07', '07207', '9620847', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '諏訪町', 'スワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市弘法坦', '07', '07207', '9620848', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '弘法坦', 'コウボウダン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市中宿', '07', '07207', '9620851', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '中宿', 'ナカジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市仲の町', '07', '07207', '9620852', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '仲の町', 'ナカノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市前川', '07', '07207', '9620853', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '前川', 'マエカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市古屋敷', '07', '07207', '9620854', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '古屋敷', 'フルヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市守谷舘', '07', '07207', '9620855', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '守谷舘', 'モリヤタテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市北町', '07', '07207', '9620856', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '北町', 'キタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市長禄町', '07', '07207', '9620857', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '長禄町', 'チョウロクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市栄町', '07', '07207', '9620858', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市塚田', '07', '07207', '9620859', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '塚田', 'ツカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市古舘', '07', '07207', '9620861', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '古舘', 'フルダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市六郎兵衛', '07', '07207', '9620862', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '六郎兵衛', 'ロクロウベエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市緑町', '07', '07207', '9620863', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '緑町', 'ミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市北上町', '07', '07207', '9620864', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '北上町', 'キタウワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市妙見', '07', '07207', '9620865', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '妙見', 'ミョウケン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市栗谷沢', '07', '07207', '9620866', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '栗谷沢', 'クリヤサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市愛宕山', '07', '07207', '9620867', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '愛宕山', 'アタゴヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県須賀川市芦田塚', '07', '07207', '9620868', '福島県', 'フクシマケン', '須賀川市', 'スカガワシ', '芦田塚', 'アシダツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市', '07', '07203', '9630000', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('136616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市安積町日出山', '07', '07203', '9630101', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '安積町日出山', 'アサカマチヒデノヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市安積町笹川', '07', '07203', '9630102', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '安積町笹川', 'アサカマチササガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市安積町大森町', '07', '07203', '9630103', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '安積町大森町', 'アサカマチオオモリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市安積町南長久保', '07', '07203', '9630104', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '安積町南長久保', 'アサカマチミナミナガクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市安積町長久保', '07', '07203', '9630105', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '安積町長久保', 'アサカマチナガクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市成山町', '07', '07203', '9630106', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '成山町', 'ナリヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市安積', '07', '07203', '9630107', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '安積', 'アサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市笹川', '07', '07203', '9630108', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '笹川', 'ササガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市安積町吉田', '07', '07203', '9630109', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '安積町吉田', 'アサカマチヨシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市安積町荒井', '07', '07203', '9630111', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '安積町荒井', 'アサカマチアライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市安積町成田', '07', '07203', '9630112', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '安積町成田', 'アサカマチナリタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市安積町牛庭', '07', '07203', '9630113', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '安積町牛庭', 'アサカマチウシニワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市安積町柴宮東', '07', '07203', '9630114', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '安積町', 'アサカマチ', null, null, '柴宮東', 'シバミヤヒガシ');
INSERT INTO `ms_addresses` VALUES ('136629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市三穂田町川田', '07', '07203', '9630121', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '三穂田町川田', 'ミホタマチカワタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市三穂田町野田', '07', '07203', '9630122', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '三穂田町野田', 'ミホタマチノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市三穂田町鍋山', '07', '07203', '9630123', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '三穂田町鍋山', 'ミホタマチナベヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市三穂田町下守屋', '07', '07203', '9630124', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '三穂田町下守屋', 'ミホタマチシモモリヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市三穂田町富岡', '07', '07203', '9630125', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '三穂田町富岡', 'ミホタマチトミオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市三穂田町山口', '07', '07203', '9630126', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '三穂田町山口', 'ミホタマチヤマグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市三穂田町大谷', '07', '07203', '9630127', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '三穂田町大谷', 'ミホタマチオオヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市三穂田町駒屋', '07', '07203', '9630128', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '三穂田町駒屋', 'ミホタマチコマヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市三穂田町八幡', '07', '07203', '9630129', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '三穂田町八幡', 'ミホタマチヤハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市大槻町', '07', '07203', '9630201', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '大槻町', 'オオツキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市柏山町', '07', '07203', '9630202', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '柏山町', 'カシワヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市静町', '07', '07203', '9630203', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '静町', 'シズカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市土瓜', '07', '07203', '9630204', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '土瓜', 'ツチウリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市堤', '07', '07203', '9630205', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '堤', 'ツツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市中野', '07', '07203', '9630206', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '中野', 'ナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市鳴神', '07', '07203', '9630207', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '鳴神', 'ナルガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市谷地', '07', '07203', '9630208', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '谷地', 'ヤジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市片平町', '07', '07203', '9630211', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '片平町', 'カタヒラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市逢瀬町河内', '07', '07203', '9630212', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '逢瀬町河内', 'オウセマチコウズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市逢瀬町多田野', '07', '07203', '9630213', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '逢瀬町多田野', 'オウセマチタダノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市逢瀬町夏出', '07', '07203', '9630214', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '逢瀬町夏出', 'オウセマチナツイデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市待池台', '07', '07203', '9630215', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '待池台', 'マチイケダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市中ノ目', '07', '07203', '9630216', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '中ノ目', 'ナカノメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市亀田西', '07', '07203', '9630221', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '亀田西', 'カメダニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市日和田町高倉', '07', '07203', '9630531', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '日和田町高倉', 'ヒワダマチタカクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市日和田町梅沢', '07', '07203', '9630532', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '日和田町梅沢', 'ヒワダマチウメザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市日和田町八丁目', '07', '07203', '9630533', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '日和田町八丁目', 'ヒワダマチハッチョウメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市日和田町', '07', '07203', '9630534', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '日和田町', 'ヒワダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市喜久田町堀之内', '07', '07203', '9630541', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '喜久田町堀之内', 'キクタマチホリノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市喜久田町原', '07', '07203', '9630542', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '喜久田町原', 'キクタマチハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市喜久田町前田沢', '07', '07203', '9630543', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '喜久田町前田沢', 'キクタマチマエタザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市喜久田町坪沢', '07', '07203', '9630544', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '喜久田町坪沢', 'キクタマチツボサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市喜久田町赤坂', '07', '07203', '9630545', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '喜久田町赤坂', 'キクタマチアカサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市喜久田町早稲原', '07', '07203', '9630546', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '喜久田町早稲原', 'キクタマチワセハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市喜久田町卸', '07', '07203', '9630547', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '喜久田町卸', 'キクタマチオロシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市喜久田町', '07', '07203', '9630551', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '喜久田町', 'キクタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市舞木町', '07', '07203', '9630661', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '舞木町', 'モウギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市白岩町', '07', '07203', '9630662', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '白岩町', 'シライワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市下白岩町', '07', '07203', '9630663', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '下白岩町', 'シモシライワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市あぶくま台', '07', '07203', '9630664', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', 'あぶくま台', 'アブクマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市横川町', '07', '07203', '9630665', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '横川町', 'ヨコカワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市安原町', '07', '07203', '9630666', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '安原町', 'ヤスハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市阿久津町', '07', '07203', '9630667', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '阿久津町', 'アクツマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市富久山町南小泉', '07', '07203', '9630671', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '富久山町南小泉', 'フクヤママチミナミコイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市富久山町北小泉', '07', '07203', '9630672', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '富久山町北小泉', 'フクヤママチキタコイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市富久山町堂坂', '07', '07203', '9630673', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '富久山町堂坂', 'フクヤママチドウザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市緑ケ丘西', '07', '07203', '9630701', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '緑ケ丘西', 'ミドリガオカニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市緑ケ丘東', '07', '07203', '9630702', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '緑ケ丘東', 'ミドリガオカヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市蒲倉町', '07', '07203', '9630703', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '蒲倉町', 'カバクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市荒井町', '07', '07203', '9630704', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '荒井町', 'アライマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市中田町上石', '07', '07203', '9630711', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '中田町上石', 'ナカタマチアゲイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市中田町海老根', '07', '07203', '9630712', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '中田町海老根', 'ナカタマチエビネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市中田町高倉', '07', '07203', '9630713', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '中田町高倉', 'ナカタマチタカクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市中田町赤沼', '07', '07203', '9630714', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '中田町赤沼', 'ナカタマチアカヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市田村町手代木', '07', '07203', '9630721', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '田村町手代木', 'タムラマチテシロギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市田村町小川', '07', '07203', '9630722', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '田村町小川', 'タムラマチコガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市田村町桜ケ丘', '07', '07203', '9630723', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '田村町桜ケ丘', 'タムラマチサクラガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市田村町上行合', '07', '07203', '9630724', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '田村町上行合', 'タムラマチカミユキアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市田村町金屋', '07', '07203', '9630725', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '田村町金屋', 'タムラマチカナヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市田村町下行合', '07', '07203', '9630726', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '田村町下行合', 'タムラマチシモユキアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市中田町柳橋', '07', '07203', '9630831', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '中田町柳橋', 'ナカタマチヤナギハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市中田町中津川', '07', '07203', '9630832', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '中田町中津川', 'ナカタマチナカツガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市中田町下枝', '07', '07203', '9630833', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '中田町下枝', 'ナカタマチシタエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市中田町牛縊本郷', '07', '07203', '9630834', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '中田町牛縊本郷', 'ナカタマチウシクビリホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市中田町黒木', '07', '07203', '9630835', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '中田町黒木', 'ナカタマチクロキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市中田町木目沢', '07', '07203', '9630836', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '中田町木目沢', 'ナカタマチコノメザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市中田町駒板', '07', '07203', '9630837', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '中田町駒板', 'ナカタマチコマイタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市西田町丹伊田', '07', '07203', '9630901', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '西田町丹伊田', 'ニシタマチニイタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市西田町高柴', '07', '07203', '9630902', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '西田町高柴', 'ニシタマチタカシバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市西田町板橋', '07', '07203', '9630903', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '西田町板橋', 'ニシタマチイタハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市西田町土棚', '07', '07203', '9630904', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '西田町土棚', 'ニシタマチツチダナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市西田町大田', '07', '07203', '9630911', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '西田町大田', 'ニシタマチオオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市西田町根木屋', '07', '07203', '9630912', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '西田町根木屋', 'ニシタマチネギヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市西田町芹沢', '07', '07203', '9630913', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '西田町芹沢', 'ニシタマチセリサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市西田町木村', '07', '07203', '9630914', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '西田町木村', 'ニシタマチキムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市西田町鬼生田', '07', '07203', '9630921', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '西田町鬼生田', 'ニシタマチオニウタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市西田町三町目', '07', '07203', '9630922', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '西田町三町目', 'ニシタマチサンチョウメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市西田町黒田', '07', '07203', '9630923', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '西田町黒田', 'ニシタマチクロダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市西田町大網', '07', '07203', '9630924', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '西田町大網', 'ニシタマチオオアミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市西田町阿広木', '07', '07203', '9630925', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '西田町阿広木', 'ニシタマチアコウギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市田村町金沢', '07', '07203', '9631151', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '田村町金沢', 'タムラマチカネザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市田村町細田', '07', '07203', '9631152', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '田村町細田', 'タムラマチホソダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市田村町大供', '07', '07203', '9631153', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '田村町大供', 'タムラマチオオトモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市田村町岩作', '07', '07203', '9631154', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '田村町岩作', 'タムラマチガンザク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市田村町守山', '07', '07203', '9631155', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '田村町守山', 'タムラマチモリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市田村町東山', '07', '07203', '9631156', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '田村町東山', 'タムラマチヒガシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市田村町大善寺', '07', '07203', '9631161', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '田村町大善寺', 'タムラマチダイゼンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市田村町山中', '07', '07203', '9631162', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '田村町山中', 'タムラマチサンチュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市田村町正直', '07', '07203', '9631163', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '田村町正直', 'タムラマチショウジキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市田村町御代田', '07', '07203', '9631164', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '田村町御代田', 'タムラマチミヨダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市田村町徳定', '07', '07203', '9631165', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '田村町徳定', 'タムラマチトクサダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市田村町川曲', '07', '07203', '9631241', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '田村町川曲', 'タムラマチカワマガリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市田村町糠塚', '07', '07203', '9631242', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '田村町糠塚', 'タムラマチヌカヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市田村町田母神', '07', '07203', '9631243', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '田村町田母神', 'タムラマチタモガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市田村町栃本', '07', '07203', '9631244', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '田村町栃本', 'タムラマチトチモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市田村町栃山神', '07', '07203', '9631245', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '田村町栃山神', 'タムラマチトチヤマカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市田村町谷田川', '07', '07203', '9631246', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '田村町谷田川', 'タムラマチヤタガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市田村町下道渡', '07', '07203', '9631247', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '田村町下道渡', 'タムラマチシモミチワタシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市田村町上道渡', '07', '07203', '9631248', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '田村町上道渡', 'タムラマチカミミチワタシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市熱海町石筵', '07', '07203', '9631301', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '熱海町石筵', 'アタミマチイシムシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市熱海町高玉', '07', '07203', '9631302', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '熱海町高玉', 'アタミマチタカタマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市熱海町玉川', '07', '07203', '9631303', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '熱海町玉川', 'アタミマチタマガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市熱海町安子島', '07', '07203', '9631304', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '熱海町安子島', 'アタミマチアコガシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市熱海町下伊豆島', '07', '07203', '9631305', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '熱海町下伊豆島', 'アタミマチシモイズシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市熱海町上伊豆島', '07', '07203', '9631306', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '熱海町上伊豆島', 'アタミマチカミイズシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市熱海町長橋', '07', '07203', '9631307', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '熱海町長橋', 'アタミマチナガハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市熱海町中山', '07', '07203', '9631308', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '熱海町中山', 'アタミマチナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市熱海町熱海', '07', '07203', '9631309', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '熱海町熱海', 'アタミマチアタミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市湖南町舟津', '07', '07203', '9631411', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '湖南町舟津', 'コナンマチフナツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市湖南町舘', '07', '07203', '9631412', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '湖南町舘', 'コナンマチタテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市湖南町横沢', '07', '07203', '9631413', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '湖南町横沢', 'コナンマチヨコサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市湖南町浜路', '07', '07203', '9631414', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '湖南町浜路', 'コナンマチハマジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市湖南町中野', '07', '07203', '9631521', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '湖南町中野', 'コナンマチナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市湖南町三代', '07', '07203', '9631522', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '湖南町三代', 'コナンマチミヨ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市湖南町赤津', '07', '07203', '9631631', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '湖南町赤津', 'コナンマチアカツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市湖南町馬入新田', '07', '07203', '9631632', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '湖南町馬入新田', 'コナンマチバニュウシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市湖南町福良', '07', '07203', '9631633', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '湖南町福良', 'コナンマチフクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡小野町湯沢', '07', '07522', '9633311', '福島県', 'フクシマケン', '田村郡小野町', 'タムラグンオノマチ', '湯沢', 'ユザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡小野町夏井', '07', '07522', '9633312', '福島県', 'フクシマケン', '田村郡小野町', 'タムラグンオノマチ', '夏井', 'ナツイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡小野町南田原井', '07', '07522', '9633313', '福島県', 'フクシマケン', '田村郡小野町', 'タムラグンオノマチ', '南田原井', 'ミナミタワライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡小野町塩庭', '07', '07522', '9633314', '福島県', 'フクシマケン', '田村郡小野町', 'タムラグンオノマチ', '塩庭', 'シオニワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡小野町和名田', '07', '07522', '9633315', '福島県', 'フクシマケン', '田村郡小野町', 'タムラグンオノマチ', '和名田', 'ワナダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡小野町上羽出庭', '07', '07522', '9633316', '福島県', 'フクシマケン', '田村郡小野町', 'タムラグンオノマチ', '上羽出庭', 'カミハデニワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡小野町', '07', '07522', '9633400', '福島県', 'フクシマケン', '田村郡小野町', 'タムラグンオノマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('136763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡小野町小野新町', '07', '07522', '9633401', '福島県', 'フクシマケン', '田村郡小野町', 'タムラグンオノマチ', '小野新町', 'オノニイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡小野町谷津作', '07', '07522', '9633402', '福島県', 'フクシマケン', '田村郡小野町', 'タムラグンオノマチ', '谷津作', 'ヤツザク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡小野町小野赤沼', '07', '07522', '9633403', '福島県', 'フクシマケン', '田村郡小野町', 'タムラグンオノマチ', '小野赤沼', 'オノアカヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡小野町菖蒲谷', '07', '07522', '9633404', '福島県', 'フクシマケン', '田村郡小野町', 'タムラグンオノマチ', '菖蒲谷', 'ショウブヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡小野町雁股田', '07', '07522', '9633405', '福島県', 'フクシマケン', '田村郡小野町', 'タムラグンオノマチ', '雁股田', 'カリマンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡小野町皮籠石', '07', '07522', '9633406', '福島県', 'フクシマケン', '田村郡小野町', 'タムラグンオノマチ', '皮籠石', 'カワゴイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡小野町飯豊', '07', '07522', '9633521', '福島県', 'フクシマケン', '田村郡小野町', 'タムラグンオノマチ', '飯豊', 'イイトヨ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡小野町小戸神', '07', '07522', '9633522', '福島県', 'フクシマケン', '田村郡小野町', 'タムラグンオノマチ', '小戸神', 'オトカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡小野町小野山神', '07', '07522', '9633523', '福島県', 'フクシマケン', '田村郡小野町', 'タムラグンオノマチ', '小野山神', 'オノヤマカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡小野町浮金', '07', '07522', '9633524', '福島県', 'フクシマケン', '田村郡小野町', 'タムラグンオノマチ', '浮金', 'ウキガネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡小野町吉野辺', '07', '07522', '9633525', '福島県', 'フクシマケン', '田村郡小野町', 'タムラグンオノマチ', '吉野辺', 'ヨシノベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村市滝根町菅谷', '07', '07211', '9633601', '福島県', 'フクシマケン', '田村市', 'タムラシ', '滝根町菅谷', 'タキネマチスガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村市滝根町神俣', '07', '07211', '9633602', '福島県', 'フクシマケン', '田村市', 'タムラシ', '滝根町神俣', 'タキネマチカンマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村市滝根町広瀬', '07', '07211', '9633603', '福島県', 'フクシマケン', '田村市', 'タムラシ', '滝根町広瀬', 'タキネマチヒロセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村市大越町上大越', '07', '07211', '9634111', '福島県', 'フクシマケン', '田村市', 'タムラシ', '大越町上大越', 'オオゴエマチカミオオゴエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村市大越町下大越', '07', '07211', '9634112', '福島県', 'フクシマケン', '田村市', 'タムラシ', '大越町下大越', 'オオゴエマチシモオオゴエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村市大越町早稲川', '07', '07211', '9634113', '福島県', 'フクシマケン', '田村市', 'タムラシ', '大越町早稲川', 'オオゴエマチワセガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村市大越町牧野', '07', '07211', '9634114', '福島県', 'フクシマケン', '田村市', 'タムラシ', '大越町牧野', 'オオゴエマチマギノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村市大越町栗出', '07', '07211', '9634115', '福島県', 'フクシマケン', '田村市', 'タムラシ', '大越町栗出', 'オオゴエマチクリデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村市船引町永谷', '07', '07211', '9634201', '福島県', 'フクシマケン', '田村市', 'タムラシ', '船引町永谷', 'フネヒキマチナガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村市船引町椚山', '07', '07211', '9634202', '福島県', 'フクシマケン', '田村市', 'タムラシ', '船引町椚山', 'フネヒキマチクヌギヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村市船引町門沢', '07', '07211', '9634203', '福島県', 'フクシマケン', '田村市', 'タムラシ', '船引町門沢', 'フネヒキマチカドサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村市船引町堀越', '07', '07211', '9634204', '福島県', 'フクシマケン', '田村市', 'タムラシ', '船引町堀越', 'フネヒキマチホリコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村市船引町遠山沢', '07', '07211', '9634205', '福島県', 'フクシマケン', '田村市', 'タムラシ', '船引町遠山沢', 'フネヒキマチトオヤマザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村市', '07', '07211', '9634300', '福島県', 'フクシマケン', '田村市', 'タムラシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('136791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村市船引町今泉', '07', '07211', '9634311', '福島県', 'フクシマケン', '田村市', 'タムラシ', '船引町今泉', 'フネヒキマチイマイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村市船引町船引', '07', '07211', '9634312', '福島県', 'フクシマケン', '田村市', 'タムラシ', '船引町船引', 'フネヒキマチフネヒキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村市船引町石森', '07', '07211', '9634313', '福島県', 'フクシマケン', '田村市', 'タムラシ', '船引町石森', 'フネヒキマチイシモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村市船引町文珠', '07', '07211', '9634314', '福島県', 'フクシマケン', '田村市', 'タムラシ', '船引町文珠', 'フネヒキマチモンジュ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村市船引町春山', '07', '07211', '9634315', '福島県', 'フクシマケン', '田村市', 'タムラシ', '船引町春山', 'フネヒキマチハルヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村市船引町芦沢', '07', '07211', '9634316', '福島県', 'フクシマケン', '田村市', 'タムラシ', '船引町芦沢', 'フネヒキマチアシザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村市船引町東部台', '07', '07211', '9634317', '福島県', 'フクシマケン', '田村市', 'タムラシ', '船引町東部台', 'フネヒキマチトウブダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村市船引町光陽台', '07', '07211', '9634318', '福島県', 'フクシマケン', '田村市', 'タムラシ', '船引町光陽台', 'フネヒキマチコウヨウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村市船引町笹山', '07', '07211', '9634321', '福島県', 'フクシマケン', '田村市', 'タムラシ', '船引町笹山', 'フネヒキマチササヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村市船引町荒和田', '07', '07211', '9634322', '福島県', 'フクシマケン', '田村市', 'タムラシ', '船引町荒和田', 'フネヒキマチアラワタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村市船引町要田', '07', '07211', '9634323', '福島県', 'フクシマケン', '田村市', 'タムラシ', '船引町要田', 'フネヒキマチカナメタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村市船引町成田', '07', '07211', '9634324', '福島県', 'フクシマケン', '田村市', 'タムラシ', '船引町成田', 'フネヒキマチナリタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村市船引町石沢', '07', '07211', '9634431', '福島県', 'フクシマケン', '田村市', 'タムラシ', '船引町石沢', 'フネヒキマチイシザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村市船引町長外路', '07', '07211', '9634432', '福島県', 'フクシマケン', '田村市', 'タムラシ', '船引町長外路', 'フネヒキマチナガトロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村市船引町北鹿又', '07', '07211', '9634433', '福島県', 'フクシマケン', '田村市', 'タムラシ', '船引町北鹿又', 'フネヒキマチキタカノマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村市船引町門鹿', '07', '07211', '9634434', '福島県', 'フクシマケン', '田村市', 'タムラシ', '船引町門鹿', 'フネヒキマチカドシカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村市船引町大倉', '07', '07211', '9634435', '福島県', 'フクシマケン', '田村市', 'タムラシ', '船引町大倉', 'フネヒキマチオオクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村市船引町新舘', '07', '07211', '9634436', '福島県', 'フクシマケン', '田村市', 'タムラシ', '船引町新舘', 'フネヒキマチニイタテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村市船引町上移', '07', '07211', '9634541', '福島県', 'フクシマケン', '田村市', 'タムラシ', '船引町上移', 'フネヒキマチカミウツシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村市船引町横道', '07', '07211', '9634542', '福島県', 'フクシマケン', '田村市', 'タムラシ', '船引町横道', 'フネヒキマチヨコミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村市船引町中山', '07', '07211', '9634543', '福島県', 'フクシマケン', '田村市', 'タムラシ', '船引町中山', 'フネヒキマチナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村市船引町南移', '07', '07211', '9634544', '福島県', 'フクシマケン', '田村市', 'タムラシ', '船引町南移', 'フネヒキマチミナミウツシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村市船引町北移', '07', '07211', '9634545', '福島県', 'フクシマケン', '田村市', 'タムラシ', '船引町北移', 'フネヒキマチキタウツシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村市常葉町山根', '07', '07211', '9634601', '福島県', 'フクシマケン', '田村市', 'タムラシ', '常葉町山根', 'トキワマチヤマネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村市常葉町常葉', '07', '07211', '9634602', '福島県', 'フクシマケン', '田村市', 'タムラシ', '常葉町常葉', 'トキワマチトキワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村市常葉町西向', '07', '07211', '9634603', '福島県', 'フクシマケン', '田村市', 'タムラシ', '常葉町西向', 'トキワマチニシムキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村市常葉町鹿山', '07', '07211', '9634604', '福島県', 'フクシマケン', '田村市', 'タムラシ', '常葉町鹿山', 'トキワマチカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村市常葉町久保', '07', '07211', '9634605', '福島県', 'フクシマケン', '田村市', 'タムラシ', '常葉町久保', 'トキワマチクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村市常葉町新田作', '07', '07211', '9634606', '福島県', 'フクシマケン', '田村市', 'タムラシ', '常葉町新田作', 'トキワマチニッタサク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村市常葉町堀田', '07', '07211', '9634611', '福島県', 'フクシマケン', '田村市', 'タムラシ', '常葉町堀田', 'トキワマチホッタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村市常葉町早稲川', '07', '07211', '9634612', '福島県', 'フクシマケン', '田村市', 'タムラシ', '常葉町早稲川', 'トキワマチワセガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村市常葉町関本', '07', '07211', '9634613', '福島県', 'フクシマケン', '田村市', 'タムラシ', '常葉町関本', 'トキワマチセキモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村市常葉町小桧山', '07', '07211', '9634614', '福島県', 'フクシマケン', '田村市', 'タムラシ', '常葉町小桧山', 'トキワマチコビヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村市都路町古道', '07', '07211', '9634701', '福島県', 'フクシマケン', '田村市', 'タムラシ', '都路町古道', 'ミヤコジマチフルミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村市都路町岩井沢', '07', '07211', '9634702', '福島県', 'フクシマケン', '田村市', 'タムラシ', '都路町岩井沢', 'ミヤコジマチイワイザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県東白川郡矢祭町', '07', '07482', '9635100', '福島県', 'フクシマケン', '東白川郡矢祭町', 'ヒガシシラカワグンヤマツリマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('136831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県東白川郡矢祭町金沢', '07', '07482', '9635111', '福島県', 'フクシマケン', '東白川郡矢祭町', 'ヒガシシラカワグンヤマツリマチ', '金沢', 'カネザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県東白川郡矢祭町宝坂', '07', '07482', '9635112', '福島県', 'フクシマケン', '東白川郡矢祭町', 'ヒガシシラカワグンヤマツリマチ', '宝坂', 'ホウザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県東白川郡矢祭町下関河内', '07', '07482', '9635113', '福島県', 'フクシマケン', '東白川郡矢祭町', 'ヒガシシラカワグンヤマツリマチ', '下関河内', 'シモセキゴウド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県東白川郡矢祭町大ぬかり', '07', '07482', '9635114', '福島県', 'フクシマケン', '東白川郡矢祭町', 'ヒガシシラカワグンヤマツリマチ', '大ぬかり', 'オオヌカリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県東白川郡矢祭町上関河内', '07', '07482', '9635115', '福島県', 'フクシマケン', '東白川郡矢祭町', 'ヒガシシラカワグンヤマツリマチ', '上関河内', 'カミセキゴウド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県東白川郡矢祭町高野', '07', '07482', '9635116', '福島県', 'フクシマケン', '東白川郡矢祭町', 'ヒガシシラカワグンヤマツリマチ', '高野', 'コウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県東白川郡矢祭町山下', '07', '07482', '9635117', '福島県', 'フクシマケン', '東白川郡矢祭町', 'ヒガシシラカワグンヤマツリマチ', '山下', 'ヤマシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県東白川郡矢祭町東舘', '07', '07482', '9635118', '福島県', 'フクシマケン', '東白川郡矢祭町', 'ヒガシシラカワグンヤマツリマチ', '東舘', 'ヒガシタテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県東白川郡矢祭町小田川', '07', '07482', '9635119', '福島県', 'フクシマケン', '東白川郡矢祭町', 'ヒガシシラカワグンヤマツリマチ', '小田川', 'オダガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県東白川郡矢祭町中石井', '07', '07482', '9635201', '福島県', 'フクシマケン', '東白川郡矢祭町', 'ヒガシシラカワグンヤマツリマチ', '中石井', 'ナカイシイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県東白川郡矢祭町下石井', '07', '07482', '9635202', '福島県', 'フクシマケン', '東白川郡矢祭町', 'ヒガシシラカワグンヤマツリマチ', '下石井', 'シモイシイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県東白川郡矢祭町戸塚', '07', '07482', '9635203', '福島県', 'フクシマケン', '東白川郡矢祭町', 'ヒガシシラカワグンヤマツリマチ', '戸塚', 'トツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県東白川郡矢祭町関岡', '07', '07482', '9635321', '福島県', 'フクシマケン', '東白川郡矢祭町', 'ヒガシシラカワグンヤマツリマチ', '関岡', 'セキオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県東白川郡矢祭町内川', '07', '07482', '9635322', '福島県', 'フクシマケン', '東白川郡矢祭町', 'ヒガシシラカワグンヤマツリマチ', '内川', 'ウチカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県東白川郡矢祭町茗荷', '07', '07482', '9635323', '福島県', 'フクシマケン', '東白川郡矢祭町', 'ヒガシシラカワグンヤマツリマチ', '茗荷', 'ミョウガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県東白川郡塙町台宿', '07', '07483', '9635341', '福島県', 'フクシマケン', '東白川郡塙町', 'ヒガシシラカワグンハナワマチ', '台宿', 'ダイジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県東白川郡塙町伊香', '07', '07483', '9635342', '福島県', 'フクシマケン', '東白川郡塙町', 'ヒガシシラカワグンハナワマチ', '伊香', 'イコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県東白川郡塙町植田', '07', '07483', '9635343', '福島県', 'フクシマケン', '東白川郡塙町', 'ヒガシシラカワグンハナワマチ', '植田', 'ウエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県東白川郡塙町真名畑', '07', '07483', '9635344', '福島県', 'フクシマケン', '東白川郡塙町', 'ヒガシシラカワグンハナワマチ', '真名畑', 'マナハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県東白川郡塙町', '07', '07483', '9635400', '福島県', 'フクシマケン', '東白川郡塙町', 'ヒガシシラカワグンハナワマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('136852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県東白川郡塙町東河内', '07', '07483', '9635401', '福島県', 'フクシマケン', '東白川郡塙町', 'ヒガシシラカワグンハナワマチ', '東河内', 'ヒガシゴウド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県東白川郡塙町常世北野', '07', '07483', '9635402', '福島県', 'フクシマケン', '東白川郡塙町', 'ヒガシシラカワグンハナワマチ', '常世北野', 'トコヨキタノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県東白川郡塙町常世中野', '07', '07483', '9635403', '福島県', 'フクシマケン', '東白川郡塙町', 'ヒガシシラカワグンハナワマチ', '常世中野', 'トコヨナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県東白川郡塙町竹之内', '07', '07483', '9635404', '福島県', 'フクシマケン', '東白川郡塙町', 'ヒガシシラカワグンハナワマチ', '竹之内', 'タケノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県東白川郡塙町塙', '07', '07483', '9635405', '福島県', 'フクシマケン', '東白川郡塙町', 'ヒガシシラカワグンハナワマチ', '塙', 'ハナワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県東白川郡塙町上渋井', '07', '07483', '9635406', '福島県', 'フクシマケン', '東白川郡塙町', 'ヒガシシラカワグンハナワマチ', '上渋井', 'カミシブイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県東白川郡塙町西河内', '07', '07483', '9635407', '福島県', 'フクシマケン', '東白川郡塙町', 'ヒガシシラカワグンハナワマチ', '西河内', 'ニシゴウド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県東白川郡塙町堀越', '07', '07483', '9635408', '福島県', 'フクシマケン', '東白川郡塙町', 'ヒガシシラカワグンハナワマチ', '堀越', 'ホリゴシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県東白川郡塙町上石井', '07', '07483', '9635411', '福島県', 'フクシマケン', '東白川郡塙町', 'ヒガシシラカワグンハナワマチ', '上石井', 'カミイシイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県東白川郡鮫川村渡瀬', '07', '07484', '9635505', '福島県', 'フクシマケン', '東白川郡鮫川村', 'ヒガシシラカワグンサメガワムラ', '渡瀬', 'ワタラセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県東白川郡塙町那倉', '07', '07483', '9635521', '福島県', 'フクシマケン', '東白川郡塙町', 'ヒガシシラカワグンハナワマチ', '那倉', 'ナグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県東白川郡塙町片貝', '07', '07483', '9635522', '福島県', 'フクシマケン', '東白川郡塙町', 'ヒガシシラカワグンハナワマチ', '片貝', 'カタカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県東白川郡塙町田代', '07', '07483', '9635531', '福島県', 'フクシマケン', '東白川郡塙町', 'ヒガシシラカワグンハナワマチ', '田代', 'タシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県東白川郡塙町大蕨', '07', '07483', '9635532', '福島県', 'フクシマケン', '東白川郡塙町', 'ヒガシシラカワグンハナワマチ', '大蕨', 'オオワラビ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県東白川郡塙町湯岐', '07', '07483', '9635533', '福島県', 'フクシマケン', '東白川郡塙町', 'ヒガシシラカワグンハナワマチ', '湯岐', 'ユジマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県東白川郡塙町木野反', '07', '07483', '9635534', '福島県', 'フクシマケン', '東白川郡塙町', 'ヒガシシラカワグンハナワマチ', '木野反', 'キノソリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県東白川郡塙町山形', '07', '07483', '9635535', '福島県', 'フクシマケン', '東白川郡塙町', 'ヒガシシラカワグンハナワマチ', '山形', 'ヤマガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県東白川郡塙町川上', '07', '07483', '9635536', '福島県', 'フクシマケン', '東白川郡塙町', 'ヒガシシラカワグンハナワマチ', '川上', 'カワカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県東白川郡塙町板庭', '07', '07483', '9635537', '福島県', 'フクシマケン', '東白川郡塙町', 'ヒガシシラカワグンハナワマチ', '板庭', 'イタニワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県東白川郡塙町中塚', '07', '07483', '9635538', '福島県', 'フクシマケン', '東白川郡塙町', 'ヒガシシラカワグンハナワマチ', '中塚', 'ナカツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県東白川郡塙町田野作', '07', '07483', '9635539', '福島県', 'フクシマケン', '東白川郡塙町', 'ヒガシシラカワグンハナワマチ', '田野作', 'タノサク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県東白川郡棚倉町山田', '07', '07481', '9635661', '福島県', 'フクシマケン', '東白川郡棚倉町', 'ヒガシシラカワグンタナグラマチ', '山田', 'ヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県東白川郡棚倉町岡田', '07', '07481', '9635662', '福島県', 'フクシマケン', '東白川郡棚倉町', 'ヒガシシラカワグンタナグラマチ', '岡田', 'オカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県東白川郡棚倉町流', '07', '07481', '9635663', '福島県', 'フクシマケン', '東白川郡棚倉町', 'ヒガシシラカワグンタナグラマチ', '流', 'ナガレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県東白川郡棚倉町塚原', '07', '07481', '9635664', '福島県', 'フクシマケン', '東白川郡棚倉町', 'ヒガシシラカワグンタナグラマチ', '塚原', 'ツカハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県東白川郡棚倉町寺山', '07', '07481', '9635671', '福島県', 'フクシマケン', '東白川郡棚倉町', 'ヒガシシラカワグンタナグラマチ', '寺山', 'テラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県東白川郡棚倉町八槻', '07', '07481', '9635672', '福島県', 'フクシマケン', '東白川郡棚倉町', 'ヒガシシラカワグンタナグラマチ', '八槻', 'ヤツキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県東白川郡棚倉町上手沢', '07', '07481', '9635681', '福島県', 'フクシマケン', '東白川郡棚倉町', 'ヒガシシラカワグンタナグラマチ', '上手沢', 'カミテザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県東白川郡棚倉町下手沢', '07', '07481', '9635682', '福島県', 'フクシマケン', '東白川郡棚倉町', 'ヒガシシラカワグンタナグラマチ', '下手沢', 'シモテザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県東白川郡棚倉町下山本', '07', '07481', '9635683', '福島県', 'フクシマケン', '東白川郡棚倉町', 'ヒガシシラカワグンタナグラマチ', '下山本', 'シモヤマモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県東白川郡棚倉町中山本', '07', '07481', '9635684', '福島県', 'フクシマケン', '東白川郡棚倉町', 'ヒガシシラカワグンタナグラマチ', '中山本', 'ナカヤマモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県東白川郡棚倉町北山本', '07', '07481', '9635685', '福島県', 'フクシマケン', '東白川郡棚倉町', 'ヒガシシラカワグンタナグラマチ', '北山本', 'キタヤマモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県東白川郡棚倉町', '07', '07481', '9636100', '福島県', 'フクシマケン', '東白川郡棚倉町', 'ヒガシシラカワグンタナグラマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('136888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県東白川郡棚倉町堤', '07', '07481', '9636101', '福島県', 'フクシマケン', '東白川郡棚倉町', 'ヒガシシラカワグンタナグラマチ', '堤', 'ツツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県東白川郡棚倉町天王内', '07', '07481', '9636102', '福島県', 'フクシマケン', '東白川郡棚倉町', 'ヒガシシラカワグンタナグラマチ', '天王内', 'テンノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県東白川郡棚倉町逆川', '07', '07481', '9636103', '福島県', 'フクシマケン', '東白川郡棚倉町', 'ヒガシシラカワグンタナグラマチ', '逆川', 'サカサガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県東白川郡棚倉町檜木', '07', '07481', '9636104', '福島県', 'フクシマケン', '東白川郡棚倉町', 'ヒガシシラカワグンタナグラマチ', '檜木', 'ヒノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県東白川郡棚倉町小菅生', '07', '07481', '9636105', '福島県', 'フクシマケン', '東白川郡棚倉町', 'ヒガシシラカワグンタナグラマチ', '小菅生', 'コスゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県東白川郡棚倉町金沢内', '07', '07481', '9636106', '福島県', 'フクシマケン', '東白川郡棚倉町', 'ヒガシシラカワグンタナグラマチ', '金沢内', 'カナザワウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県東白川郡棚倉町一色', '07', '07481', '9636111', '福島県', 'フクシマケン', '東白川郡棚倉町', 'ヒガシシラカワグンタナグラマチ', '一色', 'イッシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県東白川郡棚倉町玉野', '07', '07481', '9636112', '福島県', 'フクシマケン', '東白川郡棚倉町', 'ヒガシシラカワグンタナグラマチ', '玉野', 'タマノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県東白川郡棚倉町板橋', '07', '07481', '9636113', '福島県', 'フクシマケン', '東白川郡棚倉町', 'ヒガシシラカワグンタナグラマチ', '板橋', 'イタバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県東白川郡棚倉町上台', '07', '07481', '9636114', '福島県', 'フクシマケン', '東白川郡棚倉町', 'ヒガシシラカワグンタナグラマチ', '上台', 'ウワダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県東白川郡棚倉町福井', '07', '07481', '9636115', '福島県', 'フクシマケン', '東白川郡棚倉町', 'ヒガシシラカワグンタナグラマチ', '福井', 'フクイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県東白川郡棚倉町花園', '07', '07481', '9636121', '福島県', 'フクシマケン', '東白川郡棚倉町', 'ヒガシシラカワグンタナグラマチ', '花園', 'ハナゾノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県東白川郡棚倉町仁公儀', '07', '07481', '9636122', '福島県', 'フクシマケン', '東白川郡棚倉町', 'ヒガシシラカワグンタナグラマチ', '仁公儀', 'ニコウギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県東白川郡棚倉町関口', '07', '07481', '9636123', '福島県', 'フクシマケン', '東白川郡棚倉町', 'ヒガシシラカワグンタナグラマチ', '関口', 'セキグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県東白川郡棚倉町棚倉', '07', '07481', '9636131', '福島県', 'フクシマケン', '東白川郡棚倉町', 'ヒガシシラカワグンタナグラマチ', '棚倉', 'タナグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県東白川郡棚倉町富岡', '07', '07481', '9636141', '福島県', 'フクシマケン', '東白川郡棚倉町', 'ヒガシシラカワグンタナグラマチ', '富岡', 'トミオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県東白川郡棚倉町山際', '07', '07481', '9636142', '福島県', 'フクシマケン', '東白川郡棚倉町', 'ヒガシシラカワグンタナグラマチ', '山際', 'ヤマギワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県東白川郡棚倉町福岡', '07', '07481', '9636143', '福島県', 'フクシマケン', '東白川郡棚倉町', 'ヒガシシラカワグンタナグラマチ', '福岡', 'フクオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県東白川郡棚倉町強梨', '07', '07481', '9636144', '福島県', 'フクシマケン', '東白川郡棚倉町', 'ヒガシシラカワグンタナグラマチ', '強梨', 'コワナシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県東白川郡棚倉町大梅', '07', '07481', '9636145', '福島県', 'フクシマケン', '東白川郡棚倉町', 'ヒガシシラカワグンタナグラマチ', '大梅', 'オオメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県東白川郡棚倉町戸中', '07', '07481', '9636146', '福島県', 'フクシマケン', '東白川郡棚倉町', 'ヒガシシラカワグンタナグラマチ', '戸中', 'トチュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県東白川郡棚倉町漆草', '07', '07481', '9636147', '福島県', 'フクシマケン', '東白川郡棚倉町', 'ヒガシシラカワグンタナグラマチ', '漆草', 'ウルシノクサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県東白川郡棚倉町祝部内', '07', '07481', '9636151', '福島県', 'フクシマケン', '東白川郡棚倉町', 'ヒガシシラカワグンタナグラマチ', '祝部内', 'ホウリウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県東白川郡棚倉町小爪', '07', '07481', '9636152', '福島県', 'フクシマケン', '東白川郡棚倉町', 'ヒガシシラカワグンタナグラマチ', '小爪', 'コヅメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県東白川郡棚倉町瀬ケ野', '07', '07481', '9636153', '福島県', 'フクシマケン', '東白川郡棚倉町', 'ヒガシシラカワグンタナグラマチ', '瀬ケ野', 'セガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡浅川町', '07', '07504', '9636200', '福島県', 'フクシマケン', '石川郡浅川町', 'イシカワグンアサカワマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('136915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡浅川町福貴作', '07', '07504', '9636201', '福島県', 'フクシマケン', '石川郡浅川町', 'イシカワグンアサカワマチ', '福貴作', 'フキザク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡浅川町里白石', '07', '07504', '9636202', '福島県', 'フクシマケン', '石川郡浅川町', 'イシカワグンアサカワマチ', '里白石', 'サトシライシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡浅川町山白石', '07', '07504', '9636203', '福島県', 'フクシマケン', '石川郡浅川町', 'イシカワグンアサカワマチ', '山白石', 'ヤマシライシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡浅川町浅川', '07', '07504', '9636204', '福島県', 'フクシマケン', '石川郡浅川町', 'イシカワグンアサカワマチ', '浅川', 'アサカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡浅川町滝輪', '07', '07504', '9636205', '福島県', 'フクシマケン', '石川郡浅川町', 'イシカワグンアサカワマチ', '滝輪', 'タキワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡浅川町太田輪', '07', '07504', '9636206', '福島県', 'フクシマケン', '石川郡浅川町', 'イシカワグンアサカワマチ', '太田輪', 'オオタワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡浅川町小貫', '07', '07504', '9636207', '福島県', 'フクシマケン', '石川郡浅川町', 'イシカワグンアサカワマチ', '小貫', 'オヌキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡浅川町染', '07', '07504', '9636208', '福島県', 'フクシマケン', '石川郡浅川町', 'イシカワグンアサカワマチ', '染', 'ソメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡浅川町畑田', '07', '07504', '9636211', '福島県', 'フクシマケン', '石川郡浅川町', 'イシカワグンアサカワマチ', '畑田', 'ハタダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡浅川町松野入', '07', '07504', '9636212', '福島県', 'フクシマケン', '石川郡浅川町', 'イシカワグンアサカワマチ', '松野入', 'マツノイリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡浅川町中里', '07', '07504', '9636213', '福島県', 'フクシマケン', '石川郡浅川町', 'イシカワグンアサカワマチ', '中里', 'ナカザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡浅川町大草', '07', '07504', '9636214', '福島県', 'フクシマケン', '石川郡浅川町', 'イシカワグンアサカワマチ', '大草', 'オオクサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡浅川町根岸', '07', '07504', '9636215', '福島県', 'フクシマケン', '石川郡浅川町', 'イシカワグンアサカワマチ', '根岸', 'ネギシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡浅川町袖山', '07', '07504', '9636216', '福島県', 'フクシマケン', '石川郡浅川町', 'イシカワグンアサカワマチ', '袖山', 'ソデヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡浅川町簑輪', '07', '07504', '9636217', '福島県', 'フクシマケン', '石川郡浅川町', 'イシカワグンアサカワマチ', '簑輪', 'ミノワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡浅川町東大畑', '07', '07504', '9636218', '福島県', 'フクシマケン', '石川郡浅川町', 'イシカワグンアサカワマチ', '東大畑', 'ヒガシオオハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡玉川村', '07', '07502', '9636300', '福島県', 'フクシマケン', '石川郡玉川村', 'イシカワグンタマカワムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('136933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡玉川村四辻新田', '07', '07502', '9636301', '福島県', 'フクシマケン', '石川郡玉川村', 'イシカワグンタマカワムラ', '四辻新田', 'ヨッツジシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡玉川村南須釜', '07', '07502', '9636302', '福島県', 'フクシマケン', '石川郡玉川村', 'イシカワグンタマカワムラ', '南須釜', 'ミナミスガマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡玉川村吉', '07', '07502', '9636303', '福島県', 'フクシマケン', '石川郡玉川村', 'イシカワグンタマカワムラ', '吉', 'ヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡玉川村北須釜', '07', '07502', '9636304', '福島県', 'フクシマケン', '石川郡玉川村', 'イシカワグンタマカワムラ', '北須釜', 'キタスガマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡玉川村山小屋', '07', '07502', '9636305', '福島県', 'フクシマケン', '石川郡玉川村', 'イシカワグンタマカワムラ', '山小屋', 'ヤマゴヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡玉川村山新田', '07', '07502', '9636306', '福島県', 'フクシマケン', '石川郡玉川村', 'イシカワグンタマカワムラ', '山新田', 'ヤマシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡玉川村岩法寺', '07', '07502', '9636311', '福島県', 'フクシマケン', '石川郡玉川村', 'イシカワグンタマカワムラ', '岩法寺', 'ガンポウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡玉川村小高', '07', '07502', '9636312', '福島県', 'フクシマケン', '石川郡玉川村', 'イシカワグンタマカワムラ', '小高', 'オダカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡玉川村川辺', '07', '07502', '9636313', '福島県', 'フクシマケン', '石川郡玉川村', 'イシカワグンタマカワムラ', '川辺', 'カワベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡玉川村蒜生', '07', '07502', '9636314', '福島県', 'フクシマケン', '石川郡玉川村', 'イシカワグンタマカワムラ', '蒜生', 'ヒリュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡玉川村中', '07', '07502', '9636315', '福島県', 'フクシマケン', '石川郡玉川村', 'イシカワグンタマカワムラ', '中', 'ナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡玉川村竜崎', '07', '07502', '9636316', '福島県', 'フクシマケン', '石川郡玉川村', 'イシカワグンタマカワムラ', '竜崎', 'タツザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡三春町', '07', '07521', '9637700', '福島県', 'フクシマケン', '田村郡三春町', 'タムラグンミハルマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('136947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡三春町実沢', '07', '07521', '9637701', '福島県', 'フクシマケン', '田村郡三春町', 'タムラグンミハルマチ', '実沢', 'サネザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡三春町青石', '07', '07521', '9637702', '福島県', 'フクシマケン', '田村郡三春町', 'タムラグンミハルマチ', '青石', 'アオイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡三春町庄司', '07', '07521', '9637703', '福島県', 'フクシマケン', '田村郡三春町', 'タムラグンミハルマチ', '庄司', 'ショウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡三春町熊耳', '07', '07521', '9637704', '福島県', 'フクシマケン', '田村郡三春町', 'タムラグンミハルマチ', '熊耳', 'クマガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡三春町天王下', '07', '07521', '9637705', '福島県', 'フクシマケン', '田村郡三春町', 'タムラグンミハルマチ', '天王下', 'テンノウシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡三春町大平', '07', '07521', '9637706', '福島県', 'フクシマケン', '田村郡三春町', 'タムラグンミハルマチ', '大平', 'オオダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡三春町芹ケ沢', '07', '07521', '9637707', '福島県', 'フクシマケン', '田村郡三春町', 'タムラグンミハルマチ', '芹ケ沢', 'セリガサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡三春町栗林', '07', '07521', '9637708', '福島県', 'フクシマケン', '田村郡三春町', 'タムラグンミハルマチ', '栗林', 'クリバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡三春町小滝', '07', '07521', '9637709', '福島県', 'フクシマケン', '田村郡三春町', 'タムラグンミハルマチ', '小滝', 'コダキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡三春町桜ケ丘', '07', '07521', '9637711', '福島県', 'フクシマケン', '田村郡三春町', 'タムラグンミハルマチ', '桜ケ丘', 'サクラガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡三春町込木', '07', '07521', '9637712', '福島県', 'フクシマケン', '田村郡三春町', 'タムラグンミハルマチ', '込木', 'クグリキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡三春町八方谷', '07', '07521', '9637712', '福島県', 'フクシマケン', '田村郡三春町', 'タムラグンミハルマチ', '八方谷', 'ハッポウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡三春町楽内', '07', '07521', '9637712', '福島県', 'フクシマケン', '田村郡三春町', 'タムラグンミハルマチ', '楽内', 'ラクウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡三春町柴原', '07', '07521', '9637713', '福島県', 'フクシマケン', '田村郡三春町', 'タムラグンミハルマチ', '柴原', 'シバハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡三春町滝', '07', '07521', '9637714', '福島県', 'フクシマケン', '田村郡三春町', 'タムラグンミハルマチ', '滝', 'タキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡三春町樋渡', '07', '07521', '9637715', '福島県', 'フクシマケン', '田村郡三春町', 'タムラグンミハルマチ', '樋渡', 'ヒワタシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡三春町根本', '07', '07521', '9637716', '福島県', 'フクシマケン', '田村郡三春町', 'タムラグンミハルマチ', '根本', 'ネモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡三春町蛇石', '07', '07521', '9637716', '福島県', 'フクシマケン', '田村郡三春町', 'タムラグンミハルマチ', '蛇石', 'ヘビイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡三春町狐田', '07', '07521', '9637717', '福島県', 'フクシマケン', '田村郡三春町', 'タムラグンミハルマチ', '狐田', 'キツネダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡三春町過足', '07', '07521', '9637718', '福島県', 'フクシマケン', '田村郡三春町', 'タムラグンミハルマチ', '過足', 'ヨギアシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡三春町貝山', '07', '07521', '9637719', '福島県', 'フクシマケン', '田村郡三春町', 'タムラグンミハルマチ', '貝山', 'カイヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡三春町春沢', '07', '07521', '9637721', '福島県', 'フクシマケン', '田村郡三春町', 'タムラグンミハルマチ', '春沢', 'ハルサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡三春町春田', '07', '07521', '9637721', '福島県', 'フクシマケン', '田村郡三春町', 'タムラグンミハルマチ', '春田', 'ハルダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡三春町蛇沢', '07', '07521', '9637721', '福島県', 'フクシマケン', '田村郡三春町', 'タムラグンミハルマチ', '蛇沢', 'ヘビサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡三春町西方', '07', '07521', '9637722', '福島県', 'フクシマケン', '田村郡三春町', 'タムラグンミハルマチ', '西方', 'ニシカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡三春町斎藤', '07', '07521', '9637723', '福島県', 'フクシマケン', '田村郡三春町', 'タムラグンミハルマチ', '斎藤', 'サイトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡三春町沼沢', '07', '07521', '9637724', '福島県', 'フクシマケン', '田村郡三春町', 'タムラグンミハルマチ', '沼沢', 'ヌマサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡三春町鷹巣', '07', '07521', '9637725', '福島県', 'フクシマケン', '田村郡三春町', 'タムラグンミハルマチ', '鷹巣', 'タカノス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡三春町沼之倉', '07', '07521', '9637726', '福島県', 'フクシマケン', '田村郡三春町', 'タムラグンミハルマチ', '沼之倉', 'ヌマノクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡三春町下舞木', '07', '07521', '9637731', '福島県', 'フクシマケン', '田村郡三春町', 'タムラグンミハルマチ', '下舞木', 'シモモウギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡三春町上舞木', '07', '07521', '9637732', '福島県', 'フクシマケン', '田村郡三春町', 'タムラグンミハルマチ', '上舞木', 'カミモウギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡三春町山田', '07', '07521', '9637733', '福島県', 'フクシマケン', '田村郡三春町', 'タムラグンミハルマチ', '山田', 'ヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡三春町鎌田前', '07', '07521', '9637741', '福島県', 'フクシマケン', '田村郡三春町', 'タムラグンミハルマチ', '鎌田前', 'カマタマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡三春町天王前', '07', '07521', '9637741', '福島県', 'フクシマケン', '田村郡三春町', 'タムラグンミハルマチ', '天王前', 'テンノウマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡三春町八島台', '07', '07521', '9637741', '福島県', 'フクシマケン', '田村郡三春町', 'タムラグンミハルマチ', '八島台', 'ヤシマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡三春町鶴蒔田', '07', '07521', '9637742', '福島県', 'フクシマケン', '田村郡三春町', 'タムラグンミハルマチ', '鶴蒔田', 'ツルマキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡三春町丈六', '07', '07521', '9637743', '福島県', 'フクシマケン', '田村郡三春町', 'タムラグンミハルマチ', '丈六', 'ジョウロク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡三春町八幡町', '07', '07521', '9637744', '福島県', 'フクシマケン', '田村郡三春町', 'タムラグンミハルマチ', '八幡町', 'ハチマンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡三春町尼ケ谷', '07', '07521', '9637745', '福島県', 'フクシマケン', '田村郡三春町', 'タムラグンミハルマチ', '尼ケ谷', 'アマガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡三春町馬場', '07', '07521', '9637746', '福島県', 'フクシマケン', '田村郡三春町', 'タムラグンミハルマチ', '馬場', 'ババ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡三春町雁木田', '07', '07521', '9637747', '福島県', 'フクシマケン', '田村郡三春町', 'タムラグンミハルマチ', '雁木田', 'ガンギタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡三春町山崎', '07', '07521', '9637748', '福島県', 'フクシマケン', '田村郡三春町', 'タムラグンミハルマチ', '山崎', 'ヤマザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡三春町一本松', '07', '07521', '9637749', '福島県', 'フクシマケン', '田村郡三春町', 'タムラグンミハルマチ', '一本松', 'イッポンマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡三春町大久保', '07', '07521', '9637749', '福島県', 'フクシマケン', '田村郡三春町', 'タムラグンミハルマチ', '大久保', 'オオクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡三春町北町', '07', '07521', '9637751', '福島県', 'フクシマケン', '田村郡三春町', 'タムラグンミハルマチ', '北町', 'キタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡三春町烏帽子石', '07', '07521', '9637752', '福島県', 'フクシマケン', '田村郡三春町', 'タムラグンミハルマチ', '烏帽子石', 'エボシイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡三春町亀井', '07', '07521', '9637752', '福島県', 'フクシマケン', '田村郡三春町', 'タムラグンミハルマチ', '亀井', 'カメイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡三春町清水畑', '07', '07521', '9637752', '福島県', 'フクシマケン', '田村郡三春町', 'タムラグンミハルマチ', '清水畑', 'シミズバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡三春町仁井町', '07', '07521', '9637752', '福島県', 'フクシマケン', '田村郡三春町', 'タムラグンミハルマチ', '仁井町', 'ニイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡三春町六升蒔', '07', '07521', '9637752', '福島県', 'フクシマケン', '田村郡三春町', 'タムラグンミハルマチ', '六升蒔', 'ロクショウマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡三春町赤坂', '07', '07521', '9637753', '福島県', 'フクシマケン', '田村郡三春町', 'タムラグンミハルマチ', '赤坂', 'アカサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡三春町師範場', '07', '07521', '9637753', '福島県', 'フクシマケン', '田村郡三春町', 'タムラグンミハルマチ', '師範場', 'シハンバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('136999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡三春町清水', '07', '07521', '9637753', '福島県', 'フクシマケン', '田村郡三春町', 'タムラグンミハルマチ', '清水', 'シミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡三春町永作', '07', '07521', '9637753', '福島県', 'フクシマケン', '田村郡三春町', 'タムラグンミハルマチ', '永作', 'ナガサク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡三春町八十内', '07', '07521', '9637753', '福島県', 'フクシマケン', '田村郡三春町', 'タムラグンミハルマチ', '八十内', 'ヤソウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡三春町恵下越', '07', '07521', '9637754', '福島県', 'フクシマケン', '田村郡三春町', 'タムラグンミハルマチ', '恵下越', 'エゲノコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡三春町化粧坂', '07', '07521', '9637754', '福島県', 'フクシマケン', '田村郡三春町', 'タムラグンミハルマチ', '化粧坂', 'ケハイザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡三春町庚申坂', '07', '07521', '9637754', '福島県', 'フクシマケン', '田村郡三春町', 'タムラグンミハルマチ', '庚申坂', 'コウシンザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡三春町四軒丁', '07', '07521', '9637754', '福島県', 'フクシマケン', '田村郡三春町', 'タムラグンミハルマチ', '四軒丁', 'シケンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡三春町新町', '07', '07521', '9637754', '福島県', 'フクシマケン', '田村郡三春町', 'タムラグンミハルマチ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡三春町番組', '07', '07521', '9637754', '福島県', 'フクシマケン', '田村郡三春町', 'タムラグンミハルマチ', '番組', 'バングミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡三春町番組頭', '07', '07521', '9637754', '福島県', 'フクシマケン', '田村郡三春町', 'タムラグンミハルマチ', '番組頭', 'バングミガシラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡三春町弓町', '07', '07521', '9637754', '福島県', 'フクシマケン', '田村郡三春町', 'タムラグンミハルマチ', '弓町', 'ユミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡三春町山中', '07', '07521', '9637755', '福島県', 'フクシマケン', '田村郡三春町', 'タムラグンミハルマチ', '山中', 'サンチュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡三春町南町', '07', '07521', '9637756', '福島県', 'フクシマケン', '田村郡三春町', 'タムラグンミハルマチ', '南町', 'ミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡三春町会下谷', '07', '07521', '9637757', '福島県', 'フクシマケン', '田村郡三春町', 'タムラグンミハルマチ', '会下谷', 'エゲタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡三春町小金滝', '07', '07521', '9637758', '福島県', 'フクシマケン', '田村郡三春町', 'タムラグンミハルマチ', '小金滝', 'コガネダキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡三春町桜谷', '07', '07521', '9637758', '福島県', 'フクシマケン', '田村郡三春町', 'タムラグンミハルマチ', '桜谷', 'サクラダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡三春町大町', '07', '07521', '9637759', '福島県', 'フクシマケン', '田村郡三春町', 'タムラグンミハルマチ', '大町', 'オオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡三春町四反田', '07', '07521', '9637761', '福島県', 'フクシマケン', '田村郡三春町', 'タムラグンミハルマチ', '四反田', 'シタンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡三春町樋ノ口', '07', '07521', '9637761', '福島県', 'フクシマケン', '田村郡三春町', 'タムラグンミハルマチ', '樋ノ口', 'トイノクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡三春町小浜海道', '07', '07521', '9637762', '福島県', 'フクシマケン', '田村郡三春町', 'タムラグンミハルマチ', '小浜海道', 'オバマカイドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡三春町燕清水', '07', '07521', '9637763', '福島県', 'フクシマケン', '田村郡三春町', 'タムラグンミハルマチ', '燕清水', 'ツバメシミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡三春町日向町', '07', '07521', '9637763', '福島県', 'フクシマケン', '田村郡三春町', 'タムラグンミハルマチ', '日向町', 'ヒナタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡三春町持合畑', '07', '07521', '9637763', '福島県', 'フクシマケン', '田村郡三春町', 'タムラグンミハルマチ', '持合畑', 'モチアイバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡三春町北向町', '07', '07521', '9637764', '福島県', 'フクシマケン', '田村郡三春町', 'タムラグンミハルマチ', '北向町', 'キタムキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡三春町荒町', '07', '07521', '9637765', '福島県', 'フクシマケン', '田村郡三春町', 'タムラグンミハルマチ', '荒町', 'アラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡三春町中町', '07', '07521', '9637766', '福島県', 'フクシマケン', '田村郡三春町', 'タムラグンミハルマチ', '中町', 'ナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡三春町御免町', '07', '07521', '9637767', '福島県', 'フクシマケン', '田村郡三春町', 'タムラグンミハルマチ', '御免町', 'ゴメンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡三春町渋池', '07', '07521', '9637768', '福島県', 'フクシマケン', '田村郡三春町', 'タムラグンミハルマチ', '渋池', 'シブイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡三春町担橋', '07', '07521', '9637769', '福島県', 'フクシマケン', '田村郡三春町', 'タムラグンミハルマチ', '担橋', 'カツギバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡三春町平沢', '07', '07521', '9637771', '福島県', 'フクシマケン', '田村郡三春町', 'タムラグンミハルマチ', '平沢', 'ヒラサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡三春町御祭', '07', '07521', '9637772', '福島県', 'フクシマケン', '田村郡三春町', 'タムラグンミハルマチ', '御祭', 'オマツリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡三春町深田和', '07', '07521', '9637773', '福島県', 'フクシマケン', '田村郡三春町', 'タムラグンミハルマチ', '深田和', 'フカダワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡三春町北成田', '07', '07521', '9637781', '福島県', 'フクシマケン', '田村郡三春町', 'タムラグンミハルマチ', '北成田', 'キタナリタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡三春町富沢', '07', '07521', '9637782', '福島県', 'フクシマケン', '田村郡三春町', 'タムラグンミハルマチ', '富沢', 'トミサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡三春町南成田', '07', '07521', '9637783', '福島県', 'フクシマケン', '田村郡三春町', 'タムラグンミハルマチ', '南成田', 'ミナミナリタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡三春町六斗蒔', '07', '07521', '9637784', '福島県', 'フクシマケン', '田村郡三春町', 'タムラグンミハルマチ', '六斗蒔', 'ロクトマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡三春町松橋', '07', '07521', '9637785', '福島県', 'フクシマケン', '田村郡三春町', 'タムラグンミハルマチ', '松橋', 'マツバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県田村郡三春町七草木', '07', '07521', '9637786', '福島県', 'フクシマケン', '田村郡三春町', 'タムラグンミハルマチ', '七草木', 'ナナクサギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡石川町', '07', '07501', '9637800', '福島県', 'フクシマケン', '石川郡石川町', 'イシカワグンイシカワマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('137039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡石川町湯郷渡', '07', '07501', '9637801', '福島県', 'フクシマケン', '石川郡石川町', 'イシカワグンイシカワマチ', '湯郷渡', 'ユゴウト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡石川町北山', '07', '07501', '9637802', '福島県', 'フクシマケン', '石川郡石川町', 'イシカワグンイシカワマチ', '北山', 'キタヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡石川町中田', '07', '07501', '9637803', '福島県', 'フクシマケン', '石川郡石川町', 'イシカワグンイシカワマチ', '中田', 'ナカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡石川町坂路', '07', '07501', '9637804', '福島県', 'フクシマケン', '石川郡石川町', 'イシカワグンイシカワマチ', '坂路', 'サカジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡石川町谷地', '07', '07501', '9637805', '福島県', 'フクシマケン', '石川郡石川町', 'イシカワグンイシカワマチ', '谷地', 'ヤジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡石川町谷沢', '07', '07501', '9637806', '福島県', 'フクシマケン', '石川郡石川町', 'イシカワグンイシカワマチ', '谷沢', 'ヤザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡石川町形見', '07', '07501', '9637807', '福島県', 'フクシマケン', '石川郡石川町', 'イシカワグンイシカワマチ', '形見', 'カタミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡石川町双里', '07', '07501', '9637808', '福島県', 'フクシマケン', '石川郡石川町', 'イシカワグンイシカワマチ', '双里', 'ソウリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡石川町北山形', '07', '07501', '9637811', '福島県', 'フクシマケン', '石川郡石川町', 'イシカワグンイシカワマチ', '北山形', 'キタヤマガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡石川町南山形', '07', '07501', '9637812', '福島県', 'フクシマケン', '石川郡石川町', 'イシカワグンイシカワマチ', '南山形', 'ミナミヤマガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡石川町板橋', '07', '07501', '9637813', '福島県', 'フクシマケン', '石川郡石川町', 'イシカワグンイシカワマチ', '板橋', 'イタバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡石川町山形', '07', '07501', '9637814', '福島県', 'フクシマケン', '石川郡石川町', 'イシカワグンイシカワマチ', '山形', 'ヤマガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡石川町大沢', '07', '07501', '9637815', '福島県', 'フクシマケン', '石川郡石川町', 'イシカワグンイシカワマチ', '大沢', 'オオサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡石川町豆ケ平', '07', '07501', '9637816', '福島県', 'フクシマケン', '石川郡石川町', 'イシカワグンイシカワマチ', '豆ケ平', 'マメガヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡石川町立ケ岡', '07', '07501', '9637817', '福島県', 'フクシマケン', '石川郡石川町', 'イシカワグンイシカワマチ', '立ケ岡', 'タテガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡石川町塩沼', '07', '07501', '9637818', '福島県', 'フクシマケン', '石川郡石川町', 'イシカワグンイシカワマチ', '塩沼', 'シオヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡石川町宝殿前', '07', '07501', '9637821', '福島県', 'フクシマケン', '石川郡石川町', 'イシカワグンイシカワマチ', '宝殿前', 'ホウデンマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡石川町梁瀬', '07', '07501', '9637822', '福島県', 'フクシマケン', '石川郡石川町', 'イシカワグンイシカワマチ', '梁瀬', 'ヤナセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡石川町王子平', '07', '07501', '9637823', '福島県', 'フクシマケン', '石川郡石川町', 'イシカワグンイシカワマチ', '王子平', 'オウジダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡石川町原', '07', '07501', '9637824', '福島県', 'フクシマケン', '石川郡石川町', 'イシカワグンイシカワマチ', '原', 'ハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡石川町沢井', '07', '07501', '9637825', '福島県', 'フクシマケン', '石川郡石川町', 'イシカワグンイシカワマチ', '沢井', 'サワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡石川町赤羽', '07', '07501', '9637826', '福島県', 'フクシマケン', '石川郡石川町', 'イシカワグンイシカワマチ', '赤羽', 'アカバネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡石川町新屋敷', '07', '07501', '9637827', '福島県', 'フクシマケン', '石川郡石川町', 'イシカワグンイシカワマチ', '新屋敷', 'アラヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡石川町下ノ内', '07', '07501', '9637828', '福島県', 'フクシマケン', '石川郡石川町', 'イシカワグンイシカワマチ', '下ノ内', 'シモノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡石川町母畑', '07', '07501', '9637831', '福島県', 'フクシマケン', '石川郡石川町', 'イシカワグンイシカワマチ', '母畑', 'ボバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡石川町弥吾', '07', '07501', '9637832', '福島県', 'フクシマケン', '石川郡石川町', 'イシカワグンイシカワマチ', '弥吾', 'ヤゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡石川町石田', '07', '07501', '9637833', '福島県', 'フクシマケン', '石川郡石川町', 'イシカワグンイシカワマチ', '石田', 'イシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡石川町轡取', '07', '07501', '9637834', '福島県', 'フクシマケン', '石川郡石川町', 'イシカワグンイシカワマチ', '轡取', 'クツワドリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡石川町草倉田', '07', '07501', '9637835', '福島県', 'フクシマケン', '石川郡石川町', 'イシカワグンイシカワマチ', '草倉田', 'クサクラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡石川町塩沢', '07', '07501', '9637836', '福島県', 'フクシマケン', '石川郡石川町', 'イシカワグンイシカワマチ', '塩沢', 'シオザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡石川町中野', '07', '07501', '9637837', '福島県', 'フクシマケン', '石川郡石川町', 'イシカワグンイシカワマチ', '中野', 'ナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡石川町曲木', '07', '07501', '9637838', '福島県', 'フクシマケン', '石川郡石川町', 'イシカワグンイシカワマチ', '曲木', 'マガキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡石川町江堀田', '07', '07501', '9637841', '福島県', 'フクシマケン', '石川郡石川町', 'イシカワグンイシカワマチ', '江堀田', 'エホリダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡石川町境ノ内', '07', '07501', '9637842', '福島県', 'フクシマケン', '石川郡石川町', 'イシカワグンイシカワマチ', '境ノ内', 'サカイノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡石川町屋敷ノ入', '07', '07501', '9637843', '福島県', 'フクシマケン', '石川郡石川町', 'イシカワグンイシカワマチ', '屋敷ノ入', 'ヤシキノイリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡石川町北町', '07', '07501', '9637844', '福島県', 'フクシマケン', '石川郡石川町', 'イシカワグンイシカワマチ', '北町', 'キタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡石川町高田', '07', '07501', '9637845', '福島県', 'フクシマケン', '石川郡石川町', 'イシカワグンイシカワマチ', '高田', 'タカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡石川町長久保', '07', '07501', '9637846', '福島県', 'フクシマケン', '石川郡石川町', 'イシカワグンイシカワマチ', '長久保', 'ナガクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡石川町古舘', '07', '07501', '9637847', '福島県', 'フクシマケン', '石川郡石川町', 'イシカワグンイシカワマチ', '古舘', 'コダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡石川町長郷田', '07', '07501', '9637848', '福島県', 'フクシマケン', '石川郡石川町', 'イシカワグンイシカワマチ', '長郷田', 'オサゴウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡石川町一ノ沢', '07', '07501', '9637849', '福島県', 'フクシマケン', '石川郡石川町', 'イシカワグンイシカワマチ', '一ノ沢', 'イチノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡石川町新町', '07', '07501', '9637851', '福島県', 'フクシマケン', '石川郡石川町', 'イシカワグンイシカワマチ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡石川町関根', '07', '07501', '9637852', '福島県', 'フクシマケン', '石川郡石川町', 'イシカワグンイシカワマチ', '関根', 'セキネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡石川町大室', '07', '07501', '9637853', '福島県', 'フクシマケン', '石川郡石川町', 'イシカワグンイシカワマチ', '大室', 'オオムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡石川町松木下', '07', '07501', '9637854', '福島県', 'フクシマケン', '石川郡石川町', 'イシカワグンイシカワマチ', '松木下', 'マツキシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡石川町猫啼', '07', '07501', '9637855', '福島県', 'フクシマケン', '石川郡石川町', 'イシカワグンイシカワマチ', '猫啼', 'ネコナキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡石川町白石', '07', '07501', '9637856', '福島県', 'フクシマケン', '石川郡石川町', 'イシカワグンイシカワマチ', '白石', 'シロイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡石川町当町', '07', '07501', '9637857', '福島県', 'フクシマケン', '石川郡石川町', 'イシカワグンイシカワマチ', '当町', 'トウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡石川町下泉', '07', '07501', '9637858', '福島県', 'フクシマケン', '石川郡石川町', 'イシカワグンイシカワマチ', '下泉', 'シモイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡石川町南町', '07', '07501', '9637859', '福島県', 'フクシマケン', '石川郡石川町', 'イシカワグンイシカワマチ', '南町', 'ミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡石川町矢ノ目田', '07', '07501', '9637861', '福島県', 'フクシマケン', '石川郡石川町', 'イシカワグンイシカワマチ', '矢ノ目田', 'ヤノメダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡石川町鹿ノ坂', '07', '07501', '9637862', '福島県', 'フクシマケン', '石川郡石川町', 'イシカワグンイシカワマチ', '鹿ノ坂', 'カノサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡石川町渡里沢', '07', '07501', '9637863', '福島県', 'フクシマケン', '石川郡石川町', 'イシカワグンイシカワマチ', '渡里沢', 'ワタリサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡石川町秋台', '07', '07501', '9637864', '福島県', 'フクシマケン', '石川郡石川町', 'イシカワグンイシカワマチ', '秋台', 'アキダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡石川町曲ノ内', '07', '07501', '9637865', '福島県', 'フクシマケン', '石川郡石川町', 'イシカワグンイシカワマチ', '曲ノ内', 'マガリノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡石川町外国見', '07', '07501', '9637866', '福島県', 'フクシマケン', '石川郡石川町', 'イシカワグンイシカワマチ', '外国見', 'ソトクニミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡石川町石塚', '07', '07501', '9637867', '福島県', 'フクシマケン', '石川郡石川町', 'イシカワグンイシカワマチ', '石塚', 'イシヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡石川町前ノ内', '07', '07501', '9637871', '福島県', 'フクシマケン', '石川郡石川町', 'イシカワグンイシカワマチ', '前ノ内', 'マエノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡石川町大内', '07', '07501', '9637872', '福島県', 'フクシマケン', '石川郡石川町', 'イシカワグンイシカワマチ', '大内', 'オオウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡石川町飛ケ作', '07', '07501', '9637873', '福島県', 'フクシマケン', '石川郡石川町', 'イシカワグンイシカワマチ', '飛ケ作', 'トビガサク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡石川町大五郎内', '07', '07501', '9637874', '福島県', 'フクシマケン', '石川郡石川町', 'イシカワグンイシカワマチ', '大五郎内', 'ダイゴロウウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡石川町柳作', '07', '07501', '9637875', '福島県', 'フクシマケン', '石川郡石川町', 'イシカワグンイシカワマチ', '柳作', 'ヤナギサク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡石川町国見', '07', '07501', '9637876', '福島県', 'フクシマケン', '石川郡石川町', 'イシカワグンイシカワマチ', '国見', 'クニミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡石川町大橋', '07', '07501', '9637881', '福島県', 'フクシマケン', '石川郡石川町', 'イシカワグンイシカワマチ', '大橋', 'オオハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡石川町塩ノ平', '07', '07501', '9637882', '福島県', 'フクシマケン', '石川郡石川町', 'イシカワグンイシカワマチ', '塩ノ平', 'シオノヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡石川町麦ノ内', '07', '07501', '9637883', '福島県', 'フクシマケン', '石川郡石川町', 'イシカワグンイシカワマチ', '麦ノ内', 'ムギノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡石川町新屋敷', '07', '07501', '9637884', '福島県', 'フクシマケン', '石川郡石川町', 'イシカワグンイシカワマチ', '新屋敷', 'アラヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡石川町成亀', '07', '07501', '9637885', '福島県', 'フクシマケン', '石川郡石川町', 'イシカワグンイシカワマチ', '成亀', 'ナリガメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡石川町和久', '07', '07501', '9637886', '福島県', 'フクシマケン', '石川郡石川町', 'イシカワグンイシカワマチ', '和久', 'ワグ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市大町', '07', '07203', '9638001', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '大町', 'オオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市駅前', '07', '07203', '9638002', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '駅前', 'エキマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市燧田', '07', '07203', '9638003', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '燧田', 'ヒウチタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市中町', '07', '07203', '9638004', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '中町', 'ナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市清水台', '07', '07203', '9638005', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '清水台', 'シミズダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市赤木町', '07', '07203', '9638006', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '赤木町', 'アカギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市大名艮', '07', '07203', '9638007', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '大名艮', 'ダイナゴン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市東宿', '07', '07203', '9638008', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '東宿', 'トウジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市若葉町', '07', '07203', '9638011', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '若葉町', 'ワカバマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市咲田', '07', '07203', '9638012', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '咲田', 'サクタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市神明町', '07', '07203', '9638013', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '神明町', 'シンメイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市虎丸町', '07', '07203', '9638014', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '虎丸町', 'トラマルマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市細沼町', '07', '07203', '9638015', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '細沼町', 'ホソヌママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市豊田町', '07', '07203', '9638016', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '豊田町', 'トヨタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市長者', '07', '07203', '9638017', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '長者', 'チョウジャ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市桃見台', '07', '07203', '9638018', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '桃見台', 'モモミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市桜木', '07', '07203', '9638021', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '桜木', 'サクラギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市西ノ内', '07', '07203', '9638022', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '西ノ内', 'ニシノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市緑町', '07', '07203', '9638023', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '緑町', 'ミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市朝日', '07', '07203', '9638024', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '朝日', 'アサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市桑野', '07', '07203', '9638025', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '桑野', 'クワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市並木', '07', '07203', '9638026', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '並木', 'ナミキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市上亀田', '07', '07203', '9638031', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '上亀田', 'カミカメダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市下亀田', '07', '07203', '9638032', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '下亀田', 'シモカメダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市亀田', '07', '07203', '9638033', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '亀田', 'カメダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市島', '07', '07203', '9638034', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '島', 'シマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市希望ケ丘', '07', '07203', '9638035', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '希望ケ丘', 'キボウガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市うねめ町', '07', '07203', '9638036', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', 'うねめ町', 'ウネメチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市原中', '07', '07203', '9638037', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '原中', 'ハラナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市桑野北町', '07', '07203', '9638038', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '桑野北町', 'クワノキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市小関谷地', '07', '07203', '9638039', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '小関谷地', 'コセキヤジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市富田町', '07', '07203', '9638041', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '富田町', 'トミタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市不動前', '07', '07203', '9638042', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '不動前', 'フドウマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市名郷田', '07', '07203', '9638043', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '名郷田', 'ナゴウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市備前舘', '07', '07203', '9638044', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '備前舘', 'ビゼンダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市新屋敷', '07', '07203', '9638045', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '新屋敷', 'アラヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市町東', '07', '07203', '9638046', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '町東', 'マチヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市富久山町八山田', '07', '07203', '9638051', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '富久山町八山田', 'フクヤママチヤツヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市八山田', '07', '07203', '9638052', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '八山田', 'ヤツヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市富久山町福原', '07', '07203', '9638061', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '富久山町福原', 'フクヤママチフクハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市富久山町久保田', '07', '07203', '9638071', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '富久山町久保田', 'フクヤママチクボタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡平田村', '07', '07503', '9638100', '福島県', 'フクシマケン', '石川郡平田村', 'イシカワグンヒラタムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('137151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡平田村東山', '07', '07503', '9638111', '福島県', 'フクシマケン', '石川郡平田村', 'イシカワグンヒラタムラ', '東山', 'ヒガシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡平田村北方', '07', '07503', '9638112', '福島県', 'フクシマケン', '石川郡平田村', 'イシカワグンヒラタムラ', '北方', 'キタカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡平田村駒形', '07', '07503', '9638113', '福島県', 'フクシマケン', '石川郡平田村', 'イシカワグンヒラタムラ', '駒形', 'コマガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡平田村小平', '07', '07503', '9638114', '福島県', 'フクシマケン', '石川郡平田村', 'イシカワグンヒラタムラ', '小平', 'オダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡平田村中倉', '07', '07503', '9638115', '福島県', 'フクシマケン', '石川郡平田村', 'イシカワグンヒラタムラ', '中倉', 'ナカグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡平田村西山', '07', '07503', '9638116', '福島県', 'フクシマケン', '石川郡平田村', 'イシカワグンヒラタムラ', '西山', 'ニシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡平田村蓬田新田', '07', '07503', '9638201', '福島県', 'フクシマケン', '石川郡平田村', 'イシカワグンヒラタムラ', '蓬田新田', 'ヨモギダシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡平田村上蓬田', '07', '07503', '9638202', '福島県', 'フクシマケン', '石川郡平田村', 'イシカワグンヒラタムラ', '上蓬田', 'カミヨモギダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡平田村九生滝', '07', '07503', '9638203', '福島県', 'フクシマケン', '石川郡平田村', 'イシカワグンヒラタムラ', '九生滝', 'クリュウダキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡平田村鴇子', '07', '07503', '9638204', '福島県', 'フクシマケン', '石川郡平田村', 'イシカワグンヒラタムラ', '鴇子', 'トウノコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡平田村永田', '07', '07503', '9638205', '福島県', 'フクシマケン', '石川郡平田村', 'イシカワグンヒラタムラ', '永田', 'ナガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡平田村小松原', '07', '07503', '9638206', '福島県', 'フクシマケン', '石川郡平田村', 'イシカワグンヒラタムラ', '小松原', 'コマツバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡平田村下蓬田', '07', '07503', '9638207', '福島県', 'フクシマケン', '石川郡平田村', 'イシカワグンヒラタムラ', '下蓬田', 'シモヨモギダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡古殿町', '07', '07505', '9638300', '福島県', 'フクシマケン', '石川郡古殿町', 'イシカワグンフルドノマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('137166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡古殿町論田', '07', '07505', '9638301', '福島県', 'フクシマケン', '石川郡古殿町', 'イシカワグンフルドノマチ', '論田', 'ロンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡古殿町山上', '07', '07505', '9638302', '福島県', 'フクシマケン', '石川郡古殿町', 'イシカワグンフルドノマチ', '山上', 'ヤマカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡古殿町大久田', '07', '07505', '9638303', '福島県', 'フクシマケン', '石川郡古殿町', 'イシカワグンフルドノマチ', '大久田', 'オオグタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡古殿町松川', '07', '07505', '9638304', '福島県', 'フクシマケン', '石川郡古殿町', 'イシカワグンフルドノマチ', '松川', 'マツカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡古殿町竹貫', '07', '07505', '9638305', '福島県', 'フクシマケン', '石川郡古殿町', 'イシカワグンフルドノマチ', '竹貫', 'タカヌキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡古殿町田口', '07', '07505', '9638306', '福島県', 'フクシマケン', '石川郡古殿町', 'イシカワグンフルドノマチ', '田口', 'タグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡古殿町鎌田', '07', '07505', '9638307', '福島県', 'フクシマケン', '石川郡古殿町', 'イシカワグンフルドノマチ', '鎌田', 'カマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県石川郡古殿町仙石', '07', '07505', '9638308', '福島県', 'フクシマケン', '石川郡古殿町', 'イシカワグンフルドノマチ', '仙石', 'センゴク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県東白川郡鮫川村', '07', '07484', '9638400', '福島県', 'フクシマケン', '東白川郡鮫川村', 'ヒガシシラカワグンサメガワムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('137175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県東白川郡鮫川村赤坂中野', '07', '07484', '9638401', '福島県', 'フクシマケン', '東白川郡鮫川村', 'ヒガシシラカワグンサメガワムラ', '赤坂中野', 'アカサカナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県東白川郡鮫川村石井草', '07', '07484', '9638402', '福島県', 'フクシマケン', '東白川郡鮫川村', 'ヒガシシラカワグンサメガワムラ', '石井草', 'イシイクサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県東白川郡鮫川村赤坂東野', '07', '07484', '9638403', '福島県', 'フクシマケン', '東白川郡鮫川村', 'ヒガシシラカワグンサメガワムラ', '赤坂東野', 'アカサカヒガシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県東白川郡鮫川村渡瀬青生野', '07', '07484', '9638404', '福島県', 'フクシマケン', '東白川郡鮫川村', 'ヒガシシラカワグンサメガワムラ', '渡瀬', 'ワタラセ', null, null, '青生野', 'アオノ');
INSERT INTO `ms_addresses` VALUES ('137179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県東白川郡鮫川村渡瀬', '07', '07484', '9638405', '福島県', 'フクシマケン', '東白川郡鮫川村', 'ヒガシシラカワグンサメガワムラ', '渡瀬', 'ワタラセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県東白川郡鮫川村富田', '07', '07484', '9638406', '福島県', 'フクシマケン', '東白川郡鮫川村', 'ヒガシシラカワグンサメガワムラ', '富田', 'トミタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県東白川郡鮫川村赤坂西野', '07', '07484', '9638407', '福島県', 'フクシマケン', '東白川郡鮫川村', 'ヒガシシラカワグンサメガワムラ', '赤坂西野', 'アカサカニシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県東白川郡鮫川村西山', '07', '07484', '9638408', '福島県', 'フクシマケン', '東白川郡鮫川村', 'ヒガシシラカワグンサメガワムラ', '西山', 'ニシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市向河原町', '07', '07203', '9638801', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '向河原町', 'ムカイガワラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市谷島町', '07', '07203', '9638802', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '谷島町', 'ヤシママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市横塚', '07', '07203', '9638803', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '横塚', 'ヨコヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市北畑', '07', '07203', '9638804', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '北畑', 'キタバタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市古屋敷', '07', '07203', '9638805', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '古屋敷', 'フルヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市下舘野', '07', '07203', '9638806', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '下舘野', 'シモタテノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市佐野良', '07', '07203', '9638807', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '佐野良', 'サノラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市方八町', '07', '07203', '9638811', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '方八町', 'ホウハッチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市松木町', '07', '07203', '9638812', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '松木町', 'マツキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市芳賀', '07', '07203', '9638813', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '芳賀', 'ハガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市石渕町', '07', '07203', '9638814', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '石渕町', 'イシブチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市水門町', '07', '07203', '9638815', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '水門町', 'スイモンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市上野山', '07', '07203', '9638816', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '上野山', 'カミノヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市大平町', '07', '07203', '9638817', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '大平町', 'オオダイラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市十貫河原', '07', '07203', '9638818', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '十貫河原', 'ジツカンガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市菱田町', '07', '07203', '9638821', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '菱田町', 'ヒシダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市昭和', '07', '07203', '9638822', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '昭和', 'ショウワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市古川', '07', '07203', '9638823', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '古川', 'フルカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市道場', '07', '07203', '9638824', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '道場', 'ドウバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市石塚', '07', '07203', '9638825', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '石塚', 'イシヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市船場向', '07', '07203', '9638826', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '船場向', 'フナバムカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市外河原', '07', '07203', '9638827', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '外河原', 'ソトガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市大河原', '07', '07203', '9638828', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '大河原', 'オオカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市榧の木', '07', '07203', '9638829', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '榧の木', 'カヤノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市七ツ池町', '07', '07203', '9638831', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '七ツ池町', 'ナナツイケマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市山根町', '07', '07203', '9638832', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '山根町', 'ヤマネマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市香久池', '07', '07203', '9638833', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '香久池', 'カグイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市図景', '07', '07203', '9638834', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '図景', 'ズケイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市小原田', '07', '07203', '9638835', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '小原田', 'コハラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市八作内', '07', '07203', '9638836', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '八作内', 'ハッサクウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市八木橋', '07', '07203', '9638837', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '八木橋', 'ヤギハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市深田台', '07', '07203', '9638838', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '深田台', 'フカダダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市山崎', '07', '07203', '9638841', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '山崎', 'ヤマザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市城清水', '07', '07203', '9638842', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '城清水', 'シロシミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市川向', '07', '07203', '9638843', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '川向', 'カワムカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市賀庄', '07', '07203', '9638844', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '賀庄', 'ガショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市名倉', '07', '07203', '9638845', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '名倉', 'ナグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市久留米', '07', '07203', '9638846', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '久留米', 'クルメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市開成', '07', '07203', '9638851', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '開成', 'カイセイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市台新', '07', '07203', '9638852', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '台新', 'ダイシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市鶴見坦', '07', '07203', '9638861', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '鶴見坦', 'ツルミダン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市菜根', '07', '07203', '9638862', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '菜根', 'サイコン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市菜根屋敷', '07', '07203', '9638863', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '菜根屋敷', 'サイコンヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市台東', '07', '07203', '9638864', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '台東', 'ダイヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市五百渕西', '07', '07203', '9638865', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '五百渕西', 'ゴヒャクブチニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市桑野清水台', '07', '07203', '9638866', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '桑野清水台', 'クワノシミズダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市五百渕山', '07', '07203', '9638867', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '五百渕山', 'ゴヒャクブチヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市晴門田', '07', '07203', '9638871', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '晴門田', 'ハレモンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市本町', '07', '07203', '9638871', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '本町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市栄町', '07', '07203', '9638872', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市愛宕町', '07', '07203', '9638873', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '愛宕町', 'アタゴマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市深沢', '07', '07203', '9638874', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '深沢', 'フカザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市池ノ台', '07', '07203', '9638875', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '池ノ台', 'イケノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市麓山', '07', '07203', '9638876', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '麓山', 'ハヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市堂前町', '07', '07203', '9638877', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '堂前町', 'ドウマエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県郡山市堤下町', '07', '07203', '9638878', '福島県', 'フクシマケン', '郡山市', 'コオリヤマシ', '堤下町', 'ツツミシタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市', '07', '07210', '9640000', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('137304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市中ノ目', '07', '07210', '9640001', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '中ノ目', 'ナカノメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市湯川町', '07', '07210', '9640002', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '湯川町', 'ユカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市二伊滝', '07', '07210', '9640003', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '二伊滝', 'ニイタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市伊佐沼町', '07', '07210', '9640004', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '伊佐沼町', 'イサヌママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市笹屋', '07', '07210', '9640005', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '笹屋', 'ササヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市二又', '07', '07210', '9640006', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '二又', 'フタマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市古家', '07', '07210', '9640007', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '古家', 'コヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市鉄扇町', '07', '07210', '9640008', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '鉄扇町', 'テッセンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市永田才木', '07', '07210', '9640011', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '永田才木', 'ナガタサイキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市永田積内', '07', '07210', '9640012', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '永田積内', 'ナガタツミウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市新田', '07', '07210', '9640013', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '新田', 'シンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市上新田', '07', '07210', '9640014', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '上新田', 'カミシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市板目沢', '07', '07210', '9640015', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '板目沢', 'イタメザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市大森沢', '07', '07210', '9640016', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '大森沢', 'オオモリサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市永田御堂内', '07', '07210', '9640017', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '永田御堂内', 'ナガタミドウウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市永田馬保内', '07', '07210', '9640021', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '永田馬保内', 'ナガタバボウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市永田鍛治内', '07', '07210', '9640022', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '永田鍛治内', 'ナガタカジウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市硯石', '07', '07210', '9640023', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '硯石', 'スズリイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市井戸神', '07', '07210', '9640024', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '井戸神', 'イドガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市屋戸入', '07', '07210', '9640025', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '屋戸入', 'ヤドイリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市中山田', '07', '07210', '9640026', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '中山田', 'ナカヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市山田', '07', '07210', '9640027', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '山田', 'ヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市高平', '07', '07210', '9640028', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '高平', 'タカヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市永田', '07', '07210', '9640029', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '永田', 'ナガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市前原', '07', '07210', '9640031', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '前原', 'マエハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市毘沙門堂山', '07', '07210', '9640032', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '毘沙門堂山', 'ビシャモンドウヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市毘沙門堂', '07', '07210', '9640033', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '毘沙門堂', 'ビシャモンドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市原セ堰下', '07', '07210', '9640034', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '原セ堰下', 'ハラセセキシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市原セ天ケ作', '07', '07210', '9640035', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '原セ天ケ作', 'ハラセアマガサク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市原セ才木', '07', '07210', '9640036', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '原セ才木', 'ハラセサイキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市原セ川原', '07', '07210', '9640037', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '原セ川原', 'ハラセカワハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市立石', '07', '07210', '9640038', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '立石', 'タテイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市萩坂', '07', '07210', '9640039', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '萩坂', 'ハギサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市原セ日照田', '07', '07210', '9640041', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '原セ日照田', 'ハラセヒデリタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市原セ大畑', '07', '07210', '9640042', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '原セ大畑', 'ハラセオオハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市原セ諏訪', '07', '07210', '9640043', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '原セ諏訪', 'ハラセスワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市原セ上ノ内', '07', '07210', '9640044', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '原セ上ノ内', 'ハラセカミノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市原セ笠張', '07', '07210', '9640045', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '原セ笠張', 'ハラセカサハリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市原セ山口', '07', '07210', '9640046', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '原セ山口', 'ハラセヤマグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市原セ上平', '07', '07210', '9640047', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '原セ上平', 'ハラセカミタイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市大坂', '07', '07210', '9640048', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '大坂', 'オオサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市原セ仲谷地', '07', '07210', '9640049', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '原セ仲谷地', 'ハラセナカヤジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市舘野原', '07', '07210', '9640051', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '舘野原', 'タテノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市箕輪', '07', '07210', '9640052', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '箕輪', 'ミノワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市乳母沢', '07', '07210', '9640053', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '乳母沢', 'ウバザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市苗松', '07', '07210', '9640054', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '苗松', 'ナエマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市馬場平', '07', '07210', '9640055', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '馬場平', 'ババダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市雄平台', '07', '07210', '9640056', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '雄平台', 'ユウヘイダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市大石ケ作', '07', '07210', '9640057', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '大石ケ作', 'オオイシガサク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市三雄山', '07', '07210', '9640058', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '三雄山', 'サンユウザン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市岳温泉深堀', '07', '07210', '9640061', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '岳温泉深堀', 'ダケオンセンフカホリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市岳温泉大和', '07', '07210', '9640062', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '岳温泉大和', 'ダケオンセンダイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市才木山', '07', '07210', '9640063', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '才木山', 'サイキヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市岳温泉横森', '07', '07210', '9640064', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '岳温泉横森', 'ダケオンセンヨコモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市小関', '07', '07210', '9640065', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '小関', 'コセキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市岳温泉西大和', '07', '07210', '9640066', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '岳温泉西大和', 'ダケオンセンニシダイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市栄町', '07', '07210', '9640071', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市岳東町', '07', '07210', '9640072', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '岳東町', 'ダケヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市上葉木坂', '07', '07210', '9640073', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '上葉木坂', 'カミハギザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市岳温泉', '07', '07210', '9640074', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '岳温泉', 'ダケオンセン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市永田長坂国有林', '07', '07210', '9640075', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '永田', 'ナガタ', null, null, '長坂国有林', 'ナガサカコクユウリン');
INSERT INTO `ms_addresses` VALUES ('137365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市永田橋積', '07', '07210', '9640076', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '永田橋積', 'ナガタバシツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市大関', '07', '07210', '9640077', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '大関', 'オオゼキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市宮沢', '07', '07210', '9640081', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '宮沢', 'ミヤザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市休石', '07', '07210', '9640082', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '休石', 'ヤスミイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市休石原', '07', '07210', '9640083', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '休石原', 'ヤスミイシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市大根畑', '07', '07210', '9640084', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '大根畑', 'ダイコンハタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市不動平', '07', '07210', '9640085', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '不動平', 'フドウダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市塩沢', '07', '07210', '9640086', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '塩沢', 'シオザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市木ノ根坂', '07', '07210', '9640087', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '木ノ根坂', 'キノネサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市沢松倉', '07', '07210', '9640088', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '沢松倉', 'サワマツクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県安達郡大玉村玉井馬場平', '07', '07322', '9640091', '福島県', 'フクシマケン', '安達郡大玉村', 'アダチグンオオタマムラ', '玉井', 'タマノイ', null, null, '馬場平', 'ババダイラ');
INSERT INTO `ms_addresses` VALUES ('137376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市太田', '07', '07210', '9640111', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '太田', 'オオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市戸沢', '07', '07210', '9640201', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '戸沢', 'トサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市針道', '07', '07210', '9640202', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '針道', 'ハリミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市木幡', '07', '07210', '9640203', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '木幡', 'コハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市東新殿', '07', '07210', '9640301', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '東新殿', 'ヒガシニイドノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市杉沢', '07', '07210', '9640302', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '杉沢', 'スギサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市初森', '07', '07210', '9640303', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '初森', 'ハツモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市西新殿', '07', '07210', '9640304', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '西新殿', 'ニシニイドノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市長折', '07', '07210', '9640311', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '長折', 'ナガオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市上長折', '07', '07210', '9640312', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '上長折', 'カミナガオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市小浜', '07', '07210', '9640313', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '小浜', 'オバマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市西勝田', '07', '07210', '9640314', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '西勝田', 'サイカチタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市成田', '07', '07210', '9640315', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '成田', 'ナリタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市下長折', '07', '07210', '9640316', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '下長折', 'シモナガオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市上太田', '07', '07210', '9640321', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '上太田', 'カミオオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市田沢', '07', '07210', '9640431', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '田沢', 'タザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市茂原', '07', '07210', '9640432', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '茂原', 'モバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市百目木', '07', '07210', '9640433', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '百目木', 'ドウメキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市向作田', '07', '07210', '9640801', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '向作田', 'ムカイサクタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市鐙摺石', '07', '07210', '9640802', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '鐙摺石', 'アブズリイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市八万舘', '07', '07210', '9640803', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '八万舘', 'ハチマンダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市下平', '07', '07210', '9640804', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '下平', 'シモタイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市下ノ内', '07', '07210', '9640805', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '下ノ内', 'シモノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市羽石', '07', '07210', '9640806', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '羽石', 'ハネイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市金色久保', '07', '07210', '9640807', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '金色久保', 'カナイロクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市木藤次郎内', '07', '07210', '9640808', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '木藤次郎内', 'キトウジロウウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市宮戸', '07', '07210', '9640811', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '宮戸', 'ミヤト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市関', '07', '07210', '9640812', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '関', 'セキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市舟形石山', '07', '07210', '9640813', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '舟形石山', 'フナカタイシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市遠西', '07', '07210', '9640814', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '遠西', 'トオニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市唐谷山', '07', '07210', '9640815', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '唐谷山', 'カラカイヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市原田', '07', '07210', '9640816', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '原田', 'ハラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市高西', '07', '07210', '9640817', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '高西', 'タカニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市不動', '07', '07210', '9640818', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '不動', 'フドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市舟形石', '07', '07210', '9640821', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '舟形石', 'フナカタイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市舟石', '07', '07210', '9640822', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '舟石', 'フナイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市岩崎', '07', '07210', '9640823', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '岩崎', 'イワサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市諏訪原', '07', '07210', '9640824', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '諏訪原', 'スワハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市下町', '07', '07210', '9640825', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '下町', 'シタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市石ノ花', '07', '07210', '9640826', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '石ノ花', 'イシノハナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市反返', '07', '07210', '9640827', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '反返', 'ソリカエリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市新林', '07', '07210', '9640828', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '新林', 'シンバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市袋内', '07', '07210', '9640829', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '袋内', 'フクロウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市前田', '07', '07210', '9640831', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '前田', 'マエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市落合', '07', '07210', '9640832', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '落合', 'オチアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市杉田仲之内', '07', '07210', '9640833', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '杉田仲之内', 'スギタナカノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市十神', '07', '07210', '9640834', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '十神', 'トオガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市水神', '07', '07210', '9640835', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '水神', 'スイジン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市菅田', '07', '07210', '9640836', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '菅田', 'スガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市七ツ段', '07', '07210', '9640837', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '七ツ段', 'ナナツダン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市借宿', '07', '07210', '9640838', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '借宿', 'カリヤド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市瀬ノ上', '07', '07210', '9640841', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '瀬ノ上', 'セノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市隠里', '07', '07210', '9640842', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '隠里', 'カクレサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市坊主滝', '07', '07210', '9640843', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '坊主滝', 'ボウズタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市在師', '07', '07210', '9640844', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '在師', 'ザイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市竹柄', '07', '07210', '9640845', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '竹柄', 'タケガラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市峠', '07', '07210', '9640846', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '峠', 'トウゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市薬師', '07', '07210', '9640847', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '薬師', 'ヤクシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市上平内', '07', '07210', '9640848', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '上平内', 'カミヒラウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市大沢', '07', '07210', '9640849', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '大沢', 'オオサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市反田', '07', '07210', '9640851', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '反田', 'ソリタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市長者宮', '07', '07210', '9640852', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '長者宮', 'チョウジャミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市向陽台', '07', '07210', '9640853', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '向陽台', 'コウヨウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市郡山台', '07', '07210', '9640854', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '郡山台', 'コオリヤマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市成上', '07', '07210', '9640855', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '成上', 'ナリカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市西町', '07', '07210', '9640856', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '西町', 'ニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市東町', '07', '07210', '9640857', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '東町', 'ヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市姫子松', '07', '07210', '9640858', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '姫子松', 'ヒメコマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市中江', '07', '07210', '9640859', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '中江', 'ナカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市西池', '07', '07210', '9640861', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '西池', 'ニシイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市杉田駄子内', '07', '07210', '9640862', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '杉田駄子内', 'スギタダゴウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市片岸', '07', '07210', '9640863', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '片岸', 'カタギシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市社前', '07', '07210', '9640864', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '社前', 'ヤシロマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市杉田町', '07', '07210', '9640865', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '杉田町', 'スギタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市長命', '07', '07210', '9640866', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '長命', 'チョウメイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市住吉', '07', '07210', '9640867', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '住吉', 'スミヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市舘野', '07', '07210', '9640868', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '舘野', 'タテノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市大平山', '07', '07210', '9640869', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '大平山', 'オオヒラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市成田町', '07', '07210', '9640871', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '成田町', 'ナリタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市藤太郎内', '07', '07210', '9640872', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '藤太郎内', 'トウタロウウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市東裏', '07', '07210', '9640873', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '東裏', 'ヒガシウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市中里', '07', '07210', '9640874', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '中里', 'ナカサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市槻木', '07', '07210', '9640875', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '槻木', 'ツキノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市正法寺町', '07', '07210', '9640876', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '正法寺町', 'ショウボウジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市藤之前', '07', '07210', '9640881', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '藤之前', 'トウノマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市新座', '07', '07210', '9640882', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '新座', 'シンザ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市下山田', '07', '07210', '9640883', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '下山田', 'シモヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市大作', '07', '07210', '9640884', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '大作', 'ダイサク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市高越屋戸', '07', '07210', '9640885', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '高越屋戸', 'タカコシヤド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市高越松ケ作', '07', '07210', '9640886', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '高越松ケ作', 'タカコシマツガサク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市三保内', '07', '07210', '9640887', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '三保内', 'ミホウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市大壇', '07', '07210', '9640891', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '大壇', 'オオダン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市成田日向', '07', '07210', '9640892', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '成田日向', 'ナリタヒナタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市幸町', '07', '07210', '9640893', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市坦子内', '07', '07210', '9640894', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '坦子内', 'ダンゴウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市三原町', '07', '07210', '9640895', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '三原町', 'ミハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市末広町', '07', '07210', '9640896', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '末広町', 'スエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市塩沢町', '07', '07210', '9640897', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '塩沢町', 'シオザワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市上原', '07', '07210', '9640898', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '上原', 'ウワバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市表', '07', '07210', '9640901', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '表', 'オモテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市竹田', '07', '07210', '9640902', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '竹田', 'タケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市根崎', '07', '07210', '9640903', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '根崎', 'ネザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市郭内', '07', '07210', '9640904', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '郭内', 'カクナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市松岡', '07', '07210', '9640905', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '松岡', 'マツオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市若宮', '07', '07210', '9640906', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '若宮', 'ワカミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市細野', '07', '07210', '9640907', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '細野', 'ホソノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市亀谷', '07', '07210', '9640911', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '亀谷', 'カメガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市上竹', '07', '07210', '9640912', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '上竹', 'ジョウタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市茶園', '07', '07210', '9640913', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '茶園', 'サエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市市海道', '07', '07210', '9640914', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '市海道', 'イチカイドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市金色', '07', '07210', '9640915', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '金色', 'カナイロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市向原', '07', '07210', '9640916', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '向原', 'ムカイハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市本町', '07', '07210', '9640917', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '本町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市小セ川', '07', '07210', '9640921', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '小セ川', 'コセガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市島寺', '07', '07210', '9640922', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '島寺', 'シマデラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市長下', '07', '07210', '9640923', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '長下', 'ナガシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市中森', '07', '07210', '9640924', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '中森', 'ナカモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市谷和子', '07', '07210', '9640925', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '谷和子', 'ヤワコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市上蓬田', '07', '07210', '9640926', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '上蓬田', 'カミヨモギタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市石畑', '07', '07210', '9640927', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '石畑', 'イシハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市蓬田', '07', '07210', '9640928', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '蓬田', 'ヨモギダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市浅川', '07', '07210', '9640929', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '浅川', 'アサガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市矢ノ戸', '07', '07210', '9640931', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '矢ノ戸', 'ヤノト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市丑子内', '07', '07210', '9640932', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '丑子内', 'ウシコウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市西光内', '07', '07210', '9640933', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '西光内', 'サイコウウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市三合内', '07', '07210', '9640934', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '三合内', 'サンゴウウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市島ノ内', '07', '07210', '9640935', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '島ノ内', 'シマノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市諸越谷', '07', '07210', '9640936', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '諸越谷', 'モロコシガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市榎戸', '07', '07210', '9640937', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '榎戸', 'エノキド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市安達ケ原', '07', '07210', '9640938', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '安達ケ原', 'アダチガハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市水上', '07', '07210', '9640941', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '水上', 'ミズカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市式部内', '07', '07210', '9640942', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '式部内', 'シキブウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市明主内', '07', '07210', '9640943', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '明主内', 'ミョウシュウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市作', '07', '07210', '9640944', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '作', 'サク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市遠山', '07', '07210', '9640945', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '遠山', 'トオヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市堀越', '07', '07210', '9640946', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '堀越', 'ホリコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市松林', '07', '07210', '9640947', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '松林', 'マツバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市橋本', '07', '07210', '9640948', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '橋本', 'ハシモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市大平中井', '07', '07210', '9640949', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '大平中井', 'オオタイラナカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市宮本', '07', '07210', '9640951', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '宮本', 'ミヤモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市神明石', '07', '07210', '9640952', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '神明石', 'シンメイイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市沼ケ作', '07', '07210', '9640953', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '沼ケ作', 'ヌマガサク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市大稲場', '07', '07210', '9640954', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '大稲場', 'オオイナバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市沖', '07', '07210', '9640955', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '沖', 'オキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市木ノ崎', '07', '07210', '9640956', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '木ノ崎', 'キノサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市太子堂', '07', '07210', '9640957', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '太子堂', 'タイシドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市竹ノ内', '07', '07210', '9640958', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '竹ノ内', 'タケノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市八坂町', '07', '07210', '9640961', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '八坂町', 'ヤサカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市鈴石東町', '07', '07210', '9640962', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '鈴石東町', 'スズイシアズマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市大久保', '07', '07210', '9640963', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '大久保', 'オオクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市五月町', '07', '07210', '9640964', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '五月町', 'サツキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市芹沢', '07', '07210', '9640965', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '芹沢', 'セリサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市昭和町', '07', '07210', '9640966', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '昭和町', 'ショウワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市米五町', '07', '07210', '9640971', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '米五町', 'ヨナゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市鈴石町', '07', '07210', '9640972', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '鈴石町', 'スズイシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市平石町', '07', '07210', '9640973', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '平石町', 'ヒライシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市小高内', '07', '07210', '9640974', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '小高内', 'コダコウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市岡ノ内', '07', '07210', '9640975', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '岡ノ内', 'オカノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市新生町', '07', '07210', '9640976', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '新生町', 'シンセイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市平石高田', '07', '07210', '9640981', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '平石高田', 'ヒライシタカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市赤井沢', '07', '07210', '9640982', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '赤井沢', 'アカイサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市南トロミ', '07', '07210', '9640983', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '南トロミ', 'ミナミトロミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市北トロミ', '07', '07210', '9640984', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '北トロミ', 'キタトロミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市高田', '07', '07210', '9640985', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '高田', 'タカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市作田', '07', '07210', '9640986', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '作田', 'サクタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市冠木', '07', '07210', '9640987', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '冠木', 'カブキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市中町', '07', '07210', '9640991', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '中町', 'ナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市平石三丁目', '07', '07210', '9640992', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '平石三丁目', 'ヒライシサンチョウメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市田町', '07', '07210', '9640993', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '田町', 'タマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市南町', '07', '07210', '9640994', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '南町', 'ミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市錦町', '07', '07210', '9640995', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '錦町', 'ニシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市大町', '07', '07210', '9640996', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '大町', 'オオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市江口', '07', '07210', '9640997', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '江口', 'エグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市', '07', '07202', '9650000', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('137557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市一箕町松長', '07', '07202', '9650001', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '一箕町松長', 'イッキマチマツナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市一箕町金堀', '07', '07202', '9650002', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '一箕町金堀', 'イッキマチカネホリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市一箕町八幡', '07', '07202', '9650003', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '一箕町八幡', 'イッキマチヤハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市一箕町八角', '07', '07202', '9650004', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '一箕町八角', 'イッキマチヤスミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市一箕町亀賀', '07', '07202', '9650005', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '一箕町亀賀', 'イッキマチカメガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市一箕町鶴賀', '07', '07202', '9650006', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '一箕町鶴賀', 'イッキマチツルガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市飯盛', '07', '07202', '9650007', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '飯盛', 'イイモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市桧町', '07', '07202', '9650008', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '桧町', 'ヒノキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市鶴賀町', '07', '07202', '9650011', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '鶴賀町', 'ツルガマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市居合町', '07', '07202', '9650012', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '居合町', 'イアワセマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市堤町', '07', '07202', '9650013', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '堤町', 'ツツミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市大塚', '07', '07202', '9650014', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '大塚', 'オオツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市北滝沢', '07', '07202', '9650015', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '北滝沢', 'キタタキザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市中島町', '07', '07202', '9650016', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '中島町', 'ナカジママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市山見町', '07', '07202', '9650021', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '山見町', 'ヤマミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市滝沢町', '07', '07202', '9650022', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '滝沢町', 'タキザワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市蚕養町', '07', '07202', '9650023', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '蚕養町', 'コガイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市白虎町', '07', '07202', '9650024', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '白虎町', 'ビャッコマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市扇町', '07', '07202', '9650025', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '扇町', 'オオギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市平安町', '07', '07202', '9650026', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '平安町', 'ヘイアンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市花畑東', '07', '07202', '9650027', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '花畑東', 'ハナバタケヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市相生町', '07', '07202', '9650031', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '相生町', 'アイオイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市旭町', '07', '07202', '9650032', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '旭町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市行仁町', '07', '07202', '9650033', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '行仁町', 'ギョウニンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市上町', '07', '07202', '9650034', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '上町', 'ウワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市馬場町', '07', '07202', '9650035', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '馬場町', 'ババマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市馬場本町', '07', '07202', '9650036', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '馬場本町', 'ババモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市中央', '07', '07202', '9650037', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市昭和町', '07', '07202', '9650038', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '昭和町', 'ショウワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市駅前町', '07', '07202', '9650041', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '駅前町', 'エキマエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市大町', '07', '07202', '9650042', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '大町', 'オオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市城北町', '07', '07202', '9650043', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '城北町', 'ジョウホクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市七日町', '07', '07202', '9650044', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '七日町', 'ナノカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市西七日町', '07', '07202', '9650045', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '西七日町', 'ニシナノカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市八日町', '07', '07202', '9650046', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '八日町', 'ヨウカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市五月町', '07', '07202', '9650047', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '五月町', 'サツキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市橋本', '07', '07202', '9650048', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '橋本', 'ハシモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市町北町谷地', '07', '07202', '9650051', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '町北町谷地', 'マチキタマチヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市町北町始', '07', '07202', '9650052', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '町北町始', 'マチキタマチハシメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市町北町上荒久田', '07', '07202', '9650053', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '町北町上荒久田', 'マチキタマチカミアラクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市町北町石堂', '07', '07202', '9650054', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '町北町石堂', 'マチキタマチイシドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市石堂町', '07', '07202', '9650055', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '石堂町', 'イシドウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市金川町', '07', '07202', '9650056', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '金川町', 'カナガワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市町北町藤室', '07', '07202', '9650057', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '町北町藤室', 'マチキタマチフジムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市町北町中沢', '07', '07202', '9650058', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '町北町中沢', 'マチキタマチナカサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市インター西', '07', '07202', '9650059', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', 'インター西', 'インターニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市高久工業団地', '07', '07202', '9650060', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '高久工業団地', 'タカクコウギョウダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市神指町高久', '07', '07202', '9650061', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '神指町高久', 'コウザシマチタカク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市神指町北四合', '07', '07202', '9650062', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '神指町北四合', 'コウザシマチキタシゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市神指町高瀬', '07', '07202', '9650063', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '神指町高瀬', 'コウザシマチタカセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市神指町黒川', '07', '07202', '9650064', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '神指町黒川', 'コウザシマチクロカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市神指町中四合', '07', '07202', '9650065', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '神指町中四合', 'コウザシマチナカシゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市神指町横沼', '07', '07202', '9650066', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '神指町横沼', 'コウザシマチヨコヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市神指町下神指', '07', '07202', '9650067', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '神指町下神指', 'コウザシマチシモコウザシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市神指町小見', '07', '07202', '9650068', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '神指町小見', 'コウザシマチオミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市神指町天満', '07', '07202', '9650069', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '神指町天満', 'コウザシマチテンマン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市高野町木流', '07', '07202', '9650071', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '高野町木流', 'コウヤマチキナガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市高野町橋本木流', '07', '07202', '9650072', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '高野町橋本木流', 'コウヤマチハシモトキナガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市高野町上沼', '07', '07202', '9650073', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '高野町上沼', 'コウヤマチウワヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市高野町平塚', '07', '07202', '9650074', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '高野町平塚', 'コウヤマチヒラツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市高野町中前田', '07', '07202', '9650075', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '高野町中前田', 'コウヤマチナカマエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市高野町中沼', '07', '07202', '9650076', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '高野町中沼', 'コウヤマチナカヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市高野町上高野', '07', '07202', '9650077', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '高野町上高野', 'コウヤマチカミコウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市高野町柳川', '07', '07202', '9650078', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '高野町柳川', 'コウヤマチヤナガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市高野町界沢', '07', '07202', '9650079', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '高野町界沢', 'コウヤマチサカイザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市神指町西城戸', '07', '07202', '9650081', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '神指町西城戸', 'コウザシマチニシキド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市神指町榎木檀', '07', '07202', '9650082', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '神指町榎木檀', 'コウザシマチエノキダン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市神指町上神指', '07', '07202', '9650083', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '神指町上神指', 'コウザシマチカミコウザシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市神指町東神指', '07', '07202', '9650084', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '神指町東神指', 'コウザシマチヒガシコウザシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市神指町如来堂', '07', '07202', '9650085', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '神指町如来堂', 'コウザシマチニョライドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市神指町本丸', '07', '07202', '9650086', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '神指町本丸', 'コウザシマチホンマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市神指町高瀬新田', '07', '07202', '9650087', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '神指町高瀬新田', 'コウザシマチタカセシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市町北町中沢西', '07', '07202', '9650088', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '町北町中沢西', 'マチキタマチナカサワニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市北会津町真宮', '07', '07202', '9650101', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '北会津町真宮', 'キタアイヅマチマミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市真宮新町北', '07', '07202', '9650102', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '真宮新町北', 'マミヤシンマチキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市真宮新町南', '07', '07202', '9650103', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '真宮新町南', 'マミヤシンマチミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市北会津町和泉', '07', '07202', '9650107', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '北会津町和泉', 'キタアイヅマチイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市北会津町中里', '07', '07202', '9650110', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '北会津町中里', 'キタアイヅマチナカザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市北会津町下荒井', '07', '07202', '9650111', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '北会津町下荒井', 'キタアイヅマチシモアライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市北会津町白山', '07', '07202', '9650112', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '北会津町白山', 'キタアイヅマチハクサン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市北会津町安良田', '07', '07202', '9650113', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '北会津町安良田', 'キタアイヅマチアラタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市北会津町宮ノ下', '07', '07202', '9650114', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '北会津町宮ノ下', 'キタアイヅマチミヤノシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市北会津町舘', '07', '07202', '9650115', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '北会津町舘', 'キタアイヅマチタテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市北会津町出尻', '07', '07202', '9650116', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '北会津町出尻', 'キタアイヅマチイデジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市北会津町田村山', '07', '07202', '9650117', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '北会津町田村山', 'キタアイヅマチタムラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市北会津町石原', '07', '07202', '9650118', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '北会津町石原', 'キタアイヅマチイシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市北会津町蟹川', '07', '07202', '9650121', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '北会津町蟹川', 'キタアイヅマチカニカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市北会津町宮袋', '07', '07202', '9650124', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '北会津町宮袋', 'キタアイヅマチミヤブクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市北会津町鷺林', '07', '07202', '9650126', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '北会津町鷺林', 'キタアイヅマチサギバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市北会津町宮袋新田', '07', '07202', '9650127', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '北会津町宮袋新田', 'キタアイヅマチミヤブクロシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市北会津町十二所', '07', '07202', '9650128', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '北会津町十二所', 'キタアイヅマチジュウニショ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市北会津町本田', '07', '07202', '9650129', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '北会津町本田', 'キタアイヅマチホンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市北会津町中荒井', '07', '07202', '9650131', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '北会津町中荒井', 'キタアイヅマチナカアライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市北会津町ほたるの森', '07', '07202', '9650132', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '北会津町ほたるの森', 'キタアイヅマチホタルノモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市北会津町二日町', '07', '07202', '9650133', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '北会津町二日町', 'キタアイヅマチフツカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市北会津町東麻生', '07', '07202', '9650134', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '北会津町東麻生', 'キタアイヅマチヒガシアソウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市北会津町寺堀', '07', '07202', '9650135', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '北会津町寺堀', 'キタアイヅマチテラボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市北会津町今和泉', '07', '07202', '9650136', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '北会津町今和泉', 'キタアイヅマチイマイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市湊町赤井', '07', '07202', '9650201', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '湊町赤井', 'ミナトマチアカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市湊町共和', '07', '07202', '9650202', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '湊町共和', 'ミナトマチキョウワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市湊町静潟', '07', '07202', '9650203', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '湊町静潟', 'ミナトマチシズカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市湊町原', '07', '07202', '9650204', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '湊町原', 'ミナトマチハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市湊町平潟', '07', '07202', '9650205', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '湊町平潟', 'ミナトマチヒラカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市宮町', '07', '07202', '9650801', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '宮町', 'ミヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市徒之町', '07', '07202', '9650802', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '徒之町', 'カチノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市城前', '07', '07202', '9650803', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '城前', 'シロマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市花春町', '07', '07202', '9650804', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '花春町', 'ハナハルマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市天寧寺町', '07', '07202', '9650805', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '天寧寺町', 'テンネイジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市宝町', '07', '07202', '9650806', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '宝町', 'タカラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市城東町', '07', '07202', '9650807', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '城東町', 'ジョウトウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市南町', '07', '07202', '9650808', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '南町', 'ミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市城南町', '07', '07202', '9650809', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '城南町', 'ジョウナンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市和田', '07', '07202', '9650811', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '和田', 'ワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市慶山', '07', '07202', '9650812', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '慶山', 'ケイザン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市東山町石山', '07', '07202', '9650813', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '東山町石山', 'ヒガシヤママチイシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市東山町湯本', '07', '07202', '9650814', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '東山町湯本', 'ヒガシヤママチユモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市東山町湯川', '07', '07202', '9650815', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '東山町湯川', 'ヒガシヤママチユガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市南千石町', '07', '07202', '9650816', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '南千石町', 'ミナミセンゴクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市千石町', '07', '07202', '9650817', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '千石町', 'センゴクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市東千石', '07', '07202', '9650818', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '東千石', 'ヒガシセンゴク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市湯川南', '07', '07202', '9650821', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '湯川南', 'ユガワミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市花見ケ丘', '07', '07202', '9650822', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '花見ケ丘', 'ハナミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市建福寺前', '07', '07202', '9650823', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '建福寺前', 'ケンプクジマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市北青木', '07', '07202', '9650824', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '北青木', 'キタアオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市門田町黒岩', '07', '07202', '9650825', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '門田町黒岩', 'モンデンマチクロイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市門田町御山', '07', '07202', '9650826', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '門田町御山', 'モンデンマチオヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市門田町堤沢', '07', '07202', '9650827', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '門田町堤沢', 'モンデンマチツツミザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市門田町面川', '07', '07202', '9650828', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '門田町面川', 'モンデンマチオモガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市西年貢', '07', '07202', '9650830', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '西年貢', 'ニシネング', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市表町', '07', '07202', '9650831', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '表町', 'オモテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市天神町', '07', '07202', '9650832', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '天神町', 'テンジンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市明和町', '07', '07202', '9650833', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '明和町', 'メイワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市門田町年貢町', '07', '07202', '9650834', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '門田町年貢町', 'モンデンマチネングマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市館馬町', '07', '07202', '9650835', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '館馬町', 'タテウママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市館脇町', '07', '07202', '9650836', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '館脇町', 'タテワキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市錦町', '07', '07202', '9650837', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '錦町', 'ニシキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市古川町', '07', '07202', '9650838', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '古川町', 'フルカワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市東年貢', '07', '07202', '9650839', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '東年貢', 'ヒガシネング', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市門田町日吉', '07', '07202', '9650841', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '門田町日吉', 'モンデンマチヒヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市門田町中野', '07', '07202', '9650842', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '門田町中野', 'モンデンマチナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市門田町徳久', '07', '07202', '9650843', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '門田町徳久', 'モンデンマチトクヒサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市門田町一ノ堰', '07', '07202', '9650844', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '門田町一ノ堰', 'モンデンマチイチノセキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市門田町工業団地', '07', '07202', '9650845', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '門田町工業団地', 'モンデンマチコウギョウダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市門田町飯寺', '07', '07202', '9650846', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '門田町飯寺', 'モンデンマチニイデラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市御旗町', '07', '07202', '9650851', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '御旗町', 'オハタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市日吉町', '07', '07202', '9650852', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '日吉町', 'ヒヨシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市材木町', '07', '07202', '9650853', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '材木町', 'ザイモクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市桜町', '07', '07202', '9650854', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '桜町', 'サクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市住吉町', '07', '07202', '9650855', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '住吉町', 'スミヨシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市幕内東町', '07', '07202', '9650856', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '幕内東町', 'マクウチヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市柳原町', '07', '07202', '9650857', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '柳原町', 'ヤナギワラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市神指町南四合', '07', '07202', '9650858', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '神指町南四合', 'コウザシマチミナミシゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市日新町', '07', '07202', '9650861', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '日新町', 'ニッシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市本町', '07', '07202', '9650862', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市湯川町', '07', '07202', '9650863', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '湯川町', 'ユガワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市城西町', '07', '07202', '9650864', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '城西町', 'ジョウサイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市川原町', '07', '07202', '9650865', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '川原町', 'カワラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市新横町', '07', '07202', '9650866', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '新横町', 'シンヨコマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市緑町', '07', '07202', '9650867', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '緑町', 'ミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市栄町', '07', '07202', '9650871', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市東栄町', '07', '07202', '9650872', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '東栄町', 'ヒガシサカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市追手町', '07', '07202', '9650873', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '追手町', 'オウテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市南花畑', '07', '07202', '9650874', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '南花畑', 'ミナミハナバタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市米代', '07', '07202', '9650875', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '米代', 'ヨネダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市山鹿町', '07', '07202', '9650876', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '山鹿町', 'ヤマガマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市西栄町', '07', '07202', '9650877', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '西栄町', 'ニシサカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市中町', '07', '07202', '9650878', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '中町', 'ナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市', '07', '07208', '9660000', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('137750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市岩月町入田付', '07', '07208', '9660001', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '岩月町入田付', 'イワツキマチイリタツキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市岩月町宮津', '07', '07208', '9660002', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '岩月町宮津', 'イワツキマチミヤツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市岩月町橿野', '07', '07208', '9660003', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '岩月町橿野', 'イワツキマチカシワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市岩月町喜多方', '07', '07208', '9660004', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '岩月町喜多方', 'イワツキマチキタカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市岩月町大都', '07', '07208', '9660005', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '岩月町大都', 'イワツキマチオオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市北町上', '07', '07208', '9660006', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '北町上', 'キタマチカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市東桜ガ丘', '07', '07208', '9660007', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '東桜ガ丘', 'ヒガシサクラガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市関柴町関柴', '07', '07208', '9660011', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '関柴町関柴', 'セキシバマチセキシバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市関柴町下柴', '07', '07208', '9660012', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '関柴町下柴', 'セキシバマチシモシバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市関柴町豊芦', '07', '07208', '9660013', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '関柴町豊芦', 'セキシバマチトヨアシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市関柴町西勝', '07', '07208', '9660014', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '関柴町西勝', 'セキシバマチサイカツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市関柴町上高額', '07', '07208', '9660015', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '関柴町上高額', 'セキシバマチカミタカヒタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市関柴町平林', '07', '07208', '9660016', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '関柴町平林', 'セキシバマチヒラバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市関柴町三津井', '07', '07208', '9660017', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '関柴町三津井', 'セキシバマチミツイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市熊倉町都', '07', '07208', '9660021', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '熊倉町都', 'クマグラマチミヤコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市熊倉町雄国', '07', '07208', '9660022', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '熊倉町雄国', 'クマグラマチオグニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市熊倉町新合', '07', '07208', '9660023', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '熊倉町新合', 'クマグラマチシンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市熊倉町熊倉', '07', '07208', '9660024', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '熊倉町熊倉', 'クマグラマチクマグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市舞台田', '07', '07208', '9660031', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '舞台田', 'ブタイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市梨子ノ木', '07', '07208', '9660032', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '梨子ノ木', 'ナシノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市瀬戸', '07', '07208', '9660033', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '瀬戸', 'セト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市二本木', '07', '07208', '9660034', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '二本木', 'ニホンギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市中台', '07', '07208', '9660035', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '中台', 'ナカダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市畑台', '07', '07208', '9660035', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '畑台', 'ハタケダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市柳清水', '07', '07208', '9660036', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '柳清水', 'ヤナギシミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市大豆田', '07', '07208', '9660037', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '大豆田', 'オオマメダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市桜町', '07', '07208', '9660038', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '桜町', 'サクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市加登', '07', '07208', '9660039', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '加登', 'カト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市蒔田', '07', '07208', '9660041', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '蒔田', 'マキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市下江', '07', '07208', '9660042', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '下江', 'シモエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市上江', '07', '07208', '9660043', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '上江', 'カミエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市沢ノ目', '07', '07208', '9660044', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '沢ノ目', 'サワノメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市南原', '07', '07208', '9660045', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '南原', 'ミナミハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市原田', '07', '07208', '9660046', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '原田', 'ハラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市銭田', '07', '07208', '9660047', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '銭田', 'ゼニタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市越巻', '07', '07208', '9660048', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '越巻', 'コシマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市長面', '07', '07208', '9660049', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '長面', 'チョウメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市東町', '07', '07208', '9660051', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '東町', 'ヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市四百苅', '07', '07208', '9660052', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '四百苅', 'ヨンヒャクガリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市石田', '07', '07208', '9660053', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '石田', 'イシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市大谷地田', '07', '07208', '9660054', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '大谷地田', 'オオヤチタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市台', '07', '07208', '9660055', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '台', 'ダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市屋敷免', '07', '07208', '9660056', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '屋敷免', 'ヤシキメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市井戸尻', '07', '07208', '9660057', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '井戸尻', 'イドジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市馬場', '07', '07208', '9660061', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '馬場', 'ババ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市寺南', '07', '07208', '9660062', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '寺南', 'テラミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市五ノ神', '07', '07208', '9660063', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '五ノ神', 'ゴノカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市惣座宮', '07', '07208', '9660064', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '惣座宮', 'ソウザノミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市中川原', '07', '07208', '9660065', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '中川原', 'ナカガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市宮西', '07', '07208', '9660066', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '宮西', 'ミヤニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市村西', '07', '07208', '9660067', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '村西', 'ムラニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市寺西', '07', '07208', '9660068', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '寺西', 'テラニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市稲清水', '07', '07208', '9660069', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '稲清水', 'イナシミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市山ノ神', '07', '07208', '9660071', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '山ノ神', 'ヤマノカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市北町', '07', '07208', '9660072', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '北町', 'キタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市中町', '07', '07208', '9660073', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '中町', 'ナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市南町', '07', '07208', '9660074', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '南町', 'ミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市西町', '07', '07208', '9660081', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '西町', 'ニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市南条', '07', '07208', '9660082', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '南条', 'ナンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市六枚長', '07', '07208', '9660083', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '六枚長', 'ロクマイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市西井戸尻', '07', '07208', '9660084', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '西井戸尻', 'ニシイドジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市江中子', '07', '07208', '9660085', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '江中子', 'エナカコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市西四ツ谷', '07', '07208', '9660086', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '西四ツ谷', 'ニシヨツヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市稲荷宮', '07', '07208', '9660087', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '稲荷宮', 'イナリノミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市青葉台', '07', '07208', '9660091', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '青葉台', 'アオバダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市清水台', '07', '07208', '9660092', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '清水台', 'シミズダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市清水が丘', '07', '07208', '9660093', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '清水が丘', 'シミズガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市押切', '07', '07208', '9660094', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '押切', 'オシキリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市押切東', '07', '07208', '9660095', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '押切東', 'オシキリヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市押切南', '07', '07208', '9660096', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '押切南', 'オシキリミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市通船場', '07', '07208', '9660097', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '通船場', 'ツウセンバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市熱塩加納町熱塩', '07', '07208', '9660101', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '熱塩加納町熱塩', 'アツシオカノウマチアツシオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市熱塩加納町山田', '07', '07208', '9660102', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '熱塩加納町山田', 'アツシオカノウマチヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市熱塩加納町加納', '07', '07208', '9660103', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '熱塩加納町加納', 'アツシオカノウマチカノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市熱塩加納町米岡', '07', '07208', '9660104', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '熱塩加納町米岡', 'アツシオカノウマチヨネオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市熱塩加納町宮川', '07', '07208', '9660105', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '熱塩加納町宮川', 'アツシオカノウマチミヤカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市熱塩加納町林際', '07', '07208', '9660106', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '熱塩加納町林際', 'アツシオカノウマチハヤシギワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市熱塩加納町居廻', '07', '07208', '9660107', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '熱塩加納町居廻', 'アツシオカノウマチイマワリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市熱塩加納町相田', '07', '07208', '9660108', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '熱塩加納町相田', 'アツシオカノウマチアイタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡北塩原村', '07', '07402', '9660400', '福島県', 'フクシマケン', '耶麻郡北塩原村', 'ヤマグンキタシオバラムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('137833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡北塩原村檜原黄連沢山', '07', '07402', '9660401', '福島県', 'フクシマケン', '耶麻郡北塩原村', 'ヤマグンキタシオバラムラ', '檜原', 'ヒバラ', null, null, '黄連沢山', 'オウレンサワヤマ');
INSERT INTO `ms_addresses` VALUES ('137834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡北塩原村檜原黄連原山', '07', '07402', '9660401', '福島県', 'フクシマケン', '耶麻郡北塩原村', 'ヤマグンキタシオバラムラ', '檜原', 'ヒバラ', null, null, '黄連原山', 'オウレンハラヤマ');
INSERT INTO `ms_addresses` VALUES ('137835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡北塩原村檜原雄子沢', '07', '07402', '9660401', '福島県', 'フクシマケン', '耶麻郡北塩原村', 'ヤマグンキタシオバラムラ', '檜原', 'ヒバラ', null, null, '雄子沢', 'オシザワ');
INSERT INTO `ms_addresses` VALUES ('137836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡北塩原村檜原雄子沢原', '07', '07402', '9660401', '福島県', 'フクシマケン', '耶麻郡北塩原村', 'ヤマグンキタシオバラムラ', '檜原', 'ヒバラ', null, null, '雄子沢原', 'オシザワハラ');
INSERT INTO `ms_addresses` VALUES ('137837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡北塩原村檜原細野', '07', '07402', '9660401', '福島県', 'フクシマケン', '耶麻郡北塩原村', 'ヤマグンキタシオバラムラ', '檜原', 'ヒバラ', null, null, '細野', 'ホソノ');
INSERT INTO `ms_addresses` VALUES ('137838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡北塩原村檜原南黄連沢', '07', '07402', '9660401', '福島県', 'フクシマケン', '耶麻郡北塩原村', 'ヤマグンキタシオバラムラ', '檜原', 'ヒバラ', null, null, '南黄連沢', 'ミナミオウレンサワ');
INSERT INTO `ms_addresses` VALUES ('137839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡北塩原村檜原南黄連沢山', '07', '07402', '9660401', '福島県', 'フクシマケン', '耶麻郡北塩原村', 'ヤマグンキタシオバラムラ', '檜原', 'ヒバラ', null, null, '南黄連沢山', 'ミナミオウレンサワヤマ');
INSERT INTO `ms_addresses` VALUES ('137840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡北塩原村大塩', '07', '07402', '9660402', '福島県', 'フクシマケン', '耶麻郡北塩原村', 'ヤマグンキタシオバラムラ', '大塩', 'オオシオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡北塩原村関屋', '07', '07402', '9660403', '福島県', 'フクシマケン', '耶麻郡北塩原村', 'ヤマグンキタシオバラムラ', '関屋', 'セキヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡北塩原村北山', '07', '07402', '9660404', '福島県', 'フクシマケン', '耶麻郡北塩原村', 'ヤマグンキタシオバラムラ', '北山', 'キタヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡北塩原村下吉', '07', '07402', '9660405', '福島県', 'フクシマケン', '耶麻郡北塩原村', 'ヤマグンキタシオバラムラ', '下吉', 'シモヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡北塩原村檜原苧畑沢', '07', '07402', '9660501', '福島県', 'フクシマケン', '耶麻郡北塩原村', 'ヤマグンキタシオバラムラ', '檜原', 'ヒバラ', null, null, '苧畑沢', 'ウバタサワ');
INSERT INTO `ms_addresses` VALUES ('137846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡北塩原村檜原金山', '07', '07402', '9660501', '福島県', 'フクシマケン', '耶麻郡北塩原村', 'ヤマグンキタシオバラムラ', '檜原', 'ヒバラ', null, null, '金山', 'カナヤマ');
INSERT INTO `ms_addresses` VALUES ('137847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡北塩原村檜原五十両原', '07', '07402', '9660501', '福島県', 'フクシマケン', '耶麻郡北塩原村', 'ヤマグンキタシオバラムラ', '檜原', 'ヒバラ', null, null, '五十両原', 'ゴジュウリョウハラ');
INSERT INTO `ms_addresses` VALUES ('137848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡北塩原村檜原小屋沢', '07', '07402', '9660501', '福島県', 'フクシマケン', '耶麻郡北塩原村', 'ヤマグンキタシオバラムラ', '檜原', 'ヒバラ', null, null, '小屋沢', 'コヤサワ');
INSERT INTO `ms_addresses` VALUES ('137849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡北塩原村檜原巣ノ山', '07', '07402', '9660501', '福島県', 'フクシマケン', '耶麻郡北塩原村', 'ヤマグンキタシオバラムラ', '檜原', 'ヒバラ', null, null, '巣ノ山', 'スノヤマ');
INSERT INTO `ms_addresses` VALUES ('137850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡北塩原村檜原滝ノ原', '07', '07402', '9660501', '福島県', 'フクシマケン', '耶麻郡北塩原村', 'ヤマグンキタシオバラムラ', '檜原', 'ヒバラ', null, null, '滝ノ原', 'タキノハラ');
INSERT INTO `ms_addresses` VALUES ('137851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡北塩原村檜原館山', '07', '07402', '9660501', '福島県', 'フクシマケン', '耶麻郡北塩原村', 'ヤマグンキタシオバラムラ', '檜原', 'ヒバラ', null, null, '館山', 'タテヤマ');
INSERT INTO `ms_addresses` VALUES ('137852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡北塩原村檜原道前原', '07', '07402', '9660501', '福島県', 'フクシマケン', '耶麻郡北塩原村', 'ヤマグンキタシオバラムラ', '檜原', 'ヒバラ', null, null, '道前原', 'ドウゼンハラ');
INSERT INTO `ms_addresses` VALUES ('137853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡北塩原村檜原中原', '07', '07402', '9660501', '福島県', 'フクシマケン', '耶麻郡北塩原村', 'ヤマグンキタシオバラムラ', '檜原', 'ヒバラ', null, null, '中原', 'ナカハラ');
INSERT INTO `ms_addresses` VALUES ('137854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡北塩原村檜原楢木平原', '07', '07402', '9660501', '福島県', 'フクシマケン', '耶麻郡北塩原村', 'ヤマグンキタシオバラムラ', '檜原', 'ヒバラ', null, null, '楢木平原', 'ナラノキダイラハラ');
INSERT INTO `ms_addresses` VALUES ('137855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡北塩原村檜原墓下', '07', '07402', '9660501', '福島県', 'フクシマケン', '耶麻郡北塩原村', 'ヤマグンキタシオバラムラ', '檜原', 'ヒバラ', null, null, '墓下', 'ハカシタ');
INSERT INTO `ms_addresses` VALUES ('137856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡北塩原村檜原桧原', '07', '07402', '9660501', '福島県', 'フクシマケン', '耶麻郡北塩原村', 'ヤマグンキタシオバラムラ', '檜原', 'ヒバラ', null, null, '桧原', 'ヒバラ');
INSERT INTO `ms_addresses` VALUES ('137857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡北塩原村檜原水梨原', '07', '07402', '9660501', '福島県', 'フクシマケン', '耶麻郡北塩原村', 'ヤマグンキタシオバラムラ', '檜原', 'ヒバラ', null, null, '水梨原', 'ミズナシハラ');
INSERT INTO `ms_addresses` VALUES ('137858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡北塩原村檜原無縁原', '07', '07402', '9660501', '福島県', 'フクシマケン', '耶麻郡北塩原村', 'ヤマグンキタシオバラムラ', '檜原', 'ヒバラ', null, null, '無縁原', 'ムエンハラ');
INSERT INTO `ms_addresses` VALUES ('137859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡北塩原村檜原焼桂山', '07', '07402', '9660501', '福島県', 'フクシマケン', '耶麻郡北塩原村', 'ヤマグンキタシオバラムラ', '檜原', 'ヒバラ', null, null, '焼桂山', 'ヤケガツラヤマ');
INSERT INTO `ms_addresses` VALUES ('137860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡北塩原村檜原早稲沢', '07', '07402', '9660501', '福島県', 'フクシマケン', '耶麻郡北塩原村', 'ヤマグンキタシオバラムラ', '檜原', 'ヒバラ', null, null, '早稲沢', 'ワセザワ');
INSERT INTO `ms_addresses` VALUES ('137861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市常盤台', '07', '07208', '9660801', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '常盤台', 'トキワダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市桜が丘', '07', '07208', '9660802', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '桜が丘', 'サクラガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市落合', '07', '07208', '9660803', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '落合', 'オチアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市沼田', '07', '07208', '9660804', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '沼田', 'ヌマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市小田付道上', '07', '07208', '9660805', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '小田付道上', 'オタヅキミチウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市水上', '07', '07208', '9660806', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '水上', 'ミズカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市上川向', '07', '07208', '9660811', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '上川向', 'カミカワムカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市緑町', '07', '07208', '9660812', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '緑町', 'ミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市小田付道下', '07', '07208', '9660813', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '小田付道下', 'オタヅキミチシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市御清水', '07', '07208', '9660814', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '御清水', 'オシミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市御清水東', '07', '07208', '9660814', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '御清水東', 'オシミズヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市谷地田', '07', '07208', '9660815', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '谷地田', 'ヤチタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市細田', '07', '07208', '9660816', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '細田', 'ホソダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市3丁目', '07', '07208', '9660817', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '3丁目', '03チョウメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市2丁目', '07', '07208', '9660818', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '2丁目', '02チョウメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市1丁目', '07', '07208', '9660819', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '1丁目', '01チョウメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市梅竹', '07', '07208', '9660821', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '梅竹', 'ウメタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市柳原', '07', '07208', '9660822', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '柳原', 'ヤナギハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市東川原田', '07', '07208', '9660823', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '東川原田', 'ヒガシカワラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市六百刈', '07', '07208', '9660824', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '六百刈', 'ロッピャクガリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市御清水南', '07', '07208', '9660825', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '御清水南', 'オシミズミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市町尻東', '07', '07208', '9660826', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '町尻東', 'マチジリヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市沢ノ免', '07', '07208', '9660827', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '沢ノ免', 'サワノメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市小田', '07', '07208', '9660831', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '小田', 'オダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市百苅田', '07', '07208', '9660832', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '百苅田', 'ヒャクガリダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市中島', '07', '07208', '9660833', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '中島', 'ナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市谷地田上', '07', '07208', '9660834', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '谷地田上', 'ヤチダカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市行作', '07', '07208', '9660835', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '行作', 'ギョウサク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市大坪', '07', '07208', '9660836', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '大坪', 'オオツボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市前田上', '07', '07208', '9660837', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '前田上', 'マエダカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市永久', '07', '07208', '9660838', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '永久', 'エイキュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市大道田', '07', '07208', '9660839', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '大道田', 'オオミチタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市さつきが丘', '07', '07208', '9660841', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', 'さつきが丘', 'サツキガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市川下', '07', '07208', '9660842', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '川下', 'カワシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市東籠田', '07', '07208', '9660843', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '東籠田', 'ヒガシカゴタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市西籠田', '07', '07208', '9660844', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '西籠田', 'ニシカゴタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市長内', '07', '07208', '9660845', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '長内', 'オサナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市町田下', '07', '07208', '9660846', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '町田下', 'マチダシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市町田', '07', '07208', '9660847', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '町田', 'マチダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市一本木下', '07', '07208', '9660848', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '一本木下', 'イッポンギシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市一本木上', '07', '07208', '9660849', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '一本木上', 'イッポンギウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市北原', '07', '07208', '9660851', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '北原', 'キタハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市天満前', '07', '07208', '9660852', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '天満前', 'テンマンマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市千苅', '07', '07208', '9660853', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '千苅', 'センガリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市千苅道上', '07', '07208', '9660854', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '千苅道上', 'センガリミチウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市太子堂', '07', '07208', '9660855', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '太子堂', 'タイシドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市長源段', '07', '07208', '9660856', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '長源段', 'チョウゲンダン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市町西', '07', '07208', '9660857', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '町西', 'マチニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市町北', '07', '07208', '9660858', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '町北', 'マチキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市番帳免', '07', '07208', '9660859', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '番帳免', 'バンチョウメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市寺町', '07', '07208', '9660861', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '寺町', 'テラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市常盤町', '07', '07208', '9660862', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '常盤町', 'トキワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市前田', '07', '07208', '9660862', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '前田', 'マエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市町尻西', '07', '07208', '9660863', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '町尻西', 'マチジリニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市七百苅', '07', '07208', '9660864', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '七百苅', 'ナナヒャクガリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市寺田', '07', '07208', '9660865', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '寺田', 'テラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市古寺', '07', '07208', '9660866', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '古寺', 'フルデラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市扇田', '07', '07208', '9660867', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '扇田', 'オウギダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市市道', '07', '07208', '9660868', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '市道', 'イチミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市慶徳道下', '07', '07208', '9660869', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '慶徳道下', 'ケイトクミチシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市寺町南', '07', '07208', '9660871', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '寺町南', 'テラマチミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市慶徳道上', '07', '07208', '9660872', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '慶徳道上', 'ケイトクミチウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市舘野', '07', '07208', '9660873', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '舘野', 'タテノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市窪屋敷', '07', '07208', '9660874', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '窪屋敷', 'クボヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市鶴巻', '07', '07208', '9660875', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '鶴巻', 'ツルマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市坂井道上', '07', '07208', '9660877', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '坂井道上', 'サカイミチウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市中清水', '07', '07208', '9660881', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '中清水', 'ナカシミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市中寺', '07', '07208', '9660882', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '中寺', 'ナカデラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市壇ノ前', '07', '07208', '9660884', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '壇ノ前', 'ダンノマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市飯田道上', '07', '07208', '9660887', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '飯田道上', 'イイダミチウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市蝦蟆渕', '07', '07208', '9660891', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '蝦蟆渕', 'ガマブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市経壇', '07', '07208', '9660892', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '経壇', 'キョウダン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市花園', '07', '07208', '9660893', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '花園', 'ハナゾノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市御茶屋', '07', '07208', '9660894', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '御茶屋', 'オチヤヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市東小原', '07', '07208', '9660895', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '東小原', 'ヒガシオバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市諏訪', '07', '07208', '9660896', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '諏訪', 'スワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市見頃道上', '07', '07208', '9660898', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '見頃道上', 'ミゴロミチウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市樋越', '07', '07208', '9660899', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '樋越', 'トイゴシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市松山町鳥見山', '07', '07208', '9660901', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '松山町鳥見山', 'マツヤママチトリミヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市松山町村松', '07', '07208', '9660902', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '松山町村松', 'マツヤママチムラマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市松山町大飯坂', '07', '07208', '9660903', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '松山町大飯坂', 'マツヤママチオオイイザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市豊川町高堂太', '07', '07208', '9660911', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '豊川町高堂太', 'トヨカワマチタカドウタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市豊川町一井', '07', '07208', '9660912', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '豊川町一井', 'トヨカワマチイチイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市豊川町沢部', '07', '07208', '9660913', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '豊川町沢部', 'トヨカワマチサワベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市豊川町米室', '07', '07208', '9660914', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '豊川町米室', 'トヨカワマチヨネムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市大谷地', '07', '07208', '9660915', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '大谷地', 'オオヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市慶徳町松舞家', '07', '07208', '9660921', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '慶徳町松舞家', 'ケイトクマチマツマイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市慶徳町豊岡', '07', '07208', '9660922', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '慶徳町豊岡', 'ケイトクマチトヨオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市慶徳町新宮', '07', '07208', '9660923', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '慶徳町新宮', 'ケイトクマチシングウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市慶徳町山科', '07', '07208', '9660924', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '慶徳町山科', 'ケイトクマチヤマシナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市上三宮町上三宮', '07', '07208', '9660931', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '上三宮町上三宮', 'カミサンミヤマチカミサンミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市上三宮町吉川', '07', '07208', '9660932', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '上三宮町吉川', 'カミサンミヤマチヨシカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市上三宮町三谷', '07', '07208', '9660933', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '上三宮町三谷', 'カミサンミヤマチミタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡南会津町', '07', '07368', '9670000', '福島県', 'フクシマケン', '南会津郡南会津町', 'ミナミアイヅグンミナミアイヅマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('137956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡南会津町長野', '07', '07368', '9670001', '福島県', 'フクシマケン', '南会津郡南会津町', 'ミナミアイヅグンミナミアイヅマチ', '長野', 'ナガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡南会津町田部', '07', '07368', '9670002', '福島県', 'フクシマケン', '南会津郡南会津町', 'ミナミアイヅグンミナミアイヅマチ', '田部', 'タベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡南会津町水無', '07', '07368', '9670003', '福島県', 'フクシマケン', '南会津郡南会津町', 'ミナミアイヅグンミナミアイヅマチ', '水無', 'ミズナシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡南会津町田島', '07', '07368', '9670004', '福島県', 'フクシマケン', '南会津郡南会津町', 'ミナミアイヅグンミナミアイヅマチ', '田島', 'タジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡南会津町中荒井', '07', '07368', '9670005', '福島県', 'フクシマケン', '南会津郡南会津町', 'ミナミアイヅグンミナミアイヅマチ', '中荒井', 'ナカアライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡南会津町永田', '07', '07368', '9670006', '福島県', 'フクシマケン', '南会津郡南会津町', 'ミナミアイヅグンミナミアイヅマチ', '永田', 'ナガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡南会津町丹藤', '07', '07368', '9670007', '福島県', 'フクシマケン', '南会津郡南会津町', 'ミナミアイヅグンミナミアイヅマチ', '丹藤', 'タンドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡南会津町栗生沢', '07', '07368', '9670011', '福島県', 'フクシマケン', '南会津郡南会津町', 'ミナミアイヅグンミナミアイヅマチ', '栗生沢', 'クリュウザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡南会津町川島', '07', '07368', '9670012', '福島県', 'フクシマケン', '南会津郡南会津町', 'ミナミアイヅグンミナミアイヅマチ', '川島', 'カワシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡南会津町関本', '07', '07368', '9670013', '福島県', 'フクシマケン', '南会津郡南会津町', 'ミナミアイヅグンミナミアイヅマチ', '関本', 'セキモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡南会津町糸沢', '07', '07368', '9670014', '福島県', 'フクシマケン', '南会津郡南会津町', 'ミナミアイヅグンミナミアイヅマチ', '糸沢', 'イトザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡南会津町滝原', '07', '07368', '9670015', '福島県', 'フクシマケン', '南会津郡南会津町', 'ミナミアイヅグンミナミアイヅマチ', '滝原', 'タキノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡南会津町藤生', '07', '07368', '9670016', '福島県', 'フクシマケン', '南会津郡南会津町', 'ミナミアイヅグンミナミアイヅマチ', '藤生', 'トウニュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡南会津町高野', '07', '07368', '9670021', '福島県', 'フクシマケン', '南会津郡南会津町', 'ミナミアイヅグンミナミアイヅマチ', '高野', 'コウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡南会津町塩江', '07', '07368', '9670022', '福島県', 'フクシマケン', '南会津郡南会津町', 'ミナミアイヅグンミナミアイヅマチ', '塩江', 'シオエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡南会津町福米沢', '07', '07368', '9670023', '福島県', 'フクシマケン', '南会津郡南会津町', 'ミナミアイヅグンミナミアイヅマチ', '福米沢', 'フクメザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡南会津町金井沢', '07', '07368', '9670024', '福島県', 'フクシマケン', '南会津郡南会津町', 'ミナミアイヅグンミナミアイヅマチ', '金井沢', 'カナイザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡南会津町静川', '07', '07368', '9670025', '福島県', 'フクシマケン', '南会津郡南会津町', 'ミナミアイヅグンミナミアイヅマチ', '静川', 'シズカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡南会津町針生', '07', '07368', '9670026', '福島県', 'フクシマケン', '南会津郡南会津町', 'ミナミアイヅグンミナミアイヅマチ', '針生', 'ハリュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡南会津町たのせ', '07', '07368', '9670301', '福島県', 'フクシマケン', '南会津郡南会津町', 'ミナミアイヅグンミナミアイヅマチ', 'たのせ', 'タノセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡南会津町塩ノ原', '07', '07368', '9670302', '福島県', 'フクシマケン', '南会津郡南会津町', 'ミナミアイヅグンミナミアイヅマチ', '塩ノ原', 'シオノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡南会津町福渡', '07', '07368', '9670303', '福島県', 'フクシマケン', '南会津郡南会津町', 'ミナミアイヅグンミナミアイヅマチ', '福渡', 'フクワタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡南会津町松戸原', '07', '07368', '9670304', '福島県', 'フクシマケン', '南会津郡南会津町', 'ミナミアイヅグンミナミアイヅマチ', '松戸原', 'マツトハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡南会津町戸中', '07', '07368', '9670305', '福島県', 'フクシマケン', '南会津郡南会津町', 'ミナミアイヅグンミナミアイヅマチ', '戸中', 'トチュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡南会津町前沢', '07', '07368', '9670306', '福島県', 'フクシマケン', '南会津郡南会津町', 'ミナミアイヅグンミナミアイヅマチ', '前沢', 'マエザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡南会津町水石', '07', '07368', '9670307', '福島県', 'フクシマケン', '南会津郡南会津町', 'ミナミアイヅグンミナミアイヅマチ', '水石', 'スイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡南会津町新田原', '07', '07368', '9670311', '福島県', 'フクシマケン', '南会津郡南会津町', 'ミナミアイヅグンミナミアイヅマチ', '新田原', 'シンデンハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡南会津町熨斗戸', '07', '07368', '9670312', '福島県', 'フクシマケン', '南会津郡南会津町', 'ミナミアイヅグンミナミアイヅマチ', '熨斗戸', 'ノシト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡南会津町森戸', '07', '07368', '9670313', '福島県', 'フクシマケン', '南会津郡南会津町', 'ミナミアイヅグンミナミアイヅマチ', '森戸', 'モリト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡南会津町八総', '07', '07368', '9670314', '福島県', 'フクシマケン', '南会津郡南会津町', 'ミナミアイヅグンミナミアイヅマチ', '八総', 'ヤソウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡南会津町高杖原', '07', '07368', '9670315', '福島県', 'フクシマケン', '南会津郡南会津町', 'ミナミアイヅグンミナミアイヅマチ', '高杖原', 'タカツエハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡南会津町伊与戸', '07', '07368', '9670317', '福島県', 'フクシマケン', '南会津郡南会津町', 'ミナミアイヅグンミナミアイヅマチ', '伊与戸', 'イヨト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡南会津町八木ノ沢', '07', '07368', '9670318', '福島県', 'フクシマケン', '南会津郡南会津町', 'ミナミアイヅグンミナミアイヅマチ', '八木ノ沢', 'ヤギノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡南会津町大久保', '07', '07368', '9670319', '福島県', 'フクシマケン', '南会津郡南会津町', 'ミナミアイヅグンミナミアイヅマチ', '大久保', 'オオクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡南会津町井桁', '07', '07368', '9670321', '福島県', 'フクシマケン', '南会津郡南会津町', 'ミナミアイヅグンミナミアイヅマチ', '井桁', 'イゲタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡南会津町精舎', '07', '07368', '9670322', '福島県', 'フクシマケン', '南会津郡南会津町', 'ミナミアイヅグンミナミアイヅマチ', '精舎', 'ショウジャ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡南会津町岩下', '07', '07368', '9670323', '福島県', 'フクシマケン', '南会津郡南会津町', 'ミナミアイヅグンミナミアイヅマチ', '岩下', 'イワシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡南会津町番屋', '07', '07368', '9670324', '福島県', 'フクシマケン', '南会津郡南会津町', 'ミナミアイヅグンミナミアイヅマチ', '番屋', 'バンヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡南会津町押戸', '07', '07368', '9670331', '福島県', 'フクシマケン', '南会津郡南会津町', 'ミナミアイヅグンミナミアイヅマチ', '押戸', 'オシド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡南会津町角生', '07', '07368', '9670332', '福島県', 'フクシマケン', '南会津郡南会津町', 'ミナミアイヅグンミナミアイヅマチ', '角生', 'ツノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡南会津町湯ノ花', '07', '07368', '9670333', '福島県', 'フクシマケン', '南会津郡南会津町', 'ミナミアイヅグンミナミアイヅマチ', '湯ノ花', 'ユノハナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡南会津町水引', '07', '07368', '9670334', '福島県', 'フクシマケン', '南会津郡南会津町', 'ミナミアイヅグンミナミアイヅマチ', '水引', 'ミズヒキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡南会津町貝原', '07', '07368', '9670335', '福島県', 'フクシマケン', '南会津郡南会津町', 'ミナミアイヅグンミナミアイヅマチ', '貝原', 'カイバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('137999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡南会津町吉高', '07', '07368', '9670336', '福島県', 'フクシマケン', '南会津郡南会津町', 'ミナミアイヅグンミナミアイヅマチ', '吉高', 'ヨシタカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡南会津町穴原', '07', '07368', '9670341', '福島県', 'フクシマケン', '南会津郡南会津町', 'ミナミアイヅグンミナミアイヅマチ', '穴原', 'アナバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡南会津町助木生', '07', '07368', '9670342', '福島県', 'フクシマケン', '南会津郡南会津町', 'ミナミアイヅグンミナミアイヅマチ', '助木生', 'スケギュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡南会津町小高林', '07', '07368', '9670343', '福島県', 'フクシマケン', '南会津郡南会津町', 'ミナミアイヅグンミナミアイヅマチ', '小高林', 'コタカバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡南会津町上ミノ原', '07', '07368', '9670344', '福島県', 'フクシマケン', '南会津郡南会津町', 'ミナミアイヅグンミナミアイヅマチ', '上ミノ原', 'カミノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡南会津町木賊', '07', '07368', '9670345', '福島県', 'フクシマケン', '南会津郡南会津町', 'ミナミアイヅグンミナミアイヅマチ', '木賊', 'トクサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡南会津町川衣', '07', '07368', '9670346', '福島県', 'フクシマケン', '南会津郡南会津町', 'ミナミアイヅグンミナミアイヅマチ', '川衣', 'カワギヌ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡南会津町宮里', '07', '07368', '9670347', '福島県', 'フクシマケン', '南会津郡南会津町', 'ミナミアイヅグンミナミアイヅマチ', '宮里', 'ミヤザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡檜枝岐村', '07', '07364', '9670500', '福島県', 'フクシマケン', '南会津郡檜枝岐村', 'ミナミアイヅグンヒノエマタムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('138008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡南会津町古町', '07', '07368', '9670501', '福島県', 'フクシマケン', '南会津郡南会津町', 'ミナミアイヅグンミナミアイヅマチ', '古町', 'フルマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡南会津町多々石', '07', '07368', '9670502', '福島県', 'フクシマケン', '南会津郡南会津町', 'ミナミアイヅグンミナミアイヅマチ', '多々石', 'タダイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡南会津町白沢', '07', '07368', '9670503', '福島県', 'フクシマケン', '南会津郡南会津町', 'ミナミアイヅグンミナミアイヅマチ', '白沢', 'シラサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡南会津町浜野', '07', '07368', '9670504', '福島県', 'フクシマケン', '南会津郡南会津町', 'ミナミアイヅグンミナミアイヅマチ', '浜野', 'ハマノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡南会津町宮沢', '07', '07368', '9670505', '福島県', 'フクシマケン', '南会津郡南会津町', 'ミナミアイヅグンミナミアイヅマチ', '宮沢', 'ミヤザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡南会津町小塩', '07', '07368', '9670506', '福島県', 'フクシマケン', '南会津郡南会津町', 'ミナミアイヅグンミナミアイヅマチ', '小塩', 'コシオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡南会津町青柳', '07', '07368', '9670507', '福島県', 'フクシマケン', '南会津郡南会津町', 'ミナミアイヅグンミナミアイヅマチ', '青柳', 'アオヤギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡南会津町内川', '07', '07368', '9670511', '福島県', 'フクシマケン', '南会津郡南会津町', 'ミナミアイヅグンミナミアイヅマチ', '内川', 'ウチカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡南会津町耻風', '07', '07368', '9670512', '福島県', 'フクシマケン', '南会津郡南会津町', 'ミナミアイヅグンミナミアイヅマチ', '耻風', 'ハジカゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡南会津町大原', '07', '07368', '9670513', '福島県', 'フクシマケン', '南会津郡南会津町', 'ミナミアイヅグンミナミアイヅマチ', '大原', 'オオハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡南会津町小立岩', '07', '07368', '9670514', '福島県', 'フクシマケン', '南会津郡南会津町', 'ミナミアイヅグンミナミアイヅマチ', '小立岩', 'コダテイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡南会津町大桃', '07', '07368', '9670515', '福島県', 'フクシマケン', '南会津郡南会津町', 'ミナミアイヅグンミナミアイヅマチ', '大桃', 'オオモモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡檜枝岐村居平', '07', '07364', '9670521', '福島県', 'フクシマケン', '南会津郡檜枝岐村', 'ミナミアイヅグンヒノエマタムラ', '居平', 'イダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡檜枝岐村上ノ原', '07', '07364', '9670522', '福島県', 'フクシマケン', '南会津郡檜枝岐村', 'ミナミアイヅグンヒノエマタムラ', '上ノ原', 'カミノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡檜枝岐村下ノ台', '07', '07364', '9670523', '福島県', 'フクシマケン', '南会津郡檜枝岐村', 'ミナミアイヅグンヒノエマタムラ', '下ノ台', 'シタノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡檜枝岐村上ノ台', '07', '07364', '9670524', '福島県', 'フクシマケン', '南会津郡檜枝岐村', 'ミナミアイヅグンヒノエマタムラ', '上ノ台', 'ウエノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡檜枝岐村下ノ原', '07', '07364', '9670525', '福島県', 'フクシマケン', '南会津郡檜枝岐村', 'ミナミアイヅグンヒノエマタムラ', '下ノ原', 'シモノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡檜枝岐村滝沢', '07', '07364', '9670526', '福島県', 'フクシマケン', '南会津郡檜枝岐村', 'ミナミアイヅグンヒノエマタムラ', '滝沢', 'タキザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡檜枝岐村見通', '07', '07364', '9670527', '福島県', 'フクシマケン', '南会津郡檜枝岐村', 'ミナミアイヅグンヒノエマタムラ', '見通', 'ミヅウリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡檜枝岐村葭ケ平', '07', '07364', '9670528', '福島県', 'フクシマケン', '南会津郡檜枝岐村', 'ミナミアイヅグンヒノエマタムラ', '葭ケ平', 'ヨシガタイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡檜枝岐村燧ケ岳', '07', '07364', '9670531', '福島県', 'フクシマケン', '南会津郡檜枝岐村', 'ミナミアイヅグンヒノエマタムラ', '燧ケ岳', 'ヒウチガタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡檜枝岐村尾瀬沼', '07', '07364', '9670532', '福島県', 'フクシマケン', '南会津郡檜枝岐村', 'ミナミアイヅグンヒノエマタムラ', '尾瀬沼', 'オゼヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡南会津町木伏', '07', '07368', '9670601', '福島県', 'フクシマケン', '南会津郡南会津町', 'ミナミアイヅグンミナミアイヅマチ', '木伏', 'キブシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡南会津町水根沢', '07', '07368', '9670602', '福島県', 'フクシマケン', '南会津郡南会津町', 'ミナミアイヅグンミナミアイヅマチ', '水根沢', 'ミズネサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡南会津町大新田', '07', '07368', '9670603', '福島県', 'フクシマケン', '南会津郡南会津町', 'ミナミアイヅグンミナミアイヅマチ', '大新田', 'オオニタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡南会津町大橋', '07', '07368', '9670604', '福島県', 'フクシマケン', '南会津郡南会津町', 'ミナミアイヅグンミナミアイヅマチ', '大橋', 'オオハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡南会津町東', '07', '07368', '9670605', '福島県', 'フクシマケン', '南会津郡南会津町', 'ミナミアイヅグンミナミアイヅマチ', '東', 'アズマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡南会津町山口', '07', '07368', '9670611', '福島県', 'フクシマケン', '南会津郡南会津町', 'ミナミアイヅグンミナミアイヅマチ', '山口', 'ヤマグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡南会津町鴇巣', '07', '07368', '9670621', '福島県', 'フクシマケン', '南会津郡南会津町', 'ミナミアイヅグンミナミアイヅマチ', '鴇巣', 'トウノス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡南会津町宮床', '07', '07368', '9670622', '福島県', 'フクシマケン', '南会津郡南会津町', 'ミナミアイヅグンミナミアイヅマチ', '宮床', 'ミヤトコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡南会津町界', '07', '07368', '9670631', '福島県', 'フクシマケン', '南会津郡南会津町', 'ミナミアイヅグンミナミアイヅマチ', '界', 'サカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡南会津町片貝', '07', '07368', '9670632', '福島県', 'フクシマケン', '南会津郡南会津町', 'ミナミアイヅグンミナミアイヅマチ', '片貝', 'カタカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡南会津町富山', '07', '07368', '9670633', '福島県', 'フクシマケン', '南会津郡南会津町', 'ミナミアイヅグンミナミアイヅマチ', '富山', 'トミヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡南会津町下山', '07', '07368', '9670634', '福島県', 'フクシマケン', '南会津郡南会津町', 'ミナミアイヅグンミナミアイヅマチ', '下山', 'シモヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡南会津町和泉田', '07', '07368', '9670641', '福島県', 'フクシマケン', '南会津郡南会津町', 'ミナミアイヅグンミナミアイヅマチ', '和泉田', 'イズミタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡南会津町小野島', '07', '07368', '9670642', '福島県', 'フクシマケン', '南会津郡南会津町', 'ミナミアイヅグンミナミアイヅマチ', '小野島', 'オノシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡金山町', '07', '07445', '9680000', '福島県', 'フクシマケン', '大沼郡金山町', 'オオヌマグンカネヤママチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('138046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡金山町水沼', '07', '07445', '9680001', '福島県', 'フクシマケン', '大沼郡金山町', 'オオヌマグンカネヤママチ', '水沼', 'ミズヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡金山町大栗山', '07', '07445', '9680002', '福島県', 'フクシマケン', '大沼郡金山町', 'オオヌマグンカネヤママチ', '大栗山', 'オオクリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡金山町沼沢', '07', '07445', '9680003', '福島県', 'フクシマケン', '大沼郡金山町', 'オオヌマグンカネヤママチ', '沼沢', 'ヌマザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡金山町太郎布', '07', '07445', '9680004', '福島県', 'フクシマケン', '大沼郡金山町', 'オオヌマグンカネヤママチ', '太郎布', 'タロウブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡金山町大志', '07', '07445', '9680005', '福島県', 'フクシマケン', '大沼郡金山町', 'オオヌマグンカネヤママチ', '大志', 'オオシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡金山町中川', '07', '07445', '9680006', '福島県', 'フクシマケン', '大沼郡金山町', 'オオヌマグンカネヤママチ', '中川', 'ナカガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡金山町川口', '07', '07445', '9680011', '福島県', 'フクシマケン', '大沼郡金山町', 'オオヌマグンカネヤママチ', '川口', 'カワグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡金山町小栗山', '07', '07445', '9680012', '福島県', 'フクシマケン', '大沼郡金山町', 'オオヌマグンカネヤママチ', '小栗山', 'コグリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡金山町八町', '07', '07445', '9680013', '福島県', 'フクシマケン', '大沼郡金山町', 'オオヌマグンカネヤママチ', '八町', 'ハチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡金山町玉梨', '07', '07445', '9680014', '福島県', 'フクシマケン', '大沼郡金山町', 'オオヌマグンカネヤママチ', '玉梨', 'タマナシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡金山町西谷', '07', '07445', '9680015', '福島県', 'フクシマケン', '大沼郡金山町', 'オオヌマグンカネヤママチ', '西谷', 'ニシタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡金山町本名', '07', '07445', '9680016', '福島県', 'フクシマケン', '大沼郡金山町', 'オオヌマグンカネヤママチ', '本名', 'ホンナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡昭和村', '07', '07446', '9680100', '福島県', 'フクシマケン', '大沼郡昭和村', 'オオヌマグンショウワムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('138059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡昭和村松山', '07', '07446', '9680101', '福島県', 'フクシマケン', '大沼郡昭和村', 'オオヌマグンショウワムラ', '松山', 'マツヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡昭和村野尻', '07', '07446', '9680102', '福島県', 'フクシマケン', '大沼郡昭和村', 'オオヌマグンショウワムラ', '野尻', 'ノジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡昭和村下中津川', '07', '07446', '9680103', '福島県', 'フクシマケン', '大沼郡昭和村', 'オオヌマグンショウワムラ', '下中津川', 'シモナカツカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡昭和村小中津川', '07', '07446', '9680104', '福島県', 'フクシマケン', '大沼郡昭和村', 'オオヌマグンショウワムラ', '小中津川', 'コナカツカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡昭和村小野川', '07', '07446', '9680211', '福島県', 'フクシマケン', '大沼郡昭和村', 'オオヌマグンショウワムラ', '小野川', 'オノガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡昭和村喰丸', '07', '07446', '9680212', '福島県', 'フクシマケン', '大沼郡昭和村', 'オオヌマグンショウワムラ', '喰丸', 'クイマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡昭和村両原', '07', '07446', '9680213', '福島県', 'フクシマケン', '大沼郡昭和村', 'オオヌマグンショウワムラ', '両原', 'リョウハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡昭和村大芦', '07', '07446', '9680214', '福島県', 'フクシマケン', '大沼郡昭和村', 'オオヌマグンショウワムラ', '大芦', 'オオアシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡昭和村佐倉', '07', '07446', '9680215', '福島県', 'フクシマケン', '大沼郡昭和村', 'オオヌマグンショウワムラ', '佐倉', 'サグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡金山町越川', '07', '07445', '9680321', '福島県', 'フクシマケン', '大沼郡金山町', 'オオヌマグンカネヤママチ', '越川', 'コスガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡金山町横田', '07', '07445', '9680322', '福島県', 'フクシマケン', '大沼郡金山町', 'オオヌマグンカネヤママチ', '横田', 'ヨコタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡金山町山入', '07', '07445', '9680323', '福島県', 'フクシマケン', '大沼郡金山町', 'オオヌマグンカネヤママチ', '山入', 'ヤマイリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡金山町田沢', '07', '07445', '9680324', '福島県', 'フクシマケン', '大沼郡金山町', 'オオヌマグンカネヤママチ', '田沢', 'タザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡金山町滝沢', '07', '07445', '9680325', '福島県', 'フクシマケン', '大沼郡金山町', 'オオヌマグンカネヤママチ', '滝沢', 'タキザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡金山町大塩', '07', '07445', '9680326', '福島県', 'フクシマケン', '大沼郡金山町', 'オオヌマグンカネヤママチ', '大塩', 'オオシオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡只見町', '07', '07367', '9680400', '福島県', 'フクシマケン', '南会津郡只見町', 'ミナミアイヅグンタダミマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('138075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡只見町塩沢', '07', '07367', '9680411', '福島県', 'フクシマケン', '南会津郡只見町', 'ミナミアイヅグンタダミマチ', '塩沢', 'シオザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡只見町十島', '07', '07367', '9680412', '福島県', 'フクシマケン', '南会津郡只見町', 'ミナミアイヅグンタダミマチ', '十島', 'ジュウジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡只見町寄岩', '07', '07367', '9680413', '福島県', 'フクシマケン', '南会津郡只見町', 'ミナミアイヅグンタダミマチ', '寄岩', 'ヨリイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡只見町蒲生', '07', '07367', '9680414', '福島県', 'フクシマケン', '南会津郡只見町', 'ミナミアイヅグンタダミマチ', '蒲生', 'ガモウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡只見町叶津', '07', '07367', '9680415', '福島県', 'フクシマケン', '南会津郡只見町', 'ミナミアイヅグンタダミマチ', '叶津', 'カノウヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡只見町只見', '07', '07367', '9680421', '福島県', 'フクシマケン', '南会津郡只見町', 'ミナミアイヅグンタダミマチ', '只見', 'タダミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡只見町石伏', '07', '07367', '9680422', '福島県', 'フクシマケン', '南会津郡只見町', 'ミナミアイヅグンタダミマチ', '石伏', 'イシブシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡只見町田子倉', '07', '07367', '9680423', '福島県', 'フクシマケン', '南会津郡只見町', 'ミナミアイヅグンタダミマチ', '田子倉', 'タゴクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡只見町楢戸', '07', '07367', '9680431', '福島県', 'フクシマケン', '南会津郡只見町', 'ミナミアイヅグンタダミマチ', '楢戸', 'ナラト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡只見町黒沢', '07', '07367', '9680432', '福島県', 'フクシマケン', '南会津郡只見町', 'ミナミアイヅグンタダミマチ', '黒沢', 'クロサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡只見町福井', '07', '07367', '9680433', '福島県', 'フクシマケン', '南会津郡只見町', 'ミナミアイヅグンタダミマチ', '福井', 'フクイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡只見町小川', '07', '07367', '9680434', '福島県', 'フクシマケン', '南会津郡只見町', 'ミナミアイヅグンタダミマチ', '小川', 'オガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡只見町黒谷', '07', '07367', '9680441', '福島県', 'フクシマケン', '南会津郡只見町', 'ミナミアイヅグンタダミマチ', '黒谷', 'クロタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡只見町長浜', '07', '07367', '9680442', '福島県', 'フクシマケン', '南会津郡只見町', 'ミナミアイヅグンタダミマチ', '長浜', 'ナガハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡只見町荒島', '07', '07367', '9680443', '福島県', 'フクシマケン', '南会津郡只見町', 'ミナミアイヅグンタダミマチ', '荒島', 'アラシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡只見町熊倉', '07', '07367', '9680444', '福島県', 'フクシマケン', '南会津郡只見町', 'ミナミアイヅグンタダミマチ', '熊倉', 'クマグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡只見町亀岡', '07', '07367', '9680445', '福島県', 'フクシマケン', '南会津郡只見町', 'ミナミアイヅグンタダミマチ', '亀岡', 'カメオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡只見町小林', '07', '07367', '9680601', '福島県', 'フクシマケン', '南会津郡只見町', 'ミナミアイヅグンタダミマチ', '小林', 'コバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡只見町大倉', '07', '07367', '9680602', '福島県', 'フクシマケン', '南会津郡只見町', 'ミナミアイヅグンタダミマチ', '大倉', 'オオクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡只見町梁取', '07', '07367', '9680603', '福島県', 'フクシマケン', '南会津郡只見町', 'ミナミアイヅグンタダミマチ', '梁取', 'ヤナトリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡只見町塩ノ岐', '07', '07367', '9680604', '福島県', 'フクシマケン', '南会津郡只見町', 'ミナミアイヅグンタダミマチ', '塩ノ岐', 'シオノマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡只見町二軒在家', '07', '07367', '9680605', '福島県', 'フクシマケン', '南会津郡只見町', 'ミナミアイヅグンタダミマチ', '二軒在家', 'ニケンザイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡只見町坂田', '07', '07367', '9680606', '福島県', 'フクシマケン', '南会津郡只見町', 'ミナミアイヅグンタダミマチ', '坂田', 'サカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡只見町布沢', '07', '07367', '9680607', '福島県', 'フクシマケン', '南会津郡只見町', 'ミナミアイヅグンタダミマチ', '布沢', 'フザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡泉崎村', '07', '07464', '9690100', '福島県', 'フクシマケン', '西白河郡泉崎村', 'ニシシラカワグンイズミザキムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('138112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡泉崎村泉崎', '07', '07464', '9690101', '福島県', 'フクシマケン', '西白河郡泉崎村', 'ニシシラカワグンイズミザキムラ', '泉崎', 'イズミザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡泉崎村関和久', '07', '07464', '9690102', '福島県', 'フクシマケン', '西白河郡泉崎村', 'ニシシラカワグンイズミザキムラ', '関和久', 'セキワグ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡泉崎村北平山', '07', '07464', '9690103', '福島県', 'フクシマケン', '西白河郡泉崎村', 'ニシシラカワグンイズミザキムラ', '北平山', 'キタヒラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡泉崎村太田川', '07', '07464', '9690104', '福島県', 'フクシマケン', '西白河郡泉崎村', 'ニシシラカワグンイズミザキムラ', '太田川', 'オオタガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡泉崎村踏瀬', '07', '07464', '9690105', '福島県', 'フクシマケン', '西白河郡泉崎村', 'ニシシラカワグンイズミザキムラ', '踏瀬', 'フマセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡泉崎村関和久八雲神社', '07', '07464', '9690106', '福島県', 'フクシマケン', '西白河郡泉崎村', 'ニシシラカワグンイズミザキムラ', '関和久', 'セキワグ', null, null, '八雲神社', 'ヤグモジンジャ');
INSERT INTO `ms_addresses` VALUES ('138119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡矢吹町', '07', '07466', '9690200', '福島県', 'フクシマケン', '西白河郡矢吹町', 'ニシシラカワグンヤブキマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('138120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡矢吹町大町', '07', '07466', '9690201', '福島県', 'フクシマケン', '西白河郡矢吹町', 'ニシシラカワグンヤブキマチ', '大町', 'オオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡矢吹町新町', '07', '07466', '9690202', '福島県', 'フクシマケン', '西白河郡矢吹町', 'ニシシラカワグンヤブキマチ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡矢吹町北浦', '07', '07466', '9690203', '福島県', 'フクシマケン', '西白河郡矢吹町', 'ニシシラカワグンヤブキマチ', '北浦', 'キタウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡矢吹町関山', '07', '07466', '9690204', '福島県', 'フクシマケン', '西白河郡矢吹町', 'ニシシラカワグンヤブキマチ', '関山', 'セキヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡矢吹町五本松', '07', '07466', '9690205', '福島県', 'フクシマケン', '西白河郡矢吹町', 'ニシシラカワグンヤブキマチ', '五本松', 'ゴホンマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡矢吹町赤沢', '07', '07466', '9690206', '福島県', 'フクシマケン', '西白河郡矢吹町', 'ニシシラカワグンヤブキマチ', '赤沢', 'アカサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡矢吹町北町', '07', '07466', '9690211', '福島県', 'フクシマケン', '西白河郡矢吹町', 'ニシシラカワグンヤブキマチ', '北町', 'キタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡矢吹町善郷内', '07', '07466', '9690212', '福島県', 'フクシマケン', '西白河郡矢吹町', 'ニシシラカワグンヤブキマチ', '善郷内', 'ゼンゴウウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡矢吹町本町', '07', '07466', '9690213', '福島県', 'フクシマケン', '西白河郡矢吹町', 'ニシシラカワグンヤブキマチ', '本町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡矢吹町中町', '07', '07466', '9690221', '福島県', 'フクシマケン', '西白河郡矢吹町', 'ニシシラカワグンヤブキマチ', '中町', 'ナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡矢吹町八幡町', '07', '07466', '9690222', '福島県', 'フクシマケン', '西白河郡矢吹町', 'ニシシラカワグンヤブキマチ', '八幡町', 'ハチマンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡矢吹町文京町', '07', '07466', '9690223', '福島県', 'フクシマケン', '西白河郡矢吹町', 'ニシシラカワグンヤブキマチ', '文京町', 'ブンキョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡矢吹町大久保', '07', '07466', '9690224', '福島県', 'フクシマケン', '西白河郡矢吹町', 'ニシシラカワグンヤブキマチ', '大久保', 'オオクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡矢吹町東長峰', '07', '07466', '9690225', '福島県', 'フクシマケン', '西白河郡矢吹町', 'ニシシラカワグンヤブキマチ', '東長峰', 'ヒガシナガミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡矢吹町西長峰', '07', '07466', '9690226', '福島県', 'フクシマケン', '西白河郡矢吹町', 'ニシシラカワグンヤブキマチ', '西長峰', 'ニシナガミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡矢吹町田町', '07', '07466', '9690227', '福島県', 'フクシマケン', '西白河郡矢吹町', 'ニシシラカワグンヤブキマチ', '田町', 'タマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡矢吹町中丸', '07', '07466', '9690231', '福島県', 'フクシマケン', '西白河郡矢吹町', 'ニシシラカワグンヤブキマチ', '中丸', 'ナカマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡矢吹町本城舘', '07', '07466', '9690232', '福島県', 'フクシマケン', '西白河郡矢吹町', 'ニシシラカワグンヤブキマチ', '本城舘', 'ホンジョウダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡矢吹町花の里', '07', '07466', '9690233', '福島県', 'フクシマケン', '西白河郡矢吹町', 'ニシシラカワグンヤブキマチ', '花の里', 'ハナノサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡矢吹町前田', '07', '07466', '9690234', '福島県', 'フクシマケン', '西白河郡矢吹町', 'ニシシラカワグンヤブキマチ', '前田', 'マエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡矢吹町丸の内', '07', '07466', '9690235', '福島県', 'フクシマケン', '西白河郡矢吹町', 'ニシシラカワグンヤブキマチ', '丸の内', 'マルノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡矢吹町一本木', '07', '07466', '9690236', '福島県', 'フクシマケン', '西白河郡矢吹町', 'ニシシラカワグンヤブキマチ', '一本木', 'イッポンギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡矢吹町中畑新田', '07', '07466', '9690236', '福島県', 'フクシマケン', '西白河郡矢吹町', 'ニシシラカワグンヤブキマチ', '中畑新田', 'ナカハタシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡矢吹町矢吹', '07', '07466', '9690236', '福島県', 'フクシマケン', '西白河郡矢吹町', 'ニシシラカワグンヤブキマチ', '矢吹', 'ヤブキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡矢吹町牡丹平', '07', '07466', '9690237', '福島県', 'フクシマケン', '西白河郡矢吹町', 'ニシシラカワグンヤブキマチ', '牡丹平', 'ボタンダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡矢吹町大池', '07', '07466', '9690238', '福島県', 'フクシマケン', '西白河郡矢吹町', 'ニシシラカワグンヤブキマチ', '大池', 'オオイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡矢吹町陣ケ岡', '07', '07466', '9690241', '福島県', 'フクシマケン', '西白河郡矢吹町', 'ニシシラカワグンヤブキマチ', '陣ケ岡', 'ジンガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡矢吹町天開', '07', '07466', '9690241', '福島県', 'フクシマケン', '西白河郡矢吹町', 'ニシシラカワグンヤブキマチ', '天開', 'テンカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡矢吹町三城目', '07', '07466', '9690242', '福島県', 'フクシマケン', '西白河郡矢吹町', 'ニシシラカワグンヤブキマチ', '三城目', 'サンジョウメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡矢吹町中沖', '07', '07466', '9690243', '福島県', 'フクシマケン', '西白河郡矢吹町', 'ニシシラカワグンヤブキマチ', '中沖', 'ナカオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡矢吹町東川原', '07', '07466', '9690243', '福島県', 'フクシマケン', '西白河郡矢吹町', 'ニシシラカワグンヤブキマチ', '東川原', 'ヒガシカワハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡矢吹町奉行塚', '07', '07466', '9690244', '福島県', 'フクシマケン', '西白河郡矢吹町', 'ニシシラカワグンヤブキマチ', '奉行塚', 'ブギョウヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡矢吹町谷中', '07', '07466', '9690244', '福島県', 'フクシマケン', '西白河郡矢吹町', 'ニシシラカワグンヤブキマチ', '谷中', 'ヤナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡矢吹町白山', '07', '07466', '9690245', '福島県', 'フクシマケン', '西白河郡矢吹町', 'ニシシラカワグンヤブキマチ', '白山', 'ハクサン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡矢吹町上宮崎', '07', '07466', '9690246', '福島県', 'フクシマケン', '西白河郡矢吹町', 'ニシシラカワグンヤブキマチ', '上宮崎', 'カミミヤザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡矢吹町下宮崎', '07', '07466', '9690246', '福島県', 'フクシマケン', '西白河郡矢吹町', 'ニシシラカワグンヤブキマチ', '下宮崎', 'シモミヤザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡矢吹町諏訪の前', '07', '07466', '9690247', '福島県', 'フクシマケン', '西白河郡矢吹町', 'ニシシラカワグンヤブキマチ', '諏訪の前', 'スワノマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡矢吹町寺の前', '07', '07466', '9690247', '福島県', 'フクシマケン', '西白河郡矢吹町', 'ニシシラカワグンヤブキマチ', '寺の前', 'テラノマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡矢吹町東郷', '07', '07466', '9690248', '福島県', 'フクシマケン', '西白河郡矢吹町', 'ニシシラカワグンヤブキマチ', '東郷', 'トウゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡矢吹町神田西', '07', '07466', '9690251', '福島県', 'フクシマケン', '西白河郡矢吹町', 'ニシシラカワグンヤブキマチ', '神田西', 'カンタニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡矢吹町神田東', '07', '07466', '9690251', '福島県', 'フクシマケン', '西白河郡矢吹町', 'ニシシラカワグンヤブキマチ', '神田東', 'カンタヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡矢吹町神田南', '07', '07466', '9690251', '福島県', 'フクシマケン', '西白河郡矢吹町', 'ニシシラカワグンヤブキマチ', '神田南', 'カンタミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡矢吹町神の内', '07', '07466', '9690252', '福島県', 'フクシマケン', '西白河郡矢吹町', 'ニシシラカワグンヤブキマチ', '神の内', 'カミノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡矢吹町堤', '07', '07466', '9690252', '福島県', 'フクシマケン', '西白河郡矢吹町', 'ニシシラカワグンヤブキマチ', '堤', 'ツツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡矢吹町中野目西', '07', '07466', '9690252', '福島県', 'フクシマケン', '西白河郡矢吹町', 'ニシシラカワグンヤブキマチ', '中野目西', 'ナカノメニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡矢吹町中野目東', '07', '07466', '9690252', '福島県', 'フクシマケン', '西白河郡矢吹町', 'ニシシラカワグンヤブキマチ', '中野目東', 'ナカノメヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡矢吹町東堤', '07', '07466', '9690252', '福島県', 'フクシマケン', '西白河郡矢吹町', 'ニシシラカワグンヤブキマチ', '東堤', 'ヒガシツツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡矢吹町明新上', '07', '07466', '9690253', '福島県', 'フクシマケン', '西白河郡矢吹町', 'ニシシラカワグンヤブキマチ', '明新上', 'ミョウシンカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡矢吹町明新下', '07', '07466', '9690253', '福島県', 'フクシマケン', '西白河郡矢吹町', 'ニシシラカワグンヤブキマチ', '明新下', 'ミョウシンシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡矢吹町明新中', '07', '07466', '9690253', '福島県', 'フクシマケン', '西白河郡矢吹町', 'ニシシラカワグンヤブキマチ', '明新中', 'ミョウシンナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡矢吹町明新西', '07', '07466', '9690253', '福島県', 'フクシマケン', '西白河郡矢吹町', 'ニシシラカワグンヤブキマチ', '明新西', 'ミョウシンニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡矢吹町明新原', '07', '07466', '9690253', '福島県', 'フクシマケン', '西白河郡矢吹町', 'ニシシラカワグンヤブキマチ', '明新原', 'ミョウシンハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡矢吹町明新東', '07', '07466', '9690253', '福島県', 'フクシマケン', '西白河郡矢吹町', 'ニシシラカワグンヤブキマチ', '明新東', 'ミョウシンヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡矢吹町平鉢', '07', '07466', '9690254', '福島県', 'フクシマケン', '西白河郡矢吹町', 'ニシシラカワグンヤブキマチ', '平鉢', 'ヘイバチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡矢吹町寺内', '07', '07466', '9690255', '福島県', 'フクシマケン', '西白河郡矢吹町', 'ニシシラカワグンヤブキマチ', '寺内', 'テラウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡矢吹町寺内西', '07', '07466', '9690255', '福島県', 'フクシマケン', '西白河郡矢吹町', 'ニシシラカワグンヤブキマチ', '寺内西', 'テラウチニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡矢吹町寺内東', '07', '07466', '9690255', '福島県', 'フクシマケン', '西白河郡矢吹町', 'ニシシラカワグンヤブキマチ', '寺内東', 'テラウチヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡矢吹町寺内南', '07', '07466', '9690255', '福島県', 'フクシマケン', '西白河郡矢吹町', 'ニシシラカワグンヤブキマチ', '寺内南', 'テラウチミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡矢吹町鍋内', '07', '07466', '9690256', '福島県', 'フクシマケン', '西白河郡矢吹町', 'ニシシラカワグンヤブキマチ', '鍋内', 'ナベウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡矢吹町上の前', '07', '07466', '9690257', '福島県', 'フクシマケン', '西白河郡矢吹町', 'ニシシラカワグンヤブキマチ', '上の前', 'カミノマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡矢吹町住吉', '07', '07466', '9690257', '福島県', 'フクシマケン', '西白河郡矢吹町', 'ニシシラカワグンヤブキマチ', '住吉', 'スミヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡矢吹町前久保', '07', '07466', '9690257', '福島県', 'フクシマケン', '西白河郡矢吹町', 'ニシシラカワグンヤブキマチ', '前久保', 'マエクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡矢吹町沢尻', '07', '07466', '9690258', '福島県', 'フクシマケン', '西白河郡矢吹町', 'ニシシラカワグンヤブキマチ', '沢尻', 'サワジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡矢吹町弥栄', '07', '07466', '9690261', '福島県', 'フクシマケン', '西白河郡矢吹町', 'ニシシラカワグンヤブキマチ', '弥栄', 'ヤサカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡矢吹町松房', '07', '07466', '9690262', '福島県', 'フクシマケン', '西白河郡矢吹町', 'ニシシラカワグンヤブキマチ', '松房', 'マツボウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡矢吹町根宿', '07', '07466', '9690263', '福島県', 'フクシマケン', '西白河郡矢吹町', 'ニシシラカワグンヤブキマチ', '根宿', 'ネジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡矢吹町中畑', '07', '07466', '9690264', '福島県', 'フクシマケン', '西白河郡矢吹町', 'ニシシラカワグンヤブキマチ', '中畑', 'ナカハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡矢吹町中畑南', '07', '07466', '9690265', '福島県', 'フクシマケン', '西白河郡矢吹町', 'ニシシラカワグンヤブキマチ', '中畑南', 'ナカハタミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡矢吹町上敷面', '07', '07466', '9690266', '福島県', 'フクシマケン', '西白河郡矢吹町', 'ニシシラカワグンヤブキマチ', '上敷面', 'ジョウシキメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡矢吹町諏訪清水', '07', '07466', '9690267', '福島県', 'フクシマケン', '西白河郡矢吹町', 'ニシシラカワグンヤブキマチ', '諏訪清水', 'スワシミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡矢吹町松倉', '07', '07466', '9690268', '福島県', 'フクシマケン', '西白河郡矢吹町', 'ニシシラカワグンヤブキマチ', '松倉', 'マツクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡矢吹町小松', '07', '07466', '9690271', '福島県', 'フクシマケン', '西白河郡矢吹町', 'ニシシラカワグンヤブキマチ', '小松', 'コマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡矢吹町曙町', '07', '07466', '9690272', '福島県', 'フクシマケン', '西白河郡矢吹町', 'ニシシラカワグンヤブキマチ', '曙町', 'アケボノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡矢吹町境町', '07', '07466', '9690281', '福島県', 'フクシマケン', '西白河郡矢吹町', 'ニシシラカワグンヤブキマチ', '境町', 'サカイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡矢吹町馬場', '07', '07466', '9690281', '福島県', 'フクシマケン', '西白河郡矢吹町', 'ニシシラカワグンヤブキマチ', '馬場', 'ババ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡矢吹町本郷町', '07', '07466', '9690282', '福島県', 'フクシマケン', '西白河郡矢吹町', 'ニシシラカワグンヤブキマチ', '本郷町', 'ホンゴウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡矢吹町南町', '07', '07466', '9690283', '福島県', 'フクシマケン', '西白河郡矢吹町', 'ニシシラカワグンヤブキマチ', '南町', 'ミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡矢吹町滝八幡', '07', '07466', '9690284', '福島県', 'フクシマケン', '西白河郡矢吹町', 'ニシシラカワグンヤブキマチ', '滝八幡', 'タキハチマン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡矢吹町舘沢', '07', '07466', '9690284', '福島県', 'フクシマケン', '西白河郡矢吹町', 'ニシシラカワグンヤブキマチ', '舘沢', 'タテサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡矢吹町花咲', '07', '07466', '9690285', '福島県', 'フクシマケン', '西白河郡矢吹町', 'ニシシラカワグンヤブキマチ', '花咲', 'ハナサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡矢吹町大和内', '07', '07466', '9690286', '福島県', 'フクシマケン', '西白河郡矢吹町', 'ニシシラカワグンヤブキマチ', '大和内', 'ヤマトウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡矢吹町井戸尻', '07', '07466', '9690287', '福島県', 'フクシマケン', '西白河郡矢吹町', 'ニシシラカワグンヤブキマチ', '井戸尻', 'イドジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡矢吹町川原', '07', '07466', '9690287', '福島県', 'フクシマケン', '西白河郡矢吹町', 'ニシシラカワグンヤブキマチ', '川原', 'カワハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡矢吹町堰の上', '07', '07466', '9690287', '福島県', 'フクシマケン', '西白河郡矢吹町', 'ニシシラカワグンヤブキマチ', '堰の上', 'セキノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡矢吹町子ハ清水', '07', '07466', '9690288', '福島県', 'フクシマケン', '西白河郡矢吹町', 'ニシシラカワグンヤブキマチ', '子ハ清水', 'コハシミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡矢吹町田内', '07', '07466', '9690288', '福島県', 'フクシマケン', '西白河郡矢吹町', 'ニシシラカワグンヤブキマチ', '田内', 'タウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県西白河郡矢吹町東の内', '07', '07466', '9690288', '福島県', 'フクシマケン', '西白河郡矢吹町', 'ニシシラカワグンヤブキマチ', '東の内', 'ヒガシノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市大信上新城', '07', '07205', '9690301', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '大信上新城', 'タイシンカミシンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市大信隈戸', '07', '07205', '9690302', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '大信隈戸', 'タイシンクマド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市大信下小屋', '07', '07205', '9690303', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '大信下小屋', 'タイシンシモコヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市大信下新城', '07', '07205', '9690304', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '大信下新城', 'タイシンシモシンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市大信田園町府', '07', '07205', '9690305', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '大信田園町府', 'タイシンデンエンチョウフ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市大信豊地', '07', '07205', '9690306', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '大信豊地', 'タイシントヨチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市大信中新城', '07', '07205', '9690307', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '大信中新城', 'タイシンナカシンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市大信増見', '07', '07205', '9690308', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '大信増見', 'タイシンマスミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県白河市大信町屋', '07', '07205', '9690309', '福島県', 'フクシマケン', '白河市', 'シラカワシ', '大信町屋', 'タイシンマチヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県岩瀬郡鏡石町', '07', '07342', '9690400', '福島県', 'フクシマケン', '岩瀬郡鏡石町', 'イワセグンカガミイシマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('138220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県岩瀬郡鏡石町池ノ原', '07', '07342', '9690401', '福島県', 'フクシマケン', '岩瀬郡鏡石町', 'イワセグンカガミイシマチ', '池ノ原', 'イケノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県岩瀬郡鏡石町大池', '07', '07342', '9690401', '福島県', 'フクシマケン', '岩瀬郡鏡石町', 'イワセグンカガミイシマチ', '大池', 'オオイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県岩瀬郡鏡石町岡ノ内', '07', '07342', '9690401', '福島県', 'フクシマケン', '岩瀬郡鏡石町', 'イワセグンカガミイシマチ', '岡ノ内', 'オカノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県岩瀬郡鏡石町鏡田かげ沼町', '07', '07342', '9690401', '福島県', 'フクシマケン', '岩瀬郡鏡石町', 'イワセグンカガミイシマチ', '鏡田かげ沼町', 'カガミダカゲヌママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県岩瀬郡鏡石町鏡沼', '07', '07342', '9690401', '福島県', 'フクシマケン', '岩瀬郡鏡石町', 'イワセグンカガミイシマチ', '鏡沼', 'カガミヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県岩瀬郡鏡石町鹿島', '07', '07342', '9690401', '福島県', 'フクシマケン', '岩瀬郡鏡石町', 'イワセグンカガミイシマチ', '鹿島', 'カシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県岩瀬郡鏡石町蒲之沢町', '07', '07342', '9690401', '福島県', 'フクシマケン', '岩瀬郡鏡石町', 'イワセグンカガミイシマチ', '蒲之沢町', 'カバノサワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県岩瀬郡鏡石町川崎町', '07', '07342', '9690401', '福島県', 'フクシマケン', '岩瀬郡鏡石町', 'イワセグンカガミイシマチ', '川崎町', 'カワサキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県岩瀬郡鏡石町五斗蒔町', '07', '07342', '9690401', '福島県', 'フクシマケン', '岩瀬郡鏡石町', 'イワセグンカガミイシマチ', '五斗蒔町', 'ゴトマキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県岩瀬郡鏡石町境', '07', '07342', '9690401', '福島県', 'フクシマケン', '岩瀬郡鏡石町', 'イワセグンカガミイシマチ', '境', 'サカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県岩瀬郡鏡石町桜町', '07', '07342', '9690401', '福島県', 'フクシマケン', '岩瀬郡鏡石町', 'イワセグンカガミイシマチ', '桜町', 'サクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県岩瀬郡鏡石町高久田', '07', '07342', '9690401', '福島県', 'フクシマケン', '岩瀬郡鏡石町', 'イワセグンカガミイシマチ', '高久田', 'タカクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県岩瀬郡鏡石町豊田', '07', '07342', '9690401', '福島県', 'フクシマケン', '岩瀬郡鏡石町', 'イワセグンカガミイシマチ', '豊田', 'トヨダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県岩瀬郡鏡石町仁井田', '07', '07342', '9690401', '福島県', 'フクシマケン', '岩瀬郡鏡石町', 'イワセグンカガミイシマチ', '仁井田', 'ニイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県岩瀬郡鏡石町東鹿島', '07', '07342', '9690401', '福島県', 'フクシマケン', '岩瀬郡鏡石町', 'イワセグンカガミイシマチ', '東鹿島', 'ヒガシカシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県岩瀬郡鏡石町深内町', '07', '07342', '9690401', '福島県', 'フクシマケン', '岩瀬郡鏡石町', 'イワセグンカガミイシマチ', '深内町', 'フコウチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県岩瀬郡鏡石町不時沼', '07', '07342', '9690401', '福島県', 'フクシマケン', '岩瀬郡鏡石町', 'イワセグンカガミイシマチ', '不時沼', 'フジヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県岩瀬郡鏡石町前山', '07', '07342', '9690401', '福島県', 'フクシマケン', '岩瀬郡鏡石町', 'イワセグンカガミイシマチ', '前山', 'マエヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県岩瀬郡鏡石町南高久田', '07', '07342', '9690401', '福島県', 'フクシマケン', '岩瀬郡鏡石町', 'イワセグンカガミイシマチ', '南高久田', 'ミナミタカクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県岩瀬郡鏡石町本町', '07', '07342', '9690401', '福島県', 'フクシマケン', '岩瀬郡鏡石町', 'イワセグンカガミイシマチ', '本町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県岩瀬郡鏡石町池の台', '07', '07342', '9690402', '福島県', 'フクシマケン', '岩瀬郡鏡石町', 'イワセグンカガミイシマチ', '池の台', 'イケノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県岩瀬郡鏡石町大宮', '07', '07342', '9690402', '福島県', 'フクシマケン', '岩瀬郡鏡石町', 'イワセグンカガミイシマチ', '大宮', 'オオミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県岩瀬郡鏡石町河原', '07', '07342', '9690402', '福島県', 'フクシマケン', '岩瀬郡鏡石町', 'イワセグンカガミイシマチ', '河原', 'カワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県岩瀬郡鏡石町北町', '07', '07342', '9690402', '福島県', 'フクシマケン', '岩瀬郡鏡石町', 'イワセグンカガミイシマチ', '北町', 'キタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県岩瀬郡鏡石町新町', '07', '07342', '9690402', '福島県', 'フクシマケン', '岩瀬郡鏡石町', 'イワセグンカガミイシマチ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県岩瀬郡鏡石町諏訪町', '07', '07342', '9690402', '福島県', 'フクシマケン', '岩瀬郡鏡石町', 'イワセグンカガミイシマチ', '諏訪町', 'スワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県岩瀬郡鏡石町成田', '07', '07342', '9690402', '福島県', 'フクシマケン', '岩瀬郡鏡石町', 'イワセグンカガミイシマチ', '成田', 'ナリタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県岩瀬郡鏡石町成田原町', '07', '07342', '9690402', '福島県', 'フクシマケン', '岩瀬郡鏡石町', 'イワセグンカガミイシマチ', '成田原町', 'ナリタハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県岩瀬郡鏡石町成田東', '07', '07342', '9690402', '福島県', 'フクシマケン', '岩瀬郡鏡石町', 'イワセグンカガミイシマチ', '成田東', 'ナリタヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県岩瀬郡鏡石町東河原', '07', '07342', '9690402', '福島県', 'フクシマケン', '岩瀬郡鏡石町', 'イワセグンカガミイシマチ', '東河原', 'ヒガシカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県岩瀬郡鏡石町借宿', '07', '07342', '9690403', '福島県', 'フクシマケン', '岩瀬郡鏡石町', 'イワセグンカガミイシマチ', '借宿', 'カリヤド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県岩瀬郡鏡石町久来石', '07', '07342', '9690403', '福島県', 'フクシマケン', '岩瀬郡鏡石町', 'イワセグンカガミイシマチ', '久来石', 'キュウライシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県岩瀬郡鏡石町久来石南', '07', '07342', '9690403', '福島県', 'フクシマケン', '岩瀬郡鏡石町', 'イワセグンカガミイシマチ', '久来石南', 'キュウライシミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県岩瀬郡鏡石町小栗山', '07', '07342', '9690403', '福島県', 'フクシマケン', '岩瀬郡鏡石町', 'イワセグンカガミイシマチ', '小栗山', 'コグリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県岩瀬郡鏡石町桜岡', '07', '07342', '9690403', '福島県', 'フクシマケン', '岩瀬郡鏡石町', 'イワセグンカガミイシマチ', '桜岡', 'サクラオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県岩瀬郡鏡石町城ノ内', '07', '07342', '9690403', '福島県', 'フクシマケン', '岩瀬郡鏡石町', 'イワセグンカガミイシマチ', '城ノ内', 'ジョウノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県岩瀬郡鏡石町堂前', '07', '07342', '9690403', '福島県', 'フクシマケン', '岩瀬郡鏡石町', 'イワセグンカガミイシマチ', '堂前', 'ドウマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県岩瀬郡鏡石町旭町', '07', '07342', '9690404', '福島県', 'フクシマケン', '岩瀬郡鏡石町', 'イワセグンカガミイシマチ', '旭町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県岩瀬郡鏡石町大山', '07', '07342', '9690404', '福島県', 'フクシマケン', '岩瀬郡鏡石町', 'イワセグンカガミイシマチ', '大山', 'オオヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県岩瀬郡鏡石町岡の台', '07', '07342', '9690404', '福島県', 'フクシマケン', '岩瀬郡鏡石町', 'イワセグンカガミイシマチ', '岡の台', 'オカノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県岩瀬郡鏡石町笠石', '07', '07342', '9690404', '福島県', 'フクシマケン', '岩瀬郡鏡石町', 'イワセグンカガミイシマチ', '笠石', 'カサイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県岩瀬郡鏡石町笠石原町', '07', '07342', '9690404', '福島県', 'フクシマケン', '岩瀬郡鏡石町', 'イワセグンカガミイシマチ', '笠石原町', 'カサイシハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県岩瀬郡鏡石町中央', '07', '07342', '9690404', '福島県', 'フクシマケン', '岩瀬郡鏡石町', 'イワセグンカガミイシマチ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県岩瀬郡鏡石町豊郷', '07', '07342', '9690404', '福島県', 'フクシマケン', '岩瀬郡鏡石町', 'イワセグンカガミイシマチ', '豊郷', 'トヨサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県岩瀬郡鏡石町豊郷中', '07', '07342', '9690404', '福島県', 'フクシマケン', '岩瀬郡鏡石町', 'イワセグンカガミイシマチ', '豊郷中', 'トヨサトナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県岩瀬郡鏡石町中町', '07', '07342', '9690404', '福島県', 'フクシマケン', '岩瀬郡鏡石町', 'イワセグンカガミイシマチ', '中町', 'ナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県岩瀬郡鏡石町羽鳥', '07', '07342', '9690404', '福島県', 'フクシマケン', '岩瀬郡鏡石町', 'イワセグンカガミイシマチ', '羽鳥', 'ハトリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県岩瀬郡鏡石町東町', '07', '07342', '9690404', '福島県', 'フクシマケン', '岩瀬郡鏡石町', 'イワセグンカガミイシマチ', '東町', 'ヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県岩瀬郡鏡石町堀米', '07', '07342', '9690404', '福島県', 'フクシマケン', '岩瀬郡鏡石町', 'イワセグンカガミイシマチ', '堀米', 'ホリゴメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県岩瀬郡鏡石町緑町', '07', '07342', '9690404', '福島県', 'フクシマケン', '岩瀬郡鏡石町', 'イワセグンカガミイシマチ', '緑町', 'ミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県岩瀬郡鏡石町南町', '07', '07342', '9690404', '福島県', 'フクシマケン', '岩瀬郡鏡石町', 'イワセグンカガミイシマチ', '南町', 'ミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県本宮市', '07', '07214', '9691100', '福島県', 'フクシマケン', '本宮市', 'モトミヤシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('138273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県本宮市高木', '07', '07214', '9691101', '福島県', 'フクシマケン', '本宮市', 'モトミヤシ', '高木', 'タカギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県本宮市仁井田', '07', '07214', '9691103', '福島県', 'フクシマケン', '本宮市', 'モトミヤシ', '仁井田', 'ニイタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県本宮市荒井', '07', '07214', '9691104', '福島県', 'フクシマケン', '本宮市', 'モトミヤシ', '荒井', 'アライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県本宮市関下', '07', '07214', '9691105', '福島県', 'フクシマケン', '本宮市', 'モトミヤシ', '関下', 'セキシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県本宮市岩根', '07', '07214', '9691106', '福島県', 'フクシマケン', '本宮市', 'モトミヤシ', '岩根', 'イワネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県本宮市青田', '07', '07214', '9691107', '福島県', 'フクシマケン', '本宮市', 'モトミヤシ', '青田', 'アオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県本宮市本宮堀切', '07', '07214', '9691108', '福島県', 'フクシマケン', '本宮市', 'モトミヤシ', '本宮堀切', 'モトミヤホッキリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県本宮市本宮富ヶ峰', '07', '07214', '9691109', '福島県', 'フクシマケン', '本宮市', 'モトミヤシ', '本宮富ヶ峰', 'モトミヤトミガミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県本宮市本宮作田', '07', '07214', '9691111', '福島県', 'フクシマケン', '本宮市', 'モトミヤシ', '本宮作田', 'モトミヤサクタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県本宮市本宮作田台', '07', '07214', '9691111', '福島県', 'フクシマケン', '本宮市', 'モトミヤシ', '本宮作田台', 'モトミヤサクタダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県本宮市本宮大榎', '07', '07214', '9691112', '福島県', 'フクシマケン', '本宮市', 'モトミヤシ', '本宮大榎', 'モトミヤオオエノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県本宮市本宮坊屋敷', '07', '07214', '9691113', '福島県', 'フクシマケン', '本宮市', 'モトミヤシ', '本宮坊屋敷', 'モトミヤボウヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県本宮市本宮関根', '07', '07214', '9691114', '福島県', 'フクシマケン', '本宮市', 'モトミヤシ', '本宮関根', 'モトミヤセキネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県本宮市本宮立石', '07', '07214', '9691115', '福島県', 'フクシマケン', '本宮市', 'モトミヤシ', '本宮立石', 'モトミヤタテイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県本宮市本宮弁天', '07', '07214', '9691116', '福島県', 'フクシマケン', '本宮市', 'モトミヤシ', '本宮弁天', 'モトミヤベンテン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県本宮市本宮鹿ノ子田', '07', '07214', '9691117', '福島県', 'フクシマケン', '本宮市', 'モトミヤシ', '本宮鹿ノ子田', 'モトミヤカノコダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県本宮市本宮下台', '07', '07214', '9691118', '福島県', 'フクシマケン', '本宮市', 'モトミヤシ', '本宮下台', 'モトミヤシモダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県本宮市本宮柳ノ内', '07', '07214', '9691119', '福島県', 'フクシマケン', '本宮市', 'モトミヤシ', '本宮柳ノ内', 'モトミヤヤナギノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県本宮市本宮舘ノ越', '07', '07214', '9691121', '福島県', 'フクシマケン', '本宮市', 'モトミヤシ', '本宮舘ノ越', 'モトミヤタテノコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県本宮市本宮大町', '07', '07214', '9691122', '福島県', 'フクシマケン', '本宮市', 'モトミヤシ', '本宮大町', 'モトミヤダイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県本宮市本宮東町', '07', '07214', '9691123', '福島県', 'フクシマケン', '本宮市', 'モトミヤシ', '本宮東町', 'モトミヤヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県本宮市本宮東町裏', '07', '07214', '9691123', '福島県', 'フクシマケン', '本宮市', 'モトミヤシ', '本宮東町裏', 'モトミヤヒガシマチウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県本宮市本宮仲町', '07', '07214', '9691124', '福島県', 'フクシマケン', '本宮市', 'モトミヤシ', '本宮仲町', 'モトミヤナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県本宮市本宮荒町', '07', '07214', '9691125', '福島県', 'フクシマケン', '本宮市', 'モトミヤシ', '本宮荒町', 'モトミヤアラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県本宮市本宮馬場', '07', '07214', '9691126', '福島県', 'フクシマケン', '本宮市', 'モトミヤシ', '本宮馬場', 'モトミヤババ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県本宮市本宮鉄砲町', '07', '07214', '9691127', '福島県', 'フクシマケン', '本宮市', 'モトミヤシ', '本宮鉄砲町', 'モトミヤテッポウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県本宮市本宮舘町', '07', '07214', '9691128', '福島県', 'フクシマケン', '本宮市', 'モトミヤシ', '本宮舘町', 'モトミヤタテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県本宮市本宮鍛冶免', '07', '07214', '9691129', '福島県', 'フクシマケン', '本宮市', 'モトミヤシ', '本宮鍛冶免', 'モトミヤカジメン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県本宮市本宮矢来', '07', '07214', '9691129', '福島県', 'フクシマケン', '本宮市', 'モトミヤシ', '本宮矢来', 'モトミヤヤライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県本宮市本宮南町裡', '07', '07214', '9691131', '福島県', 'フクシマケン', '本宮市', 'モトミヤシ', '本宮南町裡', 'モトミヤミナミマチウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県本宮市本宮下町', '07', '07214', '9691132', '福島県', 'フクシマケン', '本宮市', 'モトミヤシ', '本宮下町', 'モトミヤシモマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県本宮市本宮中條', '07', '07214', '9691133', '福島県', 'フクシマケン', '本宮市', 'モトミヤシ', '本宮中條', 'モトミヤナカジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県本宮市本宮上町', '07', '07214', '9691134', '福島県', 'フクシマケン', '本宮市', 'モトミヤシ', '本宮上町', 'モトミヤカミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県本宮市本宮土樋', '07', '07214', '9691135', '福島県', 'フクシマケン', '本宮市', 'モトミヤシ', '本宮土樋', 'モトミヤツチドイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県本宮市本宮蛭田', '07', '07214', '9691135', '福島県', 'フクシマケン', '本宮市', 'モトミヤシ', '本宮蛭田', 'モトミヤヒルタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県本宮市本宮九縄', '07', '07214', '9691136', '福島県', 'フクシマケン', '本宮市', 'モトミヤシ', '本宮九縄', 'モトミヤクナワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県本宮市本宮太郎丸', '07', '07214', '9691137', '福島県', 'フクシマケン', '本宮市', 'モトミヤシ', '本宮太郎丸', 'モトミヤタロウマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県本宮市本宮鳴瀬', '07', '07214', '9691138', '福島県', 'フクシマケン', '本宮市', 'モトミヤシ', '本宮鳴瀬', 'モトミヤナルセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県本宮市本宮石塚', '07', '07214', '9691139', '福島県', 'フクシマケン', '本宮市', 'モトミヤシ', '本宮石塚', 'モトミヤイシヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県本宮市本宮兼谷', '07', '07214', '9691141', '福島県', 'フクシマケン', '本宮市', 'モトミヤシ', '本宮兼谷', 'モトミヤカナヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県本宮市本宮兼谷平', '07', '07214', '9691142', '福島県', 'フクシマケン', '本宮市', 'モトミヤシ', '本宮兼谷平', 'モトミヤカナヤダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県本宮市本宮山田', '07', '07214', '9691143', '福島県', 'フクシマケン', '本宮市', 'モトミヤシ', '本宮山田', 'モトミヤヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県本宮市本宮大森', '07', '07214', '9691144', '福島県', 'フクシマケン', '本宮市', 'モトミヤシ', '本宮大森', 'モトミヤオオモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県本宮市本宮葭ヶ入', '07', '07214', '9691145', '福島県', 'フクシマケン', '本宮市', 'モトミヤシ', '本宮葭ヶ入', 'モトミヤヨシガイリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県本宮市本宮南山神', '07', '07214', '9691146', '福島県', 'フクシマケン', '本宮市', 'モトミヤシ', '本宮南山神', 'モトミヤミナミヤマカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県本宮市本宮花町', '07', '07214', '9691147', '福島県', 'フクシマケン', '本宮市', 'モトミヤシ', '本宮花町', 'モトミヤハナマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県本宮市本宮栄田', '07', '07214', '9691148', '福島県', 'フクシマケン', '本宮市', 'モトミヤシ', '本宮栄田', 'モトミヤサカエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県本宮市本宮万世', '07', '07214', '9691149', '福島県', 'フクシマケン', '本宮市', 'モトミヤシ', '本宮万世', 'モトミヤバンセイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県本宮市本宮千代田', '07', '07214', '9691151', '福島県', 'フクシマケン', '本宮市', 'モトミヤシ', '本宮千代田', 'モトミヤチヨダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県本宮市本宮上千束', '07', '07214', '9691152', '福島県', 'フクシマケン', '本宮市', 'モトミヤシ', '本宮上千束', 'モトミヤカミセンゾク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県本宮市本宮千束', '07', '07214', '9691152', '福島県', 'フクシマケン', '本宮市', 'モトミヤシ', '本宮千束', 'モトミヤセンゾク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県本宮市本宮塩田入', '07', '07214', '9691153', '福島県', 'フクシマケン', '本宮市', 'モトミヤシ', '本宮塩田入', 'モトミヤシオダイリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県本宮市本宮塩田', '07', '07214', '9691154', '福島県', 'フクシマケン', '本宮市', 'モトミヤシ', '本宮塩田', 'モトミヤシオダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県本宮市本宮懸鉄', '07', '07214', '9691155', '福島県', 'フクシマケン', '本宮市', 'モトミヤシ', '本宮懸鉄', 'モトミヤカンカネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県本宮市本宮反町', '07', '07214', '9691155', '福島県', 'フクシマケン', '本宮市', 'モトミヤシ', '本宮反町', 'モトミヤソリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県本宮市本宮雲雀田', '07', '07214', '9691155', '福島県', 'フクシマケン', '本宮市', 'モトミヤシ', '本宮雲雀田', 'モトミヤヒバリタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県本宮市本宮舞台', '07', '07214', '9691155', '福島県', 'フクシマケン', '本宮市', 'モトミヤシ', '本宮舞台', 'モトミヤブタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県本宮市本宮諏訪', '07', '07214', '9691156', '福島県', 'フクシマケン', '本宮市', 'モトミヤシ', '本宮諏訪', 'モトミヤスワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県本宮市本宮鍋田', '07', '07214', '9691156', '福島県', 'フクシマケン', '本宮市', 'モトミヤシ', '本宮鍋田', 'モトミヤナベタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県本宮市本宮瀬樋内', '07', '07214', '9691157', '福島県', 'フクシマケン', '本宮市', 'モトミヤシ', '本宮瀬樋内', 'モトミヤセビウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県本宮市本宮田中', '07', '07214', '9691157', '福島県', 'フクシマケン', '本宮市', 'モトミヤシ', '本宮田中', 'モトミヤタナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県本宮市本宮天ヶ', '07', '07214', '9691158', '福島県', 'フクシマケン', '本宮市', 'モトミヤシ', '本宮天ヶ', 'モトミヤアマガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県本宮市本宮蛇ノ鼻', '07', '07214', '9691158', '福島県', 'フクシマケン', '本宮市', 'モトミヤシ', '本宮蛇ノ鼻', 'モトミヤジャノハナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県本宮市本宮平井', '07', '07214', '9691158', '福島県', 'フクシマケン', '本宮市', 'モトミヤシ', '本宮平井', 'モトミヤヒライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県本宮市本宮小幡', '07', '07214', '9691159', '福島県', 'フクシマケン', '本宮市', 'モトミヤシ', '本宮小幡', 'モトミヤオバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県本宮市本宮小籏北', '07', '07214', '9691159', '福島県', 'フクシマケン', '本宮市', 'モトミヤシ', '本宮小籏北', 'モトミヤオバタキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県本宮市本宮広町', '07', '07214', '9691159', '福島県', 'フクシマケン', '本宮市', 'モトミヤシ', '本宮広町', 'モトミヤヒロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県本宮市本宮欠下', '07', '07214', '9691161', '福島県', 'フクシマケン', '本宮市', 'モトミヤシ', '本宮欠下', 'モトミヤガケシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県本宮市本宮北川原田', '07', '07214', '9691162', '福島県', 'フクシマケン', '本宮市', 'モトミヤシ', '本宮北川原田', 'モトミヤキタカワハラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県本宮市本宮南河原田', '07', '07214', '9691162', '福島県', 'フクシマケン', '本宮市', 'モトミヤシ', '本宮南河原田', 'モトミヤミナミカワハラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県本宮市本宮白川', '07', '07214', '9691163', '福島県', 'フクシマケン', '本宮市', 'モトミヤシ', '本宮白川', 'モトミヤシラカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県本宮市本宮戸崎', '07', '07214', '9691164', '福島県', 'フクシマケン', '本宮市', 'モトミヤシ', '本宮戸崎', 'モトミヤトサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県本宮市本宮中台', '07', '07214', '9691165', '福島県', 'フクシマケン', '本宮市', 'モトミヤシ', '本宮中台', 'モトミヤナカダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県本宮市本宮近江内', '07', '07214', '9691166', '福島県', 'フクシマケン', '本宮市', 'モトミヤシ', '本宮近江内', 'モトミヤオオミウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県本宮市本宮北山神', '07', '07214', '9691167', '福島県', 'フクシマケン', '本宮市', 'モトミヤシ', '本宮北山神', 'モトミヤキタヤマノカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県本宮市本宮道屋敷', '07', '07214', '9691167', '福島県', 'フクシマケン', '本宮市', 'モトミヤシ', '本宮道屋敷', 'モトミヤドウヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県本宮市本宮一ッ屋', '07', '07214', '9691168', '福島県', 'フクシマケン', '本宮市', 'モトミヤシ', '本宮一ッ屋', 'モトミヤヒトツヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県本宮市本宮小原田', '07', '07214', '9691169', '福島県', 'フクシマケン', '本宮市', 'モトミヤシ', '本宮小原田', 'モトミヤコハラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県本宮市本宮樋ノ口', '07', '07214', '9691171', '福島県', 'フクシマケン', '本宮市', 'モトミヤシ', '本宮樋ノ口', 'モトミヤトイノクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県本宮市本宮北ノ内', '07', '07214', '9691172', '福島県', 'フクシマケン', '本宮市', 'モトミヤシ', '本宮北ノ内', 'モトミヤキタノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県本宮市本宮中野', '07', '07214', '9691173', '福島県', 'フクシマケン', '本宮市', 'モトミヤシ', '本宮中野', 'モトミヤナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県本宮市本宮中野後', '07', '07214', '9691173', '福島県', 'フクシマケン', '本宮市', 'モトミヤシ', '本宮中野後', 'モトミヤナカノウシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県本宮市本宮南ノ内', '07', '07214', '9691174', '福島県', 'フクシマケン', '本宮市', 'モトミヤシ', '本宮南ノ内', 'モトミヤミナミノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県本宮市本宮竹花', '07', '07214', '9691175', '福島県', 'フクシマケン', '本宮市', 'モトミヤシ', '本宮竹花', 'モトミヤタケノハナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県本宮市本宮名郷', '07', '07214', '9691175', '福島県', 'フクシマケン', '本宮市', 'モトミヤシ', '本宮名郷', 'モトミヤナゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県本宮市本宮名郷脇', '07', '07214', '9691175', '福島県', 'フクシマケン', '本宮市', 'モトミヤシ', '本宮名郷脇', 'モトミヤナゴウワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県本宮市本宮赤坂', '07', '07214', '9691176', '福島県', 'フクシマケン', '本宮市', 'モトミヤシ', '本宮赤坂', 'モトミヤアカサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県本宮市本宮地蔵堂', '07', '07214', '9691176', '福島県', 'フクシマケン', '本宮市', 'モトミヤシ', '本宮地蔵堂', 'モトミヤジゾウドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県本宮市稲沢', '07', '07214', '9691201', '福島県', 'フクシマケン', '本宮市', 'モトミヤシ', '稲沢', 'イナザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県本宮市松沢', '07', '07214', '9691202', '福島県', 'フクシマケン', '本宮市', 'モトミヤシ', '松沢', 'マツザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県本宮市白岩', '07', '07214', '9691203', '福島県', 'フクシマケン', '本宮市', 'モトミヤシ', '白岩', 'シライワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県本宮市糠沢', '07', '07214', '9691204', '福島県', 'フクシマケン', '本宮市', 'モトミヤシ', '糠沢', 'ヌカザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県本宮市和田', '07', '07214', '9691205', '福島県', 'フクシマケン', '本宮市', 'モトミヤシ', '和田', 'ワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県本宮市長屋', '07', '07214', '9691206', '福島県', 'フクシマケン', '本宮市', 'モトミヤシ', '長屋', 'ナガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県安達郡大玉村', '07', '07322', '9691300', '福島県', 'フクシマケン', '安達郡大玉村', 'アダチグンオオタマムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('138376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県安達郡大玉村大山', '07', '07322', '9691301', '福島県', 'フクシマケン', '安達郡大玉村', 'アダチグンオオタマムラ', '大山', 'オオヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県安達郡大玉村玉井', '07', '07322', '9691302', '福島県', 'フクシマケン', '安達郡大玉村', 'アダチグンオオタマムラ', '玉井', 'タマノイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市吉倉', '07', '07210', '9691401', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '吉倉', 'ヨシクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市米沢', '07', '07210', '9691402', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '米沢', 'ヨナザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市渋川', '07', '07210', '9691403', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '渋川', 'シブカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市油井', '07', '07210', '9691404', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '油井', 'ユイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市智恵子の森', '07', '07210', '9691405', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '智恵子の森', 'チエコノモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市下川崎', '07', '07210', '9691511', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '下川崎', 'シモカワサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市上川崎', '07', '07210', '9691512', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '上川崎', 'カミカワサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県二本松市小沢', '07', '07210', '9691513', '福島県', 'フクシマケン', '二本松市', 'ニホンマツシ', '小沢', 'オザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡桑折町', '07', '07301', '9691600', '福島県', 'フクシマケン', '伊達郡桑折町', 'ダテグンコオリマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('138389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡桑折町北町', '07', '07301', '9691601', '福島県', 'フクシマケン', '伊達郡桑折町', 'ダテグンコオリマチ', '北町', 'キタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡桑折町町裏', '07', '07301', '9691602', '福島県', 'フクシマケン', '伊達郡桑折町', 'ダテグンコオリマチ', '町裏', 'マチウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡桑折町上町', '07', '07301', '9691603', '福島県', 'フクシマケン', '伊達郡桑折町', 'ダテグンコオリマチ', '上町', 'ウワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡桑折町堰下', '07', '07301', '9691604', '福島県', 'フクシマケン', '伊達郡桑折町', 'ダテグンコオリマチ', '堰下', 'セキシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡桑折町堰合', '07', '07301', '9691605', '福島県', 'フクシマケン', '伊達郡桑折町', 'ダテグンコオリマチ', '堰合', 'セキアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡桑折町東段', '07', '07301', '9691606', '福島県', 'フクシマケン', '伊達郡桑折町', 'ダテグンコオリマチ', '東段', 'ヒガシダン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡桑折町西段', '07', '07301', '9691607', '福島県', 'フクシマケン', '伊達郡桑折町', 'ダテグンコオリマチ', '西段', 'ニシダン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡桑折町芝堤', '07', '07301', '9691608', '福島県', 'フクシマケン', '伊達郡桑折町', 'ダテグンコオリマチ', '芝堤', 'シバツツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡桑折町東大隅', '07', '07301', '9691611', '福島県', 'フクシマケン', '伊達郡桑折町', 'ダテグンコオリマチ', '東大隅', 'ヒガシオオスミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡桑折町西大隅', '07', '07301', '9691612', '福島県', 'フクシマケン', '伊達郡桑折町', 'ダテグンコオリマチ', '西大隅', 'ニシオオスミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡桑折町桑島', '07', '07301', '9691613', '福島県', 'フクシマケン', '伊達郡桑折町', 'ダテグンコオリマチ', '桑島', 'クワジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡桑折町本町', '07', '07301', '9691614', '福島県', 'フクシマケン', '伊達郡桑折町', 'ダテグンコオリマチ', '本町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡桑折町沢', '07', '07301', '9691615', '福島県', 'フクシマケン', '伊達郡桑折町', 'ダテグンコオリマチ', '沢', 'サワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡桑折町舘', '07', '07301', '9691616', '福島県', 'フクシマケン', '伊達郡桑折町', 'ダテグンコオリマチ', '舘', 'タテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡桑折町陣屋', '07', '07301', '9691617', '福島県', 'フクシマケン', '伊達郡桑折町', 'ダテグンコオリマチ', '陣屋', 'ジンヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡桑折町庫場', '07', '07301', '9691618', '福島県', 'フクシマケン', '伊達郡桑折町', 'ダテグンコオリマチ', '庫場', 'クラバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡桑折町仮屋', '07', '07301', '9691619', '福島県', 'フクシマケン', '伊達郡桑折町', 'ダテグンコオリマチ', '仮屋', 'カリヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡桑折町道場前', '07', '07301', '9691621', '福島県', 'フクシマケン', '伊達郡桑折町', 'ダテグンコオリマチ', '道場前', 'ドウジョウマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡桑折町南町', '07', '07301', '9691622', '福島県', 'フクシマケン', '伊達郡桑折町', 'ダテグンコオリマチ', '南町', 'ミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡桑折町和尚堂', '07', '07301', '9691623', '福島県', 'フクシマケン', '伊達郡桑折町', 'ダテグンコオリマチ', '和尚堂', 'オショウドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡桑折町新和町', '07', '07301', '9691624', '福島県', 'フクシマケン', '伊達郡桑折町', 'ダテグンコオリマチ', '新和町', 'シンワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡桑折町新吉町', '07', '07301', '9691625', '福島県', 'フクシマケン', '伊達郡桑折町', 'ダテグンコオリマチ', '新吉町', 'シンヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡桑折町寺坂', '07', '07301', '9691626', '福島県', 'フクシマケン', '伊達郡桑折町', 'ダテグンコオリマチ', '寺坂', 'テラサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡桑折町諏訪', '07', '07301', '9691627', '福島県', 'フクシマケン', '伊達郡桑折町', 'ダテグンコオリマチ', '諏訪', 'スワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡桑折町新町', '07', '07301', '9691628', '福島県', 'フクシマケン', '伊達郡桑折町', 'ダテグンコオリマチ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡桑折町西町', '07', '07301', '9691629', '福島県', 'フクシマケン', '伊達郡桑折町', 'ダテグンコオリマチ', '西町', 'ニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡桑折町白銀', '07', '07301', '9691631', '福島県', 'フクシマケン', '伊達郡桑折町', 'ダテグンコオリマチ', '白銀', 'シロガネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡桑折町薮内', '07', '07301', '9691631', '福島県', 'フクシマケン', '伊達郡桑折町', 'ダテグンコオリマチ', '薮内', 'ヤブウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡桑折町田植', '07', '07301', '9691632', '福島県', 'フクシマケン', '伊達郡桑折町', 'ダテグンコオリマチ', '田植', 'タウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡桑折町赤坂', '07', '07301', '9691633', '福島県', 'フクシマケン', '伊達郡桑折町', 'ダテグンコオリマチ', '赤坂', 'アカサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡桑折町一里壇', '07', '07301', '9691633', '福島県', 'フクシマケン', '伊達郡桑折町', 'ダテグンコオリマチ', '一里壇', 'イチリダン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡桑折町界', '07', '07301', '9691633', '福島県', 'フクシマケン', '伊達郡桑折町', 'ダテグンコオリマチ', '界', 'サカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡桑折町落合', '07', '07301', '9691634', '福島県', 'フクシマケン', '伊達郡桑折町', 'ダテグンコオリマチ', '落合', 'オチアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡桑折町杉ノ前', '07', '07301', '9691634', '福島県', 'フクシマケン', '伊達郡桑折町', 'ダテグンコオリマチ', '杉ノ前', 'スギノマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡桑折町砂子沢', '07', '07301', '9691634', '福島県', 'フクシマケン', '伊達郡桑折町', 'ダテグンコオリマチ', '砂子沢', 'スナゴザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡桑折町狐崎', '07', '07301', '9691635', '福島県', 'フクシマケン', '伊達郡桑折町', 'ダテグンコオリマチ', '狐崎', 'キツネザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡桑折町東八串', '07', '07301', '9691635', '福島県', 'フクシマケン', '伊達郡桑折町', 'ダテグンコオリマチ', '東八串', 'ヒガシヤクシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡桑折町南半田', '07', '07301', '9691641', '福島県', 'フクシマケン', '伊達郡桑折町', 'ダテグンコオリマチ', '南半田', 'ミナミハンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡桑折町北半田', '07', '07301', '9691642', '福島県', 'フクシマケン', '伊達郡桑折町', 'ダテグンコオリマチ', '北半田', 'キタハンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡桑折町谷地', '07', '07301', '9691643', '福島県', 'フクシマケン', '伊達郡桑折町', 'ダテグンコオリマチ', '谷地', 'ヤジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡桑折町万正寺', '07', '07301', '9691651', '福島県', 'フクシマケン', '伊達郡桑折町', 'ダテグンコオリマチ', '万正寺', 'マンショウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡桑折町成田', '07', '07301', '9691652', '福島県', 'フクシマケン', '伊達郡桑折町', 'ダテグンコオリマチ', '成田', 'ナリタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡桑折町松原', '07', '07301', '9691653', '福島県', 'フクシマケン', '伊達郡桑折町', 'ダテグンコオリマチ', '松原', 'マツバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡桑折町平沢', '07', '07301', '9691654', '福島県', 'フクシマケン', '伊達郡桑折町', 'ダテグンコオリマチ', '平沢', 'ヒラサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡桑折町上郡', '07', '07301', '9691661', '福島県', 'フクシマケン', '伊達郡桑折町', 'ダテグンコオリマチ', '上郡', 'カミゴオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡桑折町下郡', '07', '07301', '9691662', '福島県', 'フクシマケン', '伊達郡桑折町', 'ダテグンコオリマチ', '下郡', 'シモゴオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡桑折町伊達崎', '07', '07301', '9691663', '福島県', 'フクシマケン', '伊達郡桑折町', 'ダテグンコオリマチ', '伊達崎', 'ダンザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡国見町', '07', '07303', '9691700', '福島県', 'フクシマケン', '伊達郡国見町', 'ダテグンクニミマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('138438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡国見町石母田', '07', '07303', '9691701', '福島県', 'フクシマケン', '伊達郡国見町', 'ダテグンクニミマチ', '石母田', 'イシモダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡国見町貝田', '07', '07303', '9691711', '福島県', 'フクシマケン', '伊達郡国見町', 'ダテグンクニミマチ', '貝田', 'カイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡国見町光明寺', '07', '07303', '9691712', '福島県', 'フクシマケン', '伊達郡国見町', 'ダテグンクニミマチ', '光明寺', 'コウミョウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡国見町大木戸', '07', '07303', '9691713', '福島県', 'フクシマケン', '伊達郡国見町', 'ダテグンクニミマチ', '大木戸', 'オオキド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡国見町高城', '07', '07303', '9691714', '福島県', 'フクシマケン', '伊達郡国見町', 'ダテグンクニミマチ', '高城', 'タカギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡国見町川内', '07', '07303', '9691721', '福島県', 'フクシマケン', '伊達郡国見町', 'ダテグンクニミマチ', '川内', 'カワウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡国見町西大枝', '07', '07303', '9691722', '福島県', 'フクシマケン', '伊達郡国見町', 'ダテグンクニミマチ', '西大枝', 'ニシオオエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡国見町森山', '07', '07303', '9691731', '福島県', 'フクシマケン', '伊達郡国見町', 'ダテグンクニミマチ', '森山', 'モリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡国見町徳江', '07', '07303', '9691741', '福島県', 'フクシマケン', '伊達郡国見町', 'ダテグンクニミマチ', '徳江', 'トクエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡国見町塚野目', '07', '07303', '9691751', '福島県', 'フクシマケン', '伊達郡国見町', 'ダテグンクニミマチ', '塚野目', 'ツカノメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡国見町藤田', '07', '07303', '9691761', '福島県', 'フクシマケン', '伊達郡国見町', 'ダテグンクニミマチ', '藤田', 'フジタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡国見町山崎', '07', '07303', '9691771', '福島県', 'フクシマケン', '伊達郡国見町', 'ダテグンクニミマチ', '山崎', 'ヤマザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡国見町新内谷', '07', '07303', '9691780', '福島県', 'フクシマケン', '伊達郡国見町', 'ダテグンクニミマチ', '新内谷', 'シンウチヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡国見町内谷', '07', '07303', '9691781', '福島県', 'フクシマケン', '伊達郡国見町', 'ダテグンクニミマチ', '内谷', 'ウチヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡国見町泉田', '07', '07303', '9691782', '福島県', 'フクシマケン', '伊達郡国見町', 'ダテグンクニミマチ', '泉田', 'イズミダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡国見町鳥取', '07', '07303', '9691783', '福島県', 'フクシマケン', '伊達郡国見町', 'ダテグンクニミマチ', '鳥取', 'トットリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡国見町小坂', '07', '07303', '9691784', '福島県', 'フクシマケン', '伊達郡国見町', 'ダテグンクニミマチ', '小坂', 'コサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡国見町板橋南', '07', '07303', '9691785', '福島県', 'フクシマケン', '伊達郡国見町', 'ダテグンクニミマチ', '板橋南', 'イタバシミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡国見町新泉田', '07', '07303', '9691786', '福島県', 'フクシマケン', '伊達郡国見町', 'ダテグンクニミマチ', '新泉田', 'シンイズミダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡国見町新小坂', '07', '07303', '9691787', '福島県', 'フクシマケン', '伊達郡国見町', 'ダテグンクニミマチ', '新小坂', 'シンコサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡国見町小坂南', '07', '07303', '9691788', '福島県', 'フクシマケン', '伊達郡国見町', 'ダテグンクニミマチ', '小坂南', 'コサカミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県伊達郡国見町新鳥取', '07', '07303', '9691789', '福島県', 'フクシマケン', '伊達郡国見町', 'ダテグンクニミマチ', '新鳥取', 'シントットリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町中小松', '07', '07408', '9692271', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '中小松', 'ナカコマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町金田', '07', '07408', '9692272', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '金田', 'カネダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町関都', '07', '07408', '9692273', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '関都', 'セキト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町壺楊', '07', '07408', '9692274', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '壺楊', 'ツボヨウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町山潟', '07', '07408', '9692275', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '山潟', 'ヤマガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町三郷', '07', '07408', '9692661', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '三郷', 'ミサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町八幡', '07', '07408', '9692662', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '八幡', 'ヤハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町川桁', '07', '07408', '9692663', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '川桁', 'カワゲタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡北塩原村檜原秋元', '07', '07402', '9692701', '福島県', 'フクシマケン', '耶麻郡北塩原村', 'ヤマグンキタシオバラムラ', '檜原', 'ヒバラ', null, null, '秋元', 'アキモト');
INSERT INTO `ms_addresses` VALUES ('138471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡北塩原村檜原荒砂沢山', '07', '07402', '9692701', '福島県', 'フクシマケン', '耶麻郡北塩原村', 'ヤマグンキタシオバラムラ', '檜原', 'ヒバラ', null, null, '荒砂沢山', 'アラスナサワヤマ');
INSERT INTO `ms_addresses` VALUES ('138472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡北塩原村檜原裏磐梯', '07', '07402', '9692701', '福島県', 'フクシマケン', '耶麻郡北塩原村', 'ヤマグンキタシオバラムラ', '檜原', 'ヒバラ', null, null, '裏磐梯', 'ウラバンダイ');
INSERT INTO `ms_addresses` VALUES ('138473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡北塩原村檜原大府平', '07', '07402', '9692701', '福島県', 'フクシマケン', '耶麻郡北塩原村', 'ヤマグンキタシオバラムラ', '檜原', 'ヒバラ', null, null, '大府平', 'オオブダイラ');
INSERT INTO `ms_addresses` VALUES ('138474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡北塩原村檜原小野川', '07', '07402', '9692701', '福島県', 'フクシマケン', '耶麻郡北塩原村', 'ヤマグンキタシオバラムラ', '檜原', 'ヒバラ', null, null, '小野川', 'オノガワ');
INSERT INTO `ms_addresses` VALUES ('138475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡北塩原村檜原小野川原', '07', '07402', '9692701', '福島県', 'フクシマケン', '耶麻郡北塩原村', 'ヤマグンキタシオバラムラ', '檜原', 'ヒバラ', null, null, '小野川原', 'オノガワハラ');
INSERT INTO `ms_addresses` VALUES ('138476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡北塩原村檜原剣ケ峯', '07', '07402', '9692701', '福島県', 'フクシマケン', '耶麻郡北塩原村', 'ヤマグンキタシオバラムラ', '檜原', 'ヒバラ', null, null, '剣ケ峯', 'ケンガミネ');
INSERT INTO `ms_addresses` VALUES ('138477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡北塩原村檜原五色沼', '07', '07402', '9692701', '福島県', 'フクシマケン', '耶麻郡北塩原村', 'ヤマグンキタシオバラムラ', '檜原', 'ヒバラ', null, null, '五色沼', 'ゴシキヌマ');
INSERT INTO `ms_addresses` VALUES ('138478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡北塩原村檜原狐鷹森', '07', '07402', '9692701', '福島県', 'フクシマケン', '耶麻郡北塩原村', 'ヤマグンキタシオバラムラ', '檜原', 'ヒバラ', null, null, '狐鷹森', 'コタカモリ');
INSERT INTO `ms_addresses` VALUES ('138479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡北塩原村檜原甚九郎山', '07', '07402', '9692701', '福島県', 'フクシマケン', '耶麻郡北塩原村', 'ヤマグンキタシオバラムラ', '檜原', 'ヒバラ', null, null, '甚九郎山', 'ジンクロウヤマ');
INSERT INTO `ms_addresses` VALUES ('138480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡北塩原村檜原曽原山', '07', '07402', '9692701', '福島県', 'フクシマケン', '耶麻郡北塩原村', 'ヤマグンキタシオバラムラ', '檜原', 'ヒバラ', null, null, '曽原山', 'ソハラヤマ');
INSERT INTO `ms_addresses` VALUES ('138481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡北塩原村檜原寺沢山', '07', '07402', '9692701', '福島県', 'フクシマケン', '耶麻郡北塩原村', 'ヤマグンキタシオバラムラ', '檜原', 'ヒバラ', null, null, '寺沢山', 'テラサワヤマ');
INSERT INTO `ms_addresses` VALUES ('138482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡北塩原村檜原蛇平原山', '07', '07402', '9692701', '福島県', 'フクシマケン', '耶麻郡北塩原村', 'ヤマグンキタシオバラムラ', '檜原', 'ヒバラ', null, null, '蛇平原山', 'ヘビタイラハラヤマ');
INSERT INTO `ms_addresses` VALUES ('138483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡北塩原村檜原湯平山', '07', '07402', '9692701', '福島県', 'フクシマケン', '耶麻郡北塩原村', 'ヤマグンキタシオバラムラ', '檜原', 'ヒバラ', null, null, '湯平山', 'ユダイラヤマ');
INSERT INTO `ms_addresses` VALUES ('138484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町若宮', '07', '07408', '9692751', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '若宮', 'ワカミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町蚕養', '07', '07408', '9692752', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '蚕養', 'コガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町', '07', '07408', '9693100', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('138487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町家ノ前', '07', '07408', '9693101', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '家ノ前', 'イエノマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町大谷地', '07', '07408', '9693101', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '大谷地', 'オオヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町欠上り', '07', '07408', '9693101', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '欠上り', 'カケアガリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町上ノ山', '07', '07408', '9693101', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '上ノ山', 'カミノヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町北ノ林', '07', '07408', '9693101', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '北ノ林', 'キタノハヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町行人壇', '07', '07408', '9693101', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '行人壇', 'ギョウニンダン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町グミ沢原', '07', '07408', '9693101', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', 'グミ沢原', 'グミザワハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町渋谷', '07', '07408', '9693101', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '渋谷', 'シブタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町清水', '07', '07408', '9693101', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '清水', 'シミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町清水端', '07', '07408', '9693101', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '清水端', 'シミズバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町下辺沢', '07', '07408', '9693101', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '下辺沢', 'シモヘンザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町菖蒲田', '07', '07408', '9693101', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '菖蒲田', 'ショウブダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町新堀田東', '07', '07408', '9693101', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '新堀田東', 'シンボリタヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町新堀西', '07', '07408', '9693101', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '新堀西', 'シンボリニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町堰間上', '07', '07408', '9693101', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '堰間上', 'セキマウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町芹沢', '07', '07408', '9693101', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '芹沢', 'セリサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町土湯沢山', '07', '07408', '9693101', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '土湯沢山', 'ツチユサワヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町土手間', '07', '07408', '9693101', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '土手間', 'ドテマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町長坂', '07', '07408', '9693101', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '長坂', 'ナガサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町中道西', '07', '07408', '9693101', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '中道西', 'ナカミチニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町沼ノ倉', '07', '07408', '9693101', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '沼ノ倉', 'ヌマノクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町琵琶沢原', '07', '07408', '9693101', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '琵琶沢原', 'ビワサワハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町辺沢', '07', '07408', '9693101', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '辺沢', 'ヘンザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町程塚', '07', '07408', '9693101', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '程塚', 'ホドヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町三ツ屋', '07', '07408', '9693101', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '三ツ屋', 'ミツヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町村北', '07', '07408', '9693101', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '村北', 'ムラキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町村中', '07', '07408', '9693101', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '村中', 'ムラナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町山神原', '07', '07408', '9693101', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '山神原', 'ヤマカミハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町右近山', '07', '07408', '9693102', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '右近山', 'ウコンヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町西峰', '07', '07408', '9693102', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '西峰', 'ニシミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町猫石山', '07', '07408', '9693102', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '猫石山', 'ネコイシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町葉山', '07', '07408', '9693102', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '葉山', 'ハヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町雛草', '07', '07408', '9693102', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '雛草', 'ヒナクサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町見禰', '07', '07408', '9693102', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '見禰', 'ミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町見禰山', '07', '07408', '9693102', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '見禰山', 'ミネヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町鹿野境', '07', '07408', '9693103', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '鹿野境', 'カノザカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町上村東', '07', '07408', '9693103', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '上村東', 'カミムラヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町上村前', '07', '07408', '9693103', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '上村前', 'カミムラマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町桐木沢', '07', '07408', '9693103', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '桐木沢', 'キリノキザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町五輪原', '07', '07408', '9693103', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '五輪原', 'ゴリンパラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町諏訪西', '07', '07408', '9693103', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '諏訪西', 'スワニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町諏訪東', '07', '07408', '9693103', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '諏訪東', 'スワヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町諏訪前', '07', '07408', '9693103', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '諏訪前', 'スワマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町禰次', '07', '07408', '9693103', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '禰次', 'ネツギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町ハノ木沢', '07', '07408', '9693103', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', 'ハノ木沢', 'ハノキザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町林崎', '07', '07408', '9693103', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '林崎', 'ハヤシザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町町島田', '07', '07408', '9693103', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '町島田', 'マチシマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町雷', '07', '07408', '9693111', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '雷', 'イカズチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町出雲壇', '07', '07408', '9693111', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '出雲壇', 'イズモダン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町板橋北', '07', '07408', '9693111', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '板橋北', 'イタバシキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町太田', '07', '07408', '9693111', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '太田', 'オオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町太田西', '07', '07408', '9693111', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '太田西', 'オオタニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町小黒川', '07', '07408', '9693111', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '小黒川', 'オグロガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町窪田', '07', '07408', '9693111', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '窪田', 'クボタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町窪ノ内', '07', '07408', '9693111', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '窪ノ内', 'クボノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町窪南', '07', '07408', '9693111', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '窪南', 'クボミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町御三壇', '07', '07408', '9693111', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '御三壇', 'ゴサンダン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町五百苅', '07', '07408', '9693111', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '五百苅', 'ゴヒャクガリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町猿壇', '07', '07408', '9693111', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '猿壇', 'サルダン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町二丁田', '07', '07408', '9693111', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '二丁田', 'ニチョウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町沼田', '07', '07408', '9693111', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '沼田', 'ヌマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町東町裏', '07', '07408', '9693111', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '東町裏', 'ヒガシマチウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町明円', '07', '07408', '9693111', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '明円', 'ミョウエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町村東', '07', '07408', '9693111', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '村東', 'ムラヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町村東下', '07', '07408', '9693111', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '村東下', 'ムラヒガシシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町堤', '07', '07408', '9693112', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '堤', 'ツツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町寺後', '07', '07408', '9693112', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '寺後', 'テラウシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町中町', '07', '07408', '9693112', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '中町', 'ナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町馬場', '07', '07408', '9693112', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '馬場', 'ババ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町弁才天西', '07', '07408', '9693112', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '弁才天西', 'ベンザイテンニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町大道西', '07', '07408', '9693113', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '大道西', 'オオミチニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町北半坂', '07', '07408', '9693113', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '北半坂', 'キタハンザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町新地', '07', '07408', '9693113', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '新地', 'シンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町茶園', '07', '07408', '9693113', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '茶園', 'チャエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町堤北', '07', '07408', '9693113', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '堤北', 'ツツミキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町堤下', '07', '07408', '9693113', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '堤下', 'ツツミシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町鶴峰西', '07', '07408', '9693113', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '鶴峰西', 'ツルミネニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町樋場', '07', '07408', '9693113', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '樋場', 'トイバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町樋場道下', '07', '07408', '9693113', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '樋場道下', 'トイバミチシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町並杉西', '07', '07408', '9693113', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '並杉西', 'ナミスギニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町土町', '07', '07408', '9693113', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '土町', 'ハニマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町土町西裡', '07', '07408', '9693113', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '土町西裡', 'ハニマチニシウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町土町南', '07', '07408', '9693113', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '土町南', 'ハニマチミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町半坂', '07', '07408', '9693113', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '半坂', 'ハンザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町町西', '07', '07408', '9693113', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '町西', 'マチニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町南半坂', '07', '07408', '9693113', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '南半坂', 'ミナミハンザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町芦原', '07', '07408', '9693121', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '芦原', 'アシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町裏町', '07', '07408', '9693121', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '裏町', 'ウラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町オヒテ川', '07', '07408', '9693121', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', 'オヒテ川', 'オヒテカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町上ザル田', '07', '07408', '9693121', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '上ザル田', 'カミザルタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町津金沢', '07', '07408', '9693121', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '津金沢', 'ツガネサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町寺東', '07', '07408', '9693121', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '寺東', 'テラヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町梨木西', '07', '07408', '9693121', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '梨木西', 'ナシノキニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町町東', '07', '07408', '9693121', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '町東', 'マチヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町横まくり', '07', '07408', '9693121', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '横まくり', 'ヨコマクリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町横マクリ', '07', '07408', '9693121', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '横マクリ', 'ヨコマクリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町新町', '07', '07408', '9693122', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '新町', 'アラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町カキ田', '07', '07408', '9693122', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', 'カキ田', 'カキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町ガギ田', '07', '07408', '9693122', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', 'ガギ田', 'ガギタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町坂下', '07', '07408', '9693122', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '坂下', 'サカシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町塚田', '07', '07408', '9693122', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '塚田', 'ツカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町町尻', '07', '07408', '9693122', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '町尻', 'マチジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町本町', '07', '07408', '9693122', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '本町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町古城跡', '07', '07408', '9693123', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '古城跡', 'コジョウアト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町古城町', '07', '07408', '9693123', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '古城町', 'コジョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町城南', '07', '07408', '9693123', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '城南', 'シロミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町鶴田', '07', '07408', '9693123', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '鶴田', 'ツルタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町今泉', '07', '07408', '9693131', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '今泉', 'イマイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町上屋敷', '07', '07408', '9693131', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '上屋敷', 'カミヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町下園', '07', '07408', '9693131', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '下園', 'シモゾノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町新堀向', '07', '07408', '9693131', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '新堀向', 'シンボリムカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町西舘', '07', '07408', '9693131', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '西舘', 'ニシダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町東谷地', '07', '07408', '9693131', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '東谷地', 'ヒガシヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町村南', '07', '07408', '9693131', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '村南', 'ムラミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町堅田', '07', '07408', '9693132', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '堅田', 'カタダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町千代田', '07', '07408', '9693133', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '千代田', 'チヨダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町磐里', '07', '07408', '9693141', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '磐里', 'イワサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町六角', '07', '07408', '9693141', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '六角', 'ロッカク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町西葉山', '07', '07408', '9693281', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '西葉山', 'ニシハヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町酸奨沢', '07', '07408', '9693282', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '酸奨沢', 'サンショウザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町長田', '07', '07408', '9693283', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '長田', 'オサダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町三ツ和', '07', '07408', '9693284', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '三ツ和', 'ミツワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町翁沢', '07', '07408', '9693285', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '翁沢', 'オキナザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町磐根', '07', '07408', '9693286', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '磐根', 'イワネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町不動', '07', '07408', '9693287', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '不動', 'フドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡猪苗代町綿場', '07', '07408', '9693288', '福島県', 'フクシマケン', '耶麻郡猪苗代町', 'ヤマグンイナワシロマチ', '綿場', 'ワタバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡磐梯町', '07', '07407', '9693300', '福島県', 'フクシマケン', '耶麻郡磐梯町', 'ヤマグンバンダイマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('138615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡磐梯町磐梯', '07', '07407', '9693301', '福島県', 'フクシマケン', '耶麻郡磐梯町', 'ヤマグンバンダイマチ', '磐梯', 'バンダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡磐梯町更科', '07', '07407', '9693302', '福島県', 'フクシマケン', '耶麻郡磐梯町', 'ヤマグンバンダイマチ', '更科', 'サラシナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡磐梯町赤枝', '07', '07407', '9693303', '福島県', 'フクシマケン', '耶麻郡磐梯町', 'ヤマグンバンダイマチ', '赤枝', 'アカエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡磐梯町大谷', '07', '07407', '9693304', '福島県', 'フクシマケン', '耶麻郡磐梯町', 'ヤマグンバンダイマチ', '大谷', 'オオタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市河東町岡田', '07', '07202', '9693401', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '河東町岡田', 'カワヒガシマチオカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市河東町福島', '07', '07202', '9693402', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '河東町福島', 'カワヒガシマチフクシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市河東町大田原', '07', '07202', '9693411', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '河東町大田原', 'カワヒガシマチオオタワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市河東町代田', '07', '07202', '9693412', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '河東町代田', 'カワヒガシマチヨダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市河東町熊野堂', '07', '07202', '9693421', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '河東町熊野堂', 'カワヒガシマチクマノドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市河東町広野', '07', '07202', '9693422', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '河東町広野', 'カワヒガシマチコウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市河東町東長原', '07', '07202', '9693431', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '河東町東長原', 'カワヒガシマチヒガシナガハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市河東町南高野', '07', '07202', '9693441', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '河東町南高野', 'カワヒガシマチミナミコウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市河東町八田', '07', '07202', '9693451', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '河東町八田', 'カワヒガシマチハッタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市河東町浅山', '07', '07202', '9693461', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '河東町浅山', 'カワヒガシマチアサヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市河東町金田', '07', '07202', '9693462', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '河東町金田', 'カワヒガシマチカネダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市河東町倉橋', '07', '07202', '9693463', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '河東町倉橋', 'カワヒガシマチクラハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市河東町広田', '07', '07202', '9693471', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '河東町広田', 'カワヒガシマチヒロタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市河東町郡山', '07', '07202', '9693481', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '河東町郡山', 'カワヒガシマチコオリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市河東町谷沢', '07', '07202', '9693482', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '河東町谷沢', 'カワヒガシマチタニサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡湯川村', '07', '07422', '9693500', '福島県', 'フクシマケン', '河沼郡湯川村', 'カワヌマグンユガワムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('138639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市塩川町三吉', '07', '07208', '9693501', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '塩川町三吉', 'シオカワマチミヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市塩川町常世', '07', '07208', '9693502', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '塩川町常世', 'シオカワマチトコヨ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市塩川町五合', '07', '07208', '9693503', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '塩川町五合', 'シオカワマチゴゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市塩川町中屋沢', '07', '07208', '9693504', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '塩川町中屋沢', 'シオカワマチナカヤザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市塩川町金橋', '07', '07208', '9693505', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '塩川町金橋', 'シオカワマチカナハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市塩川町窪', '07', '07208', '9693506', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '塩川町窪', 'シオカワマチクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市塩川町町北', '07', '07208', '9693511', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '塩川町町北', 'シオカワマチマチキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市塩川町東栄町', '07', '07208', '9693512', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '塩川町東栄町', 'シオカワマチヒガシサカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市塩川町中町', '07', '07208', '9693513', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '塩川町中町', 'シオカワマチナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市塩川町新町', '07', '07208', '9693514', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '塩川町新町', 'シオカワマチアラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市塩川町米沢町', '07', '07208', '9693515', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '塩川町米沢町', 'シオカワマチヨネザワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市塩川町岡ノ前', '07', '07208', '9693521', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '塩川町岡ノ前', 'シオカワマチオカノマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市塩川町東岡', '07', '07208', '9693521', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '塩川町東岡', 'シオカワマチヒガシオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市塩川町身神', '07', '07208', '9693521', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '塩川町身神', 'シオカワマチミカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市塩川町新丁', '07', '07208', '9693522', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '塩川町新丁', 'シオカワマチシンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市塩川町石橋', '07', '07208', '9693523', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '塩川町石橋', 'シオカワマチイシバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市塩川町反町', '07', '07208', '9693523', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '塩川町反町', 'シオカワマチソリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市塩川町清水岸', '07', '07208', '9693524', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '塩川町清水岸', 'シオカワマチシミズギシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市塩川町竹ノ花', '07', '07208', '9693524', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '塩川町竹ノ花', 'シオカワマチタケノハナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市塩川町舘ノ内', '07', '07208', '9693524', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '塩川町舘ノ内', 'シオカワマチタテノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市塩川町恵比寿喜田', '07', '07208', '9693525', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '塩川町恵比寿喜田', 'シオカワマチエビスキダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市塩川町源屋', '07', '07208', '9693525', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '塩川町源屋', 'シオカワマチゲンヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市塩川町黄金田', '07', '07208', '9693525', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '塩川町黄金田', 'シオカワマチコガネダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市塩川町四郎田', '07', '07208', '9693525', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '塩川町四郎田', 'シオカワマチシロウデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市塩川町諏訪町', '07', '07208', '9693525', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '塩川町諏訪町', 'シオカワマチスワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市塩川町諏訪前', '07', '07208', '9693525', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '塩川町諏訪前', 'シオカワマチスワマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市塩川町西岡', '07', '07208', '9693525', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '塩川町西岡', 'シオカワマチニシオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市塩川町鼠田', '07', '07208', '9693525', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '塩川町鼠田', 'シオカワマチネズミダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市塩川町蛭田', '07', '07208', '9693525', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '塩川町蛭田', 'シオカワマチヒルダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市塩川町新井田谷地', '07', '07208', '9693531', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '塩川町新井田谷地', 'シオカワマチニイダヤヂ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市塩川町大在家', '07', '07208', '9693532', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '塩川町大在家', 'シオカワマチオオザイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市塩川町経塚', '07', '07208', '9693532', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '塩川町経塚', 'シオカワマチキョウヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市塩川町小府根', '07', '07208', '9693532', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '塩川町小府根', 'シオカワマチコフネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市塩川町高道', '07', '07208', '9693532', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '塩川町高道', 'シオカワマチタカミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市塩川町藤ノ木', '07', '07208', '9693532', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '塩川町藤ノ木', 'シオカワマチフジノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市塩川町新江木', '07', '07208', '9693533', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '塩川町新江木', 'シオカワマチニエキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市塩川町遠田', '07', '07208', '9693534', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '塩川町遠田', 'シオカワマチトオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市塩川町西ノ新田', '07', '07208', '9693534', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '塩川町西ノ新田', 'シオカワマチニシノシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市塩川町会知', '07', '07208', '9693535', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '塩川町会知', 'シオカワマチカイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市塩川町大田木', '07', '07208', '9693536', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '塩川町大田木', 'シオカワマチオオタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市塩川町四奈川', '07', '07208', '9693537', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '塩川町四奈川', 'シオカワマチシナガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市塩川町天沼', '07', '07208', '9693538', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '塩川町天沼', 'シオカワマチアマヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市塩川町源太屋敷', '07', '07208', '9693539', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '塩川町源太屋敷', 'シオカワマチゲンダヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市塩川町吉沖', '07', '07208', '9693539', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '塩川町吉沖', 'シオカワマチヨシオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡湯川村浜崎', '07', '07422', '9693541', '福島県', 'フクシマケン', '河沼郡湯川村', 'カワヌマグンユガワムラ', '浜崎', 'ハマサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡湯川村湊', '07', '07422', '9693542', '福島県', 'フクシマケン', '河沼郡湯川村', 'カワヌマグンユガワムラ', '湊', 'ミナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡湯川村笈川', '07', '07422', '9693543', '福島県', 'フクシマケン', '河沼郡湯川村', 'カワヌマグンユガワムラ', '笈川', 'オイカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡湯川村清水田', '07', '07422', '9693544', '福島県', 'フクシマケン', '河沼郡湯川村', 'カワヌマグンユガワムラ', '清水田', 'シミズダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡湯川村桜町', '07', '07422', '9693545', '福島県', 'フクシマケン', '河沼郡湯川村', 'カワヌマグンユガワムラ', '桜町', 'サクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡湯川村堂畑', '07', '07422', '9693551', '福島県', 'フクシマケン', '河沼郡湯川村', 'カワヌマグンユガワムラ', '堂畑', 'ドウバタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡湯川村三川', '07', '07422', '9693552', '福島県', 'フクシマケン', '河沼郡湯川村', 'カワヌマグンユガワムラ', '三川', 'ミカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡湯川村田川', '07', '07422', '9693553', '福島県', 'フクシマケン', '河沼郡湯川村', 'カワヌマグンユガワムラ', '田川', 'タガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡湯川村熊ノ目', '07', '07422', '9693554', '福島県', 'フクシマケン', '河沼郡湯川村', 'カワヌマグンユガワムラ', '熊ノ目', 'クマノメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡湯川村佐野目', '07', '07422', '9693555', '福島県', 'フクシマケン', '河沼郡湯川村', 'カワヌマグンユガワムラ', '佐野目', 'サノメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡湯川村勝常', '07', '07422', '9693556', '福島県', 'フクシマケン', '河沼郡湯川村', 'カワヌマグンユガワムラ', '勝常', 'ショウジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市山都町小舟寺', '07', '07208', '9694101', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '山都町小舟寺', 'ヤマトマチコフナジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市山都町一川', '07', '07208', '9694102', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '山都町一川', 'ヤマトマチイチカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市山都町木幡', '07', '07208', '9694103', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '山都町木幡', 'ヤマトマチコハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市山都町蓬莱', '07', '07208', '9694104', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '山都町蓬莱', 'ヤマトマチホウライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市山都町三津合', '07', '07208', '9694105', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '山都町三津合', 'ヤマトマチミツアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市山都町朝倉', '07', '07208', '9694106', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '山都町朝倉', 'ヤマトマチアサクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市山都町相川', '07', '07208', '9694107', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '山都町相川', 'ヤマトマチアイカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市山都町一ノ木', '07', '07208', '9694108', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '山都町一ノ木', 'ヤマトマチイチノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市山都町早稲谷', '07', '07208', '9694109', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '山都町早稲谷', 'ヤマトマチワセタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市山都町蔵ノ後', '07', '07208', '9694111', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '山都町蔵ノ後', 'ヤマトマチクラノアト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市山都町上ノ原道東', '07', '07208', '9694112', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '山都町上ノ原道東', 'ヤマトマチウエノハラミチヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市山都町上ノ原道西', '07', '07208', '9694113', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '山都町上ノ原道西', 'ヤマトマチウエノハラミチニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市山都町小山', '07', '07208', '9694114', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '山都町小山', 'ヤマトマチコヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市山都町五十苅', '07', '07208', '9694115', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '山都町五十苅', 'ヤマトマチゴジュウカリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市山都町清水上', '07', '07208', '9694116', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '山都町清水上', 'ヤマトマチシミズカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市山都町清水尻', '07', '07208', '9694117', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '山都町清水尻', 'ヤマトマチシミズジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市山都町古屋敷', '07', '07208', '9694118', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '山都町古屋敷', 'ヤマトマチフルヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市山都町江戸塚', '07', '07208', '9694119', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '山都町江戸塚', 'ヤマトマチエドツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市山都町太田', '07', '07208', '9694121', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '山都町太田', 'ヤマトマチオオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市山都町木曽', '07', '07208', '9694122', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '山都町木曽', 'ヤマトマチキソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市山都町中新田', '07', '07208', '9694123', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '山都町中新田', 'ヤマトマチナカシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市山都町墓ノ後', '07', '07208', '9694124', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '山都町墓ノ後', 'ヤマトマチハカノアト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市山都町弥左エ門田', '07', '07208', '9694125', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '山都町弥左エ門田', 'ヤマトマチヤザエモンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市山都町馬放場', '07', '07208', '9694126', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '山都町馬放場', 'ヤマトマチウマハナシバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市山都町久祢花', '07', '07208', '9694127', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '山都町久祢花', 'ヤマトマチクヤバナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市山都町広野', '07', '07208', '9694131', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '山都町広野', 'ヤマトマチヒロノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市山都町三ノ宮', '07', '07208', '9694132', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '山都町三ノ宮', 'ヤマトマチサンノミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市山都町広葎田', '07', '07208', '9694133', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '山都町広葎田', 'ヤマトマチヒロムクロダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市山都町葎田', '07', '07208', '9694134', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '山都町葎田', 'ヤマトマチムクロダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市山都町広中新田', '07', '07208', '9694135', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '山都町広中新田', 'ヤマトマチヒロナカシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市山都町町尻', '07', '07208', '9694136', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '山都町町尻', 'ヤマトマチマチジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市山都町中野', '07', '07208', '9694137', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '山都町中野', 'ヤマトマチナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市山都町蛇崩', '07', '07208', '9694138', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '山都町蛇崩', 'ヤマトマチジャクズレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市山都町北松ノ前', '07', '07208', '9694139', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '山都町北松ノ前', 'ヤマトマチキタマツノマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市山都町田向', '07', '07208', '9694141', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '山都町田向', 'ヤマトマチタムカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市山都町七十苅', '07', '07208', '9694142', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '山都町七十苅', 'ヤマトマチナナジュウガリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市山都町沢田', '07', '07208', '9694143', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '山都町沢田', 'ヤマトマチサワタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市山都町殿戸', '07', '07208', '9694144', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '山都町殿戸', 'ヤマトマチトノト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市山都町西原', '07', '07208', '9694145', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '山都町西原', 'ヤマトマチニシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市山都町広古屋敷', '07', '07208', '9694146', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '山都町広古屋敷', 'ヤマトマチヒロコヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市山都町石堀古', '07', '07208', '9694147', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '山都町石堀古', 'ヤマトマチイシボツコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市山都町岩渕', '07', '07208', '9694148', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '山都町岩渕', 'ヤマトマチイワブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市山都町谷地', '07', '07208', '9694149', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '山都町谷地', 'ヤマトマチヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市山都町大山中', '07', '07208', '9694151', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '山都町大山中', 'ヤマトマチオオヤマナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市山都町上ノ山平', '07', '07208', '9694152', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '山都町上ノ山平', 'ヤマトマチウエノヤマタイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市山都町下殿戸', '07', '07208', '9694153', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '山都町下殿戸', 'ヤマトマチシモトノト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市山都町舘原', '07', '07208', '9694154', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '山都町舘原', 'ヤマトマチタテノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市山都町入海', '07', '07208', '9694155', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '山都町入海', 'ヤマトマチイリウミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市山都町西川', '07', '07208', '9694156', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '山都町西川', 'ヤマトマチニシカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市山都町小松', '07', '07208', '9694157', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '山都町小松', 'ヤマトマチコマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市山都町中石打場', '07', '07208', '9694161', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '山都町中石打場', 'ヤマトマチナカイシウチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市山都町上新田', '07', '07208', '9694162', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '山都町上新田', 'ヤマトマチカミシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市山都町下石打場', '07', '07208', '9694163', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '山都町下石打場', 'ヤマトマチシモイシウチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市山都町上石打場', '07', '07208', '9694164', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '山都町上石打場', 'ヤマトマチカミイシウチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市山都町三ツ山', '07', '07208', '9694165', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '山都町三ツ山', 'ヤマトマチミツヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市山都町沢尻', '07', '07208', '9694166', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '山都町沢尻', 'ヤマトマチサワジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市山都町大林', '07', '07208', '9694167', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '山都町大林', 'ヤマトマチオオバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市高郷町上郷', '07', '07208', '9694301', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '高郷町上郷', 'タカサトマチカミゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市高郷町峯', '07', '07208', '9694302', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '高郷町峯', 'タカサトマチミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市高郷町揚津', '07', '07208', '9694303', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '高郷町揚津', 'タカサトマチアガツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市高郷町磐見', '07', '07208', '9694304', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '高郷町磐見', 'タカサトマチイワミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市高郷町西羽賀', '07', '07208', '9694311', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '高郷町西羽賀', 'タカサトマチニシハガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市高郷町池ノ原', '07', '07208', '9694312', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '高郷町池ノ原', 'タカサトマチイケノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市高郷町塩坪', '07', '07208', '9694313', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '高郷町塩坪', 'タカサトマチシオツボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市高郷町川井', '07', '07208', '9694314', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '高郷町川井', 'タカサトマチカワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市高郷町夏井', '07', '07208', '9694315', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '高郷町夏井', 'タカサトマチナツイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県喜多方市高郷町大田賀', '07', '07208', '9694316', '福島県', 'フクシマケン', '喜多方市', 'キタカタシ', '高郷町大田賀', 'タカサトマチオオタガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡西会津町', '07', '07405', '9694400', '福島県', 'フクシマケン', '耶麻郡西会津町', 'ヤマグンニシアイヅマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('138765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡西会津町登世島', '07', '07405', '9694401', '福島県', 'フクシマケン', '耶麻郡西会津町', 'ヤマグンニシアイヅマチ', '登世島', 'トセジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡西会津町尾野本', '07', '07405', '9694402', '福島県', 'フクシマケン', '耶麻郡西会津町', 'ヤマグンニシアイヅマチ', '尾野本', 'オノモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡西会津町束松', '07', '07405', '9694403', '福島県', 'フクシマケン', '耶麻郡西会津町', 'ヤマグンニシアイヅマチ', '束松', 'タバネマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡西会津町睦合', '07', '07405', '9694404', '福島県', 'フクシマケン', '耶麻郡西会津町', 'ヤマグンニシアイヅマチ', '睦合', 'ムツアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡西会津町下谷', '07', '07405', '9694405', '福島県', 'フクシマケン', '耶麻郡西会津町', 'ヤマグンニシアイヅマチ', '下谷', 'シタタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡西会津町野沢', '07', '07405', '9694406', '福島県', 'フクシマケン', '耶麻郡西会津町', 'ヤマグンニシアイヅマチ', '野沢', 'ノザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡西会津町群岡', '07', '07405', '9694511', '福島県', 'フクシマケン', '耶麻郡西会津町', 'ヤマグンニシアイヅマチ', '群岡', 'ムラオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡西会津町上野尻', '07', '07405', '9694512', '福島県', 'フクシマケン', '耶麻郡西会津町', 'ヤマグンニシアイヅマチ', '上野尻', 'カミノジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡西会津町宝坂屋敷', '07', '07405', '9694513', '福島県', 'フクシマケン', '耶麻郡西会津町', 'ヤマグンニシアイヅマチ', '宝坂屋敷', 'ホウサカヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡西会津町宝坂宝坂', '07', '07405', '9694514', '福島県', 'フクシマケン', '耶麻郡西会津町', 'ヤマグンニシアイヅマチ', '宝坂宝坂', 'ホウサカホウサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡西会津町下野尻', '07', '07405', '9694515', '福島県', 'フクシマケン', '耶麻郡西会津町', 'ヤマグンニシアイヅマチ', '下野尻', 'シモノジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡西会津町新郷冨士', '07', '07405', '9694621', '福島県', 'フクシマケン', '耶麻郡西会津町', 'ヤマグンニシアイヅマチ', '新郷冨士', 'シンゴウフジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡西会津町新郷笹川', '07', '07405', '9694622', '福島県', 'フクシマケン', '耶麻郡西会津町', 'ヤマグンニシアイヅマチ', '新郷笹川', 'シンゴウササガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡西会津町新郷豊洲', '07', '07405', '9694623', '福島県', 'フクシマケン', '耶麻郡西会津町', 'ヤマグンニシアイヅマチ', '新郷豊洲', 'シンゴウトヨス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡西会津町新郷三河', '07', '07405', '9694624', '福島県', 'フクシマケン', '耶麻郡西会津町', 'ヤマグンニシアイヅマチ', '新郷三河', 'シンゴウミカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡西会津町奥川飯根', '07', '07405', '9694731', '福島県', 'フクシマケン', '耶麻郡西会津町', 'ヤマグンニシアイヅマチ', '奥川飯根', 'オクガワイイネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡西会津町奥川飯沢', '07', '07405', '9694732', '福島県', 'フクシマケン', '耶麻郡西会津町', 'ヤマグンニシアイヅマチ', '奥川飯沢', 'オクガワイイザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡西会津町奥川大綱木', '07', '07405', '9694733', '福島県', 'フクシマケン', '耶麻郡西会津町', 'ヤマグンニシアイヅマチ', '奥川大綱木', 'オクガワオオツナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡西会津町奥川飯里', '07', '07405', '9694734', '福島県', 'フクシマケン', '耶麻郡西会津町', 'ヤマグンニシアイヅマチ', '奥川飯里', 'オクガワイイサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡西会津町奥川豊島', '07', '07405', '9694735', '福島県', 'フクシマケン', '耶麻郡西会津町', 'ヤマグンニシアイヅマチ', '奥川豊島', 'オクガワトヨシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡西会津町奥川元島', '07', '07405', '9694736', '福島県', 'フクシマケン', '耶麻郡西会津町', 'ヤマグンニシアイヅマチ', '奥川元島', 'オクガワモトシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県耶麻郡西会津町奥川高陽根', '07', '07405', '9694737', '福島県', 'フクシマケン', '耶麻郡西会津町', 'ヤマグンニシアイヅマチ', '奥川高陽根', 'オクガワカヤネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市大戸町石村', '07', '07202', '9695111', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '大戸町石村', 'オオトマチイシムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市大戸町下雨屋', '07', '07202', '9695112', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '大戸町下雨屋', 'オオトマチシモアマヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市大戸町宮内', '07', '07202', '9695113', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '大戸町宮内', 'オオトマチミヤウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市大戸町上雨屋', '07', '07202', '9695114', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '大戸町上雨屋', 'オオトマチカミアマヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市大戸町上三寄南原', '07', '07202', '9695121', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '大戸町上三寄南原', 'オオトマチカミミヨリミナミハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市大戸町上三寄乙', '07', '07202', '9695122', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '大戸町上三寄乙', 'オオトマチカミミヨリオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市大戸町上三寄香塩', '07', '07202', '9695122', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '大戸町上三寄香塩', 'オオトマチカミミヨリカシュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市大戸町上三寄大豆田', '07', '07202', '9695123', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '大戸町上三寄大豆田', 'オオトマチカミミヨリオオマメタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市大戸町上三寄丙', '07', '07202', '9695123', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '大戸町上三寄丙', 'オオトマチカミミヨリヘイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市大戸町高川', '07', '07202', '9695131', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '大戸町高川', 'オオトマチタカガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市大戸町上小塩', '07', '07202', '9695132', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '大戸町上小塩', 'オオトマチカミオシュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市大戸町大川', '07', '07202', '9695133', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '大戸町大川', 'オオトマチオオカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市大戸町小谷川端', '07', '07202', '9695141', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '大戸町小谷川端', 'オオトマチオヤカワバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市大戸町小谷坂下', '07', '07202', '9695142', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '大戸町小谷坂下', 'オオトマチオヤサカノシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市大戸町小谷原', '07', '07202', '9695143', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '大戸町小谷原', 'オオトマチオヤハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市大戸町小谷西村', '07', '07202', '9695144', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '大戸町小谷西村', 'オオトマチオヤニシムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市大戸町小谷平沢', '07', '07202', '9695145', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '大戸町小谷平沢', 'オオトマチオヤヒラサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市大戸町小谷湯ノ平', '07', '07202', '9695146', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '大戸町小谷湯ノ平', 'オオトマチオヤユノダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市大戸町芦牧', '07', '07202', '9695147', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '大戸町芦牧', 'オオトマチアシノマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡下郷町高陦', '07', '07362', '9695201', '福島県', 'フクシマケン', '南会津郡下郷町', 'ミナミアイヅグンシモゴウマチ', '高陦', 'タカシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡下郷町枝松', '07', '07362', '9695202', '福島県', 'フクシマケン', '南会津郡下郷町', 'ミナミアイヅグンシモゴウマチ', '枝松', 'エダマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡下郷町白岩', '07', '07362', '9695203', '福島県', 'フクシマケン', '南会津郡下郷町', 'ミナミアイヅグンシモゴウマチ', '白岩', 'シライワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡下郷町弥五島', '07', '07362', '9695204', '福島県', 'フクシマケン', '南会津郡下郷町', 'ミナミアイヅグンシモゴウマチ', '弥五島', 'ヤゴシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡下郷町大沢', '07', '07362', '9695205', '福島県', 'フクシマケン', '南会津郡下郷町', 'ミナミアイヅグンシモゴウマチ', '大沢', 'オオサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡下郷町湯野上', '07', '07362', '9695206', '福島県', 'フクシマケン', '南会津郡下郷町', 'ミナミアイヅグンシモゴウマチ', '湯野上', 'ユノカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡下郷町大内', '07', '07362', '9695207', '福島県', 'フクシマケン', '南会津郡下郷町', 'ミナミアイヅグンシモゴウマチ', '大内', 'オオウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡下郷町小沼崎', '07', '07362', '9695208', '福島県', 'フクシマケン', '南会津郡下郷町', 'ミナミアイヅグンシモゴウマチ', '小沼崎', 'オヌマザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡下郷町', '07', '07362', '9695300', '福島県', 'フクシマケン', '南会津郡下郷町', 'ミナミアイヅグンシモゴウマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('138816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡下郷町豊成', '07', '07362', '9695311', '福島県', 'フクシマケン', '南会津郡下郷町', 'ミナミアイヅグンシモゴウマチ', '豊成', 'トヨナリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡下郷町戸赤', '07', '07362', '9695312', '福島県', 'フクシマケン', '南会津郡下郷町', 'ミナミアイヅグンシモゴウマチ', '戸赤', 'トアカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡下郷町原', '07', '07362', '9695313', '福島県', 'フクシマケン', '南会津郡下郷町', 'ミナミアイヅグンシモゴウマチ', '原', 'ハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡下郷町日影', '07', '07362', '9695314', '福島県', 'フクシマケン', '南会津郡下郷町', 'ミナミアイヅグンシモゴウマチ', '日影', 'ヒカゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡下郷町荒石', '07', '07362', '9695315', '福島県', 'フクシマケン', '南会津郡下郷町', 'ミナミアイヅグンシモゴウマチ', '荒石', 'アライシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡下郷町石井', '07', '07362', '9695316', '福島県', 'フクシマケン', '南会津郡下郷町', 'ミナミアイヅグンシモゴウマチ', '石井', 'イシイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡下郷町志源行', '07', '07362', '9695317', '福島県', 'フクシマケン', '南会津郡下郷町', 'ミナミアイヅグンシモゴウマチ', '志源行', 'シゲンギョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡下郷町磯上', '07', '07362', '9695318', '福島県', 'フクシマケン', '南会津郡下郷町', 'ミナミアイヅグンシモゴウマチ', '磯上', 'イソガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡下郷町沢口', '07', '07362', '9695321', '福島県', 'フクシマケン', '南会津郡下郷町', 'ミナミアイヅグンシモゴウマチ', '沢口', 'サワグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡下郷町領毛', '07', '07362', '9695322', '福島県', 'フクシマケン', '南会津郡下郷町', 'ミナミアイヅグンシモゴウマチ', '領毛', 'リョウゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡下郷町桑取火', '07', '07362', '9695323', '福島県', 'フクシマケン', '南会津郡下郷町', 'ミナミアイヅグンシモゴウマチ', '桑取火', 'クワトビ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡下郷町安張', '07', '07362', '9695324', '福島県', 'フクシマケン', '南会津郡下郷町', 'ミナミアイヅグンシモゴウマチ', '安張', 'ヤスハリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡下郷町中山', '07', '07362', '9695325', '福島県', 'フクシマケン', '南会津郡下郷町', 'ミナミアイヅグンシモゴウマチ', '中山', 'ナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡下郷町栄富', '07', '07362', '9695326', '福島県', 'フクシマケン', '南会津郡下郷町', 'ミナミアイヅグンシモゴウマチ', '栄富', 'エイトミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡下郷町澳田', '07', '07362', '9695331', '福島県', 'フクシマケン', '南会津郡下郷町', 'ミナミアイヅグンシモゴウマチ', '澳田', 'イクタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡下郷町中妻', '07', '07362', '9695332', '福島県', 'フクシマケン', '南会津郡下郷町', 'ミナミアイヅグンシモゴウマチ', '中妻', 'ナカツマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡下郷町合川', '07', '07362', '9695333', '福島県', 'フクシマケン', '南会津郡下郷町', 'ミナミアイヅグンシモゴウマチ', '合川', 'アイカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡下郷町大松川', '07', '07362', '9695334', '福島県', 'フクシマケン', '南会津郡下郷町', 'ミナミアイヅグンシモゴウマチ', '大松川', 'オオマツカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡下郷町南倉沢', '07', '07362', '9695335', '福島県', 'フクシマケン', '南会津郡下郷町', 'ミナミアイヅグンシモゴウマチ', '南倉沢', 'ナグラサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡下郷町野際新田', '07', '07362', '9695341', '福島県', 'フクシマケン', '南会津郡下郷町', 'ミナミアイヅグンシモゴウマチ', '野際新田', 'ノギワシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡下郷町音金', '07', '07362', '9695342', '福島県', 'フクシマケン', '南会津郡下郷町', 'ミナミアイヅグンシモゴウマチ', '音金', 'オトカネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡下郷町落合', '07', '07362', '9695343', '福島県', 'フクシマケン', '南会津郡下郷町', 'ミナミアイヅグンシモゴウマチ', '落合', 'オチアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡下郷町沢田', '07', '07362', '9695344', '福島県', 'フクシマケン', '南会津郡下郷町', 'ミナミアイヅグンシモゴウマチ', '沢田', 'サワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南会津郡下郷町塩生', '07', '07362', '9695345', '福島県', 'フクシマケン', '南会津郡下郷町', 'ミナミアイヅグンシモゴウマチ', '塩生', 'シオノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市北会津町天満', '07', '07202', '9696001', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '北会津町天満', 'キタアイヅマチテンマン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市北会津町麻生新田', '07', '07202', '9696002', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '北会津町麻生新田', 'キタアイヅマチアソウシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市北会津町西麻生', '07', '07202', '9696003', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '北会津町西麻生', 'キタアイヅマチニシアソウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市北会津町古麻生', '07', '07202', '9696004', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '北会津町古麻生', 'キタアイヅマチフルアソウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市北会津町松野', '07', '07202', '9696005', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '北会津町松野', 'キタアイヅマチマツノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市北会津町新在家', '07', '07202', '9696006', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '北会津町新在家', 'キタアイヅマチシンザイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市北会津町北後庵', '07', '07202', '9696007', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '北会津町北後庵', 'キタアイヅマチキタゴアン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市北会津町大島', '07', '07202', '9696008', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '北会津町大島', 'キタアイヅマチオオシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市北会津町西後庵', '07', '07202', '9696011', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '北会津町西後庵', 'キタアイヅマチニシゴアン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市北会津町金屋', '07', '07202', '9696012', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '北会津町金屋', 'キタアイヅマチカナヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市北会津町下野', '07', '07202', '9696013', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '北会津町下野', 'キタアイヅマチシモノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市北会津町水季の里', '07', '07202', '9696015', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '北会津町水季の里', 'キタアイヅマチミズキノサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町舘ノ廻甲', '07', '07447', '9696021', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '舘ノ廻甲', 'タテノマワリコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町大道上甲', '07', '07447', '9696022', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '大道上甲', 'オオミチカミコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町近右エ門田', '07', '07447', '9696023', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '近右エ門田', 'コンウエモンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町川原町北甲', '07', '07447', '9696024', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '川原町北甲', 'カワラチョウキタコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町権現堂甲', '07', '07447', '9696025', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '権現堂甲', 'ゴンゲンドウコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町本郷前川原甲', '07', '07447', '9696026', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '本郷前川原甲', 'ホンゴウマエカワハラコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町荒井甲', '07', '07447', '9696027', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '荒井甲', 'アライコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町旱泥甲', '07', '07447', '9696028', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '旱泥甲', 'ヒドロコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町三本松甲', '07', '07447', '9696029', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '三本松甲', 'サンボンマツコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町広面', '07', '07447', '9696031', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '広面', 'ヒロヅラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町竹原', '07', '07447', '9696032', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '竹原', 'タケハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町堰向', '07', '07447', '9696033', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '堰向', 'セキムカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町堰向甲', '07', '07447', '9696034', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '堰向甲', 'セキムカイコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町中樋', '07', '07447', '9696035', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '中樋', 'ナカトイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町上野川原', '07', '07447', '9696036', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '上野川原', 'ウエノカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町家西甲', '07', '07447', '9696037', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '家西甲', 'イエニシコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町御用地甲', '07', '07447', '9696038', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '御用地甲', 'ゴヨウチコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町川原町', '07', '07447', '9696041', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '川原町', 'カワラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町瀬戸町甲', '07', '07447', '9696042', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '瀬戸町甲', 'セトマチコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町松原際甲', '07', '07447', '9696043', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '松原際甲', 'マツバラギワコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町瀬戸屋前', '07', '07447', '9696044', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '瀬戸屋前', 'セトヤマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町北浦甲', '07', '07447', '9696045', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '北浦甲', 'キタウラコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町石切畑甲', '07', '07447', '9696046', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '石切畑甲', 'イシキリバタコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町北川原甲', '07', '07447', '9696047', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '北川原甲', 'キタガワラコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町思堀', '07', '07447', '9696051', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '思堀', 'オモイボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町黒川', '07', '07447', '9696052', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '黒川', 'クロカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町仲塚甲', '07', '07447', '9696053', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '仲塚甲', 'ナカヅカコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町惣印南', '07', '07447', '9696054', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '惣印南', 'ソウインミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町惣印甲', '07', '07447', '9696055', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '惣印甲', 'ソウインコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町惣印東', '07', '07447', '9696056', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '惣印東', 'ソウインヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町大川端甲', '07', '07447', '9696057', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '大川端甲', 'オオカワバタコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町的場甲', '07', '07447', '9696058', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '的場甲', 'マトバコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町六日町甲', '07', '07447', '9696059', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '六日町甲', 'ムイカマチコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町上町甲', '07', '07447', '9696061', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '上町甲', 'ウワマチコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町御用地', '07', '07447', '9696062', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '御用地', 'ゴヨウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町御用地跡甲', '07', '07447', '9696063', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '御用地跡甲', 'ゴヨウチアトコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町向川原', '07', '07447', '9696064', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '向川原', 'ムカイガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町本郷入口道上甲', '07', '07447', '9696065', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '本郷入口道上甲', 'ホンゴウイリグチミチウエコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町本郷入口中道上甲', '07', '07447', '9696066', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '本郷入口中道上甲', 'ホンゴウイリグチナカミチウエコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町梁場上甲', '07', '07447', '9696067', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '梁場上甲', 'ヤナバカミコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町車川原甲', '07', '07447', '9696068', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '車川原甲', 'クルマガワラコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町船場甲', '07', '07447', '9696069', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '船場甲', 'フナバコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町本郷上', '07', '07447', '9696071', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '本郷上', 'ホンゴウカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町真々川甲', '07', '07447', '9696072', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '真々川甲', 'ママカワコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町寺ノ前甲', '07', '07447', '9696073', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '寺ノ前甲', 'テラノマエコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町中道下甲', '07', '07447', '9696074', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '中道下甲', 'ナカミチシタコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町本郷道東', '07', '07447', '9696075', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '本郷道東', 'ホンゴウミチヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町本郷道東甲', '07', '07447', '9696076', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '本郷道東甲', 'ホンゴウミチヒガシコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町東谷地甲', '07', '07447', '9696077', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '東谷地甲', 'ヒガシヤチコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町蛭ケ窪', '07', '07447', '9696078', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '蛭ケ窪', 'ヒルガクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町三日町甲', '07', '07447', '9696079', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '三日町甲', 'ミッカマチコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町三日町上', '07', '07447', '9696081', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '三日町上', 'ミッカマチウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町三日町上甲', '07', '07447', '9696082', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '三日町上甲', 'ミッカマチウエコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町三日町道上甲', '07', '07447', '9696083', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '三日町道上甲', 'ミッカマチミチウエコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町本郷高田町甲', '07', '07447', '9696084', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '本郷高田町甲', 'ホンゴウタカダマチコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町西谷地', '07', '07447', '9696085', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '西谷地', 'ニシヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町西谷地甲', '07', '07447', '9696086', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '西谷地甲', 'ニシヤチコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町本郷道西', '07', '07447', '9696087', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '本郷道西', 'ホンゴウミチニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町駅前', '07', '07447', '9696101', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '駅前', 'エキマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町思堀向', '07', '07447', '9696102', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '思堀向', 'オモイボリムカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町上村北', '07', '07447', '9696103', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '上村北', 'カミムラキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町上村西道上', '07', '07447', '9696104', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '上村西道上', 'カミムラニシミチカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町上村西道下', '07', '07447', '9696104', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '上村西道下', 'カミムラニシミチシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町上村東', '07', '07447', '9696105', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '上村東', 'カミムラヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町上村南', '07', '07447', '9696105', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '上村南', 'カミムラミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町黒川内', '07', '07447', '9696106', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '黒川内', 'クロカワウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町新用地', '07', '07447', '9696107', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '新用地', 'シンヨウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町堰下', '07', '07447', '9696108', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '堰下', 'セキシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町宗頤町', '07', '07447', '9696109', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '宗頤町', 'ソウエンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町家西', '07', '07447', '9696111', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '家西', 'イエニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町家東甲', '07', '07447', '9696112', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '家東甲', 'イエヒガシコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町車川原', '07', '07447', '9696113', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '車川原', 'クルマガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町御用地跡', '07', '07447', '9696114', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '御用地跡', 'ゴヨウチアト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町新町', '07', '07447', '9696115', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '新町', 'シンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町瀬戸町', '07', '07447', '9696116', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '瀬戸町', 'セトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町本郷入口道上', '07', '07447', '9696117', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '本郷入口道上', 'ホンゴウイリクチミチカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町仲塚', '07', '07447', '9696118', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '仲塚', 'ナカツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町向川原甲', '07', '07447', '9696118', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '向川原甲', 'ムカイカワハラコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町梁場上', '07', '07447', '9696119', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '梁場上', 'ヤナバカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町延命寺前', '07', '07447', '9696121', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '延命寺前', 'エンメイジマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町寺ノ前', '07', '07447', '9696122', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '寺ノ前', 'テラノマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町中道下', '07', '07447', '9696123', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '中道下', 'ナカミチシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町東谷地', '07', '07447', '9696124', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '東谷地', 'ヒガシヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町本郷', '07', '07447', '9696125', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '本郷', 'ホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町本郷甲', '07', '07447', '9696126', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '本郷甲', 'ホンゴウコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町本郷上甲', '07', '07447', '9696127', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '本郷上甲', 'ホンゴウカミコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町真々川', '07', '07447', '9696128', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '真々川', 'ママカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町本郷道西甲', '07', '07447', '9696129', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '本郷道西甲', 'ホンゴウミチニシコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町大石', '07', '07447', '9696131', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '大石', 'オオイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町本郷高田町', '07', '07447', '9696132', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '本郷高田町', 'ホンゴウタカダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町船場', '07', '07447', '9696133', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '船場', 'フナバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町三日町', '07', '07447', '9696134', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '三日町', 'ミッカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町穂馬', '07', '07447', '9696135', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '穂馬', 'ホマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町大八郷', '07', '07447', '9696141', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '大八郷', 'オオハチゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町村上', '07', '07447', '9696142', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '村上', 'ムラカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町氷玉', '07', '07447', '9696143', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '氷玉', 'ヒダマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町福重岡', '07', '07447', '9696144', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '福重岡', 'フクエオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町山南', '07', '07447', '9696145', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '山南', 'ヤマミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町横堀下', '07', '07447', '9696146', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '横堀下', 'ヨコボリシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町石切畑', '07', '07447', '9696151', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '石切畑', 'イシキリバタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町川原町甲', '07', '07447', '9696152', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '川原町甲', 'カワラチョウコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町北浦', '07', '07447', '9696154', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '北浦', 'キタウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町北川原', '07', '07447', '9696155', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '北川原', 'キタガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町瀬戸屋前甲', '07', '07447', '9696156', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '瀬戸屋前甲', 'セトヤマエコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町本屋敷', '07', '07447', '9696157', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '本屋敷', 'モトヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町松原際', '07', '07447', '9696158', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '松原際', 'マツバラキワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町川原町北', '07', '07447', '9696159', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '川原町北', 'カワハラチョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町荒井前', '07', '07447', '9696161', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '荒井前', 'アライマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町杉', '07', '07447', '9696162', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '杉', 'スギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町黒沢', '07', '07447', '9696163', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '黒沢', 'クロサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町本郷道上', '07', '07447', '9696164', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '本郷道上', 'ホンゴウミチカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町山道下', '07', '07447', '9696165', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '山道下', 'ヤマミチシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町下川原', '07', '07447', '9696166', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '下川原', 'シモガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町荒井', '07', '07447', '9696171', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '荒井', 'アライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町本郷村西', '07', '07447', '9696172', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '本郷村西', 'ホンゴウムラニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町大道上', '07', '07447', '9696173', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '大道上', 'オオミチカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町権現堂', '07', '07447', '9696174', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '権現堂', 'ゴンゲンドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町舘ノ廻', '07', '07447', '9696175', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '舘ノ廻', 'タテノマワリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町旱泥', '07', '07447', '9696176', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '旱泥', 'ヒドロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町本郷前川原', '07', '07447', '9696177', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '本郷前川原', 'ホンゴウマエカワハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市北会津町両堂', '07', '07202', '9696180', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '北会津町両堂', 'キタアイヅマチリョウドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市北会津町柏原', '07', '07202', '9696182', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '北会津町柏原', 'キタアイヅマチカシワバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市北会津町上米塚', '07', '07202', '9696183', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '北会津町上米塚', 'キタアイヅマチカミヨネヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市北会津町三本松', '07', '07202', '9696184', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '北会津町三本松', 'キタアイヅマチサンボンマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市北会津町下米塚', '07', '07202', '9696185', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '北会津町下米塚', 'キタアイヅマチシモヨネヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市北会津町古館', '07', '07202', '9696186', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '北会津町古館', 'キタアイヅマチフルダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市北会津町東小松', '07', '07202', '9696188', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '北会津町東小松', 'キタアイヅマチヒガシコマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県会津若松市北会津町小松', '07', '07202', '9696189', '福島県', 'フクシマケン', '会津若松市', 'アイヅワカマツシ', '北会津町小松', 'キタアイヅマチコマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町', '07', '07447', '9696200', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('138984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町安田', '07', '07447', '9696201', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '安田', 'ヤスダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町安田乙', '07', '07447', '9696201', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '安田乙', 'ヤスダオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町高田村東', '07', '07447', '9696202', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '高田村東', 'タカダムラヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町村前', '07', '07447', '9696202', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '村前', 'ムラマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町高田前川原', '07', '07447', '9696203', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '高田前川原', 'タカダマエカワハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町水戸', '07', '07447', '9696203', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '水戸', 'ミト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町台ノ下', '07', '07447', '9696204', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '台ノ下', 'ダイノシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町宮ノ腰', '07', '07447', '9696204', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '宮ノ腰', 'ミヤノコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町御田', '07', '07447', '9696205', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '御田', 'オンタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町家ノ下', '07', '07447', '9696206', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '家ノ下', 'イエノシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町坂ノ下道上', '07', '07447', '9696206', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '坂ノ下道上', 'サカノシタミチウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町坂ノ下道下', '07', '07447', '9696206', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '坂ノ下道下', 'サカノシタミチシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町坂ノ下道下甲', '07', '07447', '9696206', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '坂ノ下道下甲', 'サカノシタミチシタコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町佐布川', '07', '07447', '9696206', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '佐布川', 'サブカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町高田中川原道下', '07', '07447', '9696206', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '高田中川原道下', 'タカダナカガワラミチシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('138999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町松木田', '07', '07447', '9696206', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '松木田', 'マツキダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町葭添', '07', '07447', '9696206', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '葭添', 'ヨシゾエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町宮里', '07', '07447', '9696207', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '宮里', 'ミヤザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町橋丸', '07', '07447', '9696211', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '橋丸', 'ハシマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町藤家館', '07', '07447', '9696212', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '藤家館', 'フジイエタテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町勝原', '07', '07447', '9696213', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '勝原', 'カツハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町冨川', '07', '07447', '9696214', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '冨川', 'トミカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町下堀', '07', '07447', '9696215', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '下堀', 'シモホリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町旭館端', '07', '07447', '9696221', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '旭館端', 'アサヒタテハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町旭市川', '07', '07447', '9696222', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '旭市川', 'アサヒイチカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町旭寺入', '07', '07447', '9696223', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '旭寺入', 'アサヒテライリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町旭無量', '07', '07447', '9696224', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '旭無量', 'アサヒムリョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町旭三寄', '07', '07447', '9696225', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '旭三寄', 'アサヒミヨセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町旭杉原', '07', '07447', '9696226', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '旭杉原', 'アサヒスギハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町尾岐窪', '07', '07447', '9696231', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '尾岐窪', 'オマタクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町東尾岐', '07', '07447', '9696232', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '東尾岐', 'ヒガシオマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町吉田', '07', '07447', '9696241', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '吉田', 'ヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町大室', '07', '07447', '9696242', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '大室', 'オオムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町宮川', '07', '07447', '9696243', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '宮川', 'ミヤカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町西尾', '07', '07447', '9696244', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '西尾', 'ニシオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町西本', '07', '07447', '9696245', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '西本', 'ニシモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町永井野', '07', '07447', '9696251', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '永井野', 'ナガイノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町松岸', '07', '07447', '9696252', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '松岸', 'マツキシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町杉屋', '07', '07447', '9696253', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '杉屋', 'スギヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町荻窪', '07', '07447', '9696254', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '荻窪', 'オギクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町松沢', '07', '07447', '9696255', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '松沢', 'マツザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町上戸原', '07', '07447', '9696256', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '上戸原', 'ジョウドハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町内川原', '07', '07447', '9696261', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '内川原', 'ウチカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町梅ノ木', '07', '07447', '9696261', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '梅ノ木', 'ウメノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町権現宮', '07', '07447', '9696261', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '権現宮', 'ゴンゲンミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町権現宮甲', '07', '07447', '9696261', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '権現宮甲', 'ゴンゲンミヤコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町権現宮南', '07', '07447', '9696261', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '権現宮南', 'ゴンゲンミヤミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町権現宮南甲', '07', '07447', '9696261', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '権現宮南甲', 'ゴンゲンミヤミナミコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町高田道上', '07', '07447', '9696261', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '高田道上', 'タカダミチウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町地尻', '07', '07447', '9696261', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '地尻', 'チジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町東川原', '07', '07447', '9696261', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '東川原', 'ヒガシカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町鹿島', '07', '07447', '9696262', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '鹿島', 'カシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町観音北', '07', '07447', '9696262', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '観音北', 'カンノンキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町外川原', '07', '07447', '9696262', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '外川原', 'ソトカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町外川原甲', '07', '07447', '9696262', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '外川原甲', 'ソトカワラコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町法憧寺北', '07', '07447', '9696262', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '法憧寺北', 'ホウドウジキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町法憧寺北甲', '07', '07447', '9696262', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '法憧寺北甲', 'ホウドウジキタコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町法憧寺東', '07', '07447', '9696262', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '法憧寺東', 'ホウドウジヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町法憧寺南', '07', '07447', '9696262', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '法憧寺南', 'ホウドウジミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町法憧寺南甲', '07', '07447', '9696262', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '法憧寺南甲', 'ホウドウジミナミコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町清竜寺北', '07', '07447', '9696263', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '清竜寺北', 'セイリュウジキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町宮北', '07', '07447', '9696263', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '宮北', 'ミヤキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町宮林', '07', '07447', '9696263', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '宮林', 'ミヤバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町宮林甲', '07', '07447', '9696263', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '宮林甲', 'ミヤバヤシコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町文珠西', '07', '07447', '9696263', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '文珠西', 'モンジュニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町文珠東', '07', '07447', '9696263', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '文珠東', 'モンジュヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町高田', '07', '07447', '9696264', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '高田', 'タカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町高田乙', '07', '07447', '9696264', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '高田乙', 'タカダオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町高田甲', '07', '07447', '9696264', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '高田甲', 'タカダコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町漆原北', '07', '07447', '9696265', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '漆原北', 'ウルシワラキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町御蔵南', '07', '07447', '9696265', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '御蔵南', 'オクラミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町川添', '07', '07447', '9696265', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '川添', 'カワゾエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町館南', '07', '07447', '9696265', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '館南', 'タテミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町長光寺南', '07', '07447', '9696265', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '長光寺南', 'チョウコウジミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町六地蔵', '07', '07447', '9696265', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '六地蔵', 'ロクジゾウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町油田', '07', '07447', '9696266', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '油田', 'アブラデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町新丁屋敷', '07', '07447', '9696266', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '新丁屋敷', 'シンチョウヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町館ノ越', '07', '07447', '9696266', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '館ノ越', 'タテノコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町西裏屋敷添', '07', '07447', '9696266', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '西裏屋敷添', 'ニシウラヤシキゾエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町布才地', '07', '07447', '9696266', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '布才地', 'フサイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町竜興寺北', '07', '07447', '9696266', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '竜興寺北', 'リュウコウジキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町新丁西', '07', '07447', '9696267', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '新丁西', 'シンチョウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町西裏', '07', '07447', '9696267', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '西裏', 'ニシウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町谷地', '07', '07447', '9696268', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '谷地', 'ヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町谷地前', '07', '07447', '9696268', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '谷地前', 'ヤチマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町柳台', '07', '07447', '9696268', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '柳台', 'ヤナギダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町柳台甲', '07', '07447', '9696268', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '柳台甲', 'ヤナギダイコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町寺崎', '07', '07447', '9696271', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '寺崎', 'テラサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町沼ノ上', '07', '07447', '9696271', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '沼ノ上', 'ヌマノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町赤留', '07', '07447', '9696272', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '赤留', 'アカル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町八木沢', '07', '07447', '9696273', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '八木沢', 'ヤギサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町雀林', '07', '07447', '9696274', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '雀林', 'スズメバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町杉甲', '07', '07447', '9696301', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '杉甲', 'スギコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町山道下甲', '07', '07447', '9696302', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '山道下甲', 'ヤマミチシタコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町山道上', '07', '07447', '9696303', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '山道上', 'ヤマミチカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町黒沢甲', '07', '07447', '9696304', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '黒沢甲', 'クロサワコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町延命寺前甲', '07', '07447', '9696305', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '延命寺前甲', 'エンメイジマエコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町延命寺前乙', '07', '07447', '9696306', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '延命寺前乙', 'エンメイジマエオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町石田甲', '07', '07447', '9696307', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '石田甲', 'イシダコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町清水台', '07', '07447', '9696311', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '清水台', 'シミズダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町清水台甲', '07', '07447', '9696312', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '清水台甲', 'シミズダイコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町下川原甲', '07', '07447', '9696313', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '下川原甲', 'シモカワラコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町清水川甲', '07', '07447', '9696314', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '清水川甲', 'シミズカワコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町蛇ノ宮甲', '07', '07447', '9696315', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '蛇ノ宮甲', 'ヘビノミヤコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町北原', '07', '07447', '9696316', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '北原', 'キタハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町北原甲', '07', '07447', '9696317', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '北原甲', 'キタハラコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町北原乙', '07', '07447', '9696318', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '北原乙', 'キタハラオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町丸山北', '07', '07447', '9696321', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '丸山北', 'マルヤマキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町丸山北甲', '07', '07447', '9696322', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '丸山北甲', 'マルヤマキタコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町丸山', '07', '07447', '9696323', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '丸山', 'マルヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町丸山乙', '07', '07447', '9696324', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '丸山乙', 'マルヤマオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町宮後', '07', '07447', '9696325', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '宮後', 'ミヤゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町宮後甲', '07', '07447', '9696326', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '宮後甲', 'ミヤゴコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町宮後乙', '07', '07447', '9696327', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '宮後乙', 'ミヤゴオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町山南乙', '07', '07447', '9696328', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '山南乙', 'ヤマミナミオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町本郷村西甲', '07', '07447', '9696331', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '本郷村西甲', 'ホンゴウムラニシコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町本郷村西乙', '07', '07447', '9696332', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '本郷村西乙', 'ホウンゴウムラニシオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町大八郷乙', '07', '07447', '9696333', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '大八郷乙', 'オオハチゴウオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町本郷村東乙', '07', '07447', '9696334', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '本郷村東乙', 'ホンゴウムラヒガシオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町村上乙', '07', '07447', '9696335', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '村上乙', 'ムラカミオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町本郷千苅', '07', '07447', '9696336', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '本郷千苅', 'ホンゴウセンガリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町本郷千苅乙', '07', '07447', '9696337', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '本郷千苅乙', 'ホンゴウセンガリオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町橋本乙', '07', '07447', '9696338', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '橋本乙', 'ハシモトオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町横堀下乙', '07', '07447', '9696341', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '横堀下乙', 'ヨコボリシタオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町倉田', '07', '07447', '9696342', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '倉田', 'クラタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町沖田', '07', '07447', '9696343', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '沖田', 'オキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町穴田', '07', '07447', '9696351', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '穴田', 'アナダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町穴田乙', '07', '07447', '9696352', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '穴田乙', 'アナダオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町堂ノ前', '07', '07447', '9696353', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '堂ノ前', 'ドウノマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町堂ノ前甲', '07', '07447', '9696354', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '堂ノ前甲', 'ドウノマエコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町西沖', '07', '07447', '9696355', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '西沖', 'ニシオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町稗田乙', '07', '07447', '9696356', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '稗田乙', 'ヒエダオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町和田目', '07', '07447', '9696401', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '和田目', 'ワダメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町新屋敷', '07', '07447', '9696402', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '新屋敷', 'シンヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町鶴野辺', '07', '07447', '9696403', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '鶴野辺', 'ツルノベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町境野', '07', '07447', '9696404', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '境野', 'サカイノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町米田', '07', '07447', '9696405', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '米田', 'ヨネタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町佐賀瀬川', '07', '07447', '9696406', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '佐賀瀬川', 'サカセガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町上平', '07', '07447', '9696407', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '上平', 'ウワダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町沼田', '07', '07447', '9696408', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '沼田', 'ヌマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町小沢', '07', '07447', '9696409', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '小沢', 'オザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡会津美里町立石田', '07', '07447', '9696411', '福島県', 'フクシマケン', '大沼郡会津美里町', 'オオヌマグンアイヅミサトマチ', '立石田', 'タチイシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡会津坂下町', '07', '07421', '9696500', '福島県', 'フクシマケン', '河沼郡会津坂下町', 'カワヌマグンアイヅバンゲマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('139129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡会津坂下町長井', '07', '07421', '9696501', '福島県', 'フクシマケン', '河沼郡会津坂下町', 'カワヌマグンアイヅバンゲマチ', '長井', 'ナガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡会津坂下町津尻', '07', '07421', '9696502', '福島県', 'フクシマケン', '河沼郡会津坂下町', 'カワヌマグンアイヅバンゲマチ', '津尻', 'ツジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡会津坂下町宇内', '07', '07421', '9696503', '福島県', 'フクシマケン', '河沼郡会津坂下町', 'カワヌマグンアイヅバンゲマチ', '宇内', 'ウナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡会津坂下町八日沢', '07', '07421', '9696504', '福島県', 'フクシマケン', '河沼郡会津坂下町', 'カワヌマグンアイヅバンゲマチ', '八日沢', 'ヨウカザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡会津坂下町新舘', '07', '07421', '9696505', '福島県', 'フクシマケン', '河沼郡会津坂下町', 'カワヌマグンアイヅバンゲマチ', '新舘', 'ニイダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡会津坂下町見明', '07', '07421', '9696506', '福島県', 'フクシマケン', '河沼郡会津坂下町', 'カワヌマグンアイヅバンゲマチ', '見明', 'ミミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡会津坂下町大上', '07', '07421', '9696507', '福島県', 'フクシマケン', '河沼郡会津坂下町', 'カワヌマグンアイヅバンゲマチ', '大上', 'オオカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡会津坂下町青木', '07', '07421', '9696511', '福島県', 'フクシマケン', '河沼郡会津坂下町', 'カワヌマグンアイヅバンゲマチ', '青木', 'アオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡会津坂下町沼越', '07', '07421', '9696512', '福島県', 'フクシマケン', '河沼郡会津坂下町', 'カワヌマグンアイヅバンゲマチ', '沼越', 'ヌマコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡会津坂下町立川', '07', '07421', '9696513', '福島県', 'フクシマケン', '河沼郡会津坂下町', 'カワヌマグンアイヅバンゲマチ', '立川', 'タチカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡会津坂下町五香', '07', '07421', '9696514', '福島県', 'フクシマケン', '河沼郡会津坂下町', 'カワヌマグンアイヅバンゲマチ', '五香', 'ゴカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡会津坂下町福原前', '07', '07421', '9696515', '福島県', 'フクシマケン', '河沼郡会津坂下町', 'カワヌマグンアイヅバンゲマチ', '福原前', 'フクハラマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡会津坂下町中泉', '07', '07421', '9696516', '福島県', 'フクシマケン', '河沼郡会津坂下町', 'カワヌマグンアイヅバンゲマチ', '中泉', 'ナカイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡会津坂下町合川', '07', '07421', '9696517', '福島県', 'フクシマケン', '河沼郡会津坂下町', 'カワヌマグンアイヅバンゲマチ', '合川', 'アイカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡会津坂下町青津', '07', '07421', '9696518', '福島県', 'フクシマケン', '河沼郡会津坂下町', 'カワヌマグンアイヅバンゲマチ', '青津', 'アオヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡会津坂下町御池田', '07', '07421', '9696519', '福島県', 'フクシマケン', '河沼郡会津坂下町', 'カワヌマグンアイヅバンゲマチ', '御池田', 'オイケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡会津坂下町三谷', '07', '07421', '9696519', '福島県', 'フクシマケン', '河沼郡会津坂下町', 'カワヌマグンアイヅバンゲマチ', '三谷', 'ミタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡会津坂下町金上', '07', '07421', '9696521', '福島県', 'フクシマケン', '河沼郡会津坂下町', 'カワヌマグンアイヅバンゲマチ', '金上', 'カナガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡会津坂下町宮古', '07', '07421', '9696522', '福島県', 'フクシマケン', '河沼郡会津坂下町', 'カワヌマグンアイヅバンゲマチ', '宮古', 'ミヤコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡会津坂下町海老細', '07', '07421', '9696523', '福島県', 'フクシマケン', '河沼郡会津坂下町', 'カワヌマグンアイヅバンゲマチ', '海老細', 'エビサイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡会津坂下町束原', '07', '07421', '9696524', '福島県', 'フクシマケン', '河沼郡会津坂下町', 'カワヌマグンアイヅバンゲマチ', '束原', 'ツカハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡会津坂下町開津', '07', '07421', '9696525', '福島県', 'フクシマケン', '河沼郡会津坂下町', 'カワヌマグンアイヅバンゲマチ', '開津', 'カイヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡会津坂下町五ノ併', '07', '07421', '9696526', '福島県', 'フクシマケン', '河沼郡会津坂下町', 'カワヌマグンアイヅバンゲマチ', '五ノ併', 'ゴノヘイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡会津坂下町福原', '07', '07421', '9696527', '福島県', 'フクシマケン', '河沼郡会津坂下町', 'カワヌマグンアイヅバンゲマチ', '福原', 'フクハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡会津坂下町新開津', '07', '07421', '9696528', '福島県', 'フクシマケン', '河沼郡会津坂下町', 'カワヌマグンアイヅバンゲマチ', '新開津', 'シンカイヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡会津坂下町上口', '07', '07421', '9696531', '福島県', 'フクシマケン', '河沼郡会津坂下町', 'カワヌマグンアイヅバンゲマチ', '上口', 'ジョウグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡会津坂下町東上口甲', '07', '07421', '9696531', '福島県', 'フクシマケン', '河沼郡会津坂下町', 'カワヌマグンアイヅバンゲマチ', '東上口甲', 'ヒガシジョウグチコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡会津坂下町東川前丙', '07', '07421', '9696532', '福島県', 'フクシマケン', '河沼郡会津坂下町', 'カワヌマグンアイヅバンゲマチ', '東川前丙', 'ヒガシカワマエヘイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡会津坂下町道下丙', '07', '07421', '9696532', '福島県', 'フクシマケン', '河沼郡会津坂下町', 'カワヌマグンアイヅバンゲマチ', '道下丙', 'ミチシタヘイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡会津坂下町上ノ台乙', '07', '07421', '9696533', '福島県', 'フクシマケン', '河沼郡会津坂下町', 'カワヌマグンアイヅバンゲマチ', '上ノ台乙', 'カミノダイオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡会津坂下町台ノ下', '07', '07421', '9696533', '福島県', 'フクシマケン', '河沼郡会津坂下町', 'カワヌマグンアイヅバンゲマチ', '台ノ下', 'ダイノシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡会津坂下町小川原', '07', '07421', '9696534', '福島県', 'フクシマケン', '河沼郡会津坂下町', 'カワヌマグンアイヅバンゲマチ', '小川原', 'オガワハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡会津坂下町北小川原乙', '07', '07421', '9696534', '福島県', 'フクシマケン', '河沼郡会津坂下町', 'カワヌマグンアイヅバンゲマチ', '北小川原乙', 'キタオガワハラオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡会津坂下町原道東甲', '07', '07421', '9696534', '福島県', 'フクシマケン', '河沼郡会津坂下町', 'カワヌマグンアイヅバンゲマチ', '原道東甲', 'ハラミチヒガシコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡会津坂下町家ノ前乙', '07', '07421', '9696535', '福島県', 'フクシマケン', '河沼郡会津坂下町', 'カワヌマグンアイヅバンゲマチ', '家ノ前乙', 'イエノマエオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡会津坂下町東屋敷添乙', '07', '07421', '9696535', '福島県', 'フクシマケン', '河沼郡会津坂下町', 'カワヌマグンアイヅバンゲマチ', '東屋敷添乙', 'ヒガシヤシキゾエオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡会津坂下町市中一番甲', '07', '07421', '9696536', '福島県', 'フクシマケン', '河沼郡会津坂下町', 'カワヌマグンアイヅバンゲマチ', '市中一番甲', 'イチナカ01バンコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡会津坂下町戌亥乙', '07', '07421', '9696537', '福島県', 'フクシマケン', '河沼郡会津坂下町', 'カワヌマグンアイヅバンゲマチ', '戌亥乙', 'イヌイオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡会津坂下町西ノ宮乙', '07', '07421', '9696537', '福島県', 'フクシマケン', '河沼郡会津坂下町', 'カワヌマグンアイヅバンゲマチ', '西ノ宮乙', 'ニシノミヤオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡会津坂下町姥ケ下乙', '07', '07421', '9696538', '福島県', 'フクシマケン', '河沼郡会津坂下町', 'カワヌマグンアイヅバンゲマチ', '姥ケ下乙', 'ウバガシタオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡会津坂下町上窪道北乙', '07', '07421', '9696538', '福島県', 'フクシマケン', '河沼郡会津坂下町', 'カワヌマグンアイヅバンゲマチ', '上窪道北乙', 'カミクボミチキタオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡会津坂下町上沼ノ上丙', '07', '07421', '9696538', '福島県', 'フクシマケン', '河沼郡会津坂下町', 'カワヌマグンアイヅバンゲマチ', '上沼ノ上丙', 'カミヌマノウエヘイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡会津坂下町古市乙', '07', '07421', '9696539', '福島県', 'フクシマケン', '河沼郡会津坂下町', 'カワヌマグンアイヅバンゲマチ', '古市乙', 'フルイチオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡会津坂下町上四十石甲', '07', '07421', '9696541', '福島県', 'フクシマケン', '河沼郡会津坂下町', 'カワヌマグンアイヅバンゲマチ', '上四十石甲', 'カミシジュツコクコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡会津坂下町四十石', '07', '07421', '9696541', '福島県', 'フクシマケン', '河沼郡会津坂下町', 'カワヌマグンアイヅバンゲマチ', '四十石', 'シジュツコク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡会津坂下町光明寺東甲', '07', '07421', '9696542', '福島県', 'フクシマケン', '河沼郡会津坂下町', 'カワヌマグンアイヅバンゲマチ', '光明寺東甲', 'コウミョウジヒガシコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡会津坂下町古屋敷甲', '07', '07421', '9696542', '福島県', 'フクシマケン', '河沼郡会津坂下町', 'カワヌマグンアイヅバンゲマチ', '古屋敷甲', 'フルヤシキコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡会津坂下町市中二番甲', '07', '07421', '9696543', '福島県', 'フクシマケン', '河沼郡会津坂下町', 'カワヌマグンアイヅバンゲマチ', '市中二番甲', 'イチナカ02バンコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡会津坂下町大堀川西甲', '07', '07421', '9696544', '福島県', 'フクシマケン', '河沼郡会津坂下町', 'カワヌマグンアイヅバンゲマチ', '大堀川西甲', 'オオホリカワニシコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡会津坂下町東南町裏甲', '07', '07421', '9696544', '福島県', 'フクシマケン', '河沼郡会津坂下町', 'カワヌマグンアイヅバンゲマチ', '東南町裏甲', 'トウナンマチウラコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡会津坂下町五反田', '07', '07421', '9696545', '福島県', 'フクシマケン', '河沼郡会津坂下町', 'カワヌマグンアイヅバンゲマチ', '五反田', 'ゴタンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡会津坂下町曲田', '07', '07421', '9696546', '福島県', 'フクシマケン', '河沼郡会津坂下町', 'カワヌマグンアイヅバンゲマチ', '曲田', 'マガリダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡会津坂下町市中三番甲', '07', '07421', '9696547', '福島県', 'フクシマケン', '河沼郡会津坂下町', 'カワヌマグンアイヅバンゲマチ', '市中三番甲', 'イチナカ03バンコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡会津坂下町茶屋町甲', '07', '07421', '9696548', '福島県', 'フクシマケン', '河沼郡会津坂下町', 'カワヌマグンアイヅバンゲマチ', '茶屋町甲', 'チャヤマチコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡会津坂下町古町川尻', '07', '07421', '9696549', '福島県', 'フクシマケン', '河沼郡会津坂下町', 'カワヌマグンアイヅバンゲマチ', '古町川尻', 'フルマチカワジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡会津坂下町舘ノ下', '07', '07421', '9696551', '福島県', 'フクシマケン', '河沼郡会津坂下町', 'カワヌマグンアイヅバンゲマチ', '舘ノ下', 'タテノシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡会津坂下町舘ノ内甲', '07', '07421', '9696552', '福島県', 'フクシマケン', '河沼郡会津坂下町', 'カワヌマグンアイヅバンゲマチ', '舘ノ内甲', 'タテノウチコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡会津坂下町石田', '07', '07421', '9696553', '福島県', 'フクシマケン', '河沼郡会津坂下町', 'カワヌマグンアイヅバンゲマチ', '石田', 'イシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡会津坂下町西南町裏甲', '07', '07421', '9696553', '福島県', 'フクシマケン', '河沼郡会津坂下町', 'カワヌマグンアイヅバンゲマチ', '西南町裏甲', 'セイナンマチウラコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡会津坂下町松ノ目', '07', '07421', '9696554', '福島県', 'フクシマケン', '河沼郡会津坂下町', 'カワヌマグンアイヅバンゲマチ', '松ノ目', 'マツノメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡会津坂下町沢ノ目', '07', '07421', '9696555', '福島県', 'フクシマケン', '河沼郡会津坂下町', 'カワヌマグンアイヅバンゲマチ', '沢ノ目', 'サワノメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡会津坂下町北逆水甲', '07', '07421', '9696556', '福島県', 'フクシマケン', '河沼郡会津坂下町', 'カワヌマグンアイヅバンゲマチ', '北逆水甲', 'キタサカミズコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡会津坂下町逆水', '07', '07421', '9696556', '福島県', 'フクシマケン', '河沼郡会津坂下町', 'カワヌマグンアイヅバンゲマチ', '逆水', 'サカミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡会津坂下町市中四番甲', '07', '07421', '9696557', '福島県', 'フクシマケン', '河沼郡会津坂下町', 'カワヌマグンアイヅバンゲマチ', '市中四番甲', 'イチナカ04バンコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡会津坂下町大道', '07', '07421', '9696561', '福島県', 'フクシマケン', '河沼郡会津坂下町', 'カワヌマグンアイヅバンゲマチ', '大道', 'ダイドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡会津坂下町一丁田甲', '07', '07421', '9696562', '福島県', 'フクシマケン', '河沼郡会津坂下町', 'カワヌマグンアイヅバンゲマチ', '一丁田甲', 'イッチョウダコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡会津坂下町中岡甲', '07', '07421', '9696562', '福島県', 'フクシマケン', '河沼郡会津坂下町', 'カワヌマグンアイヅバンゲマチ', '中岡甲', 'ナカオカコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡会津坂下町市中新町甲', '07', '07421', '9696563', '福島県', 'フクシマケン', '河沼郡会津坂下町', 'カワヌマグンアイヅバンゲマチ', '市中新町甲', 'イチナカシンチョウコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡会津坂下町中岩田', '07', '07421', '9696564', '福島県', 'フクシマケン', '河沼郡会津坂下町', 'カワヌマグンアイヅバンゲマチ', '中岩田', 'ナカイワタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡会津坂下町惣六', '07', '07421', '9696565', '福島県', 'フクシマケン', '河沼郡会津坂下町', 'カワヌマグンアイヅバンゲマチ', '惣六', 'ソウロク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡会津坂下町稲荷塚', '07', '07421', '9696566', '福島県', 'フクシマケン', '河沼郡会津坂下町', 'カワヌマグンアイヅバンゲマチ', '稲荷塚', 'イナリヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡会津坂下町沼田甲', '07', '07421', '9696567', '福島県', 'フクシマケン', '河沼郡会津坂下町', 'カワヌマグンアイヅバンゲマチ', '沼田甲', 'ヌマタコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡会津坂下町白狐', '07', '07421', '9696571', '福島県', 'フクシマケン', '河沼郡会津坂下町', 'カワヌマグンアイヅバンゲマチ', '白狐', 'ビャッコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡会津坂下町羽林', '07', '07421', '9696572', '福島県', 'フクシマケン', '河沼郡会津坂下町', 'カワヌマグンアイヅバンゲマチ', '羽林', 'ハバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡会津坂下町大沖', '07', '07421', '9696573', '福島県', 'フクシマケン', '河沼郡会津坂下町', 'カワヌマグンアイヅバンゲマチ', '大沖', 'オオオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡会津坂下町樋島', '07', '07421', '9696574', '福島県', 'フクシマケン', '河沼郡会津坂下町', 'カワヌマグンアイヅバンゲマチ', '樋島', 'トイシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡会津坂下町勝大', '07', '07421', '9696575', '福島県', 'フクシマケン', '河沼郡会津坂下町', 'カワヌマグンアイヅバンゲマチ', '勝大', 'カツオオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡会津坂下町牛川', '07', '07421', '9696576', '福島県', 'フクシマケン', '河沼郡会津坂下町', 'カワヌマグンアイヅバンゲマチ', '牛川', 'ウシカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡会津坂下町片門', '07', '07421', '9696581', '福島県', 'フクシマケン', '河沼郡会津坂下町', 'カワヌマグンアイヅバンゲマチ', '片門', 'カタカド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡会津坂下町高寺', '07', '07421', '9696582', '福島県', 'フクシマケン', '河沼郡会津坂下町', 'カワヌマグンアイヅバンゲマチ', '高寺', 'タカテラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡会津坂下町気多宮', '07', '07421', '9696583', '福島県', 'フクシマケン', '河沼郡会津坂下町', 'カワヌマグンアイヅバンゲマチ', '気多宮', 'ケタノミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡会津坂下町塔寺', '07', '07421', '9696584', '福島県', 'フクシマケン', '河沼郡会津坂下町', 'カワヌマグンアイヅバンゲマチ', '塔寺', 'トウデラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡会津坂下町船杉', '07', '07421', '9696585', '福島県', 'フクシマケン', '河沼郡会津坂下町', 'カワヌマグンアイヅバンゲマチ', '船杉', 'フナスギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡会津坂下町坂本', '07', '07421', '9696586', '福島県', 'フクシマケン', '河沼郡会津坂下町', 'カワヌマグンアイヅバンゲマチ', '坂本', 'サカモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡会津坂下町束松', '07', '07421', '9696587', '福島県', 'フクシマケン', '河沼郡会津坂下町', 'カワヌマグンアイヅバンゲマチ', '束松', 'タバネマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡柳津町', '07', '07423', '9697200', '福島県', 'フクシマケン', '河沼郡柳津町', 'カワヌマグンヤナイヅマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('139217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡柳津町柳津', '07', '07423', '9697201', '福島県', 'フクシマケン', '河沼郡柳津町', 'カワヌマグンヤナイヅマチ', '柳津', 'ヤナイヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡柳津町大柳', '07', '07423', '9697202', '福島県', 'フクシマケン', '河沼郡柳津町', 'カワヌマグンヤナイヅマチ', '大柳', 'オオリュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡柳津町軽井沢', '07', '07423', '9697203', '福島県', 'フクシマケン', '河沼郡柳津町', 'カワヌマグンヤナイヅマチ', '軽井沢', 'カルイザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡柳津町猪倉野', '07', '07423', '9697204', '福島県', 'フクシマケン', '河沼郡柳津町', 'カワヌマグンヤナイヅマチ', '猪倉野', 'イクラノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡柳津町郷戸', '07', '07423', '9697205', '福島県', 'フクシマケン', '河沼郡柳津町', 'カワヌマグンヤナイヅマチ', '郷戸', 'ゴウド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡柳津町飯谷', '07', '07423', '9697206', '福島県', 'フクシマケン', '河沼郡柳津町', 'カワヌマグンヤナイヅマチ', '飯谷', 'イイタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡柳津町小椿', '07', '07423', '9697207', '福島県', 'フクシマケン', '河沼郡柳津町', 'カワヌマグンヤナイヅマチ', '小椿', 'コツバキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡柳津町藤', '07', '07423', '9697208', '福島県', 'フクシマケン', '河沼郡柳津町', 'カワヌマグンヤナイヅマチ', '藤', 'フジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡柳津町細八', '07', '07423', '9697209', '福島県', 'フクシマケン', '河沼郡柳津町', 'カワヌマグンヤナイヅマチ', '細八', 'ホソハチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡柳津町湯八木沢', '07', '07423', '9697311', '福島県', 'フクシマケン', '河沼郡柳津町', 'カワヌマグンヤナイヅマチ', '湯八木沢', 'ユヤギサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡柳津町久保田', '07', '07423', '9697312', '福島県', 'フクシマケン', '河沼郡柳津町', 'カワヌマグンヤナイヅマチ', '久保田', 'クボタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡柳津町五畳敷', '07', '07423', '9697313', '福島県', 'フクシマケン', '河沼郡柳津町', 'カワヌマグンヤナイヅマチ', '五畳敷', 'ゴジョウジキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡柳津町牧沢', '07', '07423', '9697314', '福島県', 'フクシマケン', '河沼郡柳津町', 'カワヌマグンヤナイヅマチ', '牧沢', 'マキザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡柳津町四つ谷', '07', '07423', '9697315', '福島県', 'フクシマケン', '河沼郡柳津町', 'カワヌマグンヤナイヅマチ', '四つ谷', 'ヨツヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡柳津町砂子原', '07', '07423', '9697321', '福島県', 'フクシマケン', '河沼郡柳津町', 'カワヌマグンヤナイヅマチ', '砂子原', 'スナコハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡柳津町黒沢', '07', '07423', '9697322', '福島県', 'フクシマケン', '河沼郡柳津町', 'カワヌマグンヤナイヅマチ', '黒沢', 'クロサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡柳津町芋小屋', '07', '07423', '9697323', '福島県', 'フクシマケン', '河沼郡柳津町', 'カワヌマグンヤナイヅマチ', '芋小屋', 'イモゴヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡柳津町胄中', '07', '07423', '9697324', '福島県', 'フクシマケン', '河沼郡柳津町', 'カワヌマグンヤナイヅマチ', '胄中', 'カブチュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡柳津町大成沢', '07', '07423', '9697325', '福島県', 'フクシマケン', '河沼郡柳津町', 'カワヌマグンヤナイヅマチ', '大成沢', 'オオナリサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県河沼郡柳津町琵琶首', '07', '07423', '9697326', '福島県', 'フクシマケン', '河沼郡柳津町', 'カワヌマグンヤナイヅマチ', '琵琶首', 'ビワクビ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡三島町西方', '07', '07444', '9697401', '福島県', 'フクシマケン', '大沼郡三島町', 'オオヌマグンミシママチ', '西方', 'ニシカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡三島町名入', '07', '07444', '9697402', '福島県', 'フクシマケン', '大沼郡三島町', 'オオヌマグンミシママチ', '名入', 'ナイリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡三島町小山', '07', '07444', '9697403', '福島県', 'フクシマケン', '大沼郡三島町', 'オオヌマグンミシママチ', '小山', 'コヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡三島町高清水', '07', '07444', '9697404', '福島県', 'フクシマケン', '大沼郡三島町', 'オオヌマグンミシママチ', '高清水', 'タカシミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡三島町滝原', '07', '07444', '9697405', '福島県', 'フクシマケン', '大沼郡三島町', 'オオヌマグンミシママチ', '滝原', 'タキバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡三島町早戸', '07', '07444', '9697406', '福島県', 'フクシマケン', '大沼郡三島町', 'オオヌマグンミシママチ', '早戸', 'ハヤト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡三島町大石田', '07', '07444', '9697407', '福島県', 'フクシマケン', '大沼郡三島町', 'オオヌマグンミシママチ', '大石田', 'オオイシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡三島町桧原小和瀬', '07', '07444', '9697413', '福島県', 'フクシマケン', '大沼郡三島町', 'オオヌマグンミシママチ', '桧原', 'ヒノハラ', null, null, '小和瀬', 'コワゼ');
INSERT INTO `ms_addresses` VALUES ('139245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡三島町', '07', '07444', '9697500', '福島県', 'フクシマケン', '大沼郡三島町', 'オオヌマグンミシママチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('139246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡三島町宮下', '07', '07444', '9697511', '福島県', 'フクシマケン', '大沼郡三島町', 'オオヌマグンミシママチ', '宮下', 'ミヤシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡三島町桑原', '07', '07444', '9697512', '福島県', 'フクシマケン', '大沼郡三島町', 'オオヌマグンミシママチ', '桑原', 'クワノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡三島町桧原', '07', '07444', '9697513', '福島県', 'フクシマケン', '大沼郡三島町', 'オオヌマグンミシママチ', '桧原', 'ヒノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡三島町滝谷', '07', '07444', '9697514', '福島県', 'フクシマケン', '大沼郡三島町', 'オオヌマグンミシママチ', '滝谷', 'タキヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡三島町川井', '07', '07444', '9697515', '福島県', 'フクシマケン', '大沼郡三島町', 'オオヌマグンミシママチ', '川井', 'カワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡三島町大登', '07', '07444', '9697516', '福島県', 'フクシマケン', '大沼郡三島町', 'オオヌマグンミシママチ', '大登', 'オオノボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡三島町大谷', '07', '07444', '9697517', '福島県', 'フクシマケン', '大沼郡三島町', 'オオヌマグンミシママチ', '大谷', 'オオタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡三島町浅岐', '07', '07444', '9697518', '福島県', 'フクシマケン', '大沼郡三島町', 'オオヌマグンミシママチ', '浅岐', 'アサマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県大沼郡三島町間方', '07', '07444', '9697519', '福島県', 'フクシマケン', '大沼郡三島町', 'オオヌマグンミシママチ', '間方', 'マガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道稚内市', '01', '01214', '0970000', '北海道', 'ホッカイドウ', '稚内市', 'ワッカナイシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('139256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市', '07', '07204', '9700000', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('139257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道稚内市末広', '01', '01214', '0970001', '北海道', 'ホッカイドウ', '稚内市', 'ワッカナイシ', '末広', 'スエヒロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道稚内市潮見', '01', '01214', '0970002', '北海道', 'ホッカイドウ', '稚内市', 'ワッカナイシ', '潮見', 'シオミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道稚内市こまどり', '01', '01214', '0970003', '北海道', 'ホッカイドウ', '稚内市', 'ワッカナイシ', 'こまどり', 'コマドリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道稚内市緑', '01', '01214', '0970004', '北海道', 'ホッカイドウ', '稚内市', 'ワッカナイシ', '緑', 'ミドリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道稚内市大黒', '01', '01214', '0970005', '北海道', 'ホッカイドウ', '稚内市', 'ワッカナイシ', '大黒', 'ダイコク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道稚内市新港町', '01', '01214', '0970006', '北海道', 'ホッカイドウ', '稚内市', 'ワッカナイシ', '新港町', 'シンミナトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道稚内市新末広', '01', '01214', '0970007', '北海道', 'ホッカイドウ', '稚内市', 'ワッカナイシ', '新末広', 'シンスエヒロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市平下神谷', '07', '07204', '9700101', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '平下神谷', 'タイラシモカベヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市平下大越', '07', '07204', '9700102', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '平下大越', 'タイラシモオオゴエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市平藤間', '07', '07204', '9700103', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '平藤間', 'タイラフジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市平上大越', '07', '07204', '9700104', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '平上大越', 'タイラカミオオゴエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市平菅波', '07', '07204', '9700105', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '平菅波', 'タイラスギナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市平山崎', '07', '07204', '9700106', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '平山崎', 'タイラヤマザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市平荒田目', '07', '07204', '9700107', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '平荒田目', 'タイラアッタメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道稚内市はまなす', '01', '01214', '0970011', '北海道', 'ホッカイドウ', '稚内市', 'ワッカナイシ', 'はまなす', 'ハマナス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市平原高野', '07', '07204', '9700111', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '平原高野', 'タイラハラゴヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市平泉崎', '07', '07204', '9700112', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '平泉崎', 'タイライズミザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市平絹谷', '07', '07204', '9700113', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '平絹谷', 'タイラキヌヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市平水品', '07', '07204', '9700114', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '平水品', 'タイラミズシナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市平北神谷', '07', '07204', '9700115', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '平北神谷', 'タイラキタカベヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市平馬目', '07', '07204', '9700116', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '平馬目', 'タイラマノメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道稚内市富岡', '01', '01214', '0970012', '北海道', 'ホッカイドウ', '稚内市', 'ワッカナイシ', '富岡', 'トミオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道稚内市若葉台', '01', '01214', '0970013', '北海道', 'ホッカイドウ', '稚内市', 'ワッカナイシ', '若葉台', 'ワカバダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道稚内市新光町', '01', '01214', '0970014', '北海道', 'ホッカイドウ', '稚内市', 'ワッカナイシ', '新光町', 'シンコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道稚内市朝日', '01', '01214', '0970015', '北海道', 'ホッカイドウ', '稚内市', 'ワッカナイシ', '朝日', 'アサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道稚内市萩見', '01', '01214', '0970016', '北海道', 'ホッカイドウ', '稚内市', 'ワッカナイシ', '萩見', 'ハギミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道稚内市栄', '01', '01214', '0970017', '北海道', 'ホッカイドウ', '稚内市', 'ワッカナイシ', '栄', 'サカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道稚内市港', '01', '01214', '0970021', '北海道', 'ホッカイドウ', '稚内市', 'ワッカナイシ', '港', 'ミナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道稚内市中央', '01', '01214', '0970022', '北海道', 'ホッカイドウ', '稚内市', 'ワッカナイシ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市平下高久', '07', '07204', '9700221', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '平下高久', 'タイラシモタカク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市平沼ノ内', '07', '07204', '9700222', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '平沼ノ内', 'タイラヌマノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市平沼ノ内諏訪原', '07', '07204', '9700222', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '平沼ノ内諏訪原', 'タイラヌマノウチスワハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市平薄磯', '07', '07204', '9700223', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '平薄磯', 'タイラウスイソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市平豊間', '07', '07204', '9700224', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '平豊間', 'タイラトヨマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市平上山口', '07', '07204', '9700225', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '平上山口', 'タイラカミヤマグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市平下山口', '07', '07204', '9700226', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '平下山口', 'タイラシモヤマグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市平鶴ケ井', '07', '07204', '9700227', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '平鶴ケ井', 'タイラツルガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市平神谷作', '07', '07204', '9700228', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '平神谷作', 'タイラカミヤサク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道稚内市開運', '01', '01214', '0970023', '北海道', 'ホッカイドウ', '稚内市', 'ワッカナイシ', '開運', 'カイウン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道稚内市宝来', '01', '01214', '0970024', '北海道', 'ホッカイドウ', '稚内市', 'ワッカナイシ', '宝来', 'ホウライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道稚内市恵比須', '01', '01214', '0970025', '北海道', 'ホッカイドウ', '稚内市', 'ワッカナイシ', '恵比須', 'エビス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道稚内市ノシャップ', '01', '01214', '0970026', '北海道', 'ホッカイドウ', '稚内市', 'ワッカナイシ', 'ノシャップ', 'ノシャップ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道稚内市富士見', '01', '01214', '0970027', '北海道', 'ホッカイドウ', '稚内市', 'ワッカナイシ', '富士見', 'フジミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市江名', '07', '07204', '9700311', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '江名', 'エナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市折戸', '07', '07204', '9700312', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '折戸', 'オリト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市中之作', '07', '07204', '9700313', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '中之作', 'ナカノサク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市洋向台', '07', '07204', '9700314', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '洋向台', 'ヨウコウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市永崎', '07', '07204', '9700315', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '永崎', 'ナガサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市小名浜下神白', '07', '07204', '9700316', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '小名浜下神白', 'オナハマシモカジロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市小名浜上神白', '07', '07204', '9700317', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '小名浜上神白', 'オナハマカミカジロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道稚内市抜海村バッカイ', '01', '01214', '0970035', '北海道', 'ホッカイドウ', '稚内市', 'ワッカナイシ', '抜海村', 'バッカイムラ', null, null, 'バッカイ', 'バッカイ');
INSERT INTO `ms_addresses` VALUES ('139308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道稚内市抜海村クトネベツ', '01', '01214', '0970036', '北海道', 'ホッカイドウ', '稚内市', 'ワッカナイシ', '抜海村', 'バッカイムラ', null, null, 'クトネベツ', 'クトネベツ');
INSERT INTO `ms_addresses` VALUES ('139309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道稚内市西浜', '01', '01214', '0970037', '北海道', 'ホッカイドウ', '稚内市', 'ワッカナイシ', '西浜', 'ニシハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道利尻郡利尻富士町', '01', '01519', '0970100', '北海道', 'ホッカイドウ', '利尻郡利尻富士町', 'リシリグンリシリフジチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('139311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道利尻郡利尻富士町鴛泊', '01', '01519', '0970101', '北海道', 'ホッカイドウ', '利尻郡利尻富士町', 'リシリグンリシリフジチョウ', '鴛泊', 'オシドマリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市好間町愛谷', '07', '07204', '9701141', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '好間町愛谷', 'ヨシママチアイヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市好間町今新田', '07', '07204', '9701142', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '好間町今新田', 'ヨシママチイマニイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市好間町小谷作', '07', '07204', '9701143', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '好間町小谷作', 'ヨシママチオヤサク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市好間工業団地', '07', '07204', '9701144', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '好間工業団地', 'ヨシマコウギョウダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市好間町北好間', '07', '07204', '9701145', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '好間町北好間', 'ヨシママチキタヨシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市好間町榊小屋', '07', '07204', '9701146', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '好間町榊小屋', 'ヨシママチサカキゴヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市好間町大利', '07', '07204', '9701147', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '好間町大利', 'ヨシママチオオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市好間町下好間', '07', '07204', '9701151', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '好間町下好間', 'ヨシママチシモヨシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市好間町中好間', '07', '07204', '9701152', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '好間町中好間', 'ヨシママチナカヨシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市好間町上好間', '07', '07204', '9701153', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '好間町上好間', 'ヨシママチカミヨシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市三和町渡戸', '07', '07204', '9701261', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '三和町渡戸', 'ミワマチワタド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市三和町上永井', '07', '07204', '9701262', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '三和町上永井', 'ミワマチカミナガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市三和町下永井', '07', '07204', '9701263', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '三和町下永井', 'ミワマチシモナガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市三和町合戸', '07', '07204', '9701264', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '三和町合戸', 'ミワマチゴウド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市三和町渡戸川前', '07', '07204', '9701361', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '三和町渡戸', 'ミワマチワタド', null, null, '川前', 'カワマエ');
INSERT INTO `ms_addresses` VALUES ('139330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市三和町中寺', '07', '07204', '9701371', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '三和町中寺', 'ミワマチナカデラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市三和町下市萱', '07', '07204', '9701372', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '三和町下市萱', 'ミワマチシモイチガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市三和町上市萱', '07', '07204', '9701373', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '三和町上市萱', 'ミワマチカミイチガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市三和町上三坂', '07', '07204', '9701374', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '三和町上三坂', 'ミワマチカミミサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市三和町中三坂', '07', '07204', '9701375', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '三和町中三坂', 'ミワマチナカミサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市三和町下三坂', '07', '07204', '9701376', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '三和町下三坂', 'ミワマチシモミサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市三和町差塩', '07', '07204', '9701377', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '三和町差塩', 'ミワマチサイソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道利尻郡利尻富士町鬼脇', '01', '01519', '0970211', '北海道', 'ホッカイドウ', '利尻郡利尻富士町', 'リシリグンリシリフジチョウ', '鬼脇', 'オニワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道利尻郡利尻町仙法志', '01', '01518', '0970311', '北海道', 'ホッカイドウ', '利尻郡利尻町', 'リシリグンリシリチョウ', '仙法志', 'センポウシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道利尻郡利尻町', '01', '01518', '0970400', '北海道', 'ホッカイドウ', '利尻郡利尻町', 'リシリグンリシリチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('139340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道利尻郡利尻町沓形', '01', '01518', '0970401', '北海道', 'ホッカイドウ', '利尻郡利尻町', 'リシリグンリシリチョウ', '沓形', 'クツガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市平上平窪', '07', '07204', '9708001', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '平上平窪', 'タイラカミヒラクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市平中平窪', '07', '07204', '9708002', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '平中平窪', 'タイラナカヒラクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市平下平窪', '07', '07204', '9708003', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '平下平窪', 'タイラシモヒラクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市平下平窪中島町', '07', '07204', '9708004', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '平下平窪中島町', 'タイラシモヒラクボナカジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市平下平窪古川町', '07', '07204', '9708005', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '平下平窪古川町', 'タイラシモヒラクボフルカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市平下平窪山土内町', '07', '07204', '9708006', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '平下平窪山土内町', 'タイラシモヒラクボヤマドウチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市平中平窪新町', '07', '07204', '9708007', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '平中平窪新町', 'タイラナカヒラクボシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市平中平窪細田町', '07', '07204', '9708008', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '平中平窪細田町', 'タイラナカヒラクボホソダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市平上片寄', '07', '07204', '9708011', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '平上片寄', 'タイラカミカタヨセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市平下片寄', '07', '07204', '9708012', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '平下片寄', 'タイラシモカタヨセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市平大室', '07', '07204', '9708013', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '平大室', 'タイラオオムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市平幕ノ内', '07', '07204', '9708014', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '平幕ノ内', 'タイラマクノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市好間町川中子', '07', '07204', '9708015', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '好間町川中子', 'ヨシママチカワナゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市平中塩', '07', '07204', '9708016', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '平中塩', 'タイラナカシオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市石森', '07', '07204', '9708017', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '石森', 'イシモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市平四ツ波', '07', '07204', '9708018', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '平四ツ波', 'タイラヨツナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市平中神谷', '07', '07204', '9708021', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '平中神谷', 'タイラナカカベヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市平塩', '07', '07204', '9708022', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '平塩', 'タイラシオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市平鎌田', '07', '07204', '9708023', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '平鎌田', 'タイラカマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市平北白土', '07', '07204', '9708024', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '平北白土', 'タイラキタシラド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市平南白土', '07', '07204', '9708025', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '平南白土', 'タイラミナミシラド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市平', '07', '07204', '9708026', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '平', 'タイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市平鯨岡', '07', '07204', '9708027', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '平鯨岡', 'タイラクジラオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市平上神谷', '07', '07204', '9708028', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '平上神谷', 'タイラカミカベヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市平中山', '07', '07204', '9708031', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '平中山', 'タイラナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市平下荒川', '07', '07204', '9708032', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '平下荒川', 'タイラシモアラカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市自由ケ丘', '07', '07204', '9708033', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '自由ケ丘', 'ジュウガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市平上荒川', '07', '07204', '9708034', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '平上荒川', 'タイラカミアラカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市明治団地', '07', '07204', '9708035', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '明治団地', 'メイジダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市平谷川瀬', '07', '07204', '9708036', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '平谷川瀬', 'タイラヤガワセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市平小泉', '07', '07204', '9708041', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '平小泉', 'タイラコイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市平上高久', '07', '07204', '9708042', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '平上高久', 'タイラカミタカク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市中央台鹿島', '07', '07204', '9708043', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '中央台鹿島', 'チュウオウダイカシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市中央台飯野', '07', '07204', '9708044', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '中央台飯野', 'チュウオウダイイイノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市郷ケ丘', '07', '07204', '9708045', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '郷ケ丘', 'サトガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市平吉野谷', '07', '07204', '9708046', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '平吉野谷', 'タイラヨシノヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市中央台高久', '07', '07204', '9708047', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '中央台高久', 'チュウオウダイタカク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市平六町目', '07', '07204', '9708051', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '平六町目', 'タイラロクチョウメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市平祢宜町', '07', '07204', '9708052', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '平祢宜町', 'タイラネギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市平正月町', '07', '07204', '9708053', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '平正月町', 'タイラショウガツマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市平鎌田町', '07', '07204', '9708054', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '平鎌田町', 'タイラカマタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道礼文郡礼文町船泊村', '01', '01517', '0971111', '北海道', 'ホッカイドウ', '礼文郡礼文町', 'レブングンレブンチョウ', '船泊村', 'フナドマリムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道礼文郡礼文町', '01', '01517', '0971200', '北海道', 'ホッカイドウ', '礼文郡礼文町', 'レブングンレブンチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('139393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道礼文郡礼文町香深村', '01', '01517', '0971201', '北海道', 'ホッカイドウ', '礼文郡礼文町', 'レブングンレブンチョウ', '香深村', 'カフカムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道礼文郡礼文町船泊村ウヱンナイ', '01', '01517', '0971202', '北海道', 'ホッカイドウ', '礼文郡礼文町', 'レブングンレブンチョウ', '船泊村', 'フナドマリムラ', null, null, 'ウヱンナイ', 'ウエンナイ');
INSERT INTO `ms_addresses` VALUES ('139395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市小名浜', '07', '07204', '9718101', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '小名浜', 'オナハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市小名浜港ケ丘', '07', '07204', '9718102', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '小名浜港ケ丘', 'オナハマミナトガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市小名浜大原', '07', '07204', '9718111', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '小名浜大原', 'オナハマオオハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市小名浜南富岡', '07', '07204', '9718112', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '小名浜南富岡', 'オナハマミナミトミオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市小名浜岩出', '07', '07204', '9718121', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '小名浜岩出', 'オナハマイワデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市小名浜林城', '07', '07204', '9718122', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '小名浜林城', 'オナハマリンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市小名浜相子島', '07', '07204', '9718123', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '小名浜相子島', 'オナハマアイコシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市小名浜住吉', '07', '07204', '9718124', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '小名浜住吉', 'オナハマスミヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市小名浜島', '07', '07204', '9718125', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '小名浜島', 'オナハマシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市小名浜野田', '07', '07204', '9718126', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '小名浜野田', 'オナハマノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市小名浜玉川町', '07', '07204', '9718127', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '小名浜玉川町', 'オナハマタマガワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市常磐上矢田町', '07', '07204', '9718131', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '常磐上矢田町', 'ジョウバンカミヤダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市鹿島町下矢田', '07', '07204', '9718132', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '鹿島町下矢田', 'カシママチシモヤダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市鹿島町米田', '07', '07204', '9718133', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '鹿島町米田', 'カシママチコモダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市鹿島町飯田', '07', '07204', '9718134', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '鹿島町飯田', 'カシママチイイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市小名浜金成', '07', '07204', '9718135', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '小名浜金成', 'オナハマカナリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市常磐三沢町', '07', '07204', '9718136', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '常磐三沢町', 'ジョウバンミサワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市常磐松久須根町', '07', '07204', '9718137', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '常磐松久須根町', 'ジョウバンマツクスネマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市若葉台', '07', '07204', '9718138', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '若葉台', 'ワカバダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市鹿島町鹿島', '07', '07204', '9718139', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '鹿島町鹿島', 'カシママチカシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市鹿島町走熊', '07', '07204', '9718141', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '鹿島町走熊', 'カシママチハシリクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市鹿島町上蔵持', '07', '07204', '9718142', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '鹿島町上蔵持', 'カシママチカミクラモチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市鹿島町下蔵持', '07', '07204', '9718143', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '鹿島町下蔵持', 'カシママチシモクラモチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市鹿島町久保', '07', '07204', '9718144', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '鹿島町久保', 'カシママチクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市鹿島町船戸', '07', '07204', '9718145', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '鹿島町船戸', 'カシママチフナド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市鹿島町御代', '07', '07204', '9718146', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '鹿島町御代', 'カシママチミヨ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市小名浜岡小名', '07', '07204', '9718151', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '小名浜岡小名', 'オナハマオカオナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市湘南台', '07', '07204', '9718152', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '湘南台', 'ショウナンダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市小名浜諏訪町', '07', '07204', '9718161', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '小名浜諏訪町', 'オナハマスワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市小名浜花畑町', '07', '07204', '9718162', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '小名浜花畑町', 'オナハマハナバタケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市小名浜中町境', '07', '07204', '9718163', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '小名浜中町境', 'オナハマナカチョウザカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市小名浜寺廻町', '07', '07204', '9718164', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '小名浜寺廻町', 'オナハマテラマワリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市小名浜西町', '07', '07204', '9718164', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '小名浜西町', 'オナハマニシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市小名浜愛宕町', '07', '07204', '9718165', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '小名浜愛宕町', 'オナハマアタゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市小名浜愛宕上', '07', '07204', '9718166', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '小名浜愛宕上', 'オナハマアタゴウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市小名浜西君ケ塚町', '07', '07204', '9718167', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '小名浜西君ケ塚町', 'オナハマニシキミガツカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市小名浜君ケ塚町', '07', '07204', '9718168', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '小名浜君ケ塚町', 'オナハマキミガツカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市小名浜南君ケ塚町', '07', '07204', '9718169', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '小名浜南君ケ塚町', 'オナハマミナミキミガツカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市泉ケ丘', '07', '07204', '9718171', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '泉ケ丘', 'イズミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市泉玉露', '07', '07204', '9718172', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '泉玉露', 'イズミタマツユ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市泉町本谷', '07', '07204', '9718181', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '泉町本谷', 'イズミマチホンヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市泉町滝尻', '07', '07204', '9718182', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '泉町滝尻', 'イズミマチタキジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市泉町下川', '07', '07204', '9718183', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '泉町下川', 'イズミマチシモガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市泉町黒須野', '07', '07204', '9718184', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '泉町黒須野', 'イズミマチクロスノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市泉町', '07', '07204', '9718185', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '泉町', 'イズミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市泉町玉露', '07', '07204', '9718186', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '泉町玉露', 'イズミマチタマツユ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市葉山', '07', '07204', '9718187', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '葉山', 'ハヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市泉もえぎ台', '07', '07204', '9718188', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '泉もえぎ台', 'イズミモエギダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市遠野町上遠野', '07', '07204', '9720161', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '遠野町上遠野', 'トオノマチカトオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市遠野町滝', '07', '07204', '9720162', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '遠野町滝', 'トオノマチタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市遠野町根岸', '07', '07204', '9720163', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '遠野町根岸', 'トオノマチネギシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市遠野町深山田', '07', '07204', '9720164', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '遠野町深山田', 'トオノマチミヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市遠野町入遠野', '07', '07204', '9720251', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '遠野町入遠野', 'トオノマチイリトオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市遠野町上根本', '07', '07204', '9720252', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '遠野町上根本', 'トオノマチカミネモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市遠野町大平', '07', '07204', '9720253', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '遠野町大平', 'トオノマチオオダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市草木台', '07', '07204', '9728301', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '草木台', 'クサキダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市常磐水野谷町', '07', '07204', '9728311', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '常磐水野谷町', 'ジョウバンミズノヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市常磐下船尾町', '07', '07204', '9728312', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '常磐下船尾町', 'ジョウバンシモフナオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市常磐岩ケ岡町', '07', '07204', '9728313', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '常磐岩ケ岡町', 'ジョウバンイワガオカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市常磐馬玉町', '07', '07204', '9728314', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '常磐馬玉町', 'ジョウバンマダママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市常磐長孫町', '07', '07204', '9728315', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '常磐長孫町', 'ジョウバンオサマゴマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市常磐西郷町', '07', '07204', '9728316', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '常磐西郷町', 'ジョウバンニシゴウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市常磐下湯長谷町', '07', '07204', '9728317', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '常磐下湯長谷町', 'ジョウバンシモユナガヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市常磐関船町', '07', '07204', '9728318', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '常磐関船町', 'ジョウバンセキフネマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市常磐湯本町', '07', '07204', '9728321', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '常磐湯本町', 'ジョウバンユモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市常磐上湯長谷町', '07', '07204', '9728322', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '常磐上湯長谷町', 'ジョウバンカミユナガヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市常磐松が台', '07', '07204', '9728323', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '常磐松が台', 'ジョウバンマツガダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市桜ケ丘', '07', '07204', '9728324', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '桜ケ丘', 'サクラガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市常磐白鳥町', '07', '07204', '9728325', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '常磐白鳥町', 'ジョウバンシラトリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市常磐藤原町', '07', '07204', '9728326', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '常磐藤原町', 'ジョウバンフジワラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市渡辺町泉田', '07', '07204', '9728331', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '渡辺町泉田', 'ワタナベマチイズミダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市渡辺町昼野', '07', '07204', '9728332', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '渡辺町昼野', 'ワタナベマチヒルノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市渡辺町洞', '07', '07204', '9728333', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '渡辺町洞', 'ワタナベマチボラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市渡辺町田部', '07', '07204', '9728334', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '渡辺町田部', 'ワタナベマチタナベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市渡辺町松小屋', '07', '07204', '9728335', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '渡辺町松小屋', 'ワタナベマチマツゴヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市渡辺町上釜戸', '07', '07204', '9728336', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '渡辺町上釜戸', 'ワタナベマチカミカマド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市渡辺町中釜戸', '07', '07204', '9728337', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '渡辺町中釜戸', 'ワタナベマチナカカマド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市中部工業団地', '07', '07204', '9728338', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '中部工業団地', 'チュウブコウギョウダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市内郷小島町', '07', '07204', '9738401', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '内郷小島町', 'ウチゴウオジママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市内郷御厩町', '07', '07204', '9738402', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '内郷御厩町', 'ウチゴウミマヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市内郷綴町', '07', '07204', '9738403', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '内郷綴町', 'ウチゴウツヅラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市内郷内町', '07', '07204', '9738404', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '内郷内町', 'ウチゴウウチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市内郷白水町', '07', '07204', '9738405', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '内郷白水町', 'ウチゴウシラミズマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市内郷高野町', '07', '07204', '9738406', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '内郷高野町', 'ウチゴウコウヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市内郷宮町', '07', '07204', '9738407', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '内郷宮町', 'ウチゴウミヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市内郷高坂町', '07', '07204', '9738408', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '内郷高坂町', 'ウチゴウタカサカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市内郷御台境町', '07', '07204', '9738409', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '内郷御台境町', 'ウチゴウミダイサカイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市小島町', '07', '07204', '9738411', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '小島町', 'オジママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市平成', '07', '07204', '9738412', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '平成', 'ヘイセイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市田人町黒田', '07', '07204', '9740151', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '田人町黒田', 'タビトマチクロダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市田人町旅人', '07', '07204', '9740152', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '田人町旅人', 'タビトマチタビウト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市田人町南大平', '07', '07204', '9740153', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '田人町南大平', 'タビトマチミナミオオダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市田人町荷路夫', '07', '07204', '9740241', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '田人町荷路夫', 'タビトマチニチブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市田人町貝泊', '07', '07204', '9740242', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '田人町貝泊', 'タビトマチカイドマリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市田人町石住', '07', '07204', '9740243', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '田人町石住', 'タビトマチイシズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市田人町旅人水呑場', '07', '07204', '9740252', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '田人町旅人', 'タビトマチタビウト', null, null, '水呑場', 'ミズノミバ');
INSERT INTO `ms_addresses` VALUES ('139497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市江畑町', '07', '07204', '9748201', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '江畑町', 'エバタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市添野町', '07', '07204', '9748202', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '添野町', 'ソエノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市後田町', '07', '07204', '9748203', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '後田町', 'ウシロダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市高倉町', '07', '07204', '9748204', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '高倉町', 'タカクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市金山町', '07', '07204', '9748211', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '金山町', 'カネヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市東田町', '07', '07204', '9748212', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '東田町', 'アズマダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市石塚町', '07', '07204', '9748213', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '石塚町', 'イシヅカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市小浜町', '07', '07204', '9748221', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '小浜町', 'オバママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市岩間町', '07', '07204', '9748222', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '岩間町', 'イワママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市佐糠町', '07', '07204', '9748223', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '佐糠町', 'サヌカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市富津町', '07', '07204', '9748231', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '富津町', 'トミツマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市錦町', '07', '07204', '9748232', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '錦町', 'ニシキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市錦町中央', '07', '07204', '9748233', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '錦町中央', 'ニシキマチチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市山田町', '07', '07204', '9748241', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '山田町', 'ヤマダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市南台', '07', '07204', '9748242', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '南台', 'ミナミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市中岡町', '07', '07204', '9748251', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '中岡町', 'ナカオカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市仁井田町', '07', '07204', '9748252', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '仁井田町', 'ニイダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市植田町', '07', '07204', '9748261', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '植田町', 'ウエダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市', '07', '07212', '9750000', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('139518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市原町区大町', '07', '07212', '9750001', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '原町区大町', 'ハラマチクオオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市原町区東町', '07', '07212', '9750002', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '原町区東町', 'ハラマチクアズマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市原町区栄町', '07', '07212', '9750003', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '原町区栄町', 'ハラマチクサカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市原町区旭町', '07', '07212', '9750004', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '原町区旭町', 'ハラマチクアサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市原町区二見町', '07', '07212', '9750005', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '原町区二見町', 'ハラマチクフタミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市原町区橋本町', '07', '07212', '9750006', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '原町区橋本町', 'ハラマチクハシモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市原町区南町', '07', '07212', '9750007', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '原町区南町', 'ハラマチクミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市原町区本町', '07', '07212', '9750008', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '原町区本町', 'ハラマチクモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市原町区小川町', '07', '07212', '9750011', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '原町区小川町', 'ハラマチクオガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市原町区三島町', '07', '07212', '9750012', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '原町区三島町', 'ハラマチクミシマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市原町区上町', '07', '07212', '9750013', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '原町区上町', 'ハラマチクカミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市原町区西町', '07', '07212', '9750014', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '原町区西町', 'ハラマチクニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市原町区国見町', '07', '07212', '9750015', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '原町区国見町', 'ハラマチククニミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市原町区仲町', '07', '07212', '9750016', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '原町区仲町', 'ハラマチクナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市原町区牛越', '07', '07212', '9750017', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '原町区牛越', 'ハラマチクウシゴエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市原町区北町', '07', '07212', '9750018', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '原町区北町', 'ハラマチクキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市原町区金沢', '07', '07212', '9750021', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '原町区金沢', 'ハラマチクカネザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市原町区北泉', '07', '07212', '9750022', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '原町区北泉', 'ハラマチクキタイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市原町区泉', '07', '07212', '9750023', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '原町区泉', 'ハラマチクイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市原町区下北高平', '07', '07212', '9750024', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '原町区下北高平', 'ハラマチクシモキタタカヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市原町区下高平', '07', '07212', '9750025', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '原町区下高平', 'ハラマチクシモタカヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市原町区上高平', '07', '07212', '9750026', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '原町区上高平', 'ハラマチクカミタカヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市原町区上北高平', '07', '07212', '9750027', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '原町区上北高平', 'ハラマチクカミキタタカヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市原町区錦町', '07', '07212', '9750031', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '原町区錦町', 'ハラマチクニシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市原町区桜井町', '07', '07212', '9750032', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '原町区桜井町', 'ハラマチクサクライチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市原町区高見町', '07', '07212', '9750033', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '原町区高見町', 'ハラマチクタカミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市原町区上渋佐', '07', '07212', '9750034', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '原町区上渋佐', 'ハラマチクカミシブサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市原町区下渋佐', '07', '07212', '9750035', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '原町区下渋佐', 'ハラマチクシモシブサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市原町区萱浜', '07', '07212', '9750036', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '原町区萱浜', 'ハラマチクカイバマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市原町区北原', '07', '07212', '9750037', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '原町区北原', 'ハラマチクキタハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市原町区日の出町', '07', '07212', '9750038', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '原町区日の出町', 'ハラマチクヒノデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市原町区青葉町', '07', '07212', '9750039', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '原町区青葉町', 'ハラマチクアオバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市原町区下太田', '07', '07212', '9750041', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '原町区下太田', 'ハラマチクシモオオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市原町区雫', '07', '07212', '9750042', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '原町区雫', 'ハラマチクシドケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市原町区小浜', '07', '07212', '9750043', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '原町区小浜', 'ハラマチクコバマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市原町区下江井', '07', '07212', '9750044', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '原町区下江井', 'ハラマチクシモエネイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市原町区小沢', '07', '07212', '9750045', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '原町区小沢', 'ハラマチクコザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市原町区堤谷', '07', '07212', '9750046', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '原町区堤谷', 'ハラマチクツツミガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市原町区江井', '07', '07212', '9750047', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '原町区江井', 'ハラマチクエネイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市原町区米々沢', '07', '07212', '9750048', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '原町区米々沢', 'ハラマチクメメザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市原町区大甕', '07', '07212', '9750049', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '原町区大甕', 'ハラマチクオオミカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市原町区牛来', '07', '07212', '9750051', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '原町区牛来', 'ハラマチクゴライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市原町区中太田', '07', '07212', '9750052', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '原町区中太田', 'ハラマチクナカオオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市原町区益田', '07', '07212', '9750053', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '原町区益田', 'ハラマチクマスダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市原町区高', '07', '07212', '9750054', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '原町区高', 'ハラマチクタカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市原町区小木さく', '07', '07212', '9750055', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '原町区小木さく', 'ハラマチクオギサク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市原町区鶴谷', '07', '07212', '9750056', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '原町区鶴谷', 'ハラマチクツルガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市原町区矢川原', '07', '07212', '9750057', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '原町区矢川原', 'ハラマチクヤガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市原町区片倉', '07', '07212', '9750058', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '原町区片倉', 'ハラマチクカタクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市原町区上太田', '07', '07212', '9750059', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '原町区上太田', 'ハラマチクカミオオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市原町区大木戸', '07', '07212', '9750061', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '原町区大木戸', 'ハラマチクオオキド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市原町区本陣前', '07', '07212', '9750062', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '原町区本陣前', 'ハラマチクホンジンマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市原町区馬場', '07', '07212', '9750063', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '原町区馬場', 'ハラマチクババ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市原町区押釜', '07', '07212', '9750064', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '原町区押釜', 'ハラマチクオシガマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市原町区深野', '07', '07212', '9750071', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '原町区深野', 'ハラマチクフコウノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市原町区北長野', '07', '07212', '9750072', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '原町区北長野', 'ハラマチクキタナガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市原町区北新田', '07', '07212', '9750073', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '原町区北新田', 'ハラマチクキタニイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市原町区長野', '07', '07212', '9750074', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '原町区長野', 'ハラマチクナガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市原町区石神', '07', '07212', '9750075', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '原町区石神', 'ハラマチクイシガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市原町区信田沢', '07', '07212', '9750076', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '原町区信田沢', 'ハラマチクシダザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市原町区高倉', '07', '07212', '9750077', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '原町区高倉', 'ハラマチクタカノクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市原町区大谷', '07', '07212', '9750078', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '原町区大谷', 'ハラマチクオオガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市原町区大原', '07', '07212', '9750079', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '原町区大原', 'ハラマチクオオハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県相馬市', '07', '07209', '9760000', '福島県', 'フクシマケン', '相馬市', 'ソウマシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('139583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県相馬市大野台', '07', '07209', '9760001', '福島県', 'フクシマケン', '相馬市', 'ソウマシ', '大野台', 'オオノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県相馬市椎木', '07', '07209', '9760002', '福島県', 'フクシマケン', '相馬市', 'ソウマシ', '椎木', 'シイノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県相馬市塚部', '07', '07209', '9760003', '福島県', 'フクシマケン', '相馬市', 'ソウマシ', '塚部', 'ツカノベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県相馬市長老内', '07', '07209', '9760004', '福島県', 'フクシマケン', '相馬市', 'ソウマシ', '長老内', 'チョウロウウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県相馬市光陽', '07', '07209', '9760005', '福島県', 'フクシマケン', '相馬市', 'ソウマシ', '光陽', 'コウヨウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県相馬市石上', '07', '07209', '9760006', '福島県', 'フクシマケン', '相馬市', 'ソウマシ', '石上', 'イシガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県相馬市大坪', '07', '07209', '9760007', '福島県', 'フクシマケン', '相馬市', 'ソウマシ', '大坪', 'オオツボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県相馬市新沼', '07', '07209', '9760011', '福島県', 'フクシマケン', '相馬市', 'ソウマシ', '新沼', 'ニイヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県相馬市北小泉', '07', '07209', '9760012', '福島県', 'フクシマケン', '相馬市', 'ソウマシ', '北小泉', 'キタコイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県相馬市小泉', '07', '07209', '9760013', '福島県', 'フクシマケン', '相馬市', 'ソウマシ', '小泉', 'コイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県相馬市北飯渕', '07', '07209', '9760014', '福島県', 'フクシマケン', '相馬市', 'ソウマシ', '北飯渕', 'キタイイブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県相馬市塚ノ町', '07', '07209', '9760015', '福島県', 'フクシマケン', '相馬市', 'ソウマシ', '塚ノ町', 'ツカノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県相馬市沖ノ内', '07', '07209', '9760016', '福島県', 'フクシマケン', '相馬市', 'ソウマシ', '沖ノ内', 'オキノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県相馬市原釜', '07', '07209', '9760021', '福島県', 'フクシマケン', '相馬市', 'ソウマシ', '原釜', 'ハラガマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県相馬市尾浜', '07', '07209', '9760022', '福島県', 'フクシマケン', '相馬市', 'ソウマシ', '尾浜', 'オバマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県相馬市和田', '07', '07209', '9760023', '福島県', 'フクシマケン', '相馬市', 'ソウマシ', '和田', 'ワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県相馬市本笑', '07', '07209', '9760024', '福島県', 'フクシマケン', '相馬市', 'ソウマシ', '本笑', 'モトワロウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県相馬市岩子', '07', '07209', '9760025', '福島県', 'フクシマケン', '相馬市', 'ソウマシ', '岩子', 'イワノコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県相馬市南飯渕', '07', '07209', '9760026', '福島県', 'フクシマケン', '相馬市', 'ソウマシ', '南飯渕', 'ミナミイイブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県相馬市百槻', '07', '07209', '9760031', '福島県', 'フクシマケン', '相馬市', 'ソウマシ', '百槻', 'ドウヅキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県相馬市大曲', '07', '07209', '9760032', '福島県', 'フクシマケン', '相馬市', 'ソウマシ', '大曲', 'オオマガリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県相馬市新田', '07', '07209', '9760033', '福島県', 'フクシマケン', '相馬市', 'ソウマシ', '新田', 'ニイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県相馬市柏崎', '07', '07209', '9760034', '福島県', 'フクシマケン', '相馬市', 'ソウマシ', '柏崎', 'カシワザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県相馬市程田', '07', '07209', '9760035', '福島県', 'フクシマケン', '相馬市', 'ソウマシ', '程田', 'ホドタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県相馬市馬場野', '07', '07209', '9760036', '福島県', 'フクシマケン', '相馬市', 'ソウマシ', '馬場野', 'ババノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県相馬市中野', '07', '07209', '9760037', '福島県', 'フクシマケン', '相馬市', 'ソウマシ', '中野', 'ナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県相馬市西山', '07', '07209', '9760041', '福島県', 'フクシマケン', '相馬市', 'ソウマシ', '西山', 'ニシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県相馬市中村', '07', '07209', '9760042', '福島県', 'フクシマケン', '相馬市', 'ソウマシ', '中村', 'ナカムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県相馬市初野', '07', '07209', '9760051', '福島県', 'フクシマケン', '相馬市', 'ソウマシ', '初野', 'ハツノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県相馬市黒木', '07', '07209', '9760052', '福島県', 'フクシマケン', '相馬市', 'ソウマシ', '黒木', 'クロキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県相馬市小野', '07', '07209', '9760053', '福島県', 'フクシマケン', '相馬市', 'ソウマシ', '小野', 'オノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県相馬市山上', '07', '07209', '9760151', '福島県', 'フクシマケン', '相馬市', 'ソウマシ', '山上', 'ヤマカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県相馬市粟津', '07', '07209', '9760152', '福島県', 'フクシマケン', '相馬市', 'ソウマシ', '粟津', 'アワヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県相馬市東玉野', '07', '07209', '9760153', '福島県', 'フクシマケン', '相馬市', 'ソウマシ', '東玉野', 'ヒガシタマノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県相馬市玉野', '07', '07209', '9760154', '福島県', 'フクシマケン', '相馬市', 'ソウマシ', '玉野', 'タマノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市勿来町窪田', '07', '07204', '9790141', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '勿来町', 'ナコソマチ', null, null, '窪田', 'クボタ');
INSERT INTO `ms_addresses` VALUES ('139630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市勿来町酒井', '07', '07204', '9790142', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '勿来町', 'ナコソマチ', null, null, '酒井', 'サカイ');
INSERT INTO `ms_addresses` VALUES ('139631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市勿来町白米', '07', '07204', '9790143', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '勿来町', 'ナコソマチ', null, null, '白米', 'シロヨネ');
INSERT INTO `ms_addresses` VALUES ('139632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市勿来町大高', '07', '07204', '9790144', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '勿来町', 'ナコソマチ', null, null, '大高', 'オオダカ');
INSERT INTO `ms_addresses` VALUES ('139633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市勿来町四沢', '07', '07204', '9790145', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '勿来町', 'ナコソマチ', null, null, '四沢', 'シサワ');
INSERT INTO `ms_addresses` VALUES ('139634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市勿来町関田', '07', '07204', '9790146', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '勿来町', 'ナコソマチ', null, null, '関田', 'セキタ');
INSERT INTO `ms_addresses` VALUES ('139635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市勿来町九面', '07', '07204', '9790147', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '勿来町', 'ナコソマチ', null, null, '九面', 'ココヅラ');
INSERT INTO `ms_addresses` VALUES ('139636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市瀬戸町', '07', '07204', '9790151', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '瀬戸町', 'セトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市山玉町', '07', '07204', '9790152', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '山玉町', 'ヤマダママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市川部町', '07', '07204', '9790153', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '川部町', 'カワベマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市沼部町', '07', '07204', '9790154', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '沼部町', 'ヌマベマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市三沢町', '07', '07204', '9790155', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '三沢町', 'ミサワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市四倉町', '07', '07204', '9790201', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '四倉町', 'ヨツクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市四倉町上仁井田', '07', '07204', '9790202', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '四倉町上仁井田', 'ヨツクラマチカミニイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市四倉町下仁井田', '07', '07204', '9790203', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '四倉町下仁井田', 'ヨツクラマチシモニイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市四倉町細谷', '07', '07204', '9790204', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '四倉町細谷', 'ヨツクラマチホソヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市四倉町大森', '07', '07204', '9790205', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '四倉町大森', 'ヨツクラマチオオモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市四倉町狐塚', '07', '07204', '9790206', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '四倉町狐塚', 'ヨツクラマチキツネヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市四倉町塩木', '07', '07204', '9790207', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '四倉町塩木', 'ヨツクラマチシオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市四倉町白岩', '07', '07204', '9790211', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '四倉町白岩', 'ヨツクラマチシライワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市四倉町戸田', '07', '07204', '9790212', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '四倉町戸田', 'ヨツクラマチトダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市四倉町名木', '07', '07204', '9790213', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '四倉町名木', 'ヨツクラマチナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市四倉町長友', '07', '07204', '9790214', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '四倉町長友', 'ヨツクラマチナガトモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市四倉町中島', '07', '07204', '9790215', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '四倉町中島', 'ヨツクラマチナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市四倉町玉山', '07', '07204', '9790216', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '四倉町玉山', 'ヨツクラマチタマヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市四倉町上岡', '07', '07204', '9790221', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '四倉町上岡', 'ヨツクラマチカミオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市四倉町八茎', '07', '07204', '9790222', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '四倉町八茎', 'ヨツクラマチヤグキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市四倉町山田小湊', '07', '07204', '9790223', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '四倉町山田小湊', 'ヨツクラマチヤマダコミナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市四倉町薬王寺', '07', '07204', '9790224', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '四倉町薬王寺', 'ヨツクラマチヤクオウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市四倉町下柳生', '07', '07204', '9790225', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '四倉町下柳生', 'ヨツクラマチシモヤギュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市四倉町上柳生', '07', '07204', '9790226', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '四倉町上柳生', 'ヨツクラマチカミヤギュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市四倉町駒込', '07', '07204', '9790227', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '四倉町駒込', 'ヨツクラマチコマゴメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市久之浜町末続', '07', '07204', '9790331', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '久之浜町末続', 'ヒサノハママチスエツギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市久之浜町金ケ沢', '07', '07204', '9790332', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '久之浜町金ケ沢', 'ヒサノハママチカネガサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市久之浜町久之浜', '07', '07204', '9790333', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '久之浜町久之浜', 'ヒサノハママチヒサノハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市久之浜町西', '07', '07204', '9790334', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '久之浜町西', 'ヒサノハママチニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市久之浜町田之網', '07', '07204', '9790335', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '久之浜町田之網', 'ヒサノハママチタノアミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市大久町小山田', '07', '07204', '9790336', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '大久町小山田', 'オオヒサマチオヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市大久町小久', '07', '07204', '9790337', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '大久町小久', 'オオヒサマチコヒサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市大久町大久', '07', '07204', '9790338', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '大久町大久', 'オオヒサマチオオヒサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡広野町', '07', '07541', '9790400', '福島県', 'フクシマケン', '双葉郡広野町', 'フタバグンヒロノマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('139671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡広野町上北迫', '07', '07541', '9790401', '福島県', 'フクシマケン', '双葉郡広野町', 'フタバグンヒロノマチ', '上北迫', 'カミキタバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡広野町下北迫', '07', '07541', '9790402', '福島県', 'フクシマケン', '双葉郡広野町', 'フタバグンヒロノマチ', '下北迫', 'シモキタバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡広野町下浅見川', '07', '07541', '9790403', '福島県', 'フクシマケン', '双葉郡広野町', 'フタバグンヒロノマチ', '下浅見川', 'シモアサミガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡広野町折木', '07', '07541', '9790404', '福島県', 'フクシマケン', '双葉郡広野町', 'フタバグンヒロノマチ', '折木', 'オリキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡広野町夕筋', '07', '07541', '9790405', '福島県', 'フクシマケン', '双葉郡広野町', 'フタバグンヒロノマチ', '夕筋', 'ユウスジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡広野町上浅見川', '07', '07541', '9790406', '福島県', 'フクシマケン', '双葉郡広野町', 'フタバグンヒロノマチ', '上浅見川', 'カミアサミガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡広野町広洋台', '07', '07541', '9790407', '福島県', 'フクシマケン', '双葉郡広野町', 'フタバグンヒロノマチ', '広洋台', 'コウヨウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡広野町中央台', '07', '07541', '9790408', '福島県', 'フクシマケン', '双葉郡広野町', 'フタバグンヒロノマチ', '中央台', 'チュウオウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡楢葉町前原', '07', '07542', '9790511', '福島県', 'フクシマケン', '双葉郡楢葉町', 'フタバグンナラハマチ', '前原', 'マエバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡楢葉町山田浜', '07', '07542', '9790512', '福島県', 'フクシマケン', '双葉郡楢葉町', 'フタバグンナラハマチ', '山田浜', 'ヤマダハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡楢葉町山田岡', '07', '07542', '9790513', '福島県', 'フクシマケン', '双葉郡楢葉町', 'フタバグンナラハマチ', '山田岡', 'ヤマダオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡楢葉町下小塙', '07', '07542', '9790514', '福島県', 'フクシマケン', '双葉郡楢葉町', 'フタバグンナラハマチ', '下小塙', 'シモコバナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡楢葉町上小塙', '07', '07542', '9790515', '福島県', 'フクシマケン', '双葉郡楢葉町', 'フタバグンナラハマチ', '上小塙', 'カミコバナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡楢葉町', '07', '07542', '9790600', '福島県', 'フクシマケン', '双葉郡楢葉町', 'フタバグンナラハマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('139685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡楢葉町波倉', '07', '07542', '9790601', '福島県', 'フクシマケン', '双葉郡楢葉町', 'フタバグンナラハマチ', '波倉', 'ナミクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡楢葉町下繁岡', '07', '07542', '9790602', '福島県', 'フクシマケン', '双葉郡楢葉町', 'フタバグンナラハマチ', '下繁岡', 'シモシゲオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡楢葉町井出', '07', '07542', '9790603', '福島県', 'フクシマケン', '双葉郡楢葉町', 'フタバグンナラハマチ', '井出', 'イデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡楢葉町北田', '07', '07542', '9790604', '福島県', 'フクシマケン', '双葉郡楢葉町', 'フタバグンナラハマチ', '北田', 'キタダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡楢葉町大谷', '07', '07542', '9790605', '福島県', 'フクシマケン', '双葉郡楢葉町', 'フタバグンナラハマチ', '大谷', 'オオヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡楢葉町上繁岡', '07', '07542', '9790606', '福島県', 'フクシマケン', '双葉郡楢葉町', 'フタバグンナラハマチ', '上繁岡', 'カミシゲオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡富岡町毛萱', '07', '07543', '9790622', '福島県', 'フクシマケン', '双葉郡富岡町', 'フタバグントミオカマチ', '毛萱', 'ケガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡富岡町', '07', '07543', '9791100', '福島県', 'フクシマケン', '双葉郡富岡町', 'フタバグントミオカマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('139695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡富岡町小良ケ浜', '07', '07543', '9791101', '福島県', 'フクシマケン', '双葉郡富岡町', 'フタバグントミオカマチ', '小良ケ浜', 'オラガハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡富岡町小浜', '07', '07543', '9791111', '福島県', 'フクシマケン', '双葉郡富岡町', 'フタバグントミオカマチ', '小浜', 'コバマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡富岡町中央', '07', '07543', '9791112', '福島県', 'フクシマケン', '双葉郡富岡町', 'フタバグントミオカマチ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡富岡町仏浜', '07', '07543', '9791121', '福島県', 'フクシマケン', '双葉郡富岡町', 'フタバグントミオカマチ', '仏浜', 'ホトケハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡富岡町毛萱', '07', '07543', '9791122', '福島県', 'フクシマケン', '双葉郡富岡町', 'フタバグントミオカマチ', '毛萱', 'ケガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡富岡町上郡山', '07', '07543', '9791131', '福島県', 'フクシマケン', '双葉郡富岡町', 'フタバグントミオカマチ', '上郡山', 'カミコオリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡富岡町下郡山', '07', '07543', '9791132', '福島県', 'フクシマケン', '双葉郡富岡町', 'フタバグントミオカマチ', '下郡山', 'シモコオリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡富岡町上手岡', '07', '07543', '9791141', '福島県', 'フクシマケン', '双葉郡富岡町', 'フタバグントミオカマチ', '上手岡', 'カミテオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡富岡町本岡', '07', '07543', '9791151', '福島県', 'フクシマケン', '双葉郡富岡町', 'フタバグントミオカマチ', '本岡', 'モトオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡富岡町本町', '07', '07543', '9791152', '福島県', 'フクシマケン', '双葉郡富岡町', 'フタバグントミオカマチ', '本町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡富岡町夜の森', '07', '07543', '9791161', '福島県', 'フクシマケン', '双葉郡富岡町', 'フタバグントミオカマチ', '夜の森', 'ヨノモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡富岡町桜', '07', '07543', '9791162', '福島県', 'フクシマケン', '双葉郡富岡町', 'フタバグントミオカマチ', '桜', 'サクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡富岡町大菅', '07', '07543', '9791171', '福島県', 'フクシマケン', '双葉郡富岡町', 'フタバグントミオカマチ', '大菅', 'オオスゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡川内村', '07', '07544', '9791200', '福島県', 'フクシマケン', '双葉郡川内村', 'フタバグンカワウチムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('139710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡川内村上川内', '07', '07544', '9791201', '福島県', 'フクシマケン', '双葉郡川内村', 'フタバグンカワウチムラ', '上川内', 'カミカワウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡川内村下川内', '07', '07544', '9791202', '福島県', 'フクシマケン', '双葉郡川内村', 'フタバグンカワウチムラ', '下川内', 'シモカワウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡大熊町', '07', '07545', '9791300', '福島県', 'フクシマケン', '双葉郡大熊町', 'フタバグンオオクママチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('139713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡大熊町夫沢', '07', '07545', '9791301', '福島県', 'フクシマケン', '双葉郡大熊町', 'フタバグンオオクママチ', '夫沢', 'オットザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡大熊町小入野', '07', '07545', '9791302', '福島県', 'フクシマケン', '双葉郡大熊町', 'フタバグンオオクママチ', '小入野', 'コイリノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡大熊町熊川', '07', '07545', '9791303', '福島県', 'フクシマケン', '双葉郡大熊町', 'フタバグンオオクママチ', '熊川', 'クマガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡大熊町小良浜', '07', '07545', '9791304', '福島県', 'フクシマケン', '双葉郡大熊町', 'フタバグンオオクママチ', '小良浜', 'オラハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡大熊町熊', '07', '07545', '9791305', '福島県', 'フクシマケン', '双葉郡大熊町', 'フタバグンオオクママチ', '熊', 'クマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡大熊町大川原', '07', '07545', '9791306', '福島県', 'フクシマケン', '双葉郡大熊町', 'フタバグンオオクママチ', '大川原', 'オオガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡大熊町野上', '07', '07545', '9791307', '福島県', 'フクシマケン', '双葉郡大熊町', 'フタバグンオオクママチ', '野上', 'ノガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡大熊町下野上', '07', '07545', '9791308', '福島県', 'フクシマケン', '双葉郡大熊町', 'フタバグンオオクママチ', '下野上', 'シモノガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡双葉町', '07', '07546', '9791400', '福島県', 'フクシマケン', '双葉郡双葉町', 'フタバグンフタバマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('139723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡双葉町中野', '07', '07546', '9791401', '福島県', 'フクシマケン', '双葉郡双葉町', 'フタバグンフタバマチ', '中野', 'ナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡双葉町中浜', '07', '07546', '9791402', '福島県', 'フクシマケン', '双葉郡双葉町', 'フタバグンフタバマチ', '中浜', 'ナカハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡双葉町郡山', '07', '07546', '9791411', '福島県', 'フクシマケン', '双葉郡双葉町', 'フタバグンフタバマチ', '郡山', 'コオリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡双葉町細谷', '07', '07546', '9791412', '福島県', 'フクシマケン', '双葉郡双葉町', 'フタバグンフタバマチ', '細谷', 'ホソヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡双葉町前田', '07', '07546', '9791421', '福島県', 'フクシマケン', '双葉郡双葉町', 'フタバグンフタバマチ', '前田', 'マエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡双葉町水沢', '07', '07546', '9791422', '福島県', 'フクシマケン', '双葉郡双葉町', 'フタバグンフタバマチ', '水沢', 'ミズサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡双葉町目迫', '07', '07546', '9791423', '福島県', 'フクシマケン', '双葉郡双葉町', 'フタバグンフタバマチ', '目迫', 'メサク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡双葉町山田', '07', '07546', '9791431', '福島県', 'フクシマケン', '双葉郡双葉町', 'フタバグンフタバマチ', '山田', 'ヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡双葉町松迫', '07', '07546', '9791432', '福島県', 'フクシマケン', '双葉郡双葉町', 'フタバグンフタバマチ', '松迫', 'マツザク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡双葉町石熊', '07', '07546', '9791433', '福島県', 'フクシマケン', '双葉郡双葉町', 'フタバグンフタバマチ', '石熊', 'イシクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡双葉町下羽鳥', '07', '07546', '9791441', '福島県', 'フクシマケン', '双葉郡双葉町', 'フタバグンフタバマチ', '下羽鳥', 'シモハトリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡双葉町上羽鳥', '07', '07546', '9791442', '福島県', 'フクシマケン', '双葉郡双葉町', 'フタバグンフタバマチ', '上羽鳥', 'カミハトリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡双葉町渋川', '07', '07546', '9791451', '福島県', 'フクシマケン', '双葉郡双葉町', 'フタバグンフタバマチ', '渋川', 'シブカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡双葉町松倉', '07', '07546', '9791452', '福島県', 'フクシマケン', '双葉郡双葉町', 'フタバグンフタバマチ', '松倉', 'マツクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡双葉町寺沢', '07', '07546', '9791453', '福島県', 'フクシマケン', '双葉郡双葉町', 'フタバグンフタバマチ', '寺沢', 'テラザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡双葉町両竹', '07', '07546', '9791461', '福島県', 'フクシマケン', '双葉郡双葉町', 'フタバグンフタバマチ', '両竹', 'モロタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡双葉町中田', '07', '07546', '9791462', '福島県', 'フクシマケン', '双葉郡双葉町', 'フタバグンフタバマチ', '中田', 'ナカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡双葉町鴻草', '07', '07546', '9791463', '福島県', 'フクシマケン', '双葉郡双葉町', 'フタバグンフタバマチ', '鴻草', 'コウノクサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡双葉町長塚', '07', '07546', '9791471', '福島県', 'フクシマケン', '双葉郡双葉町', 'フタバグンフタバマチ', '長塚', 'ナガツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡双葉町新山', '07', '07546', '9791472', '福島県', 'フクシマケン', '双葉郡双葉町', 'フタバグンフタバマチ', '新山', 'シンザン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡浪江町', '07', '07547', '9791500', '福島県', 'フクシマケン', '双葉郡浪江町', 'フタバグンナミエマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('139745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡浪江町立野', '07', '07547', '9791501', '福島県', 'フクシマケン', '双葉郡浪江町', 'フタバグンナミエマチ', '立野', 'タツノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡浪江町藤橋', '07', '07547', '9791502', '福島県', 'フクシマケン', '双葉郡浪江町', 'フタバグンナミエマチ', '藤橋', 'フジハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡浪江町西台', '07', '07547', '9791503', '福島県', 'フクシマケン', '双葉郡浪江町', 'フタバグンナミエマチ', '西台', 'ニシダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡浪江町酒田', '07', '07547', '9791504', '福島県', 'フクシマケン', '双葉郡浪江町', 'フタバグンナミエマチ', '酒田', 'サカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡浪江町苅宿', '07', '07547', '9791505', '福島県', 'フクシマケン', '双葉郡浪江町', 'フタバグンナミエマチ', '苅宿', 'カリヤド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡浪江町室原', '07', '07547', '9791506', '福島県', 'フクシマケン', '双葉郡浪江町', 'フタバグンナミエマチ', '室原', 'ムロハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡浪江町棚塩', '07', '07547', '9791511', '福島県', 'フクシマケン', '双葉郡浪江町', 'フタバグンナミエマチ', '棚塩', 'タナシオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡浪江町北幾世橋', '07', '07547', '9791512', '福島県', 'フクシマケン', '双葉郡浪江町', 'フタバグンナミエマチ', '北幾世橋', 'キタキヨハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡浪江町幾世橋', '07', '07547', '9791513', '福島県', 'フクシマケン', '双葉郡浪江町', 'フタバグンナミエマチ', '幾世橋', 'キヨハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡浪江町権現堂', '07', '07547', '9791521', '福島県', 'フクシマケン', '双葉郡浪江町', 'フタバグンナミエマチ', '権現堂', 'ゴンゲンドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡浪江町請戸', '07', '07547', '9791522', '福島県', 'フクシマケン', '双葉郡浪江町', 'フタバグンナミエマチ', '請戸', 'ウケド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡浪江町中浜', '07', '07547', '9791523', '福島県', 'フクシマケン', '双葉郡浪江町', 'フタバグンナミエマチ', '中浜', 'ナカハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡浪江町両竹', '07', '07547', '9791524', '福島県', 'フクシマケン', '双葉郡浪江町', 'フタバグンナミエマチ', '両竹', 'モロタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡浪江町高瀬', '07', '07547', '9791525', '福島県', 'フクシマケン', '双葉郡浪江町', 'フタバグンナミエマチ', '高瀬', 'タカセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡浪江町牛渡', '07', '07547', '9791526', '福島県', 'フクシマケン', '双葉郡浪江町', 'フタバグンナミエマチ', '牛渡', 'ウシワタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡浪江町川添', '07', '07547', '9791531', '福島県', 'フクシマケン', '双葉郡浪江町', 'フタバグンナミエマチ', '川添', 'カワゾエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡浪江町樋渡', '07', '07547', '9791532', '福島県', 'フクシマケン', '双葉郡浪江町', 'フタバグンナミエマチ', '樋渡', 'ヒワタシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡浪江町酒井', '07', '07547', '9791533', '福島県', 'フクシマケン', '双葉郡浪江町', 'フタバグンナミエマチ', '酒井', 'サカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡浪江町谷津田', '07', '07547', '9791534', '福島県', 'フクシマケン', '双葉郡浪江町', 'フタバグンナミエマチ', '谷津田', 'ヤツダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡浪江町井手', '07', '07547', '9791535', '福島県', 'フクシマケン', '双葉郡浪江町', 'フタバグンナミエマチ', '井手', 'イデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡浪江町加倉', '07', '07547', '9791536', '福島県', 'フクシマケン', '双葉郡浪江町', 'フタバグンナミエマチ', '加倉', 'カクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡浪江町田尻', '07', '07547', '9791541', '福島県', 'フクシマケン', '双葉郡浪江町', 'フタバグンナミエマチ', '田尻', 'タジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡浪江町末森', '07', '07547', '9791542', '福島県', 'フクシマケン', '双葉郡浪江町', 'フタバグンナミエマチ', '末森', 'スエノモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡浪江町小野田', '07', '07547', '9791543', '福島県', 'フクシマケン', '双葉郡浪江町', 'フタバグンナミエマチ', '小野田', 'オノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡浪江町大堀', '07', '07547', '9791544', '福島県', 'フクシマケン', '双葉郡浪江町', 'フタバグンナミエマチ', '大堀', 'オオボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡浪江町小丸', '07', '07547', '9791545', '福島県', 'フクシマケン', '双葉郡浪江町', 'フタバグンナミエマチ', '小丸', 'オマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡葛尾村', '07', '07548', '9791600', '福島県', 'フクシマケン', '双葉郡葛尾村', 'フタバグンカツラオムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('139773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡葛尾村葛尾', '07', '07548', '9791601', '福島県', 'フクシマケン', '双葉郡葛尾村', 'フタバグンカツラオムラ', '葛尾', 'カツラオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡葛尾村落合', '07', '07548', '9791602', '福島県', 'フクシマケン', '双葉郡葛尾村', 'フタバグンカツラオムラ', '落合', 'オチアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡葛尾村野川', '07', '07548', '9791603', '福島県', 'フクシマケン', '双葉郡葛尾村', 'フタバグンカツラオムラ', '野川', 'ノガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡葛尾村上野川', '07', '07548', '9791604', '福島県', 'フクシマケン', '双葉郡葛尾村', 'フタバグンカツラオムラ', '上野川', 'カミノガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡浪江町室原', '07', '07547', '9791706', '福島県', 'フクシマケン', '双葉郡浪江町', 'フタバグンナミエマチ', '室原', 'ムロハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡浪江町赤宇木', '07', '07547', '9791751', '福島県', 'フクシマケン', '双葉郡浪江町', 'フタバグンナミエマチ', '赤宇木', 'アコウギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡浪江町昼曽根', '07', '07547', '9791752', '福島県', 'フクシマケン', '双葉郡浪江町', 'フタバグンナミエマチ', '昼曽根', 'ヒルソネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡浪江町川房', '07', '07547', '9791753', '福島県', 'フクシマケン', '双葉郡浪江町', 'フタバグンナミエマチ', '川房', 'カワブサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡浪江町南津島', '07', '07547', '9791754', '福島県', 'フクシマケン', '双葉郡浪江町', 'フタバグンナミエマチ', '南津島', 'ミナミツシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡浪江町羽附', '07', '07547', '9791755', '福島県', 'フクシマケン', '双葉郡浪江町', 'フタバグンナミエマチ', '羽附', 'ハツケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡浪江町下津島', '07', '07547', '9791756', '福島県', 'フクシマケン', '双葉郡浪江町', 'フタバグンナミエマチ', '下津島', 'シモツシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県双葉郡浪江町津島', '07', '07547', '9791757', '福島県', 'フクシマケン', '双葉郡浪江町', 'フタバグンナミエマチ', '津島', 'ツシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市小高区片草', '07', '07212', '9792101', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '小高区片草', 'オダカクカタクサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市小高区小高', '07', '07212', '9792102', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '小高区小高', 'オダカクオダカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市小高区大井', '07', '07212', '9792103', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '小高区大井', 'オダカクオオイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市小高区塚原', '07', '07212', '9792104', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '小高区塚原', 'オダカクツカバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市小高区仲町', '07', '07212', '9792111', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '小高区仲町', 'オダカクナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市小高区田町', '07', '07212', '9792112', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '小高区田町', 'オダカクタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市小高区関場', '07', '07212', '9792113', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '小高区関場', 'オダカクセキバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市小高区西町', '07', '07212', '9792114', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '小高区西町', 'オダカクニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市小高区上町', '07', '07212', '9792115', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '小高区上町', 'オダカクカミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市小高区東町', '07', '07212', '9792121', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '小高区東町', 'オダカクヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市小高区南町', '07', '07212', '9792122', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '小高区南町', 'オダカクミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市小高区大町', '07', '07212', '9792123', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '小高区大町', 'オダカクオオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市小高区本町', '07', '07212', '9792124', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '小高区本町', 'オダカクモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市小高区福岡', '07', '07212', '9792131', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '小高区福岡', 'オダカクフクオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市小高区水谷', '07', '07212', '9792132', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '小高区水谷', 'オダカクミズガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市小高区泉沢', '07', '07212', '9792133', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '小高区泉沢', 'オダカクイズミサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市小高区岡田', '07', '07212', '9792134', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '小高区岡田', 'オダカクオカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市小高区村上', '07', '07212', '9792141', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '小高区村上', 'オダカクムラカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市小高区角部内', '07', '07212', '9792142', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '小高区角部内', 'オダカクツノベウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市小高区蛯沢', '07', '07212', '9792143', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '小高区蛯沢', 'オダカクエビサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市小高区井田川', '07', '07212', '9792144', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '小高区井田川', 'オダカクイダガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市小高区浦尻', '07', '07212', '9792145', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '小高区浦尻', 'オダカクウラジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市小高区下浦', '07', '07212', '9792146', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '小高区下浦', 'オダカクシモウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市小高区女場', '07', '07212', '9792147', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '小高区女場', 'オダカクオナバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市小高区耳谷', '07', '07212', '9792151', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '小高区耳谷', 'オダカクミミガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市小高区行津', '07', '07212', '9792152', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '小高区行津', 'オダカクナメヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市小高区上浦', '07', '07212', '9792153', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '小高区上浦', 'オダカクカミウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市小高区神山', '07', '07212', '9792154', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '小高区神山', 'オダカクカミヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市小高区上根沢', '07', '07212', '9792155', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '小高区上根沢', 'オダカクウワネザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市小高区小屋木', '07', '07212', '9792156', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '小高区小屋木', 'オダカクコヤギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市小高区吉名', '07', '07212', '9792157', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '小高区吉名', 'オダカクヨシナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市小高区藤木', '07', '07212', '9792161', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '小高区藤木', 'オダカクフジキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市小高区飯崎', '07', '07212', '9792162', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '小高区飯崎', 'オダカクハンサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市小高区大田和', '07', '07212', '9792163', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '小高区大田和', 'オダカクオオタワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市小高区川房', '07', '07212', '9792164', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '小高区川房', 'オダカクカワブサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市小高区金谷', '07', '07212', '9792165', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '小高区金谷', 'オダカクカナヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市小高区北鳩原', '07', '07212', '9792171', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '小高区北鳩原', 'オダカクキタハツパラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市小高区南鳩原', '07', '07212', '9792172', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '小高区南鳩原', 'オダカクミナミハツパラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市小高区小谷', '07', '07212', '9792173', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '小高区小谷', 'オダカクオヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市小高区大富', '07', '07212', '9792174', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '小高区大富', 'オダカクオオトミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市小高区羽倉', '07', '07212', '9792175', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '小高区羽倉', 'オダカクハノクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市鹿島区永渡', '07', '07212', '9792301', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '鹿島区永渡', 'カシマクナガワタリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市鹿島区南柚木', '07', '07212', '9792302', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '鹿島区南柚木', 'カシマクミナミユノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市鹿島区北屋形', '07', '07212', '9792303', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '鹿島区北屋形', 'カシマクキタヤカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市鹿島区南屋形', '07', '07212', '9792304', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '鹿島区南屋形', 'カシマクミナミヤカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市鹿島区永田', '07', '07212', '9792305', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '鹿島区永田', 'カシマクナガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市鹿島区北海老', '07', '07212', '9792311', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '鹿島区北海老', 'カシマクキタエビ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市鹿島区南海老', '07', '07212', '9792312', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '鹿島区南海老', 'カシマクミナミエビ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市鹿島区北右田', '07', '07212', '9792313', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '鹿島区北右田', 'カシマクキタミギタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市鹿島区南右田', '07', '07212', '9792314', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '鹿島区南右田', 'カシマクミナミミギタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市鹿島区小島田', '07', '07212', '9792321', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '鹿島区小島田', 'カシマクオシマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市鹿島区大内', '07', '07212', '9792322', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '鹿島区大内', 'カシマクオオウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市鹿島区烏崎', '07', '07212', '9792323', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '鹿島区烏崎', 'カシマクカラスザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市鹿島区川子', '07', '07212', '9792324', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '鹿島区川子', 'カシマクカワゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市鹿島区江垂', '07', '07212', '9792331', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '鹿島区江垂', 'カシマクエタリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市鹿島区塩崎', '07', '07212', '9792332', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '鹿島区塩崎', 'カシマクシオノサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市鹿島区寺内', '07', '07212', '9792333', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '鹿島区寺内', 'カシマクテラウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市鹿島区西町', '07', '07212', '9792334', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '鹿島区西町', 'カシマクニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市鹿島区鹿島', '07', '07212', '9792335', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '鹿島区鹿島', 'カシマクカシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市鹿島区あさひ', '07', '07212', '9792336', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '鹿島区あさひ', 'カシマクアサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市鹿島区角川原', '07', '07212', '9792441', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '鹿島区角川原', 'カシマクツノガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市鹿島区横手', '07', '07212', '9792442', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '鹿島区横手', 'カシマクヨコテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市鹿島区牛河内', '07', '07212', '9792443', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '鹿島区牛河内', 'カシマクウシコウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市鹿島区岡和田', '07', '07212', '9792444', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '鹿島区岡和田', 'カシマクオカワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市鹿島区浮田', '07', '07212', '9792451', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '鹿島区浮田', 'カシマクウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市鹿島区小山田', '07', '07212', '9792452', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '鹿島区小山田', 'カシマクコヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市鹿島区小池', '07', '07212', '9792453', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '鹿島区小池', 'カシマクコイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市鹿島区橲原', '07', '07212', '9792454', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '鹿島区橲原', 'カシマクジサバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市鹿島区山下', '07', '07212', '9792461', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '鹿島区山下', 'カシマクヤマシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市鹿島区上栃窪', '07', '07212', '9792462', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '鹿島区上栃窪', 'カシマクカミトチクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市鹿島区栃窪', '07', '07212', '9792463', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '鹿島区栃窪', 'カシマクトチクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県南相馬市鹿島区御山', '07', '07212', '9792464', '福島県', 'フクシマケン', '南相馬市', 'ミナミソウマシ', '鹿島区御山', 'カシマクオヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県相馬市磯部', '07', '07209', '9792501', '福島県', 'フクシマケン', '相馬市', 'ソウマシ', '磯部', 'イソベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県相馬市蒲庭', '07', '07209', '9792511', '福島県', 'フクシマケン', '相馬市', 'ソウマシ', '蒲庭', 'カバニワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県相馬市柚木', '07', '07209', '9792512', '福島県', 'フクシマケン', '相馬市', 'ソウマシ', '柚木', 'ユヌキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県相馬市赤木', '07', '07209', '9792521', '福島県', 'フクシマケン', '相馬市', 'ソウマシ', '赤木', 'アカギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県相馬市日下石', '07', '07209', '9792522', '福島県', 'フクシマケン', '相馬市', 'ソウマシ', '日下石', 'ニッケシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県相馬市立谷', '07', '07209', '9792531', '福島県', 'フクシマケン', '相馬市', 'ソウマシ', '立谷', 'タチヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県相馬市富沢', '07', '07209', '9792532', '福島県', 'フクシマケン', '相馬市', 'ソウマシ', '富沢', 'トミザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県相馬市坪田', '07', '07209', '9792533', '福島県', 'フクシマケン', '相馬市', 'ソウマシ', '坪田', 'ツボタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県相馬市今田', '07', '07209', '9792541', '福島県', 'フクシマケン', '相馬市', 'ソウマシ', '今田', 'イマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県相馬市成田', '07', '07209', '9792542', '福島県', 'フクシマケン', '相馬市', 'ソウマシ', '成田', 'ナリタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県相馬郡新地町駒ケ嶺', '07', '07561', '9792611', '福島県', 'フクシマケン', '相馬郡新地町', 'ソウマグンシンチマチ', '駒ケ嶺', 'コマガミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県相馬郡新地町', '07', '07561', '9792700', '福島県', 'フクシマケン', '相馬郡新地町', 'ソウマグンシンチマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('139873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県相馬郡新地町埓木崎', '07', '07561', '9792701', '福島県', 'フクシマケン', '相馬郡新地町', 'ソウマグンシンチマチ', '埓木崎', 'ラチキザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県相馬郡新地町谷地小屋', '07', '07561', '9792702', '福島県', 'フクシマケン', '相馬郡新地町', 'ソウマグンシンチマチ', '谷地小屋', 'ヤチゴヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県相馬郡新地町小川', '07', '07561', '9792703', '福島県', 'フクシマケン', '相馬郡新地町', 'ソウマグンシンチマチ', '小川', 'オガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県相馬郡新地町大戸浜', '07', '07561', '9792704', '福島県', 'フクシマケン', '相馬郡新地町', 'ソウマグンシンチマチ', '大戸浜', 'オオドハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県相馬郡新地町今泉', '07', '07561', '9792705', '福島県', 'フクシマケン', '相馬郡新地町', 'ソウマグンシンチマチ', '今泉', 'イマイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県相馬郡新地町杉目', '07', '07561', '9792706', '福島県', 'フクシマケン', '相馬郡新地町', 'ソウマグンシンチマチ', '杉目', 'スギノメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県相馬郡新地町真弓', '07', '07561', '9792707', '福島県', 'フクシマケン', '相馬郡新地町', 'ソウマグンシンチマチ', '真弓', 'マユミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県相馬郡新地町福田', '07', '07561', '9792708', '福島県', 'フクシマケン', '相馬郡新地町', 'ソウマグンシンチマチ', '福田', 'フクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市小川町柴原', '07', '07204', '9793111', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '小川町柴原', 'オガワマチシバハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市小川町上平', '07', '07204', '9793112', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '小川町上平', 'オガワマチウワダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市小川町三島', '07', '07204', '9793113', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '小川町三島', 'オガワマチミシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市小川町関場', '07', '07204', '9793114', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '小川町関場', 'オガワマチセキバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市小川町下小川', '07', '07204', '9793115', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '小川町下小川', 'オガワマチシモオガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市小川町西小川', '07', '07204', '9793121', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '小川町西小川', 'オガワマチニシオガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市小川町高萩', '07', '07204', '9793122', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '小川町高萩', 'オガワマチタカハギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市小川町塩田', '07', '07204', '9793123', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '小川町塩田', 'オガワマチシオダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市小川町上小川', '07', '07204', '9793124', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '小川町上小川', 'オガワマチカミオガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市小川町福岡', '07', '07204', '9793125', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '小川町福岡', 'オガワマチフクオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市平赤井', '07', '07204', '9793131', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '平赤井', 'タイラアカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市平赤井比良', '07', '07204', '9793132', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '平赤井比良', 'タイラアカイヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市川前町川前', '07', '07204', '9793201', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '川前町川前', 'カワマエマチカワマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市川前町下桶売', '07', '07204', '9793202', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '川前町下桶売', 'カワマエマチシモオケウリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市川前町上桶売', '07', '07204', '9793203', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '川前町上桶売', 'カワマエマチカミオケウリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '福島県いわき市川前町小白井', '07', '07204', '9793204', '福島県', 'フクシマケン', 'いわき市', 'イワキシ', '川前町小白井', 'カワマエマチオジロイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区', '04', '04101', '9800000', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('139899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区中江', '04', '04101', '9800001', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '中江', 'ナカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区福沢町', '04', '04101', '9800002', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '福沢町', 'フクザワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区小田原4丁目', '04', '04101', '9800003', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '小田原', 'オダワラ', null, null, '4丁目', '04チョウメ');
INSERT INTO `ms_addresses` VALUES ('139902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区小田原5丁目', '04', '04101', '9800003', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '小田原', 'オダワラ', null, null, '5丁目', '05チョウメ');
INSERT INTO `ms_addresses` VALUES ('139903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区小田原6丁目', '04', '04101', '9800003', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '小田原', 'オダワラ', null, null, '6丁目', '06チョウメ');
INSERT INTO `ms_addresses` VALUES ('139904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区小田原7丁目', '04', '04101', '9800003', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '小田原', 'オダワラ', null, null, '7丁目', '07チョウメ');
INSERT INTO `ms_addresses` VALUES ('139905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区小田原8丁目', '04', '04101', '9800003', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '小田原', 'オダワラ', null, null, '8丁目', '08チョウメ');
INSERT INTO `ms_addresses` VALUES ('139906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区宮町', '04', '04101', '9800004', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '宮町', 'ミヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区梅田町', '04', '04101', '9800005', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '梅田町', 'ウメダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区上杉', '04', '04101', '9800011', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '上杉', 'カミスギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区錦町', '04', '04101', '9800012', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '錦町', 'ニシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区花京院', '04', '04101', '9800013', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '花京院', 'カキョウイン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区本町', '04', '04101', '9800014', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区中央', '04', '04101', '9800021', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区五橋1丁目', '04', '04101', '9800022', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '五橋', 'イツツバシ', null, null, '1丁目', '01チョウメ');
INSERT INTO `ms_addresses` VALUES ('139914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区五橋2丁目', '04', '04101', '9800022', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '五橋', 'イツツバシ', null, null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('139915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区北目町', '04', '04101', '9800023', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '北目町', 'キタメマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区土樋1丁目', '04', '04101', '9800065', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '土樋', 'ツチトイ', null, null, '1丁目', '01チョウメ');
INSERT INTO `ms_addresses` VALUES ('139917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区木町通', '04', '04101', '9800801', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '木町通', 'キマチドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区二日町', '04', '04101', '9800802', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '二日町', 'フツカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区国分町', '04', '04101', '9800803', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '国分町', 'コクブンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区大町', '04', '04101', '9800804', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '大町', 'オオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区大手町', '04', '04101', '9800805', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '大手町', 'オオテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区一番町', '04', '04101', '9800811', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '一番町', 'イチバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区片平', '04', '04101', '9800812', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '片平', 'カタヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区米ケ袋', '04', '04101', '9800813', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '米ケ袋', 'コメガフクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区霊屋下', '04', '04101', '9800814', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '霊屋下', 'オタマヤシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区花壇', '04', '04101', '9800815', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '花壇', 'カダン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区春日町', '04', '04101', '9800821', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '春日町', 'カスガマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区立町', '04', '04101', '9800822', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '立町', 'タチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区桜ケ岡公園', '04', '04101', '9800823', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '桜ケ岡公園', 'サクラガオカコウエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区支倉町', '04', '04101', '9800824', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '支倉町', 'ハセクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区荒巻', '04', '04101', '9800845', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '荒巻', 'アラマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区川内明神横丁', '04', '04101', '9800851', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '川内明神横丁', 'カワウチミョウジンヨコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区川内川前丁', '04', '04101', '9800852', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '川内川前丁', 'カワウチカワマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区川内大工町', '04', '04101', '9800853', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '川内大工町', 'カワウチダイクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区川内中ノ瀬町', '04', '04101', '9800854', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '川内中ノ瀬町', 'カワウチナカノセマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区川内澱橋通', '04', '04101', '9800855', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '川内澱橋通', 'カワウチヨドミバシドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区青葉山', '04', '04101', '9800856', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '青葉山', 'アオバヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区川内元支倉', '04', '04101', '9800861', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '川内元支倉', 'カワウチモトハセクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区川内', '04', '04101', '9800862', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '川内', 'カワウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区川内追廻', '04', '04101', '9800863', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '川内追廻', 'カワウチオイマワシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区川内山屋敷', '04', '04101', '9800864', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '川内山屋敷', 'カワウチヤマヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区川内亀岡町', '04', '04101', '9800865', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '川内亀岡町', 'カワウチカメオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区川内三十人町', '04', '04101', '9800866', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '川内三十人町', 'カワウチサンジュウニンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区川内亀岡北裏丁', '04', '04101', '9800867', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '川内亀岡北裏丁', 'カワウチカメオカキタウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区八幡', '04', '04101', '9800871', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '八幡', 'ハチマン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区星陵町', '04', '04101', '9800872', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '星陵町', 'セイリョウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区広瀬町', '04', '04101', '9800873', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '広瀬町', 'ヒロセマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区角五郎', '04', '04101', '9800874', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '角五郎', 'ツノゴロウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡和寒町', '01', '01464', '0980100', '北海道', 'ホッカイドウ', '上川郡和寒町', 'カミカワグンワッサムチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('139950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡和寒町日ノ出', '01', '01464', '0980101', '北海道', 'ホッカイドウ', '上川郡和寒町', 'カミカワグンワッサムチョウ', '日ノ出', 'ヒノデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡和寒町大成', '01', '01464', '0980102', '北海道', 'ホッカイドウ', '上川郡和寒町', 'カミカワグンワッサムチョウ', '大成', 'タイセイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡和寒町北原', '01', '01464', '0980103', '北海道', 'ホッカイドウ', '上川郡和寒町', 'カミカワグンワッサムチョウ', '北原', 'キタハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡和寒町松岡', '01', '01464', '0980104', '北海道', 'ホッカイドウ', '上川郡和寒町', 'カミカワグンワッサムチョウ', '松岡', 'マツオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡和寒町三笠', '01', '01464', '0980111', '北海道', 'ホッカイドウ', '上川郡和寒町', 'カミカワグンワッサムチョウ', '三笠', 'ミカサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡和寒町三和', '01', '01464', '0980112', '北海道', 'ホッカイドウ', '上川郡和寒町', 'カミカワグンワッサムチョウ', '三和', 'サンワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡和寒町菊野', '01', '01464', '0980113', '北海道', 'ホッカイドウ', '上川郡和寒町', 'カミカワグンワッサムチョウ', '菊野', 'キクノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡和寒町西和', '01', '01464', '0980114', '北海道', 'ホッカイドウ', '上川郡和寒町', 'カミカワグンワッサムチョウ', '西和', 'セイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡和寒町福原', '01', '01464', '0980115', '北海道', 'ホッカイドウ', '上川郡和寒町', 'カミカワグンワッサムチョウ', '福原', 'フクハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡和寒町川西', '01', '01464', '0980121', '北海道', 'ホッカイドウ', '上川郡和寒町', 'カミカワグンワッサムチョウ', '川西', 'カワニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡和寒町中和', '01', '01464', '0980122', '北海道', 'ホッカイドウ', '上川郡和寒町', 'カミカワグンワッサムチョウ', '中和', 'チュウワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡和寒町東丘', '01', '01464', '0980123', '北海道', 'ホッカイドウ', '上川郡和寒町', 'カミカワグンワッサムチョウ', '東丘', 'ヒガシオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡和寒町南丘', '01', '01464', '0980124', '北海道', 'ホッカイドウ', '上川郡和寒町', 'カミカワグンワッサムチョウ', '南丘', 'ミナミオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡和寒町塩狩', '01', '01464', '0980125', '北海道', 'ホッカイドウ', '上川郡和寒町', 'カミカワグンワッサムチョウ', '塩狩', 'シオカリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡和寒町朝日', '01', '01464', '0980126', '北海道', 'ホッカイドウ', '上川郡和寒町', 'カミカワグンワッサムチョウ', '朝日', 'アサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡和寒町南町', '01', '01464', '0980131', '北海道', 'ホッカイドウ', '上川郡和寒町', 'カミカワグンワッサムチョウ', '南町', 'ミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡和寒町西町', '01', '01464', '0980132', '北海道', 'ホッカイドウ', '上川郡和寒町', 'カミカワグンワッサムチョウ', '西町', 'ニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡和寒町北町', '01', '01464', '0980133', '北海道', 'ホッカイドウ', '上川郡和寒町', 'カミカワグンワッサムチョウ', '北町', 'キタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡和寒町東町', '01', '01464', '0980134', '北海道', 'ホッカイドウ', '上川郡和寒町', 'カミカワグンワッサムチョウ', '東町', 'ヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡和寒町東和', '01', '01464', '0980135', '北海道', 'ホッカイドウ', '上川郡和寒町', 'カミカワグンワッサムチョウ', '東和', 'トウワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡剣淵町', '01', '01465', '0980300', '北海道', 'ホッカイドウ', '上川郡剣淵町', 'カミカワグンケンブチチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('139972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡剣淵町西町', '01', '01465', '0980331', '北海道', 'ホッカイドウ', '上川郡剣淵町', 'カミカワグンケンブチチョウ', '西町', 'ニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡剣淵町緑町', '01', '01465', '0980332', '北海道', 'ホッカイドウ', '上川郡剣淵町', 'カミカワグンケンブチチョウ', '緑町', 'ミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡剣淵町元町', '01', '01465', '0980333', '北海道', 'ホッカイドウ', '上川郡剣淵町', 'カミカワグンケンブチチョウ', '元町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡剣淵町屯田町', '01', '01465', '0980334', '北海道', 'ホッカイドウ', '上川郡剣淵町', 'カミカワグンケンブチチョウ', '屯田町', 'トンデンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡剣淵町南桜町', '01', '01465', '0980335', '北海道', 'ホッカイドウ', '上川郡剣淵町', 'カミカワグンケンブチチョウ', '南桜町', 'ナンオウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡剣淵町旭町', '01', '01465', '0980336', '北海道', 'ホッカイドウ', '上川郡剣淵町', 'カミカワグンケンブチチョウ', '旭町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡剣淵町西岡町', '01', '01465', '0980337', '北海道', 'ホッカイドウ', '上川郡剣淵町', 'カミカワグンケンブチチョウ', '西岡町', 'ニシオカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡剣淵町仲町', '01', '01465', '0980338', '北海道', 'ホッカイドウ', '上川郡剣淵町', 'カミカワグンケンブチチョウ', '仲町', 'ナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡剣淵町西原町', '01', '01465', '0980339', '北海道', 'ホッカイドウ', '上川郡剣淵町', 'カミカワグンケンブチチョウ', '西原町', 'ニシハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡剣淵町東町', '01', '01465', '0980341', '北海道', 'ホッカイドウ', '上川郡剣淵町', 'カミカワグンケンブチチョウ', '東町', 'ヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡剣淵町藤本町', '01', '01465', '0980342', '北海道', 'ホッカイドウ', '上川郡剣淵町', 'カミカワグンケンブチチョウ', '藤本町', 'フジモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道士別市多寄町', '01', '01220', '0980475', '北海道', 'ホッカイドウ', '士別市', 'シベツシ', '多寄町', 'タヨロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道名寄市風連町豊里', '01', '01221', '0980501', '北海道', 'ホッカイドウ', '名寄市', 'ナヨロシ', '風連町豊里', 'フウレンチョウトヨサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道名寄市風連町北栄町', '01', '01221', '0980502', '北海道', 'ホッカイドウ', '名寄市', 'ナヨロシ', '風連町北栄町', 'フウレンチョウホクエイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道名寄市風連町大町', '01', '01221', '0980503', '北海道', 'ホッカイドウ', '名寄市', 'ナヨロシ', '風連町大町', 'フウレンチョウオオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道名寄市風連町本町', '01', '01221', '0980504', '北海道', 'ホッカイドウ', '名寄市', 'ナヨロシ', '風連町本町', 'フウレンチョウモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道名寄市風連町南町', '01', '01221', '0980505', '北海道', 'ホッカイドウ', '名寄市', 'ナヨロシ', '風連町南町', 'フウレンチョウミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道名寄市風連町仲町', '01', '01221', '0980506', '北海道', 'ホッカイドウ', '名寄市', 'ナヨロシ', '風連町仲町', 'フウレンチョウナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道名寄市風連町西町', '01', '01221', '0980507', '北海道', 'ホッカイドウ', '名寄市', 'ナヨロシ', '風連町西町', 'フウレンチョウニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道名寄市風連町瑞生', '01', '01221', '0980508', '北海道', 'ホッカイドウ', '名寄市', 'ナヨロシ', '風連町瑞生', 'フウレンチョウズイショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道名寄市風連町西風連', '01', '01221', '0980509', '北海道', 'ホッカイドウ', '名寄市', 'ナヨロシ', '風連町西風連', 'フウレンチョウニシフウレン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道名寄市風連町新生町', '01', '01221', '0980511', '北海道', 'ホッカイドウ', '名寄市', 'ナヨロシ', '風連町新生町', 'フウレンチョウシンセイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道名寄市風連町東風連', '01', '01221', '0980512', '北海道', 'ホッカイドウ', '名寄市', 'ナヨロシ', '風連町東風連', 'フウレンチョウヒガシフウレン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道名寄市風連町池の上', '01', '01221', '0980513', '北海道', 'ホッカイドウ', '名寄市', 'ナヨロシ', '風連町池の上', 'フウレンチョウイケノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道名寄市風連町旭', '01', '01221', '0980514', '北海道', 'ホッカイドウ', '名寄市', 'ナヨロシ', '風連町旭', 'フウレンチョウアサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道名寄市風連町中央', '01', '01221', '0980515', '北海道', 'ホッカイドウ', '名寄市', 'ナヨロシ', '風連町中央', 'フウレンチョウチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('139999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道名寄市風連町緑町', '01', '01221', '0980516', '北海道', 'ホッカイドウ', '名寄市', 'ナヨロシ', '風連町緑町', 'フウレンチョウミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区中央SS30住友生命仙台中央ビル　1階', '04', '04101', '9806001', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '中央', 'チュウオウ', null, null, 'SS30住友生命仙台中央ビル　1階', 'SS30スミトモセイメイセンダイチュウオウビル　01カイ');
INSERT INTO `ms_addresses` VALUES ('140001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区中央SS30住友生命仙台中央ビル　2階', '04', '04101', '9806002', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '中央', 'チュウオウ', null, null, 'SS30住友生命仙台中央ビル　2階', 'SS30スミトモセイメイセンダイチュウオウビル　02カイ');
INSERT INTO `ms_addresses` VALUES ('140002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区中央SS30住友生命仙台中央ビル　3階', '04', '04101', '9806003', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '中央', 'チュウオウ', null, null, 'SS30住友生命仙台中央ビル　3階', 'SS30スミトモセイメイセンダイチュウオウビル　03カイ');
INSERT INTO `ms_addresses` VALUES ('140003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区中央SS30住友生命仙台中央ビル　4階', '04', '04101', '9806004', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '中央', 'チュウオウ', null, null, 'SS30住友生命仙台中央ビル　4階', 'SS30スミトモセイメイセンダイチュウオウビル　04カイ');
INSERT INTO `ms_addresses` VALUES ('140004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区中央SS30住友生命仙台中央ビル　5階', '04', '04101', '9806005', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '中央', 'チュウオウ', null, null, 'SS30住友生命仙台中央ビル　5階', 'SS30スミトモセイメイセンダイチュウオウビル　05カイ');
INSERT INTO `ms_addresses` VALUES ('140005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区中央SS30住友生命仙台中央ビル　6階', '04', '04101', '9806006', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '中央', 'チュウオウ', null, null, 'SS30住友生命仙台中央ビル　6階', 'SS30スミトモセイメイセンダイチュウオウビル　06カイ');
INSERT INTO `ms_addresses` VALUES ('140006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区中央SS30住友生命仙台中央ビル　7階', '04', '04101', '9806007', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '中央', 'チュウオウ', null, null, 'SS30住友生命仙台中央ビル　7階', 'SS30スミトモセイメイセンダイチュウオウビル　07カイ');
INSERT INTO `ms_addresses` VALUES ('140007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区中央SS30住友生命仙台中央ビル　8階', '04', '04101', '9806008', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '中央', 'チュウオウ', null, null, 'SS30住友生命仙台中央ビル　8階', 'SS30スミトモセイメイセンダイチュウオウビル　08カイ');
INSERT INTO `ms_addresses` VALUES ('140008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区中央SS30住友生命仙台中央ビル　9階', '04', '04101', '9806009', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '中央', 'チュウオウ', null, null, 'SS30住友生命仙台中央ビル　9階', 'SS30スミトモセイメイセンダイチュウオウビル　09カイ');
INSERT INTO `ms_addresses` VALUES ('140009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区中央SS30住友生命仙台中央ビル　10階', '04', '04101', '9806010', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '中央', 'チュウオウ', null, null, 'SS30住友生命仙台中央ビル　10階', 'SS30スミトモセイメイセンダイチュウオウビル　10カイ');
INSERT INTO `ms_addresses` VALUES ('140010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区中央SS30住友生命仙台中央ビル　11階', '04', '04101', '9806011', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '中央', 'チュウオウ', null, null, 'SS30住友生命仙台中央ビル　11階', 'SS30スミトモセイメイセンダイチュウオウビル　11カイ');
INSERT INTO `ms_addresses` VALUES ('140011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区中央SS30住友生命仙台中央ビル　12階', '04', '04101', '9806012', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '中央', 'チュウオウ', null, null, 'SS30住友生命仙台中央ビル　12階', 'SS30スミトモセイメイセンダイチュウオウビル　12カイ');
INSERT INTO `ms_addresses` VALUES ('140012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区中央SS30住友生命仙台中央ビル　13階', '04', '04101', '9806013', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '中央', 'チュウオウ', null, null, 'SS30住友生命仙台中央ビル　13階', 'SS30スミトモセイメイセンダイチュウオウビル　13カイ');
INSERT INTO `ms_addresses` VALUES ('140013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区中央SS30住友生命仙台中央ビル　14階', '04', '04101', '9806014', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '中央', 'チュウオウ', null, null, 'SS30住友生命仙台中央ビル　14階', 'SS30スミトモセイメイセンダイチュウオウビル　14カイ');
INSERT INTO `ms_addresses` VALUES ('140014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区中央SS30住友生命仙台中央ビル　15階', '04', '04101', '9806015', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '中央', 'チュウオウ', null, null, 'SS30住友生命仙台中央ビル　15階', 'SS30スミトモセイメイセンダイチュウオウビル　15カイ');
INSERT INTO `ms_addresses` VALUES ('140015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区中央SS30住友生命仙台中央ビル　16階', '04', '04101', '9806016', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '中央', 'チュウオウ', null, null, 'SS30住友生命仙台中央ビル　16階', 'SS30スミトモセイメイセンダイチュウオウビル　16カイ');
INSERT INTO `ms_addresses` VALUES ('140016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区中央SS30住友生命仙台中央ビル　17階', '04', '04101', '9806017', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '中央', 'チュウオウ', null, null, 'SS30住友生命仙台中央ビル　17階', 'SS30スミトモセイメイセンダイチュウオウビル　17カイ');
INSERT INTO `ms_addresses` VALUES ('140017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区中央SS30住友生命仙台中央ビル　18階', '04', '04101', '9806018', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '中央', 'チュウオウ', null, null, 'SS30住友生命仙台中央ビル　18階', 'SS30スミトモセイメイセンダイチュウオウビル　18カイ');
INSERT INTO `ms_addresses` VALUES ('140018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区中央SS30住友生命仙台中央ビル　19階', '04', '04101', '9806019', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '中央', 'チュウオウ', null, null, 'SS30住友生命仙台中央ビル　19階', 'SS30スミトモセイメイセンダイチュウオウビル　19カイ');
INSERT INTO `ms_addresses` VALUES ('140019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区中央SS30住友生命仙台中央ビル　20階', '04', '04101', '9806020', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '中央', 'チュウオウ', null, null, 'SS30住友生命仙台中央ビル　20階', 'SS30スミトモセイメイセンダイチュウオウビル　20カイ');
INSERT INTO `ms_addresses` VALUES ('140020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区中央SS30住友生命仙台中央ビル　21階', '04', '04101', '9806021', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '中央', 'チュウオウ', null, null, 'SS30住友生命仙台中央ビル　21階', 'SS30スミトモセイメイセンダイチュウオウビル　21カイ');
INSERT INTO `ms_addresses` VALUES ('140021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区中央SS30住友生命仙台中央ビル　22階', '04', '04101', '9806022', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '中央', 'チュウオウ', null, null, 'SS30住友生命仙台中央ビル　22階', 'SS30スミトモセイメイセンダイチュウオウビル　22カイ');
INSERT INTO `ms_addresses` VALUES ('140022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区中央SS30住友生命仙台中央ビル　23階', '04', '04101', '9806023', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '中央', 'チュウオウ', null, null, 'SS30住友生命仙台中央ビル　23階', 'SS30スミトモセイメイセンダイチュウオウビル　23カイ');
INSERT INTO `ms_addresses` VALUES ('140023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区中央SS30住友生命仙台中央ビル　24階', '04', '04101', '9806024', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '中央', 'チュウオウ', null, null, 'SS30住友生命仙台中央ビル　24階', 'SS30スミトモセイメイセンダイチュウオウビル　24カイ');
INSERT INTO `ms_addresses` VALUES ('140024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区中央SS30住友生命仙台中央ビル　25階', '04', '04101', '9806025', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '中央', 'チュウオウ', null, null, 'SS30住友生命仙台中央ビル　25階', 'SS30スミトモセイメイセンダイチュウオウビル　25カイ');
INSERT INTO `ms_addresses` VALUES ('140025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区中央SS30住友生命仙台中央ビル　26階', '04', '04101', '9806026', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '中央', 'チュウオウ', null, null, 'SS30住友生命仙台中央ビル　26階', 'SS30スミトモセイメイセンダイチュウオウビル　26カイ');
INSERT INTO `ms_addresses` VALUES ('140026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区中央SS30住友生命仙台中央ビル　27階', '04', '04101', '9806027', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '中央', 'チュウオウ', null, null, 'SS30住友生命仙台中央ビル　27階', 'SS30スミトモセイメイセンダイチュウオウビル　27カイ');
INSERT INTO `ms_addresses` VALUES ('140027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区中央SS30住友生命仙台中央ビル　28階', '04', '04101', '9806028', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '中央', 'チュウオウ', null, null, 'SS30住友生命仙台中央ビル　28階', 'SS30スミトモセイメイセンダイチュウオウビル　28カイ');
INSERT INTO `ms_addresses` VALUES ('140028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区中央SS30住友生命仙台中央ビル　29階', '04', '04101', '9806029', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '中央', 'チュウオウ', null, null, 'SS30住友生命仙台中央ビル　29階', 'SS30スミトモセイメイセンダイチュウオウビル　29カイ');
INSERT INTO `ms_addresses` VALUES ('140029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区中央SS30住友生命仙台中央ビル　30階', '04', '04101', '9806030', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '中央', 'チュウオウ', null, null, 'SS30住友生命仙台中央ビル　30階', 'SS30スミトモセイメイセンダイチュウオウビル　30カイ');
INSERT INTO `ms_addresses` VALUES ('140033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区中央SS30住友生命仙台中央ビル　', '04', '04101', '9806090', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '中央', 'チュウオウ', null, null, 'SS30住友生命仙台中央ビル　', 'SS30スミトモセイメイセンダイチュウオウビル　');
INSERT INTO `ms_addresses` VALUES ('140034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区中央アエル　1階', '04', '04101', '9806101', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '中央', 'チュウオウ', null, null, 'アエル　1階', 'アエル　01カイ');
INSERT INTO `ms_addresses` VALUES ('140035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区中央アエル　2階', '04', '04101', '9806102', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '中央', 'チュウオウ', null, null, 'アエル　2階', 'アエル　02カイ');
INSERT INTO `ms_addresses` VALUES ('140036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区中央アエル　3階', '04', '04101', '9806103', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '中央', 'チュウオウ', null, null, 'アエル　3階', 'アエル　03カイ');
INSERT INTO `ms_addresses` VALUES ('140037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区中央アエル　4階', '04', '04101', '9806104', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '中央', 'チュウオウ', null, null, 'アエル　4階', 'アエル　04カイ');
INSERT INTO `ms_addresses` VALUES ('140038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区中央アエル　5階', '04', '04101', '9806105', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '中央', 'チュウオウ', null, null, 'アエル　5階', 'アエル　05カイ');
INSERT INTO `ms_addresses` VALUES ('140039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区中央アエル　6階', '04', '04101', '9806106', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '中央', 'チュウオウ', null, null, 'アエル　6階', 'アエル　06カイ');
INSERT INTO `ms_addresses` VALUES ('140040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区中央アエル　7階', '04', '04101', '9806107', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '中央', 'チュウオウ', null, null, 'アエル　7階', 'アエル　07カイ');
INSERT INTO `ms_addresses` VALUES ('140041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区中央アエル　8階', '04', '04101', '9806108', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '中央', 'チュウオウ', null, null, 'アエル　8階', 'アエル　08カイ');
INSERT INTO `ms_addresses` VALUES ('140042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区中央アエル　9階', '04', '04101', '9806109', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '中央', 'チュウオウ', null, null, 'アエル　9階', 'アエル　09カイ');
INSERT INTO `ms_addresses` VALUES ('140043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区中央アエル　10階', '04', '04101', '9806110', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '中央', 'チュウオウ', null, null, 'アエル　10階', 'アエル　10カイ');
INSERT INTO `ms_addresses` VALUES ('140044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区中央アエル　11階', '04', '04101', '9806111', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '中央', 'チュウオウ', null, null, 'アエル　11階', 'アエル　11カイ');
INSERT INTO `ms_addresses` VALUES ('140045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区中央アエル　12階', '04', '04101', '9806112', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '中央', 'チュウオウ', null, null, 'アエル　12階', 'アエル　12カイ');
INSERT INTO `ms_addresses` VALUES ('140046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区中央アエル　13階', '04', '04101', '9806113', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '中央', 'チュウオウ', null, null, 'アエル　13階', 'アエル　13カイ');
INSERT INTO `ms_addresses` VALUES ('140047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区中央アエル　14階', '04', '04101', '9806114', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '中央', 'チュウオウ', null, null, 'アエル　14階', 'アエル　14カイ');
INSERT INTO `ms_addresses` VALUES ('140048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区中央アエル　15階', '04', '04101', '9806115', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '中央', 'チュウオウ', null, null, 'アエル　15階', 'アエル　15カイ');
INSERT INTO `ms_addresses` VALUES ('140049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区中央アエル　16階', '04', '04101', '9806116', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '中央', 'チュウオウ', null, null, 'アエル　16階', 'アエル　16カイ');
INSERT INTO `ms_addresses` VALUES ('140050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区中央アエル　17階', '04', '04101', '9806117', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '中央', 'チュウオウ', null, null, 'アエル　17階', 'アエル　17カイ');
INSERT INTO `ms_addresses` VALUES ('140051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区中央アエル　18階', '04', '04101', '9806118', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '中央', 'チュウオウ', null, null, 'アエル　18階', 'アエル　18カイ');
INSERT INTO `ms_addresses` VALUES ('140052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区中央アエル　19階', '04', '04101', '9806119', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '中央', 'チュウオウ', null, null, 'アエル　19階', 'アエル　19カイ');
INSERT INTO `ms_addresses` VALUES ('140053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区中央アエル　20階', '04', '04101', '9806120', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '中央', 'チュウオウ', null, null, 'アエル　20階', 'アエル　20カイ');
INSERT INTO `ms_addresses` VALUES ('140054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区中央アエル　21階', '04', '04101', '9806121', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '中央', 'チュウオウ', null, null, 'アエル　21階', 'アエル　21カイ');
INSERT INTO `ms_addresses` VALUES ('140055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区中央アエル　22階', '04', '04101', '9806122', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '中央', 'チュウオウ', null, null, 'アエル　22階', 'アエル　22カイ');
INSERT INTO `ms_addresses` VALUES ('140056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区中央アエル　23階', '04', '04101', '9806123', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '中央', 'チュウオウ', null, null, 'アエル　23階', 'アエル　23カイ');
INSERT INTO `ms_addresses` VALUES ('140057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区中央アエル　24階', '04', '04101', '9806124', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '中央', 'チュウオウ', null, null, 'アエル　24階', 'アエル　24カイ');
INSERT INTO `ms_addresses` VALUES ('140058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区中央アエル　25階', '04', '04101', '9806125', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '中央', 'チュウオウ', null, null, 'アエル　25階', 'アエル　25カイ');
INSERT INTO `ms_addresses` VALUES ('140059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区中央アエル　26階', '04', '04101', '9806126', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '中央', 'チュウオウ', null, null, 'アエル　26階', 'アエル　26カイ');
INSERT INTO `ms_addresses` VALUES ('140060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区中央アエル　27階', '04', '04101', '9806127', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '中央', 'チュウオウ', null, null, 'アエル　27階', 'アエル　27カイ');
INSERT INTO `ms_addresses` VALUES ('140061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区中央アエル　28階', '04', '04101', '9806128', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '中央', 'チュウオウ', null, null, 'アエル　28階', 'アエル　28カイ');
INSERT INTO `ms_addresses` VALUES ('140062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区中央アエル　29階', '04', '04101', '9806129', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '中央', 'チュウオウ', null, null, 'アエル　29階', 'アエル　29カイ');
INSERT INTO `ms_addresses` VALUES ('140063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区中央アエル　30階', '04', '04101', '9806130', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '中央', 'チュウオウ', null, null, 'アエル　30階', 'アエル　30カイ');
INSERT INTO `ms_addresses` VALUES ('140064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区中央アエル　31階', '04', '04101', '9806131', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '中央', 'チュウオウ', null, null, 'アエル　31階', 'アエル　31カイ');
INSERT INTO `ms_addresses` VALUES ('140067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区中央アエル　', '04', '04101', '9806190', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '中央', 'チュウオウ', null, null, 'アエル　', 'アエル　');
INSERT INTO `ms_addresses` VALUES ('140068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道名寄市風連町日進', '01', '01221', '0980631', '北海道', 'ホッカイドウ', '名寄市', 'ナヨロシ', '風連町日進', 'フウレンチョウニッシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道名寄市風連町東生', '01', '01221', '0980632', '北海道', 'ホッカイドウ', '名寄市', 'ナヨロシ', '風連町東生', 'フウレンチョウトウセイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県宮城郡利府町', '04', '04406', '9810100', '宮城県', 'ミヤギケン', '宮城郡利府町', 'ミヤギグンリフチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('140187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県宮城郡利府町赤沼', '04', '04406', '9810101', '宮城県', 'ミヤギケン', '宮城郡利府町', 'ミヤギグンリフチョウ', '赤沼', 'アカヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県宮城郡利府町春日', '04', '04406', '9810102', '宮城県', 'ミヤギケン', '宮城郡利府町', 'ミヤギグンリフチョウ', '春日', 'カスガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県宮城郡利府町森郷', '04', '04406', '9810103', '宮城県', 'ミヤギケン', '宮城郡利府町', 'ミヤギグンリフチョウ', '森郷', 'モリゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県宮城郡利府町中央', '04', '04406', '9810104', '宮城県', 'ミヤギケン', '宮城郡利府町', 'ミヤギグンリフチョウ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県宮城郡利府町葉山', '04', '04406', '9810105', '宮城県', 'ミヤギケン', '宮城郡利府町', 'ミヤギグンリフチョウ', '葉山', 'ハヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県宮城郡利府町加瀬', '04', '04406', '9810111', '宮城県', 'ミヤギケン', '宮城郡利府町', 'ミヤギグンリフチョウ', '加瀬', 'カセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県宮城郡利府町利府', '04', '04406', '9810112', '宮城県', 'ミヤギケン', '宮城郡利府町', 'ミヤギグンリフチョウ', '利府', 'リフ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県宮城郡利府町飯土井', '04', '04406', '9810113', '宮城県', 'ミヤギケン', '宮城郡利府町', 'ミヤギグンリフチョウ', '飯土井', 'イイドイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県宮城郡利府町神谷沢', '04', '04406', '9810121', '宮城県', 'ミヤギケン', '宮城郡利府町', 'ミヤギグンリフチョウ', '神谷沢', 'カミヤサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県宮城郡利府町菅谷', '04', '04406', '9810122', '宮城県', 'ミヤギケン', '宮城郡利府町', 'ミヤギグンリフチョウ', '菅谷', 'スガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県宮城郡利府町沢乙', '04', '04406', '9810123', '宮城県', 'ミヤギケン', '宮城郡利府町', 'ミヤギグンリフチョウ', '沢乙', 'サワオト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県宮城郡利府町沢乙東', '04', '04406', '9810124', '宮城県', 'ミヤギケン', '宮城郡利府町', 'ミヤギグンリフチョウ', '沢乙東', 'サワオトヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県宮城郡利府町青山', '04', '04406', '9810131', '宮城県', 'ミヤギケン', '宮城郡利府町', 'ミヤギグンリフチョウ', '青山', 'アオヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県宮城郡利府町花園', '04', '04406', '9810132', '宮城県', 'ミヤギケン', '宮城郡利府町', 'ミヤギグンリフチョウ', '花園', 'ハナゾノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県宮城郡利府町青葉台', '04', '04406', '9810133', '宮城県', 'ミヤギケン', '宮城郡利府町', 'ミヤギグンリフチョウ', '青葉台', 'アオバダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県宮城郡利府町しらかし台', '04', '04406', '9810134', '宮城県', 'ミヤギケン', '宮城郡利府町', 'ミヤギグンリフチョウ', 'しらかし台', 'シラカシダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県宮城郡利府町菅谷台', '04', '04406', '9810135', '宮城県', 'ミヤギケン', '宮城郡利府町', 'ミヤギグンリフチョウ', '菅谷台', 'スガヤダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県宮城郡利府町皆の丘', '04', '04406', '9810136', '宮城県', 'ミヤギケン', '宮城郡利府町', 'ミヤギグンリフチョウ', '皆の丘', 'ミナノオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県宮城郡松島町', '04', '04401', '9810200', '宮城県', 'ミヤギケン', '宮城郡松島町', 'ミヤギグンマツシママチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('140206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県宮城郡松島町竹谷', '04', '04401', '9810201', '宮城県', 'ミヤギケン', '宮城郡松島町', 'ミヤギグンマツシママチ', '竹谷', 'タケヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県宮城郡松島町北小泉', '04', '04401', '9810202', '宮城県', 'ミヤギケン', '宮城郡松島町', 'ミヤギグンマツシママチ', '北小泉', 'キタコイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県宮城郡松島町根廻', '04', '04401', '9810203', '宮城県', 'ミヤギケン', '宮城郡松島町', 'ミヤギグンマツシママチ', '根廻', 'ネマワリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県宮城郡松島町初原', '04', '04401', '9810204', '宮城県', 'ミヤギケン', '宮城郡松島町', 'ミヤギグンマツシママチ', '初原', 'ハツバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県宮城郡松島町幡谷', '04', '04401', '9810205', '宮城県', 'ミヤギケン', '宮城郡松島町', 'ミヤギグンマツシママチ', '幡谷', 'ハタヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県宮城郡松島町手樽', '04', '04401', '9810211', '宮城県', 'ミヤギケン', '宮城郡松島町', 'ミヤギグンマツシママチ', '手樽', 'テタル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県宮城郡松島町磯崎', '04', '04401', '9810212', '宮城県', 'ミヤギケン', '宮城郡松島町', 'ミヤギグンマツシママチ', '磯崎', 'イソザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県宮城郡松島町松島', '04', '04401', '9810213', '宮城県', 'ミヤギケン', '宮城郡松島町', 'ミヤギグンマツシママチ', '松島', 'マツシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県宮城郡松島町桜渡戸', '04', '04401', '9810214', '宮城県', 'ミヤギケン', '宮城郡松島町', 'ミヤギグンマツシママチ', '桜渡戸', 'サクラワタシド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県宮城郡松島町高城', '04', '04401', '9810215', '宮城県', 'ミヤギケン', '宮城郡松島町', 'ミヤギグンマツシママチ', '高城', 'タカギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県東松島市牛網', '04', '04214', '9810301', '宮城県', 'ミヤギケン', '東松島市', 'ヒガシマツシマシ', '牛網', 'ウシアミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県東松島市浜市', '04', '04214', '9810302', '宮城県', 'ミヤギケン', '東松島市', 'ヒガシマツシマシ', '浜市', 'ハマイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県東松島市小野', '04', '04214', '9810303', '宮城県', 'ミヤギケン', '東松島市', 'ヒガシマツシマシ', '小野', 'オノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県東松島市川下', '04', '04214', '9810304', '宮城県', 'ミヤギケン', '東松島市', 'ヒガシマツシマシ', '川下', 'カワクダリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県東松島市上下堤', '04', '04214', '9810305', '宮城県', 'ミヤギケン', '東松島市', 'ヒガシマツシマシ', '上下堤', 'ジョウゲツツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県東松島市西福田', '04', '04214', '9810306', '宮城県', 'ミヤギケン', '東松島市', 'ヒガシマツシマシ', '西福田', 'ニシフクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県東松島市新田', '04', '04214', '9810307', '宮城県', 'ミヤギケン', '東松島市', 'ヒガシマツシマシ', '新田', 'ニツタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県東松島市高松', '04', '04214', '9810308', '宮城県', 'ミヤギケン', '東松島市', 'ヒガシマツシマシ', '高松', 'タカマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県東松島市根古', '04', '04214', '9810309', '宮城県', 'ミヤギケン', '東松島市', 'ヒガシマツシマシ', '根古', 'ネコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県東松島市野蒜', '04', '04214', '9810411', '宮城県', 'ミヤギケン', '東松島市', 'ヒガシマツシマシ', '野蒜', 'ノビル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県東松島市宮戸', '04', '04214', '9810412', '宮城県', 'ミヤギケン', '東松島市', 'ヒガシマツシマシ', '宮戸', 'ミヤト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県東松島市新東名', '04', '04214', '9810413', '宮城県', 'ミヤギケン', '東松島市', 'ヒガシマツシマシ', '新東名', 'シントウナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県東松島市大塚', '04', '04214', '9810414', '宮城県', 'ミヤギケン', '東松島市', 'ヒガシマツシマシ', '大塚', 'オオツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県東松島市浅井', '04', '04214', '9810415', '宮城県', 'ミヤギケン', '東松島市', 'ヒガシマツシマシ', '浅井', 'アサイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県東松島市', '04', '04214', '9810500', '宮城県', 'ミヤギケン', '東松島市', 'ヒガシマツシマシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('140231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県東松島市赤井', '04', '04214', '9810501', '宮城県', 'ミヤギケン', '東松島市', 'ヒガシマツシマシ', '赤井', 'アカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県東松島市大曲', '04', '04214', '9810502', '宮城県', 'ミヤギケン', '東松島市', 'ヒガシマツシマシ', '大曲', 'オオマガリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県東松島市矢本', '04', '04214', '9810503', '宮城県', 'ミヤギケン', '東松島市', 'ヒガシマツシマシ', '矢本', 'ヤモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県東松島市小松', '04', '04214', '9810504', '宮城県', 'ミヤギケン', '東松島市', 'ヒガシマツシマシ', '小松', 'コマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県東松島市大塩', '04', '04214', '9810505', '宮城県', 'ミヤギケン', '東松島市', 'ヒガシマツシマシ', '大塩', 'オオシオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区北根黒松', '04', '04101', '9810901', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '北根黒松', 'キタネクロマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区北根', '04', '04101', '9810902', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '北根', 'キタネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区台原森林公園', '04', '04101', '9810903', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '台原森林公園', 'ダイノハラシンリンコウエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区旭ケ丘', '04', '04101', '9810904', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '旭ケ丘', 'アサヒガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区小松島', '04', '04101', '9810905', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '小松島', 'コマツシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区小松島新堤', '04', '04101', '9810906', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '小松島新堤', 'コマツシマシンツツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区高松', '04', '04101', '9810907', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '高松', 'タカマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区東照宮', '04', '04101', '9810908', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '東照宮', 'トウショウグウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区台原', '04', '04101', '9810911', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '台原', 'ダイノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区堤町', '04', '04101', '9810912', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '堤町', 'ツツミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区昭和町', '04', '04101', '9810913', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '昭和町', 'ショウワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区堤通雨宮町', '04', '04101', '9810914', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '堤通雨宮町', 'ツツミドオリアマミヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区通町', '04', '04101', '9810915', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '通町', 'トオリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区青葉町', '04', '04101', '9810916', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '青葉町', 'アオバマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区葉山町', '04', '04101', '9810917', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '葉山町', 'ハヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区藤松', '04', '04101', '9810921', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '藤松', 'フジマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区鷺ケ森', '04', '04101', '9810922', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '鷺ケ森', 'サギガモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区東勝山', '04', '04101', '9810923', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '東勝山', 'ヒガシカツヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区双葉ケ丘', '04', '04101', '9810924', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '双葉ケ丘', 'フタバガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区北山', '04', '04101', '9810931', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '北山', 'キタヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区木町', '04', '04101', '9810932', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '木町', 'キマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区柏木', '04', '04101', '9810933', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '柏木', 'カシワギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区新坂町', '04', '04101', '9810934', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '新坂町', 'ニイザカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区三条町', '04', '04101', '9810935', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '三条町', 'サンジョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区千代田町', '04', '04101', '9810936', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '千代田町', 'チヨダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区菊田町', '04', '04101', '9810941', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '菊田町', 'キクタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区貝ケ森', '04', '04101', '9810942', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '貝ケ森', 'カイガモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区国見', '04', '04101', '9810943', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '国見', 'クニミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区子平町', '04', '04101', '9810944', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '子平町', 'シヘイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区荒巻西雷神', '04', '04101', '9810945', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '荒巻', 'アラマキ', null, null, '西雷神', 'ニシライジン');
INSERT INTO `ms_addresses` VALUES ('140266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区荒巻仁田谷地', '04', '04101', '9810945', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '荒巻', 'アラマキ', null, null, '仁田谷地', 'ニタヤチ');
INSERT INTO `ms_addresses` VALUES ('140267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区荒巻坊主門', '04', '04101', '9810945', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '荒巻', 'アラマキ', null, null, '坊主門', 'ボウズモン');
INSERT INTO `ms_addresses` VALUES ('140268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区滝道', '04', '04101', '9810951', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '滝道', 'タキミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区中山', '04', '04101', '9810952', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '中山', 'ナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区西勝山', '04', '04101', '9810953', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '西勝山', 'ニシカツヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区川平', '04', '04101', '9810954', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '川平', 'カワダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区桜ケ丘', '04', '04101', '9810961', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '桜ケ丘', 'サクラガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区水の森', '04', '04101', '9810962', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '水の森', 'ミズノモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区あけぼの町', '04', '04101', '9810963', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', 'あけぼの町', 'アケボノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区荒巻中央', '04', '04101', '9810964', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '荒巻中央', 'アラマキチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区荒巻神明町', '04', '04101', '9810965', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '荒巻神明町', 'アラマキシンメイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区荒巻本沢', '04', '04101', '9810966', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '荒巻本沢', 'アラマキホンザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区山手町', '04', '04101', '9810967', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '山手町', 'ヤマテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市太白区四郎丸', '04', '04104', '9811101', '宮城県', 'ミヤギケン', '仙台市太白区', 'センダイシタイハクク', '四郎丸', 'シロウマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市太白区袋原', '04', '04104', '9811102', '宮城県', 'ミヤギケン', '仙台市太白区', 'センダイシタイハクク', '袋原', 'フクロバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市太白区中田町', '04', '04104', '9811103', '宮城県', 'ミヤギケン', '仙台市太白区', 'センダイシタイハクク', '中田町', 'ナカダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市太白区中田', '04', '04104', '9811104', '宮城県', 'ミヤギケン', '仙台市太白区', 'センダイシタイハクク', '中田', 'ナカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市太白区西中田', '04', '04104', '9811105', '宮城県', 'ミヤギケン', '仙台市太白区', 'センダイシタイハクク', '西中田', 'ニシナカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市太白区柳生', '04', '04104', '9811106', '宮城県', 'ミヤギケン', '仙台市太白区', 'センダイシタイハクク', '柳生', 'ヤナギウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市太白区東中田', '04', '04104', '9811107', '宮城県', 'ミヤギケン', '仙台市太白区', 'センダイシタイハクク', '東中田', 'ヒガシナカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県名取市', '04', '04207', '9811200', '宮城県', 'ミヤギケン', '名取市', 'ナトリシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('140287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県名取市下増田', '04', '04207', '9811201', '宮城県', 'ミヤギケン', '名取市', 'ナトリシ', '下増田', 'シモマスダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県名取市高柳', '04', '04207', '9811211', '宮城県', 'ミヤギケン', '名取市', 'ナトリシ', '高柳', 'タカヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県名取市小塚原', '04', '04207', '9811212', '宮城県', 'ミヤギケン', '名取市', 'ナトリシ', '小塚原', 'コヅカハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県名取市閖上', '04', '04207', '9811213', '宮城県', 'ミヤギケン', '名取市', 'ナトリシ', '閖上', 'ユリアゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県名取市杉ケ袋', '04', '04207', '9811214', '宮城県', 'ミヤギケン', '名取市', 'ナトリシ', '杉ケ袋', 'スギガフクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県名取市牛野', '04', '04207', '9811215', '宮城県', 'ミヤギケン', '名取市', 'ナトリシ', '牛野', 'ウシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県名取市大曲', '04', '04207', '9811216', '宮城県', 'ミヤギケン', '名取市', 'ナトリシ', '大曲', 'オオマガリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県名取市田高', '04', '04207', '9811221', '宮城県', 'ミヤギケン', '名取市', 'ナトリシ', '田高', 'タコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県名取市上余田', '04', '04207', '9811222', '宮城県', 'ミヤギケン', '名取市', 'ナトリシ', '上余田', 'カミヨウデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県名取市下余田', '04', '04207', '9811223', '宮城県', 'ミヤギケン', '名取市', 'ナトリシ', '下余田', 'シモヨウデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県名取市増田', '04', '04207', '9811224', '宮城県', 'ミヤギケン', '名取市', 'ナトリシ', '増田', 'マスダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県名取市飯野坂', '04', '04207', '9811225', '宮城県', 'ミヤギケン', '名取市', 'ナトリシ', '飯野坂', 'イイノザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県名取市植松', '04', '04207', '9811226', '宮城県', 'ミヤギケン', '名取市', 'ナトリシ', '植松', 'ウエマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県名取市愛の杜', '04', '04207', '9811230', '宮城県', 'ミヤギケン', '名取市', 'ナトリシ', '愛の杜', 'アイノモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県名取市手倉田', '04', '04207', '9811231', '宮城県', 'ミヤギケン', '名取市', 'ナトリシ', '手倉田', 'テクラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県名取市大手町', '04', '04207', '9811232', '宮城県', 'ミヤギケン', '名取市', 'ナトリシ', '大手町', 'オオテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県名取市小山', '04', '04207', '9811233', '宮城県', 'ミヤギケン', '名取市', 'ナトリシ', '小山', 'オヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県名取市箱塚', '04', '04207', '9811234', '宮城県', 'ミヤギケン', '名取市', 'ナトリシ', '箱塚', 'ハコヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県名取市名取が丘', '04', '04207', '9811235', '宮城県', 'ミヤギケン', '名取市', 'ナトリシ', '名取が丘', 'ナトリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県名取市愛島小豆島', '04', '04207', '9811236', '宮城県', 'ミヤギケン', '名取市', 'ナトリシ', '愛島小豆島', 'メデシマアズキシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県名取市愛島北目', '04', '04207', '9811237', '宮城県', 'ミヤギケン', '名取市', 'ナトリシ', '愛島北目', 'メデシマキタメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県名取市愛島笠島', '04', '04207', '9811238', '宮城県', 'ミヤギケン', '名取市', 'ナトリシ', '愛島笠島', 'メデシマカサシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県名取市愛島塩手', '04', '04207', '9811239', '宮城県', 'ミヤギケン', '名取市', 'ナトリシ', '愛島塩手', 'メデシマシオテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県名取市高舘熊野堂', '04', '04207', '9811241', '宮城県', 'ミヤギケン', '名取市', 'ナトリシ', '高舘熊野堂', 'タカダテクマノドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県名取市高舘吉田', '04', '04207', '9811242', '宮城県', 'ミヤギケン', '名取市', 'ナトリシ', '高舘吉田', 'タカダテヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県名取市高舘川上', '04', '04207', '9811243', '宮城県', 'ミヤギケン', '名取市', 'ナトリシ', '高舘川上', 'タカダテカワカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県名取市那智が丘', '04', '04207', '9811244', '宮城県', 'ミヤギケン', '名取市', 'ナトリシ', '那智が丘', 'ナチガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県名取市ゆりが丘', '04', '04207', '9811245', '宮城県', 'ミヤギケン', '名取市', 'ナトリシ', 'ゆりが丘', 'ユリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県名取市相互台', '04', '04207', '9811246', '宮城県', 'ミヤギケン', '名取市', 'ナトリシ', '相互台', 'ソウゴダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県名取市みどり台', '04', '04207', '9811247', '宮城県', 'ミヤギケン', '名取市', 'ナトリシ', 'みどり台', 'ミドリダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県名取市相互台東', '04', '04207', '9811248', '宮城県', 'ミヤギケン', '名取市', 'ナトリシ', '相互台東', 'ソウゴダイヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県名取市愛島台', '04', '04207', '9811251', '宮城県', 'ミヤギケン', '名取市', 'ナトリシ', '愛島台', 'メデシマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県角田市', '04', '04208', '9811500', '宮城県', 'ミヤギケン', '角田市', 'カクダシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('140324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県角田市藤田', '04', '04208', '9811501', '宮城県', 'ミヤギケン', '角田市', 'カクダシ', '藤田', 'フジタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県角田市尾山', '04', '04208', '9811502', '宮城県', 'ミヤギケン', '角田市', 'カクダシ', '尾山', 'オヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県角田市島田', '04', '04208', '9811503', '宮城県', 'ミヤギケン', '角田市', 'カクダシ', '島田', 'シマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県角田市枝野', '04', '04208', '9811504', '宮城県', 'ミヤギケン', '角田市', 'カクダシ', '枝野', 'エダノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県角田市角田', '04', '04208', '9811505', '宮城県', 'ミヤギケン', '角田市', 'カクダシ', '角田', 'カクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県角田市花島', '04', '04208', '9811511', '宮城県', 'ミヤギケン', '角田市', 'カクダシ', '花島', 'ハナシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県角田市横倉', '04', '04208', '9811512', '宮城県', 'ミヤギケン', '角田市', 'カクダシ', '横倉', 'ヨコクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県角田市豊室', '04', '04208', '9811513', '宮城県', 'ミヤギケン', '角田市', 'カクダシ', '豊室', 'トヨムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県角田市小田', '04', '04208', '9811514', '宮城県', 'ミヤギケン', '角田市', 'カクダシ', '小田', 'オダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県角田市笠島', '04', '04208', '9811515', '宮城県', 'ミヤギケン', '角田市', 'カクダシ', '笠島', 'カサシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県角田市高倉', '04', '04208', '9811516', '宮城県', 'ミヤギケン', '角田市', 'カクダシ', '高倉', 'タカクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県角田市毛萱', '04', '04208', '9811517', '宮城県', 'ミヤギケン', '角田市', 'カクダシ', '毛萱', 'ケガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県角田市稲置', '04', '04208', '9811518', '宮城県', 'ミヤギケン', '角田市', 'カクダシ', '稲置', 'イナオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県角田市江尻', '04', '04208', '9811521', '宮城県', 'ミヤギケン', '角田市', 'カクダシ', '江尻', 'エジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県角田市佐倉', '04', '04208', '9811522', '宮城県', 'ミヤギケン', '角田市', 'カクダシ', '佐倉', 'サクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県角田市梶賀', '04', '04208', '9811523', '宮城県', 'ミヤギケン', '角田市', 'カクダシ', '梶賀', 'カジカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県角田市岡', '04', '04208', '9811524', '宮城県', 'ミヤギケン', '角田市', 'カクダシ', '岡', 'オカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県角田市君萱', '04', '04208', '9811525', '宮城県', 'ミヤギケン', '角田市', 'カクダシ', '君萱', 'キミガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県角田市神次郎', '04', '04208', '9811526', '宮城県', 'ミヤギケン', '角田市', 'カクダシ', '神次郎', 'ジンジロウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県角田市鳩原', '04', '04208', '9811531', '宮城県', 'ミヤギケン', '角田市', 'カクダシ', '鳩原', 'ハトバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県角田市小坂', '04', '04208', '9811532', '宮城県', 'ミヤギケン', '角田市', 'カクダシ', '小坂', 'オサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県角田市平貫', '04', '04208', '9811533', '宮城県', 'ミヤギケン', '角田市', 'カクダシ', '平貫', 'ヒラヌキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県角田市坂津田', '04', '04208', '9811534', '宮城県', 'ミヤギケン', '角田市', 'カクダシ', '坂津田', 'サカツタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡下川町', '01', '01468', '0981200', '北海道', 'ホッカイドウ', '上川郡下川町', 'カミカワグンシモカワチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('140355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡下川町旭町', '01', '01468', '0981201', '北海道', 'ホッカイドウ', '上川郡下川町', 'カミカワグンシモカワチョウ', '旭町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡下川町緑町', '01', '01468', '0981202', '北海道', 'ホッカイドウ', '上川郡下川町', 'カミカワグンシモカワチョウ', '緑町', 'ミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡下川町共栄町', '01', '01468', '0981203', '北海道', 'ホッカイドウ', '上川郡下川町', 'カミカワグンシモカワチョウ', '共栄町', 'キョウエイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡下川町南町', '01', '01468', '0981204', '北海道', 'ホッカイドウ', '上川郡下川町', 'カミカワグンシモカワチョウ', '南町', 'ミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡下川町西町', '01', '01468', '0981205', '北海道', 'ホッカイドウ', '上川郡下川町', 'カミカワグンシモカワチョウ', '西町', 'ニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡下川町幸町', '01', '01468', '0981206', '北海道', 'ホッカイドウ', '上川郡下川町', 'カミカワグンシモカワチョウ', '幸町', 'サイワイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡下川町錦町', '01', '01468', '0981207', '北海道', 'ホッカイドウ', '上川郡下川町', 'カミカワグンシモカワチョウ', '錦町', 'ニシキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町', '04', '04341', '9812100', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('140363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町舘矢間木沼', '04', '04341', '9812101', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '舘矢間木沼', 'タテヤマキヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町舘矢間舘山', '04', '04341', '9812102', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '舘矢間舘山', 'タテヤマタテヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町舘矢間山田', '04', '04341', '9812103', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '舘矢間山田', 'タテヤマヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町大舘', '04', '04341', '9812104', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '大舘', 'オオダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町舘矢間松掛', '04', '04341', '9812105', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '舘矢間松掛', 'タテヤママツカケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町木沼', '04', '04341', '9812106', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '木沼', 'キヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡下川町珊瑠', '01', '01468', '0981211', '北海道', 'ホッカイドウ', '上川郡下川町', 'カミカワグンシモカワチョウ', '珊瑠', 'サンル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町神明', '04', '04341', '9812111', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '神明', 'シンメイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町神明東', '04', '04341', '9812111', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '神明東', 'シンメイヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町神明南', '04', '04341', '9812111', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '神明南', 'シンメイミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町石渕', '04', '04341', '9812112', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '石渕', 'イシブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町作田', '04', '04341', '9812112', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '作田', 'サクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町城東', '04', '04341', '9812112', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '城東', 'ジョウトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町新町', '04', '04341', '9812112', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町平', '04', '04341', '9812112', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '平', 'タイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町寺内', '04', '04341', '9812112', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '寺内', 'テラウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町寺内前', '04', '04341', '9812112', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '寺内前', 'テラウチマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町羽山', '04', '04341', '9812112', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '羽山', 'ハヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町蛭田', '04', '04341', '9812112', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '蛭田', 'ヒルタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町渕ノ上', '04', '04341', '9812112', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '渕ノ上', 'フチノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町矢洗', '04', '04341', '9812112', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '矢洗', 'ヤアライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町越田', '04', '04341', '9812113', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '越田', 'コエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町羽入', '04', '04341', '9812113', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '羽入', 'ハニュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町羽入前', '04', '04341', '9812113', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '羽入前', 'ハニュウマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町宮脇', '04', '04341', '9812113', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '宮脇', 'ミヤノワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町赤堀', '04', '04341', '9812114', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '赤堀', 'アカボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町泉', '04', '04341', '9812114', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '泉', 'イズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町泉下', '04', '04341', '9812114', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '泉下', 'イズミシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町大目', '04', '04341', '9812114', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '大目', 'オオメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町北前', '04', '04341', '9812114', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '北前', 'キタマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町天王', '04', '04341', '9812114', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '天王', 'テンノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町稲場', '04', '04341', '9812115', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '稲場', 'イナバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町稲場東', '04', '04341', '9812115', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '稲場東', 'イナバヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町三瓶内', '04', '04341', '9812115', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '三瓶内', 'サンベイウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町沼', '04', '04341', '9812115', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '沼', 'ヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町前河原', '04', '04341', '9812115', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '前河原', 'マエカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町山古谷', '04', '04341', '9812115', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '山古谷', 'ヤマゴヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町石倉', '04', '04341', '9812116', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '石倉', 'イシクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町石倉前', '04', '04341', '9812116', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '石倉前', 'イシクラマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町石羽', '04', '04341', '9812116', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '石羽', 'イシパ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町上滝西', '04', '04341', '9812116', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '上滝西', 'カミダキニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町上滝東', '04', '04341', '9812116', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '上滝東', 'カミダキヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町桜渕', '04', '04341', '9812116', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '桜渕', 'サクラブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町新田西', '04', '04341', '9812116', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '新田西', 'シンデンニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町新田東', '04', '04341', '9812116', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '新田東', 'シンデンヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町新田向', '04', '04341', '9812116', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '新田向', 'シンデンムカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町高松', '04', '04341', '9812116', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '高松', 'タカマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町滝原', '04', '04341', '9812116', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '滝原', 'タキパラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町不動', '04', '04341', '9812116', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '不動', 'フドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町上林西', '04', '04341', '9812117', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '上林西', 'ジョウリンニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町上林東', '04', '04341', '9812117', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '上林東', 'ジョウリンヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町上林南', '04', '04341', '9812117', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '上林南', 'ジョウリンミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町中島', '04', '04341', '9812117', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '中島', 'ナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町畑中', '04', '04341', '9812117', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '畑中', 'ハタケナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町和田西', '04', '04341', '9812117', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '和田西', 'ワダニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町和田東', '04', '04341', '9812117', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '和田東', 'ワダヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡下川町北町', '01', '01468', '0981212', '北海道', 'ホッカイドウ', '上川郡下川町', 'カミカワグンシモカワチョウ', '北町', 'キタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町吉田', '04', '04341', '9812121', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '吉田', 'ヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町荒田', '04', '04341', '9812122', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '荒田', 'アラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町福沢', '04', '04341', '9812122', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '福沢', 'フクザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町福沢前', '04', '04341', '9812122', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '福沢前', 'フクザワマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町原場', '04', '04341', '9812123', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '原場', 'ゲンバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町柳田', '04', '04341', '9812123', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '柳田', 'ヤナギダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町切立', '04', '04341', '9812124', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '切立', 'キリタテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町椚塚', '04', '04341', '9812124', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '椚塚', 'クヌギヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町深田上', '04', '04341', '9812125', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '深田上', 'フカダカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町深田下', '04', '04341', '9812125', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '深田下', 'フカダシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町梅木坂', '04', '04341', '9812126', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '梅木坂', 'ウメキザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町金ケ作', '04', '04341', '9812126', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '金ケ作', 'カネガサク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町金ケ作前', '04', '04341', '9812126', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '金ケ作前', 'カネガサクマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町中ノ内', '04', '04341', '9812127', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '中ノ内', 'ナカノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡下川町三の橋', '01', '01468', '0981213', '北海道', 'ホッカイドウ', '上川郡下川町', 'カミカワグンシモカワチョウ', '三の橋', 'サンノハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町銀杏', '04', '04341', '9812131', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '銀杏', 'イチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町後屋敷', '04', '04341', '9812131', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '後屋敷', 'ウシロヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町五福谷', '04', '04341', '9812131', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '五福谷', 'ゴフクヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町四反田', '04', '04341', '9812131', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '四反田', 'シタンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町上地', '04', '04341', '9812131', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '上地', 'ジョウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町塚田', '04', '04341', '9812131', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '塚田', 'ツカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町坂上', '04', '04341', '9812131', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '坂上', 'バンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町牛子', '04', '04341', '9812132', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '牛子', 'ウシコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町薄平', '04', '04341', '9812132', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '薄平', 'ウスダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町馬渕', '04', '04341', '9812132', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '馬渕', 'マブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町向原', '04', '04341', '9812132', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '向原', 'ムカエパラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町蕨平', '04', '04341', '9812132', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '蕨平', 'ワラビダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町秋柴', '04', '04341', '9812133', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '秋柴', 'アキシバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町四重麦一', '04', '04341', '9812133', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '四重麦一', 'ヨエムギ01', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町四重麦二', '04', '04341', '9812133', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '四重麦二', 'ヨエムギ02', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町四重麦三', '04', '04341', '9812133', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '四重麦三', 'ヨエムギ03', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町四重麦四', '04', '04341', '9812133', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '四重麦四', 'ヨエムギ04', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町四重麦五', '04', '04341', '9812133', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '四重麦五', 'ヨエムギ05', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町四重麦六', '04', '04341', '9812133', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '四重麦六', 'ヨエムギ06', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町四重麦七', '04', '04341', '9812133', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '四重麦七', 'ヨエムギ07', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町峠上', '04', '04341', '9812134', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '峠上', 'トウゲカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町峠革踏石', '04', '04341', '9812134', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '峠革踏石', 'トウゲカワフミイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町峠小屋下', '04', '04341', '9812134', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '峠小屋下', 'トウゲコヤシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町峠境', '04', '04341', '9812134', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '峠境', 'トウゲサカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町峠坂下', '04', '04341', '9812134', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '峠坂下', 'トウゲサカシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町峠下', '04', '04341', '9812134', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '峠下', 'トウゲシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町峠滝沢', '04', '04341', '9812134', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '峠滝沢', 'トウゲタキザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町峠野上', '04', '04341', '9812134', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '峠野上', 'トウゲノジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町峠橋元', '04', '04341', '9812134', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '峠橋元', 'トウゲハシモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町峠前', '04', '04341', '9812134', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '峠前', 'トウゲマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町峠廻戸', '04', '04341', '9812134', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '峠廻戸', 'トウゲマワリド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町峠向', '04', '04341', '9812134', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '峠向', 'トウゲムカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町峠横向', '04', '04341', '9812134', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '峠横向', 'トウゲヨコムキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡下川町渓和', '01', '01468', '0981214', '北海道', 'ホッカイドウ', '上川郡下川町', 'カミカワグンシモカワチョウ', '渓和', 'ケイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町板山', '04', '04341', '9812141', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '板山', 'イタヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町梅木平', '04', '04341', '9812141', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '梅木平', 'ウメキダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町北沢', '04', '04341', '9812141', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '北沢', 'キタザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町小保田', '04', '04341', '9812141', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '小保田', 'コボタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町飯泉', '04', '04341', '9812142', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '飯泉', 'イイセン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町飯塚', '04', '04341', '9812142', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '飯塚', 'イイヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町飯塚下', '04', '04341', '9812142', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '飯塚下', 'イイヅカシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町竹谷', '04', '04341', '9812142', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '竹谷', 'タケヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町垂松', '04', '04341', '9812142', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '垂松', 'タレマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町日向', '04', '04341', '9812142', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '日向', 'ヒナタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町日向上', '04', '04341', '9812142', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '日向上', 'ヒナタカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町虚空蔵上', '04', '04341', '9812143', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '虚空蔵上', 'コクゾウカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町虚空蔵下', '04', '04341', '9812143', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '虚空蔵下', 'コクゾウシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町虚空蔵中', '04', '04341', '9812143', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '虚空蔵中', 'コクゾウナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町大畑', '04', '04341', '9812144', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '大畑', 'オオバタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町大畑前', '04', '04341', '9812144', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '大畑前', 'オオバタケマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町土ケ森', '04', '04341', '9812144', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '土ケ森', 'ツチガモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町武士沢', '04', '04341', '9812144', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '武士沢', 'ブシザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町由縄坂', '04', '04341', '9812144', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '由縄坂', 'ヨナザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町川田島', '04', '04341', '9812145', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '川田島', 'カワダシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町川田島菅', '04', '04341', '9812145', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '川田島菅', 'カワダシマスゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町川端', '04', '04341', '9812145', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '川端', 'カワバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町五本松', '04', '04341', '9812145', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '五本松', 'ゴホンマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町欠入上', '04', '04341', '9812146', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '欠入上', 'カケイリカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町欠入下', '04', '04341', '9812146', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '欠入下', 'カケイリシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町欠入菅', '04', '04341', '9812146', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '欠入菅', 'カケイリスゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町欠入前山', '04', '04341', '9812146', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '欠入前山', 'カケイリマエヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町関場', '04', '04341', '9812146', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '関場', 'セキバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町手掛橋中', '04', '04341', '9812146', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '手掛橋中', 'テカケバシナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町手掛橋西', '04', '04341', '9812146', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '手掛橋西', 'テカケバシニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町手掛橋東', '04', '04341', '9812146', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '手掛橋東', 'テカケバシヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町中道', '04', '04341', '9812146', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '中道', 'ナカミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町広町', '04', '04341', '9812146', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '広町', 'ヒロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡下川町班渓', '01', '01468', '0981215', '北海道', 'ホッカイドウ', '上川郡下川町', 'カミカワグンシモカワチョウ', '班渓', 'パンケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町千刈場', '04', '04341', '9812151', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '千刈場', 'センガリバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町鳥屋', '04', '04341', '9812152', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '鳥屋', 'トリヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町花田', '04', '04341', '9812152', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '花田', 'ハナダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町雁歌', '04', '04341', '9812153', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '雁歌', 'カリガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町大川口', '04', '04341', '9812154', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '大川口', 'オオカワグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町大川口前', '04', '04341', '9812154', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '大川口前', 'オオカワグチマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町片岸', '04', '04341', '9812155', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '片岸', 'カタギシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町山崎', '04', '04341', '9812155', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '山崎', 'ヤマザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町山崎前', '04', '04341', '9812155', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '山崎前', 'ヤマザキマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町うるし原', '04', '04341', '9812156', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', 'うるし原', 'ウルシバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町小塚', '04', '04341', '9812156', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '小塚', 'コヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町玉貫', '04', '04341', '9812156', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '玉貫', 'タマヌキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町菱川内', '04', '04341', '9812156', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '菱川内', 'ヒシカワウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡下川町上名寄', '01', '01468', '0981216', '北海道', 'ホッカイドウ', '上川郡下川町', 'カミカワグンシモカワチョウ', '上名寄', 'カミナヨロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町除南', '04', '04341', '9812161', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '除南', 'ノゾキミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町除北', '04', '04341', '9812162', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '除北', 'ノゾキキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町除', '04', '04341', '9812163', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '除', 'ノゾキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町町東', '04', '04341', '9812164', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '町東', 'マチヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町町西', '04', '04341', '9812165', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '町西', 'マチニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町高畑', '04', '04341', '9812166', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '高畑', 'タカバタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町田町南', '04', '04341', '9812167', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '田町南', 'タマチミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町田町北', '04', '04341', '9812168', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '田町北', 'タマチキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町下滝', '04', '04341', '9812171', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '下滝', 'シモタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町下滝南', '04', '04341', '9812171', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '下滝南', 'シモタキミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町船場', '04', '04341', '9812171', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '船場', 'フナバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町敷文西', '04', '04341', '9812172', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '敷文西', 'シキブミニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町敷文東', '04', '04341', '9812172', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '敷文東', 'シキブミヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町百合沢', '04', '04341', '9812172', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '百合沢', 'ユリサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町天炉', '04', '04341', '9812173', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '天炉', 'アマホド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町船越', '04', '04341', '9812173', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '船越', 'フナコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町山田上', '04', '04341', '9812173', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '山田上', 'ヤマダカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町山田下', '04', '04341', '9812173', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '山田下', 'ヤマダシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町岡巻', '04', '04341', '9812174', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '岡巻', 'オカマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町木落', '04', '04341', '9812174', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '木落', 'キオトシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町小倉', '04', '04341', '9812174', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '小倉', 'コグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町砂ノ入', '04', '04341', '9812174', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '砂ノ入', 'スナノイリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町子安', '04', '04341', '9812181', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '子安', 'コヤス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町高見北', '04', '04341', '9812181', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '高見北', 'タカミキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町高見南', '04', '04341', '9812181', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '高見南', 'タカミミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町曲木', '04', '04341', '9812181', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '曲木', 'マガキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町廻倉', '04', '04341', '9812181', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '廻倉', 'マワリグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町覆盆子原', '04', '04341', '9812182', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '覆盆子原', 'イチゴハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町大鹿野', '04', '04341', '9812182', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '大鹿野', 'オオガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町石釜', '04', '04341', '9812183', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '石釜', 'イシガマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町大高森', '04', '04341', '9812183', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '大高森', 'オオタカモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町萱森', '04', '04341', '9812183', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '萱森', 'カヤモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町塩ノ貝', '04', '04341', '9812183', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '塩ノ貝', 'シオノガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町塩ノ貝後', '04', '04341', '9812183', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '塩ノ貝後', 'シオノガイウシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町空焼', '04', '04341', '9812183', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '空焼', 'ソラヤキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町角切', '04', '04341', '9812183', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '角切', 'ツノキリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町鳥木', '04', '04341', '9812183', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '鳥木', 'トリキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町屋敷', '04', '04341', '9812183', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '屋敷', 'ヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町屋敷前', '04', '04341', '9812183', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '屋敷前', 'ヤシキマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町笠松', '04', '04341', '9812184', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '笠松', 'カサマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町柏木', '04', '04341', '9812184', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '柏木', 'カシワギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町坂下', '04', '04341', '9812184', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '坂下', 'サカシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町田ノ入', '04', '04341', '9812184', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '田ノ入', 'タノイリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町深田', '04', '04341', '9812184', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '深田', 'フカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町森', '04', '04341', '9812184', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '森', 'モリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町椚林', '04', '04341', '9812185', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '椚林', 'クヌギバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町滝の上', '04', '04341', '9812185', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '滝の上', 'タキノカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町羽出庭', '04', '04341', '9812185', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '羽出庭', 'ハデニワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町火打石', '04', '04341', '9812185', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '火打石', 'ヒウチイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町小坊木北', '04', '04341', '9812186', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '小坊木北', 'コボウギキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町小坊木南', '04', '04341', '9812186', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '小坊木南', 'コボウギミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町立沢北', '04', '04341', '9812186', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '立沢北', 'タツザワキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町立沢南', '04', '04341', '9812186', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '立沢南', 'タツザワミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町早坂', '04', '04341', '9812186', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '早坂', 'ハヤサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町荒屋敷', '04', '04341', '9812187', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '荒屋敷', 'アラヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町大巻北', '04', '04341', '9812187', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '大巻北', 'オオマキキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町大巻南', '04', '04341', '9812187', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '大巻南', 'オオマキミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町川原田', '04', '04341', '9812187', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '川原田', 'カワハラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町川前', '04', '04341', '9812187', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '川前', 'カワマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町北原東', '04', '04341', '9812187', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '北原東', 'キタハラヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町北原南', '04', '04341', '9812187', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '北原南', 'キタハラミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町袖五郎', '04', '04341', '9812187', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '袖五郎', 'ソデゴロウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町日照田', '04', '04341', '9812187', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '日照田', 'ヒデリダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町水沢', '04', '04341', '9812187', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '水沢', 'ミズサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町筆甫', '04', '04341', '9812201', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '筆甫', 'ヒッポ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町大張大蔵', '04', '04341', '9812301', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '大張大蔵', 'オオハリオオクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町大張川張', '04', '04341', '9812302', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '大張川張', 'オオハリカワハリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町耕野', '04', '04341', '9812303', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '耕野', 'コウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町小斎', '04', '04341', '9812401', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '小斎', 'コサイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町金山', '04', '04341', '9812402', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '金山', 'カネヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県伊具郡丸森町大内', '04', '04341', '9812501', '宮城県', 'ミヤギケン', '伊具郡丸森町', 'イググンマルモリマチ', '大内', 'オオウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市泉区', '04', '04105', '9813100', '宮城県', 'ミヤギケン', '仙台市泉区', 'センダイシイズミク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('140590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市泉区明石南', '04', '04105', '9813101', '宮城県', 'ミヤギケン', '仙台市泉区', 'センダイシイズミク', '明石南', 'アカイシミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市泉区向陽台', '04', '04105', '9813102', '宮城県', 'ミヤギケン', '仙台市泉区', 'センダイシイズミク', '向陽台', 'コウヨウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市泉区山の寺', '04', '04105', '9813103', '宮城県', 'ミヤギケン', '仙台市泉区', 'センダイシイズミク', '山の寺', 'ヤマノテラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市泉区永和台', '04', '04105', '9813104', '宮城県', 'ミヤギケン', '仙台市泉区', 'センダイシイズミク', '永和台', 'エイワダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市泉区天神沢', '04', '04105', '9813105', '宮城県', 'ミヤギケン', '仙台市泉区', 'センダイシイズミク', '天神沢', 'テンジンザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市泉区歩坂町', '04', '04105', '9813106', '宮城県', 'ミヤギケン', '仙台市泉区', 'センダイシイズミク', '歩坂町', 'ホサカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市泉区本田町', '04', '04105', '9813107', '宮城県', 'ミヤギケン', '仙台市泉区', 'センダイシイズミク', '本田町', 'ホンダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市泉区松陵', '04', '04105', '9813108', '宮城県', 'ミヤギケン', '仙台市泉区', 'センダイシイズミク', '松陵', 'ショウリョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市泉区鶴が丘', '04', '04105', '9813109', '宮城県', 'ミヤギケン', '仙台市泉区', 'センダイシイズミク', '鶴が丘', 'ツルガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市泉区松森', '04', '04105', '9813111', '宮城県', 'ミヤギケン', '仙台市泉区', 'センダイシイズミク', '松森', 'マツモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市泉区八乙女', '04', '04105', '9813112', '宮城県', 'ミヤギケン', '仙台市泉区', 'センダイシイズミク', '八乙女', 'ヤオトメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市泉区真美沢', '04', '04105', '9813113', '宮城県', 'ミヤギケン', '仙台市泉区', 'センダイシイズミク', '真美沢', 'マミサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市泉区友愛町', '04', '04105', '9813114', '宮城県', 'ミヤギケン', '仙台市泉区', 'センダイシイズミク', '友愛町', 'ユウアイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市泉区愛隣町', '04', '04105', '9813115', '宮城県', 'ミヤギケン', '仙台市泉区', 'センダイシイズミク', '愛隣町', 'アイリンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市泉区高玉町', '04', '04105', '9813116', '宮城県', 'ミヤギケン', '仙台市泉区', 'センダイシイズミク', '高玉町', 'タカダマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市泉区市名坂', '04', '04105', '9813117', '宮城県', 'ミヤギケン', '仙台市泉区', 'センダイシイズミク', '市名坂', 'イチナザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市泉区上谷刈', '04', '04105', '9813121', '宮城県', 'ミヤギケン', '仙台市泉区', 'センダイシイズミク', '上谷刈', 'カミヤガリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市泉区加茂', '04', '04105', '9813122', '宮城県', 'ミヤギケン', '仙台市泉区', 'センダイシイズミク', '加茂', 'カモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市泉区古内', '04', '04105', '9813123', '宮城県', 'ミヤギケン', '仙台市泉区', 'センダイシイズミク', '古内', 'フルウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市泉区野村', '04', '04105', '9813124', '宮城県', 'ミヤギケン', '仙台市泉区', 'センダイシイズミク', '野村', 'ノムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市泉区みずほ台', '04', '04105', '9813125', '宮城県', 'ミヤギケン', '仙台市泉区', 'センダイシイズミク', 'みずほ台', 'ミズホダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市泉区七北田', '04', '04105', '9813131', '宮城県', 'ミヤギケン', '仙台市泉区', 'センダイシイズミク', '七北田', 'ナナキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市泉区将監', '04', '04105', '9813132', '宮城県', 'ミヤギケン', '仙台市泉区', 'センダイシイズミク', '将監', 'ショウゲン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市泉区泉中央', '04', '04105', '9813133', '宮城県', 'ミヤギケン', '仙台市泉区', 'センダイシイズミク', '泉中央', 'イズミチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市泉区桂', '04', '04105', '9813134', '宮城県', 'ミヤギケン', '仙台市泉区', 'センダイシイズミク', '桂', 'カツラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市泉区八乙女中央', '04', '04105', '9813135', '宮城県', 'ミヤギケン', '仙台市泉区', 'センダイシイズミク', '八乙女中央', 'ヤオトメチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市泉区将監殿', '04', '04105', '9813136', '宮城県', 'ミヤギケン', '仙台市泉区', 'センダイシイズミク', '将監殿', 'ショウゲントノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市泉区大沢', '04', '04105', '9813137', '宮城県', 'ミヤギケン', '仙台市泉区', 'センダイシイズミク', '大沢', 'オオサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市泉区泉ケ丘', '04', '04105', '9813201', '宮城県', 'ミヤギケン', '仙台市泉区', 'センダイシイズミク', '泉ケ丘', 'イズミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市泉区北高森', '04', '04105', '9813202', '宮城県', 'ミヤギケン', '仙台市泉区', 'センダイシイズミク', '北高森', 'キタタカモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市泉区高森', '04', '04105', '9813203', '宮城県', 'ミヤギケン', '仙台市泉区', 'センダイシイズミク', '高森', 'タカモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市泉区寺岡', '04', '04105', '9813204', '宮城県', 'ミヤギケン', '仙台市泉区', 'センダイシイズミク', '寺岡', 'テラオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市泉区紫山', '04', '04105', '9813205', '宮城県', 'ミヤギケン', '仙台市泉区', 'センダイシイズミク', '紫山', 'ムラサキヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市泉区明通', '04', '04105', '9813206', '宮城県', 'ミヤギケン', '仙台市泉区', 'センダイシイズミク', '明通', 'アケドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市泉区長命ケ丘東', '04', '04105', '9813211', '宮城県', 'ミヤギケン', '仙台市泉区', 'センダイシイズミク', '長命ケ丘東', 'チョウメイガオカヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市泉区長命ケ丘', '04', '04105', '9813212', '宮城県', 'ミヤギケン', '仙台市泉区', 'センダイシイズミク', '長命ケ丘', 'チョウメイガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市泉区南中山', '04', '04105', '9813213', '宮城県', 'ミヤギケン', '仙台市泉区', 'センダイシイズミク', '南中山', 'ミナミナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市泉区館', '04', '04105', '9813214', '宮城県', 'ミヤギケン', '仙台市泉区', 'センダイシイズミク', '館', 'ヤカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市泉区北中山', '04', '04105', '9813215', '宮城県', 'ミヤギケン', '仙台市泉区', 'センダイシイズミク', '北中山', 'キタナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市泉区小角', '04', '04105', '9813216', '宮城県', 'ミヤギケン', '仙台市泉区', 'センダイシイズミク', '小角', 'オガク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市泉区実沢', '04', '04105', '9813217', '宮城県', 'ミヤギケン', '仙台市泉区', 'センダイシイズミク', '実沢', 'サネザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市泉区根白石', '04', '04105', '9813221', '宮城県', 'ミヤギケン', '仙台市泉区', 'センダイシイズミク', '根白石', 'ネノシロイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市泉区住吉台東', '04', '04105', '9813222', '宮城県', 'ミヤギケン', '仙台市泉区', 'センダイシイズミク', '住吉台東', 'スミヨシダイヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市泉区住吉台西', '04', '04105', '9813223', '宮城県', 'ミヤギケン', '仙台市泉区', 'センダイシイズミク', '住吉台西', 'スミヨシダイニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市泉区西田中', '04', '04105', '9813224', '宮城県', 'ミヤギケン', '仙台市泉区', 'センダイシイズミク', '西田中', 'ニシタナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市泉区福岡', '04', '04105', '9813225', '宮城県', 'ミヤギケン', '仙台市泉区', 'センダイシイズミク', '福岡', 'フクオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市泉区朴沢', '04', '04105', '9813226', '宮城県', 'ミヤギケン', '仙台市泉区', 'センダイシイズミク', '朴沢', 'ホウザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県黒川郡大和町学苑', '04', '04421', '9813271', '宮城県', 'ミヤギケン', '黒川郡大和町', 'クロカワグンタイワチョウ', '学苑', 'ガクエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県黒川郡富谷町', '04', '04423', '9813300', '宮城県', 'ミヤギケン', '黒川郡富谷町', 'クロカワグントミヤマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('140654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県黒川郡富谷町志戸田', '04', '04423', '9813301', '宮城県', 'ミヤギケン', '黒川郡富谷町', 'クロカワグントミヤマチ', '志戸田', 'シトダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県黒川郡富谷町三ノ関', '04', '04423', '9813302', '宮城県', 'ミヤギケン', '黒川郡富谷町', 'クロカワグントミヤマチ', '三ノ関', 'サンノセキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県黒川郡富谷町太子堂', '04', '04423', '9813303', '宮城県', 'ミヤギケン', '黒川郡富谷町', 'クロカワグントミヤマチ', '太子堂', 'タイシドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県黒川郡富谷町ひより台', '04', '04423', '9813304', '宮城県', 'ミヤギケン', '黒川郡富谷町', 'クロカワグントミヤマチ', 'ひより台', 'ヒヨリダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県黒川郡富谷町一ノ関', '04', '04423', '9813305', '宮城県', 'ミヤギケン', '黒川郡富谷町', 'クロカワグントミヤマチ', '一ノ関', 'イチノセキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県黒川郡富谷町二ノ関', '04', '04423', '9813306', '宮城県', 'ミヤギケン', '黒川郡富谷町', 'クロカワグントミヤマチ', '二ノ関', 'ニノセキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡下川町一の橋', '01', '01468', '0981331', '北海道', 'ホッカイドウ', '上川郡下川町', 'カミカワグンシモカワチョウ', '一の橋', 'イチノハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県黒川郡富谷町富谷', '04', '04423', '9813311', '宮城県', 'ミヤギケン', '黒川郡富谷町', 'クロカワグントミヤマチ', '富谷', 'トミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県黒川郡富谷町とちの木', '04', '04423', '9813312', '宮城県', 'ミヤギケン', '黒川郡富谷町', 'クロカワグントミヤマチ', 'とちの木', 'トチノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道上川郡下川町二の橋', '01', '01468', '0981332', '北海道', 'ホッカイドウ', '上川郡下川町', 'カミカワグンシモカワチョウ', '二の橋', 'ニノハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県黒川郡富谷町大童', '04', '04423', '9813321', '宮城県', 'ミヤギケン', '黒川郡富谷町', 'クロカワグントミヤマチ', '大童', 'オオワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県黒川郡富谷町今泉', '04', '04423', '9813322', '宮城県', 'ミヤギケン', '黒川郡富谷町', 'クロカワグントミヤマチ', '今泉', 'イマイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県黒川郡富谷町大亀', '04', '04423', '9813323', '宮城県', 'ミヤギケン', '黒川郡富谷町', 'クロカワグントミヤマチ', '大亀', 'オオガメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県黒川郡富谷町西成田', '04', '04423', '9813324', '宮城県', 'ミヤギケン', '黒川郡富谷町', 'クロカワグントミヤマチ', '西成田', 'ニシナリタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県黒川郡富谷町石積', '04', '04423', '9813325', '宮城県', 'ミヤギケン', '黒川郡富谷町', 'クロカワグントミヤマチ', '石積', 'イシヅモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県黒川郡富谷町明石', '04', '04423', '9813326', '宮城県', 'ミヤギケン', '黒川郡富谷町', 'クロカワグントミヤマチ', '明石', 'アカイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県黒川郡富谷町穀田', '04', '04423', '9813327', '宮城県', 'ミヤギケン', '黒川郡富谷町', 'クロカワグントミヤマチ', '穀田', 'コクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県黒川郡富谷町上桜木', '04', '04423', '9813328', '宮城県', 'ミヤギケン', '黒川郡富谷町', 'クロカワグントミヤマチ', '上桜木', 'カミサクラギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県黒川郡富谷町大清水', '04', '04423', '9813329', '宮城県', 'ミヤギケン', '黒川郡富谷町', 'クロカワグントミヤマチ', '大清水', 'オオシミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県黒川郡富谷町東向陽台', '04', '04423', '9813331', '宮城県', 'ミヤギケン', '黒川郡富谷町', 'クロカワグントミヤマチ', '東向陽台', 'ヒガシコウヨウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県黒川郡富谷町明石台', '04', '04423', '9813332', '宮城県', 'ミヤギケン', '黒川郡富谷町', 'クロカワグントミヤマチ', '明石台', 'アカイシダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県黒川郡富谷町成田', '04', '04423', '9813341', '宮城県', 'ミヤギケン', '黒川郡富谷町', 'クロカワグントミヤマチ', '成田', 'ナリタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県黒川郡富谷町鷹乃杜', '04', '04423', '9813351', '宮城県', 'ミヤギケン', '黒川郡富谷町', 'クロカワグントミヤマチ', '鷹乃杜', 'タカノモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県黒川郡富谷町富ケ丘', '04', '04423', '9813352', '宮城県', 'ミヤギケン', '黒川郡富谷町', 'クロカワグントミヤマチ', '富ケ丘', 'トミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県黒川郡富谷町あけの平', '04', '04423', '9813361', '宮城県', 'ミヤギケン', '黒川郡富谷町', 'クロカワグントミヤマチ', 'あけの平', 'アケノダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県黒川郡富谷町日吉台', '04', '04423', '9813362', '宮城県', 'ミヤギケン', '黒川郡富谷町', 'クロカワグントミヤマチ', '日吉台', 'ヒヨシダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県黒川郡富谷町杜乃橋', '04', '04423', '9813363', '宮城県', 'ミヤギケン', '黒川郡富谷町', 'クロカワグントミヤマチ', '杜乃橋', 'モリノハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県黒川郡大和町落合三ケ内', '04', '04421', '9813401', '宮城県', 'ミヤギケン', '黒川郡大和町', 'クロカワグンタイワチョウ', '落合三ケ内', 'オチアイサンガウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県黒川郡大和町落合報恩寺', '04', '04421', '9813402', '宮城県', 'ミヤギケン', '黒川郡大和町', 'クロカワグンタイワチョウ', '落合報恩寺', 'オチアイホウオンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県黒川郡大和町落合檜和田', '04', '04421', '9813403', '宮城県', 'ミヤギケン', '黒川郡大和町', 'クロカワグンタイワチョウ', '落合檜和田', 'オチアイヒワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県黒川郡大和町落合相川', '04', '04421', '9813404', '宮城県', 'ミヤギケン', '黒川郡大和町', 'クロカワグンタイワチョウ', '落合相川', 'オチアイアイカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県黒川郡大和町落合舞野', '04', '04421', '9813405', '宮城県', 'ミヤギケン', '黒川郡大和町', 'クロカワグンタイワチョウ', '落合舞野', 'オチアイマイノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県黒川郡大和町落合蒜袋', '04', '04421', '9813406', '宮城県', 'ミヤギケン', '黒川郡大和町', 'クロカワグンタイワチョウ', '落合蒜袋', 'オチアイヒルブクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県黒川郡大和町落合松坂', '04', '04421', '9813407', '宮城県', 'ミヤギケン', '黒川郡大和町', 'クロカワグンタイワチョウ', '落合松坂', 'オチアイマツサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県黒川郡大和町松坂平', '04', '04421', '9813408', '宮城県', 'ミヤギケン', '黒川郡大和町', 'クロカワグンタイワチョウ', '松坂平', 'マツサカダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県黒川郡大和町流通平', '04', '04421', '9813409', '宮城県', 'ミヤギケン', '黒川郡大和町', 'クロカワグンタイワチョウ', '流通平', 'リュウツウダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県黒川郡大和町鶴巣大平', '04', '04421', '9813411', '宮城県', 'ミヤギケン', '黒川郡大和町', 'クロカワグンタイワチョウ', '鶴巣大平', 'ツルスオオダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県黒川郡大和町鶴巣鳥屋', '04', '04421', '9813412', '宮城県', 'ミヤギケン', '黒川郡大和町', 'クロカワグンタイワチョウ', '鶴巣鳥屋', 'ツルストヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県黒川郡大和町鶴巣幕柳', '04', '04421', '9813413', '宮城県', 'ミヤギケン', '黒川郡大和町', 'クロカワグンタイワチョウ', '鶴巣幕柳', 'ツルスマクヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県黒川郡大和町鶴巣太田', '04', '04421', '9813414', '宮城県', 'ミヤギケン', '黒川郡大和町', 'クロカワグンタイワチョウ', '鶴巣太田', 'ツルスオオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県黒川郡大和町鶴巣小鶴沢', '04', '04421', '9813415', '宮城県', 'ミヤギケン', '黒川郡大和町', 'クロカワグンタイワチョウ', '鶴巣小鶴沢', 'ツルスオヅルサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県黒川郡大和町鶴巣山田', '04', '04421', '9813416', '宮城県', 'ミヤギケン', '黒川郡大和町', 'クロカワグンタイワチョウ', '鶴巣山田', 'ツルスヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県黒川郡大和町鶴巣北目大崎', '04', '04421', '9813417', '宮城県', 'ミヤギケン', '黒川郡大和町', 'クロカワグンタイワチョウ', '鶴巣北目大崎', 'ツルスキタメオオサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県黒川郡大和町鶴巣下草', '04', '04421', '9813418', '宮城県', 'ミヤギケン', '黒川郡大和町', 'クロカワグンタイワチョウ', '鶴巣下草', 'ツルスシモクサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県黒川郡大郷町', '04', '04422', '9813500', '宮城県', 'ミヤギケン', '黒川郡大郷町', 'クロカワグンオオサトチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('140706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県黒川郡大郷町大松沢', '04', '04422', '9813501', '宮城県', 'ミヤギケン', '黒川郡大郷町', 'クロカワグンオオサトチョウ', '大松沢', 'オオマツザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県黒川郡大郷町粕川', '04', '04422', '9813502', '宮城県', 'ミヤギケン', '黒川郡大郷町', 'クロカワグンオオサトチョウ', '粕川', 'カスカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県黒川郡大郷町石原', '04', '04422', '9813503', '宮城県', 'ミヤギケン', '黒川郡大郷町', 'クロカワグンオオサトチョウ', '石原', 'イシバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県黒川郡大郷町山崎', '04', '04422', '9813511', '宮城県', 'ミヤギケン', '黒川郡大郷町', 'クロカワグンオオサトチョウ', '山崎', 'ヤマサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県黒川郡大郷町不来内', '04', '04422', '9813512', '宮城県', 'ミヤギケン', '黒川郡大郷町', 'クロカワグンオオサトチョウ', '不来内', 'コズナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県黒川郡大郷町味明', '04', '04422', '9813513', '宮城県', 'ミヤギケン', '黒川郡大郷町', 'クロカワグンオオサトチョウ', '味明', 'ミアケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県黒川郡大郷町川内', '04', '04422', '9813514', '宮城県', 'ミヤギケン', '黒川郡大郷町', 'クロカワグンオオサトチョウ', '川内', 'カワウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県黒川郡大郷町羽生', '04', '04422', '9813515', '宮城県', 'ミヤギケン', '黒川郡大郷町', 'クロカワグンオオサトチョウ', '羽生', 'ハニュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県黒川郡大郷町中村', '04', '04422', '9813521', '宮城県', 'ミヤギケン', '黒川郡大郷町', 'クロカワグンオオサトチョウ', '中村', 'ナカムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県黒川郡大郷町東成田', '04', '04422', '9813522', '宮城県', 'ミヤギケン', '黒川郡大郷町', 'クロカワグンオオサトチョウ', '東成田', 'ヒガシナリタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県黒川郡大郷町土橋', '04', '04422', '9813523', '宮城県', 'ミヤギケン', '黒川郡大郷町', 'クロカワグンオオサトチョウ', '土橋', 'ツチハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県黒川郡大郷町鶉崎', '04', '04422', '9813524', '宮城県', 'ミヤギケン', '黒川郡大郷町', 'クロカワグンオオサトチョウ', '鶉崎', 'ウズラサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県黒川郡大和町', '04', '04421', '9813600', '宮城県', 'ミヤギケン', '黒川郡大和町', 'クロカワグンタイワチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('140720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県黒川郡大衡村', '04', '04424', '9813600', '宮城県', 'ミヤギケン', '黒川郡大衡村', 'クロカワグンオオヒラムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('140721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県黒川郡大衡村大瓜', '04', '04424', '9813601', '宮城県', 'ミヤギケン', '黒川郡大衡村', 'クロカワグンオオヒラムラ', '大瓜', 'オオウリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県黒川郡大衡村大衡', '04', '04424', '9813602', '宮城県', 'ミヤギケン', '黒川郡大衡村', 'クロカワグンオオヒラムラ', '大衡', 'オオヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県黒川郡大衡村沖の平', '04', '04424', '9813603', '宮城県', 'ミヤギケン', '黒川郡大衡村', 'クロカワグンオオヒラムラ', '沖の平', 'オキノダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県黒川郡大衡村駒場', '04', '04424', '9813604', '宮城県', 'ミヤギケン', '黒川郡大衡村', 'クロカワグンオオヒラムラ', '駒場', 'コマバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県黒川郡大衡村大森', '04', '04424', '9813605', '宮城県', 'ミヤギケン', '黒川郡大衡村', 'クロカワグンオオヒラムラ', '大森', 'オオモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県黒川郡大衡村桔梗平', '04', '04424', '9813606', '宮城県', 'ミヤギケン', '黒川郡大衡村', 'クロカワグンオオヒラムラ', '桔梗平', 'キキョウダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県黒川郡大衡村奥田', '04', '04424', '9813607', '宮城県', 'ミヤギケン', '黒川郡大衡村', 'クロカワグンオオヒラムラ', '奥田', 'オクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県黒川郡大衡村松の平', '04', '04424', '9813608', '宮城県', 'ミヤギケン', '黒川郡大衡村', 'クロカワグンオオヒラムラ', '松の平', 'マツノダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県黒川郡大和町吉岡', '04', '04421', '9813621', '宮城県', 'ミヤギケン', '黒川郡大和町', 'クロカワグンタイワチョウ', '吉岡', 'ヨシオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県黒川郡大和町もみじケ丘', '04', '04421', '9813622', '宮城県', 'ミヤギケン', '黒川郡大和町', 'クロカワグンタイワチョウ', 'もみじケ丘', 'モミジガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県黒川郡大和町小野', '04', '04421', '9813623', '宮城県', 'ミヤギケン', '黒川郡大和町', 'クロカワグンタイワチョウ', '小野', 'オノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県黒川郡大和町宮床', '04', '04421', '9813624', '宮城県', 'ミヤギケン', '黒川郡大和町', 'クロカワグンタイワチョウ', '宮床', 'ミヤトコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県黒川郡大和町吉田', '04', '04421', '9813625', '宮城県', 'ミヤギケン', '黒川郡大和町', 'クロカワグンタイワチョウ', '吉田', 'ヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県黒川郡大和町吉岡南', '04', '04421', '9813626', '宮城県', 'ミヤギケン', '黒川郡大和町', 'クロカワグンタイワチョウ', '吉岡南', 'ヨシオカミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県黒川郡大和町吉岡東', '04', '04421', '9813627', '宮城県', 'ミヤギケン', '黒川郡大和町', 'クロカワグンタイワチョウ', '吉岡東', 'ヨシオカヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県黒川郡大和町杜の丘', '04', '04421', '9813628', '宮城県', 'ミヤギケン', '黒川郡大和町', 'クロカワグンタイワチョウ', '杜の丘', 'モリノオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡色麻町', '04', '04444', '9814100', '宮城県', 'ミヤギケン', '加美郡色麻町', 'カミグンシカマチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('140748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡色麻町清水', '04', '04444', '9814101', '宮城県', 'ミヤギケン', '加美郡色麻町', 'カミグンシカマチョウ', '清水', 'キヨミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡色麻町高城', '04', '04444', '9814102', '宮城県', 'ミヤギケン', '加美郡色麻町', 'カミグンシカマチョウ', '高城', 'タカギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡色麻町高根', '04', '04444', '9814103', '宮城県', 'ミヤギケン', '加美郡色麻町', 'カミグンシカマチョウ', '高根', 'タカネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡色麻町平沢', '04', '04444', '9814104', '宮城県', 'ミヤギケン', '加美郡色麻町', 'カミグンシカマチョウ', '平沢', 'ヒラサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡色麻町吉田', '04', '04444', '9814105', '宮城県', 'ミヤギケン', '加美郡色麻町', 'カミグンシカマチョウ', '吉田', 'ヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡色麻町黒沢', '04', '04444', '9814111', '宮城県', 'ミヤギケン', '加美郡色麻町', 'カミグンシカマチョウ', '黒沢', 'クロサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡色麻町志津', '04', '04444', '9814112', '宮城県', 'ミヤギケン', '加美郡色麻町', 'カミグンシカマチョウ', '志津', 'シヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡色麻町一の関', '04', '04444', '9814121', '宮城県', 'ミヤギケン', '加美郡色麻町', 'カミグンシカマチョウ', '一の関', 'イチノセキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡色麻町四竃', '04', '04444', '9814122', '宮城県', 'ミヤギケン', '加美郡色麻町', 'カミグンシカマチョウ', '四竃', 'シカマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡色麻町大', '04', '04444', '9814131', '宮城県', 'ミヤギケン', '加美郡色麻町', 'カミグンシカマチョウ', '大', 'ダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡色麻町王城寺', '04', '04444', '9814141', '宮城県', 'ミヤギケン', '加美郡色麻町', 'カミグンシカマチョウ', '王城寺', 'オウジョウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡色麻町小栗山', '04', '04444', '9814151', '宮城県', 'ミヤギケン', '加美郡色麻町', 'カミグンシカマチョウ', '小栗山', 'コグリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町', '04', '04445', '9814200', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('140761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町上多田川', '04', '04445', '9814201', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '上多田川', 'カミタダガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町下多田川', '04', '04445', '9814202', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '下多田川', 'シモタダガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町菜切谷', '04', '04445', '9814203', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '菜切谷', 'ナギリヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡西興部村上興部', '01', '01562', '0981421', '北海道', 'ホッカイドウ', '紋別郡西興部村', 'モンベツグンニシオコッペムラ', '上興部', 'カミオコッペ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町上狼塚', '04', '04445', '9814211', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '上狼塚', 'カミオイノヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町下狼塚', '04', '04445', '9814212', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '下狼塚', 'シモオイノヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町平柳', '04', '04445', '9814213', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '平柳', 'ヒラヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡西興部村東興', '01', '01562', '0981422', '北海道', 'ホッカイドウ', '紋別郡西興部村', 'モンベツグンニシオコッペムラ', '東興', 'トウコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町四日市場', '04', '04445', '9814221', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '四日市場', 'ヨッカイチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町下新田', '04', '04445', '9814222', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '下新田', 'シモニイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町雑式ノ目', '04', '04445', '9814223', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '雑式ノ目', 'ゾウシキノメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町木伏', '04', '04445', '9814224', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '木伏', 'キップシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町新木伏', '04', '04445', '9814225', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '新木伏', 'シンキップシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町押登目', '04', '04445', '9814226', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '押登目', 'オシトメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町新川原', '04', '04445', '9814227', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '新川原', 'シンカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町鹿島越', '04', '04445', '9814228', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '鹿島越', 'カシマゴシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町薬師堂', '04', '04445', '9814229', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '薬師堂', 'ヤクシドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡西興部村札滑', '01', '01562', '0981423', '北海道', 'ホッカイドウ', '紋別郡西興部村', 'モンベツグンニシオコッペムラ', '札滑', 'サッコツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町百目木1番', '04', '04445', '9814231', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '百目木1番', 'ドウメキ01バン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町百目木2番', '04', '04445', '9814232', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '百目木2番', 'ドウメキ02バン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町百目木3番', '04', '04445', '9814233', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '百目木3番', 'ドウメキ03バン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町旧舘1番', '04', '04445', '9814234', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '旧舘1番', 'キュウカン01バン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町旧舘2番', '04', '04445', '9814235', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '旧舘2番', 'キュウカン02バン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡西興部村奥興部', '01', '01562', '0981424', '北海道', 'ホッカイドウ', '紋別郡西興部村', 'モンベツグンニシオコッペムラ', '奥興部', 'オクオコッペ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町南町', '04', '04445', '9814241', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '南町', 'ミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町町西', '04', '04445', '9814242', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '町西', 'マチニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町西町', '04', '04445', '9814251', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '西町', 'ニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町西田', '04', '04445', '9814252', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '西田', 'ニシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町大門', '04', '04445', '9814253', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '大門', 'ダイモン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町北町', '04', '04445', '9814254', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '北町', 'キタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町岡町', '04', '04445', '9814255', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '岡町', 'オカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町下川原', '04', '04445', '9814256', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '下川原', 'シモカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町町裏', '04', '04445', '9814261', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '町裏', 'マチウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町一本杉', '04', '04445', '9814262', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '一本杉', 'イッポンスギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町雁原', '04', '04445', '9814263', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '雁原', 'ガンバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町赤塚', '04', '04445', '9814264', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '赤塚', 'アカツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町矢越', '04', '04445', '9814265', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '矢越', 'ヤゴシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町羽場', '04', '04445', '9814271', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '羽場', 'ハバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町城生', '04', '04445', '9814272', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '城生', 'ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町上川原', '04', '04445', '9814273', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '上川原', 'カミカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町一本柳', '04', '04445', '9814274', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '一本柳', 'イッポンヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町穴畑', '04', '04445', '9814275', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '穴畑', 'アナハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町焼橋', '04', '04445', '9814276', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '焼橋', 'ヤキハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町樋田', '04', '04445', '9814301', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '樋田', 'トイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町下野目', '04', '04445', '9814302', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '下野目', 'シモノメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町前田下', '04', '04445', '9814303', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '前田下', 'マエダシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町久保', '04', '04445', '9814304', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '久保', 'クボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町宮田', '04', '04445', '9814305', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '宮田', 'ミヤタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町天王', '04', '04445', '9814306', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '天王', 'テンノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町北田', '04', '04445', '9814307', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '北田', 'キタダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町板橋', '04', '04445', '9814311', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '板橋', 'イタバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町月崎皆屋敷', '04', '04445', '9814312', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '月崎', 'ツキザキ', null, null, '皆屋敷', 'ミナヤシキ');
INSERT INTO `ms_addresses` VALUES ('140816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町二ノ坪', '04', '04445', '9814313', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '二ノ坪', 'ニノツボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町田中', '04', '04445', '9814314', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '田中', 'タナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町中嶋', '04', '04445', '9814315', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '中嶋', 'ナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町月崎', '04', '04445', '9814316', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '月崎', 'ツキザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町神山西', '04', '04445', '9814317', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '神山西', 'シンザンニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町下原', '04', '04445', '9814321', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '下原', 'シモハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町北下原', '04', '04445', '9814322', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '北下原', 'キタシモハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町石原', '04', '04445', '9814323', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '石原', 'イシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町北原', '04', '04445', '9814324', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '北原', 'キタハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町五百刈', '04', '04445', '9814325', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '五百刈', 'ゴヒャクガリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町北ノ口', '04', '04445', '9814326', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '北ノ口', 'キタノクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町上野原', '04', '04445', '9814327', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '上野原', 'ウエノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町一里塚', '04', '04445', '9814328', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '一里塚', 'イチリツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町鶴喰', '04', '04445', '9814329', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '鶴喰', 'ツルバミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町鶴羽美', '04', '04445', '9814329', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '鶴羽美', 'ツルバミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町北寺宿', '04', '04445', '9814331', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '北寺宿', 'キタテラシュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町南寺宿', '04', '04445', '9814332', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '南寺宿', 'ミナミテラシュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町中畑', '04', '04445', '9814333', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '中畑', 'ナカハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町町屋敷', '04', '04445', '9814334', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '町屋敷', 'マチヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町新小路', '04', '04445', '9814335', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '新小路', 'シンコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町下タ川原', '04', '04445', '9814336', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '下タ川原', 'シモタカワハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町長檀', '04', '04445', '9814337', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '長檀', 'ナガダン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町中原', '04', '04445', '9814341', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '中原', 'ナカハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町原中原浦', '04', '04445', '9814342', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '原中原浦', 'ハラナカハラウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町内谷地', '04', '04445', '9814343', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '内谷地', 'ウチヤジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町原道端屋敷', '04', '04445', '9814344', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '原道端屋敷', 'ハラミチバタヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町下北浦', '04', '04445', '9814345', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '下北浦', 'シモキタウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町原南江端', '04', '04445', '9814346', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '原南江端', 'ハラミナミエバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町原高谷地屋敷', '04', '04445', '9814347', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '原高谷地屋敷', 'ハラタカヤジヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町南小路', '04', '04445', '9814351', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '南小路', 'ミナミコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町八石下', '04', '04445', '9814352', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '八石下', 'ハッコクシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町照井', '04', '04445', '9814353', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '照井', 'テルイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町麓山', '04', '04445', '9814354', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '麓山', 'フモトヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町鹿原', '04', '04445', '9814355', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '鹿原', 'カノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町芋沢', '04', '04445', '9814356', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '芋沢', 'イモザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町藤兵衛前', '04', '04445', '9814361', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '藤兵衛前', 'トウベエマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町小瀬', '04', '04445', '9814362', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '小瀬', 'コゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町滝下', '04', '04445', '9814363', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '滝下', 'タキシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町松田', '04', '04445', '9814364', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '松田', 'マツタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町伯治', '04', '04445', '9814365', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '伯治', 'ハクジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町水芋', '04', '04445', '9814366', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '水芋', 'ミズイモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町門沢', '04', '04445', '9814367', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '門沢', 'カドサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町漆沢', '04', '04445', '9814368', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '漆沢', 'ウルシザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町原', '04', '04445', '9814371', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '原', 'ハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町長清水', '04', '04445', '9814372', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '長清水', 'チョウシミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町原町', '04', '04445', '9814373', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '原町', 'ハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町上野目', '04', '04445', '9814374', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '上野目', 'カミノメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町味ケ袋', '04', '04445', '9814375', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '味ケ袋', 'アジガフクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町宮崎', '04', '04445', '9814401', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '宮崎', 'ミヤザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町北川内', '04', '04445', '9814402', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '北川内', 'キタカワウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町柳沢', '04', '04445', '9814403', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '柳沢', 'ヤナギサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町谷地森', '04', '04445', '9814411', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '谷地森', 'ヤチモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町鳥嶋', '04', '04445', '9814412', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '鳥嶋', 'トリシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町鳥屋ケ崎', '04', '04445', '9814413', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '鳥屋ケ崎', 'トリヤガサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町孫沢', '04', '04445', '9814414', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '孫沢', 'マゴサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町米泉', '04', '04445', '9814415', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '米泉', 'コメイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町沼ケ袋', '04', '04445', '9814416', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '沼ケ袋', 'ヌマガフクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町君ケ袋', '04', '04445', '9814417', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '君ケ袋', 'キミガフクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町小泉', '04', '04445', '9814418', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '小泉', 'コイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県加美郡加美町木舟', '04', '04445', '9814419', '宮城県', 'ミヤギケン', '加美郡加美町', 'カミグンカミマチ', '木舟', 'キブネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡西興部村', '01', '01562', '0981500', '北海道', 'ホッカイドウ', '紋別郡西興部村', 'モンベツグンニシオコッペムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('140878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡西興部村西興部', '01', '01562', '0981501', '北海道', 'ホッカイドウ', '紋別郡西興部村', 'モンベツグンニシオコッペムラ', '西興部', 'ニシオコッペ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡西興部村六興', '01', '01562', '0981502', '北海道', 'ホッカイドウ', '紋別郡西興部村', 'モンベツグンニシオコッペムラ', '六興', 'ロッコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡西興部村中興部', '01', '01562', '0981503', '北海道', 'ホッカイドウ', '紋別郡西興部村', 'モンベツグンニシオコッペムラ', '中興部', 'ナカオコッペ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡西興部村忍路子', '01', '01562', '0981504', '北海道', 'ホッカイドウ', '紋別郡西興部村', 'モンベツグンニシオコッペムラ', '忍路子', 'オショロッコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡西興部村上藻', '01', '01562', '0981505', '北海道', 'ホッカイドウ', '紋別郡西興部村', 'モンベツグンニシオコッペムラ', '上藻', 'カミモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡西興部村中藻', '01', '01562', '0981506', '北海道', 'ホッカイドウ', '紋別郡西興部村', 'モンベツグンニシオコッペムラ', '中藻', 'ナカモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡興部町', '01', '01561', '0981600', '北海道', 'ホッカイドウ', '紋別郡興部町', 'モンベツグンオコッペチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('140885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡興部町興部元町', '01', '01561', '0981601', '北海道', 'ホッカイドウ', '紋別郡興部町', 'モンベツグンオコッペチョウ', '興部', 'オコッペ', null, null, '元町', 'モトマチ');
INSERT INTO `ms_addresses` VALUES ('140886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡興部町興部浜町', '01', '01561', '0981602', '北海道', 'ホッカイドウ', '紋別郡興部町', 'モンベツグンオコッペチョウ', '興部', 'オコッペ', null, null, '浜町', 'ハマチョウ');
INSERT INTO `ms_addresses` VALUES ('140887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡興部町興部東町', '01', '01561', '0981603', '北海道', 'ホッカイドウ', '紋別郡興部町', 'モンベツグンオコッペチョウ', '興部', 'オコッペ', null, null, '東町', 'ヒガシマチ');
INSERT INTO `ms_addresses` VALUES ('140888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡興部町興部春日町', '01', '01561', '0981604', '北海道', 'ホッカイドウ', '紋別郡興部町', 'モンベツグンオコッペチョウ', '興部', 'オコッペ', null, null, '春日町', 'カスガチョウ');
INSERT INTO `ms_addresses` VALUES ('140889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡興部町興部緑ケ丘', '01', '01561', '0981605', '北海道', 'ホッカイドウ', '紋別郡興部町', 'モンベツグンオコッペチョウ', '興部', 'オコッペ', null, null, '緑ケ丘', 'ミドリガオカ');
INSERT INTO `ms_addresses` VALUES ('140890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡興部町興部栄町', '01', '01561', '0981606', '北海道', 'ホッカイドウ', '紋別郡興部町', 'モンベツグンオコッペチョウ', '興部', 'オコッペ', null, null, '栄町', 'サカエマチ');
INSERT INTO `ms_addresses` VALUES ('140891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡興部町興部旭町', '01', '01561', '0981607', '北海道', 'ホッカイドウ', '紋別郡興部町', 'モンベツグンオコッペチョウ', '興部', 'オコッペ', null, null, '旭町', 'アサヒマチ');
INSERT INTO `ms_addresses` VALUES ('140892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡興部町興部泉町', '01', '01561', '0981611', '北海道', 'ホッカイドウ', '紋別郡興部町', 'モンベツグンオコッペチョウ', '興部', 'オコッペ', null, null, '泉町', 'イズミマチ');
INSERT INTO `ms_addresses` VALUES ('140893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡興部町興部新泉町', '01', '01561', '0981612', '北海道', 'ホッカイドウ', '紋別郡興部町', 'モンベツグンオコッペチョウ', '興部', 'オコッペ', null, null, '新泉町', 'シンイズミマチ');
INSERT INTO `ms_addresses` VALUES ('140894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡興部町興部新町', '01', '01561', '0981613', '北海道', 'ホッカイドウ', '紋別郡興部町', 'モンベツグンオコッペチョウ', '興部', 'オコッペ', null, null, '新町', 'シンマチ');
INSERT INTO `ms_addresses` VALUES ('140895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡興部町興部幸町', '01', '01561', '0981614', '北海道', 'ホッカイドウ', '紋別郡興部町', 'モンベツグンオコッペチョウ', '興部', 'オコッペ', null, null, '幸町', 'サイワイチョウ');
INSERT INTO `ms_addresses` VALUES ('140896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡興部町興部仲町', '01', '01561', '0981615', '北海道', 'ホッカイドウ', '紋別郡興部町', 'モンベツグンオコッペチョウ', '興部', 'オコッペ', null, null, '仲町', 'ナカマチ');
INSERT INTO `ms_addresses` VALUES ('140897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡興部町興部本町', '01', '01561', '0981616', '北海道', 'ホッカイドウ', '紋別郡興部町', 'モンベツグンオコッペチョウ', '興部', 'オコッペ', null, null, '本町', 'ホンチョウ');
INSERT INTO `ms_addresses` VALUES ('140898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡興部町秋里', '01', '01561', '0981621', '北海道', 'ホッカイドウ', '紋別郡興部町', 'モンベツグンオコッペチョウ', '秋里', 'アキサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡興部町北興', '01', '01561', '0981622', '北海道', 'ホッカイドウ', '紋別郡興部町', 'モンベツグンオコッペチョウ', '北興', 'ホッコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡興部町興部宮下町', '01', '01561', '0981623', '北海道', 'ホッカイドウ', '紋別郡興部町', 'モンベツグンオコッペチョウ', '興部', 'オコッペ', null, null, '宮下町', 'ミヤシタチョウ');
INSERT INTO `ms_addresses` VALUES ('140901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡興部町宇津', '01', '01561', '0981624', '北海道', 'ホッカイドウ', '紋別郡興部町', 'モンベツグンオコッペチョウ', '宇津', 'ウツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡雄武町', '01', '01563', '0981700', '北海道', 'ホッカイドウ', '紋別郡雄武町', 'モンベツグンオウムチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('140905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡雄武町北雄武', '01', '01563', '0981701', '北海道', 'ホッカイドウ', '紋別郡雄武町', 'モンベツグンオウムチョウ', '北雄武', 'キタオウム', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡雄武町雄武', '01', '01563', '0981702', '北海道', 'ホッカイドウ', '紋別郡雄武町', 'モンベツグンオウムチョウ', '雄武', 'オウム', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡雄武町沢木', '01', '01563', '0981703', '北海道', 'ホッカイドウ', '紋別郡雄武町', 'モンベツグンオウムチョウ', '沢木', 'サワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡雄武町上沢木', '01', '01563', '0981704', '北海道', 'ホッカイドウ', '紋別郡雄武町', 'モンベツグンオウムチョウ', '上沢木', 'カミサワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡雄武町南雄武', '01', '01563', '0981705', '北海道', 'ホッカイドウ', '紋別郡雄武町', 'モンベツグンオウムチョウ', '南雄武', 'ミナミオウム', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡雄武町中雄武', '01', '01563', '0981706', '北海道', 'ホッカイドウ', '紋別郡雄武町', 'モンベツグンオウムチョウ', '中雄武', 'ナカオウム', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡雄武町上雄武', '01', '01563', '0981707', '北海道', 'ホッカイドウ', '紋別郡雄武町', 'モンベツグンオウムチョウ', '上雄武', 'カミオウム', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡雄武町上幌内', '01', '01563', '0981708', '北海道', 'ホッカイドウ', '紋別郡雄武町', 'モンベツグンオウムチョウ', '上幌内', 'カミホロナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市泉区南光台東', '04', '04105', '9818001', '宮城県', 'ミヤギケン', '仙台市泉区', 'センダイシイズミク', '南光台東', 'ナンコウダイヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市泉区南光台南', '04', '04105', '9818002', '宮城県', 'ミヤギケン', '仙台市泉区', 'センダイシイズミク', '南光台南', 'ナンコウダイミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市泉区南光台', '04', '04105', '9818003', '宮城県', 'ミヤギケン', '仙台市泉区', 'センダイシイズミク', '南光台', 'ナンコウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市泉区旭丘堤', '04', '04105', '9818004', '宮城県', 'ミヤギケン', '仙台市泉区', 'センダイシイズミク', '旭丘堤', 'アサヒガオカツツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市泉区東黒松', '04', '04105', '9818005', '宮城県', 'ミヤギケン', '仙台市泉区', 'センダイシイズミク', '東黒松', 'ヒガシクロマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市泉区黒松', '04', '04105', '9818006', '宮城県', 'ミヤギケン', '仙台市泉区', 'センダイシイズミク', '黒松', 'クロマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市泉区虹の丘', '04', '04105', '9818007', '宮城県', 'ミヤギケン', '仙台市泉区', 'センダイシイズミク', '虹の丘', 'ニジノオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡雄武町北幌内', '01', '01563', '0981821', '北海道', 'ホッカイドウ', '紋別郡雄武町', 'モンベツグンオウムチョウ', '北幌内', 'キタホロナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡雄武町中幌内', '01', '01563', '0981821', '北海道', 'ホッカイドウ', '紋別郡雄武町', 'モンベツグンオウムチョウ', '中幌内', 'ナカホロナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡雄武町幌内', '01', '01563', '0981821', '北海道', 'ホッカイドウ', '紋別郡雄武町', 'モンベツグンオウムチョウ', '幌内', 'ホロナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡興部町沙留', '01', '01561', '0981941', '北海道', 'ホッカイドウ', '紋別郡興部町', 'モンベツグンオコッペチョウ', '沙留', 'サルル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡興部町富丘', '01', '01561', '0981942', '北海道', 'ホッカイドウ', '紋別郡興部町', 'モンベツグンオコッペチョウ', '富丘', 'トミオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡興部町住吉', '01', '01561', '0981943', '北海道', 'ホッカイドウ', '紋別郡興部町', 'モンベツグンオコッペチョウ', '住吉', 'スミヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡興部町豊野', '01', '01561', '0981944', '北海道', 'ホッカイドウ', '紋別郡興部町', 'モンベツグンオコッペチョウ', '豊野', 'トヨノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市太白区', '04', '04104', '9820000', '宮城県', 'ミヤギケン', '仙台市太白区', 'センダイシタイハクク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('140953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市太白区八本松', '04', '04104', '9820001', '宮城県', 'ミヤギケン', '仙台市太白区', 'センダイシタイハクク', '八本松', 'ハチホンマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市太白区飯田', '04', '04104', '9820002', '宮城県', 'ミヤギケン', '仙台市太白区', 'センダイシタイハクク', '飯田', 'イイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市太白区郡山', '04', '04104', '9820003', '宮城県', 'ミヤギケン', '仙台市太白区', 'センダイシタイハクク', '郡山', 'コオリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市太白区東大野田', '04', '04104', '9820004', '宮城県', 'ミヤギケン', '仙台市太白区', 'センダイシタイハクク', '東大野田', 'ヒガシオオノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市太白区諏訪町', '04', '04104', '9820005', '宮城県', 'ミヤギケン', '仙台市太白区', 'センダイシタイハクク', '諏訪町', 'スワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市太白区東郡山', '04', '04104', '9820006', '宮城県', 'ミヤギケン', '仙台市太白区', 'センダイシタイハクク', '東郡山', 'ヒガシコオリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市太白区あすと長町', '04', '04104', '9820007', '宮城県', 'ミヤギケン', '仙台市太白区', 'センダイシタイハクク', 'あすと長町', 'アストナガマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市太白区長町', '04', '04104', '9820011', '宮城県', 'ミヤギケン', '仙台市太白区', 'センダイシタイハクク', '長町', 'ナガマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市太白区長町南', '04', '04104', '9820012', '宮城県', 'ミヤギケン', '仙台市太白区', 'センダイシタイハクク', '長町南', 'ナガマチミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市太白区太子堂', '04', '04104', '9820013', '宮城県', 'ミヤギケン', '仙台市太白区', 'センダイシタイハクク', '太子堂', 'タイシドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市太白区大野田', '04', '04104', '9820014', '宮城県', 'ミヤギケン', '仙台市太白区', 'センダイシタイハクク', '大野田', 'オオノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市太白区南大野田', '04', '04104', '9820015', '宮城県', 'ミヤギケン', '仙台市太白区', 'センダイシタイハクク', '南大野田', 'ミナミオオノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市太白区緑ケ丘', '04', '04104', '9820021', '宮城県', 'ミヤギケン', '仙台市太白区', 'センダイシタイハクク', '緑ケ丘', 'ミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市太白区鹿野本町', '04', '04104', '9820022', '宮城県', 'ミヤギケン', '仙台市太白区', 'センダイシタイハクク', '鹿野本町', 'カノホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市太白区鹿野', '04', '04104', '9820023', '宮城県', 'ミヤギケン', '仙台市太白区', 'センダイシタイハクク', '鹿野', 'カノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市太白区砂押南町', '04', '04104', '9820024', '宮城県', 'ミヤギケン', '仙台市太白区', 'センダイシタイハクク', '砂押南町', 'スナオシミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市太白区砂押町', '04', '04104', '9820025', '宮城県', 'ミヤギケン', '仙台市太白区', 'センダイシタイハクク', '砂押町', 'スナオシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市太白区土手内', '04', '04104', '9820026', '宮城県', 'ミヤギケン', '仙台市太白区', 'センダイシタイハクク', '土手内', 'ドテウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市太白区大塒町', '04', '04104', '9820027', '宮城県', 'ミヤギケン', '仙台市太白区', 'センダイシタイハクク', '大塒町', 'オオトヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市太白区泉崎', '04', '04104', '9820031', '宮城県', 'ミヤギケン', '仙台市太白区', 'センダイシタイハクク', '泉崎', 'イズミザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市太白区富沢', '04', '04104', '9820032', '宮城県', 'ミヤギケン', '仙台市太白区', 'センダイシタイハクク', '富沢', 'トミザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市太白区富田', '04', '04104', '9820033', '宮城県', 'ミヤギケン', '仙台市太白区', 'センダイシタイハクク', '富田', 'トミタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市太白区西多賀', '04', '04104', '9820034', '宮城県', 'ミヤギケン', '仙台市太白区', 'センダイシタイハクク', '西多賀', 'ニシタガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市太白区大谷地', '04', '04104', '9820035', '宮城県', 'ミヤギケン', '仙台市太白区', 'センダイシタイハクク', '大谷地', 'オオヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市太白区富沢南', '04', '04104', '9820036', '宮城県', 'ミヤギケン', '仙台市太白区', 'センダイシタイハクク', '富沢南', 'トミザワミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市太白区佐保山', '04', '04104', '9820211', '宮城県', 'ミヤギケン', '仙台市太白区', 'センダイシタイハクク', '佐保山', 'サホヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市太白区太白', '04', '04104', '9820212', '宮城県', 'ミヤギケン', '仙台市太白区', 'センダイシタイハクク', '太白', 'タイハク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市太白区山田自由ケ丘', '04', '04104', '9820213', '宮城県', 'ミヤギケン', '仙台市太白区', 'センダイシタイハクク', '山田自由ケ丘', 'ヤマダジユウガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市太白区山田', '04', '04104', '9820214', '宮城県', 'ミヤギケン', '仙台市太白区', 'センダイシタイハクク', '山田', 'ヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市太白区旗立', '04', '04104', '9820215', '宮城県', 'ミヤギケン', '仙台市太白区', 'センダイシタイハクク', '旗立', 'ハタタテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市太白区日本平', '04', '04104', '9820221', '宮城県', 'ミヤギケン', '仙台市太白区', 'センダイシタイハクク', '日本平', 'ニホンダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市太白区人来田', '04', '04104', '9820222', '宮城県', 'ミヤギケン', '仙台市太白区', 'センダイシタイハクク', '人来田', 'ヒトキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市太白区坪沼', '04', '04104', '9820231', '宮城県', 'ミヤギケン', '仙台市太白区', 'センダイシタイハクク', '坪沼', 'ツボヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市太白区秋保町湯元', '04', '04104', '9820241', '宮城県', 'ミヤギケン', '仙台市太白区', 'センダイシタイハクク', '秋保町湯元', 'アキウマチユモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市太白区秋保町境野', '04', '04104', '9820242', '宮城県', 'ミヤギケン', '仙台市太白区', 'センダイシタイハクク', '秋保町境野', 'アキウマチサカイノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市太白区秋保町長袋', '04', '04104', '9820243', '宮城県', 'ミヤギケン', '仙台市太白区', 'センダイシタイハクク', '秋保町長袋', 'アキウマチナガフクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市太白区秋保町馬場', '04', '04104', '9820244', '宮城県', 'ミヤギケン', '仙台市太白区', 'センダイシタイハクク', '秋保町馬場', 'アキウマチババ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市太白区秋保町湯向', '04', '04104', '9820245', '宮城県', 'ミヤギケン', '仙台市太白区', 'センダイシタイハクク', '秋保町湯向', 'アキウマチユムカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市太白区茂庭', '04', '04104', '9820251', '宮城県', 'ミヤギケン', '仙台市太白区', 'センダイシタイハクク', '茂庭', 'モニワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市太白区茂庭台', '04', '04104', '9820252', '宮城県', 'ミヤギケン', '仙台市太白区', 'センダイシタイハクク', '茂庭台', 'モニワダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区折立', '04', '04101', '9820261', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '折立', 'オリタテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区西花苑', '04', '04101', '9820262', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '西花苑', 'セイカエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区茂庭', '04', '04101', '9820263', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '茂庭', 'モニワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市太白区八木山本町', '04', '04104', '9820801', '宮城県', 'ミヤギケン', '仙台市太白区', 'センダイシタイハクク', '八木山本町', 'ヤギヤマホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市太白区八木山東', '04', '04104', '9820802', '宮城県', 'ミヤギケン', '仙台市太白区', 'センダイシタイハクク', '八木山東', 'ヤギヤマヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市太白区金剛沢', '04', '04104', '9820803', '宮城県', 'ミヤギケン', '仙台市太白区', 'センダイシタイハクク', '金剛沢', 'コンゴウサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('140999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市太白区鈎取', '04', '04104', '9820804', '宮城県', 'ミヤギケン', '仙台市太白区', 'センダイシタイハクク', '鈎取', 'カギトリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市太白区鈎取本町', '04', '04104', '9820805', '宮城県', 'ミヤギケン', '仙台市太白区', 'センダイシタイハクク', '鈎取本町', 'カギトリホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市太白区御堂平', '04', '04104', '9820806', '宮城県', 'ミヤギケン', '仙台市太白区', 'センダイシタイハクク', '御堂平', 'ミドウダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市太白区八木山南', '04', '04104', '9820807', '宮城県', 'ミヤギケン', '仙台市太白区', 'センダイシタイハクク', '八木山南', 'ヤギヤマミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市太白区ひより台', '04', '04104', '9820811', '宮城県', 'ミヤギケン', '仙台市太白区', 'センダイシタイハクク', 'ひより台', 'ヒヨリダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市太白区上野山', '04', '04104', '9820812', '宮城県', 'ミヤギケン', '仙台市太白区', 'センダイシタイハクク', '上野山', 'カミノヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市太白区山田北前町', '04', '04104', '9820813', '宮城県', 'ミヤギケン', '仙台市太白区', 'センダイシタイハクク', '山田北前町', 'ヤマダキタマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市太白区山田', '04', '04104', '9820814', '宮城県', 'ミヤギケン', '仙台市太白区', 'センダイシタイハクク', '山田', 'ヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市太白区山田上ノ台町', '04', '04104', '9820815', '宮城県', 'ミヤギケン', '仙台市太白区', 'センダイシタイハクク', '山田上ノ台町', 'ヤマダウエノダイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市太白区山田本町', '04', '04104', '9820816', '宮城県', 'ミヤギケン', '仙台市太白区', 'センダイシタイハクク', '山田本町', 'ヤマダホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市太白区羽黒台', '04', '04104', '9820817', '宮城県', 'ミヤギケン', '仙台市太白区', 'センダイシタイハクク', '羽黒台', 'ハグロダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市太白区松が丘', '04', '04104', '9820821', '宮城県', 'ミヤギケン', '仙台市太白区', 'センダイシタイハクク', '松が丘', 'マツガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市太白区若葉町', '04', '04104', '9820822', '宮城県', 'ミヤギケン', '仙台市太白区', 'センダイシタイハクク', '若葉町', 'ワカバマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市太白区恵和町', '04', '04104', '9820823', '宮城県', 'ミヤギケン', '仙台市太白区', 'センダイシタイハクク', '恵和町', 'ケイワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市太白区芦の口', '04', '04104', '9820824', '宮城県', 'ミヤギケン', '仙台市太白区', 'センダイシタイハクク', '芦の口', 'アシノクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市太白区西の平', '04', '04104', '9820825', '宮城県', 'ミヤギケン', '仙台市太白区', 'センダイシタイハクク', '西の平', 'ニシノダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市太白区三神峯', '04', '04104', '9820826', '宮城県', 'ミヤギケン', '仙台市太白区', 'センダイシタイハクク', '三神峯', 'ミカミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市太白区八木山香澄町', '04', '04104', '9820831', '宮城県', 'ミヤギケン', '仙台市太白区', 'センダイシタイハクク', '八木山香澄町', 'ヤギヤマカスミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市太白区八木山緑町', '04', '04104', '9820832', '宮城県', 'ミヤギケン', '仙台市太白区', 'センダイシタイハクク', '八木山緑町', 'ヤギヤマミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市太白区八木山弥生町', '04', '04104', '9820833', '宮城県', 'ミヤギケン', '仙台市太白区', 'センダイシタイハクク', '八木山弥生町', 'ヤギヤマヤヨイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市太白区青山', '04', '04104', '9820834', '宮城県', 'ミヤギケン', '仙台市太白区', 'センダイシタイハクク', '青山', 'アオヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市太白区桜木町', '04', '04104', '9820835', '宮城県', 'ミヤギケン', '仙台市太白区', 'センダイシタイハクク', '桜木町', 'サクラギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市太白区八木山松波町', '04', '04104', '9820836', '宮城県', 'ミヤギケン', '仙台市太白区', 'センダイシタイハクク', '八木山松波町', 'ヤギヤママツナミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市太白区長町越路', '04', '04104', '9820837', '宮城県', 'ミヤギケン', '仙台市太白区', 'センダイシタイハクク', '長町', 'ナガマチ', null, null, '越路', 'コエジ');
INSERT INTO `ms_addresses` VALUES ('141023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市太白区向山', '04', '04104', '9820841', '宮城県', 'ミヤギケン', '仙台市太白区', 'センダイシタイハクク', '向山', 'ムカイヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市太白区越路', '04', '04104', '9820842', '宮城県', 'ミヤギケン', '仙台市太白区', 'センダイシタイハクク', '越路', 'コエジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市太白区茂ケ崎', '04', '04104', '9820843', '宮城県', 'ミヤギケン', '仙台市太白区', 'センダイシタイハクク', '茂ケ崎', 'モガサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市太白区根岸町', '04', '04104', '9820844', '宮城県', 'ミヤギケン', '仙台市太白区', 'センダイシタイハクク', '根岸町', 'ネギシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市太白区門前町', '04', '04104', '9820845', '宮城県', 'ミヤギケン', '仙台市太白区', 'センダイシタイハクク', '門前町', 'モンゼンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市太白区二ツ沢', '04', '04104', '9820846', '宮城県', 'ミヤギケン', '仙台市太白区', 'センダイシタイハクク', '二ツ沢', 'フタツサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市太白区長嶺', '04', '04104', '9820847', '宮城県', 'ミヤギケン', '仙台市太白区', 'センダイシタイハクク', '長嶺', 'ナガミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市太白区萩ケ丘', '04', '04104', '9820848', '宮城県', 'ミヤギケン', '仙台市太白区', 'センダイシタイハクク', '萩ケ丘', 'ハギガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道名寄市智恵文', '01', '01221', '0982181', '北海道', 'ホッカイドウ', '名寄市', 'ナヨロシ', '智恵文', 'チエブン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡美深町', '01', '01469', '0982200', '北海道', 'ホッカイドウ', '中川郡美深町', 'ナカガワグンビフカチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('141033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡美深町泉', '01', '01469', '0982201', '北海道', 'ホッカイドウ', '中川郡美深町', 'ナカガワグンビフカチョウ', '泉', 'イズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡美深町玉川', '01', '01469', '0982202', '北海道', 'ホッカイドウ', '中川郡美深町', 'ナカガワグンビフカチョウ', '玉川', 'タマカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡美深町六郷', '01', '01469', '0982203', '北海道', 'ホッカイドウ', '中川郡美深町', 'ナカガワグンビフカチョウ', '六郷', 'ロクゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡美深町川西', '01', '01469', '0982204', '北海道', 'ホッカイドウ', '中川郡美深町', 'ナカガワグンビフカチョウ', '川西', 'カワニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡美深町美深', '01', '01469', '0982205', '北海道', 'ホッカイドウ', '中川郡美深町', 'ナカガワグンビフカチョウ', '美深', 'ビフカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡美深町菊丘', '01', '01469', '0982206', '北海道', 'ホッカイドウ', '中川郡美深町', 'ナカガワグンビフカチョウ', '菊丘', 'キクオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡美深町辺渓', '01', '01469', '0982207', '北海道', 'ホッカイドウ', '中川郡美深町', 'ナカガワグンビフカチョウ', '辺渓', 'ペンケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡美深町仁宇布', '01', '01469', '0982208', '北海道', 'ホッカイドウ', '中川郡美深町', 'ナカガワグンビフカチョウ', '仁宇布', 'ニウプ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡美深町富岡', '01', '01469', '0982211', '北海道', 'ホッカイドウ', '中川郡美深町', 'ナカガワグンビフカチョウ', '富岡', 'トミオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡美深町班渓', '01', '01469', '0982212', '北海道', 'ホッカイドウ', '中川郡美深町', 'ナカガワグンビフカチョウ', '班渓', 'パンケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡美深町吉野', '01', '01469', '0982213', '北海道', 'ホッカイドウ', '中川郡美深町', 'ナカガワグンビフカチョウ', '吉野', 'ヨシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡美深町敷島', '01', '01469', '0982214', '北海道', 'ホッカイドウ', '中川郡美深町', 'ナカガワグンビフカチョウ', '敷島', 'シキシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡美深町大通北', '01', '01469', '0982220', '北海道', 'ホッカイドウ', '中川郡美深町', 'ナカガワグンビフカチョウ', '大通北', 'オオドオリキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡美深町東1条北', '01', '01469', '0982221', '北海道', 'ホッカイドウ', '中川郡美深町', 'ナカガワグンビフカチョウ', '東1条北', 'ヒガシ01ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡美深町東2条北', '01', '01469', '0982222', '北海道', 'ホッカイドウ', '中川郡美深町', 'ナカガワグンビフカチョウ', '東2条北', 'ヒガシ02ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡美深町東3条北', '01', '01469', '0982223', '北海道', 'ホッカイドウ', '中川郡美深町', 'ナカガワグンビフカチョウ', '東3条北', 'ヒガシ03ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡美深町東4条北', '01', '01469', '0982224', '北海道', 'ホッカイドウ', '中川郡美深町', 'ナカガワグンビフカチョウ', '東4条北', 'ヒガシ04ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡美深町東5条北', '01', '01469', '0982225', '北海道', 'ホッカイドウ', '中川郡美深町', 'ナカガワグンビフカチョウ', '東5条北', 'ヒガシ05ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡美深町東6条北', '01', '01469', '0982226', '北海道', 'ホッカイドウ', '中川郡美深町', 'ナカガワグンビフカチョウ', '東6条北', 'ヒガシ06ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡美深町北町', '01', '01469', '0982227', '北海道', 'ホッカイドウ', '中川郡美深町', 'ナカガワグンビフカチョウ', '北町', 'キタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡美深町大通南', '01', '01469', '0982230', '北海道', 'ホッカイドウ', '中川郡美深町', 'ナカガワグンビフカチョウ', '大通南', 'オオドオリミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡美深町東1条南', '01', '01469', '0982231', '北海道', 'ホッカイドウ', '中川郡美深町', 'ナカガワグンビフカチョウ', '東1条南', 'ヒガシ01ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡美深町東2条南', '01', '01469', '0982232', '北海道', 'ホッカイドウ', '中川郡美深町', 'ナカガワグンビフカチョウ', '東2条南', 'ヒガシ02ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡美深町東3条南', '01', '01469', '0982233', '北海道', 'ホッカイドウ', '中川郡美深町', 'ナカガワグンビフカチョウ', '東3条南', 'ヒガシ03ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡美深町東4条南', '01', '01469', '0982234', '北海道', 'ホッカイドウ', '中川郡美深町', 'ナカガワグンビフカチョウ', '東4条南', 'ヒガシ04ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡美深町南町', '01', '01469', '0982235', '北海道', 'ホッカイドウ', '中川郡美深町', 'ナカガワグンビフカチョウ', '南町', 'ミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡美深町東6条南', '01', '01469', '0982236', '北海道', 'ホッカイドウ', '中川郡美深町', 'ナカガワグンビフカチョウ', '東6条南', 'ヒガシ06ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡美深町若松町', '01', '01469', '0982237', '北海道', 'ホッカイドウ', '中川郡美深町', 'ナカガワグンビフカチョウ', '若松町', 'ワカマツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡美深町開運町', '01', '01469', '0982238', '北海道', 'ホッカイドウ', '中川郡美深町', 'ナカガワグンビフカチョウ', '開運町', 'カイウンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡美深町西1条南', '01', '01469', '0982241', '北海道', 'ホッカイドウ', '中川郡美深町', 'ナカガワグンビフカチョウ', '西1条南', 'ニシ01ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡美深町西2条南', '01', '01469', '0982242', '北海道', 'ホッカイドウ', '中川郡美深町', 'ナカガワグンビフカチョウ', '西2条南', 'ニシ02ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡美深町西3条南', '01', '01469', '0982243', '北海道', 'ホッカイドウ', '中川郡美深町', 'ナカガワグンビフカチョウ', '西3条南', 'ニシ03ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡美深町西1条北', '01', '01469', '0982251', '北海道', 'ホッカイドウ', '中川郡美深町', 'ナカガワグンビフカチョウ', '西1条北', 'ニシ01ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡美深町西町', '01', '01469', '0982252', '北海道', 'ホッカイドウ', '中川郡美深町', 'ナカガワグンビフカチョウ', '西町', 'ニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡美深町西3条北', '01', '01469', '0982253', '北海道', 'ホッカイドウ', '中川郡美深町', 'ナカガワグンビフカチョウ', '西3条北', 'ニシ03ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡美深町恩根内', '01', '01469', '0982361', '北海道', 'ホッカイドウ', '中川郡美深町', 'ナカガワグンビフカチョウ', '恩根内', 'オンネナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡美深町大手', '01', '01469', '0982362', '北海道', 'ホッカイドウ', '中川郡美深町', 'ナカガワグンビフカチョウ', '大手', 'オオテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡美深町小車', '01', '01469', '0982363', '北海道', 'ホッカイドウ', '中川郡美深町', 'ナカガワグンビフカチョウ', '小車', 'オグルマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡美深町報徳', '01', '01469', '0982364', '北海道', 'ホッカイドウ', '中川郡美深町', 'ナカガワグンビフカチョウ', '報徳', 'ホウトク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡美深町西里', '01', '01469', '0982365', '北海道', 'ホッカイドウ', '中川郡美深町', 'ナカガワグンビフカチョウ', '西里', 'ニシサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡美深町紋穂内', '01', '01469', '0982366', '北海道', 'ホッカイドウ', '中川郡美深町', 'ナカガワグンビフカチョウ', '紋穂内', 'モンポナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡美深町楠', '01', '01469', '0982367', '北海道', 'ホッカイドウ', '中川郡美深町', 'ナカガワグンビフカチョウ', '楠', 'クスノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡美深町清水', '01', '01469', '0982368', '北海道', 'ホッカイドウ', '中川郡美深町', 'ナカガワグンビフカチョウ', '清水', 'シミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡音威子府村', '01', '01470', '0982500', '北海道', 'ホッカイドウ', '中川郡音威子府村', 'ナカガワグンオトイネップムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('141077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡音威子府村音威子府', '01', '01470', '0982501', '北海道', 'ホッカイドウ', '中川郡音威子府村', 'ナカガワグンオトイネップムラ', '音威子府', 'オトイネップ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡音威子府村咲来', '01', '01470', '0982502', '北海道', 'ホッカイドウ', '中川郡音威子府村', 'ナカガワグンオトイネップムラ', '咲来', 'サツクル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡中川町共和', '01', '01471', '0982621', '北海道', 'ホッカイドウ', '中川郡中川町', 'ナカガワグンナカガワチョウ', '共和', 'キョウワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡中川町佐久', '01', '01471', '0982622', '北海道', 'ホッカイドウ', '中川郡中川町', 'ナカガワグンナカガワチョウ', '佐久', 'サク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡中川町富和', '01', '01471', '0982623', '北海道', 'ホッカイドウ', '中川郡中川町', 'ナカガワグンナカガワチョウ', '富和', 'トミワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡中川町豊里', '01', '01471', '0982624', '北海道', 'ホッカイドウ', '中川郡中川町', 'ナカガワグンナカガワチョウ', '豊里', 'トヨサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡中川町安川', '01', '01471', '0982625', '北海道', 'ホッカイドウ', '中川郡中川町', 'ナカガワグンナカガワチョウ', '安川', 'ヤスカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡中川町安川', '01', '01471', '0982626', '北海道', 'ホッカイドウ', '中川郡中川町', 'ナカガワグンナカガワチョウ', '安川', 'ヤスカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡中川町', '01', '01471', '0982800', '北海道', 'ホッカイドウ', '中川郡中川町', 'ナカガワグンナカガワチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('141086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡中川町歌内', '01', '01471', '0982801', '北海道', 'ホッカイドウ', '中川郡中川町', 'ナカガワグンナカガワチョウ', '歌内', 'ウタナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡中川町中川', '01', '01471', '0982802', '北海道', 'ホッカイドウ', '中川郡中川町', 'ナカガワグンナカガワチョウ', '中川', 'ナカガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡中川町琴平', '01', '01471', '0982803', '北海道', 'ホッカイドウ', '中川郡中川町', 'ナカガワグンナカガワチョウ', '琴平', 'コトヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡中川町大富', '01', '01471', '0982804', '北海道', 'ホッカイドウ', '中川郡中川町', 'ナカガワグンナカガワチョウ', '大富', 'オオトミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡中川町誉', '01', '01471', '0982805', '北海道', 'ホッカイドウ', '中川郡中川町', 'ナカガワグンナカガワチョウ', '誉', 'ホマレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道中川郡中川町国府', '01', '01471', '0982806', '北海道', 'ホッカイドウ', '中川郡中川町', 'ナカガワグンナカガワチョウ', '国府', 'コクフ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡幌延町上問寒', '01', '01488', '0982941', '北海道', 'ホッカイドウ', '天塩郡幌延町', 'テシオグンホロノベチョウ', '上問寒', 'カミトイカン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡幌延町中問寒', '01', '01488', '0982942', '北海道', 'ホッカイドウ', '天塩郡幌延町', 'テシオグンホロノベチョウ', '中問寒', 'ナカトイカン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡幌延町問寒別', '01', '01488', '0982943', '北海道', 'ホッカイドウ', '天塩郡幌延町', 'テシオグンホロノベチョウ', '問寒別', 'トイカンベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡天塩町下コクネップ', '01', '01487', '0982951', '北海道', 'ホッカイドウ', '天塩郡天塩町', 'テシオグンテシオチョウ', '下コクネップ', 'シモコクネップ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市宮城野区', '04', '04102', '9830000', '宮城県', 'ミヤギケン', '仙台市宮城野区', 'センダイシミヤギノク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('141113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市宮城野区港1丁目', '04', '04102', '9830001', '宮城県', 'ミヤギケン', '仙台市宮城野区', 'センダイシミヤギノク', '港', 'ミナト', null, null, '1丁目', '01チョウメ');
INSERT INTO `ms_addresses` VALUES ('141114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市宮城野区港2丁目', '04', '04102', '9830001', '宮城県', 'ミヤギケン', '仙台市宮城野区', 'センダイシミヤギノク', '港', 'ミナト', null, null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('141115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市宮城野区港3丁目', '04', '04102', '9830001', '宮城県', 'ミヤギケン', '仙台市宮城野区', 'センダイシミヤギノク', '港', 'ミナト', null, null, '3丁目', '03チョウメ');
INSERT INTO `ms_addresses` VALUES ('141116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市宮城野区港4丁目', '04', '04102', '9830001', '宮城県', 'ミヤギケン', '仙台市宮城野区', 'センダイシミヤギノク', '港', 'ミナト', null, null, '4丁目', '04チョウメ');
INSERT INTO `ms_addresses` VALUES ('141117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市宮城野区蒲生', '04', '04102', '9830002', '宮城県', 'ミヤギケン', '仙台市宮城野区', 'センダイシミヤギノク', '蒲生', 'ガモウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市宮城野区岡田', '04', '04102', '9830003', '宮城県', 'ミヤギケン', '仙台市宮城野区', 'センダイシミヤギノク', '岡田', 'オカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市宮城野区岡田西町', '04', '04102', '9830004', '宮城県', 'ミヤギケン', '仙台市宮城野区', 'センダイシミヤギノク', '岡田西町', 'オカダニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市宮城野区福室', '04', '04102', '9830005', '宮城県', 'ミヤギケン', '仙台市宮城野区', 'センダイシミヤギノク', '福室', 'フクムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市宮城野区白鳥', '04', '04102', '9830006', '宮城県', 'ミヤギケン', '仙台市宮城野区', 'センダイシミヤギノク', '白鳥', 'シラトリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市宮城野区栄', '04', '04102', '9830011', '宮城県', 'ミヤギケン', '仙台市宮城野区', 'センダイシミヤギノク', '栄', 'サカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市宮城野区出花', '04', '04102', '9830012', '宮城県', 'ミヤギケン', '仙台市宮城野区', 'センダイシミヤギノク', '出花', 'イデカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市宮城野区中野', '04', '04102', '9830013', '宮城県', 'ミヤギケン', '仙台市宮城野区', 'センダイシミヤギノク', '中野', 'ナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市宮城野区高砂', '04', '04102', '9830014', '宮城県', 'ミヤギケン', '仙台市宮城野区', 'センダイシミヤギノク', '高砂', 'タカサゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市宮城野区田子', '04', '04102', '9830021', '宮城県', 'ミヤギケン', '仙台市宮城野区', 'センダイシミヤギノク', '田子', 'タゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市宮城野区福田町', '04', '04102', '9830023', '宮城県', 'ミヤギケン', '仙台市宮城野区', 'センダイシミヤギノク', '福田町', 'フクダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市宮城野区鶴巻', '04', '04102', '9830024', '宮城県', 'ミヤギケン', '仙台市宮城野区', 'センダイシミヤギノク', '鶴巻', 'ツルマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市宮城野区福田町南', '04', '04102', '9830025', '宮城県', 'ミヤギケン', '仙台市宮城野区', 'センダイシミヤギノク', '福田町南', 'フクダマチミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市宮城野区小鶴', '04', '04102', '9830031', '宮城県', 'ミヤギケン', '仙台市宮城野区', 'センダイシミヤギノク', '小鶴', 'コヅル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市宮城野区仙石', '04', '04102', '9830032', '宮城県', 'ミヤギケン', '仙台市宮城野区', 'センダイシミヤギノク', '仙石', 'センゴク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市宮城野区福住町', '04', '04102', '9830033', '宮城県', 'ミヤギケン', '仙台市宮城野区', 'センダイシミヤギノク', '福住町', 'フクズミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市宮城野区扇町', '04', '04102', '9830034', '宮城県', 'ミヤギケン', '仙台市宮城野区', 'センダイシミヤギノク', '扇町', 'オウギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市宮城野区日の出町', '04', '04102', '9830035', '宮城県', 'ミヤギケン', '仙台市宮城野区', 'センダイシミヤギノク', '日の出町', 'ヒノデマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市宮城野区苦竹', '04', '04102', '9830036', '宮城県', 'ミヤギケン', '仙台市宮城野区', 'センダイシミヤギノク', '苦竹', 'ニガタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市宮城野区原町苦竹', '04', '04102', '9830036', '宮城県', 'ミヤギケン', '仙台市宮城野区', 'センダイシミヤギノク', '原町苦竹', 'ハラノマチニガタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市宮城野区平成', '04', '04102', '9830037', '宮城県', 'ミヤギケン', '仙台市宮城野区', 'センダイシミヤギノク', '平成', 'ヘイセイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市宮城野区新田', '04', '04102', '9830038', '宮城県', 'ミヤギケン', '仙台市宮城野区', 'センダイシミヤギノク', '新田', 'シンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市宮城野区新田東', '04', '04102', '9830039', '宮城県', 'ミヤギケン', '仙台市宮城野区', 'センダイシミヤギノク', '新田東', 'シンデンヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市宮城野区南目館', '04', '04102', '9830041', '宮城県', 'ミヤギケン', '仙台市宮城野区', 'センダイシミヤギノク', '南目館', 'ミナミノメタテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市宮城野区東宮城野', '04', '04102', '9830042', '宮城県', 'ミヤギケン', '仙台市宮城野区', 'センダイシミヤギノク', '東宮城野', 'ヒガシミヤギノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市宮城野区萩野町', '04', '04102', '9830043', '宮城県', 'ミヤギケン', '仙台市宮城野区', 'センダイシミヤギノク', '萩野町', 'ハギノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市宮城野区宮千代', '04', '04102', '9830044', '宮城県', 'ミヤギケン', '仙台市宮城野区', 'センダイシミヤギノク', '宮千代', 'ミヤチヨ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市宮城野区宮城野', '04', '04102', '9830045', '宮城県', 'ミヤギケン', '仙台市宮城野区', 'センダイシミヤギノク', '宮城野', 'ミヤギノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市宮城野区西宮城野', '04', '04102', '9830046', '宮城県', 'ミヤギケン', '仙台市宮城野区', 'センダイシミヤギノク', '西宮城野', 'ニシミヤギノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市宮城野区銀杏町', '04', '04102', '9830047', '宮城県', 'ミヤギケン', '仙台市宮城野区', 'センダイシミヤギノク', '銀杏町', 'イチョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市宮城野区小田原1丁目', '04', '04102', '9830803', '宮城県', 'ミヤギケン', '仙台市宮城野区', 'センダイシミヤギノク', '小田原', 'オダワラ', null, null, '1丁目', '01チョウメ');
INSERT INTO `ms_addresses` VALUES ('141148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市宮城野区小田原2丁目', '04', '04102', '9830803', '宮城県', 'ミヤギケン', '仙台市宮城野区', 'センダイシミヤギノク', '小田原', 'オダワラ', null, null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('141149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市宮城野区小田原3丁目', '04', '04102', '9830803', '宮城県', 'ミヤギケン', '仙台市宮城野区', 'センダイシミヤギノク', '小田原', 'オダワラ', null, null, '3丁目', '03チョウメ');
INSERT INTO `ms_addresses` VALUES ('141150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市宮城野区小田原清水沼通', '04', '04102', '9830811', '宮城県', 'ミヤギケン', '仙台市宮城野区', 'センダイシミヤギノク', '小田原清水沼通', 'オダワラシミズヌマドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市宮城野区小田原弓ノ町', '04', '04102', '9830812', '宮城県', 'ミヤギケン', '仙台市宮城野区', 'センダイシミヤギノク', '小田原弓ノ町', 'オダワラユミノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市宮城野区小田原牛小屋丁', '04', '04102', '9830813', '宮城県', 'ミヤギケン', '仙台市宮城野区', 'センダイシミヤギノク', '小田原牛小屋丁', 'オダワラウシゴヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市宮城野区小田原大行院丁', '04', '04102', '9830814', '宮城県', 'ミヤギケン', '仙台市宮城野区', 'センダイシミヤギノク', '小田原大行院丁', 'オダワラダイギョウインチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市宮城野区小田原広丁', '04', '04102', '9830815', '宮城県', 'ミヤギケン', '仙台市宮城野区', 'センダイシミヤギノク', '小田原広丁', 'オダワラヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市宮城野区小田原金剛院丁', '04', '04102', '9830816', '宮城県', 'ミヤギケン', '仙台市宮城野区', 'センダイシミヤギノク', '小田原金剛院丁', 'オダワラコンゴウインチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市宮城野区小田原山本丁', '04', '04102', '9830817', '宮城県', 'ミヤギケン', '仙台市宮城野区', 'センダイシミヤギノク', '小田原山本丁', 'オダワラヤマモトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市宮城野区岩切', '04', '04102', '9830821', '宮城県', 'ミヤギケン', '仙台市宮城野区', 'センダイシミヤギノク', '岩切', 'イワキリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市宮城野区燕沢東', '04', '04102', '9830822', '宮城県', 'ミヤギケン', '仙台市宮城野区', 'センダイシミヤギノク', '燕沢東', 'ツバメサワヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市宮城野区燕沢', '04', '04102', '9830823', '宮城県', 'ミヤギケン', '仙台市宮城野区', 'センダイシミヤギノク', '燕沢', 'ツバメサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市宮城野区鶴ケ谷', '04', '04102', '9830824', '宮城県', 'ミヤギケン', '仙台市宮城野区', 'センダイシミヤギノク', '鶴ケ谷', 'ツルガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市宮城野区鶴ケ谷北', '04', '04102', '9830825', '宮城県', 'ミヤギケン', '仙台市宮城野区', 'センダイシミヤギノク', '鶴ケ谷北', 'ツルガヤキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市宮城野区鶴ケ谷東', '04', '04102', '9830826', '宮城県', 'ミヤギケン', '仙台市宮城野区', 'センダイシミヤギノク', '鶴ケ谷東', 'ツルガヤヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市宮城野区南宮', '04', '04102', '9830827', '宮城県', 'ミヤギケン', '仙台市宮城野区', 'センダイシミヤギノク', '南宮', 'ナングウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市宮城野区自由ケ丘', '04', '04102', '9830831', '宮城県', 'ミヤギケン', '仙台市宮城野区', 'センダイシミヤギノク', '自由ケ丘', 'ジユウガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市宮城野区安養寺', '04', '04102', '9830832', '宮城県', 'ミヤギケン', '仙台市宮城野区', 'センダイシミヤギノク', '安養寺', 'アンヨウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市宮城野区東仙台', '04', '04102', '9830833', '宮城県', 'ミヤギケン', '仙台市宮城野区', 'センダイシミヤギノク', '東仙台', 'ヒガシセンダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市宮城野区松岡町', '04', '04102', '9830834', '宮城県', 'ミヤギケン', '仙台市宮城野区', 'センダイシミヤギノク', '松岡町', 'マツオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市宮城野区大梶', '04', '04102', '9830835', '宮城県', 'ミヤギケン', '仙台市宮城野区', 'センダイシミヤギノク', '大梶', 'オオカジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市宮城野区幸町', '04', '04102', '9830836', '宮城県', 'ミヤギケン', '仙台市宮城野区', 'センダイシミヤギノク', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市宮城野区枡江', '04', '04102', '9830837', '宮城県', 'ミヤギケン', '仙台市宮城野区', 'センダイシミヤギノク', '枡江', 'マスエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市宮城野区二の森', '04', '04102', '9830838', '宮城県', 'ミヤギケン', '仙台市宮城野区', 'センダイシミヤギノク', '二の森', 'ニノモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市宮城野区蟹沢', '04', '04102', '9830839', '宮城県', 'ミヤギケン', '仙台市宮城野区', 'センダイシミヤギノク', '蟹沢', 'カニサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市宮城野区原町', '04', '04102', '9830841', '宮城県', 'ミヤギケン', '仙台市宮城野区', 'センダイシミヤギノク', '原町', 'ハラノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市宮城野区五輪', '04', '04102', '9830842', '宮城県', 'ミヤギケン', '仙台市宮城野区', 'センダイシミヤギノク', '五輪', 'ゴリン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市宮城野区二十人町通', '04', '04102', '9830843', '宮城県', 'ミヤギケン', '仙台市宮城野区', 'センダイシミヤギノク', '二十人町通', 'ニジュウニンマチドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市宮城野区原町南目', '04', '04102', '9830844', '宮城県', 'ミヤギケン', '仙台市宮城野区', 'センダイシミヤギノク', '原町南目', 'ハラノマチミナミノメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市宮城野区清水沼', '04', '04102', '9830845', '宮城県', 'ミヤギケン', '仙台市宮城野区', 'センダイシミヤギノク', '清水沼', 'シミズヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市宮城野区榴ケ岡', '04', '04102', '9830851', '宮城県', 'ミヤギケン', '仙台市宮城野区', 'センダイシミヤギノク', '榴ケ岡', 'ツツジガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市宮城野区榴岡', '04', '04102', '9830852', '宮城県', 'ミヤギケン', '仙台市宮城野区', 'センダイシミヤギノク', '榴岡', 'ツツジガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市宮城野区東六番丁', '04', '04102', '9830853', '宮城県', 'ミヤギケン', '仙台市宮城野区', 'センダイシミヤギノク', '東六番丁', 'ヒガシ06バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市宮城野区東七番丁', '04', '04102', '9830854', '宮城県', 'ミヤギケン', '仙台市宮城野区', 'センダイシミヤギノク', '東七番丁', 'ヒガシ07バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市宮城野区東八番丁', '04', '04102', '9830855', '宮城県', 'ミヤギケン', '仙台市宮城野区', 'センダイシミヤギノク', '東八番丁', 'ヒガシ08バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市宮城野区東九番丁', '04', '04102', '9830856', '宮城県', 'ミヤギケン', '仙台市宮城野区', 'センダイシミヤギノク', '東九番丁', 'ヒガシ09バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市宮城野区東十番丁', '04', '04102', '9830857', '宮城県', 'ミヤギケン', '仙台市宮城野区', 'センダイシミヤギノク', '東十番丁', 'ヒガシ10バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市宮城野区鉄砲町', '04', '04102', '9830861', '宮城県', 'ミヤギケン', '仙台市宮城野区', 'センダイシミヤギノク', '鉄砲町', 'テッポウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市宮城野区二十人町', '04', '04102', '9830862', '宮城県', 'ミヤギケン', '仙台市宮城野区', 'センダイシミヤギノク', '二十人町', 'ニジュウニンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市宮城野区車町', '04', '04102', '9830863', '宮城県', 'ミヤギケン', '仙台市宮城野区', 'センダイシミヤギノク', '車町', 'クルママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市宮城野区名掛丁', '04', '04102', '9830864', '宮城県', 'ミヤギケン', '仙台市宮城野区', 'センダイシミヤギノク', '名掛丁', 'ナカケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市宮城野区元寺小路', '04', '04102', '9830865', '宮城県', 'ミヤギケン', '仙台市宮城野区', 'センダイシミヤギノク', '元寺小路', 'モトテラコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市宮城野区花京院通', '04', '04102', '9830866', '宮城県', 'ミヤギケン', '仙台市宮城野区', 'センダイシミヤギノク', '花京院通', 'カキョウインドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡天塩町タツネウシ', '01', '01487', '0983131', '北海道', 'ホッカイドウ', '天塩郡天塩町', 'テシオグンテシオチョウ', 'タツネウシ', 'タツネウシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡天塩町東雄信内', '01', '01487', '0983132', '北海道', 'ホッカイドウ', '天塩郡天塩町', 'テシオグンテシオチョウ', '東雄信内', 'ヒガシオノブナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡天塩町オヌプナイ', '01', '01487', '0983133', '北海道', 'ホッカイドウ', '天塩郡天塩町', 'テシオグンテシオチョウ', 'オヌプナイ', 'オヌプナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡天塩町雄信内', '01', '01487', '0983133', '北海道', 'ホッカイドウ', '天塩郡天塩町', 'テシオグンテシオチョウ', '雄信内', 'オノブナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡天塩町円山', '01', '01487', '0983134', '北海道', 'ホッカイドウ', '天塩郡天塩町', 'テシオグンテシオチョウ', '円山', 'マルヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡天塩町東産士', '01', '01487', '0983135', '北海道', 'ホッカイドウ', '天塩郡天塩町', 'テシオグンテシオチョウ', '東産士', 'ヒガシウブシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡天塩町西雄信内', '01', '01487', '0983141', '北海道', 'ホッカイドウ', '天塩郡天塩町', 'テシオグンテシオチョウ', '西雄信内', 'ニシオノブナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡天塩町新成', '01', '01487', '0983142', '北海道', 'ホッカイドウ', '天塩郡天塩町', 'テシオグンテシオチョウ', '新成', 'シンセイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡天塩町泉源', '01', '01487', '0983143', '北海道', 'ホッカイドウ', '天塩郡天塩町', 'テシオグンテシオチョウ', '泉源', 'センゲン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡天塩町男能富', '01', '01487', '0983144', '北海道', 'ホッカイドウ', '天塩郡天塩町', 'テシオグンテシオチョウ', '男能富', 'ダンノップ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡幌延町雄興', '01', '01488', '0983151', '北海道', 'ホッカイドウ', '天塩郡幌延町', 'テシオグンホロノベチョウ', '雄興', 'ユウコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡幌延町', '01', '01488', '0983200', '北海道', 'ホッカイドウ', '天塩郡幌延町', 'テシオグンホロノベチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('141203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡幌延町1条北', '01', '01488', '0983201', '北海道', 'ホッカイドウ', '天塩郡幌延町', 'テシオグンホロノベチョウ', '1条北', '01ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡幌延町2条北', '01', '01488', '0983202', '北海道', 'ホッカイドウ', '天塩郡幌延町', 'テシオグンホロノベチョウ', '2条北', '02ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡幌延町3条北', '01', '01488', '0983203', '北海道', 'ホッカイドウ', '天塩郡幌延町', 'テシオグンホロノベチョウ', '3条北', '03ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡幌延町4条北', '01', '01488', '0983204', '北海道', 'ホッカイドウ', '天塩郡幌延町', 'テシオグンホロノベチョウ', '4条北', '04ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡幌延町5条北', '01', '01488', '0983205', '北海道', 'ホッカイドウ', '天塩郡幌延町', 'テシオグンホロノベチョウ', '5条北', '05ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡幌延町6条北', '01', '01488', '0983206', '北海道', 'ホッカイドウ', '天塩郡幌延町', 'テシオグンホロノベチョウ', '6条北', '06ジョウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡幌延町宮園町', '01', '01488', '0983207', '北海道', 'ホッカイドウ', '天塩郡幌延町', 'テシオグンホロノベチョウ', '宮園町', 'ミヤゾノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡幌延町1条南', '01', '01488', '0983211', '北海道', 'ホッカイドウ', '天塩郡幌延町', 'テシオグンホロノベチョウ', '1条南', '01ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡幌延町2条南', '01', '01488', '0983212', '北海道', 'ホッカイドウ', '天塩郡幌延町', 'テシオグンホロノベチョウ', '2条南', '02ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡幌延町3条南', '01', '01488', '0983213', '北海道', 'ホッカイドウ', '天塩郡幌延町', 'テシオグンホロノベチョウ', '3条南', '03ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡幌延町4条南', '01', '01488', '0983214', '北海道', 'ホッカイドウ', '天塩郡幌延町', 'テシオグンホロノベチョウ', '4条南', '04ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡幌延町5条南', '01', '01488', '0983215', '北海道', 'ホッカイドウ', '天塩郡幌延町', 'テシオグンホロノベチョウ', '5条南', '05ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡幌延町6条南', '01', '01488', '0983216', '北海道', 'ホッカイドウ', '天塩郡幌延町', 'テシオグンホロノベチョウ', '6条南', '06ジョウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡幌延町元町', '01', '01488', '0983217', '北海道', 'ホッカイドウ', '天塩郡幌延町', 'テシオグンホロノベチョウ', '元町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡幌延町栄町', '01', '01488', '0983221', '北海道', 'ホッカイドウ', '天塩郡幌延町', 'テシオグンホロノベチョウ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡幌延町東町', '01', '01488', '0983222', '北海道', 'ホッカイドウ', '天塩郡幌延町', 'テシオグンホロノベチョウ', '東町', 'ヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡幌延町幌延', '01', '01488', '0983223', '北海道', 'ホッカイドウ', '天塩郡幌延町', 'テシオグンホロノベチョウ', '幌延', 'ホロノベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡幌延町北進', '01', '01488', '0983224', '北海道', 'ホッカイドウ', '天塩郡幌延町', 'テシオグンホロノベチョウ', '北進', 'ホクシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡幌延町上幌延', '01', '01488', '0983225', '北海道', 'ホッカイドウ', '天塩郡幌延町', 'テシオグンホロノベチョウ', '上幌延', 'カミホロノベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡幌延町開進', '01', '01488', '0983226', '北海道', 'ホッカイドウ', '天塩郡幌延町', 'テシオグンホロノベチョウ', '開進', 'カイシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡幌延町浜里', '01', '01488', '0983227', '北海道', 'ホッカイドウ', '天塩郡幌延町', 'テシオグンホロノベチョウ', '浜里', 'ハマサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡幌延町下沼', '01', '01488', '0983228', '北海道', 'ホッカイドウ', '天塩郡幌延町', 'テシオグンホロノベチョウ', '下沼', 'シモヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡天塩町', '01', '01487', '0983300', '北海道', 'ホッカイドウ', '天塩郡天塩町', 'テシオグンテシオチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('141226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡天塩町山手通', '01', '01487', '0983301', '北海道', 'ホッカイドウ', '天塩郡天塩町', 'テシオグンテシオチョウ', '山手通', 'ヤマテドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡天塩町山手裏通', '01', '01487', '0983302', '北海道', 'ホッカイドウ', '天塩郡天塩町', 'テシオグンテシオチョウ', '山手裏通', 'ヤマテウラドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡天塩町新栄通', '01', '01487', '0983303', '北海道', 'ホッカイドウ', '天塩郡天塩町', 'テシオグンテシオチョウ', '新栄通', 'シンエイドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡天塩町新地通', '01', '01487', '0983304', '北海道', 'ホッカイドウ', '天塩郡天塩町', 'テシオグンテシオチョウ', '新地通', 'シンチドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡天塩町新開通', '01', '01487', '0983305', '北海道', 'ホッカイドウ', '天塩郡天塩町', 'テシオグンテシオチョウ', '新開通', 'シンカイドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡天塩町海岸通', '01', '01487', '0983306', '北海道', 'ホッカイドウ', '天塩郡天塩町', 'テシオグンテシオチョウ', '海岸通', 'カイガンドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡天塩町産士', '01', '01487', '0983311', '北海道', 'ホッカイドウ', '天塩郡天塩町', 'テシオグンテシオチョウ', '産士', 'ウブシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡天塩町川口', '01', '01487', '0983312', '北海道', 'ホッカイドウ', '天塩郡天塩町', 'テシオグンテシオチョウ', '川口', 'カワグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡天塩町作返', '01', '01487', '0983313', '北海道', 'ホッカイドウ', '天塩郡天塩町', 'テシオグンテシオチョウ', '作返', 'サクカエシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡天塩町更岸', '01', '01487', '0983314', '北海道', 'ホッカイドウ', '天塩郡天塩町', 'テシオグンテシオチョウ', '更岸', 'サラキシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡天塩町天塩', '01', '01487', '0983315', '北海道', 'ホッカイドウ', '天塩郡天塩町', 'テシオグンテシオチョウ', '天塩', 'テシオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡天塩町振老', '01', '01487', '0983316', '北海道', 'ホッカイドウ', '天塩郡天塩町', 'テシオグンテシオチョウ', '振老', 'フラオイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡遠別町北里15号の沢', '01', '01486', '0983361', '北海道', 'ホッカイドウ', '天塩郡遠別町', 'テシオグンエンベツチョウ', '北里', 'キタサト', null, null, '15号の沢', '15ゴウノサワ');
INSERT INTO `ms_addresses` VALUES ('141244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡遠別町', '01', '01486', '0983500', '北海道', 'ホッカイドウ', '天塩郡遠別町', 'テシオグンエンベツチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('141245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡遠別町北里', '01', '01486', '0983501', '北海道', 'ホッカイドウ', '天塩郡遠別町', 'テシオグンエンベツチョウ', '北里', 'キタサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡遠別町清川', '01', '01486', '0983502', '北海道', 'ホッカイドウ', '天塩郡遠別町', 'テシオグンエンベツチョウ', '清川', 'キヨカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡遠別町啓明', '01', '01486', '0983503', '北海道', 'ホッカイドウ', '天塩郡遠別町', 'テシオグンエンベツチョウ', '啓明', 'ケイメイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡遠別町丸松', '01', '01486', '0983504', '北海道', 'ホッカイドウ', '天塩郡遠別町', 'テシオグンエンベツチョウ', '丸松', 'マルマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡遠別町久光', '01', '01486', '0983511', '北海道', 'ホッカイドウ', '天塩郡遠別町', 'テシオグンエンベツチョウ', '久光', 'キュウコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡遠別町中央', '01', '01486', '0983512', '北海道', 'ホッカイドウ', '天塩郡遠別町', 'テシオグンエンベツチョウ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡遠別町共栄', '01', '01486', '0983521', '北海道', 'ホッカイドウ', '天塩郡遠別町', 'テシオグンエンベツチョウ', '共栄', 'キョウエイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡遠別町大成', '01', '01486', '0983522', '北海道', 'ホッカイドウ', '天塩郡遠別町', 'テシオグンエンベツチョウ', '大成', 'タイセイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡遠別町東野', '01', '01486', '0983523', '北海道', 'ホッカイドウ', '天塩郡遠別町', 'テシオグンエンベツチョウ', '東野', 'ヒガシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡遠別町旭', '01', '01486', '0983531', '北海道', 'ホッカイドウ', '天塩郡遠別町', 'テシオグンエンベツチョウ', '旭', 'アサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡遠別町歌越', '01', '01486', '0983532', '北海道', 'ホッカイドウ', '天塩郡遠別町', 'テシオグンエンベツチョウ', '歌越', 'ウタコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡遠別町金浦', '01', '01486', '0983533', '北海道', 'ホッカイドウ', '天塩郡遠別町', 'テシオグンエンベツチョウ', '金浦', 'カナウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡遠別町富士見', '01', '01486', '0983534', '北海道', 'ホッカイドウ', '天塩郡遠別町', 'テシオグンエンベツチョウ', '富士見', 'フジミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡遠別町北浜', '01', '01486', '0983541', '北海道', 'ホッカイドウ', '天塩郡遠別町', 'テシオグンエンベツチョウ', '北浜', 'キタハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡遠別町幸和', '01', '01486', '0983542', '北海道', 'ホッカイドウ', '天塩郡遠別町', 'テシオグンエンベツチョウ', '幸和', 'コウワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡遠別町本町', '01', '01486', '0983543', '北海道', 'ホッカイドウ', '天塩郡遠別町', 'テシオグンエンベツチョウ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市若林区', '04', '04103', '9840000', '宮城県', 'ミヤギケン', '仙台市若林区', 'センダイシワカバヤシク', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('141297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市若林区鶴代町', '04', '04103', '9840001', '宮城県', 'ミヤギケン', '仙台市若林区', 'センダイシワカバヤシク', '鶴代町', 'ツルシロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市若林区卸町東', '04', '04103', '9840002', '宮城県', 'ミヤギケン', '仙台市若林区', 'センダイシワカバヤシク', '卸町東', 'オロシマチヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市若林区六丁の目北町', '04', '04103', '9840003', '宮城県', 'ミヤギケン', '仙台市若林区', 'センダイシワカバヤシク', '六丁の目北町', 'ロクチョウノメキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市若林区六丁の目東町', '04', '04103', '9840004', '宮城県', 'ミヤギケン', '仙台市若林区', 'センダイシワカバヤシク', '六丁の目東町', 'ロクチョウノメヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市若林区六丁の目西町', '04', '04103', '9840011', '宮城県', 'ミヤギケン', '仙台市若林区', 'センダイシワカバヤシク', '六丁の目西町', 'ロクチョウノメニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市若林区六丁の目中町', '04', '04103', '9840012', '宮城県', 'ミヤギケン', '仙台市若林区', 'センダイシワカバヤシク', '六丁の目中町', 'ロクチョウノメナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市若林区六丁の目南町', '04', '04103', '9840013', '宮城県', 'ミヤギケン', '仙台市若林区', 'センダイシワカバヤシク', '六丁の目南町', 'ロクチョウノメミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市若林区六丁の目元町', '04', '04103', '9840014', '宮城県', 'ミヤギケン', '仙台市若林区', 'センダイシワカバヤシク', '六丁の目元町', 'ロクチョウノメモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市若林区卸町', '04', '04103', '9840015', '宮城県', 'ミヤギケン', '仙台市若林区', 'センダイシワカバヤシク', '卸町', 'オロシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市若林区五橋3丁目', '04', '04103', '9840022', '宮城県', 'ミヤギケン', '仙台市若林区', 'センダイシワカバヤシク', '五橋', 'イツツバシ', null, null, '3丁目', '03チョウメ');
INSERT INTO `ms_addresses` VALUES ('141307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市若林区六丁目', '04', '04103', '9840031', '宮城県', 'ミヤギケン', '仙台市若林区', 'センダイシワカバヤシク', '六丁目', 'ロクチョウノメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市若林区荒井', '04', '04103', '9840032', '宮城県', 'ミヤギケン', '仙台市若林区', 'センダイシワカバヤシク', '荒井', 'アライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市若林区荒浜', '04', '04103', '9840033', '宮城県', 'ミヤギケン', '仙台市若林区', 'センダイシワカバヤシク', '荒浜', 'アラハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市若林区荒浜新', '04', '04103', '9840034', '宮城県', 'ミヤギケン', '仙台市若林区', 'センダイシワカバヤシク', '荒浜新', 'アラハマシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市若林区霞目', '04', '04103', '9840035', '宮城県', 'ミヤギケン', '仙台市若林区', 'センダイシワカバヤシク', '霞目', 'カスミノメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市若林区長喜城', '04', '04103', '9840036', '宮城県', 'ミヤギケン', '仙台市若林区', 'センダイシワカバヤシク', '長喜城', 'チョウキジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市若林区蒲町', '04', '04103', '9840037', '宮城県', 'ミヤギケン', '仙台市若林区', 'センダイシワカバヤシク', '蒲町', 'カバノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市若林区伊在', '04', '04103', '9840038', '宮城県', 'ミヤギケン', '仙台市若林区', 'センダイシワカバヤシク', '伊在', 'イザイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市若林区志波町', '04', '04103', '9840041', '宮城県', 'ミヤギケン', '仙台市若林区', 'センダイシワカバヤシク', '志波町', 'シワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市若林区大和町', '04', '04103', '9840042', '宮城県', 'ミヤギケン', '仙台市若林区', 'センダイシワカバヤシク', '大和町', 'ヤマトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市若林区東新丁', '04', '04103', '9840043', '宮城県', 'ミヤギケン', '仙台市若林区', 'センダイシワカバヤシク', '東新丁', 'ヒガシシンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市若林区椌木通', '04', '04103', '9840044', '宮城県', 'ミヤギケン', '仙台市若林区', 'センダイシワカバヤシク', '椌木通', 'ゴウラキドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市若林区西新丁', '04', '04103', '9840045', '宮城県', 'ミヤギケン', '仙台市若林区', 'センダイシワカバヤシク', '西新丁', 'ニシシンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市若林区二軒茶屋', '04', '04103', '9840046', '宮城県', 'ミヤギケン', '仙台市若林区', 'センダイシワカバヤシク', '二軒茶屋', 'ニケンチャヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市若林区木ノ下', '04', '04103', '9840047', '宮城県', 'ミヤギケン', '仙台市若林区', 'センダイシワカバヤシク', '木ノ下', 'キノシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市若林区白萩町', '04', '04103', '9840048', '宮城県', 'ミヤギケン', '仙台市若林区', 'センダイシワカバヤシク', '白萩町', 'シラハギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市若林区新寺', '04', '04103', '9840051', '宮城県', 'ミヤギケン', '仙台市若林区', 'センダイシワカバヤシク', '新寺', 'シンテラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市若林区連坊', '04', '04103', '9840052', '宮城県', 'ミヤギケン', '仙台市若林区', 'センダイシワカバヤシク', '連坊', 'レンボウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市若林区連坊小路', '04', '04103', '9840053', '宮城県', 'ミヤギケン', '仙台市若林区', 'センダイシワカバヤシク', '連坊小路', 'レンボウコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市若林区裏柴田町', '04', '04103', '9840054', '宮城県', 'ミヤギケン', '仙台市若林区', 'センダイシワカバヤシク', '裏柴田町', 'ウラシバタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市若林区表柴田町', '04', '04103', '9840055', '宮城県', 'ミヤギケン', '仙台市若林区', 'センダイシワカバヤシク', '表柴田町', 'オモテシバタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市若林区成田町', '04', '04103', '9840056', '宮城県', 'ミヤギケン', '仙台市若林区', 'センダイシワカバヤシク', '成田町', 'ナリタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市若林区三百人町', '04', '04103', '9840057', '宮城県', 'ミヤギケン', '仙台市若林区', 'センダイシワカバヤシク', '三百人町', 'サンビャクニンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市若林区元茶畑', '04', '04103', '9840058', '宮城県', 'ミヤギケン', '仙台市若林区', 'センダイシワカバヤシク', '元茶畑', 'モトチャバタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市若林区南鍛冶町', '04', '04103', '9840061', '宮城県', 'ミヤギケン', '仙台市若林区', 'センダイシワカバヤシク', '南鍛冶町', 'ミナミカジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市若林区弓ノ町', '04', '04103', '9840062', '宮城県', 'ミヤギケン', '仙台市若林区', 'センダイシワカバヤシク', '弓ノ町', 'ユミノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市若林区石名坂', '04', '04103', '9840063', '宮城県', 'ミヤギケン', '仙台市若林区', 'センダイシワカバヤシク', '石名坂', 'イシナザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市若林区石垣町', '04', '04103', '9840064', '宮城県', 'ミヤギケン', '仙台市若林区', 'センダイシワカバヤシク', '石垣町', 'イシガキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市若林区土樋', '04', '04103', '9840065', '宮城県', 'ミヤギケン', '仙台市若林区', 'センダイシワカバヤシク', '土樋', 'ツチトイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市若林区東九番丁', '04', '04103', '9840071', '宮城県', 'ミヤギケン', '仙台市若林区', 'センダイシワカバヤシク', '東九番丁', 'ヒガシ09バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市若林区東八番丁', '04', '04103', '9840072', '宮城県', 'ミヤギケン', '仙台市若林区', 'センダイシワカバヤシク', '東八番丁', 'ヒガシ08バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市若林区荒町', '04', '04103', '9840073', '宮城県', 'ミヤギケン', '仙台市若林区', 'センダイシワカバヤシク', '荒町', 'アラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市若林区東七番丁', '04', '04103', '9840074', '宮城県', 'ミヤギケン', '仙台市若林区', 'センダイシワカバヤシク', '東七番丁', 'ヒガシ07バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市若林区清水小路', '04', '04103', '9840075', '宮城県', 'ミヤギケン', '仙台市若林区', 'センダイシワカバヤシク', '清水小路', 'シミズコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市若林区畳屋丁', '04', '04103', '9840801', '宮城県', 'ミヤギケン', '仙台市若林区', 'センダイシワカバヤシク', '畳屋丁', 'タタミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市若林区八軒小路', '04', '04103', '9840802', '宮城県', 'ミヤギケン', '仙台市若林区', 'センダイシワカバヤシク', '八軒小路', 'ハチケンコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市若林区新弓ノ町', '04', '04103', '9840803', '宮城県', 'ミヤギケン', '仙台市若林区', 'センダイシワカバヤシク', '新弓ノ町', 'シンユミノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市若林区南石切町', '04', '04103', '9840804', '宮城県', 'ミヤギケン', '仙台市若林区', 'センダイシワカバヤシク', '南石切町', 'ミナミイシキリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市若林区南材木町', '04', '04103', '9840805', '宮城県', 'ミヤギケン', '仙台市若林区', 'センダイシワカバヤシク', '南材木町', 'ミナミザイモクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市若林区舟丁', '04', '04103', '9840806', '宮城県', 'ミヤギケン', '仙台市若林区', 'センダイシワカバヤシク', '舟丁', 'フナチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市若林区穀町', '04', '04103', '9840807', '宮城県', 'ミヤギケン', '仙台市若林区', 'センダイシワカバヤシク', '穀町', 'コクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市若林区保春院前丁', '04', '04103', '9840811', '宮城県', 'ミヤギケン', '仙台市若林区', 'センダイシワカバヤシク', '保春院前丁', 'ホシュンインマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市若林区五十人町', '04', '04103', '9840812', '宮城県', 'ミヤギケン', '仙台市若林区', 'センダイシワカバヤシク', '五十人町', 'ゴジュウニンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市若林区六十人町', '04', '04103', '9840813', '宮城県', 'ミヤギケン', '仙台市若林区', 'センダイシワカバヤシク', '六十人町', 'ロクジュウニンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市若林区南染師町', '04', '04103', '9840814', '宮城県', 'ミヤギケン', '仙台市若林区', 'センダイシワカバヤシク', '南染師町', 'ミナミソメシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市若林区文化町', '04', '04103', '9840815', '宮城県', 'ミヤギケン', '仙台市若林区', 'センダイシワカバヤシク', '文化町', 'ブンカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市若林区河原町', '04', '04103', '9840816', '宮城県', 'ミヤギケン', '仙台市若林区', 'センダイシワカバヤシク', '河原町', 'カワラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市若林区堰場', '04', '04103', '9840817', '宮城県', 'ミヤギケン', '仙台市若林区', 'センダイシワカバヤシク', '堰場', 'ドウバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市若林区中倉', '04', '04103', '9840821', '宮城県', 'ミヤギケン', '仙台市若林区', 'センダイシワカバヤシク', '中倉', 'ナカクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市若林区かすみ町', '04', '04103', '9840822', '宮城県', 'ミヤギケン', '仙台市若林区', 'センダイシワカバヤシク', 'かすみ町', 'カスミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市若林区遠見塚', '04', '04103', '9840823', '宮城県', 'ミヤギケン', '仙台市若林区', 'センダイシワカバヤシク', '遠見塚', 'トオミヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市若林区遠見塚東', '04', '04103', '9840824', '宮城県', 'ミヤギケン', '仙台市若林区', 'センダイシワカバヤシク', '遠見塚東', 'トオミヅカヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市若林区古城', '04', '04103', '9840825', '宮城県', 'ミヤギケン', '仙台市若林区', 'センダイシワカバヤシク', '古城', 'フルジロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市若林区若林', '04', '04103', '9840826', '宮城県', 'ミヤギケン', '仙台市若林区', 'センダイシワカバヤシク', '若林', 'ワカバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市若林区南小泉', '04', '04103', '9840827', '宮城県', 'ミヤギケン', '仙台市若林区', 'センダイシワカバヤシク', '南小泉', 'ミナミコイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市若林区一本杉町', '04', '04103', '9840828', '宮城県', 'ミヤギケン', '仙台市若林区', 'センダイシワカバヤシク', '一本杉町', 'イッポンスギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市若林区沖野', '04', '04103', '9840831', '宮城県', 'ミヤギケン', '仙台市若林区', 'センダイシワカバヤシク', '沖野', 'オキノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市若林区下飯田', '04', '04103', '9840832', '宮城県', 'ミヤギケン', '仙台市若林区', 'センダイシワカバヤシク', '下飯田', 'シモイイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市若林区飯田', '04', '04103', '9840833', '宮城県', 'ミヤギケン', '仙台市若林区', 'センダイシワカバヤシク', '飯田', 'イイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市若林区六郷', '04', '04103', '9840834', '宮城県', 'ミヤギケン', '仙台市若林区', 'センダイシワカバヤシク', '六郷', 'ロクゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市若林区今泉', '04', '04103', '9840835', '宮城県', 'ミヤギケン', '仙台市若林区', 'センダイシワカバヤシク', '今泉', 'イマイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市若林区四郎丸', '04', '04103', '9840836', '宮城県', 'ミヤギケン', '仙台市若林区', 'センダイシワカバヤシク', '四郎丸', 'シロウマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市若林区日辺', '04', '04103', '9840837', '宮城県', 'ミヤギケン', '仙台市若林区', 'センダイシワカバヤシク', '日辺', 'ニッペ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市若林区上飯田', '04', '04103', '9840838', '宮城県', 'ミヤギケン', '仙台市若林区', 'センダイシワカバヤシク', '上飯田', 'カミイイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市若林区三本塚', '04', '04103', '9840841', '宮城県', 'ミヤギケン', '仙台市若林区', 'センダイシワカバヤシク', '三本塚', 'サンボンツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市若林区井土', '04', '04103', '9840842', '宮城県', 'ミヤギケン', '仙台市若林区', 'センダイシワカバヤシク', '井土', 'イド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市若林区藤塚', '04', '04103', '9840843', '宮城県', 'ミヤギケン', '仙台市若林区', 'センダイシワカバヤシク', '藤塚', 'フジツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市若林区種次', '04', '04103', '9840844', '宮城県', 'ミヤギケン', '仙台市若林区', 'センダイシワカバヤシク', '種次', 'タナツギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市若林区二木', '04', '04103', '9840845', '宮城県', 'ミヤギケン', '仙台市若林区', 'センダイシワカバヤシク', '二木', 'フタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡豊富町', '01', '01516', '0984100', '北海道', 'ホッカイドウ', '天塩郡豊富町', 'テシオグントヨトミチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('141377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡豊富町福永', '01', '01516', '0984101', '北海道', 'ホッカイドウ', '天塩郡豊富町', 'テシオグントヨトミチョウ', '福永', 'フクナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡豊富町目梨別', '01', '01516', '0984102', '北海道', 'ホッカイドウ', '天塩郡豊富町', 'テシオグントヨトミチョウ', '目梨別', 'メナシベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡豊富町有明', '01', '01516', '0984103', '北海道', 'ホッカイドウ', '天塩郡豊富町', 'テシオグントヨトミチョウ', '有明', 'アリアケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡豊富町修徳', '01', '01516', '0984104', '北海道', 'ホッカイドウ', '天塩郡豊富町', 'テシオグントヨトミチョウ', '修徳', 'シュウトク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡豊富町幌加', '01', '01516', '0984105', '北海道', 'ホッカイドウ', '天塩郡豊富町', 'テシオグントヨトミチョウ', '幌加', 'ホロカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡豊富町豊徳', '01', '01516', '0984106', '北海道', 'ホッカイドウ', '天塩郡豊富町', 'テシオグントヨトミチョウ', '豊徳', 'ホウトク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡豊富町稚咲内', '01', '01516', '0984107', '北海道', 'ホッカイドウ', '天塩郡豊富町', 'テシオグントヨトミチョウ', '稚咲内', 'ワカサカナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡豊富町大通り', '01', '01516', '0984110', '北海道', 'ホッカイドウ', '天塩郡豊富町', 'テシオグントヨトミチョウ', '大通り', 'オオドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡豊富町西1条', '01', '01516', '0984111', '北海道', 'ホッカイドウ', '天塩郡豊富町', 'テシオグントヨトミチョウ', '西1条', 'ニシ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡豊富町西2条', '01', '01516', '0984112', '北海道', 'ホッカイドウ', '天塩郡豊富町', 'テシオグントヨトミチョウ', '西2条', 'ニシ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡豊富町西3条', '01', '01516', '0984113', '北海道', 'ホッカイドウ', '天塩郡豊富町', 'テシオグントヨトミチョウ', '西3条', 'ニシ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡豊富町西4条', '01', '01516', '0984114', '北海道', 'ホッカイドウ', '天塩郡豊富町', 'テシオグントヨトミチョウ', '西4条', 'ニシ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡豊富町西5条', '01', '01516', '0984115', '北海道', 'ホッカイドウ', '天塩郡豊富町', 'テシオグントヨトミチョウ', '西5条', 'ニシ05ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡豊富町西豊富', '01', '01516', '0984116', '北海道', 'ホッカイドウ', '天塩郡豊富町', 'テシオグントヨトミチョウ', '西豊富', 'ニシトヨトミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡豊富町落合', '01', '01516', '0984117', '北海道', 'ホッカイドウ', '天塩郡豊富町', 'テシオグントヨトミチョウ', '落合', 'オチアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡豊富町東1条', '01', '01516', '0984121', '北海道', 'ホッカイドウ', '天塩郡豊富町', 'テシオグントヨトミチョウ', '東1条', 'ヒガシ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡豊富町東2条', '01', '01516', '0984122', '北海道', 'ホッカイドウ', '天塩郡豊富町', 'テシオグントヨトミチョウ', '東2条', 'ヒガシ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡豊富町東3条', '01', '01516', '0984123', '北海道', 'ホッカイドウ', '天塩郡豊富町', 'テシオグントヨトミチョウ', '東3条', 'ヒガシ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡豊富町東4条', '01', '01516', '0984124', '北海道', 'ホッカイドウ', '天塩郡豊富町', 'テシオグントヨトミチョウ', '東4条', 'ヒガシ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡豊富町東5条', '01', '01516', '0984125', '北海道', 'ホッカイドウ', '天塩郡豊富町', 'テシオグントヨトミチョウ', '東5条', 'ヒガシ05ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡豊富町東6条', '01', '01516', '0984126', '北海道', 'ホッカイドウ', '天塩郡豊富町', 'テシオグントヨトミチョウ', '東6条', 'ヒガシ06ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡豊富町東豊富', '01', '01516', '0984131', '北海道', 'ホッカイドウ', '天塩郡豊富町', 'テシオグントヨトミチョウ', '東豊富', 'ヒガシトヨトミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡豊富町温泉', '01', '01516', '0984132', '北海道', 'ホッカイドウ', '天塩郡豊富町', 'テシオグントヨトミチョウ', '温泉', 'オンセン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡豊富町本流', '01', '01516', '0984133', '北海道', 'ホッカイドウ', '天塩郡豊富町', 'テシオグントヨトミチョウ', '本流', 'ホンリュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡豊富町豊幌', '01', '01516', '0984134', '北海道', 'ホッカイドウ', '天塩郡豊富町', 'テシオグントヨトミチョウ', '豊幌', 'トヨホロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡豊富町豊川', '01', '01516', '0984135', '北海道', 'ホッカイドウ', '天塩郡豊富町', 'テシオグントヨトミチョウ', '豊川', 'トヨカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡豊富町新生', '01', '01516', '0984136', '北海道', 'ホッカイドウ', '天塩郡豊富町', 'テシオグントヨトミチョウ', '新生', 'シンセイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡豊富町徳満', '01', '01516', '0984137', '北海道', 'ホッカイドウ', '天塩郡豊富町', 'テシオグントヨトミチョウ', '徳満', 'トクミツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡豊富町駅前通', '01', '01516', '0984138', '北海道', 'ホッカイドウ', '天塩郡豊富町', 'テシオグントヨトミチョウ', '駅前通', 'エキマエドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡豊富町仲通り', '01', '01516', '0984139', '北海道', 'ホッカイドウ', '天塩郡豊富町', 'テシオグントヨトミチョウ', '仲通り', 'ナカドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡豊富町停車場通', '01', '01516', '0984140', '北海道', 'ホッカイドウ', '天塩郡豊富町', 'テシオグントヨトミチョウ', '停車場通', 'テイシャバドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡豊富町三条通り', '01', '01516', '0984141', '北海道', 'ホッカイドウ', '天塩郡豊富町', 'テシオグントヨトミチョウ', '三条通り', 'サンジョウドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡豊富町兜沼', '01', '01516', '0984451', '北海道', 'ホッカイドウ', '天塩郡豊富町', 'テシオグントヨトミチョウ', '兜沼', 'カブトヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡豊富町芦川', '01', '01516', '0984455', '北海道', 'ホッカイドウ', '天塩郡豊富町', 'テシオグントヨトミチョウ', '芦川', 'アシカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡豊富町開源', '01', '01516', '0984456', '北海道', 'ホッカイドウ', '天塩郡豊富町', 'テシオグントヨトミチョウ', '開源', 'カイゲン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡豊富町沼向', '01', '01516', '0984457', '北海道', 'ホッカイドウ', '天塩郡豊富町', 'テシオグントヨトミチョウ', '沼向', 'ヌマムカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡豊富町瑞穂東', '01', '01516', '0984461', '北海道', 'ホッカイドウ', '天塩郡豊富町', 'テシオグントヨトミチョウ', '瑞穂東', 'ミズホヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡豊富町阿沙流', '01', '01516', '0984462', '北海道', 'ホッカイドウ', '天塩郡豊富町', 'テシオグントヨトミチョウ', '阿沙流', 'アサル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡豊富町瑞穂南', '01', '01516', '0984463', '北海道', 'ホッカイドウ', '天塩郡豊富町', 'テシオグントヨトミチョウ', '瑞穂南', 'ミズホミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡豊富町豊栄', '01', '01516', '0984464', '北海道', 'ホッカイドウ', '天塩郡豊富町', 'テシオグントヨトミチョウ', '豊栄', 'ホウエイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡豊富町豊田', '01', '01516', '0984465', '北海道', 'ホッカイドウ', '天塩郡豊富町', 'テシオグントヨトミチョウ', '豊田', 'ホウデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡豊富町清明', '01', '01516', '0984466', '北海道', 'ホッカイドウ', '天塩郡豊富町', 'テシオグントヨトミチョウ', '清明', 'セイメイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡豊富町豊里', '01', '01516', '0984467', '北海道', 'ホッカイドウ', '天塩郡豊富町', 'テシオグントヨトミチョウ', '豊里', 'トヨサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道天塩郡豊富町落合', '01', '01516', '0984468', '北海道', 'ホッカイドウ', '天塩郡豊富町', 'テシオグントヨトミチョウ', '落合', 'オチアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道稚内市抜海村オネトマナイ', '01', '01214', '0984581', '北海道', 'ホッカイドウ', '稚内市', 'ワッカナイシ', '抜海村', 'バッカイムラ', null, null, 'オネトマナイ', 'オネトマナイ');
INSERT INTO `ms_addresses` VALUES ('141422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道稚内市抜海村上勇知', '01', '01214', '0984581', '北海道', 'ホッカイドウ', '稚内市', 'ワッカナイシ', '抜海村', 'バッカイムラ', null, null, '上勇知', 'カミユウチ');
INSERT INTO `ms_addresses` VALUES ('141423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道稚内市抜海村下勇知', '01', '01214', '0984581', '北海道', 'ホッカイドウ', '稚内市', 'ワッカナイシ', '抜海村', 'バッカイムラ', null, null, '下勇知', 'シモユウチ');
INSERT INTO `ms_addresses` VALUES ('141424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道稚内市抜海村夕来', '01', '01214', '0984581', '北海道', 'ホッカイドウ', '稚内市', 'ワッカナイシ', '抜海村', 'バッカイムラ', null, null, '夕来', 'ユウクル');
INSERT INTO `ms_addresses` VALUES ('141425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道稚内市声問村更喜苫内', '01', '01214', '0984582', '北海道', 'ホッカイドウ', '稚内市', 'ワッカナイシ', '声問村', 'コエトイムラ', null, null, '更喜苫内', 'サラキトマナイ');
INSERT INTO `ms_addresses` VALUES ('141476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県塩竈市', '04', '04203', '9850000', '宮城県', 'ミヤギケン', '塩竈市', 'シオガマシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('141477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県多賀城市', '04', '04209', '9850000', '宮城県', 'ミヤギケン', '多賀城市', 'タガジョウシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('141478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県宮城郡七ヶ浜町', '04', '04404', '9850000', '宮城県', 'ミヤギケン', '宮城郡七ヶ浜町', 'ミヤギグンシチガハママチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('141479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県塩竈市新浜町', '04', '04203', '9850001', '宮城県', 'ミヤギケン', '塩竈市', 'シオガマシ', '新浜町', 'シンハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県塩竈市海岸通', '04', '04203', '9850002', '宮城県', 'ミヤギケン', '塩竈市', 'シオガマシ', '海岸通', 'カイガンドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県塩竈市北浜', '04', '04203', '9850003', '宮城県', 'ミヤギケン', '塩竈市', 'シオガマシ', '北浜', 'キタハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県塩竈市藤倉', '04', '04203', '9850004', '宮城県', 'ミヤギケン', '塩竈市', 'シオガマシ', '藤倉', 'フジクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県塩竈市杉の入', '04', '04203', '9850005', '宮城県', 'ミヤギケン', '塩竈市', 'シオガマシ', '杉の入', 'スギノイリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県塩竈市杉の入裏', '04', '04203', '9850006', '宮城県', 'ミヤギケン', '塩竈市', 'シオガマシ', '杉の入裏', 'スギノイリウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県塩竈市貞山通', '04', '04203', '9850011', '宮城県', 'ミヤギケン', '塩竈市', 'シオガマシ', '貞山通', 'テイザンドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県塩竈市芦畔町', '04', '04203', '9850012', '宮城県', 'ミヤギケン', '塩竈市', 'シオガマシ', '芦畔町', 'アシグロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県塩竈市牛生町', '04', '04203', '9850013', '宮城県', 'ミヤギケン', '塩竈市', 'シオガマシ', '牛生町', 'ギュウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県塩竈市舟入', '04', '04203', '9850014', '宮城県', 'ミヤギケン', '塩竈市', 'シオガマシ', '舟入', 'フナイリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県塩竈市中の島', '04', '04203', '9850015', '宮城県', 'ミヤギケン', '塩竈市', 'シオガマシ', '中の島', 'ナカノシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県塩竈市港町', '04', '04203', '9850016', '宮城県', 'ミヤギケン', '塩竈市', 'シオガマシ', '港町', 'ミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県塩竈市尾島町', '04', '04203', '9850021', '宮城県', 'ミヤギケン', '塩竈市', 'シオガマシ', '尾島町', 'オジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県塩竈市新富町', '04', '04203', '9850022', '宮城県', 'ミヤギケン', '塩竈市', 'シオガマシ', '新富町', 'シントミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県塩竈市花立町', '04', '04203', '9850023', '宮城県', 'ミヤギケン', '塩竈市', 'シオガマシ', '花立町', 'ハナダテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県塩竈市錦町', '04', '04203', '9850024', '宮城県', 'ミヤギケン', '塩竈市', 'シオガマシ', '錦町', 'ニシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県塩竈市佐浦町', '04', '04203', '9850025', '宮城県', 'ミヤギケン', '塩竈市', 'シオガマシ', '佐浦町', 'サウラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県塩竈市旭町', '04', '04203', '9850026', '宮城県', 'ミヤギケン', '塩竈市', 'シオガマシ', '旭町', 'アサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県塩竈市石堂', '04', '04203', '9850031', '宮城県', 'ミヤギケン', '塩竈市', 'シオガマシ', '石堂', 'イシドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県塩竈市白萩町', '04', '04203', '9850032', '宮城県', 'ミヤギケン', '塩竈市', 'シオガマシ', '白萩町', 'シラハギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県塩竈市桜ケ丘', '04', '04203', '9850033', '宮城県', 'ミヤギケン', '塩竈市', 'シオガマシ', '桜ケ丘', 'サクラガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県塩竈市南錦町', '04', '04203', '9850034', '宮城県', 'ミヤギケン', '塩竈市', 'シオガマシ', '南錦町', 'ミナミニシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県塩竈市野田', '04', '04203', '9850035', '宮城県', 'ミヤギケン', '塩竈市', 'シオガマシ', '野田', 'ノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県塩竈市東玉川町', '04', '04203', '9850036', '宮城県', 'ミヤギケン', '塩竈市', 'シオガマシ', '東玉川町', 'ヒガシタマガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県塩竈市白菊町', '04', '04203', '9850041', '宮城県', 'ミヤギケン', '塩竈市', 'シオガマシ', '白菊町', 'シラギクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県塩竈市玉川', '04', '04203', '9850042', '宮城県', 'ミヤギケン', '塩竈市', 'シオガマシ', '玉川', 'タマガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県塩竈市袖野田町', '04', '04203', '9850043', '宮城県', 'ミヤギケン', '塩竈市', 'シオガマシ', '袖野田町', 'ソデノダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県塩竈市母子沢町', '04', '04203', '9850044', '宮城県', 'ミヤギケン', '塩竈市', 'シオガマシ', '母子沢町', 'ハハコザワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県塩竈市西玉川町', '04', '04203', '9850045', '宮城県', 'ミヤギケン', '塩竈市', 'シオガマシ', '西玉川町', 'ニシタマガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県塩竈市大日向町', '04', '04203', '9850046', '宮城県', 'ミヤギケン', '塩竈市', 'シオガマシ', '大日向町', 'オオヒナタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県塩竈市宮町', '04', '04203', '9850051', '宮城県', 'ミヤギケン', '塩竈市', 'シオガマシ', '宮町', 'ミヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県塩竈市本町', '04', '04203', '9850052', '宮城県', 'ミヤギケン', '塩竈市', 'シオガマシ', '本町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県塩竈市南町', '04', '04203', '9850053', '宮城県', 'ミヤギケン', '塩竈市', 'シオガマシ', '南町', 'ミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県塩竈市香津町', '04', '04203', '9850054', '宮城県', 'ミヤギケン', '塩竈市', 'シオガマシ', '香津町', 'コウヅマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県塩竈市赤坂', '04', '04203', '9850055', '宮城県', 'ミヤギケン', '塩竈市', 'シオガマシ', '赤坂', 'アカサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県塩竈市泉ケ岡', '04', '04203', '9850056', '宮城県', 'ミヤギケン', '塩竈市', 'シオガマシ', '泉ケ岡', 'イズミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県塩竈市西町', '04', '04203', '9850057', '宮城県', 'ミヤギケン', '塩竈市', 'シオガマシ', '西町', 'ニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県塩竈市清水沢', '04', '04203', '9850061', '宮城県', 'ミヤギケン', '塩竈市', 'シオガマシ', '清水沢', 'シミズサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県塩竈市泉沢町', '04', '04203', '9850062', '宮城県', 'ミヤギケン', '塩竈市', 'シオガマシ', '泉沢町', 'イズミサワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県塩竈市栄町', '04', '04203', '9850063', '宮城県', 'ミヤギケン', '塩竈市', 'シオガマシ', '栄町', 'サカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県塩竈市権現堂', '04', '04203', '9850064', '宮城県', 'ミヤギケン', '塩竈市', 'シオガマシ', '権現堂', 'ゴンゲンドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県塩竈市向ケ丘', '04', '04203', '9850065', '宮城県', 'ミヤギケン', '塩竈市', 'シオガマシ', '向ケ丘', 'ムカイガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県塩竈市月見ケ丘', '04', '04203', '9850066', '宮城県', 'ミヤギケン', '塩竈市', 'シオガマシ', '月見ケ丘', 'ツキミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県塩竈市後楽町', '04', '04203', '9850067', '宮城県', 'ミヤギケン', '塩竈市', 'シオガマシ', '後楽町', 'コウラクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県塩竈市松陽台', '04', '04203', '9850071', '宮城県', 'ミヤギケン', '塩竈市', 'シオガマシ', '松陽台', 'ショウヨウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県塩竈市小松崎', '04', '04203', '9850072', '宮城県', 'ミヤギケン', '塩竈市', 'シオガマシ', '小松崎', 'コマツザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県塩竈市みのが丘', '04', '04203', '9850073', '宮城県', 'ミヤギケン', '塩竈市', 'シオガマシ', 'みのが丘', 'ミノガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県塩竈市一森山', '04', '04203', '9850074', '宮城県', 'ミヤギケン', '塩竈市', 'シオガマシ', '一森山', 'イチモリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県塩竈市今宮町', '04', '04203', '9850075', '宮城県', 'ミヤギケン', '塩竈市', 'シオガマシ', '今宮町', 'イマミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県塩竈市長沢町', '04', '04203', '9850076', '宮城県', 'ミヤギケン', '塩竈市', 'シオガマシ', '長沢町', 'ナガサワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県塩竈市梅の宮', '04', '04203', '9850077', '宮城県', 'ミヤギケン', '塩竈市', 'シオガマシ', '梅の宮', 'ウメノミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県塩竈市石田', '04', '04203', '9850081', '宮城県', 'ミヤギケン', '塩竈市', 'シオガマシ', '石田', 'イシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県塩竈市青葉ケ丘', '04', '04203', '9850082', '宮城県', 'ミヤギケン', '塩竈市', 'シオガマシ', '青葉ケ丘', 'アオバガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県塩竈市越ノ浦', '04', '04203', '9850083', '宮城県', 'ミヤギケン', '塩竈市', 'シオガマシ', '越ノ浦', 'コシノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県塩竈市楓町', '04', '04203', '9850084', '宮城県', 'ミヤギケン', '塩竈市', 'シオガマシ', '楓町', 'カエデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県塩竈市庚塚', '04', '04203', '9850085', '宮城県', 'ミヤギケン', '塩竈市', 'シオガマシ', '庚塚', 'カノエヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県塩竈市千賀の台', '04', '04203', '9850086', '宮城県', 'ミヤギケン', '塩竈市', 'シオガマシ', '千賀の台', 'チガノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県塩竈市伊保石', '04', '04203', '9850087', '宮城県', 'ミヤギケン', '塩竈市', 'シオガマシ', '伊保石', 'イボイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県塩竈市長沢', '04', '04203', '9850088', '宮城県', 'ミヤギケン', '塩竈市', 'シオガマシ', '長沢', 'ナガサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県塩竈市浦戸石浜', '04', '04203', '9850191', '宮城県', 'ミヤギケン', '塩竈市', 'シオガマシ', '浦戸石浜', 'ウラトイシハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県塩竈市浦戸桂島', '04', '04203', '9850192', '宮城県', 'ミヤギケン', '塩竈市', 'シオガマシ', '浦戸桂島', 'ウラトカツラシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県塩竈市浦戸野々島', '04', '04203', '9850193', '宮城県', 'ミヤギケン', '塩竈市', 'シオガマシ', '浦戸野々島', 'ウラトノノシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県塩竈市浦戸寒風沢', '04', '04203', '9850194', '宮城県', 'ミヤギケン', '塩竈市', 'シオガマシ', '浦戸寒風沢', 'ウラトサブサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県塩竈市浦戸朴島', '04', '04203', '9850195', '宮城県', 'ミヤギケン', '塩竈市', 'シオガマシ', '浦戸朴島', 'ウラトホウジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県宮城郡七ヶ浜町代ヶ崎浜', '04', '04404', '9850801', '宮城県', 'ミヤギケン', '宮城郡七ヶ浜町', 'ミヤギグンシチガハママチ', '代ヶ崎浜', 'ヨガサキハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県宮城郡七ヶ浜町吉田浜', '04', '04404', '9850802', '宮城県', 'ミヤギケン', '宮城郡七ヶ浜町', 'ミヤギグンシチガハママチ', '吉田浜', 'ヨシダハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県宮城郡七ヶ浜町花渕浜', '04', '04404', '9850803', '宮城県', 'ミヤギケン', '宮城郡七ヶ浜町', 'ミヤギグンシチガハママチ', '花渕浜', 'ハナブチハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県宮城郡七ヶ浜町東宮浜', '04', '04404', '9850804', '宮城県', 'ミヤギケン', '宮城郡七ヶ浜町', 'ミヤギグンシチガハママチ', '東宮浜', 'トウグウハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県宮城郡七ヶ浜町菖蒲田浜', '04', '04404', '9850811', '宮城県', 'ミヤギケン', '宮城郡七ヶ浜町', 'ミヤギグンシチガハママチ', '菖蒲田浜', 'ショウブタハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県宮城郡七ヶ浜町松ヶ浜', '04', '04404', '9850812', '宮城県', 'ミヤギケン', '宮城郡七ヶ浜町', 'ミヤギグンシチガハママチ', '松ヶ浜', 'マツガハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県宮城郡七ヶ浜町湊浜', '04', '04404', '9850813', '宮城県', 'ミヤギケン', '宮城郡七ヶ浜町', 'ミヤギグンシチガハママチ', '湊浜', 'ミナトハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県宮城郡七ヶ浜町汐見台', '04', '04404', '9850821', '宮城県', 'ミヤギケン', '宮城郡七ヶ浜町', 'ミヤギグンシチガハママチ', '汐見台', 'シオミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県宮城郡七ヶ浜町汐見台南', '04', '04404', '9850822', '宮城県', 'ミヤギケン', '宮城郡七ヶ浜町', 'ミヤギグンシチガハママチ', '汐見台南', 'シオミダイミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県宮城郡七ヶ浜町遠山', '04', '04404', '9850823', '宮城県', 'ミヤギケン', '宮城郡七ヶ浜町', 'ミヤギグンシチガハママチ', '遠山', 'トオヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県宮城郡七ヶ浜町境山', '04', '04404', '9850824', '宮城県', 'ミヤギケン', '宮城郡七ヶ浜町', 'ミヤギグンシチガハママチ', '境山', 'サカイヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県多賀城市笠神', '04', '04209', '9850831', '宮城県', 'ミヤギケン', '多賀城市', 'タガジョウシ', '笠神', 'カサガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県多賀城市大代', '04', '04209', '9850832', '宮城県', 'ミヤギケン', '多賀城市', 'タガジョウシ', '大代', 'オオシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県多賀城市栄', '04', '04209', '9850833', '宮城県', 'ミヤギケン', '多賀城市', 'タガジョウシ', '栄', 'サカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県多賀城市丸山', '04', '04209', '9850834', '宮城県', 'ミヤギケン', '多賀城市', 'タガジョウシ', '丸山', 'マルヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県多賀城市下馬', '04', '04209', '9850835', '宮城県', 'ミヤギケン', '多賀城市', 'タガジョウシ', '下馬', 'ゲバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県多賀城市鶴ケ谷', '04', '04209', '9850841', '宮城県', 'ミヤギケン', '多賀城市', 'タガジョウシ', '鶴ケ谷', 'ツルガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県多賀城市桜木', '04', '04209', '9850842', '宮城県', 'ミヤギケン', '多賀城市', 'タガジョウシ', '桜木', 'サクラギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県多賀城市明月', '04', '04209', '9850843', '宮城県', 'ミヤギケン', '多賀城市', 'タガジョウシ', '明月', 'メイゲツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県多賀城市宮内', '04', '04209', '9850844', '宮城県', 'ミヤギケン', '多賀城市', 'タガジョウシ', '宮内', 'ミヤウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県多賀城市町前', '04', '04209', '9850845', '宮城県', 'ミヤギケン', '多賀城市', 'タガジョウシ', '町前', 'マチマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県多賀城市南宮', '04', '04209', '9850851', '宮城県', 'ミヤギケン', '多賀城市', 'タガジョウシ', '南宮', 'ナングウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県多賀城市山王', '04', '04209', '9850852', '宮城県', 'ミヤギケン', '多賀城市', 'タガジョウシ', '山王', 'サンノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県多賀城市高橋', '04', '04209', '9850853', '宮城県', 'ミヤギケン', '多賀城市', 'タガジョウシ', '高橋', 'タカハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県多賀城市新田', '04', '04209', '9850854', '宮城県', 'ミヤギケン', '多賀城市', 'タガジョウシ', '新田', 'ニイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県多賀城市浮島', '04', '04209', '9850861', '宮城県', 'ミヤギケン', '多賀城市', 'タガジョウシ', '浮島', 'ウキシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県多賀城市高崎', '04', '04209', '9850862', '宮城県', 'ミヤギケン', '多賀城市', 'タガジョウシ', '高崎', 'タカサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県多賀城市東田中', '04', '04209', '9850863', '宮城県', 'ミヤギケン', '多賀城市', 'タガジョウシ', '東田中', 'ヒガシタナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県多賀城市市川', '04', '04209', '9850864', '宮城県', 'ミヤギケン', '多賀城市', 'タガジョウシ', '市川', 'イチカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県多賀城市城南', '04', '04209', '9850865', '宮城県', 'ミヤギケン', '多賀城市', 'タガジョウシ', '城南', 'ジョウナン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県多賀城市留ケ谷', '04', '04209', '9850871', '宮城県', 'ミヤギケン', '多賀城市', 'タガジョウシ', '留ケ谷', 'トメガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県多賀城市伝上山', '04', '04209', '9850872', '宮城県', 'ミヤギケン', '多賀城市', 'タガジョウシ', '伝上山', 'デンジョウヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県多賀城市中央', '04', '04209', '9850873', '宮城県', 'ミヤギケン', '多賀城市', 'タガジョウシ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県多賀城市八幡', '04', '04209', '9850874', '宮城県', 'ミヤギケン', '多賀城市', 'タガジョウシ', '八幡', 'ヤワタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市宮城野区港5丁目', '04', '04102', '9850901', '宮城県', 'ミヤギケン', '仙台市宮城野区', 'センダイシミヤギノク', '港', 'ミナト', null, null, '5丁目', '05チョウメ');
INSERT INTO `ms_addresses` VALUES ('141578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道枝幸郡中頓別町岩手', '01', '01513', '0985101', '北海道', 'ホッカイドウ', '枝幸郡中頓別町', 'エサシグンナカトンベツチョウ', '岩手', 'イワテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道枝幸郡中頓別町小頓別', '01', '01513', '0985102', '北海道', 'ホッカイドウ', '枝幸郡中頓別町', 'エサシグンナカトンベツチョウ', '小頓別', 'ショウトンベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道枝幸郡中頓別町秋田', '01', '01513', '0985103', '北海道', 'ホッカイドウ', '枝幸郡中頓別町', 'エサシグンナカトンベツチョウ', '秋田', 'アキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道枝幸郡中頓別町上頓別', '01', '01513', '0985111', '北海道', 'ホッカイドウ', '枝幸郡中頓別町', 'エサシグンナカトンベツチョウ', '上頓別', 'カミトンベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道枝幸郡中頓別町豊平', '01', '01513', '0985112', '北海道', 'ホッカイドウ', '枝幸郡中頓別町', 'エサシグンナカトンベツチョウ', '豊平', 'トヨヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道枝幸郡中頓別町敏音知', '01', '01513', '0985113', '北海道', 'ホッカイドウ', '枝幸郡中頓別町', 'エサシグンナカトンベツチョウ', '敏音知', 'ピンネシリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道枝幸郡枝幸町歌登パンケナイ', '01', '01514', '0985201', '北海道', 'ホッカイドウ', '枝幸郡枝幸町', 'エサシグンエサシチョウ', '歌登パンケナイ', 'ウタノボリパンケナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道枝幸郡枝幸町歌登東歌登', '01', '01514', '0985202', '北海道', 'ホッカイドウ', '枝幸郡枝幸町', 'エサシグンエサシチョウ', '歌登東歌登', 'ウタノボリヒガシウタノボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道枝幸郡枝幸町歌登辺毛内', '01', '01514', '0985203', '北海道', 'ホッカイドウ', '枝幸郡枝幸町', 'エサシグンエサシチョウ', '歌登辺毛内', 'ウタノボリペンケナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道枝幸郡枝幸町歌登南町', '01', '01514', '0985204', '北海道', 'ホッカイドウ', '枝幸郡枝幸町', 'エサシグンエサシチョウ', '歌登南町', 'ウタノボリミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道枝幸郡枝幸町歌登桧垣町', '01', '01514', '0985205', '北海道', 'ホッカイドウ', '枝幸郡枝幸町', 'エサシグンエサシチョウ', '歌登桧垣町', 'ウタノボリヒガキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道枝幸郡枝幸町歌登西町', '01', '01514', '0985206', '北海道', 'ホッカイドウ', '枝幸郡枝幸町', 'エサシグンエサシチョウ', '歌登西町', 'ウタノボリニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道枝幸郡枝幸町歌登東町', '01', '01514', '0985207', '北海道', 'ホッカイドウ', '枝幸郡枝幸町', 'エサシグンエサシチョウ', '歌登東町', 'ウタノボリヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道枝幸郡枝幸町歌登西歌登', '01', '01514', '0985211', '北海道', 'ホッカイドウ', '枝幸郡枝幸町', 'エサシグンエサシチョウ', '歌登西歌登', 'ウタノボリニシウタノボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道枝幸郡枝幸町歌登中央', '01', '01514', '0985212', '北海道', 'ホッカイドウ', '枝幸郡枝幸町', 'エサシグンエサシチョウ', '歌登中央', 'ウタノボリチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道枝幸郡枝幸町歌登本幌別', '01', '01514', '0985213', '北海道', 'ホッカイドウ', '枝幸郡枝幸町', 'エサシグンエサシチョウ', '歌登本幌別', 'ウタノボリホンホロベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道枝幸郡枝幸町歌登毛登別', '01', '01514', '0985221', '北海道', 'ホッカイドウ', '枝幸郡枝幸町', 'エサシグンエサシチョウ', '歌登毛登別', 'ウタノボリケトベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道枝幸郡枝幸町歌登志美宇丹', '01', '01514', '0985441', '北海道', 'ホッカイドウ', '枝幸郡枝幸町', 'エサシグンエサシチョウ', '歌登志美宇丹', 'ウタノボリシビウタン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道枝幸郡枝幸町歌登豊沃', '01', '01514', '0985442', '北海道', 'ホッカイドウ', '枝幸郡枝幸町', 'エサシグンエサシチョウ', '歌登豊沃', 'ウタノボリホウヨク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道枝幸郡枝幸町歌登上徳志別', '01', '01514', '0985443', '北海道', 'ホッカイドウ', '枝幸郡枝幸町', 'エサシグンエサシチョウ', '歌登上徳志別', 'ウタノボリカミトクシベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道枝幸郡枝幸町歌登大奮', '01', '01514', '0985444', '北海道', 'ホッカイドウ', '枝幸郡枝幸町', 'エサシグンエサシチョウ', '歌登大奮', 'ウタノボリオフン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道枝幸郡枝幸町歌登大曲', '01', '01514', '0985445', '北海道', 'ホッカイドウ', '枝幸郡枝幸町', 'エサシグンエサシチョウ', '歌登大曲', 'ウタノボリオオマガリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道枝幸郡中頓別町', '01', '01513', '0985500', '北海道', 'ホッカイドウ', '枝幸郡中頓別町', 'エサシグンナカトンベツチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('141602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道枝幸郡中頓別町中頓別', '01', '01513', '0985551', '北海道', 'ホッカイドウ', '枝幸郡中頓別町', 'エサシグンナカトンベツチョウ', '中頓別', 'ナカトンベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道枝幸郡中頓別町寿', '01', '01513', '0985552', '北海道', 'ホッカイドウ', '枝幸郡中頓別町', 'エサシグンナカトンベツチョウ', '寿', 'コトブキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道枝幸郡中頓別町弥生', '01', '01513', '0985553', '北海道', 'ホッカイドウ', '枝幸郡中頓別町', 'エサシグンナカトンベツチョウ', '弥生', 'ヤヨイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道枝幸郡中頓別町旭台', '01', '01513', '0985554', '北海道', 'ホッカイドウ', '枝幸郡中頓別町', 'エサシグンナカトンベツチョウ', '旭台', 'アサヒダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道枝幸郡中頓別町豊泉', '01', '01513', '0985555', '北海道', 'ホッカイドウ', '枝幸郡中頓別町', 'エサシグンナカトンベツチョウ', '豊泉', 'トヨイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道枝幸郡中頓別町兵安', '01', '01513', '0985561', '北海道', 'ホッカイドウ', '枝幸郡中頓別町', 'エサシグンナカトンベツチョウ', '兵安', 'ヘイアン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道枝幸郡中頓別町神崎', '01', '01513', '0985562', '北海道', 'ホッカイドウ', '枝幸郡中頓別町', 'エサシグンナカトンベツチョウ', '神崎', 'カンザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道枝幸郡中頓別町藤井', '01', '01513', '0985563', '北海道', 'ホッカイドウ', '枝幸郡中頓別町', 'エサシグンナカトンベツチョウ', '藤井', 'フジイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道枝幸郡中頓別町上駒', '01', '01513', '0985564', '北海道', 'ホッカイドウ', '枝幸郡中頓別町', 'エサシグンナカトンベツチョウ', '上駒', 'カミコマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道枝幸郡中頓別町松音知', '01', '01513', '0985565', '北海道', 'ホッカイドウ', '枝幸郡中頓別町', 'エサシグンナカトンベツチョウ', '松音知', 'マツネシリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道枝幸郡浜頓別町', '01', '01512', '0985700', '北海道', 'ホッカイドウ', '枝幸郡浜頓別町', 'エサシグンハマトンベツチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('141614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道枝幸郡浜頓別町栄和', '01', '01512', '0985701', '北海道', 'ホッカイドウ', '枝幸郡浜頓別町', 'エサシグンハマトンベツチョウ', '栄和', 'エイワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道枝幸郡浜頓別町頓別', '01', '01512', '0985701', '北海道', 'ホッカイドウ', '枝幸郡浜頓別町', 'エサシグンハマトンベツチョウ', '頓別', 'トンベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道枝幸郡浜頓別町豊牛', '01', '01512', '0985702', '北海道', 'ホッカイドウ', '枝幸郡浜頓別町', 'エサシグンハマトンベツチョウ', '豊牛', 'トヨウシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道枝幸郡浜頓別町豊寒別', '01', '01512', '0985702', '北海道', 'ホッカイドウ', '枝幸郡浜頓別町', 'エサシグンハマトンベツチョウ', '豊寒別', 'トヨカンベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道枝幸郡浜頓別町斜内', '01', '01512', '0985703', '北海道', 'ホッカイドウ', '枝幸郡浜頓別町', 'エサシグンハマトンベツチョウ', '斜内', 'シャナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道枝幸郡浜頓別町豊浜', '01', '01512', '0985703', '北海道', 'ホッカイドウ', '枝幸郡浜頓別町', 'エサシグンハマトンベツチョウ', '豊浜', 'トヨハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道枝幸郡浜頓別町中央北', '01', '01512', '0985704', '北海道', 'ホッカイドウ', '枝幸郡浜頓別町', 'エサシグンハマトンベツチョウ', '中央北', 'チュウオウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道枝幸郡浜頓別町中央南', '01', '01512', '0985705', '北海道', 'ホッカイドウ', '枝幸郡浜頓別町', 'エサシグンハマトンベツチョウ', '中央南', 'チュウオウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道枝幸郡浜頓別町北1条', '01', '01512', '0985711', '北海道', 'ホッカイドウ', '枝幸郡浜頓別町', 'エサシグンハマトンベツチョウ', '北1条', 'キタ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道枝幸郡浜頓別町北2条', '01', '01512', '0985712', '北海道', 'ホッカイドウ', '枝幸郡浜頓別町', 'エサシグンハマトンベツチョウ', '北2条', 'キタ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道枝幸郡浜頓別町北3条', '01', '01512', '0985713', '北海道', 'ホッカイドウ', '枝幸郡浜頓別町', 'エサシグンハマトンベツチョウ', '北3条', 'キタ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道枝幸郡浜頓別町北4条', '01', '01512', '0985714', '北海道', 'ホッカイドウ', '枝幸郡浜頓別町', 'エサシグンハマトンベツチョウ', '北4条', 'キタ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道枝幸郡浜頓別町浜頓別', '01', '01512', '0985717', '北海道', 'ホッカイドウ', '枝幸郡浜頓別町', 'エサシグンハマトンベツチョウ', '浜頓別', 'ハマトンベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道枝幸郡浜頓別町南1条', '01', '01512', '0985721', '北海道', 'ホッカイドウ', '枝幸郡浜頓別町', 'エサシグンハマトンベツチョウ', '南1条', 'ミナミ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道枝幸郡浜頓別町南2条', '01', '01512', '0985722', '北海道', 'ホッカイドウ', '枝幸郡浜頓別町', 'エサシグンハマトンベツチョウ', '南2条', 'ミナミ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道枝幸郡浜頓別町南3条', '01', '01512', '0985723', '北海道', 'ホッカイドウ', '枝幸郡浜頓別町', 'エサシグンハマトンベツチョウ', '南3条', 'ミナミ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道枝幸郡浜頓別町大通', '01', '01512', '0985725', '北海道', 'ホッカイドウ', '枝幸郡浜頓別町', 'エサシグンハマトンベツチョウ', '大通', 'オオドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道枝幸郡浜頓別町日の出', '01', '01512', '0985734', '北海道', 'ホッカイドウ', '枝幸郡浜頓別町', 'エサシグンハマトンベツチョウ', '日の出', 'ヒノデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道枝幸郡浜頓別町緑ケ丘', '01', '01512', '0985738', '北海道', 'ホッカイドウ', '枝幸郡浜頓別町', 'エサシグンハマトンベツチョウ', '緑ケ丘', 'ミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道枝幸郡浜頓別町クッチャロ湖畔', '01', '01512', '0985739', '北海道', 'ホッカイドウ', '枝幸郡浜頓別町', 'エサシグンハマトンベツチョウ', 'クッチャロ湖畔', 'クッチャロコハン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道枝幸郡浜頓別町旭ケ丘', '01', '01512', '0985741', '北海道', 'ホッカイドウ', '枝幸郡浜頓別町', 'エサシグンハマトンベツチョウ', '旭ケ丘', 'アサヒガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道枝幸郡浜頓別町戸出', '01', '01512', '0985742', '北海道', 'ホッカイドウ', '枝幸郡浜頓別町', 'エサシグンハマトンベツチョウ', '戸出', 'トイデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道枝幸郡浜頓別町楓', '01', '01512', '0985743', '北海道', 'ホッカイドウ', '枝幸郡浜頓別町', 'エサシグンハマトンベツチョウ', '楓', 'カエデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道枝幸郡浜頓別町宇曽丹', '01', '01512', '0985744', '北海道', 'ホッカイドウ', '枝幸郡浜頓別町', 'エサシグンハマトンベツチョウ', '宇曽丹', 'ウソタン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道枝幸郡浜頓別町常盤', '01', '01512', '0985745', '北海道', 'ホッカイドウ', '枝幸郡浜頓別町', 'エサシグンハマトンベツチョウ', '常盤', 'トキワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道枝幸郡浜頓別町金ケ丘', '01', '01512', '0985751', '北海道', 'ホッカイドウ', '枝幸郡浜頓別町', 'エサシグンハマトンベツチョウ', '金ケ丘', 'カナガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道枝幸郡浜頓別町下頓別', '01', '01512', '0985752', '北海道', 'ホッカイドウ', '枝幸郡浜頓別町', 'エサシグンハマトンベツチョウ', '下頓別', 'シモトンベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道枝幸郡浜頓別町高砂', '01', '01512', '0985753', '北海道', 'ホッカイドウ', '枝幸郡浜頓別町', 'エサシグンハマトンベツチョウ', '高砂', 'タカサゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道枝幸郡浜頓別町宇津内', '01', '01512', '0985754', '北海道', 'ホッカイドウ', '枝幸郡浜頓別町', 'エサシグンハマトンベツチョウ', '宇津内', 'ウツナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道枝幸郡浜頓別町茂宇津内', '01', '01512', '0985755', '北海道', 'ホッカイドウ', '枝幸郡浜頓別町', 'エサシグンハマトンベツチョウ', '茂宇津内', 'モウツナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道枝幸郡浜頓別町智福', '01', '01512', '0985761', '北海道', 'ホッカイドウ', '枝幸郡浜頓別町', 'エサシグンハマトンベツチョウ', '智福', 'チフク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道枝幸郡浜頓別町山軽', '01', '01512', '0985761', '北海道', 'ホッカイドウ', '枝幸郡浜頓別町', 'エサシグンハマトンベツチョウ', '山軽', 'ヤマガル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道枝幸郡浜頓別町ポン仁達内', '01', '01512', '0985762', '北海道', 'ホッカイドウ', '枝幸郡浜頓別町', 'エサシグンハマトンベツチョウ', 'ポン仁達内', 'ポンニタチナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道枝幸郡浜頓別町仁達内', '01', '01512', '0985763', '北海道', 'ホッカイドウ', '枝幸郡浜頓別町', 'エサシグンハマトンベツチョウ', '仁達内', 'ニタチナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道枝幸郡浜頓別町安別', '01', '01512', '0985764', '北海道', 'ホッカイドウ', '枝幸郡浜頓別町', 'エサシグンハマトンベツチョウ', '安別', 'ヤスベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道枝幸郡浜頓別町共和', '01', '01512', '0985765', '北海道', 'ホッカイドウ', '枝幸郡浜頓別町', 'エサシグンハマトンベツチョウ', '共和', 'キョウワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道枝幸郡枝幸町', '01', '01514', '0985800', '北海道', 'ホッカイドウ', '枝幸郡枝幸町', 'エサシグンエサシチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('141652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道枝幸郡枝幸町徳志別', '01', '01514', '0985801', '北海道', 'ホッカイドウ', '枝幸郡枝幸町', 'エサシグンエサシチョウ', '徳志別', 'トクシベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道枝幸郡枝幸町岡島', '01', '01514', '0985802', '北海道', 'ホッカイドウ', '枝幸郡枝幸町', 'エサシグンエサシチョウ', '岡島', 'オカシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道枝幸郡枝幸町下幌別', '01', '01514', '0985803', '北海道', 'ホッカイドウ', '枝幸郡枝幸町', 'エサシグンエサシチョウ', '下幌別', 'シモホロベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道枝幸郡枝幸町南浜町', '01', '01514', '0985804', '北海道', 'ホッカイドウ', '枝幸郡枝幸町', 'エサシグンエサシチョウ', '南浜町', 'ミナミハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道枝幸郡枝幸町幸町', '01', '01514', '0985805', '北海道', 'ホッカイドウ', '枝幸郡枝幸町', 'エサシグンエサシチョウ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道枝幸郡枝幸町梅ケ枝町', '01', '01514', '0985806', '北海道', 'ホッカイドウ', '枝幸郡枝幸町', 'エサシグンエサシチョウ', '梅ケ枝町', 'ウメガエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道枝幸郡枝幸町本町', '01', '01514', '0985807', '北海道', 'ホッカイドウ', '枝幸郡枝幸町', 'エサシグンエサシチョウ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道枝幸郡枝幸町新港町', '01', '01514', '0985808', '北海道', 'ホッカイドウ', '枝幸郡枝幸町', 'エサシグンエサシチョウ', '新港町', 'シンコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道枝幸郡枝幸町岬町', '01', '01514', '0985814', '北海道', 'ホッカイドウ', '枝幸郡枝幸町', 'エサシグンエサシチョウ', '岬町', 'ミサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道枝幸郡枝幸町問牧', '01', '01514', '0985815', '北海道', 'ホッカイドウ', '枝幸郡枝幸町', 'エサシグンエサシチョウ', '問牧', 'トイマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道枝幸郡枝幸町目梨泊', '01', '01514', '0985816', '北海道', 'ホッカイドウ', '枝幸郡枝幸町', 'エサシグンエサシチョウ', '目梨泊', 'メナシドマリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道枝幸郡枝幸町栄町', '01', '01514', '0985821', '北海道', 'ホッカイドウ', '枝幸郡枝幸町', 'エサシグンエサシチョウ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道枝幸郡枝幸町北幸町', '01', '01514', '0985822', '北海道', 'ホッカイドウ', '枝幸郡枝幸町', 'エサシグンエサシチョウ', '北幸町', 'ホッコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道枝幸郡枝幸町三笠町', '01', '01514', '0985823', '北海道', 'ホッカイドウ', '枝幸郡枝幸町', 'エサシグンエサシチョウ', '三笠町', 'ミカサチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道枝幸郡枝幸町北栄町', '01', '01514', '0985824', '北海道', 'ホッカイドウ', '枝幸郡枝幸町', 'エサシグンエサシチョウ', '北栄町', 'ホクエイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道枝幸郡枝幸町新栄町', '01', '01514', '0985825', '北海道', 'ホッカイドウ', '枝幸郡枝幸町', 'エサシグンエサシチョウ', '新栄町', 'シンサカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道枝幸郡枝幸町北浜町', '01', '01514', '0985826', '北海道', 'ホッカイドウ', '枝幸郡枝幸町', 'エサシグンエサシチョウ', '北浜町', 'キタハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道枝幸郡枝幸町宇遠内', '01', '01514', '0985827', '北海道', 'ホッカイドウ', '枝幸郡枝幸町', 'エサシグンエサシチョウ', '宇遠内', 'ウエンナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道枝幸郡枝幸町山臼', '01', '01514', '0985951', '北海道', 'ホッカイドウ', '枝幸郡枝幸町', 'エサシグンエサシチョウ', '山臼', 'ヤマウス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道枝幸郡枝幸町乙忠部', '01', '01514', '0985952', '北海道', 'ホッカイドウ', '枝幸郡枝幸町', 'エサシグンエサシチョウ', '乙忠部', 'オツチュウベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道枝幸郡枝幸町風烈布', '01', '01514', '0985953', '北海道', 'ホッカイドウ', '枝幸郡枝幸町', 'エサシグンエサシチョウ', '風烈布', 'フウレップ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道枝幸郡枝幸町上音標', '01', '01514', '0985954', '北海道', 'ホッカイドウ', '枝幸郡枝幸町', 'エサシグンエサシチョウ', '上音標', 'カミオトシベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道枝幸郡枝幸町音標', '01', '01514', '0985955', '北海道', 'ホッカイドウ', '枝幸郡枝幸町', 'エサシグンエサシチョウ', '音標', 'オトシベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市', '04', '04202', '9860000', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('141700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市水沼', '04', '04202', '9860001', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '水沼', 'ミズヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市真野', '04', '04202', '9860002', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '真野', 'マノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市井内', '04', '04202', '9860003', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '井内', 'イナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市新栄', '04', '04202', '9860004', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '新栄', 'シンエイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市大瓜', '04', '04202', '9860005', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '大瓜', 'オウリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市高木', '04', '04202', '9860006', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '高木', 'タカキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市湊', '04', '04202', '9860011', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '湊', 'ミナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市鹿妻本町', '04', '04202', '9860013', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '鹿妻本町', 'カヅマホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市吉野町', '04', '04202', '9860015', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '吉野町', 'ヨシノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市八幡町', '04', '04202', '9860016', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '八幡町', 'ハチマンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市不動町', '04', '04202', '9860017', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '不動町', 'フドウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市緑町', '04', '04202', '9860021', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '緑町', 'ミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市魚町', '04', '04202', '9860022', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '魚町', 'サカナマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市田代浜', '04', '04202', '9860023', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '田代浜', 'タシロハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市川口町', '04', '04202', '9860024', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '川口町', 'カワグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市湊町', '04', '04202', '9860025', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '湊町', 'ミナトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市大門町', '04', '04202', '9860026', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '大門町', 'ダイモンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市明神町', '04', '04202', '9860027', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '明神町', 'ミョウジンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市松並', '04', '04202', '9860028', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '松並', 'マツナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市南境', '04', '04202', '9860031', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '南境', 'ミナミザカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市開成', '04', '04202', '9860032', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '開成', 'カイセイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市伊原津', '04', '04202', '9860041', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '伊原津', 'イバラツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市鹿妻南', '04', '04202', '9860042', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '鹿妻南', 'カヅマミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市鹿妻北', '04', '04202', '9860043', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '鹿妻北', 'カヅマキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市相野谷', '04', '04202', '9860101', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '相野谷', 'アイノヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市成田', '04', '04202', '9860102', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '成田', 'ナリタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市中島', '04', '04202', '9860103', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '中島', 'ナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市皿貝', '04', '04202', '9860104', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '皿貝', 'サラガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市中野', '04', '04202', '9860105', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '中野', 'ナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市馬鞍', '04', '04202', '9860106', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '馬鞍', 'マグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市釜谷', '04', '04202', '9860111', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '釜谷', 'カマヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市長面', '04', '04202', '9860112', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '長面', 'ナガツラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市尾ノ崎', '04', '04202', '9860113', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '尾ノ崎', 'オノサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市針岡', '04', '04202', '9860114', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '針岡', 'ハリオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市福地', '04', '04202', '9860115', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '福地', 'フクジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市大森', '04', '04202', '9860121', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '大森', 'オオモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市東福田', '04', '04202', '9860122', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '東福田', 'ヒガシフクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市北境', '04', '04202', '9860123', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '北境', 'キタザカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市三輪田', '04', '04202', '9860124', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '三輪田', 'ミノワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市飯野', '04', '04202', '9860131', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '飯野', 'イイノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市小船越', '04', '04202', '9860132', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '小船越', 'コフナコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市北上町十三浜', '04', '04202', '9860201', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '北上町十三浜', 'キタカミチョウジュウサンハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市北上町橋浦', '04', '04202', '9860202', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '北上町橋浦', 'キタカミチョウハシウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市北上町長尾', '04', '04202', '9860203', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '北上町長尾', 'キタカミチョウナガオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市北上町女川', '04', '04202', '9860204', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '北上町女川', 'キタカミチョウオナガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市桃生町脇谷', '04', '04202', '9860301', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '桃生町脇谷', 'モノウチョウワキヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市桃生町倉埣', '04', '04202', '9860302', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '桃生町倉埣', 'モノウチョウクラゾネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市桃生町永井', '04', '04202', '9860303', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '桃生町永井', 'モノウチョウナガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市桃生町樫崎', '04', '04202', '9860304', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '桃生町樫崎', 'モノウチョウカシザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市桃生町牛田', '04', '04202', '9860305', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '桃生町牛田', 'モノウチョウウシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市桃生町太田', '04', '04202', '9860311', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '桃生町太田', 'モノウチョウオオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市桃生町城内', '04', '04202', '9860312', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '桃生町城内', 'モノウチョウジョウナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市桃生町中津山', '04', '04202', '9860313', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '桃生町中津山', 'モノウチョウナカツヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市桃生町寺崎', '04', '04202', '9860314', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '桃生町寺崎', 'モノウチョウテラサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市桃生町新田', '04', '04202', '9860321', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '桃生町新田', 'モノウチョウシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市桃生町給人町', '04', '04202', '9860322', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '桃生町給人町', 'モノウチョウキュウニンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市桃生町神取', '04', '04202', '9860323', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '桃生町神取', 'モノウチョウカンドリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市桃生町高須賀', '04', '04202', '9860324', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '桃生町高須賀', 'モノウチョウタカスカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市津山町柳津', '04', '04212', '9860401', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '津山町柳津', 'ツヤマチョウヤナイヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市津山町横山', '04', '04212', '9860402', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '津山町横山', 'ツヤマチョウヨコヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町', '04', '04606', '9860700', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('141762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町志津川西田', '04', '04606', '9860701', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '志津川西田', 'シヅガワニシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町志津川細浦', '04', '04606', '9860702', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '志津川細浦', 'シヅガワホソウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町志津川蛇王', '04', '04606', '9860703', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '志津川蛇王', 'シヅガワジャオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町志津川森山', '04', '04606', '9860704', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '志津川森山', 'シヅガワモリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町志津川阿曽', '04', '04606', '9860705', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '志津川阿曽', 'シヅガワアソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町志津川清水浜', '04', '04606', '9860706', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '志津川清水浜', 'シヅガワシズハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町志津川荒坂', '04', '04606', '9860707', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '志津川荒坂', 'シヅガワアラサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町志津川松井田', '04', '04606', '9860708', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '志津川松井田', 'シヅガワマツイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町志津川内井田', '04', '04606', '9860709', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '志津川内井田', 'シヅガワウチイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町志津川権現', '04', '04606', '9860711', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '志津川権現', 'シヅガワゴンゲン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町志津川北の又', '04', '04606', '9860712', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '志津川北の又', 'シヅガワキタノマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町志津川平貝', '04', '04606', '9860713', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '志津川平貝', 'シヅガワヒラガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町志津川蒲の沢', '04', '04606', '9860714', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '志津川蒲の沢', 'シヅガワカバノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町志津川深田', '04', '04606', '9860715', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '志津川深田', 'シヅガワフカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町志津川平磯', '04', '04606', '9860716', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '志津川平磯', 'シヅガワヒライソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町志津川袖浜', '04', '04606', '9860717', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '志津川袖浜', 'シヅガワソデハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町志津川大畑', '04', '04606', '9860718', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '志津川大畑', 'シヅガワオオバタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町志津川米広', '04', '04606', '9860721', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '志津川米広', 'シヅガワコメヒロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町志津川大上坊', '04', '04606', '9860722', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '志津川大上坊', 'シヅガワダイジョウボウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町志津川立沢', '04', '04606', '9860723', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '志津川立沢', 'シヅガワタツサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町志津川平井田', '04', '04606', '9860724', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '志津川平井田', 'シヅガワヒライダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町志津川沼田', '04', '04606', '9860725', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '志津川沼田', 'シヅガワヌマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町志津川磯の沢', '04', '04606', '9860726', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '志津川磯の沢', 'シヅガワイソノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町志津川新井田', '04', '04606', '9860727', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '志津川新井田', 'シヅガワニイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町志津川天王山', '04', '04606', '9860728', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '志津川天王山', 'シヅガワテンノウサン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町志津川天王前', '04', '04606', '9860729', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '志津川天王前', 'シヅガワテンノウマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町志津川大森', '04', '04606', '9860731', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '志津川大森', 'シヅガワオオモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町志津川大森町', '04', '04606', '9860732', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '志津川大森町', 'シヅガワオオモリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町志津川旭ケ浦', '04', '04606', '9860733', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '志津川旭ケ浦', 'シヅガワアサヒガウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町志津川十日町', '04', '04606', '9860741', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '志津川十日町', 'シヅガワトオカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町志津川本浜町', '04', '04606', '9860742', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '志津川本浜町', 'シヅガワモトハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町志津川南町', '04', '04606', '9860743', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '志津川南町', 'シヅガワミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町志津川上の山', '04', '04606', '9860751', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '志津川上の山', 'シヅガワカミノヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町志津川五日町', '04', '04606', '9860752', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '志津川五日町', 'シヅガワイツカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町志津川城場', '04', '04606', '9860753', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '志津川城場', 'シヅガワジョウバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町志津川助作', '04', '04606', '9860754', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '志津川助作', 'シヅガワスケヅクリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町志津川廻館前', '04', '04606', '9860761', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '志津川廻館前', 'シヅガワマワリタテマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町志津川塩入', '04', '04606', '9860762', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '志津川塩入', 'シヅガワシオイリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町志津川汐見町', '04', '04606', '9860763', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '志津川汐見町', 'シヅガワシオミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町志津川大久保', '04', '04606', '9860764', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '志津川大久保', 'シヅガワオオクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町志津川林', '04', '04606', '9860765', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '志津川林', 'シヅガワハヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町志津川黒崎', '04', '04606', '9860766', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '志津川黒崎', 'シヅガワクロサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町志津川中瀬町', '04', '04606', '9860767', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '志津川中瀬町', 'シヅガワナカセマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町志津川御前下', '04', '04606', '9860768', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '志津川御前下', 'シヅガワゴゼンシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町志津川大沢', '04', '04606', '9860771', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '志津川大沢', 'シヅガワオオサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町志津川秋目川', '04', '04606', '9860772', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '志津川秋目川', 'シヅガワアキメガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町志津川熊田', '04', '04606', '9860773', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '志津川熊田', 'シヅガワクマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町志津川小森', '04', '04606', '9860774', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '志津川小森', 'シヅガワコモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町志津川廻館', '04', '04606', '9860775', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '志津川廻館', 'シヅガワマワリタテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町志津川竹川原', '04', '04606', '9860776', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '志津川竹川原', 'シヅガワタケガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町志津川上保呂毛', '04', '04606', '9860777', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '志津川上保呂毛', 'シヅガワカミホロケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町志津川下保呂毛', '04', '04606', '9860778', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '志津川下保呂毛', 'シヅガワシモホロケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町志津川田尻畑', '04', '04606', '9860779', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '志津川田尻畑', 'シヅガワタジリバタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町戸倉', '04', '04606', '9860781', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '戸倉', 'トクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町入谷', '04', '04606', '9860782', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '入谷', 'イリヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市水明北', '04', '04202', '9860801', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '水明北', 'スイメイキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市水明南', '04', '04202', '9860802', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '水明南', 'スイメイミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市水押', '04', '04202', '9860803', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '水押', 'ミズオシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市大橋', '04', '04202', '9860805', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '大橋', 'オオハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市開北', '04', '04202', '9860806', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '開北', 'カイホク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市元倉', '04', '04202', '9860811', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '元倉', 'モトクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市東中里', '04', '04202', '9860812', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '東中里', 'ヒガシナカサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市駅前北通り', '04', '04202', '9860813', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '駅前北通り', 'エキマエキタドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市南中里', '04', '04202', '9860814', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '南中里', 'ミナミナカサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市中里', '04', '04202', '9860815', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '中里', 'ナカサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市住吉町', '04', '04202', '9860821', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '住吉町', 'スミヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市中央', '04', '04202', '9860822', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市中瀬', '04', '04202', '9860823', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '中瀬', 'ナカゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市立町', '04', '04202', '9860824', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '立町', 'タチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市穀町', '04', '04202', '9860825', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '穀町', 'コクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市鋳銭場', '04', '04202', '9860826', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '鋳銭場', 'イセンバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市千石町', '04', '04202', '9860827', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '千石町', 'センゴクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市旭町', '04', '04202', '9860828', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '旭町', 'アサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市羽黒町', '04', '04202', '9860831', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '羽黒町', 'ハグロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市泉町', '04', '04202', '9860832', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '泉町', 'イズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市日和が丘', '04', '04202', '9860833', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '日和が丘', 'ヒヨリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市門脇町', '04', '04202', '9860834', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '門脇町', 'カドノワキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市南浜町', '04', '04202', '9860835', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '南浜町', 'ミナミハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市南光町', '04', '04202', '9860836', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '南光町', 'ナンコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市宜山町', '04', '04202', '9860837', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '宜山町', 'ヨシヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市大手町', '04', '04202', '9860838', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '大手町', 'オオテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市雲雀野町', '04', '04202', '9860841', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '雲雀野町', 'ヒバリノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市潮見町', '04', '04202', '9860842', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '潮見町', 'シオミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市西浜町', '04', '04202', '9860843', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '西浜町', 'ニシハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市重吉町', '04', '04202', '9860844', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '重吉町', 'シゲヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市中島町', '04', '04202', '9860845', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '中島町', 'ナカジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市三河町', '04', '04202', '9860846', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '三河町', 'ミカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市中浦', '04', '04202', '9860847', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '中浦', 'ナカウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市新館', '04', '04202', '9860848', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '新館', 'シンタテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市中屋敷', '04', '04202', '9860849', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '中屋敷', 'ナカヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市貞山', '04', '04202', '9860851', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '貞山', 'テイザン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市南谷地', '04', '04202', '9860852', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '南谷地', 'ミナミヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市門脇', '04', '04202', '9860853', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '門脇', 'カドノワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市大街道北', '04', '04202', '9860854', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '大街道北', 'オオカイドウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市大街道東', '04', '04202', '9860855', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '大街道東', 'オオカイドウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市大街道南', '04', '04202', '9860856', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '大街道南', 'オオカイドウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市築山', '04', '04202', '9860857', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '築山', 'ツキヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市三ツ股', '04', '04202', '9860858', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '三ツ股', 'ミツマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市大街道西', '04', '04202', '9860859', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '大街道西', 'オオカイドウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市蛇田', '04', '04202', '9860861', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '蛇田', 'ヘビタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市あけぼの', '04', '04202', '9860862', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', 'あけぼの', 'アケボノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市向陽町', '04', '04202', '9860863', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '向陽町', 'コウヨウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市新境町', '04', '04202', '9860864', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '新境町', 'シンサカイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市丸井戸', '04', '04202', '9860865', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '丸井戸', 'マルイド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市清水町', '04', '04202', '9860871', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '清水町', 'シミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市田道町', '04', '04202', '9860872', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '田道町', 'タミチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市山下町', '04', '04202', '9860873', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '山下町', 'ヤマシタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市双葉町', '04', '04202', '9860874', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '双葉町', 'フタバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市末広町', '04', '04202', '9860875', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '末広町', 'スエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市西山町', '04', '04202', '9860876', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '西山町', 'ニシヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市錦町', '04', '04202', '9860877', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '錦町', 'ニシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市新橋', '04', '04202', '9860878', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '新橋', 'シンバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道宗谷郡猿払村浅茅野', '01', '01511', '0986101', '北海道', 'ホッカイドウ', '宗谷郡猿払村', 'ソウヤグンサルフツムラ', '浅茅野', 'アサジノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道宗谷郡猿払村浅茅野台地', '01', '01511', '0986102', '北海道', 'ホッカイドウ', '宗谷郡猿払村', 'ソウヤグンサルフツムラ', '浅茅野台地', 'アサジノダイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道宗谷郡猿払村狩別', '01', '01511', '0986103', '北海道', 'ホッカイドウ', '宗谷郡猿払村', 'ソウヤグンサルフツムラ', '狩別', 'カリベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道宗谷郡猿払村猿払', '01', '01511', '0986104', '北海道', 'ホッカイドウ', '宗谷郡猿払村', 'ソウヤグンサルフツムラ', '猿払', 'サルフツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道宗谷郡猿払村浜猿払', '01', '01511', '0986105', '北海道', 'ホッカイドウ', '宗谷郡猿払村', 'ソウヤグンサルフツムラ', '浜猿払', 'ハマサルフツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道宗谷郡猿払村上猿払', '01', '01511', '0986106', '北海道', 'ホッカイドウ', '宗谷郡猿払村', 'ソウヤグンサルフツムラ', '上猿払', 'カミサルフツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市鹿又', '04', '04202', '9861111', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '鹿又', 'カノマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市雄勝町船越', '04', '04202', '9861301', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '雄勝町船越', 'オガツチョウフナコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市雄勝町大浜', '04', '04202', '9861302', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '雄勝町大浜', 'オガツチョウオオハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市雄勝町立浜', '04', '04202', '9861303', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '雄勝町立浜', 'オガツチョウタチハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市雄勝町名振', '04', '04202', '9861304', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '雄勝町名振', 'オガツチョウナブリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市雄勝町大須', '04', '04202', '9861311', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '雄勝町大須', 'オガツチョウオオス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市雄勝町熊沢', '04', '04202', '9861312', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '雄勝町熊沢', 'オガツチョウクマザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市雄勝町桑浜', '04', '04202', '9861313', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '雄勝町桑浜', 'オガツチョウクワノハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市雄勝町水浜', '04', '04202', '9861321', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '雄勝町水浜', 'オガツチョウミズハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市雄勝町分浜', '04', '04202', '9861322', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '雄勝町分浜', 'オガツチョウワケハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市雄勝町明神', '04', '04202', '9861331', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '雄勝町明神', 'オガツチョウミョウジン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市雄勝町小島', '04', '04202', '9861332', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '雄勝町小島', 'オガツチョウオジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市雄勝町雄勝', '04', '04202', '9861333', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '雄勝町雄勝', 'オガツチョウオガツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市雄勝町伊勢畑', '04', '04202', '9861334', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '雄勝町伊勢畑', 'オガツチョウイセハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市雄勝町下雄勝', '04', '04202', '9861335', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '雄勝町下雄勝', 'オガツチョウシモオガツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市雄勝町上雄勝', '04', '04202', '9861336', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '雄勝町上雄勝', 'オガツチョウカミオガツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道宗谷郡猿払村', '01', '01511', '0986200', '北海道', 'ホッカイドウ', '宗谷郡猿払村', 'ソウヤグンサルフツムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('141898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市沼津', '04', '04202', '9862101', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '沼津', 'ヌマヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市沢田', '04', '04202', '9862102', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '沢田', 'サワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市流留', '04', '04202', '9862103', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '流留', 'ナガル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市垂水町', '04', '04202', '9862104', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '垂水町', 'タレミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市三和町', '04', '04202', '9862111', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '三和町', 'ミツワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市後生橋', '04', '04202', '9862112', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '後生橋', 'ゴショウバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市宇田川町', '04', '04202', '9862113', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '宇田川町', 'ウダガワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市塩富町', '04', '04202', '9862114', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '塩富町', 'シオトミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市万石町', '04', '04202', '9862115', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '万石町', 'マンゴクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市小竹浜', '04', '04202', '9862116', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '小竹浜', 'コダケハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市渡波町', '04', '04202', '9862121', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '渡波町', 'ワタノハチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市幸町', '04', '04202', '9862122', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市伊勢町', '04', '04202', '9862123', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '伊勢町', 'イセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市浜松町', '04', '04202', '9862131', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '浜松町', 'ハママツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市大宮町', '04', '04202', '9862132', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '大宮町', 'オオミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市長浜町', '04', '04202', '9862133', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '長浜町', 'ナガハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市松原町', '04', '04202', '9862134', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '松原町', 'マツバラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市渡波', '04', '04202', '9862135', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '渡波', 'ワタノハ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市根岸', '04', '04202', '9862136', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '根岸', 'ネギシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県牡鹿郡女川町', '04', '04581', '9862200', '宮城県', 'ミヤギケン', '牡鹿郡女川町', 'オシカグンオナガワチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('141918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県牡鹿郡女川町指ケ浜', '04', '04581', '9862201', '宮城県', 'ミヤギケン', '牡鹿郡女川町', 'オシカグンオナガワチョウ', '指ケ浜', 'サシノハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県牡鹿郡女川町尾浦', '04', '04581', '9862202', '宮城県', 'ミヤギケン', '牡鹿郡女川町', 'オシカグンオナガワチョウ', '尾浦', 'オウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県牡鹿郡女川町竹浦', '04', '04581', '9862203', '宮城県', 'ミヤギケン', '牡鹿郡女川町', 'オシカグンオナガワチョウ', '竹浦', 'タケノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県牡鹿郡女川町桐ケ崎', '04', '04581', '9862204', '宮城県', 'ミヤギケン', '牡鹿郡女川町', 'オシカグンオナガワチョウ', '桐ケ崎', 'キリガサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県牡鹿郡女川町御前浜', '04', '04581', '9862205', '宮城県', 'ミヤギケン', '牡鹿郡女川町', 'オシカグンオナガワチョウ', '御前浜', 'オンマエハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県牡鹿郡女川町出島', '04', '04581', '9862211', '宮城県', 'ミヤギケン', '牡鹿郡女川町', 'オシカグンオナガワチョウ', '出島', 'イズシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県牡鹿郡女川町江島', '04', '04581', '9862212', '宮城県', 'ミヤギケン', '牡鹿郡女川町', 'オシカグンオナガワチョウ', '江島', 'エノシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道宗谷郡猿払村浜鬼志別', '01', '01511', '0986222', '北海道', 'ホッカイドウ', '宗谷郡猿払村', 'ソウヤグンサルフツムラ', '浜鬼志別', 'ハマオニシベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県牡鹿郡女川町塚浜', '04', '04581', '9862221', '宮城県', 'ミヤギケン', '牡鹿郡女川町', 'オシカグンオナガワチョウ', '塚浜', 'ツカハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県牡鹿郡女川町飯子浜', '04', '04581', '9862222', '宮城県', 'ミヤギケン', '牡鹿郡女川町', 'オシカグンオナガワチョウ', '飯子浜', 'イイゴハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県牡鹿郡女川町野々浜', '04', '04581', '9862223', '宮城県', 'ミヤギケン', '牡鹿郡女川町', 'オシカグンオナガワチョウ', '野々浜', 'ノノハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県牡鹿郡女川町大石原浜', '04', '04581', '9862224', '宮城県', 'ミヤギケン', '牡鹿郡女川町', 'オシカグンオナガワチョウ', '大石原浜', 'オオイシハラハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県牡鹿郡女川町横浦', '04', '04581', '9862225', '宮城県', 'ミヤギケン', '牡鹿郡女川町', 'オシカグンオナガワチョウ', '横浦', 'ヨコウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県牡鹿郡女川町高白浜', '04', '04581', '9862226', '宮城県', 'ミヤギケン', '牡鹿郡女川町', 'オシカグンオナガワチョウ', '高白浜', 'タカシロハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県牡鹿郡女川町浦宿浜', '04', '04581', '9862231', '宮城県', 'ミヤギケン', '牡鹿郡女川町', 'オシカグンオナガワチョウ', '浦宿浜', 'ウラシュクハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県牡鹿郡女川町針浜', '04', '04581', '9862232', '宮城県', 'ミヤギケン', '牡鹿郡女川町', 'オシカグンオナガワチョウ', '針浜', 'ハリノハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県牡鹿郡女川町黄金町', '04', '04581', '9862241', '宮城県', 'ミヤギケン', '牡鹿郡女川町', 'オシカグンオナガワチョウ', '黄金町', 'コガネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県牡鹿郡女川町小乗浜', '04', '04581', '9862242', '宮城県', 'ミヤギケン', '牡鹿郡女川町', 'オシカグンオナガワチョウ', '小乗浜', 'コノリハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県牡鹿郡女川町鷲神浜', '04', '04581', '9862243', '宮城県', 'ミヤギケン', '牡鹿郡女川町', 'オシカグンオナガワチョウ', '鷲神浜', 'ワシノカミハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県牡鹿郡女川町桜ケ丘', '04', '04581', '9862244', '宮城県', 'ミヤギケン', '牡鹿郡女川町', 'オシカグンオナガワチョウ', '桜ケ丘', 'サクラガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県牡鹿郡女川町寿町', '04', '04581', '9862245', '宮城県', 'ミヤギケン', '牡鹿郡女川町', 'オシカグンオナガワチョウ', '寿町', 'コトブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道宗谷郡猿払村芦野', '01', '01511', '0986225', '北海道', 'ホッカイドウ', '宗谷郡猿払村', 'ソウヤグンサルフツムラ', '芦野', 'アシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県牡鹿郡女川町旭が丘', '04', '04581', '9862251', '宮城県', 'ミヤギケン', '牡鹿郡女川町', 'オシカグンオナガワチョウ', '旭が丘', 'アサヒガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道宗谷郡猿払村豊里', '01', '01511', '0986226', '北海道', 'ホッカイドウ', '宗谷郡猿払村', 'ソウヤグンサルフツムラ', '豊里', 'トヨサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県牡鹿郡女川町女川浜', '04', '04581', '9862261', '宮城県', 'ミヤギケン', '牡鹿郡女川町', 'オシカグンオナガワチョウ', '女川浜', 'オナガワハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県牡鹿郡女川町清水町', '04', '04581', '9862271', '宮城県', 'ミヤギケン', '牡鹿郡女川町', 'オシカグンオナガワチョウ', '清水町', 'シミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道宗谷郡猿払村小石', '01', '01511', '0986228', '北海道', 'ホッカイドウ', '宗谷郡猿払村', 'ソウヤグンサルフツムラ', '小石', 'コイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県牡鹿郡女川町石浜', '04', '04581', '9862281', '宮城県', 'ミヤギケン', '牡鹿郡女川町', 'オシカグンオナガワチョウ', '石浜', 'イシハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県牡鹿郡女川町宮ケ崎', '04', '04581', '9862282', '宮城県', 'ミヤギケン', '牡鹿郡女川町', 'オシカグンオナガワチョウ', '宮ケ崎', 'ミヤガサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道宗谷郡猿払村鬼志別東町', '01', '01511', '0986231', '北海道', 'ホッカイドウ', '宗谷郡猿払村', 'ソウヤグンサルフツムラ', '鬼志別東町', 'オニシベツヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道宗谷郡猿払村鬼志別西町', '01', '01511', '0986232', '北海道', 'ホッカイドウ', '宗谷郡猿払村', 'ソウヤグンサルフツムラ', '鬼志別西町', 'オニシベツニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道宗谷郡猿払村鬼志別南町', '01', '01511', '0986233', '北海道', 'ホッカイドウ', '宗谷郡猿払村', 'ソウヤグンサルフツムラ', '鬼志別南町', 'オニシベツミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道宗谷郡猿払村鬼志別北町', '01', '01511', '0986234', '北海道', 'ホッカイドウ', '宗谷郡猿払村', 'ソウヤグンサルフツムラ', '鬼志別北町', 'オニシベツキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市荻浜', '04', '04202', '9862341', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '荻浜', 'オギノハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市小積浜', '04', '04202', '9862342', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '小積浜', 'コヅミハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市福貴浦', '04', '04202', '9862343', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '福貴浦', 'フッキウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市鹿立', '04', '04202', '9862344', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '鹿立', 'スダチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市狐崎浜', '04', '04202', '9862345', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '狐崎浜', 'キツネザキハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市竹浜', '04', '04202', '9862346', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '竹浜', 'タケノハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市牧浜', '04', '04202', '9862347', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '牧浜', 'マキノハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市侍浜', '04', '04202', '9862351', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '侍浜', 'サムライハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市月浦', '04', '04202', '9862352', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '月浦', 'ツキノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市桃浦', '04', '04202', '9862353', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '桃浦', 'モモノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市蛤浜', '04', '04202', '9862354', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '蛤浜', 'ハマグリハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市折浜', '04', '04202', '9862355', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '折浜', 'オリノハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市泊浜', '04', '04202', '9862401', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '泊浜', 'トマリハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市谷川浜', '04', '04202', '9862402', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '谷川浜', 'ヤガワハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市鮫浦', '04', '04202', '9862403', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '鮫浦', 'サメノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市寄磯浜', '04', '04202', '9862404', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '寄磯浜', 'ヨリイソハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市大谷川浜', '04', '04202', '9862405', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '大谷川浜', 'オオヤガワハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市前網浜', '04', '04202', '9862406', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '前網浜', 'マエアミハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市給分浜', '04', '04202', '9862411', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '給分浜', 'キュウブンハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市大原浜', '04', '04202', '9862412', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '大原浜', 'オオハラハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市清水田浜', '04', '04202', '9862413', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '清水田浜', 'シミズダハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市小網倉浜', '04', '04202', '9862414', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '小網倉浜', 'コアミクラハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市小渕浜', '04', '04202', '9862415', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '小渕浜', 'コブチハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市新山浜', '04', '04202', '9862521', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '新山浜', 'ニイヤマハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市鮎川大町', '04', '04202', '9862522', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '鮎川大町', 'アユカワオオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市鮎川浜', '04', '04202', '9862523', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '鮎川浜', 'アユカワハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市鮎川浜丁', '04', '04202', '9862524', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '鮎川浜丁', 'アユカワハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市長渡浜', '04', '04202', '9862525', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '長渡浜', 'フタワタシハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市網地浜', '04', '04202', '9862526', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '網地浜', 'アジハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市十八成浜', '04', '04202', '9862527', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '十八成浜', 'クグナリハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道宗谷郡猿払村知来別', '01', '01511', '0986341', '北海道', 'ホッカイドウ', '宗谷郡猿払村', 'ソウヤグンサルフツムラ', '知来別', 'チライベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('141985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道稚内市宗谷村峰岡', '01', '01214', '0986384', '北海道', 'ホッカイドウ', '稚内市', 'ワッカナイシ', '宗谷村', 'ソウヤムラ', null, null, '峰岡', 'ミネオカ');
INSERT INTO `ms_addresses` VALUES ('141986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道稚内市宗谷村東浦', '01', '01214', '0986385', '北海道', 'ホッカイドウ', '稚内市', 'ワッカナイシ', '宗谷村', 'ソウヤムラ', null, null, '東浦', 'ヒガシウラ');
INSERT INTO `ms_addresses` VALUES ('141987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道稚内市声問村樺岡', '01', '01214', '0986561', '北海道', 'ホッカイドウ', '稚内市', 'ワッカナイシ', '声問村', 'コエトイムラ', null, null, '樺岡', 'カバオカ');
INSERT INTO `ms_addresses` VALUES ('141988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道稚内市声問村上声問', '01', '01214', '0986562', '北海道', 'ホッカイドウ', '稚内市', 'ワッカナイシ', '声問村', 'コエトイムラ', null, null, '上声問', 'カミコエトイ');
INSERT INTO `ms_addresses` VALUES ('141989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道稚内市声問村沼川', '01', '01214', '0986563', '北海道', 'ホッカイドウ', '稚内市', 'ワッカナイシ', '声問村', 'コエトイムラ', null, null, '沼川', 'ヌマカワ');
INSERT INTO `ms_addresses` VALUES ('141990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道稚内市声問村川西', '01', '01214', '0986564', '北海道', 'ホッカイドウ', '稚内市', 'ワッカナイシ', '声問村', 'コエトイムラ', null, null, '川西', 'カワニシ');
INSERT INTO `ms_addresses` VALUES ('141991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道稚内市声問村曙', '01', '01214', '0986565', '北海道', 'ホッカイドウ', '稚内市', 'ワッカナイシ', '声問村', 'コエトイムラ', null, null, '曙', 'アケボノ');
INSERT INTO `ms_addresses` VALUES ('141992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道稚内市声問村曲渕', '01', '01214', '0986571', '北海道', 'ホッカイドウ', '稚内市', 'ワッカナイシ', '声問村', 'コエトイムラ', null, null, '曲渕', 'マガリフチ');
INSERT INTO `ms_addresses` VALUES ('141993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道稚内市声問村開進', '01', '01214', '0986572', '北海道', 'ホッカイドウ', '稚内市', 'ワッカナイシ', '声問村', 'コエトイムラ', null, null, '開進', 'カイシン');
INSERT INTO `ms_addresses` VALUES ('141994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道稚内市声問村下豊別', '01', '01214', '0986573', '北海道', 'ホッカイドウ', '稚内市', 'ワッカナイシ', '声問村', 'コエトイムラ', null, null, '下豊別', 'シモトヨベツ');
INSERT INTO `ms_addresses` VALUES ('141995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道稚内市声問村上豊別', '01', '01214', '0986574', '北海道', 'ホッカイドウ', '稚内市', 'ワッカナイシ', '声問村', 'コエトイムラ', null, null, '上豊別', 'カミトヨベツ');
INSERT INTO `ms_addresses` VALUES ('141996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道稚内市声問村天興', '01', '01214', '0986575', '北海道', 'ホッカイドウ', '稚内市', 'ワッカナイシ', '声問村', 'コエトイムラ', null, null, '天興', 'テンコウ');
INSERT INTO `ms_addresses` VALUES ('141997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道稚内市声問村川南', '01', '01214', '0986576', '北海道', 'ホッカイドウ', '稚内市', 'ワッカナイシ', '声問村', 'コエトイムラ', null, null, '川南', 'カワミナミ');
INSERT INTO `ms_addresses` VALUES ('141998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道稚内市声問1丁目', '01', '01214', '0986642', '北海道', 'ホッカイドウ', '稚内市', 'ワッカナイシ', '声問', 'コエトイ', null, null, '1丁目', '01チョウメ');
INSERT INTO `ms_addresses` VALUES ('141999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道稚内市声問2丁目', '01', '01214', '0986642', '北海道', 'ホッカイドウ', '稚内市', 'ワッカナイシ', '声問', 'コエトイ', null, null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('142000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道稚内市声問3丁目', '01', '01214', '0986642', '北海道', 'ホッカイドウ', '稚内市', 'ワッカナイシ', '声問', 'コエトイ', null, null, '3丁目', '03チョウメ');
INSERT INTO `ms_addresses` VALUES ('142001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道稚内市声問4丁目', '01', '01214', '0986642', '北海道', 'ホッカイドウ', '稚内市', 'ワッカナイシ', '声問', 'コエトイ', null, null, '4丁目', '04チョウメ');
INSERT INTO `ms_addresses` VALUES ('142002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道稚内市声問5丁目', '01', '01214', '0986642', '北海道', 'ホッカイドウ', '稚内市', 'ワッカナイシ', '声問', 'コエトイ', null, null, '5丁目', '05チョウメ');
INSERT INTO `ms_addresses` VALUES ('142003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道稚内市声問村声問', '01', '01214', '0986642', '北海道', 'ホッカイドウ', '稚内市', 'ワッカナイシ', '声問村', 'コエトイムラ', null, null, '声問', 'コエトイ');
INSERT INTO `ms_addresses` VALUES ('142004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道稚内市声問村メクマ', '01', '01214', '0986643', '北海道', 'ホッカイドウ', '稚内市', 'ワッカナイシ', '声問村', 'コエトイムラ', null, null, 'メクマ', 'メクマ');
INSERT INTO `ms_addresses` VALUES ('142005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道稚内市宗谷村増幌', '01', '01214', '0986644', '北海道', 'ホッカイドウ', '稚内市', 'ワッカナイシ', '宗谷村', 'ソウヤムラ', null, null, '増幌', 'マスホロ');
INSERT INTO `ms_addresses` VALUES ('142006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道稚内市声問村恵北', '01', '01214', '0986645', '北海道', 'ホッカイドウ', '稚内市', 'ワッカナイシ', '声問村', 'コエトイムラ', null, null, '恵北', 'ケイホク');
INSERT INTO `ms_addresses` VALUES ('142007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道稚内市宗谷村豊岩', '01', '01214', '0986751', '北海道', 'ホッカイドウ', '稚内市', 'ワッカナイシ', '宗谷村', 'ソウヤムラ', null, null, '豊岩', 'トヨイワ');
INSERT INTO `ms_addresses` VALUES ('142008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道稚内市宗谷村清浜', '01', '01214', '0986754', '北海道', 'ホッカイドウ', '稚内市', 'ワッカナイシ', '宗谷村', 'ソウヤムラ', null, null, '清浜', 'キヨハマ');
INSERT INTO `ms_addresses` VALUES ('142009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道稚内市宗谷村宗谷', '01', '01214', '0986755', '北海道', 'ホッカイドウ', '稚内市', 'ワッカナイシ', '宗谷村', 'ソウヤムラ', null, null, '宗谷', 'ソウヤ');
INSERT INTO `ms_addresses` VALUES ('142010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道稚内市宗谷村富磯', '01', '01214', '0986756', '北海道', 'ホッカイドウ', '稚内市', 'ワッカナイシ', '宗谷村', 'ソウヤムラ', null, null, '富磯', 'トミイソ');
INSERT INTO `ms_addresses` VALUES ('142011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道稚内市宗谷村増幌浜', '01', '01214', '0986757', '北海道', 'ホッカイドウ', '稚内市', 'ワッカナイシ', '宗谷村', 'ソウヤムラ', null, null, '増幌浜', 'マスホロハマ');
INSERT INTO `ms_addresses` VALUES ('142012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道稚内市宗谷岬', '01', '01214', '0986758', '北海道', 'ホッカイドウ', '稚内市', 'ワッカナイシ', '宗谷岬', 'ソウヤミサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡美里町', '04', '04505', '9870000', '宮城県', 'ミヤギケン', '遠田郡美里町', 'トオダグンミサトマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('142023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡美里町藤ケ崎', '04', '04505', '9870001', '宮城県', 'ミヤギケン', '遠田郡美里町', 'トオダグンミサトマチ', '藤ケ崎', 'フジガサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡美里町藤ケ崎町', '04', '04505', '9870002', '宮城県', 'ミヤギケン', '遠田郡美里町', 'トオダグンミサトマチ', '藤ケ崎町', 'フジガサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡美里町南小牛田', '04', '04505', '9870003', '宮城県', 'ミヤギケン', '遠田郡美里町', 'トオダグンミサトマチ', '南小牛田', 'ミナミコゴタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡美里町牛飼', '04', '04505', '9870004', '宮城県', 'ミヤギケン', '遠田郡美里町', 'トオダグンミサトマチ', '牛飼', 'ウシカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡美里町北浦', '04', '04505', '9870005', '宮城県', 'ミヤギケン', '遠田郡美里町', 'トオダグンミサトマチ', '北浦', 'キタウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡美里町関根', '04', '04505', '9870006', '宮城県', 'ミヤギケン', '遠田郡美里町', 'トオダグンミサトマチ', '関根', 'セキネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡美里町桜木町', '04', '04505', '9870011', '宮城県', 'ミヤギケン', '遠田郡美里町', 'トオダグンミサトマチ', '桜木町', 'サクラギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡美里町素山町', '04', '04505', '9870012', '宮城県', 'ミヤギケン', '遠田郡美里町', 'トオダグンミサトマチ', '素山町', 'ソヤマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡美里町素山', '04', '04505', '9870013', '宮城県', 'ミヤギケン', '遠田郡美里町', 'トオダグンミサトマチ', '素山', 'ソヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡美里町志賀町', '04', '04505', '9870014', '宮城県', 'ミヤギケン', '遠田郡美里町', 'トオダグンミサトマチ', '志賀町', 'シガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡美里町青生', '04', '04505', '9870015', '宮城県', 'ミヤギケン', '遠田郡美里町', 'トオダグンミサトマチ', '青生', 'アオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡美里町平針', '04', '04505', '9870021', '宮城県', 'ミヤギケン', '遠田郡美里町', 'トオダグンミサトマチ', '平針', 'ヒラバリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡美里町荻埣', '04', '04505', '9870022', '宮城県', 'ミヤギケン', '遠田郡美里町', 'トオダグンミサトマチ', '荻埣', 'オギゾネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡美里町中埣', '04', '04505', '9870024', '宮城県', 'ミヤギケン', '遠田郡美里町', 'トオダグンミサトマチ', '中埣', 'ナカゾネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡美里町成田', '04', '04505', '9870024', '宮城県', 'ミヤギケン', '遠田郡美里町', 'トオダグンミサトマチ', '成田', 'ナリタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡美里町中高城', '04', '04505', '9870025', '宮城県', 'ミヤギケン', '遠田郡美里町', 'トオダグンミサトマチ', '中高城', 'ナカタカギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡美里町南高城', '04', '04505', '9870026', '宮城県', 'ミヤギケン', '遠田郡美里町', 'トオダグンミサトマチ', '南高城', 'ミナミタカギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡美里町高田', '04', '04505', '9870031', '宮城県', 'ミヤギケン', '遠田郡美里町', 'トオダグンミサトマチ', '高田', 'タカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡美里町学田', '04', '04505', '9870032', '宮城県', 'ミヤギケン', '遠田郡美里町', 'トオダグンミサトマチ', '学田', 'ガクデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡美里町小町井', '04', '04505', '9870033', '宮城県', 'ミヤギケン', '遠田郡美里町', 'トオダグンミサトマチ', '小町井', 'コマチイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡美里町化粧坂', '04', '04505', '9870034', '宮城県', 'ミヤギケン', '遠田郡美里町', 'トオダグンミサトマチ', '化粧坂', 'ケショウザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡美里町志賀殿', '04', '04505', '9870035', '宮城県', 'ミヤギケン', '遠田郡美里町', 'トオダグンミサトマチ', '志賀殿', 'シガデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡美里町妻の神', '04', '04505', '9870036', '宮城県', 'ミヤギケン', '遠田郡美里町', 'トオダグンミサトマチ', '妻の神', 'サイノカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡美里町新藤ケ崎', '04', '04505', '9870037', '宮城県', 'ミヤギケン', '遠田郡美里町', 'トオダグンミサトマチ', '新藤ケ崎', 'シンフジガサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡美里町駅東', '04', '04505', '9870038', '宮城県', 'ミヤギケン', '遠田郡美里町', 'トオダグンミサトマチ', '駅東', 'エキヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡美里町峯山', '04', '04505', '9870041', '宮城県', 'ミヤギケン', '遠田郡美里町', 'トオダグンミサトマチ', '峯山', 'ミネヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡美里町峯山浦', '04', '04505', '9870042', '宮城県', 'ミヤギケン', '遠田郡美里町', 'トオダグンミサトマチ', '峯山浦', 'ミネヤマウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡美里町新妻の神', '04', '04505', '9870043', '宮城県', 'ミヤギケン', '遠田郡美里町', 'トオダグンミサトマチ', '新妻の神', 'シンサイノカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡美里町西舘', '04', '04505', '9870044', '宮城県', 'ミヤギケン', '遠田郡美里町', 'トオダグンミサトマチ', '西舘', 'ニシダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡美里町内役田', '04', '04505', '9870045', '宮城県', 'ミヤギケン', '遠田郡美里町', 'トオダグンミサトマチ', '内役田', 'ウチヤクデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡美里町役田', '04', '04505', '9870046', '宮城県', 'ミヤギケン', '遠田郡美里町', 'トオダグンミサトマチ', '役田', 'ヤクデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡美里町上意江', '04', '04505', '9870051', '宮城県', 'ミヤギケン', '遠田郡美里町', 'トオダグンミサトマチ', '上意江', 'ジョウイエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡美里町砂子田', '04', '04505', '9870052', '宮城県', 'ミヤギケン', '遠田郡美里町', 'トオダグンミサトマチ', '砂子田', 'スナゴダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡美里町叔廼前', '04', '04505', '9870053', '宮城県', 'ミヤギケン', '遠田郡美里町', 'トオダグンミサトマチ', '叔廼前', 'シュクノマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡美里町塔の越', '04', '04505', '9870054', '宮城県', 'ミヤギケン', '遠田郡美里町', 'トオダグンミサトマチ', '塔の越', 'トウノコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡美里町新一本柳', '04', '04505', '9870055', '宮城県', 'ミヤギケン', '遠田郡美里町', 'トオダグンミサトマチ', '新一本柳', 'シンイッポンヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡美里町一本柳', '04', '04505', '9870056', '宮城県', 'ミヤギケン', '遠田郡美里町', 'トオダグンミサトマチ', '一本柳', 'イッポンヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡美里町狐山', '04', '04505', '9870057', '宮城県', 'ミヤギケン', '遠田郡美里町', 'トオダグンミサトマチ', '狐山', 'キツネヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡美里町塩釜', '04', '04505', '9870058', '宮城県', 'ミヤギケン', '遠田郡美里町', 'トオダグンミサトマチ', '塩釜', 'シオガマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡美里町塩釜添', '04', '04505', '9870059', '宮城県', 'ミヤギケン', '遠田郡美里町', 'トオダグンミサトマチ', '塩釜添', 'シオガマゾエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡美里町下境', '04', '04505', '9870061', '宮城県', 'ミヤギケン', '遠田郡美里町', 'トオダグンミサトマチ', '下境', 'シモサカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡美里町待井', '04', '04505', '9870062', '宮城県', 'ミヤギケン', '遠田郡美里町', 'トオダグンミサトマチ', '待井', 'マチイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡美里町小沼', '04', '04505', '9870063', '宮城県', 'ミヤギケン', '遠田郡美里町', 'トオダグンミサトマチ', '小沼', 'コヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡美里町小沼添', '04', '04505', '9870064', '宮城県', 'ミヤギケン', '遠田郡美里町', 'トオダグンミサトマチ', '小沼添', 'コヌマゾイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡美里町勘堂', '04', '04505', '9870065', '宮城県', 'ミヤギケン', '遠田郡美里町', 'トオダグンミサトマチ', '勘堂', 'カンドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡美里町二ツ壇', '04', '04505', '9870066', '宮城県', 'ミヤギケン', '遠田郡美里町', 'トオダグンミサトマチ', '二ツ壇', 'フタツダン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡美里町大所', '04', '04505', '9870067', '宮城県', 'ミヤギケン', '遠田郡美里町', 'トオダグンミサトマチ', '大所', 'ダイドコロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡美里町新大所', '04', '04505', '9870068', '宮城県', 'ミヤギケン', '遠田郡美里町', 'トオダグンミサトマチ', '新大所', 'シンダイドコロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡美里町北原', '04', '04505', '9870069', '宮城県', 'ミヤギケン', '遠田郡美里町', 'トオダグンミサトマチ', '北原', 'キタハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡涌谷町', '04', '04501', '9870100', '宮城県', 'ミヤギケン', '遠田郡涌谷町', 'トオダグンワクヤチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('142073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡涌谷町桜町裏', '04', '04501', '9870101', '宮城県', 'ミヤギケン', '遠田郡涌谷町', 'トオダグンワクヤチョウ', '桜町裏', 'サクラチョウウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡涌谷町表桜町', '04', '04501', '9870102', '宮城県', 'ミヤギケン', '遠田郡涌谷町', 'トオダグンワクヤチョウ', '表桜町', 'オモテサクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡涌谷町裏桜町', '04', '04501', '9870103', '宮城県', 'ミヤギケン', '遠田郡涌谷町', 'トオダグンワクヤチョウ', '裏桜町', 'ウラサクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡涌谷町田沼町', '04', '04501', '9870104', '宮城県', 'ミヤギケン', '遠田郡涌谷町', 'トオダグンワクヤチョウ', '田沼町', 'タヌマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡涌谷町練丑町', '04', '04501', '9870105', '宮城県', 'ミヤギケン', '遠田郡涌谷町', 'トオダグンワクヤチョウ', '練丑町', 'ネリウシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡涌谷町六軒町', '04', '04501', '9870106', '宮城県', 'ミヤギケン', '遠田郡涌谷町', 'トオダグンワクヤチョウ', '六軒町', 'ロッケンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡涌谷町六軒町裏', '04', '04501', '9870107', '宮城県', 'ミヤギケン', '遠田郡涌谷町', 'トオダグンワクヤチョウ', '六軒町裏', 'ロッケンチョウウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡涌谷町柳町', '04', '04501', '9870111', '宮城県', 'ミヤギケン', '遠田郡涌谷町', 'トオダグンワクヤチョウ', '柳町', 'ヤナギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡涌谷町桑木荒', '04', '04501', '9870112', '宮城県', 'ミヤギケン', '遠田郡涌谷町', 'トオダグンワクヤチョウ', '桑木荒', 'クワノキアラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡涌谷町渋江', '04', '04501', '9870113', '宮城県', 'ミヤギケン', '遠田郡涌谷町', 'トオダグンワクヤチョウ', '渋江', 'シブエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡涌谷町古道下二本杉', '04', '04501', '9870113', '宮城県', 'ミヤギケン', '遠田郡涌谷町', 'トオダグンワクヤチョウ', '古道下二本杉', 'フルミチシタニホンスギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡涌谷町新町裏', '04', '04501', '9870114', '宮城県', 'ミヤギケン', '遠田郡涌谷町', 'トオダグンワクヤチョウ', '新町裏', 'シンマチウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡涌谷町新町', '04', '04501', '9870115', '宮城県', 'ミヤギケン', '遠田郡涌谷町', 'トオダグンワクヤチョウ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡涌谷町涌谷', '04', '04501', '9870121', '宮城県', 'ミヤギケン', '遠田郡涌谷町', 'トオダグンワクヤチョウ', '涌谷', 'ワクヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡涌谷町新九軒前', '04', '04501', '9870130', '宮城県', 'ミヤギケン', '遠田郡涌谷町', 'トオダグンワクヤチョウ', '新九軒前', 'シンクケンマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡涌谷町北田', '04', '04501', '9870131', '宮城県', 'ミヤギケン', '遠田郡涌谷町', 'トオダグンワクヤチョウ', '北田', 'キタダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡涌谷町蔵人沖名', '04', '04501', '9870132', '宮城県', 'ミヤギケン', '遠田郡涌谷町', 'トオダグンワクヤチョウ', '蔵人沖名', 'クランドオキナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡涌谷町小谷地', '04', '04501', '9870132', '宮城県', 'ミヤギケン', '遠田郡涌谷町', 'トオダグンワクヤチョウ', '小谷地', 'コヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡涌谷町赤間屋敷', '04', '04501', '9870133', '宮城県', 'ミヤギケン', '遠田郡涌谷町', 'トオダグンワクヤチョウ', '赤間屋敷', 'アカマヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡涌谷町掃部沖名', '04', '04501', '9870133', '宮城県', 'ミヤギケン', '遠田郡涌谷町', 'トオダグンワクヤチョウ', '掃部沖名', 'カモンオキナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡涌谷町後藤江', '04', '04501', '9870133', '宮城県', 'ミヤギケン', '遠田郡涌谷町', 'トオダグンワクヤチョウ', '後藤江', 'ゴトウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡涌谷町今左衛門沖名', '04', '04501', '9870133', '宮城県', 'ミヤギケン', '遠田郡涌谷町', 'トオダグンワクヤチョウ', '今左衛門沖名', 'コンザエモンオキナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡涌谷町新田', '04', '04501', '9870133', '宮城県', 'ミヤギケン', '遠田郡涌谷町', 'トオダグンワクヤチョウ', '新田', 'シンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡涌谷町関谷沖名', '04', '04501', '9870133', '宮城県', 'ミヤギケン', '遠田郡涌谷町', 'トオダグンワクヤチョウ', '関谷沖名', 'セキヤオキナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡涌谷町台所橋道下', '04', '04501', '9870133', '宮城県', 'ミヤギケン', '遠田郡涌谷町', 'トオダグンワクヤチョウ', '台所橋道下', 'ダイドコロバシミチシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡涌谷町鷹野橋下中瀬', '04', '04501', '9870133', '宮城県', 'ミヤギケン', '遠田郡涌谷町', 'トオダグンワクヤチョウ', '鷹野橋下中瀬', 'タカノバシシモナカゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡涌谷町北五反田', '04', '04501', '9870134', '宮城県', 'ミヤギケン', '遠田郡涌谷町', 'トオダグンワクヤチョウ', '北五反田', 'キタゴタンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡涌谷町九軒', '04', '04501', '9870134', '宮城県', 'ミヤギケン', '遠田郡涌谷町', 'トオダグンワクヤチョウ', '九軒', 'クケン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡涌谷町五反田', '04', '04501', '9870134', '宮城県', 'ミヤギケン', '遠田郡涌谷町', 'トオダグンワクヤチョウ', '五反田', 'ゴタンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡涌谷町佐山木', '04', '04501', '9870134', '宮城県', 'ミヤギケン', '遠田郡涌谷町', 'トオダグンワクヤチョウ', '佐山木', 'サヤマギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡涌谷町地不足道', '04', '04501', '9870134', '宮城県', 'ミヤギケン', '遠田郡涌谷町', 'トオダグンワクヤチョウ', '地不足道', 'ジブソクミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡涌谷町西谷地', '04', '04501', '9870134', '宮城県', 'ミヤギケン', '遠田郡涌谷町', 'トオダグンワクヤチョウ', '西谷地', 'ニシヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡涌谷町二歩', '04', '04501', '9870134', '宮城県', 'ミヤギケン', '遠田郡涌谷町', 'トオダグンワクヤチョウ', '二歩', 'ニブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡涌谷町蘭場谷地', '04', '04501', '9870134', '宮城県', 'ミヤギケン', '遠田郡涌谷町', 'トオダグンワクヤチョウ', '蘭場谷地', 'ランバヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡涌谷町小蓋谷地', '04', '04501', '9870135', '宮城県', 'ミヤギケン', '遠田郡涌谷町', 'トオダグンワクヤチョウ', '小蓋谷地', 'コブタヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡涌谷町三十軒', '04', '04501', '9870135', '宮城県', 'ミヤギケン', '遠田郡涌谷町', 'トオダグンワクヤチョウ', '三十軒', 'サンジュッケン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡涌谷町一本柳', '04', '04501', '9870136', '宮城県', 'ミヤギケン', '遠田郡涌谷町', 'トオダグンワクヤチョウ', '一本柳', 'イッポンヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡涌谷町新中島乙', '04', '04501', '9870137', '宮城県', 'ミヤギケン', '遠田郡涌谷町', 'トオダグンワクヤチョウ', '新中島乙', 'シンナカジマオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡涌谷町中島', '04', '04501', '9870137', '宮城県', 'ミヤギケン', '遠田郡涌谷町', 'トオダグンワクヤチョウ', '中島', 'ナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡涌谷町中島乙', '04', '04501', '9870137', '宮城県', 'ミヤギケン', '遠田郡涌谷町', 'トオダグンワクヤチョウ', '中島乙', 'ナカジマオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡涌谷町中島川前', '04', '04501', '9870137', '宮城県', 'ミヤギケン', '遠田郡涌谷町', 'トオダグンワクヤチョウ', '中島川前', 'ナカジマカワマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡涌谷町中島甲', '04', '04501', '9870137', '宮城県', 'ミヤギケン', '遠田郡涌谷町', 'トオダグンワクヤチョウ', '中島甲', 'ナカジマコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡涌谷町新境堀下', '04', '04501', '9870138', '宮城県', 'ミヤギケン', '遠田郡涌谷町', 'トオダグンワクヤチョウ', '新境堀下', 'シンサカイボリシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡涌谷町新台所橋', '04', '04501', '9870139', '宮城県', 'ミヤギケン', '遠田郡涌谷町', 'トオダグンワクヤチョウ', '新台所橋', 'シンダイドコロバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡涌谷町新沖新田', '04', '04501', '9870140', '宮城県', 'ミヤギケン', '遠田郡涌谷町', 'トオダグンワクヤチョウ', '新沖新田', 'シンオキシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡涌谷町田町裏', '04', '04501', '9870141', '宮城県', 'ミヤギケン', '遠田郡涌谷町', 'トオダグンワクヤチョウ', '田町裏', 'タマチウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡涌谷町浦町', '04', '04501', '9870142', '宮城県', 'ミヤギケン', '遠田郡涌谷町', 'トオダグンワクヤチョウ', '浦町', 'ウラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡涌谷町長柄町', '04', '04501', '9870143', '宮城県', 'ミヤギケン', '遠田郡涌谷町', 'トオダグンワクヤチョウ', '長柄町', 'ナガエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡涌谷町沖新田', '04', '04501', '9870144', '宮城県', 'ミヤギケン', '遠田郡涌谷町', 'トオダグンワクヤチョウ', '沖新田', 'オキシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡涌谷町小山下', '04', '04501', '9870144', '宮城県', 'ミヤギケン', '遠田郡涌谷町', 'トオダグンワクヤチョウ', '小山下', 'コヤマシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡涌谷町下新田', '04', '04501', '9870144', '宮城県', 'ミヤギケン', '遠田郡涌谷町', 'トオダグンワクヤチョウ', '下新田', 'シモシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡涌谷町砂田', '04', '04501', '9870144', '宮城県', 'ミヤギケン', '遠田郡涌谷町', 'トオダグンワクヤチョウ', '砂田', 'スナタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡涌谷町八百刈', '04', '04501', '9870144', '宮城県', 'ミヤギケン', '遠田郡涌谷町', 'トオダグンワクヤチョウ', '八百刈', 'ハッピャクガリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡涌谷町薔薇島', '04', '04501', '9870144', '宮城県', 'ミヤギケン', '遠田郡涌谷町', 'トオダグンワクヤチョウ', '薔薇島', 'バラジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡涌谷町市道', '04', '04501', '9870145', '宮城県', 'ミヤギケン', '遠田郡涌谷町', 'トオダグンワクヤチョウ', '市道', 'イチミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡涌谷町烏鴉', '04', '04501', '9870145', '宮城県', 'ミヤギケン', '遠田郡涌谷町', 'トオダグンワクヤチョウ', '烏鴉', 'ウガラス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡涌谷町尾切', '04', '04501', '9870145', '宮城県', 'ミヤギケン', '遠田郡涌谷町', 'トオダグンワクヤチョウ', '尾切', 'オギレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡涌谷町鞍掛', '04', '04501', '9870145', '宮城県', 'ミヤギケン', '遠田郡涌谷町', 'トオダグンワクヤチョウ', '鞍掛', 'クラガケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡涌谷町花勝山', '04', '04501', '9870145', '宮城県', 'ミヤギケン', '遠田郡涌谷町', 'トオダグンワクヤチョウ', '花勝山', 'ケカツヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡涌谷町新尾切', '04', '04501', '9870145', '宮城県', 'ミヤギケン', '遠田郡涌谷町', 'トオダグンワクヤチョウ', '新尾切', 'シンオギレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡涌谷町新名鰭', '04', '04501', '9870145', '宮城県', 'ミヤギケン', '遠田郡涌谷町', 'トオダグンワクヤチョウ', '新名鰭', 'シンナビレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡涌谷町名鰭', '04', '04501', '9870145', '宮城県', 'ミヤギケン', '遠田郡涌谷町', 'トオダグンワクヤチョウ', '名鰭', 'ナビレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡涌谷町中下道', '04', '04501', '9870146', '宮城県', 'ミヤギケン', '遠田郡涌谷町', 'トオダグンワクヤチョウ', '中下道', 'ナカゲドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡涌谷町下道', '04', '04501', '9870147', '宮城県', 'ミヤギケン', '遠田郡涌谷町', 'トオダグンワクヤチョウ', '下道', 'ゲドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡涌谷町三軒屋敷', '04', '04501', '9870148', '宮城県', 'ミヤギケン', '遠田郡涌谷町', 'トオダグンワクヤチョウ', '三軒屋敷', 'サンゲンヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡涌谷町新後藤江', '04', '04501', '9870149', '宮城県', 'ミヤギケン', '遠田郡涌谷町', 'トオダグンワクヤチョウ', '新後藤江', 'シンゴトウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡涌谷町小塚', '04', '04501', '9870151', '宮城県', 'ミヤギケン', '遠田郡涌谷町', 'トオダグンワクヤチョウ', '小塚', 'コヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡涌谷町川原町', '04', '04501', '9870161', '宮城県', 'ミヤギケン', '遠田郡涌谷町', 'トオダグンワクヤチョウ', '川原町', 'カワラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡涌谷町本町', '04', '04501', '9870162', '宮城県', 'ミヤギケン', '遠田郡涌谷町', 'トオダグンワクヤチョウ', '本町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡涌谷町立町', '04', '04501', '9870163', '宮城県', 'ミヤギケン', '遠田郡涌谷町', 'トオダグンワクヤチョウ', '立町', 'タツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡涌谷町刈萱町', '04', '04501', '9870164', '宮城県', 'ミヤギケン', '遠田郡涌谷町', 'トオダグンワクヤチョウ', '刈萱町', 'カルカヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡涌谷町追廻町', '04', '04501', '9870165', '宮城県', 'ミヤギケン', '遠田郡涌谷町', 'トオダグンワクヤチョウ', '追廻町', 'オイマワシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡涌谷町上郡', '04', '04501', '9870171', '宮城県', 'ミヤギケン', '遠田郡涌谷町', 'トオダグンワクヤチョウ', '上郡', 'カミゴオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡涌谷町下郡', '04', '04501', '9870172', '宮城県', 'ミヤギケン', '遠田郡涌谷町', 'トオダグンワクヤチョウ', '下郡', 'シモゴオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡涌谷町小里', '04', '04501', '9870281', '宮城県', 'ミヤギケン', '遠田郡涌谷町', 'トオダグンワクヤチョウ', '小里', 'オサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡涌谷町太田', '04', '04501', '9870282', '宮城県', 'ミヤギケン', '遠田郡涌谷町', 'トオダグンワクヤチョウ', '太田', 'オオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡涌谷町吉住', '04', '04501', '9870283', '宮城県', 'ミヤギケン', '遠田郡涌谷町', 'トオダグンワクヤチョウ', '吉住', 'ヨシズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡涌谷町猪岡短台', '04', '04501', '9870284', '宮城県', 'ミヤギケン', '遠田郡涌谷町', 'トオダグンワクヤチョウ', '猪岡短台', 'イノオカタンダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡涌谷町箟岳', '04', '04501', '9870285', '宮城県', 'ミヤギケン', '遠田郡涌谷町', 'トオダグンワクヤチョウ', '箟岳', 'ノノダケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡涌谷町成沢', '04', '04501', '9870286', '宮城県', 'ミヤギケン', '遠田郡涌谷町', 'トオダグンワクヤチョウ', '成沢', 'ナリサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市米山町善王寺', '04', '04212', '9870301', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '米山町善王寺', 'ヨネヤマチョウゼンノウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市米山町沼田', '04', '04212', '9870302', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '米山町沼田', 'ヨネヤマチョウヌマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市米山町櫓場', '04', '04212', '9870302', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '米山町櫓場', 'ヨネヤマチョウヤグラバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市米山町櫓場下', '04', '04212', '9870302', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '米山町櫓場下', 'ヨネヤマチョウヤグラバシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市米山町田畑西', '04', '04212', '9870303', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '米山町田畑西', 'ヨネヤマチョウタバタニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市米山町田畑前', '04', '04212', '9870303', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '米山町田畑前', 'ヨネヤマチョウタバタマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市米山町内', '04', '04212', '9870304', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '米山町内', 'ヨネヤマチョウウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市米山町中道東', '04', '04212', '9870304', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '米山町中道東', 'ヨネヤマチョウナカミチヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市米山町中道前', '04', '04212', '9870304', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '米山町中道前', 'ヨネヤマチョウナカミチマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市米山町川前', '04', '04212', '9870305', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '米山町川前', 'ヨネヤマチョウカワマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市米山町水門', '04', '04212', '9870305', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '米山町水門', 'ヨネヤマチョウスイモン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市米山町八反', '04', '04212', '9870305', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '米山町八反', 'ヨネヤマチョウハッタン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市米山町地蔵川', '04', '04212', '9870306', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '米山町地蔵川', 'ヨネヤマチョウジゾウガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市米山町土佐ケ渕', '04', '04212', '9870306', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '米山町土佐ケ渕', 'ヨネヤマチョウトサガフチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市米山町愛宕下', '04', '04212', '9870307', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '米山町愛宕下', 'ヨネヤマチョウアタゴシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市米山町愛宕前', '04', '04212', '9870307', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '米山町愛宕前', 'ヨネヤマチョウアタゴマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市米山町犬子松', '04', '04212', '9870307', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '米山町犬子松', 'ヨネヤマチョウイヌコマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市米山町猿ケ崎', '04', '04212', '9870307', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '米山町猿ケ崎', 'ヨネヤマチョウサルガサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市米山町小待井', '04', '04212', '9870308', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '米山町小待井', 'ヨネヤマチョウコマチイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市米山町小待井下', '04', '04212', '9870308', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '米山町小待井下', 'ヨネヤマチョウコマチイシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市米山町待井下', '04', '04212', '9870308', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '米山町待井下', 'ヨネヤマチョウマチイシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市米山町舘下', '04', '04212', '9870309', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '米山町舘下', 'ヨネヤマチョウダテシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市米山町舘前', '04', '04212', '9870309', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '米山町舘前', 'ヨネヤマチョウダテマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市米山町桜岡', '04', '04212', '9870311', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '米山町桜岡', 'ヨネヤマチョウサクラオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市米山町西野', '04', '04212', '9870321', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '米山町西野', 'ヨネヤマチョウニシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市米山町中津山', '04', '04212', '9870331', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '米山町中津山', 'ヨネヤマチョウナカツヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市豊里町大沢', '04', '04212', '9870341', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '豊里町大沢', 'トヨサトチョウオオサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市豊里町大沢沼田', '04', '04212', '9870341', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '豊里町大沢沼田', 'トヨサトチョウオオサワヌマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市豊里町大沢谷岐', '04', '04212', '9870341', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '豊里町大沢谷岐', 'トヨサトチョウオオサワヤギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市豊里町十二沢', '04', '04212', '9870341', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '豊里町十二沢', 'トヨサトチョウジュウニサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市豊里町竹ノ沢', '04', '04212', '9870341', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '豊里町竹ノ沢', 'トヨサトチョウタケノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市豊里町山根', '04', '04212', '9870342', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '豊里町山根', 'トヨサトチョウヤマネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市豊里町山根前', '04', '04212', '9870342', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '豊里町山根前', 'トヨサトチョウヤマネマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市豊里町小谷地', '04', '04212', '9870343', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '豊里町小谷地', 'トヨサトチョウコヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市豊里町沢尻', '04', '04212', '9870343', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '豊里町沢尻', 'トヨサトチョウサワジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市豊里町境沢', '04', '04212', '9870344', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '豊里町境沢', 'トヨサトチョウサカイザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市豊里町佐野', '04', '04212', '9870344', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '豊里町佐野', 'トヨサトチョウサノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市豊里町迫', '04', '04212', '9870344', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '豊里町迫', 'トヨサトチョウハサマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市豊里町中谷岐', '04', '04212', '9870345', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '豊里町中谷岐', 'トヨサトチョウナカヤギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市豊里町福沢', '04', '04212', '9870345', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '豊里町福沢', 'トヨサトチョウフクサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市豊里町白鳥山', '04', '04212', '9870346', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '豊里町白鳥山', 'トヨサトチョウシラトリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市豊里町白鳥', '04', '04212', '9870346', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '豊里町白鳥', 'トヨサトチョウシロトリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市豊里町白鳥前', '04', '04212', '9870346', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '豊里町白鳥前', 'トヨサトチョウシロトリマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市豊里町久寿田', '04', '04212', '9870351', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '豊里町久寿田', 'トヨサトチョウクスダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市豊里町久寿田前', '04', '04212', '9870351', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '豊里町久寿田前', 'トヨサトチョウクスダマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市豊里町寿崎', '04', '04212', '9870352', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '豊里町寿崎', 'トヨサトチョウスサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市豊里町笑沢', '04', '04212', '9870353', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '豊里町笑沢', 'トヨサトチョウエミサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市豊里町大椚', '04', '04212', '9870353', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '豊里町大椚', 'トヨサトチョウオオクヌギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市豊里町平林', '04', '04212', '9870353', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '豊里町平林', 'トヨサトチョウヒラバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市豊里町上沼田', '04', '04212', '9870354', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '豊里町上沼田', 'トヨサトチョウウワヌマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市豊里町下沼田', '04', '04212', '9870354', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '豊里町下沼田', 'トヨサトチョウシモヌマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市豊里町昭和', '04', '04212', '9870354', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '豊里町昭和', 'トヨサトチョウショウワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市豊里町中沼田', '04', '04212', '9870354', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '豊里町中沼田', 'トヨサトチョウナカヌマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市豊里町沼田', '04', '04212', '9870354', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '豊里町沼田', 'トヨサトチョウヌマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市豊里町後沢田', '04', '04212', '9870355', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '豊里町後沢田', 'トヨサトチョウウシロサワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市豊里町保手', '04', '04212', '9870355', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '豊里町保手', 'トヨサトチョウホデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市豊里町芝下', '04', '04212', '9870356', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '豊里町芝下', 'トヨサトチョウシバシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市豊里町杢沢', '04', '04212', '9870356', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '豊里町杢沢', 'トヨサトチョウモクサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市豊里町蕪木', '04', '04212', '9870357', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '豊里町蕪木', 'トヨサトチョウカブキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市豊里町鳥越', '04', '04212', '9870357', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '豊里町鳥越', 'トヨサトチョウトリゴエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市豊里町加々巻', '04', '04212', '9870358', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '豊里町加々巻', 'トヨサトチョウカガマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市豊里町小巻', '04', '04212', '9870358', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '豊里町小巻', 'トヨサトチョウコマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市豊里町新加々巻', '04', '04212', '9870358', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '豊里町新加々巻', 'トヨサトチョウシンカガマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市豊里町長根浦', '04', '04212', '9870358', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '豊里町長根浦', 'トヨサトチョウナガネウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市豊里町八反', '04', '04212', '9870359', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '豊里町八反', 'トヨサトチョウハツタン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市豊里町本地八反', '04', '04212', '9870359', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '豊里町本地八反', 'トヨサトチョウホンチハツタン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市豊里町新田町', '04', '04212', '9870361', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '豊里町新田町', 'トヨサトチョウシンデンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市豊里町上町裏', '04', '04212', '9870362', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '豊里町上町裏', 'トヨサトチョウカミマチウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市豊里町小口前', '04', '04212', '9870362', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '豊里町小口前', 'トヨサトチョウコグチマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市豊里町東待井下', '04', '04212', '9870362', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '豊里町東待井下', 'トヨサトチョウヒガシマチイシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市豊里町五反田', '04', '04212', '9870363', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '豊里町五反田', 'トヨサトチョウゴタンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市豊里町横町', '04', '04212', '9870363', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '豊里町横町', 'トヨサトチョウヨコチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市豊里町下古屋', '04', '04212', '9870364', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '豊里町下古屋', 'トヨサトチョウシモコヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市豊里町土手下', '04', '04212', '9870364', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '豊里町土手下', 'トヨサトチョウドテシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市豊里町本地土手下', '04', '04212', '9870364', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '豊里町本地土手下', 'トヨサトチョウホンチドテシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市豊里町新町', '04', '04212', '9870365', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '豊里町新町', 'トヨサトチョウシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市豊里町浦軒', '04', '04212', '9870366', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '豊里町浦軒', 'トヨサトチョウウラケン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市豊里町上屋浦', '04', '04212', '9870366', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '豊里町上屋浦', 'トヨサトチョウカミヤウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市豊里町下屋浦', '04', '04212', '9870366', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '豊里町下屋浦', 'トヨサトチョウシモヤウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市豊里町川前', '04', '04212', '9870367', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '豊里町川前', 'トヨサトチョウカワマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市豊里町七ツ塚', '04', '04212', '9870368', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '豊里町七ツ塚', 'トヨサトチョウナナツヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市豊里町町浦', '04', '04212', '9870368', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '豊里町町浦', 'トヨサトチョウマチウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市豊里町南町浦', '04', '04212', '9870368', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '豊里町南町浦', 'トヨサトチョウミナミマチウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市豊里町大曲', '04', '04212', '9870371', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '豊里町大曲', 'トヨサトチョウオオマガリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市豊里町唐崎', '04', '04212', '9870371', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '豊里町唐崎', 'トヨサトチョウカラサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市豊里町十丁田', '04', '04212', '9870371', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '豊里町十丁田', 'トヨサトチョウジッチョウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市豊里町西前田', '04', '04212', '9870372', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '豊里町西前田', 'トヨサトチョウニシマエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市豊里町前田', '04', '04212', '9870372', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '豊里町前田', 'トヨサトチョウマエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市豊里町内町浦', '04', '04212', '9870373', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '豊里町内町浦', 'トヨサトチョウウチマチウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市豊里町切津', '04', '04212', '9870373', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '豊里町切津', 'トヨサトチョウキツツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市豊里町南切津', '04', '04212', '9870373', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '豊里町南切津', 'トヨサトチョウミナミキツツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市豊里町東二ツ屋', '04', '04212', '9870374', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '豊里町東二ツ屋', 'トヨサトチョウヒガシフタツヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市豊里町二ツ屋', '04', '04212', '9870375', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '豊里町二ツ屋', 'トヨサトチョウフタツヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市豊里町新細沼', '04', '04212', '9870376', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '豊里町新細沼', 'トヨサトチョウシンホソヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市豊里町細沼', '04', '04212', '9870376', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '豊里町細沼', 'トヨサトチョウホソヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市豊里町細沼田', '04', '04212', '9870376', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '豊里町細沼田', 'トヨサトチョウホソヌマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市豊里町内一番江', '04', '04212', '9870377', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '豊里町内一番江', 'トヨサトチョウウチイチバンエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市豊里町外一番江', '04', '04212', '9870377', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '豊里町外一番江', 'トヨサトチョウソトイチバンエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市豊里町鏡形', '04', '04212', '9870378', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '豊里町鏡形', 'トヨサトチョウカガミガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市豊里町新田鏡形', '04', '04212', '9870378', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '豊里町新田鏡形', 'トヨサトチョウシンデンカガミガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市豊里町剣先', '04', '04212', '9870379', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '豊里町剣先', 'トヨサトチョウケンザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市豊里町新長前', '04', '04212', '9870381', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '豊里町新長前', 'トヨサトチョウシンナガマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市豊里町長前', '04', '04212', '9870381', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '豊里町長前', 'トヨサトチョウナガマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市豊里町上谷地', '04', '04212', '9870382', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '豊里町上谷地', 'トヨサトチョウカミヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市豊里町外五番江', '04', '04212', '9870383', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '豊里町外五番江', 'トヨサトチョウソトゴバンエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市豊里町外三番江', '04', '04212', '9870383', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '豊里町外三番江', 'トヨサトチョウソトサンバンエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市豊里町外七番江', '04', '04212', '9870383', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '豊里町外七番江', 'トヨサトチョウソトナナバンエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市豊里町外二番江', '04', '04212', '9870383', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '豊里町外二番江', 'トヨサトチョウソトニバンエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市豊里町外八番江', '04', '04212', '9870383', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '豊里町外八番江', 'トヨサトチョウソトハチバンエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市豊里町外四番江', '04', '04212', '9870383', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '豊里町外四番江', 'トヨサトチョウソトヨンバンエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市豊里町外六番江', '04', '04212', '9870383', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '豊里町外六番江', 'トヨサトチョウソトロクバンエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市豊里町十五貫', '04', '04212', '9870384', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '豊里町十五貫', 'トヨサトチョウジュウゴカン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市豊里町十五貫谷地', '04', '04212', '9870384', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '豊里町十五貫谷地', 'トヨサトチョウジュウゴカンヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市豊里町内田', '04', '04212', '9870385', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '豊里町内田', 'トヨサトチョウウチタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市豊里町内畑', '04', '04212', '9870385', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '豊里町内畑', 'トヨサトチョウウチハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市豊里町下九', '04', '04212', '9870385', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '豊里町下九', 'トヨサトチョウシモギュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町高石', '04', '04212', '9870401', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町高石', 'ミナミカタマチタカイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町高石浦', '04', '04212', '9870401', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町高石浦', 'ミナミカタマチタカイシウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町西山成', '04', '04212', '9870401', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町西山成', 'ミナミカタマチニシヤマナリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町西山成前', '04', '04212', '9870401', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町西山成前', 'ミナミカタマチニシヤマナリマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町八の森', '04', '04212', '9870401', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町八の森', 'ミナミカタマチハチノモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町山成', '04', '04212', '9870401', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町山成', 'ミナミカタマチヤマナリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町山成前', '04', '04212', '9870401', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町山成前', 'ミナミカタマチヤマナリマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町板倉', '04', '04212', '9870402', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町板倉', 'ミナミカタマチイタクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町板倉後', '04', '04212', '9870402', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町板倉後', 'ミナミカタマチイタクラウシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町後屋敷待井', '04', '04212', '9870402', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町後屋敷待井', 'ミナミカタマチウシロヤシキマチイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町沢田', '04', '04212', '9870402', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町沢田', 'ミナミカタマチサワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町沢田待井', '04', '04212', '9870402', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町沢田待井', 'ミナミカタマチサワダマチイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町沢田屋敷', '04', '04212', '9870402', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町沢田屋敷', 'ミナミカタマチサワダヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町鶴代', '04', '04212', '9870402', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町鶴代', 'ミナミカタマチツルシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町戸根屋敷', '04', '04212', '9870402', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町戸根屋敷', 'ミナミカタマチトネヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町中山', '04', '04212', '9870402', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町中山', 'ミナミカタマチナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町待井', '04', '04212', '9870402', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町待井', 'ミナミカタマチマチイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町松島屋敷', '04', '04212', '9870402', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町松島屋敷', 'ミナミカタマチマツシマヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町内ノ目', '04', '04212', '9870403', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町内ノ目', 'ミナミカタマチウチノメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町王塚', '04', '04212', '9870403', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町王塚', 'ミナミカタマチオオツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町河面', '04', '04212', '9870403', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町河面', 'ミナミカタマチカワヅラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町鴻ノ木', '04', '04212', '9870403', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町鴻ノ木', 'ミナミカタマチコウノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町小山', '04', '04212', '9870403', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町小山', 'ミナミカタマチコヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町二ツ橋', '04', '04212', '9870403', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町二ツ橋', 'ミナミカタマチフタツバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町峯', '04', '04212', '9870403', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町峯', 'ミナミカタマチミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町薬師島屋敷', '04', '04212', '9870403', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町薬師島屋敷', 'ミナミカタマチヤクシジマヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町新島前', '04', '04212', '9870404', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町新島前', 'ミナミカタマチシンシママエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町天沼', '04', '04212', '9870411', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町天沼', 'ミナミカタマチアマヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町瀬ノ淵', '04', '04212', '9870411', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町瀬ノ淵', 'ミナミカタマチセノフチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町寺袋', '04', '04212', '9870411', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町寺袋', 'ミナミカタマチテラブクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町上ケ戸', '04', '04212', '9870412', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町上ケ戸', 'ミナミカタマチアガト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町雷', '04', '04212', '9870412', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町雷', 'ミナミカタマチイカズチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町大涌戸', '04', '04212', '9870412', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町大涌戸', 'ミナミカタマチオオワクド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町大門', '04', '04212', '9870412', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町大門', 'ミナミカタマチダイモン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町照井', '04', '04212', '9870412', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町照井', 'ミナミカタマチテルイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町峯前', '04', '04212', '9870412', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町峯前', 'ミナミカタマチミネマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町上原', '04', '04212', '9870413', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町上原', 'ミナミカタマチカミハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町下原前', '04', '04212', '9870413', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町下原前', 'ミナミカタマチシモハラマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町宿畑', '04', '04212', '9870413', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町宿畑', 'ミナミカタマチシュクバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町中原', '04', '04212', '9870413', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町中原', 'ミナミカタマチナカハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町原', '04', '04212', '9870413', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町原', 'ミナミカタマチハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町原浦', '04', '04212', '9870413', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町原浦', 'ミナミカタマチハラウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町原前', '04', '04212', '9870413', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町原前', 'ミナミカタマチハラマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町原屋敷', '04', '04212', '9870413', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町原屋敷', 'ミナミカタマチハラヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町内鰐丸', '04', '04212', '9870414', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町内鰐丸', 'ミナミカタマチウチワニマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町大村', '04', '04212', '9870414', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町大村', 'ミナミカタマチオオムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町大村前', '04', '04212', '9870414', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町大村前', 'ミナミカタマチオオムラマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町松葉', '04', '04212', '9870414', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町松葉', 'ミナミカタマチマツバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町松葉表', '04', '04212', '9870414', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町松葉表', 'ミナミカタマチマツバオモテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町松葉前', '04', '04212', '9870414', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町松葉前', 'ミナミカタマチマツバマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町山成浦', '04', '04212', '9870414', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町山成浦', 'ミナミカタマチヤマナリウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町鰐丸', '04', '04212', '9870414', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町鰐丸', 'ミナミカタマチワニマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町大畑', '04', '04212', '9870421', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町大畑', 'ミナミカタマチオオバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町仕込', '04', '04212', '9870421', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町仕込', 'ミナミカタマチシコミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町新井宿', '04', '04212', '9870421', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町新井宿', 'ミナミカタマチニイジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町南大畑前', '04', '04212', '9870421', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町南大畑前', 'ミナミカタマチミナミオオバタマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町大畠前', '04', '04212', '9870422', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町大畠前', 'ミナミカタマチオオハタマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町川前', '04', '04212', '9870422', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町川前', 'ミナミカタマチカワマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町新大畑前', '04', '04212', '9870422', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町新大畑前', 'ミナミカタマチシンオオバタマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町新田', '04', '04212', '9870422', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町新田', 'ミナミカタマチシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町瀬川', '04', '04212', '9870422', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町瀬川', 'ミナミカタマチセガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町東川前', '04', '04212', '9870422', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町東川前', 'ミナミカタマチヒガシカワマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町蛇沼', '04', '04212', '9870422', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町蛇沼', 'ミナミカタマチヘビヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町室田', '04', '04212', '9870422', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町室田', 'ミナミカタマチムロタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町山崎', '04', '04212', '9870422', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町山崎', 'ミナミカタマチヤマザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町大嶽', '04', '04212', '9870423', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町大嶽', 'ミナミカタマチオオダケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町大嶽前', '04', '04212', '9870423', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町大嶽前', 'ミナミカタマチオオダケマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町大嶽山', '04', '04212', '9870423', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町大嶽山', 'ミナミカタマチオオダケヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町烏田', '04', '04212', '9870423', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町烏田', 'ミナミカタマチカラスダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町ぜん荷前', '04', '04212', '9870423', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町ぜん荷前', 'ミナミカタマチゼンカマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町ぜん荷山', '04', '04212', '9870423', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町ぜん荷山', 'ミナミカタマチゼンカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町館', '04', '04212', '9870423', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町館', 'ミナミカタマチタテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町堂地', '04', '04212', '9870423', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町堂地', 'ミナミカタマチドウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町堂地前', '04', '04212', '9870423', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町堂地前', 'ミナミカタマチドウチマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町堀切', '04', '04212', '9870423', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町堀切', 'ミナミカタマチホッキリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町本郷大嶽', '04', '04212', '9870423', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町本郷大嶽', 'ミナミカタマチホンゴウオオダケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町風張', '04', '04212', '9870424', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町風張', 'ミナミカタマチカザハリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町館浦', '04', '04212', '9870424', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町館浦', 'ミナミカタマチタテウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町細川', '04', '04212', '9870424', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町細川', 'ミナミカタマチホソカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町細川浦', '04', '04212', '9870424', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町細川浦', 'ミナミカタマチホソカワウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町細川前', '04', '04212', '9870424', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町細川前', 'ミナミカタマチホソカワマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町南沢', '04', '04212', '9870424', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町南沢', 'ミナミカタマチミナミザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町南細川', '04', '04212', '9870424', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町南細川', 'ミナミカタマチミナミホソカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町梶沼', '04', '04212', '9870425', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町梶沼', 'ミナミカタマチカジヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町梶沼川前', '04', '04212', '9870425', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町梶沼川前', 'ミナミカタマチカジヌマカワマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町梶沼前', '04', '04212', '9870425', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町梶沼前', 'ミナミカタマチカジヌママエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町上砥落', '04', '04212', '9870425', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町上砥落', 'ミナミカタマチカミトオトシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町下砥落', '04', '04212', '9870425', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町下砥落', 'ミナミカタマチシモトオトシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町十二山', '04', '04212', '9870425', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町十二山', 'ミナミカタマチジュウニヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町田中浦', '04', '04212', '9870425', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町田中浦', 'ミナミカタマチタナカウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町砥落', '04', '04212', '9870425', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町砥落', 'ミナミカタマチトオトシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町沼向', '04', '04212', '9870425', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町沼向', 'ミナミカタマチヌマムカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町米袋', '04', '04212', '9870425', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町米袋', 'ミナミカタマチヨネブクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町米袋浦', '04', '04212', '9870425', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町米袋浦', 'ミナミカタマチヨネブクロウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町米袋前', '04', '04212', '9870425', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町米袋前', 'ミナミカタマチヨネブクロマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町大袋', '04', '04212', '9870426', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町大袋', 'ミナミカタマチオオブクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町大袋浦', '04', '04212', '9870426', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町大袋浦', 'ミナミカタマチオオブクロウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町樟', '04', '04212', '9870426', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町樟', 'ミナミカタマチクヌギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町樟土手外', '04', '04212', '9870426', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町樟土手外', 'ミナミカタマチクヌギドテソト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町成田', '04', '04212', '9870426', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町成田', 'ミナミカタマチナリタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町若狭前', '04', '04212', '9870426', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町若狭前', 'ミナミカタマチワカサマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町一ノ曲', '04', '04212', '9870431', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町一ノ曲', 'ミナミカタマチイチノマガリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町大埣', '04', '04212', '9870431', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町大埣', 'ミナミカタマチオオゾネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町太田', '04', '04212', '9870431', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町太田', 'ミナミカタマチオオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町新一ノ曲', '04', '04212', '9870431', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町新一ノ曲', 'ミナミカタマチシンイチノマガリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町横前', '04', '04212', '9870431', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町横前', 'ミナミカタマチヨコマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町青笹', '04', '04212', '9870432', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町青笹', 'ミナミカタマチアオザサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町狼掛', '04', '04212', '9870432', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町狼掛', 'ミナミカタマチオイノガケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町上窪田', '04', '04212', '9870432', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町上窪田', 'ミナミカタマチカミクボタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町窪田', '04', '04212', '9870432', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町窪田', 'ミナミカタマチクボタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町堤田', '04', '04212', '9870432', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町堤田', 'ミナミカタマチツツミタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町畑岡', '04', '04212', '9870432', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町畑岡', 'ミナミカタマチハタオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町畑岡下', '04', '04212', '9870432', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町畑岡下', 'ミナミカタマチハタオカシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町大平', '04', '04212', '9870433', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町大平', 'ミナミカタマチオオダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町大平前', '04', '04212', '9870433', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町大平前', 'ミナミカタマチオオダイラマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町長者原', '04', '04212', '9870433', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町長者原', 'ミナミカタマチチョウジャハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町中ノ口', '04', '04212', '9870433', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町中ノ口', 'ミナミカタマチナカノクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町沼崎', '04', '04212', '9870433', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町沼崎', 'ミナミカタマチヌマサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町沼崎前', '04', '04212', '9870433', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町沼崎前', 'ミナミカタマチヌマサキマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町青島前', '04', '04212', '9870441', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町青島前', 'ミナミカタマチアオシママエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町青島待井', '04', '04212', '9870441', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町青島待井', 'ミナミカタマチアオシママチイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町青島屋敷', '04', '04212', '9870441', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町青島屋敷', 'ミナミカタマチアオシマヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町後高石', '04', '04212', '9870442', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町後高石', 'ミナミカタマチウシロタカイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町茶臼森', '04', '04212', '9870442', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町茶臼森', 'ミナミカタマチチャウスモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町茶臼森前', '04', '04212', '9870442', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町茶臼森前', 'ミナミカタマチチャウスモリマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町中高石', '04', '04212', '9870442', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町中高石', 'ミナミカタマチナカタカイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町板ケ沢', '04', '04212', '9870443', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町板ケ沢', 'ミナミカタマチイタガサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町一網', '04', '04212', '9870443', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町一網', 'ミナミカタマチイチアジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町大坂前', '04', '04212', '9870443', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町大坂前', 'ミナミカタマチオオザカマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町大西', '04', '04212', '9870443', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町大西', 'ミナミカタマチオオニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町表前', '04', '04212', '9870443', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町表前', 'ミナミカタマチオモテマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町苔野谷地', '04', '04212', '9870443', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町苔野谷地', 'ミナミカタマチコケノヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町新野谷地', '04', '04212', '9870443', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町新野谷地', 'ミナミカタマチシンノヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町外浦', '04', '04212', '9870443', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町外浦', 'ミナミカタマチソトウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町長根', '04', '04212', '9870443', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町長根', 'ミナミカタマチナガネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町長根下', '04', '04212', '9870443', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町長根下', 'ミナミカタマチナガネシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町野谷地', '04', '04212', '9870443', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町野谷地', 'ミナミカタマチノヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町尼池', '04', '04212', '9870444', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町尼池', 'ミナミカタマチアマイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町大上', '04', '04212', '9870444', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町大上', 'ミナミカタマチオオガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町大森前', '04', '04212', '9870444', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町大森前', 'ミナミカタマチオオモリマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町三代前', '04', '04212', '9870444', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町三代前', 'ミナミカタマチサンダイマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町下新山', '04', '04212', '9870444', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町下新山', 'ミナミカタマチシモシンザン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町角欠前', '04', '04212', '9870444', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町角欠前', 'ミナミカタマチツノガケマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町間内', '04', '04212', '9870444', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町間内', 'ミナミカタマチマウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町間内前', '04', '04212', '9870444', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町間内前', 'ミナミカタマチマウチマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町実沢', '04', '04212', '9870444', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町実沢', 'ミナミカタマチミサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町柳沢', '04', '04212', '9870444', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町柳沢', 'ミナミカタマチヤナギサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町柳沢前', '04', '04212', '9870444', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町柳沢前', 'ミナミカタマチヤナギサワマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町横代', '04', '04212', '9870444', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町横代', 'ミナミカタマチヨコダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町上平貝', '04', '04212', '9870445', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町上平貝', 'ミナミカタマチカミヒラガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町下平貝', '04', '04212', '9870445', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町下平貝', 'ミナミカタマチシモヒラガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町銭金壇', '04', '04212', '9870445', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町銭金壇', 'ミナミカタマチゼニガネダン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町中須崎', '04', '04212', '9870445', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町中須崎', 'ミナミカタマチナカスサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町平貝', '04', '04212', '9870445', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町平貝', 'ミナミカタマチヒラガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市南方町翌沢', '04', '04212', '9870445', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '南方町翌沢', 'ミナミカタマチヨクサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市', '04', '04212', '9870500', '宮城県', 'ミヤギケン', '登米市', 'トメシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('142427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市迫町佐沼', '04', '04212', '9870511', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '迫町佐沼', 'ハサマチョウサヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市迫町森', '04', '04212', '9870512', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '迫町森', 'ハサマチョウモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市迫町北方', '04', '04212', '9870513', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '迫町北方', 'ハサマチョウキタカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市中田町石森', '04', '04212', '9870601', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '中田町石森', 'ナカダチョウイシノモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市中田町上沼', '04', '04212', '9870602', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '中田町上沼', 'ナカダチョウウワヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市中田町浅水', '04', '04212', '9870611', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '中田町浅水', 'ナカダチョウアサミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市中田町宝江黒沼', '04', '04212', '9870621', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '中田町宝江黒沼', 'ナカダチョウタカラエクロヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市中田町宝江新井田', '04', '04212', '9870622', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '中田町宝江新井田', 'ナカダチョウタカラエニイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市中田町宝江森', '04', '04212', '9870623', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '中田町宝江森', 'ナカダチョウタカラエモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市登米町小島', '04', '04212', '9870701', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '登米町小島', 'トヨママチコジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市登米町寺池', '04', '04212', '9870702', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '登米町寺池', 'トヨママチテライケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市登米町日根牛', '04', '04212', '9870703', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '登米町日根牛', 'トヨママチヒネウシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市登米町日野渡', '04', '04212', '9870704', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '登米町日野渡', 'トヨママチヒノト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市東和町米川', '04', '04212', '9870901', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '東和町米川', 'トウワチョウヨネカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市東和町米谷', '04', '04212', '9870902', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '東和町米谷', 'トウワチョウマイヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市東和町錦織', '04', '04212', '9870903', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '東和町錦織', 'トウワチョウニシキオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市前谷地', '04', '04202', '9871101', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '前谷地', 'マエヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市和渕', '04', '04202', '9871102', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '和渕', 'ワブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市北村', '04', '04202', '9871103', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '北村', 'キタムラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市須江', '04', '04202', '9871221', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '須江', 'スエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県石巻市広渕', '04', '04202', '9871222', '宮城県', 'ミヤギケン', '石巻市', 'イシノマキシ', '広渕', 'ヒロブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市松山須摩屋', '04', '04215', '9871301', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '松山須摩屋', 'マツヤマスマヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市松山長尾', '04', '04215', '9871302', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '松山長尾', 'マツヤマナガオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市松山金谷', '04', '04215', '9871303', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '松山金谷', 'マツヤマカナヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市松山千石', '04', '04215', '9871304', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '松山千石', 'マツヤマセンゴク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市松山次橋', '04', '04215', '9871305', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '松山次橋', 'マツヤマツギハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市松山下伊場野', '04', '04215', '9871306', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '松山下伊場野', 'マツヤマシモイバノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市高清水蟹沢尻', '04', '04213', '9872001', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '高清水蟹沢尻', 'タカシミズカニサワシリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市高清水八重壁', '04', '04213', '9872002', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '高清水八重壁', 'タカシミズヤエカベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市高清水福塚', '04', '04213', '9872003', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '高清水福塚', 'タカシミズフクツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市高清水浦南沢', '04', '04213', '9872004', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '高清水浦南沢', 'タカシミズウラミナミサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市高清水忽滑沢', '04', '04213', '9872005', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '高清水忽滑沢', 'タカシミズヌカリサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市高清水京の沢', '04', '04213', '9872011', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '高清水京の沢', 'タカシミズキョウノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市高清水中の沢', '04', '04213', '9872012', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '高清水中の沢', 'タカシミズナカノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市高清水欠屋敷', '04', '04213', '9872013', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '高清水欠屋敷', 'タカシミズカケヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市高清水大沢', '04', '04213', '9872014', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '高清水大沢', 'タカシミズオオサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市高清水西中里', '04', '04213', '9872015', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '高清水西中里', 'タカシミズニシナカザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市高清水茂路具多', '04', '04213', '9872016', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '高清水茂路具多', 'タカシミズモログタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市高清水石沢', '04', '04213', '9872017', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '高清水石沢', 'タカシミズイシザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市高清水石沢浦', '04', '04213', '9872018', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '高清水石沢浦', 'タカシミズイシザワウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市高清水神原', '04', '04213', '9872021', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '高清水神原', 'タカシミズカンパラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市高清水原', '04', '04213', '9872022', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '高清水原', 'タカシミズハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市高清水熊野堂', '04', '04213', '9872023', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '高清水熊野堂', 'タカシミズクマノドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市高清水小山田', '04', '04213', '9872024', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '高清水小山田', 'タカシミズオヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市高清水大西', '04', '04213', '9872025', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '高清水大西', 'タカシミズオオニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市高清水熊野', '04', '04213', '9872026', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '高清水熊野', 'タカシミズクマノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市高清水若宮', '04', '04213', '9872027', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '高清水若宮', 'タカシミズワカミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市高清水日向', '04', '04213', '9872028', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '高清水日向', 'タカシミズヒナタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市高清水新田', '04', '04213', '9872031', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '高清水新田', 'タカシミズシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市高清水横手', '04', '04213', '9872032', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '高清水横手', 'タカシミズヨコテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市高清水浅野', '04', '04213', '9872033', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '高清水浅野', 'タカシミズアザノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市高清水明官', '04', '04213', '9872034', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '高清水明官', 'タカシミズミョウカン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市高清水浅野前', '04', '04213', '9872035', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '高清水浅野前', 'タカシミズアザノマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市高清水南沢', '04', '04213', '9872036', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '高清水南沢', 'タカシミズミナミサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市高清水要の森', '04', '04213', '9872041', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '高清水要の森', 'タカシミズヨウノモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市高清水宿の沢', '04', '04213', '9872042', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '高清水宿の沢', 'タカシミズシュクノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市高清水手取', '04', '04213', '9872043', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '高清水手取', 'タカシミズテドリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市高清水堤下', '04', '04213', '9872044', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '高清水堤下', 'タカシミズツツミシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市高清水西手取', '04', '04213', '9872045', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '高清水西手取', 'タカシミズニシテトリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市高清水三森', '04', '04213', '9872051', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '高清水三森', 'タカシミズミモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市高清水宮脇', '04', '04213', '9872052', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '高清水宮脇', 'タカシミズミヤノワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市高清水渕際', '04', '04213', '9872053', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '高清水渕際', 'タカシミズフチギワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市高清水沖', '04', '04213', '9872054', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '高清水沖', 'タカシミズオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市高清水五月田', '04', '04213', '9872055', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '高清水五月田', 'タカシミズサツキダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市高清水影の沢', '04', '04213', '9872111', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '高清水影の沢', 'タカシミズカゲノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市高清水上折木', '04', '04213', '9872112', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '高清水上折木', 'タカシミズカミオリキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市高清水折木', '04', '04213', '9872113', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '高清水折木', 'タカシミズオリキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市高清水下折木', '04', '04213', '9872114', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '高清水下折木', 'タカシミズシモオリキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市高清水一本松', '04', '04213', '9872115', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '高清水一本松', 'タカシミズイッポンマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市高清水来光沢', '04', '04213', '9872116', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '高清水来光沢', 'タカシミズライコウザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市高清水上佐野', '04', '04213', '9872121', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '高清水上佐野', 'タカシミズカミサノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市高清水中佐野', '04', '04213', '9872122', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '高清水中佐野', 'タカシミズナカサノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市高清水新佐野', '04', '04213', '9872123', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '高清水新佐野', 'タカシミズシンサノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市高清水下佐野', '04', '04213', '9872124', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '高清水下佐野', 'タカシミズシモサノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市高清水十二の神', '04', '04213', '9872125', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '高清水十二の神', 'タカシミズジュウニノカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市高清水大寺', '04', '04213', '9872126', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '高清水大寺', 'タカシミズダイテラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市高清水佐野沢田', '04', '04213', '9872127', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '高清水佐野沢田', 'タカシミズサノサワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市高清水太子堂', '04', '04213', '9872127', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '高清水太子堂', 'タカシミズタイシドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市高清水佐野丁', '04', '04213', '9872128', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '高清水佐野丁', 'タカシミズサノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市高清水水の手', '04', '04213', '9872131', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '高清水水の手', 'タカシミズミズノテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市高清水東館', '04', '04213', '9872132', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '高清水東館', 'タカシミズヒガシタテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市高清水桜丁', '04', '04213', '9872133', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '高清水桜丁', 'タカシミズサクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市高清水上外沢田', '04', '04213', '9872141', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '高清水上外沢田', 'タカシミズカミソトサワタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市高清水北甚六原', '04', '04213', '9872141', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '高清水北甚六原', 'タカシミズキタジンロクハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市高清水外沢田', '04', '04213', '9872142', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '高清水外沢田', 'タカシミズソトサワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市高清水覚満寺', '04', '04213', '9872143', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '高清水覚満寺', 'タカシミズカクマンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市高清水台町', '04', '04213', '9872144', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '高清水台町', 'タカシミズダイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市高清水向野', '04', '04213', '9872145', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '高清水向野', 'タカシミズムカイノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市高清水乙牧堀', '04', '04213', '9872146', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '高清水乙牧堀', 'タカシミズオツマキボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市高清水甲牧堀', '04', '04213', '9872146', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '高清水甲牧堀', 'タカシミズコウマキボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市高清水丁牧堀', '04', '04213', '9872146', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '高清水丁牧堀', 'タカシミズテイマキボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市高清水丙牧堀', '04', '04213', '9872146', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '高清水丙牧堀', 'タカシミズヘイマキボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市高清水観音沢', '04', '04213', '9872147', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '高清水観音沢', 'タカシミズカンノンザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市高清水観音堂', '04', '04213', '9872147', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '高清水観音堂', 'タカシミズカンノンドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市高清水東浦', '04', '04213', '9872151', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '高清水東浦', 'タカシミズヒガシウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市高清水仰ケ返り', '04', '04213', '9872151', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '高清水仰ケ返り', 'タカシミズムケガエリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市高清水天王沢', '04', '04213', '9872152', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '高清水天王沢', 'タカシミズテンノウサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市高清水北原', '04', '04213', '9872153', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '高清水北原', 'タカシミズキタハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市高清水南原', '04', '04213', '9872154', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '高清水南原', 'タカシミズミナミハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市高清水萱刈', '04', '04213', '9872155', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '高清水萱刈', 'タカシミズカヤカリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市高清水千神', '04', '04213', '9872156', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '高清水千神', 'タカシミズセンガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市高清水中の茎', '04', '04213', '9872157', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '高清水中の茎', 'タカシミズナカノクキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市高清水上萩田', '04', '04213', '9872158', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '高清水上萩田', 'タカシミズカミハギタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市高清水新中の茎', '04', '04213', '9872158', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '高清水新中の茎', 'タカシミズシンナカノクキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市高清水本道', '04', '04213', '9872158', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '高清水本道', 'タカシミズモトミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市高清水松の木沢田', '04', '04213', '9872159', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '高清水松の木沢田', 'タカシミズマツノキサワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市高清水神明', '04', '04213', '9872161', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '高清水神明', 'タカシミズシンメイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市高清水丁神明', '04', '04213', '9872162', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '高清水丁神明', 'タカシミズテイシンメイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市高清水勝負ケ町', '04', '04213', '9872163', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '高清水勝負ケ町', 'タカシミズショウブガマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市高清水新神明', '04', '04213', '9872164', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '高清水新神明', 'タカシミズシンシンメイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市高清水長福寺', '04', '04213', '9872171', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '高清水長福寺', 'タカシミズチョウフクジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市高清水松原', '04', '04213', '9872172', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '高清水松原', 'タカシミズマツバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市高清水桂葉', '04', '04213', '9872173', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '高清水桂葉', 'タカシミズカツラハ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市高清水上桂葉', '04', '04213', '9872174', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '高清水上桂葉', 'タカシミズカミカツラハ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市高清水五輪', '04', '04213', '9872175', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '高清水五輪', 'タカシミズゴリン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市高清水西善光寺', '04', '04213', '9872176', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '高清水西善光寺', 'タカシミズニシゼンコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市高清水新桂葉', '04', '04213', '9872177', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '高清水新桂葉', 'タカシミズシンカツラハ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市高清水東善光寺', '04', '04213', '9872181', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '高清水東善光寺', 'タカシミズヒガシゼンコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市高清水中里', '04', '04213', '9872182', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '高清水中里', 'タカシミズナカザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市高清水袖山', '04', '04213', '9872183', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '高清水袖山', 'タカシミズソデヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市高清水善光寺', '04', '04213', '9872184', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '高清水善光寺', 'タカシミズゼンコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市高清水新町', '04', '04213', '9872185', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '高清水新町', 'タカシミズアラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市高清水中町', '04', '04213', '9872186', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '高清水中町', 'タカシミズナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市高清水本町', '04', '04213', '9872187', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '高清水本町', 'タカシミズモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市高清水小山下', '04', '04213', '9872188', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '高清水小山下', 'タカシミズオヤマシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市高清水下町', '04', '04213', '9872189', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '高清水下町', 'タカシミズシタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市', '04', '04213', '9872200', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('142560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市築館富', '04', '04213', '9872201', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '築館富', 'ツキダテトミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市築館城生野', '04', '04213', '9872202', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '築館城生野', 'ツキダテジョウノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市築館下宮野', '04', '04213', '9872203', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '築館下宮野', 'ツキダテシモミヤノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市築館黒瀬', '04', '04213', '9872204', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '築館黒瀬', 'ツキダテクロセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市築館宮野中央', '04', '04213', '9872205', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '築館宮野中央', 'ツキダテミヤノチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市築館源光', '04', '04213', '9872211', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '築館源光', 'ツキダテゲンコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市築館木戸', '04', '04213', '9872212', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '築館木戸', 'ツキダテキド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市築館内南沢', '04', '04213', '9872213', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '築館内南沢', 'ツキダテウチミナミザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市築館内沢', '04', '04213', '9872214', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '築館内沢', 'ツキダテウチサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市築館高田', '04', '04213', '9872215', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '築館高田', 'ツキダテタカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市築館伊豆', '04', '04213', '9872216', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '築館伊豆', 'ツキダテイズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市築館下待井', '04', '04213', '9872221', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '築館下待井', 'ツキダテシモマチイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市築館外南沢', '04', '04213', '9872222', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '築館外南沢', 'ツキダテソトミナミザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市築館萩沢', '04', '04213', '9872223', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '築館萩沢', 'ツキダテハギサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市築館横須賀', '04', '04213', '9872224', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '築館横須賀', 'ツキダテヨコスカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市築館太田', '04', '04213', '9872225', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '築館太田', 'ツキダテオオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市築館八沢', '04', '04213', '9872226', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '築館八沢', 'ツキダテヤサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市築館光屋敷', '04', '04213', '9872227', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '築館光屋敷', 'ツキダテヒカリヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市築館川添', '04', '04213', '9872228', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '築館川添', 'ツキダテカワゾエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市築館赤坂', '04', '04213', '9872231', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '築館赤坂', 'ツキダテアカサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市築館沢入', '04', '04213', '9872232', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '築館沢入', 'ツキダテサワイリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市築館照越', '04', '04213', '9872233', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '築館照越', 'ツキダテテルコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市築館新八ツ沢', '04', '04213', '9872234', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '築館新八ツ沢', 'ツキダテシンヤツザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市築館築館', '04', '04213', '9872235', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '築館築館', 'ツキダテツキダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市築館蟹沢', '04', '04213', '9872236', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '築館蟹沢', 'ツキダテカニサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市築館館下', '04', '04213', '9872241', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '築館館下', 'ツキダテタテシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市築館館沢', '04', '04213', '9872242', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '築館館沢', 'ツキダテタテサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市築館萩沢東', '04', '04213', '9872243', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '築館萩沢東', 'ツキダテハギサワヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市築館萩沢南', '04', '04213', '9872243', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '築館萩沢南', 'ツキダテハギサワミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市築館西小山', '04', '04213', '9872244', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '築館西小山', 'ツキダテニシコヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市築館荒田沢', '04', '04213', '9872245', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '築館荒田沢', 'ツキダテアラタザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市築館上高森', '04', '04213', '9872246', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '築館上高森', 'ツキダテカミタカモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市築館下高森', '04', '04213', '9872247', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '築館下高森', 'ツキダテシモタカモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市築館藤木', '04', '04213', '9872251', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '築館藤木', 'ツキダテフジキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市築館薬師', '04', '04213', '9872252', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '築館薬師', 'ツキダテヤクシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市築館青野', '04', '04213', '9872253', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '築館青野', 'ツキダテアオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市築館久伝', '04', '04213', '9872261', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '築館久伝', 'ツキダテキュウデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市築館唐竹林', '04', '04213', '9872262', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '築館唐竹林', 'ツキダテカラタケバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市築館新田', '04', '04213', '9872263', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '築館新田', 'ツキダテシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市築館薬師ケ丘', '04', '04213', '9872263', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '築館薬師ケ丘', 'ツキダテヤクシガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市築館薬師台', '04', '04213', '9872264', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '築館薬師台', 'ツキダテヤクシダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市築館小淵西', '04', '04213', '9872265', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '築館小淵西', 'ツキダテコブチニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市築館小淵東', '04', '04213', '9872265', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '築館小淵東', 'ツキダテコブチヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市築館境田', '04', '04213', '9872265', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '築館境田', 'ツキダテサカイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市築館佐野原', '04', '04213', '9872265', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '築館佐野原', 'ツキダテサノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市築館芋埣', '04', '04213', '9872271', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '築館芋埣', 'ツキダテイモゾネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市築館留場', '04', '04213', '9872272', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '築館留場', 'ツキダテトメバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市築館左足', '04', '04213', '9872273', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '築館左足', 'ツキダテコエダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市築館新成田西', '04', '04213', '9872274', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '築館新成田西', 'ツキダテシンナリタニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市築館成田', '04', '04213', '9872274', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '築館成田', 'ツキダテナリタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市築館上宮野', '04', '04213', '9872275', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '築館上宮野', 'ツキダテカミミヤノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市一迫大川口', '04', '04213', '9872301', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '一迫大川口', 'イチハサマオオカワグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市一迫片子沢', '04', '04213', '9872302', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '一迫片子沢', 'イチハサマカタゴザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市一迫川口', '04', '04213', '9872303', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '一迫川口', 'イチハサマカワグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市一迫北沢', '04', '04213', '9872304', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '一迫北沢', 'イチハサマキタザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市一迫狐崎', '04', '04213', '9872305', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '一迫狐崎', 'イチハサマキツネザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市一迫嶋躰', '04', '04213', '9872306', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '一迫嶋躰', 'イチハサマシマタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市一迫清水目', '04', '04213', '9872307', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '一迫清水目', 'イチハサマスズノメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市一迫真坂', '04', '04213', '9872308', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '一迫真坂', 'イチハサママサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市一迫柳目', '04', '04213', '9872309', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '一迫柳目', 'イチハサマヤナギノメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市一迫御崎', '04', '04213', '9872311', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '一迫御崎', 'イチハサマミサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市一迫沖浦', '04', '04213', '9872312', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '一迫沖浦', 'イチハサマオキウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市一迫沖', '04', '04213', '9872313', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '一迫沖', 'イチハサマオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市一迫岡田', '04', '04213', '9872314', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '一迫岡田', 'イチハサマオカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市一迫間杭元', '04', '04213', '9872315', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '一迫間杭元', 'イチハサマケングイモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市一迫小坂本', '04', '04213', '9872316', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '一迫小坂本', 'イチハサマコサカモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市一迫久保田', '04', '04213', '9872317', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '一迫久保田', 'イチハサマクボタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市一迫松の木', '04', '04213', '9872318', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '一迫松の木', 'イチハサママツノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市一迫宮前', '04', '04213', '9872319', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '一迫宮前', 'イチハサマミヤマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市一迫横町', '04', '04213', '9872321', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '一迫横町', 'イチハサマヨコマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市一迫横町浦', '04', '04213', '9872322', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '一迫横町浦', 'イチハサマヨコマチウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市一迫女子町', '04', '04213', '9872323', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '一迫女子町', 'イチハサマメゴマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市一迫三嶋', '04', '04213', '9872324', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '一迫三嶋', 'イチハサマミシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市一迫坂下西', '04', '04213', '9872325', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '一迫坂下西', 'イチハサマサカシタニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市一迫山崎', '04', '04213', '9872326', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '一迫山崎', 'イチハサマヤマザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市一迫天神', '04', '04213', '9872327', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '一迫天神', 'イチハサマテンジン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市一迫土川', '04', '04213', '9872328', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '一迫土川', 'イチハサマツチカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市一迫細越', '04', '04213', '9872329', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '一迫細越', 'イチハサマホソゴエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市一迫萩生', '04', '04213', '9872331', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '一迫萩生', 'イチハサマハギウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市一迫高橋', '04', '04213', '9872332', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '一迫高橋', 'イチハサマタカハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市一迫要害', '04', '04213', '9872333', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '一迫要害', 'イチハサマヨウガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市一迫神山', '04', '04213', '9872334', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '一迫神山', 'イチハサマシンザン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市一迫高田', '04', '04213', '9872335', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '一迫高田', 'イチハサマタカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市一迫荒屋敷', '04', '04213', '9872336', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '一迫荒屋敷', 'イチハサマアラヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市一迫松原沢', '04', '04213', '9872337', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '一迫松原沢', 'イチハサママツバラザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市一迫日向', '04', '04213', '9872338', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '一迫日向', 'イチハサマヒナタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市一迫上中島', '04', '04213', '9872339', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '一迫上中島', 'イチハサマカミナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市一迫中屋敷浦', '04', '04213', '9872341', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '一迫中屋敷浦', 'イチハサマナカヤシキウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市一迫沢田', '04', '04213', '9872342', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '一迫沢田', 'イチハサマサワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市一迫一本杉', '04', '04213', '9872343', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '一迫一本杉', 'イチハサマイッポンスギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市一迫宮下', '04', '04213', '9872344', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '一迫宮下', 'イチハサマミヤジタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市一迫屋敷田', '04', '04213', '9872345', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '一迫屋敷田', 'イチハサマヤシキダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市一迫大清水', '04', '04213', '9872346', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '一迫大清水', 'イチハサマオオスズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市一迫平館', '04', '04213', '9872347', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '一迫平館', 'イチハサマヒラダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市一迫大平沢', '04', '04213', '9872348', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '一迫大平沢', 'イチハサマオオヒラサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市一迫大際', '04', '04213', '9872349', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '一迫大際', 'イチハサマダイギワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市一迫宇南田', '04', '04213', '9872351', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '一迫宇南田', 'イチハサマウナンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市一迫鹿込', '04', '04213', '9872352', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '一迫鹿込', 'イチハサマシシゴメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市一迫上久保', '04', '04213', '9872353', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '一迫上久保', 'イチハサマカミクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市一迫西風', '04', '04213', '9872354', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '一迫西風', 'イチハサマナライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市一迫鍛冶屋敷', '04', '04213', '9872355', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '一迫鍛冶屋敷', 'イチハサマカジヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市一迫山沢', '04', '04213', '9872356', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '一迫山沢', 'イチハサマヤマサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市一迫沼田', '04', '04213', '9872357', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '一迫沼田', 'イチハサマヌマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市一迫下小僧', '04', '04213', '9872358', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '一迫下小僧', 'イチハサマシモコゾウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市一迫佐野原', '04', '04213', '9872359', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '一迫佐野原', 'イチハサマサノバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市一迫中小僧', '04', '04213', '9872361', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '一迫中小僧', 'イチハサマナカコゾウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市一迫大栗', '04', '04213', '9872362', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '一迫大栗', 'イチハサマオオグリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市一迫佐野', '04', '04213', '9872363', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '一迫佐野', 'イチハサマサノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市一迫岩ケ沢', '04', '04213', '9872364', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '一迫岩ケ沢', 'イチハサマイワガサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市一迫新米', '04', '04213', '9872365', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '一迫新米', 'イチハサマシンマイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市一迫論田', '04', '04213', '9872366', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '一迫論田', 'イチハサマロンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市一迫上大土', '04', '04213', '9872367', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '一迫上大土', 'イチハサマカミオオド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市一迫下大土', '04', '04213', '9872368', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '一迫下大土', 'イチハサマシモオオド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市一迫荒町', '04', '04213', '9872369', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '一迫荒町', 'イチハサマアラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市一迫川台', '04', '04213', '9872371', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '一迫川台', 'イチハサマカワダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市一迫青木', '04', '04213', '9872372', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '一迫青木', 'イチハサマアオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市一迫不動西', '04', '04213', '9872373', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '一迫不動西', 'イチハサマフドウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市一迫清水原', '04', '04213', '9872374', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '一迫清水原', 'イチハサマシミズバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市花山本沢', '04', '04213', '9872511', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '花山本沢', 'ハナヤマホンサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市花山草木沢', '04', '04213', '9872512', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '花山草木沢', 'ハナヤマクサキサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市', '04', '04205', '9880000', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('142690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市東みなと町', '04', '04205', '9880001', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '東みなと町', 'ヒガシミナトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市錦町', '04', '04205', '9880002', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '錦町', 'ニシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市本浜町', '04', '04205', '9880003', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '本浜町', 'モトハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市浜町', '04', '04205', '9880004', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '浜町', 'ハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市新浜町', '04', '04205', '9880005', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '新浜町', 'シンハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市西みなと町', '04', '04205', '9880006', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '西みなと町', 'ニシミナトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市中みなと町', '04', '04205', '9880007', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '中みなと町', 'ナカミナトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市魚浜町', '04', '04205', '9880008', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '魚浜町', 'ウオハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市陣山', '04', '04205', '9880011', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '陣山', 'ジンヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市栄町', '04', '04205', '9880012', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '栄町', 'サカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市魚町', '04', '04205', '9880013', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '魚町', 'サカナマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市柏崎', '04', '04205', '9880014', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '柏崎', 'カシザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市浜見山', '04', '04205', '9880015', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '浜見山', 'ハマミヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市沢田', '04', '04205', '9880016', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '沢田', 'サワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市南町', '04', '04205', '9880017', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '南町', 'ミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市南町海岸', '04', '04205', '9880018', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '南町海岸', 'ミナミマチカイガン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市港町', '04', '04205', '9880021', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '港町', 'ミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市河原田', '04', '04205', '9880022', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '河原田', 'カワラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市南が丘', '04', '04205', '9880023', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '南が丘', 'ミナミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市仲町', '04', '04205', '9880024', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '仲町', 'ナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市内ノ脇', '04', '04205', '9880025', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '内ノ脇', 'ナイノワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市幸町', '04', '04205', '9880026', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市潮見町', '04', '04205', '9880031', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '潮見町', 'シオミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市一景島', '04', '04205', '9880032', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '一景島', 'イッケイジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市川口町', '04', '04205', '9880033', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '川口町', 'カワグチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市朝日町', '04', '04205', '9880034', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '朝日町', 'アサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市弁天町', '04', '04205', '9880036', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '弁天町', 'ベンテンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市魚市場前', '04', '04205', '9880037', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '魚市場前', 'ウオイチバマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市川畑', '04', '04205', '9880041', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '川畑', 'カワバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市本郷', '04', '04205', '9880042', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '本郷', 'ホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市南郷', '04', '04205', '9880043', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '南郷', 'ナンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市神山', '04', '04205', '9880044', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '神山', 'カミヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市田谷', '04', '04205', '9880045', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '田谷', 'タヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市田谷前', '04', '04205', '9880046', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '田谷前', 'タヤマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市常楽', '04', '04205', '9880051', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '常楽', 'ジョウラク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市田中', '04', '04205', '9880052', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '田中', 'タナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市田中前', '04', '04205', '9880053', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '田中前', 'タナカマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市駒場', '04', '04205', '9880054', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '駒場', 'コマバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市反松', '04', '04205', '9880055', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '反松', 'ソリマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市上田中', '04', '04205', '9880056', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '上田中', 'カミタナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市所沢', '04', '04205', '9880057', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '所沢', 'トコロザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市田中沖', '04', '04205', '9880058', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '田中沖', 'タナカオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市岩ケ崎', '04', '04205', '9880061', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '岩ケ崎', 'イワガサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市明戸', '04', '04205', '9880062', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '明戸', 'アケド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市四反田', '04', '04205', '9880063', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '四反田', 'シタンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市九条', '04', '04205', '9880064', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '九条', 'クジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市後九条', '04', '04205', '9880065', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '後九条', 'ウシロクジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市東新城', '04', '04205', '9880066', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '東新城', 'ヒガシシンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市新町', '04', '04205', '9880071', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '新町', 'アラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市化粧坂', '04', '04205', '9880072', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '化粧坂', 'ケショウザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市笹が陣', '04', '04205', '9880073', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '笹が陣', 'ササガジン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市本町', '04', '04205', '9880074', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '本町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市赤坂', '04', '04205', '9880075', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '赤坂', 'アカサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市舘山', '04', '04205', '9880076', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '舘山', 'タテヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市古町', '04', '04205', '9880077', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '古町', 'フルマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市蔵底', '04', '04205', '9880081', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '蔵底', 'クラソコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市太田', '04', '04205', '9880082', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '太田', 'オオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市入沢', '04', '04205', '9880083', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '入沢', 'イリサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市八日町', '04', '04205', '9880084', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '八日町', 'ヨウカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市三日町', '04', '04205', '9880085', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '三日町', 'ミッカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市福美町', '04', '04205', '9880086', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '福美町', 'フクミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市滝の入', '04', '04205', '9880087', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '滝の入', 'タキノイリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市赤岩舘下', '04', '04205', '9880101', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '赤岩舘下', 'アカイワタテシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市赤岩舘森', '04', '04205', '9880102', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '赤岩舘森', 'アカイワタテモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市赤岩港', '04', '04205', '9880103', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '赤岩港', 'アカイワミナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市赤岩五駄鱈', '04', '04205', '9880104', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '赤岩五駄鱈', 'アカイワゴダンタラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市赤岩老松', '04', '04205', '9880105', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '赤岩老松', 'アカイワオイノマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市松崎北沢', '04', '04205', '9880111', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '松崎北沢', 'マツザキキタサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市松崎前浜', '04', '04205', '9880112', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '松崎前浜', 'マツザキマエハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市松崎片浜', '04', '04205', '9880113', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '松崎片浜', 'マツザキカタハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市松崎浦田', '04', '04205', '9880114', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '松崎浦田', 'マツザキウラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市松崎萱', '04', '04205', '9880121', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '松崎萱', 'マツザキカヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市松崎五駄鱈', '04', '04205', '9880122', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '松崎五駄鱈', 'マツザキゴダンタラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市松崎中瀬', '04', '04205', '9880123', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '松崎中瀬', 'マツザキナカゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市松崎高谷', '04', '04205', '9880124', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '松崎高谷', 'マツザキタカヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市松崎尾崎', '04', '04205', '9880131', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '松崎尾崎', 'マツザキオサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市松崎馬場', '04', '04205', '9880132', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '松崎馬場', 'マツザキババ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市松崎下赤田', '04', '04205', '9880133', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '松崎下赤田', 'マツザキシモアカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市松崎上赤田', '04', '04205', '9880134', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '松崎上赤田', 'マツザキカミアカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市松崎柳沢', '04', '04205', '9880141', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '松崎柳沢', 'マツザキヤナギサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市松崎丸森', '04', '04205', '9880142', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '松崎丸森', 'マツザキマルモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市松崎地生', '04', '04205', '9880143', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '松崎地生', 'マツザキジショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市松崎鶴巻', '04', '04205', '9880144', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '松崎鶴巻', 'マツザキツルマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市松崎立石', '04', '04205', '9880151', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '松崎立石', 'マツザキタテイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市松崎外ケ沢', '04', '04205', '9880152', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '松崎外ケ沢', 'マツザキソトガサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市松崎面瀬', '04', '04205', '9880153', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '松崎面瀬', 'マツザキオモセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市松崎猫渕', '04', '04205', '9880154', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '松崎猫渕', 'マツザキネコブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市松崎大萱', '04', '04205', '9880155', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '松崎大萱', 'マツザキオオカヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市松崎下金取', '04', '04205', '9880156', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '松崎下金取', 'マツザキシモカネトリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市松崎上金取', '04', '04205', '9880157', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '松崎上金取', 'マツザキカミカネトリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市赤岩高前田', '04', '04205', '9880161', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '赤岩高前田', 'アカイワタカマエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市赤岩前田', '04', '04205', '9880162', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '赤岩前田', 'アカイワマエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市赤岩迎前田', '04', '04205', '9880163', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '赤岩迎前田', 'アカイワムカエマエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市赤岩四十二', '04', '04205', '9880164', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '赤岩四十二', 'アカイワシジュウニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市赤岩物見', '04', '04205', '9880165', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '赤岩物見', 'アカイワモノミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市赤岩上羽田', '04', '04205', '9880166', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '赤岩上羽田', 'アカイワカミハダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市赤岩羽田', '04', '04205', '9880167', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '赤岩羽田', 'アカイワハダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市赤岩水梨子', '04', '04205', '9880168', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '赤岩水梨子', 'アカイワミズナシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市物倉山', '04', '04205', '9880169', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '物倉山', 'モノクラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市赤岩牧沢', '04', '04205', '9880171', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '赤岩牧沢', 'アカイワマキサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市赤岩大石倉', '04', '04205', '9880172', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '赤岩大石倉', 'アカイワオオイシクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市赤岩長柴', '04', '04205', '9880173', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '赤岩長柴', 'アカイワナガシバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市赤岩大滝', '04', '04205', '9880174', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '赤岩大滝', 'アカイワオオタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市赤岩杉ノ沢', '04', '04205', '9880181', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '赤岩杉ノ沢', 'アカイワスギノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市赤岩石兜', '04', '04205', '9880182', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '赤岩石兜', 'アカイワイシカブト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市赤岩泥ノ木', '04', '04205', '9880183', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '赤岩泥ノ木', 'アカイワドロノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市赤岩平貝', '04', '04205', '9880184', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '赤岩平貝', 'アカイワヒラガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市赤岩小田', '04', '04205', '9880185', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '赤岩小田', 'アカイワオダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市岩月千岩田', '04', '04205', '9880201', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '岩月千岩田', 'イワツキセンガンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市岩月台ノ沢', '04', '04205', '9880202', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '岩月台ノ沢', 'イワツキダイノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市岩月星谷', '04', '04205', '9880203', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '岩月星谷', 'イワツキホシヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市岩月長平', '04', '04205', '9880204', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '岩月長平', 'イワツキナガダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市岩月箒沢', '04', '04205', '9880205', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '岩月箒沢', 'イワツキホウキサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市岩月寺沢', '04', '04205', '9880206', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '岩月寺沢', 'イワツキテラサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市岩月宝ケ沢', '04', '04205', '9880207', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '岩月宝ケ沢', 'イワツキタカラガサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市最知川原', '04', '04205', '9880211', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '最知川原', 'サイチカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市最知森合', '04', '04205', '9880212', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '最知森合', 'サイチモリアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市最知南最知', '04', '04205', '9880213', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '最知南最知', 'サイチミナミサイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市最知荒沢', '04', '04205', '9880214', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '最知荒沢', 'サイチアラサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市最知北最知', '04', '04205', '9880215', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '最知北最知', 'サイチキタサイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市長磯七半沢', '04', '04205', '9880221', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '長磯七半沢', 'ナガイソシチハンザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市長磯船原', '04', '04205', '9880222', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '長磯船原', 'ナガイソフナハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市長磯鳥子沢', '04', '04205', '9880223', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '長磯鳥子沢', 'ナガイソトリコザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市長磯前林', '04', '04205', '9880224', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '長磯前林', 'ナガイソマエバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市長磯大窪', '04', '04205', '9880225', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '長磯大窪', 'ナガイソオオクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市長磯後沢', '04', '04205', '9880226', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '長磯後沢', 'ナガイソウシロザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市長磯森', '04', '04205', '9880227', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '長磯森', 'ナガイソモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市長磯浜', '04', '04205', '9880231', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '長磯浜', 'ナガイソハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市長磯下原', '04', '04205', '9880232', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '長磯下原', 'ナガイソシモバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市長磯原', '04', '04205', '9880233', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '長磯原', 'ナガイソハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市長磯原ノ沢', '04', '04205', '9880234', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '長磯原ノ沢', 'ナガイソハラノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市長磯牧通', '04', '04205', '9880235', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '長磯牧通', 'ナガイソマギドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市長磯二本松', '04', '04205', '9880236', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '長磯二本松', 'ナガイソニホンマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市長磯赤貝', '04', '04205', '9880237', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '長磯赤貝', 'ナガイソアカガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市長磯中原', '04', '04205', '9880238', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '長磯中原', 'ナガイソナカハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市波路上岩井崎', '04', '04205', '9880241', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '波路上岩井崎', 'ハジカミイワイサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市波路上崎野', '04', '04205', '9880242', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '波路上崎野', 'ハジカミサキノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市波路上牧', '04', '04205', '9880243', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '波路上牧', 'ハジカミマギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市波路上明戸', '04', '04205', '9880244', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '波路上明戸', 'ハジカミアケド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市波路上杉ノ下', '04', '04205', '9880245', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '波路上杉ノ下', 'ハジカミスギノシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市波路上瀬向', '04', '04205', '9880246', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '波路上瀬向', 'ハジカミセムカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市波路上内沼', '04', '04205', '9880247', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '波路上内沼', 'ハジカミウチヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市波路上内田', '04', '04205', '9880251', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '波路上内田', 'ハジカミウチダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市波路上後原', '04', '04205', '9880252', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '波路上後原', 'ハジカミウシロバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市波路上原', '04', '04205', '9880253', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '波路上原', 'ハジカミハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市波路上野田', '04', '04205', '9880254', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '波路上野田', 'ハジカミノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市波路上向田', '04', '04205', '9880255', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '波路上向田', 'ハジカミムカイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市波路上向原', '04', '04205', '9880256', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '波路上向原', 'ハジカミムカイバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町後田', '04', '04603', '9880261', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', '後田', 'ウシロダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町直伝', '04', '04603', '9880261', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', '直伝', 'ジキデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町土樋下', '04', '04603', '9880261', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', '土樋下', 'ツチドイシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町沖の田', '04', '04603', '9880262', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', '沖の田', 'オキノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町洞沢', '04', '04603', '9880263', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', '洞沢', 'ホラサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町長根', '04', '04603', '9880264', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', '長根', 'ナガネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町窪', '04', '04603', '9880265', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', '窪', 'クボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町寺谷', '04', '04603', '9880266', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', '寺谷', 'テラガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町寺沢', '04', '04603', '9880267', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', '寺沢', 'テラサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町長畑', '04', '04603', '9880267', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', '長畑', 'ナガハタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町石川原', '04', '04603', '9880268', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', '石川原', 'イシカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町菖蒲沢', '04', '04603', '9880269', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', '菖蒲沢', 'ショウブザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町道貫', '04', '04603', '9880269', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', '道貫', 'ドウメキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町野々下', '04', '04603', '9880271', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', '野々下', 'ノノシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町大谷', '04', '04603', '9880272', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', '大谷', 'オオヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町三島', '04', '04603', '9880273', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', '三島', 'ミシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町滝根', '04', '04603', '9880274', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', '滝根', 'タキネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町九多丸', '04', '04603', '9880275', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', '九多丸', 'クダマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町日門', '04', '04603', '9880276', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', '日門', 'ヒカド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町天ケ沢', '04', '04603', '9880277', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', '天ケ沢', 'アマガサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町田の沢', '04', '04603', '9880277', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', '田の沢', 'タノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町高瀬ケ森', '04', '04603', '9880278', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', '高瀬ケ森', 'タカセガモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町山谷', '04', '04603', '9880278', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', '山谷', 'ヤマヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町猿内', '04', '04603', '9880279', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', '猿内', 'サルウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町府中', '04', '04603', '9880281', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', '府中', 'フチュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町前浜', '04', '04603', '9880282', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', '前浜', 'マエハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町大森', '04', '04603', '9880283', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', '大森', 'オオモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町谷地', '04', '04603', '9880283', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', '谷地', 'ヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町赤牛', '04', '04603', '9880284', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', '赤牛', 'アカウシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町小金沢', '04', '04603', '9880285', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', '小金沢', 'コガネザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町高', '04', '04603', '9880286', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', '高', 'タカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町大朴木', '04', '04603', '9880287', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', '大朴木', 'オオボウキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町', '04', '04603', '9880300', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('142871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町狼の巣', '04', '04603', '9880301', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', '狼の巣', 'オイノス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町林の沢', '04', '04603', '9880302', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', '林の沢', 'ハヤシノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町幸土', '04', '04603', '9880303', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', '幸土', 'コウド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町大沢', '04', '04603', '9880304', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', '大沢', 'オオサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町津谷長根', '04', '04603', '9880305', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', '津谷長根', 'ツヤナガネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町大椚', '04', '04603', '9880306', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', '大椚', 'オオクヌギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町津谷舘岡', '04', '04603', '9880307', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', '津谷舘岡', 'ツヤタテオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町津谷松岡', '04', '04603', '9880308', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', '津谷松岡', 'ツヤマツオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町津谷松尾', '04', '04603', '9880309', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', '津谷松尾', 'ツヤマツオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町風越', '04', '04603', '9880311', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', '風越', 'カザコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町道外', '04', '04603', '9880312', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', '道外', 'ミチソト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町卯名沢', '04', '04603', '9880313', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', '卯名沢', 'ウナザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町圃の沢', '04', '04603', '9880314', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', '圃の沢', 'ハタノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町新圃の沢', '04', '04603', '9880315', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', '新圃の沢', 'シンハタノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町新北明戸', '04', '04603', '9880316', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', '新北明戸', 'シンキタアケド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町北明戸', '04', '04603', '9880317', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', '北明戸', 'キタアケド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町登米沢', '04', '04603', '9880318', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', '登米沢', 'トヨマザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町小浜', '04', '04603', '9880321', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', '小浜', 'コハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町二十一浜', '04', '04603', '9880322', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', '二十一浜', 'ニジュウイチハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町今朝磯', '04', '04603', '9880323', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', '今朝磯', 'ケサイソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町歌生', '04', '04603', '9880324', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', '歌生', 'ウトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町蔵内', '04', '04603', '9880325', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', '蔵内', 'クラウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町柳沢', '04', '04603', '9880326', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', '柳沢', 'ヤナギサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町長窪', '04', '04603', '9880327', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', '長窪', 'ナガクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町菅の沢', '04', '04603', '9880328', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', '菅の沢', 'スゲノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町中島', '04', '04603', '9880331', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', '中島', 'ナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町下宿', '04', '04603', '9880332', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', '下宿', 'シモジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町平貝', '04', '04603', '9880333', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', '平貝', 'ヒラガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町外尾', '04', '04603', '9880334', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', '外尾', 'ソデオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町蕨野', '04', '04603', '9880335', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', '蕨野', 'ワラビノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町泉沢', '04', '04603', '9880336', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', '泉沢', 'イズミザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町新南明戸', '04', '04603', '9880337', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', '新南明戸', 'シンミナミアケド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町南明戸', '04', '04603', '9880338', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', '南明戸', 'ミナミアケド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町泉', '04', '04603', '9880339', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', '泉', 'イズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町津谷桜子', '04', '04603', '9880341', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', '津谷桜子', 'ツヤサクラゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町幣掛', '04', '04603', '9880342', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', '幣掛', 'ヌサカケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町松ケ沢', '04', '04603', '9880343', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', '松ケ沢', 'マツガサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町宮内', '04', '04603', '9880344', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', '宮内', 'ミヤウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町館下', '04', '04603', '9880345', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', '館下', 'タテシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町岳の下', '04', '04603', '9880346', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', '岳の下', 'タケノシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町猪の鼻', '04', '04603', '9880347', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', '猪の鼻', 'イノハナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町小峰崎', '04', '04603', '9880348', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', '小峰崎', 'コミネザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町午王野沢', '04', '04603', '9880351', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', '午王野沢', 'ゴオウノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町平椚', '04', '04603', '9880352', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', '平椚', 'タイラクヌギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町信夫', '04', '04603', '9880353', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', '信夫', 'シノブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町鹿の子', '04', '04603', '9880354', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', '鹿の子', 'カノコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町滝沢', '04', '04603', '9880355', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', '滝沢', 'タキサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町大柴', '04', '04603', '9880356', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', '大柴', 'オオシバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町中平', '04', '04603', '9880357', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', '中平', 'ナカダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町大東', '04', '04603', '9880358', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', '大東', 'オオヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町上野', '04', '04603', '9880359', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', '上野', 'ワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町下要害', '04', '04603', '9880361', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', '下要害', 'シモヨウガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町寺要害', '04', '04603', '9880362', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', '寺要害', 'テラヨウガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町深萩', '04', '04603', '9880363', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', '深萩', 'フカハギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町小金山', '04', '04603', '9880364', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', '小金山', 'コガネヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町馬籠町', '04', '04603', '9880365', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', '馬籠町', 'マゴメマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町馬籠町頭', '04', '04603', '9880366', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', '馬籠町頭', 'マゴメマチカシラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町向畑', '04', '04603', '9880367', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', '向畑', 'ムカイバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町漆原', '04', '04603', '9880371', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', '漆原', 'ウルシバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町尾田', '04', '04603', '9880372', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', '尾田', 'オデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町狩猟', '04', '04603', '9880373', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', '狩猟', 'カリョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町角柄', '04', '04603', '9880374', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', '角柄', 'ツノガラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町中沢', '04', '04603', '9880375', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', '中沢', 'ナカザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町津谷新明戸', '04', '04603', '9880381', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', '津谷新明戸', 'ツヤシンアケド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町津谷明戸', '04', '04603', '9880382', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', '津谷明戸', 'ツヤアケド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町坊の倉', '04', '04603', '9880383', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', '坊の倉', 'ボウノクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町高岡', '04', '04603', '9880384', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', '高岡', 'タカオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町下川内', '04', '04603', '9880385', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', '下川内', 'シモカワウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町西川内', '04', '04603', '9880386', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', '西川内', 'ニシカワウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町中川内', '04', '04603', '9880387', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', '中川内', 'ナカカワウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町上川内', '04', '04603', '9880388', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', '上川内', 'カミカワウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡本吉町東川内', '04', '04603', '9880389', '宮城県', 'ミヤギケン', '本吉郡本吉町', 'モトヨシグンモトヨシチョウ', '東川内', 'ヒガシカワウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町歌津浪板', '04', '04606', '9880401', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '歌津浪板', 'ウタツナミイタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町歌津港', '04', '04606', '9880402', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '歌津港', 'ウタツミナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町歌津長羽', '04', '04606', '9880403', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '歌津長羽', 'ウタツナガハ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町歌津牧田', '04', '04606', '9880404', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '歌津牧田', 'ウタツマキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町歌津草木沢', '04', '04606', '9880405', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '歌津草木沢', 'ウタツクサキザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町歌津中野', '04', '04606', '9880406', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '歌津中野', 'ウタツナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町歌津田茂川', '04', '04606', '9880411', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '歌津田茂川', 'ウタツタモガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町歌津南の沢', '04', '04606', '9880412', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '歌津南の沢', 'ウタツミナミノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町歌津上の山', '04', '04606', '9880413', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '歌津上の山', 'ウタツカミノヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町歌津長沢', '04', '04606', '9880414', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '歌津長沢', 'ウタツナガサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町歌津田の浦', '04', '04606', '9880415', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '歌津田の浦', 'ウタツタノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町歌津平棚', '04', '04606', '9880421', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '歌津平棚', 'ウタツヒラダナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町歌津松の崎', '04', '04606', '9880422', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '歌津松の崎', 'ウタツマツノサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町歌津枡沢', '04', '04606', '9880423', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '歌津枡沢', 'ウタツマスザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町歌津北の沢', '04', '04606', '9880424', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '歌津北の沢', 'ウタツキタノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町歌津神山', '04', '04606', '9880425', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '歌津神山', 'ウタツカミヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町歌津石浜', '04', '04606', '9880426', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '歌津石浜', 'ウタツイシハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町歌津名足', '04', '04606', '9880431', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '歌津名足', 'ウタツナタリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町歌津中山', '04', '04606', '9880432', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '歌津中山', 'ウタツナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町歌津馬場', '04', '04606', '9880433', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '歌津馬場', 'ウタツババ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町歌津大磯', '04', '04606', '9880434', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '歌津大磯', 'ウタツオオイソ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町歌津小沼', '04', '04606', '9880435', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '歌津小沼', 'ウタツコヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町歌津小長柴', '04', '04606', '9880436', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '歌津小長柴', 'ウタツコナガシバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町歌津田の頭', '04', '04606', '9880441', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '歌津田の頭', 'ウタツタノガシラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町歌津番所', '04', '04606', '9880442', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '歌津番所', 'ウタツバンドコロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町歌津尾崎', '04', '04606', '9880443', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '歌津尾崎', 'ウタツオサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町歌津泊浜', '04', '04606', '9880444', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '歌津泊浜', 'ウタツトマリハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町歌津館浜', '04', '04606', '9880445', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '歌津館浜', 'ウタツタテハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町歌津板橋', '04', '04606', '9880446', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '歌津板橋', 'ウタツイタバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町歌津長柴', '04', '04606', '9880447', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '歌津長柴', 'ウタツナガシバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町歌津大沼', '04', '04606', '9880448', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '歌津大沼', 'ウタツオオヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町歌津管の浜', '04', '04606', '9880451', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '歌津管の浜', 'ウタツクダノハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町歌津町向', '04', '04606', '9880452', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '歌津町向', 'ウタツマチムカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町歌津伊里前', '04', '04606', '9880453', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '歌津伊里前', 'ウタツイサトマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町歌津峰畑', '04', '04606', '9880454', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '歌津峰畑', 'ウタツミネハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町歌津吉野沢', '04', '04606', '9880455', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '歌津吉野沢', 'ウタツヨシノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町歌津川内', '04', '04606', '9880456', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '歌津川内', 'ウタツカワウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町歌津寄木', '04', '04606', '9880461', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '歌津寄木', 'ウタツヨリキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町歌津砂浜', '04', '04606', '9880462', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '歌津砂浜', 'ウタツスナハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町歌津大森', '04', '04606', '9880463', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '歌津大森', 'ウタツオオモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町歌津森畑', '04', '04606', '9880464', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '歌津森畑', 'ウタツモリハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町歌津韮の浜', '04', '04606', '9880465', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '歌津韮の浜', 'ウタツニラノハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町歌津平松', '04', '04606', '9880466', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '歌津平松', 'ウタツヒラマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町歌津皿貝', '04', '04606', '9880467', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '歌津皿貝', 'ウタツサラガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町歌津石泉', '04', '04606', '9880471', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '歌津石泉', 'ウタツイシズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町歌津宮方', '04', '04606', '9880472', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '歌津宮方', 'ウタツミヤカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町歌津中在', '04', '04606', '9880473', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '歌津中在', 'ウタツナカザイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町歌津田表', '04', '04606', '9880474', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '歌津田表', 'ウタツタオモテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町歌津白山', '04', '04606', '9880475', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '歌津白山', 'ウタツシラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町歌津上沢', '04', '04606', '9880476', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '歌津上沢', 'ウタツカミサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町歌津払川', '04', '04606', '9880477', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '歌津払川', 'ウタツハライカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県本吉郡南三陸町歌津樋の口', '04', '04606', '9880478', '宮城県', 'ミヤギケン', '本吉郡南三陸町', 'モトヨシグンミナミサンリクチョウ', '歌津樋の口', 'ウタツヒノクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市唐桑町釜石下', '04', '04205', '9880501', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '唐桑町釜石下', 'カラクワチョウカマイシシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市唐桑町台の下', '04', '04205', '9880502', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '唐桑町台の下', 'カラクワチョウダイノシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市唐桑町荒谷前', '04', '04205', '9880503', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '唐桑町荒谷前', 'カラクワチョウアラヤマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('142999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市唐桑町竹の袖', '04', '04205', '9880504', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '唐桑町竹の袖', 'カラクワチョウタケノソデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市唐桑町港', '04', '04205', '9880505', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '唐桑町港', 'カラクワチョウミナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市唐桑町出山', '04', '04205', '9880506', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '唐桑町出山', 'カラクワチョウデヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市唐桑町舘', '04', '04205', '9880511', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '唐桑町舘', 'カラクワチョウタテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市唐桑町岩井沢', '04', '04205', '9880512', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '唐桑町岩井沢', 'カラクワチョウイワイサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市唐桑町載鈎', '04', '04205', '9880513', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '唐桑町載鈎', 'カラクワチョウノセカギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市唐桑町小田', '04', '04205', '9880514', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '唐桑町小田', 'カラクワチョウコダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市唐桑町大畑', '04', '04205', '9880521', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '唐桑町大畑', 'カラクワチョウオオハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市唐桑町上川原', '04', '04205', '9880522', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '唐桑町上川原', 'カラクワチョウカミカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市唐桑町境', '04', '04205', '9880523', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '唐桑町境', 'カラクワチョウサカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市唐桑町只越', '04', '04205', '9880524', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '唐桑町只越', 'カラクワチョウタダコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市唐桑町堂角', '04', '04205', '9880525', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '唐桑町堂角', 'カラクワチョウドウカク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市唐桑町唯越', '04', '04205', '9880526', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '唐桑町唯越', 'カラクワチョウタダコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市唐桑町西舞根', '04', '04205', '9880527', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '唐桑町西舞根', 'カラクワチョウニシモウネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市唐桑町高石浜', '04', '04205', '9880531', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '唐桑町高石浜', 'カラクワチョウタカイシハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市唐桑町石浜', '04', '04205', '9880532', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '唐桑町石浜', 'カラクワチョウイシハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市唐桑町明戸', '04', '04205', '9880533', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '唐桑町明戸', 'カラクワチョウアケド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市唐桑町宿浦', '04', '04205', '9880534', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '唐桑町宿浦', 'カラクワチョウシュクウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市唐桑町馬場', '04', '04205', '9880535', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '唐桑町馬場', 'カラクワチョウババ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市唐桑町北中', '04', '04205', '9880541', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '唐桑町北中', 'カラクワチョウキタナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市唐桑町中', '04', '04205', '9880542', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '唐桑町中', 'カラクワチョウナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市唐桑町小長根', '04', '04205', '9880543', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '唐桑町小長根', 'カラクワチョウコナガネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市唐桑町欠浜', '04', '04205', '9880544', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '唐桑町欠浜', 'カラクワチョウカケハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市唐桑町松圃', '04', '04205', '9880551', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '唐桑町松圃', 'カラクワチョウマツバタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市唐桑町津本', '04', '04205', '9880552', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '唐桑町津本', 'カラクワチョウツモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市唐桑町神の倉', '04', '04205', '9880553', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '唐桑町神の倉', 'カラクワチョウカンノクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市唐桑町崎浜', '04', '04205', '9880554', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '唐桑町崎浜', 'カラクワチョウサキハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市唐桑町小鯖', '04', '04205', '9880561', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '唐桑町小鯖', 'カラクワチョウコサバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市唐桑町上小鯖', '04', '04205', '9880562', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '唐桑町上小鯖', 'カラクワチョウカミコサバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市唐桑町中井', '04', '04205', '9880563', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '唐桑町中井', 'カラクワチョウナカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市唐桑町鮪立', '04', '04205', '9880571', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '唐桑町鮪立', 'カラクワチョウシビタチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市唐桑町上鮪立', '04', '04205', '9880572', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '唐桑町上鮪立', 'カラクワチョウカミシビタチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市唐桑町浦', '04', '04205', '9880581', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '唐桑町浦', 'カラクワチョウウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市唐桑町東舞根', '04', '04205', '9880582', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '唐桑町東舞根', 'カラクワチョウヒガシモウネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市外浜', '04', '04205', '9880601', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '外浜', 'ソトハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市大初平', '04', '04205', '9880602', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '大初平', 'オオハツダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市外畑', '04', '04205', '9880603', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '外畑', 'ソトバタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市廻舘', '04', '04205', '9880604', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '廻舘', 'マワリダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市浦の浜', '04', '04205', '9880605', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '浦の浜', 'ウラノハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市磯草', '04', '04205', '9880606', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '磯草', 'イソクサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市亀山', '04', '04205', '9880607', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '亀山', 'カメヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市田尻', '04', '04205', '9880611', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '田尻', 'タジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市大向', '04', '04205', '9880612', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '大向', 'オオムカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市高井', '04', '04205', '9880613', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '高井', 'タカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市長崎', '04', '04205', '9880621', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '長崎', 'ナガサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市中山', '04', '04205', '9880622', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '中山', 'ナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市浅根', '04', '04205', '9880623', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '浅根', 'アサネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市三作浜', '04', '04205', '9880631', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '三作浜', 'ミサクハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市横沼', '04', '04205', '9880632', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '横沼', 'ヨコヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市駒形', '04', '04205', '9880633', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '駒形', 'コマガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市要害', '04', '04205', '9880634', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '要害', 'ヨウガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市上東側根', '04', '04205', '9880801', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '上東側根', 'カミヒガシガワネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市高判形山', '04', '04205', '9880802', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '高判形山', 'タカハンギョウヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市日ノ口', '04', '04205', '9880802', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '日ノ口', 'ヒノクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市上東側', '04', '04205', '9880803', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '上東側', 'カミヒガシガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市東中才', '04', '04205', '9880804', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '東中才', 'ヒガシナカサイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市西中才', '04', '04205', '9880805', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '西中才', 'ニシナカサイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市上西側', '04', '04205', '9880806', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '上西側', 'カミニシガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市白石', '04', '04205', '9880807', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '白石', 'シライシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市東八幡前', '04', '04205', '9880811', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '東八幡前', 'ヒガシハチマンマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市大岩井山', '04', '04205', '9880812', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '大岩井山', 'オオイワイヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市大峠山', '04', '04205', '9880812', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '大峠山', 'オオトウゲヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市浪板', '04', '04205', '9880813', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '浪板', 'ナミイタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市大浦', '04', '04205', '9880814', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '大浦', 'オオウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市小々汐', '04', '04205', '9880815', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '小々汐', 'コゴシオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市二ノ浜', '04', '04205', '9880816', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '二ノ浜', 'ニノハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市西八幡町', '04', '04205', '9880817', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '西八幡町', 'ニシハチマンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市西八幡前', '04', '04205', '9880817', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '西八幡前', 'ニシハチマンマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市三ノ浜', '04', '04205', '9880818', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '三ノ浜', 'サンノハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市大林', '04', '04205', '9880821', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '大林', 'オオバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市切通', '04', '04205', '9880822', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '切通', 'キリドオシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市茗荷沢', '04', '04205', '9880823', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '茗荷沢', 'ミョウガサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市川原崎', '04', '04205', '9880824', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '川原崎', 'カワラザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市田尻沢', '04', '04205', '9880825', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '田尻沢', 'タジリザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市百目木', '04', '04205', '9880826', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '百目木', 'ドウメキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市和野', '04', '04205', '9880827', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '和野', 'ワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市下新田', '04', '04205', '9880828', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '下新田', 'シモシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市新田', '04', '04205', '9880829', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '新田', 'シンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市金成沢', '04', '04205', '9880831', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '金成沢', 'カンナリサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市瘻槻', '04', '04205', '9880832', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '瘻槻', 'コブツキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市渡戸', '04', '04205', '9880833', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '渡戸', 'ワタド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市川上', '04', '04205', '9880834', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '川上', 'カワカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市長岩間', '04', '04205', '9880835', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '長岩間', 'ナガイワマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市小芦', '04', '04205', '9880836', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '小芦', 'コアシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市鹿ノ倉', '04', '04205', '9880837', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '鹿ノ倉', 'カノクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市柳沢', '04', '04205', '9880841', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '柳沢', 'ヤナギザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市久保', '04', '04205', '9880842', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '久保', 'クボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市落合', '04', '04205', '9880843', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '落合', 'オチアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市象ケ鼻', '04', '04205', '9880844', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '象ケ鼻', 'ゾウガハナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市前木', '04', '04205', '9880845', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '前木', 'マエギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市川崎尻', '04', '04205', '9880846', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '川崎尻', 'カワサキジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市阿霄月', '04', '04205', '9880847', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '阿霄月', 'アヨイヅキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市下八瀬', '04', '04205', '9880851', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '下八瀬', 'シモヤツセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市松川', '04', '04205', '9880852', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '松川', 'マツカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市松川前', '04', '04205', '9880853', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '松川前', 'マツカワマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市磯沢', '04', '04205', '9880854', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '磯沢', 'イソザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市名木沢', '04', '04205', '9880855', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '名木沢', 'ナギサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市細尾', '04', '04205', '9880861', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '細尾', 'ホソオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市角地', '04', '04205', '9880862', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '角地', 'カクジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市黒沢', '04', '04205', '9880863', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '黒沢', 'クロサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市芳ノ口', '04', '04205', '9880863', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '芳ノ口', 'ヨシノクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市塚沢', '04', '04205', '9880864', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '塚沢', 'ツカザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市新早稲谷', '04', '04205', '9880865', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '新早稲谷', 'シンワセヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市早稲谷', '04', '04205', '9880865', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '早稲谷', 'ワセヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市内松川', '04', '04205', '9880866', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '内松川', 'ウチマツカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市新台', '04', '04205', '9880867', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '新台', 'シンダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市台', '04', '04205', '9880867', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '台', 'ダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市黒石山', '04', '04205', '9880868', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '黒石山', 'クロイシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市新関根', '04', '04205', '9880868', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '新関根', 'シンセキネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市関根', '04', '04205', '9880868', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '関根', 'セキネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県気仙沼市唐桑町西舞根', '04', '04205', '9880927', '宮城県', 'ミヤギケン', '気仙沼市', 'ケセンヌマシ', '唐桑町西舞根', 'カラクワチョウニシモウネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県白石市越河五賀', '04', '04206', '9890111', '宮城県', 'ミヤギケン', '白石市', 'シロイシシ', '越河五賀', 'コスゴウゴカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県白石市越河平', '04', '04206', '9890112', '宮城県', 'ミヤギケン', '白石市', 'シロイシシ', '越河平', 'コスゴウタイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県白石市越河', '04', '04206', '9890113', '宮城県', 'ミヤギケン', '白石市', 'シロイシシ', '越河', 'コスゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県白石市', '04', '04206', '9890200', '宮城県', 'ミヤギケン', '白石市', 'シロイシシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('143116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県白石市小下倉', '04', '04206', '9890201', '宮城県', 'ミヤギケン', '白石市', 'シロイシシ', '小下倉', 'コシタグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県白石市上堰', '04', '04206', '9890202', '宮城県', 'ミヤギケン', '白石市', 'シロイシシ', '上堰', 'カミゼキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県白石市郡山', '04', '04206', '9890203', '宮城県', 'ミヤギケン', '白石市', 'シロイシシ', '郡山', 'コオリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県白石市松ケ丘', '04', '04206', '9890204', '宮城県', 'ミヤギケン', '白石市', 'シロイシシ', '松ケ丘', 'マツガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県白石市東大畑', '04', '04206', '9890205', '宮城県', 'ミヤギケン', '白石市', 'シロイシシ', '東大畑', 'ヒガシオオハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県白石市寺屋敷前', '04', '04206', '9890206', '宮城県', 'ミヤギケン', '白石市', 'シロイシシ', '寺屋敷前', 'テラヤシキマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県白石市堂場前', '04', '04206', '9890207', '宮城県', 'ミヤギケン', '白石市', 'シロイシシ', '堂場前', 'ドウバマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県白石市大畑', '04', '04206', '9890208', '宮城県', 'ミヤギケン', '白石市', 'シロイシシ', '大畑', 'オオハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県白石市大鷹沢鷹巣', '04', '04206', '9890211', '宮城県', 'ミヤギケン', '白石市', 'シロイシシ', '大鷹沢鷹巣', 'オオタカサワタカノス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県白石市大鷹沢大町', '04', '04206', '9890212', '宮城県', 'ミヤギケン', '白石市', 'シロイシシ', '大鷹沢大町', 'オオタカサワオオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県白石市大鷹沢三沢', '04', '04206', '9890213', '宮城県', 'ミヤギケン', '白石市', 'シロイシシ', '大鷹沢三沢', 'オオタカサワミサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県白石市大平坂谷', '04', '04206', '9890214', '宮城県', 'ミヤギケン', '白石市', 'シロイシシ', '大平坂谷', 'オオダイラサカヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県白石市斎川', '04', '04206', '9890215', '宮城県', 'ミヤギケン', '白石市', 'シロイシシ', '斎川', 'サイカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県白石市大平中目', '04', '04206', '9890216', '宮城県', 'ミヤギケン', '白石市', 'シロイシシ', '大平中目', 'オオダイラナカノメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県白石市大平森合', '04', '04206', '9890217', '宮城県', 'ミヤギケン', '白石市', 'シロイシシ', '大平森合', 'オオダイラモリアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県白石市鷹巣東', '04', '04206', '9890218', '宮城県', 'ミヤギケン', '白石市', 'シロイシシ', '鷹巣東', 'タカノスヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県白石市鷹巣西', '04', '04206', '9890220', '宮城県', 'ミヤギケン', '白石市', 'シロイシシ', '鷹巣西', 'タカノスニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県白石市緑が丘', '04', '04206', '9890221', '宮城県', 'ミヤギケン', '白石市', 'シロイシシ', '緑が丘', 'ミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県白石市鷹巣', '04', '04206', '9890222', '宮城県', 'ミヤギケン', '白石市', 'シロイシシ', '鷹巣', 'タカノス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県白石市旭町', '04', '04206', '9890223', '宮城県', 'ミヤギケン', '白石市', 'シロイシシ', '旭町', 'アサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県白石市北無双作', '04', '04206', '9890224', '宮城県', 'ミヤギケン', '白石市', 'シロイシシ', '北無双作', 'キタムソウサク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県白石市東町', '04', '04206', '9890225', '宮城県', 'ミヤギケン', '白石市', 'シロイシシ', '東町', 'ヒガシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県白石市白石沖', '04', '04206', '9890226', '宮城県', 'ミヤギケン', '白石市', 'シロイシシ', '白石沖', 'シロイシオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県白石市田町', '04', '04206', '9890227', '宮城県', 'ミヤギケン', '白石市', 'シロイシシ', '田町', 'タマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県白石市兎作', '04', '04206', '9890228', '宮城県', 'ミヤギケン', '白石市', 'シロイシシ', '兎作', 'ウサギサク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県白石市銚子ケ森', '04', '04206', '9890229', '宮城県', 'ミヤギケン', '白石市', 'シロイシシ', '銚子ケ森', 'チョウシガモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県白石市福岡蔵本', '04', '04206', '9890231', '宮城県', 'ミヤギケン', '白石市', 'シロイシシ', '福岡蔵本', 'フクオカクラモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県白石市福岡長袋', '04', '04206', '9890232', '宮城県', 'ミヤギケン', '白石市', 'シロイシシ', '福岡長袋', 'フクオカナガフクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県白石市小原', '04', '04206', '9890233', '宮城県', 'ミヤギケン', '白石市', 'シロイシシ', '小原', 'オバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県白石市寿山', '04', '04206', '9890241', '宮城県', 'ミヤギケン', '白石市', 'シロイシシ', '寿山', 'コトブキヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県白石市柳町', '04', '04206', '9890242', '宮城県', 'ミヤギケン', '白石市', 'シロイシシ', '柳町', 'ヤナギマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県白石市沢目', '04', '04206', '9890243', '宮城県', 'ミヤギケン', '白石市', 'シロイシシ', '沢目', 'サワメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県白石市上久保', '04', '04206', '9890244', '宮城県', 'ミヤギケン', '白石市', 'シロイシシ', '上久保', 'カミクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県白石市城南', '04', '04206', '9890245', '宮城県', 'ミヤギケン', '白石市', 'シロイシシ', '城南', 'ジョウナン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県白石市新館町', '04', '04206', '9890246', '宮城県', 'ミヤギケン', '白石市', 'シロイシシ', '新館町', 'シンダテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県白石市八幡町', '04', '04206', '9890247', '宮城県', 'ミヤギケン', '白石市', 'シロイシシ', '八幡町', 'ハチマンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県白石市南町', '04', '04206', '9890248', '宮城県', 'ミヤギケン', '白石市', 'シロイシシ', '南町', 'ミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県白石市益岡町', '04', '04206', '9890251', '宮城県', 'ミヤギケン', '白石市', 'シロイシシ', '益岡町', 'マスオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県白石市西益岡町', '04', '04206', '9890252', '宮城県', 'ミヤギケン', '白石市', 'シロイシシ', '西益岡町', 'ニシマスオカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県白石市東小路', '04', '04206', '9890253', '宮城県', 'ミヤギケン', '白石市', 'シロイシシ', '東小路', 'ヒガシコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県白石市大川町', '04', '04206', '9890254', '宮城県', 'ミヤギケン', '白石市', 'シロイシシ', '大川町', 'オオカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県白石市城北町', '04', '04206', '9890255', '宮城県', 'ミヤギケン', '白石市', 'シロイシシ', '城北町', 'ジョウホクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県白石市本鍛冶小路', '04', '04206', '9890256', '宮城県', 'ミヤギケン', '白石市', 'シロイシシ', '本鍛冶小路', 'モトカジコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県白石市亘理町', '04', '04206', '9890257', '宮城県', 'ミヤギケン', '白石市', 'シロイシシ', '亘理町', 'ワタリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県白石市半沢屋敷西', '04', '04206', '9890258', '宮城県', 'ミヤギケン', '白石市', 'シロイシシ', '半沢屋敷西', 'ハンザワヤシキニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県白石市半沢屋敷前', '04', '04206', '9890259', '宮城県', 'ミヤギケン', '白石市', 'シロイシシ', '半沢屋敷前', 'ハンザワヤシキマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県白石市外川原', '04', '04206', '9890261', '宮城県', 'ミヤギケン', '白石市', 'シロイシシ', '外川原', 'ソトガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県白石市北川原', '04', '04206', '9890262', '宮城県', 'ミヤギケン', '白石市', 'シロイシシ', '北川原', 'キタガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県白石市柳川原', '04', '04206', '9890263', '宮城県', 'ミヤギケン', '白石市', 'シロイシシ', '柳川原', 'ヤナギガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県白石市幸', '04', '04206', '9890264', '宮城県', 'ミヤギケン', '白石市', 'シロイシシ', '幸', 'サイワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県白石市十王堂北', '04', '04206', '9890265', '宮城県', 'ミヤギケン', '白石市', 'シロイシシ', '十王堂北', 'ジュウオウドウキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県白石市十王堂前', '04', '04206', '9890266', '宮城県', 'ミヤギケン', '白石市', 'シロイシシ', '十王堂前', 'ジュウオウドウマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県白石市延命寺北', '04', '04206', '9890267', '宮城県', 'ミヤギケン', '白石市', 'シロイシシ', '延命寺北', 'エンメイジキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県白石市祢宜内', '04', '04206', '9890268', '宮城県', 'ミヤギケン', '白石市', 'シロイシシ', '祢宜内', 'ネギウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県白石市不澄ケ池', '04', '04206', '9890271', '宮城県', 'ミヤギケン', '白石市', 'シロイシシ', '不澄ケ池', 'スマズガイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県白石市清水小路', '04', '04206', '9890272', '宮城県', 'ミヤギケン', '白石市', 'シロイシシ', '清水小路', 'シミズコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県白石市中町', '04', '04206', '9890273', '宮城県', 'ミヤギケン', '白石市', 'シロイシシ', '中町', 'ナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県白石市長町', '04', '04206', '9890274', '宮城県', 'ミヤギケン', '白石市', 'シロイシシ', '長町', 'ナガマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県白石市本町', '04', '04206', '9890275', '宮城県', 'ミヤギケン', '白石市', 'シロイシシ', '本町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県白石市大手町', '04', '04206', '9890276', '宮城県', 'ミヤギケン', '白石市', 'シロイシシ', '大手町', 'オオテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県白石市沢端町', '04', '04206', '9890277', '宮城県', 'ミヤギケン', '白石市', 'シロイシシ', '沢端町', 'サワバタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県白石市沢端', '04', '04206', '9890278', '宮城県', 'ミヤギケン', '白石市', 'シロイシシ', '沢端', 'サワバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町', '04', '04302', '9890500', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('143184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町柏木山', '04', '04302', '9890501', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '柏木山', 'カシワギヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町西町裏', '04', '04302', '9890502', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '西町裏', 'ニシマチウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町横川原', '04', '04302', '9890502', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '横川原', 'ヨコカワハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町横川', '04', '04302', '9890503', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '横川', 'ヨコカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町上ノ平', '04', '04302', '9890504', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '上ノ平', 'カミノタイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町上ノ平山', '04', '04302', '9890505', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '上ノ平山', 'カミノタイラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町油畑', '04', '04302', '9890506', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '油畑', 'アブラハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町大萱', '04', '04302', '9890507', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '大萱', 'オオガヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町町下', '04', '04302', '9890507', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '町下', 'マチシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町松原', '04', '04302', '9890511', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '松原', 'マツバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町関', '04', '04302', '9890512', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '関', 'セキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町上町尻', '04', '04302', '9890513', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '上町尻', 'カミマチジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町下町尻', '04', '04302', '9890514', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '下町尻', 'シモマチジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町町尻', '04', '04302', '9890515', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '町尻', 'マチジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町宮前', '04', '04302', '9890515', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '宮前', 'ミヤマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町大貫平', '04', '04302', '9890516', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '大貫平', 'オオヌキダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町上島田原', '04', '04302', '9890516', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '上島田原', 'カミシマダハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町下島田原', '04', '04302', '9890516', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '下島田原', 'シモシマダハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町西島田原', '04', '04302', '9890516', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '西島田原', 'ニシシマダハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町東島田原', '04', '04302', '9890516', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '東島田原', 'ヒガシシマダハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町上八合', '04', '04302', '9890517', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '上八合', 'カミハチゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町下八合', '04', '04302', '9890518', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '下八合', 'シモハチゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町神林山', '04', '04302', '9890519', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '神林山', 'カミバヤシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町諏訪原', '04', '04302', '9890519', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '諏訪原', 'スワバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町新雷神', '04', '04302', '9890521', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '新雷神', 'シンライジン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町一枚田', '04', '04302', '9890522', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '一枚田', 'イチマイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町館下', '04', '04302', '9890523', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '館下', 'タテシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町上烏川', '04', '04302', '9890524', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '上烏川', 'カミカラスガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町廻館', '04', '04302', '9890524', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '廻館', 'マワリタテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町利津保', '04', '04302', '9890525', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '利津保', 'リツホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町明神前', '04', '04302', '9890526', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '明神前', 'ミョウジンマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町烏川岳', '04', '04302', '9890527', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '烏川岳', 'カラスガワダケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町沢上山', '04', '04302', '9890528', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '沢上山', 'サワガミヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町大杉', '04', '04302', '9890529', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '大杉', 'オオスギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町瀬見原', '04', '04302', '9890529', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '瀬見原', 'セミハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町矢立', '04', '04302', '9890531', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '矢立', 'ヤタテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町根添', '04', '04302', '9890532', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '根添', 'ネゾエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町矢立平', '04', '04302', '9890533', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '矢立平', 'ヤタテダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町若林山', '04', '04302', '9890534', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '若林山', 'ワカバヤシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町夏梨平', '04', '04302', '9890535', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '夏梨平', 'ナツナシダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町野沢倉山', '04', '04302', '9890535', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '野沢倉山', 'ノザワクラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町切通', '04', '04302', '9890536', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '切通', 'キリトオシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町上野', '04', '04302', '9890537', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '上野', 'ウワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町萩崎', '04', '04302', '9890537', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '萩崎', 'ハギザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町仕切目', '04', '04302', '9890541', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '仕切目', 'シキリメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町島木野', '04', '04302', '9890542', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '島木野', 'シマギノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町蒲木', '04', '04302', '9890543', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '蒲木', 'カバノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町中ノ沢原道下', '04', '04302', '9890544', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '中ノ沢原道下', 'ナカノサワハラミチシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町原谷地際', '04', '04302', '9890544', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '原谷地際', 'ハラヤチギワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町原道上', '04', '04302', '9890545', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '原道上', 'ハラミチウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町原道下', '04', '04302', '9890546', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '原道下', 'ハラミチシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町中之沢', '04', '04302', '9890547', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '中之沢', 'ナカノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町八ツ分', '04', '04302', '9890548', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '八ツ分', 'ヤツワケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町滑津', '04', '04302', '9890549', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '滑津', 'ナメツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町八ツ森', '04', '04302', '9890551', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '八ツ森', 'ヤツモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町苗代端', '04', '04302', '9890552', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '苗代端', 'ナワシロバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町大迎', '04', '04302', '9890553', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '大迎', 'オオムカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町陳ノ窪', '04', '04302', '9890554', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '陳ノ窪', 'ジンノクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町滝ノ上', '04', '04302', '9890555', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '滝ノ上', 'タキノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町水上口', '04', '04302', '9890555', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '水上口', 'ミズカミグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町愛宕下', '04', '04302', '9890556', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '愛宕下', 'アタゴシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町西森下', '04', '04302', '9890557', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '西森下', 'ニシモリシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町栗原', '04', '04302', '9890561', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '栗原', 'クリハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町茂ヶ沢', '04', '04302', '9890601', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '茂ヶ沢', 'モガザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町寺跡', '04', '04302', '9890602', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '寺跡', 'テラアト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町山伏坂', '04', '04302', '9890611', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '山伏坂', 'ヤマブシサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町侭ノ上', '04', '04302', '9890612', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '侭ノ上', 'ママノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町上川原', '04', '04302', '9890613', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '上川原', 'カミカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町中川原', '04', '04302', '9890614', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '中川原', 'ナカガワハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町沼田', '04', '04302', '9890615', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '沼田', 'ヌマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町薄沢口', '04', '04302', '9890616', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '薄沢口', 'ススキザワグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町滝下', '04', '04302', '9890617', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '滝下', 'タキシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町峠田', '04', '04302', '9890621', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '峠田', 'トウゲタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町峠田町頭', '04', '04302', '9890622', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '峠田町頭', 'トウゲタマチカシラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町上ノ台', '04', '04302', '9890623', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '上ノ台', 'カミノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町明神下', '04', '04302', '9890624', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '明神下', 'ミョウジンシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町峠田愛宕下', '04', '04302', '9890625', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '峠田愛宕下', 'トウゲタアタゴシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町茂庭道', '04', '04302', '9890626', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '茂庭道', 'モニワミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町坂ノ下', '04', '04302', '9890627', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '坂ノ下', 'サカノシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町境ノ沢', '04', '04302', '9890628', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '境ノ沢', 'サカイノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町大石川原', '04', '04302', '9890631', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '大石川原', 'オオイシカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町田中道下', '04', '04302', '9890632', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '田中道下', 'タナカミチシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町田中道上', '04', '04302', '9890633', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '田中道上', 'タナカミチウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町小駕籠沢', '04', '04302', '9890634', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '小駕籠沢', 'コカゴサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町板木', '04', '04302', '9890635', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '板木', 'イタギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町六本杉', '04', '04302', '9890636', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '六本杉', 'ロッポンスギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町程ヶ沢', '04', '04302', '9890641', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '程ヶ沢', 'ホドガサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町割付', '04', '04302', '9890642', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '割付', 'ワリツケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町稲子', '04', '04302', '9890643', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '稲子', 'イナゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町稲子山', '04', '04302', '9890644', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '稲子山', 'イナゴヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町東口道上', '04', '04302', '9890651', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '東口道上', 'ヒガシグチミチウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町東口道下', '04', '04302', '9890652', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '東口道下', 'ヒガシグチミチシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町湯原', '04', '04302', '9890653', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '湯原', 'ユノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町寺前', '04', '04302', '9890654', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '寺前', 'テラマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町壇前', '04', '04302', '9890655', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '壇前', 'ダンノマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町柳沢山国有林', '04', '04302', '9890656', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '柳沢山国有林', 'ヤナギサワヤマコクユウリン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町町裏', '04', '04302', '9890657', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '町裏', 'マチウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町南浦畑', '04', '04302', '9890658', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '南浦畑', 'ミナミウラハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町坂ノ上', '04', '04302', '9890661', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '坂ノ上', 'サカノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町赤地', '04', '04302', '9890662', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '赤地', 'アカチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町東沢', '04', '04302', '9890663', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '東沢', 'ヒガシサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町行人原道上', '04', '04302', '9890664', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '行人原道上', 'ギョウニンハラミチウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町侭ノ上地蔵前', '04', '04302', '9890665', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '侭ノ上地蔵前', 'ママノウエジゾウマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町干蒲', '04', '04302', '9890666', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '干蒲', 'ヒカバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡七ヶ宿町水下道上', '04', '04302', '9890667', '宮城県', 'ミヤギケン', '刈田郡七ヶ宿町', 'カッタグンシチカシュクマチ', '水下道上', 'ミズシタミチウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡蔵王町宮', '04', '04301', '9890701', '宮城県', 'ミヤギケン', '刈田郡蔵王町', 'カッタグンザオウマチ', '宮', 'ミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県白石市福岡深谷', '04', '04206', '9890731', '宮城県', 'ミヤギケン', '白石市', 'シロイシシ', '福岡深谷', 'フクオカフカヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県白石市福岡長袋川寺山', '04', '04206', '9890732', '宮城県', 'ミヤギケン', '白石市', 'シロイシシ', '福岡長袋', 'フクオカナガフクロ', null, null, '川寺山', 'カワテラヤマ');
INSERT INTO `ms_addresses` VALUES ('143293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県白石市福岡長袋芹沢', '04', '04206', '9890732', '宮城県', 'ミヤギケン', '白石市', 'シロイシシ', '福岡長袋', 'フクオカナガフクロ', null, null, '芹沢', 'セリザワ');
INSERT INTO `ms_addresses` VALUES ('143294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県白石市福岡八宮', '04', '04206', '9890733', '宮城県', 'ミヤギケン', '白石市', 'シロイシシ', '福岡八宮', 'フクオカヤツミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県白石市白鳥', '04', '04206', '9890734', '宮城県', 'ミヤギケン', '白石市', 'シロイシシ', '白鳥', 'シラトリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡蔵王町', '04', '04301', '9890800', '宮城県', 'ミヤギケン', '刈田郡蔵王町', 'カッタグンザオウマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('143297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡蔵王町円田', '04', '04301', '9890821', '宮城県', 'ミヤギケン', '刈田郡蔵王町', 'カッタグンザオウマチ', '円田', 'エンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡蔵王町平沢', '04', '04301', '9890831', '宮城県', 'ミヤギケン', '刈田郡蔵王町', 'カッタグンザオウマチ', '平沢', 'ヒラサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡蔵王町小村崎', '04', '04301', '9890841', '宮城県', 'ミヤギケン', '刈田郡蔵王町', 'カッタグンザオウマチ', '小村崎', 'コムラサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡蔵王町塩沢', '04', '04301', '9890842', '宮城県', 'ミヤギケン', '刈田郡蔵王町', 'カッタグンザオウマチ', '塩沢', 'シオザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡蔵王町矢附', '04', '04301', '9890843', '宮城県', 'ミヤギケン', '刈田郡蔵王町', 'カッタグンザオウマチ', '矢附', 'ヤヅキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡蔵王町曲竹', '04', '04301', '9890851', '宮城県', 'ミヤギケン', '刈田郡蔵王町', 'カッタグンザオウマチ', '曲竹', 'マガタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡川崎町前川青根', '04', '04324', '9890901', '宮城県', 'ミヤギケン', '柴田郡川崎町', 'シバタグンカワサキマチ', '前川', 'マエカワ', null, null, '青根', 'アオネ');
INSERT INTO `ms_addresses` VALUES ('143305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡川崎町前川峩々', '04', '04324', '9890901', '宮城県', 'ミヤギケン', '柴田郡川崎町', 'シバタグンカワサキマチ', '前川', 'マエカワ', null, null, '峩々', 'ガガ');
INSERT INTO `ms_addresses` VALUES ('143306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡川崎町前川権現塚', '04', '04324', '9890901', '宮城県', 'ミヤギケン', '柴田郡川崎町', 'シバタグンカワサキマチ', '前川', 'マエカワ', null, null, '権現塚', 'ゴンゲンヅカ');
INSERT INTO `ms_addresses` VALUES ('143307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡川崎町前川手代塚山', '04', '04324', '9890901', '宮城県', 'ミヤギケン', '柴田郡川崎町', 'シバタグンカワサキマチ', '前川', 'マエカワ', null, null, '手代塚山', 'テシロツカヤマ');
INSERT INTO `ms_addresses` VALUES ('143308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡川崎町前川沼ノ平山', '04', '04324', '9890901', '宮城県', 'ミヤギケン', '柴田郡川崎町', 'シバタグンカワサキマチ', '前川', 'マエカワ', null, null, '沼ノ平山', 'ヌマノタイヤマ');
INSERT INTO `ms_addresses` VALUES ('143309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡川崎町前川火の塚山', '04', '04324', '9890901', '宮城県', 'ミヤギケン', '柴田郡川崎町', 'シバタグンカワサキマチ', '前川', 'マエカワ', null, null, '火の塚山', 'ヒノツカヤマ');
INSERT INTO `ms_addresses` VALUES ('143310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡川崎町前川名号下山', '04', '04324', '9890901', '宮城県', 'ミヤギケン', '柴田郡川崎町', 'シバタグンカワサキマチ', '前川', 'マエカワ', null, null, '名号下山', 'ミョウゴシタヤマ');
INSERT INTO `ms_addresses` VALUES ('143311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡川崎町青根温泉', '04', '04324', '9890908', '宮城県', 'ミヤギケン', '柴田郡川崎町', 'シバタグンカワサキマチ', '青根温泉', 'アオネオンセン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡蔵王町遠刈田温泉栄町', '04', '04301', '9890911', '宮城県', 'ミヤギケン', '刈田郡蔵王町', 'カッタグンザオウマチ', '遠刈田温泉栄町', 'トオガッタオンセンサカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡蔵王町遠刈田温泉仲町', '04', '04301', '9890912', '宮城県', 'ミヤギケン', '刈田郡蔵王町', 'カッタグンザオウマチ', '遠刈田温泉仲町', 'トオガッタオンセンナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡蔵王町遠刈田温泉本町', '04', '04301', '9890913', '宮城県', 'ミヤギケン', '刈田郡蔵王町', 'カッタグンザオウマチ', '遠刈田温泉本町', 'トオガッタオンセンモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡蔵王町遠刈田温泉旭町', '04', '04301', '9890914', '宮城県', 'ミヤギケン', '刈田郡蔵王町', 'カッタグンザオウマチ', '遠刈田温泉旭町', 'トオガッタオンセンアサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡蔵王町遠刈田温泉寿町', '04', '04301', '9890915', '宮城県', 'ミヤギケン', '刈田郡蔵王町', 'カッタグンザオウマチ', '遠刈田温泉寿町', 'トオガッタオンセンコトブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡蔵王町遠刈田温泉', '04', '04301', '9890916', '宮城県', 'ミヤギケン', '刈田郡蔵王町', 'カッタグンザオウマチ', '遠刈田温泉', 'トオガッタオンセン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡蔵王町円田', '04', '04301', '9890921', '宮城県', 'ミヤギケン', '刈田郡蔵王町', 'カッタグンザオウマチ', '円田', 'エンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡蔵王町円田釜沢', '04', '04301', '9890921', '宮城県', 'ミヤギケン', '刈田郡蔵王町', 'カッタグンザオウマチ', '円田', 'エンダ', null, null, '釜沢', 'カマザワ');
INSERT INTO `ms_addresses` VALUES ('143320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡蔵王町円田善舞森', '04', '04301', '9890921', '宮城県', 'ミヤギケン', '刈田郡蔵王町', 'カッタグンザオウマチ', '円田', 'エンダ', null, null, '善舞森', 'ゼンブモリ');
INSERT INTO `ms_addresses` VALUES ('143321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県刈田郡蔵王町円田土浮谷地', '04', '04301', '9890921', '宮城県', 'ミヤギケン', '刈田郡蔵王町', 'カッタグンザオウマチ', '円田', 'エンダ', null, null, '土浮谷地', 'ドブヤチ');
INSERT INTO `ms_addresses` VALUES ('143323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県白石市白川小奥', '04', '04206', '9891101', '宮城県', 'ミヤギケン', '白石市', 'シロイシシ', '白川小奥', 'シラカワコオク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県白石市白川津田', '04', '04206', '9891102', '宮城県', 'ミヤギケン', '白石市', 'シロイシシ', '白川津田', 'シラカワツダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県白石市白川犬卒都婆', '04', '04206', '9891103', '宮城県', 'ミヤギケン', '白石市', 'シロイシシ', '白川犬卒都婆', 'シラカワイヌソトバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県白石市白川内親', '04', '04206', '9891104', '宮城県', 'ミヤギケン', '白石市', 'シロイシシ', '白川内親', 'シラカワウチオヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡大河原町', '04', '04321', '9891200', '宮城県', 'ミヤギケン', '柴田郡大河原町', 'シバタグンオオガワラマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('143328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡大河原町大谷', '04', '04321', '9891201', '宮城県', 'ミヤギケン', '柴田郡大河原町', 'シバタグンオオガワラマチ', '大谷', 'オオヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡大河原町高砂町', '04', '04321', '9891202', '宮城県', 'ミヤギケン', '柴田郡大河原町', 'シバタグンオオガワラマチ', '高砂町', 'タカサゴチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡大河原町旭町', '04', '04321', '9891203', '宮城県', 'ミヤギケン', '柴田郡大河原町', 'シバタグンオオガワラマチ', '旭町', 'アサヒチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡大河原町大竜', '04', '04321', '9891204', '宮城県', 'ミヤギケン', '柴田郡大河原町', 'シバタグンオオガワラマチ', '大竜', 'オオタツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡大河原町大芝', '04', '04321', '9891205', '宮城県', 'ミヤギケン', '柴田郡大河原町', 'シバタグンオオガワラマチ', '大芝', 'オオシバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡大河原町中の倉', '04', '04321', '9891206', '宮城県', 'ミヤギケン', '柴田郡大河原町', 'シバタグンオオガワラマチ', '中の倉', 'ナカノクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡大河原町川瀬町', '04', '04321', '9891207', '宮城県', 'ミヤギケン', '柴田郡大河原町', 'シバタグンオオガワラマチ', '川瀬町', 'カワセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡大河原町広瀬町', '04', '04321', '9891211', '宮城県', 'ミヤギケン', '柴田郡大河原町', 'シバタグンオオガワラマチ', '広瀬町', 'ヒロセチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡大河原町山崎町', '04', '04321', '9891212', '宮城県', 'ミヤギケン', '柴田郡大河原町', 'シバタグンオオガワラマチ', '山崎町', 'ヤマザキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡大河原町住吉町', '04', '04321', '9891213', '宮城県', 'ミヤギケン', '柴田郡大河原町', 'シバタグンオオガワラマチ', '住吉町', 'スミヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡大河原町甲子町', '04', '04321', '9891214', '宮城県', 'ミヤギケン', '柴田郡大河原町', 'シバタグンオオガワラマチ', '甲子町', 'キノイネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡大河原町中島町', '04', '04321', '9891215', '宮城県', 'ミヤギケン', '柴田郡大河原町', 'シバタグンオオガワラマチ', '中島町', 'ナカジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡大河原町幸町', '04', '04321', '9891216', '宮城県', 'ミヤギケン', '柴田郡大河原町', 'シバタグンオオガワラマチ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡大河原町錦町', '04', '04321', '9891217', '宮城県', 'ミヤギケン', '柴田郡大河原町', 'シバタグンオオガワラマチ', '錦町', 'ニシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡大河原町緑町', '04', '04321', '9891221', '宮城県', 'ミヤギケン', '柴田郡大河原町', 'シバタグンオオガワラマチ', '緑町', 'ミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡大河原町南平', '04', '04321', '9891222', '宮城県', 'ミヤギケン', '柴田郡大河原町', 'シバタグンオオガワラマチ', '南平', 'ナンペイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡大河原町東新町', '04', '04321', '9891223', '宮城県', 'ミヤギケン', '柴田郡大河原町', 'シバタグンオオガワラマチ', '東新町', 'ヒガシシンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡大河原町金ケ瀬', '04', '04321', '9891224', '宮城県', 'ミヤギケン', '柴田郡大河原町', 'シバタグンオオガワラマチ', '金ケ瀬', 'カナガセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡大河原町中川原', '04', '04321', '9891231', '宮城県', 'ミヤギケン', '柴田郡大河原町', 'シバタグンオオガワラマチ', '中川原', 'ナカガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡大河原町南海道下', '04', '04321', '9891232', '宮城県', 'ミヤギケン', '柴田郡大河原町', 'シバタグンオオガワラマチ', '南海道下', 'ミナミカイドウシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡大河原町上川原', '04', '04321', '9891233', '宮城県', 'ミヤギケン', '柴田郡大河原町', 'シバタグンオオガワラマチ', '上川原', 'カミカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡大河原町新古川', '04', '04321', '9891234', '宮城県', 'ミヤギケン', '柴田郡大河原町', 'シバタグンオオガワラマチ', '新古川', 'シンフルカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡大河原町南原町', '04', '04321', '9891235', '宮城県', 'ミヤギケン', '柴田郡大河原町', 'シバタグンオオガワラマチ', '南原町', 'ミナミハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡大河原町東原町', '04', '04321', '9891236', '宮城県', 'ミヤギケン', '柴田郡大河原町', 'シバタグンオオガワラマチ', '東原町', 'ヒガシハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡大河原町荒町', '04', '04321', '9891237', '宮城県', 'ミヤギケン', '柴田郡大河原町', 'シバタグンオオガワラマチ', '荒町', 'アラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡大河原町町', '04', '04321', '9891241', '宮城県', 'ミヤギケン', '柴田郡大河原町', 'シバタグンオオガワラマチ', '町', 'マチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡大河原町西浦', '04', '04321', '9891242', '宮城県', 'ミヤギケン', '柴田郡大河原町', 'シバタグンオオガワラマチ', '西浦', 'ニシウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡大河原町南', '04', '04321', '9891243', '宮城県', 'ミヤギケン', '柴田郡大河原町', 'シバタグンオオガワラマチ', '南', 'ミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡大河原町西町', '04', '04321', '9891244', '宮城県', 'ミヤギケン', '柴田郡大河原町', 'シバタグンオオガワラマチ', '西町', 'ニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡大河原町新南', '04', '04321', '9891245', '宮城県', 'ミヤギケン', '柴田郡大河原町', 'シバタグンオオガワラマチ', '新南', 'シンミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡大河原町新東', '04', '04321', '9891246', '宮城県', 'ミヤギケン', '柴田郡大河原町', 'シバタグンオオガワラマチ', '新東', 'シンヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡大河原町東', '04', '04321', '9891247', '宮城県', 'ミヤギケン', '柴田郡大河原町', 'シバタグンオオガワラマチ', '東', 'ヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡大河原町土手崎', '04', '04321', '9891248', '宮城県', 'ミヤギケン', '柴田郡大河原町', 'シバタグンオオガワラマチ', '土手崎', 'ドテザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡大河原町海道東', '04', '04321', '9891249', '宮城県', 'ミヤギケン', '柴田郡大河原町', 'シバタグンオオガワラマチ', '海道東', 'カイドウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡大河原町橋本', '04', '04321', '9891251', '宮城県', 'ミヤギケン', '柴田郡大河原町', 'シバタグンオオガワラマチ', '橋本', 'ハシモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡大河原町八乙女', '04', '04321', '9891252', '宮城県', 'ミヤギケン', '柴田郡大河原町', 'シバタグンオオガワラマチ', '八乙女', 'ヤオトメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡大河原町西', '04', '04321', '9891253', '宮城県', 'ミヤギケン', '柴田郡大河原町', 'シバタグンオオガワラマチ', '西', 'ニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡大河原町沼', '04', '04321', '9891254', '宮城県', 'ミヤギケン', '柴田郡大河原町', 'シバタグンオオガワラマチ', '沼', 'ヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡大河原町袖谷地', '04', '04321', '9891255', '宮城県', 'ミヤギケン', '柴田郡大河原町', 'シバタグンオオガワラマチ', '袖谷地', 'ソデヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡大河原町堤', '04', '04321', '9891256', '宮城県', 'ミヤギケン', '柴田郡大河原町', 'シバタグンオオガワラマチ', '堤', 'ツツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡大河原町新寺', '04', '04321', '9891257', '宮城県', 'ミヤギケン', '柴田郡大河原町', 'シバタグンオオガワラマチ', '新寺', 'ニッテラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡大河原町小山田', '04', '04321', '9891258', '宮城県', 'ミヤギケン', '柴田郡大河原町', 'シバタグンオオガワラマチ', '小山田', 'オヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡大河原町福田', '04', '04321', '9891259', '宮城県', 'ミヤギケン', '柴田郡大河原町', 'シバタグンオオガワラマチ', '福田', 'フクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡大河原町大巻', '04', '04321', '9891261', '宮城県', 'ミヤギケン', '柴田郡大河原町', 'シバタグンオオガワラマチ', '大巻', 'オオマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡大河原町大谷地', '04', '04321', '9891263', '宮城県', 'ミヤギケン', '柴田郡大河原町', 'シバタグンオオガワラマチ', '大谷地', 'オオヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡大河原町新青川', '04', '04321', '9891264', '宮城県', 'ミヤギケン', '柴田郡大河原町', 'シバタグンオオガワラマチ', '新青川', 'シンアオカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡大河原町千塚前', '04', '04321', '9891266', '宮城県', 'ミヤギケン', '柴田郡大河原町', 'シバタグンオオガワラマチ', '千塚前', 'センツカマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡大河原町小島', '04', '04321', '9891267', '宮城県', 'ミヤギケン', '柴田郡大河原町', 'シバタグンオオガワラマチ', '小島', 'オシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡大河原町東桜町', '04', '04321', '9891271', '宮城県', 'ミヤギケン', '柴田郡大河原町', 'シバタグンオオガワラマチ', '東桜町', 'ヒガシサクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡大河原町南桜町', '04', '04321', '9891272', '宮城県', 'ミヤギケン', '柴田郡大河原町', 'シバタグンオオガワラマチ', '南桜町', 'ミナミサクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡大河原町西桜町', '04', '04321', '9891273', '宮城県', 'ミヤギケン', '柴田郡大河原町', 'シバタグンオオガワラマチ', '西桜町', 'ニシサクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡大河原町新桜町', '04', '04321', '9891274', '宮城県', 'ミヤギケン', '柴田郡大河原町', 'シバタグンオオガワラマチ', '新桜町', 'シンサクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡村田町', '04', '04322', '9891300', '宮城県', 'ミヤギケン', '柴田郡村田町', 'シバタグンムラタマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('143384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡村田町菅生', '04', '04322', '9891301', '宮城県', 'ミヤギケン', '柴田郡村田町', 'シバタグンムラタマチ', '菅生', 'スゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡村田町小泉', '04', '04322', '9891302', '宮城県', 'ミヤギケン', '柴田郡村田町', 'シバタグンムラタマチ', '小泉', 'コイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡村田町薄木', '04', '04322', '9891303', '宮城県', 'ミヤギケン', '柴田郡村田町', 'シバタグンムラタマチ', '薄木', 'ウスギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡村田町西ケ丘', '04', '04322', '9891304', '宮城県', 'ミヤギケン', '柴田郡村田町', 'シバタグンムラタマチ', '西ケ丘', 'ニシガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡村田町村田', '04', '04322', '9891305', '宮城県', 'ミヤギケン', '柴田郡村田町', 'シバタグンムラタマチ', '村田', 'ムラタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡村田町足立', '04', '04322', '9891311', '宮城県', 'ミヤギケン', '柴田郡村田町', 'シバタグンムラタマチ', '足立', 'アシタテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡村田町沼辺', '04', '04322', '9891321', '宮城県', 'ミヤギケン', '柴田郡村田町', 'シバタグンムラタマチ', '沼辺', 'ヌマベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡村田町関場', '04', '04322', '9891322', '宮城県', 'ミヤギケン', '柴田郡村田町', 'シバタグンムラタマチ', '関場', 'セキバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡村田町沼田', '04', '04322', '9891323', '宮城県', 'ミヤギケン', '柴田郡村田町', 'シバタグンムラタマチ', '沼田', 'ヌマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡川崎町', '04', '04324', '9891500', '宮城県', 'ミヤギケン', '柴田郡川崎町', 'シバタグンカワサキマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('143397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡川崎町前川', '04', '04324', '9891501', '宮城県', 'ミヤギケン', '柴田郡川崎町', 'シバタグンカワサキマチ', '前川', 'マエカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡川崎町今宿', '04', '04324', '9891502', '宮城県', 'ミヤギケン', '柴田郡川崎町', 'シバタグンカワサキマチ', '今宿', 'イマシュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡川崎町川内', '04', '04324', '9891503', '宮城県', 'ミヤギケン', '柴田郡川崎町', 'シバタグンカワサキマチ', '川内', 'カワウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡川崎町本砂金', '04', '04324', '9891504', '宮城県', 'ミヤギケン', '柴田郡川崎町', 'シバタグンカワサキマチ', '本砂金', 'モトイサゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡川崎町小野', '04', '04324', '9891505', '宮城県', 'ミヤギケン', '柴田郡川崎町', 'シバタグンカワサキマチ', '小野', 'オノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡川崎町支倉台', '04', '04324', '9891506', '宮城県', 'ミヤギケン', '柴田郡川崎町', 'シバタグンカワサキマチ', '支倉台', 'ハセクラダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡川崎町支倉', '04', '04324', '9891507', '宮城県', 'ミヤギケン', '柴田郡川崎町', 'シバタグンカワサキマチ', '支倉', 'ハセクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡村田町足立北向', '04', '04322', '9891511', '宮城県', 'ミヤギケン', '柴田郡村田町', 'シバタグンムラタマチ', '足立', 'アシタテ', null, null, '北向', 'キタムキ');
INSERT INTO `ms_addresses` VALUES ('143406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡柴田町', '04', '04323', '9891600', '宮城県', 'ミヤギケン', '柴田郡柴田町', 'シバタグンシバタマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('143407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡柴田町船岡中央', '04', '04323', '9891601', '宮城県', 'ミヤギケン', '柴田郡柴田町', 'シバタグンシバタマチ', '船岡中央', 'フナオカチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡柴田町船岡土手内', '04', '04323', '9891602', '宮城県', 'ミヤギケン', '柴田郡柴田町', 'シバタグンシバタマチ', '船岡土手内', 'フナオカドテウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡柴田町船岡西', '04', '04323', '9891603', '宮城県', 'ミヤギケン', '柴田郡柴田町', 'シバタグンシバタマチ', '船岡西', 'フナオカニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡柴田町船岡東', '04', '04323', '9891604', '宮城県', 'ミヤギケン', '柴田郡柴田町', 'シバタグンシバタマチ', '船岡東', 'フナオカヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡柴田町船岡南', '04', '04323', '9891605', '宮城県', 'ミヤギケン', '柴田郡柴田町', 'シバタグンシバタマチ', '船岡南', 'フナオカミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡柴田町船岡', '04', '04323', '9891606', '宮城県', 'ミヤギケン', '柴田郡柴田町', 'シバタグンシバタマチ', '船岡', 'フナオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡柴田町船岡新栄', '04', '04323', '9891607', '宮城県', 'ミヤギケン', '柴田郡柴田町', 'シバタグンシバタマチ', '船岡新栄', 'フナオカシンエイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡柴田町剣崎', '04', '04323', '9891608', '宮城県', 'ミヤギケン', '柴田郡柴田町', 'シバタグンシバタマチ', '剣崎', 'ケンザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡柴田町上名生', '04', '04323', '9891611', '宮城県', 'ミヤギケン', '柴田郡柴田町', 'シバタグンシバタマチ', '上名生', 'カミノミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡柴田町中名生', '04', '04323', '9891612', '宮城県', 'ミヤギケン', '柴田郡柴田町', 'シバタグンシバタマチ', '中名生', 'ナカノミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡柴田町下名生', '04', '04323', '9891613', '宮城県', 'ミヤギケン', '柴田郡柴田町', 'シバタグンシバタマチ', '下名生', 'シモノミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡柴田町本船迫', '04', '04323', '9891621', '宮城県', 'ミヤギケン', '柴田郡柴田町', 'シバタグンシバタマチ', '本船迫', 'ホンフナバサマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡柴田町西船迫', '04', '04323', '9891622', '宮城県', 'ミヤギケン', '柴田郡柴田町', 'シバタグンシバタマチ', '西船迫', 'ニシフナバサマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡柴田町北船岡', '04', '04323', '9891623', '宮城県', 'ミヤギケン', '柴田郡柴田町', 'シバタグンシバタマチ', '北船岡', 'キタフナオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡柴田町東船迫2丁目', '04', '04323', '9891631', '宮城県', 'ミヤギケン', '柴田郡柴田町', 'シバタグンシバタマチ', '東船迫', 'ヒガシフナバサマ', null, null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('143426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡柴田町東船迫1丁目', '04', '04323', '9891731', '宮城県', 'ミヤギケン', '柴田郡柴田町', 'シバタグンシバタマチ', '東船迫', 'ヒガシフナバサマ', null, null, '1丁目', '01チョウメ');
INSERT INTO `ms_addresses` VALUES ('143427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡柴田町富沢', '04', '04323', '9891741', '宮城県', 'ミヤギケン', '柴田郡柴田町', 'シバタグンシバタマチ', '富沢', 'トミザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡柴田町上川名', '04', '04323', '9891742', '宮城県', 'ミヤギケン', '柴田郡柴田町', 'シバタグンシバタマチ', '上川名', 'カミカワナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡柴田町四日市場', '04', '04323', '9891743', '宮城県', 'ミヤギケン', '柴田郡柴田町', 'シバタグンシバタマチ', '四日市場', 'ヨッカイチバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡柴田町松ケ越', '04', '04323', '9891744', '宮城県', 'ミヤギケン', '柴田郡柴田町', 'シバタグンシバタマチ', '松ケ越', 'マツガゴシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡柴田町入間田', '04', '04323', '9891745', '宮城県', 'ミヤギケン', '柴田郡柴田町', 'シバタグンシバタマチ', '入間田', 'イリマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡柴田町ゆずが丘', '04', '04323', '9891746', '宮城県', 'ミヤギケン', '柴田郡柴田町', 'シバタグンシバタマチ', 'ゆずが丘', 'ユズガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡柴田町槻木新町', '04', '04323', '9891751', '宮城県', 'ミヤギケン', '柴田郡柴田町', 'シバタグンシバタマチ', '槻木新町', 'ツキノキシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡柴田町槻木下町', '04', '04323', '9891752', '宮城県', 'ミヤギケン', '柴田郡柴田町', 'シバタグンシバタマチ', '槻木下町', 'ツキノキシモマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡柴田町槻木上町', '04', '04323', '9891753', '宮城県', 'ミヤギケン', '柴田郡柴田町', 'シバタグンシバタマチ', '槻木上町', 'ツキノキカミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡柴田町槻木白幡', '04', '04323', '9891754', '宮城県', 'ミヤギケン', '柴田郡柴田町', 'シバタグンシバタマチ', '槻木白幡', 'ツキノキシラハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡柴田町槻木西', '04', '04323', '9891755', '宮城県', 'ミヤギケン', '柴田郡柴田町', 'シバタグンシバタマチ', '槻木西', 'ツキノキニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡柴田町槻木', '04', '04323', '9891756', '宮城県', 'ミヤギケン', '柴田郡柴田町', 'シバタグンシバタマチ', '槻木', 'ツキノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡柴田町槻木東', '04', '04323', '9891757', '宮城県', 'ミヤギケン', '柴田郡柴田町', 'シバタグンシバタマチ', '槻木東', 'ツキノキヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡柴田町槻木駅西', '04', '04323', '9891758', '宮城県', 'ミヤギケン', '柴田郡柴田町', 'シバタグンシバタマチ', '槻木駅西', 'ツキノキエキニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡柴田町葉坂', '04', '04323', '9891761', '宮城県', 'ミヤギケン', '柴田郡柴田町', 'シバタグンシバタマチ', '葉坂', 'ハザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡柴田町海老穴', '04', '04323', '9891762', '宮城県', 'ミヤギケン', '柴田郡柴田町', 'シバタグンシバタマチ', '海老穴', 'エビアナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡柴田町船迫', '04', '04323', '9891763', '宮城県', 'ミヤギケン', '柴田郡柴田町', 'シバタグンシバタマチ', '船迫', 'フナバサマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡柴田町小成田', '04', '04323', '9891764', '宮城県', 'ミヤギケン', '柴田郡柴田町', 'シバタグンシバタマチ', '小成田', 'コナリタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県柴田郡柴田町成田', '04', '04323', '9891765', '宮城県', 'ミヤギケン', '柴田郡柴田町', 'シバタグンシバタマチ', '成田', 'ナリタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県亘理郡山元町坂元', '04', '04362', '9892111', '宮城県', 'ミヤギケン', '亘理郡山元町', 'ワタリグンヤマモトチョウ', '坂元', 'サカモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県亘理郡山元町真庭', '04', '04362', '9892112', '宮城県', 'ミヤギケン', '亘理郡山元町', 'ワタリグンヤマモトチョウ', '真庭', 'マニワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県亘理郡山元町', '04', '04362', '9892200', '宮城県', 'ミヤギケン', '亘理郡山元町', 'ワタリグンヤマモトチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('143450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県亘理郡山元町山寺', '04', '04362', '9892201', '宮城県', 'ミヤギケン', '亘理郡山元町', 'ワタリグンヤマモトチョウ', '山寺', 'ヤマデラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県亘理郡山元町高瀬', '04', '04362', '9892202', '宮城県', 'ミヤギケン', '亘理郡山元町', 'ワタリグンヤマモトチョウ', '高瀬', 'タカセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県亘理郡山元町浅生原', '04', '04362', '9892203', '宮城県', 'ミヤギケン', '亘理郡山元町', 'ワタリグンヤマモトチョウ', '浅生原', 'アソウハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県亘理郡山元町鷲足', '04', '04362', '9892204', '宮城県', 'ミヤギケン', '亘理郡山元町', 'ワタリグンヤマモトチョウ', '鷲足', 'ワシアシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県亘理郡山元町小平', '04', '04362', '9892205', '宮城県', 'ミヤギケン', '亘理郡山元町', 'ワタリグンヤマモトチョウ', '小平', 'コダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県亘理郡山元町大平', '04', '04362', '9892206', '宮城県', 'ミヤギケン', '亘理郡山元町', 'ワタリグンヤマモトチョウ', '大平', 'オオダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県亘理郡山元町八手庭', '04', '04362', '9892207', '宮城県', 'ミヤギケン', '亘理郡山元町', 'ワタリグンヤマモトチョウ', '八手庭', 'ハデニワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県亘理郡亘理町', '04', '04361', '9892300', '宮城県', 'ミヤギケン', '亘理郡亘理町', 'ワタリグンワタリチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('143459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県亘理郡亘理町逢隈中泉', '04', '04361', '9892301', '宮城県', 'ミヤギケン', '亘理郡亘理町', 'ワタリグンワタリチョウ', '逢隈中泉', 'オオクマナカイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県亘理郡亘理町逢隈牛袋', '04', '04361', '9892302', '宮城県', 'ミヤギケン', '亘理郡亘理町', 'ワタリグンワタリチョウ', '逢隈牛袋', 'オオクマウシブクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県亘理郡亘理町逢隈十文字', '04', '04361', '9892303', '宮城県', 'ミヤギケン', '亘理郡亘理町', 'ワタリグンワタリチョウ', '逢隈十文字', 'オオクマジュウモンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県亘理郡亘理町荒浜', '04', '04361', '9892311', '宮城県', 'ミヤギケン', '亘理郡亘理町', 'ワタリグンワタリチョウ', '荒浜', 'アラハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県亘理郡亘理町逢隈榎袋', '04', '04361', '9892321', '宮城県', 'ミヤギケン', '亘理郡亘理町', 'ワタリグンワタリチョウ', '逢隈榎袋', 'オオクマエノキブクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県亘理郡亘理町逢隈蕨', '04', '04361', '9892322', '宮城県', 'ミヤギケン', '亘理郡亘理町', 'ワタリグンワタリチョウ', '逢隈蕨', 'オオクマワラビ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県亘理郡亘理町逢隈鷺屋', '04', '04361', '9892323', '宮城県', 'ミヤギケン', '亘理郡亘理町', 'ワタリグンワタリチョウ', '逢隈鷺屋', 'オオクマサギヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県亘理郡亘理町逢隈高屋', '04', '04361', '9892324', '宮城県', 'ミヤギケン', '亘理郡亘理町', 'ワタリグンワタリチョウ', '逢隈高屋', 'オオクマコウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県亘理郡亘理町吉田', '04', '04361', '9892331', '宮城県', 'ミヤギケン', '亘理郡亘理町', 'ワタリグンワタリチョウ', '吉田', 'ヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県亘理郡亘理町長瀞', '04', '04361', '9892341', '宮城県', 'ミヤギケン', '亘理郡亘理町', 'ワタリグンワタリチョウ', '長瀞', 'ナガトロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県亘理郡亘理町旭', '04', '04361', '9892351', '宮城県', 'ミヤギケン', '亘理郡亘理町', 'ワタリグンワタリチョウ', '旭', 'アサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県亘理郡亘理町旭山', '04', '04361', '9892351', '宮城県', 'ミヤギケン', '亘理郡亘理町', 'ワタリグンワタリチョウ', '旭山', 'アサヒヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県亘理郡亘理町油田', '04', '04361', '9892351', '宮城県', 'ミヤギケン', '亘理郡亘理町', 'ワタリグンワタリチョウ', '油田', 'アブラデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県亘理郡亘理町五日町', '04', '04361', '9892351', '宮城県', 'ミヤギケン', '亘理郡亘理町', 'ワタリグンワタリチョウ', '五日町', 'イツカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県亘理郡亘理町祝田', '04', '04361', '9892351', '宮城県', 'ミヤギケン', '亘理郡亘理町', 'ワタリグンワタリチョウ', '祝田', 'イワイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県亘理郡亘理町裏城戸', '04', '04361', '9892351', '宮城県', 'ミヤギケン', '亘理郡亘理町', 'ワタリグンワタリチョウ', '裏城戸', 'ウラキド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県亘理郡亘理町江下', '04', '04361', '9892351', '宮城県', 'ミヤギケン', '亘理郡亘理町', 'ワタリグンワタリチョウ', '江下', 'エシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県亘理郡亘理町上中野地', '04', '04361', '9892351', '宮城県', 'ミヤギケン', '亘理郡亘理町', 'ワタリグンワタリチョウ', '上中野地', 'カミナカヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県亘理郡亘理町上浜街道', '04', '04361', '9892351', '宮城県', 'ミヤギケン', '亘理郡亘理町', 'ワタリグンワタリチョウ', '上浜街道', 'カミハマカイドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県亘理郡亘理町上茨田', '04', '04361', '9892351', '宮城県', 'ミヤギケン', '亘理郡亘理町', 'ワタリグンワタリチョウ', '上茨田', 'カミバラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県亘理郡亘理町亀井戸', '04', '04361', '9892351', '宮城県', 'ミヤギケン', '亘理郡亘理町', 'ワタリグンワタリチョウ', '亀井戸', 'カメイド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県亘理郡亘理町上町', '04', '04361', '9892351', '宮城県', 'ミヤギケン', '亘理郡亘理町', 'ワタリグンワタリチョウ', '上町', 'カンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県亘理郡亘理町北新田', '04', '04361', '9892351', '宮城県', 'ミヤギケン', '亘理郡亘理町', 'ワタリグンワタリチョウ', '北新田', 'キタシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県亘理郡亘理町北新町', '04', '04361', '9892351', '宮城県', 'ミヤギケン', '亘理郡亘理町', 'ワタリグンワタリチョウ', '北新町', 'キタシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県亘理郡亘理町狐塚', '04', '04361', '9892351', '宮城県', 'ミヤギケン', '亘理郡亘理町', 'ワタリグンワタリチョウ', '狐塚', 'キツネヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県亘理郡亘理町旧舘', '04', '04361', '9892351', '宮城県', 'ミヤギケン', '亘理郡亘理町', 'ワタリグンワタリチョウ', '旧舘', 'キュウカン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県亘理郡亘理町境堤', '04', '04361', '9892351', '宮城県', 'ミヤギケン', '亘理郡亘理町', 'ワタリグンワタリチョウ', '境堤', 'サカイツツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県亘理郡亘理町桜小路', '04', '04361', '9892351', '宮城県', 'ミヤギケン', '亘理郡亘理町', 'ワタリグンワタリチョウ', '桜小路', 'サクラコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県亘理郡亘理町芝西', '04', '04361', '9892351', '宮城県', 'ミヤギケン', '亘理郡亘理町', 'ワタリグンワタリチョウ', '芝西', 'シバニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県亘理郡亘理町下小路', '04', '04361', '9892351', '宮城県', 'ミヤギケン', '亘理郡亘理町', 'ワタリグンワタリチョウ', '下小路', 'シモコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県亘理郡亘理町下浜街道', '04', '04361', '9892351', '宮城県', 'ミヤギケン', '亘理郡亘理町', 'ワタリグンワタリチョウ', '下浜街道', 'シモハマカイドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県亘理郡亘理町下茨田', '04', '04361', '9892351', '宮城県', 'ミヤギケン', '亘理郡亘理町', 'ワタリグンワタリチョウ', '下茨田', 'シモバラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県亘理郡亘理町新町', '04', '04361', '9892351', '宮城県', 'ミヤギケン', '亘理郡亘理町', 'ワタリグンワタリチョウ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県亘理郡亘理町台田', '04', '04361', '9892351', '宮城県', 'ミヤギケン', '亘理郡亘理町', 'ワタリグンワタリチョウ', '台田', 'ダイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県亘理郡亘理町道田中', '04', '04361', '9892351', '宮城県', 'ミヤギケン', '亘理郡亘理町', 'ワタリグンワタリチョウ', '道田中', 'ドウダナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県亘理郡亘理町道田西', '04', '04361', '9892351', '宮城県', 'ミヤギケン', '亘理郡亘理町', 'ワタリグンワタリチョウ', '道田西', 'ドウダニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県亘理郡亘理町道田東', '04', '04361', '9892351', '宮城県', 'ミヤギケン', '亘理郡亘理町', 'ワタリグンワタリチョウ', '道田東', 'ドウダヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県亘理郡亘理町中町', '04', '04361', '9892351', '宮城県', 'ミヤギケン', '亘理郡亘理町', 'ワタリグンワタリチョウ', '中町', 'ナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県亘理郡亘理町中町東', '04', '04361', '9892351', '宮城県', 'ミヤギケン', '亘理郡亘理町', 'ワタリグンワタリチョウ', '中町東', 'ナカマチヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県亘理郡亘理町新井町', '04', '04361', '9892351', '宮城県', 'ミヤギケン', '亘理郡亘理町', 'ワタリグンワタリチョウ', '新井町', 'ニイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県亘理郡亘理町西郷', '04', '04361', '9892351', '宮城県', 'ミヤギケン', '亘理郡亘理町', 'ワタリグンワタリチョウ', '西郷', 'ニシゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県亘理郡亘理町茨田後', '04', '04361', '9892351', '宮城県', 'ミヤギケン', '亘理郡亘理町', 'ワタリグンワタリチョウ', '茨田後', 'バラダウシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県亘理郡亘理町東郷', '04', '04361', '9892351', '宮城県', 'ミヤギケン', '亘理郡亘理町', 'ワタリグンワタリチョウ', '東郷', 'ヒガシゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県亘理郡亘理町見田内', '04', '04361', '9892351', '宮城県', 'ミヤギケン', '亘理郡亘理町', 'ワタリグンワタリチョウ', '見田内', 'ミダウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県亘理郡亘理町南町', '04', '04361', '9892351', '宮城県', 'ミヤギケン', '亘理郡亘理町', 'ワタリグンワタリチョウ', '南町', 'ミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県亘理郡亘理町南町東', '04', '04361', '9892351', '宮城県', 'ミヤギケン', '亘理郡亘理町', 'ワタリグンワタリチョウ', '南町東', 'ミナミマチヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県亘理郡亘理町愛宕前', '04', '04361', '9892361', '宮城県', 'ミヤギケン', '亘理郡亘理町', 'ワタリグンワタリチョウ', '愛宕前', 'アタゴマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県亘理郡亘理町泉ケ入', '04', '04361', '9892361', '宮城県', 'ミヤギケン', '亘理郡亘理町', 'ワタリグンワタリチョウ', '泉ケ入', 'イズミガイリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県亘理郡亘理町北猿田', '04', '04361', '9892361', '宮城県', 'ミヤギケン', '亘理郡亘理町', 'ワタリグンワタリチョウ', '北猿田', 'キタサルタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県亘理郡亘理町倉庭', '04', '04361', '9892361', '宮城県', 'ミヤギケン', '亘理郡亘理町', 'ワタリグンワタリチョウ', '倉庭', 'クラニワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県亘理郡亘理町先達前', '04', '04361', '9892361', '宮城県', 'ミヤギケン', '亘理郡亘理町', 'ワタリグンワタリチョウ', '先達前', 'センダツマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県亘理郡亘理町舘南', '04', '04361', '9892361', '宮城県', 'ミヤギケン', '亘理郡亘理町', 'ワタリグンワタリチョウ', '舘南', 'タテミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県亘理郡亘理町鳥居前', '04', '04361', '9892361', '宮城県', 'ミヤギケン', '亘理郡亘理町', 'ワタリグンワタリチョウ', '鳥居前', 'トリイマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県亘理郡亘理町沼頭', '04', '04361', '9892361', '宮城県', 'ミヤギケン', '亘理郡亘理町', 'ワタリグンワタリチョウ', '沼頭', 'ヌマガシラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県亘理郡亘理町卑下入', '04', '04361', '9892361', '宮城県', 'ミヤギケン', '亘理郡亘理町', 'ワタリグンワタリチョウ', '卑下入', 'ヒガイリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県亘理郡亘理町堀の内', '04', '04361', '9892361', '宮城県', 'ミヤギケン', '亘理郡亘理町', 'ワタリグンワタリチョウ', '堀の内', 'ホリノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県亘理郡亘理町雪穴', '04', '04361', '9892361', '宮城県', 'ミヤギケン', '亘理郡亘理町', 'ワタリグンワタリチョウ', '雪穴', 'ユキアナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県亘理郡亘理町龍円寺前', '04', '04361', '9892361', '宮城県', 'ミヤギケン', '亘理郡亘理町', 'ワタリグンワタリチョウ', '龍円寺前', 'リュウエンジマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県亘理郡亘理町逢隈鹿島', '04', '04361', '9892371', '宮城県', 'ミヤギケン', '亘理郡亘理町', 'ワタリグンワタリチョウ', '逢隈鹿島', 'オオクマカシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県亘理郡亘理町逢隈神宮寺', '04', '04361', '9892372', '宮城県', 'ミヤギケン', '亘理郡亘理町', 'ワタリグンワタリチョウ', '逢隈神宮寺', 'オオクマジングウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県亘理郡亘理町逢隈上郡', '04', '04361', '9892381', '宮城県', 'ミヤギケン', '亘理郡亘理町', 'ワタリグンワタリチョウ', '逢隈上郡', 'オオクマカミゴオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県亘理郡亘理町逢隈下郡', '04', '04361', '9892382', '宮城県', 'ミヤギケン', '亘理郡亘理町', 'ワタリグンワタリチョウ', '逢隈下郡', 'オオクマシモゴオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県亘理郡亘理町逢隈田沢', '04', '04361', '9892383', '宮城県', 'ミヤギケン', '亘理郡亘理町', 'ワタリグンワタリチョウ', '逢隈田沢', 'オオクマタザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県亘理郡亘理町逢隈小山', '04', '04361', '9892384', '宮城県', 'ミヤギケン', '亘理郡亘理町', 'ワタリグンワタリチョウ', '逢隈小山', 'オオクマコヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県亘理郡亘理町逢隈郡', '04', '04361', '9892385', '宮城県', 'ミヤギケン', '亘理郡亘理町', 'ワタリグンワタリチョウ', '逢隈', 'オオクマ', null, null, '郡', 'コオリ');
INSERT INTO `ms_addresses` VALUES ('143525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県岩沼市', '04', '04211', '9892400', '宮城県', 'ミヤギケン', '岩沼市', 'イワヌマシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('143526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県名取市下増田仙台空港関係施設', '04', '04207', '9892401', '宮城県', 'ミヤギケン', '名取市', 'ナトリシ', '下増田', 'シモマスダ', null, null, '仙台空港関係施設', 'センダイクウコウカンケイシセツ');
INSERT INTO `ms_addresses` VALUES ('143527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県名取市下増田南原無番地', '04', '04207', '9892401', '宮城県', 'ミヤギケン', '名取市', 'ナトリシ', '下増田', 'シモマスダ', null, null, '南原無番地', 'ミナミハラムバンチ');
INSERT INTO `ms_addresses` VALUES ('143528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県名取市本郷', '04', '04207', '9892411', '宮城県', 'ミヤギケン', '名取市', 'ナトリシ', '本郷', 'ホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県名取市堀内', '04', '04207', '9892412', '宮城県', 'ミヤギケン', '名取市', 'ナトリシ', '堀内', 'ホリウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県岩沼市下野郷', '04', '04211', '9892421', '宮城県', 'ミヤギケン', '岩沼市', 'イワヌマシ', '下野郷', 'シモノゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県岩沼市空港南', '04', '04211', '9892422', '宮城県', 'ミヤギケン', '岩沼市', 'イワヌマシ', '空港南', 'クウコウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県岩沼市押分', '04', '04211', '9892423', '宮城県', 'ミヤギケン', '岩沼市', 'イワヌマシ', '押分', 'オシワケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県岩沼市早股', '04', '04211', '9892424', '宮城県', 'ミヤギケン', '岩沼市', 'イワヌマシ', '早股', 'ハヤマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県岩沼市寺島', '04', '04211', '9892425', '宮城県', 'ミヤギケン', '岩沼市', 'イワヌマシ', '寺島', 'テラシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県岩沼市末広', '04', '04211', '9892426', '宮城県', 'ミヤギケン', '岩沼市', 'イワヌマシ', '末広', 'スエヒロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県岩沼市里の杜', '04', '04211', '9892427', '宮城県', 'ミヤギケン', '岩沼市', 'イワヌマシ', '里の杜', 'サトノモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県岩沼市相の原', '04', '04211', '9892431', '宮城県', 'ミヤギケン', '岩沼市', 'イワヌマシ', '相の原', 'アイノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県岩沼市中央', '04', '04211', '9892432', '宮城県', 'ミヤギケン', '岩沼市', 'イワヌマシ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県岩沼市桜', '04', '04211', '9892433', '宮城県', 'ミヤギケン', '岩沼市', 'イワヌマシ', '桜', 'サクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県岩沼市藤浪', '04', '04211', '9892434', '宮城県', 'ミヤギケン', '岩沼市', 'イワヌマシ', '藤浪', 'フジナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県岩沼市阿武隈', '04', '04211', '9892435', '宮城県', 'ミヤギケン', '岩沼市', 'イワヌマシ', '阿武隈', 'アブクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県岩沼市吹上', '04', '04211', '9892436', '宮城県', 'ミヤギケン', '岩沼市', 'イワヌマシ', '吹上', 'フキアゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県岩沼市吹上西', '04', '04211', '9892437', '宮城県', 'ミヤギケン', '岩沼市', 'イワヌマシ', '吹上西', 'フキアゲニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県岩沼市館下', '04', '04211', '9892441', '宮城県', 'ミヤギケン', '岩沼市', 'イワヌマシ', '館下', 'タテシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県岩沼市大手町', '04', '04211', '9892442', '宮城県', 'ミヤギケン', '岩沼市', 'イワヌマシ', '大手町', 'オオテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県岩沼市稲荷町', '04', '04211', '9892443', '宮城県', 'ミヤギケン', '岩沼市', 'イワヌマシ', '稲荷町', 'イナリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県岩沼市本町', '04', '04211', '9892444', '宮城県', 'ミヤギケン', '岩沼市', 'イワヌマシ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県岩沼市桑原', '04', '04211', '9892445', '宮城県', 'ミヤギケン', '岩沼市', 'イワヌマシ', '桑原', 'クワバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県岩沼市西六角', '04', '04211', '9892446', '宮城県', 'ミヤギケン', '岩沼市', 'イワヌマシ', '西六角', 'ニシロッカク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県岩沼市桑原西', '04', '04211', '9892447', '宮城県', 'ミヤギケン', '岩沼市', 'イワヌマシ', '桑原西', 'クワバラニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県岩沼市二木', '04', '04211', '9892448', '宮城県', 'ミヤギケン', '岩沼市', 'イワヌマシ', '二木', 'フタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県岩沼市土ケ崎', '04', '04211', '9892451', '宮城県', 'ミヤギケン', '岩沼市', 'イワヌマシ', '土ケ崎', 'ドガサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県岩沼市武隈', '04', '04211', '9892452', '宮城県', 'ミヤギケン', '岩沼市', 'イワヌマシ', '武隈', 'タケクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県岩沼市大昭和', '04', '04211', '9892453', '宮城県', 'ミヤギケン', '岩沼市', 'イワヌマシ', '大昭和', 'ダイショウワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県岩沼市南長谷', '04', '04211', '9892454', '宮城県', 'ミヤギケン', '岩沼市', 'イワヌマシ', '南長谷', 'ミナミハセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県岩沼市北長谷', '04', '04211', '9892455', '宮城県', 'ミヤギケン', '岩沼市', 'イワヌマシ', '北長谷', 'キタハセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県岩沼市松ケ丘', '04', '04211', '9892456', '宮城県', 'ミヤギケン', '岩沼市', 'イワヌマシ', '松ケ丘', 'マツガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県岩沼市平等', '04', '04211', '9892457', '宮城県', 'ミヤギケン', '岩沼市', 'イワヌマシ', '平等', 'ビョウドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県岩沼市竹の里', '04', '04211', '9892458', '宮城県', 'ミヤギケン', '岩沼市', 'イワヌマシ', '竹の里', 'タケノサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県岩沼市たけくま', '04', '04211', '9892459', '宮城県', 'ミヤギケン', '岩沼市', 'イワヌマシ', 'たけくま', 'タケクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県岩沼市長岡', '04', '04211', '9892461', '宮城県', 'ミヤギケン', '岩沼市', 'イワヌマシ', '長岡', 'ナガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県岩沼市山桜', '04', '04211', '9892462', '宮城県', 'ミヤギケン', '岩沼市', 'イワヌマシ', '山桜', 'ヤマザクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県岩沼市荒井', '04', '04211', '9892463', '宮城県', 'ミヤギケン', '岩沼市', 'イワヌマシ', '荒井', 'アライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県岩沼市三色吉', '04', '04211', '9892464', '宮城県', 'ミヤギケン', '岩沼市', 'イワヌマシ', '三色吉', 'ミイロヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県岩沼市志賀', '04', '04211', '9892465', '宮城県', 'ミヤギケン', '岩沼市', 'イワヌマシ', '志賀', 'シガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県岩沼市小川', '04', '04211', '9892471', '宮城県', 'ミヤギケン', '岩沼市', 'イワヌマシ', '小川', 'オガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県岩沼市梶橋', '04', '04211', '9892472', '宮城県', 'ミヤギケン', '岩沼市', 'イワヌマシ', '梶橋', 'カジバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県岩沼市栄町', '04', '04211', '9892473', '宮城県', 'ミヤギケン', '岩沼市', 'イワヌマシ', '栄町', 'サカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県岩沼市朝日', '04', '04211', '9892474', '宮城県', 'ミヤギケン', '岩沼市', 'イワヌマシ', '朝日', 'アサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県岩沼市大和', '04', '04211', '9892475', '宮城県', 'ミヤギケン', '岩沼市', 'イワヌマシ', '大和', 'ヤマト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県岩沼市敷島', '04', '04211', '9892476', '宮城県', 'ミヤギケン', '岩沼市', 'イワヌマシ', '敷島', 'シキシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県岩沼市東谷地', '04', '04211', '9892477', '宮城県', 'ミヤギケン', '岩沼市', 'イワヌマシ', '東谷地', 'ヒガシヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区郷六', '04', '04101', '9893121', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '郷六', 'ゴウロク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区栗生', '04', '04101', '9893122', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '栗生', 'クリュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区錦ケ丘', '04', '04101', '9893123', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '錦ケ丘', 'ニシキガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区上愛子', '04', '04101', '9893124', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '上愛子', 'カミアヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区下愛子', '04', '04101', '9893125', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '下愛子', 'シモアヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区落合', '04', '04101', '9893126', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '落合', 'オチアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区愛子東', '04', '04101', '9893127', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '愛子東', 'アヤシヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区愛子中央', '04', '04101', '9893128', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '愛子中央', 'アヤシチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区国見ケ丘', '04', '04101', '9893201', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '国見ケ丘', 'クニミガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区中山台', '04', '04101', '9893202', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '中山台', 'ナカヤマダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区中山吉成', '04', '04101', '9893203', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '中山吉成', 'ナカヤマヨシナリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区南吉成', '04', '04101', '9893204', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '南吉成', 'ミナミヨシナリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区吉成', '04', '04101', '9893205', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '吉成', 'ヨシナリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区吉成台', '04', '04101', '9893206', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '吉成台', 'ヨシナリダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区赤坂', '04', '04101', '9893211', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '赤坂', 'アカサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区芋沢', '04', '04101', '9893212', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '芋沢', 'イモザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区大倉', '04', '04101', '9893213', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '大倉', 'オオクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区みやぎ台', '04', '04101', '9893214', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', 'みやぎ台', 'ミヤギダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区向田', '04', '04101', '9893215', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '向田', 'ムカイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区高野原', '04', '04101', '9893216', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '高野原', 'タカノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区作並', '04', '04101', '9893431', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '作並', 'サクナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区熊ケ根', '04', '04101', '9893432', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '熊ケ根', 'クマガネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区ニツカ', '04', '04101', '9893433', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', 'ニツカ', 'ニッカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県仙台市青葉区新川', '04', '04101', '9893434', '宮城県', 'ミヤギケン', '仙台市青葉区', 'センダイシアオバク', '新川', 'ニッカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市鹿島台船越', '04', '04215', '9894101', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '鹿島台船越', 'カシマダイフナコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市鹿島台木間塚', '04', '04215', '9894102', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '鹿島台木間塚', 'カシマダイキマヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市鹿島台平渡', '04', '04215', '9894103', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '鹿島台平渡', 'カシマダイヒラワタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市鹿島台広長', '04', '04215', '9894104', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '鹿島台広長', 'カシマダイヒロナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市鹿島台深谷', '04', '04215', '9894105', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '鹿島台深谷', 'カシマダイフカヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市鹿島台大迫', '04', '04215', '9894106', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '鹿島台大迫', 'カシマダイオオバサマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡美里町和多田沼', '04', '04505', '9894201', '宮城県', 'ミヤギケン', '遠田郡美里町', 'トオダグンミサトマチ', '和多田沼', 'ワダタヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡美里町福ケ袋', '04', '04505', '9894202', '宮城県', 'ミヤギケン', '遠田郡美里町', 'トオダグンミサトマチ', '福ケ袋', 'フクガフクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡美里町練牛', '04', '04505', '9894203', '宮城県', 'ミヤギケン', '遠田郡美里町', 'トオダグンミサトマチ', '練牛', 'ネリウシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡美里町大柳', '04', '04505', '9894204', '宮城県', 'ミヤギケン', '遠田郡美里町', 'トオダグンミサトマチ', '大柳', 'オオヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡美里町木間塚', '04', '04505', '9894205', '宮城県', 'ミヤギケン', '遠田郡美里町', 'トオダグンミサトマチ', '木間塚', 'キマツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡美里町二郷', '04', '04505', '9894206', '宮城県', 'ミヤギケン', '遠田郡美里町', 'トオダグンミサトマチ', '二郷', 'ニゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡美里町鳥谷坂一', '04', '04505', '9894207', '宮城県', 'ミヤギケン', '遠田郡美里町', 'トオダグンミサトマチ', '鳥谷坂一', 'トヤザカイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡美里町鳥谷坂二', '04', '04505', '9894208', '宮城県', 'ミヤギケン', '遠田郡美里町', 'トオダグンミサトマチ', '鳥谷坂二', 'トヤザカニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県遠田郡美里町新鳥谷坂', '04', '04505', '9894209', '宮城県', 'ミヤギケン', '遠田郡美里町', 'トオダグンミサトマチ', '新鳥谷坂', 'シントヤザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市田尻蕪栗', '04', '04215', '9894301', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '田尻蕪栗', 'タジリカブクリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市田尻大貫', '04', '04215', '9894302', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '田尻大貫', 'タジリオオヌキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市田尻大沢', '04', '04215', '9894303', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '田尻大沢', 'タジリオオサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市田尻北小牛田', '04', '04215', '9894304', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '田尻北小牛田', 'タジリキタコゴタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市田尻小塩', '04', '04215', '9894305', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '田尻小塩', 'タジリオシオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市田尻桜田高野', '04', '04215', '9894306', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '田尻桜田高野', 'タジリサクラダコウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市田尻北高城', '04', '04215', '9894307', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '田尻北高城', 'タジリキタタカギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市田尻沼部', '04', '04215', '9894308', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '田尻沼部', 'タジリヌマベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市田尻八幡', '04', '04215', '9894411', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '田尻八幡', 'タジリヤワタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市田尻大嶺', '04', '04215', '9894412', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '田尻大嶺', 'タジリオオミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市田尻通木', '04', '04215', '9894413', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '田尻通木', 'タジリトオリキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市田尻北牧目', '04', '04215', '9894414', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '田尻北牧目', 'タジリキタマギノメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市田尻', '04', '04215', '9894415', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '田尻', 'タジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市田尻中目', '04', '04215', '9894416', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '田尻中目', 'タジリナカノメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市田尻沼木', '04', '04215', '9894417', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '田尻沼木', 'タジリヌマギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市田尻諏訪峠', '04', '04215', '9894418', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '田尻諏訪峠', 'タジリスワトウゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市田尻小松', '04', '04215', '9894419', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '田尻小松', 'タジリコマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市瀬峰力石', '04', '04213', '9894503', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '瀬峰力石', 'セミネチカライシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市瀬峰小深沢', '04', '04213', '9894504', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '瀬峰小深沢', 'セミネコブカサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市瀬峰刈安沢', '04', '04213', '9894505', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '瀬峰刈安沢', 'セミネカリヤスザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市瀬峰清水沢', '04', '04213', '9894506', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '瀬峰清水沢', 'セミネシミズサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市瀬峰西原', '04', '04213', '9894507', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '瀬峰西原', 'セミネニシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市瀬峰柴ノ脇', '04', '04213', '9894508', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '瀬峰柴ノ脇', 'セミネシバノワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市瀬峰大鰐谷', '04', '04213', '9894509', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '瀬峰大鰐谷', 'セミネオオワニヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市瀬峰新下藤沢', '04', '04213', '9894510', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '瀬峰新下藤沢', 'セミネシンシタフジサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市瀬峰新田沢', '04', '04213', '9894511', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '瀬峰新田沢', 'セミネニッタザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市瀬峰下藤沢', '04', '04213', '9894512', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '瀬峰下藤沢', 'セミネシモフジサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市瀬峰根岸', '04', '04213', '9894513', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '瀬峰根岸', 'セミネネギシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市瀬峰桃生田前', '04', '04213', '9894514', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '瀬峰桃生田前', 'セミネモノウタマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市瀬峰桃生田', '04', '04213', '9894515', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '瀬峰桃生田', 'セミネモノウタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市瀬峰長者原', '04', '04213', '9894516', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '瀬峰長者原', 'セミネチョウジャハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市瀬峰藤沢瀬嶺', '04', '04213', '9894517', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '瀬峰藤沢瀬嶺', 'セミネフジサワセミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市瀬峰荒神堂', '04', '04213', '9894518', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '瀬峰荒神堂', 'セミネコウジンドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市瀬峰横森前', '04', '04213', '9894519', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '瀬峰横森前', 'セミネヨコモリマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市瀬峰下田', '04', '04213', '9894521', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '瀬峰下田', 'セミネシモダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市瀬峰下の前', '04', '04213', '9894522', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '瀬峰下の前', 'セミネシモノマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市瀬峰北谷地', '04', '04213', '9894523', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '瀬峰北谷地', 'セミネキタヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市瀬峰藤田', '04', '04213', '9894524', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '瀬峰藤田', 'セミネフジタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市瀬峰下谷地', '04', '04213', '9894525', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '瀬峰下谷地', 'セミネシモヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市瀬峰宮小路原西', '04', '04213', '9894526', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '瀬峰宮小路原西', 'セミネミヤコウジハラニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市瀬峰宮小路原東', '04', '04213', '9894527', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '瀬峰宮小路原東', 'セミネミヤコウジハラヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市瀬峰山崎前', '04', '04213', '9894528', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '瀬峰山崎前', 'セミネヤマザキマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市瀬峰新下田', '04', '04213', '9894529', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '瀬峰新下田', 'セミネシンシモダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市瀬峰筒ケ崎', '04', '04213', '9894531', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '瀬峰筒ケ崎', 'セミネドガサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市瀬峰樋口山', '04', '04213', '9894532', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '瀬峰樋口山', 'セミネヒグチヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市瀬峰愛宕', '04', '04213', '9894533', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '瀬峰愛宕', 'セミネアタゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市瀬峰泉谷', '04', '04213', '9894534', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '瀬峰泉谷', 'セミネイズミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市瀬峰泉谷南', '04', '04213', '9894535', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '瀬峰泉谷南', 'セミネイズミヤミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市瀬峰壇ノ越', '04', '04213', '9894536', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '瀬峰壇ノ越', 'セミネダンノコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市瀬峰船橋', '04', '04213', '9894537', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '瀬峰船橋', 'セミネフナバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市瀬峰諏訪原', '04', '04213', '9894538', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '瀬峰諏訪原', 'セミネスワハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市瀬峰二ツ谷', '04', '04213', '9894539', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '瀬峰二ツ谷', 'セミネフタツヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市瀬峰牛渕前', '04', '04213', '9894540', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '瀬峰牛渕前', 'セミネウシブチマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市瀬峰牛渕', '04', '04213', '9894541', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '瀬峰牛渕', 'セミネウシブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市瀬峰新井堀', '04', '04213', '9894542', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '瀬峰新井堀', 'セミネニイボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市瀬峰新井屋敷', '04', '04213', '9894543', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '瀬峰新井屋敷', 'セミネニイヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市瀬峰除', '04', '04213', '9894544', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '瀬峰除', 'セミネノゾキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市瀬峰伊勢堂', '04', '04213', '9894545', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '瀬峰伊勢堂', 'セミネイセドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市瀬峰四ツ壇', '04', '04213', '9894546', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '瀬峰四ツ壇', 'セミネヨツダン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市瀬峰神田', '04', '04213', '9894547', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '瀬峰神田', 'セミネカミタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市瀬峰長根', '04', '04213', '9894548', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '瀬峰長根', 'セミネナガネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市瀬峰荒町', '04', '04213', '9894549', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '瀬峰荒町', 'セミネアラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市瀬峰三代', '04', '04213', '9894551', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '瀬峰三代', 'セミネサンダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市瀬峰宮田', '04', '04213', '9894552', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '瀬峰宮田', 'セミネミヤタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市瀬峰二又', '04', '04213', '9894553', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '瀬峰二又', 'セミネフタマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市瀬峰原田', '04', '04213', '9894554', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '瀬峰原田', 'セミネハラタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市瀬峰野沢', '04', '04213', '9894555', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '瀬峰野沢', 'セミネノザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市瀬峰袋沢', '04', '04213', '9894556', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '瀬峰袋沢', 'セミネフクロサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市瀬峰上沢田', '04', '04213', '9894557', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '瀬峰上沢田', 'セミネカミサワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市瀬峰新道東', '04', '04213', '9894560', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '瀬峰新道東', 'セミネシンドウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市瀬峰樋渡', '04', '04213', '9894561', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '瀬峰樋渡', 'セミネヒワタシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市瀬峰川ノ畑', '04', '04213', '9894562', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '瀬峰川ノ畑', 'セミネカワノハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市瀬峰谷地田', '04', '04213', '9894564', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '瀬峰谷地田', 'セミネヤチタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市瀬峰天神下', '04', '04213', '9894565', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '瀬峰天神下', 'セミネテンジンシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市瀬峰上屋敷', '04', '04213', '9894566', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '瀬峰上屋敷', 'セミネカミヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市瀬峰西原前', '04', '04213', '9894567', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '瀬峰西原前', 'セミネニシハラマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市瀬峰大屋敷', '04', '04213', '9894568', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '瀬峰大屋敷', 'セミネオオヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市瀬峰筒場', '04', '04213', '9894569', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '瀬峰筒場', 'セミネドバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市瀬峰町田前', '04', '04213', '9894570', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '瀬峰町田前', 'セミネマチダマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市瀬峰寺沢', '04', '04213', '9894571', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '瀬峰寺沢', 'セミネテラサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市瀬峰寺浦', '04', '04213', '9894572', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '瀬峰寺浦', 'セミネテラウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市瀬峰十王堂前', '04', '04213', '9894573', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '瀬峰十王堂前', 'セミネジュウオウドウマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市瀬峰北ノ沢', '04', '04213', '9894574', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '瀬峰北ノ沢', 'セミネキタノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市瀬峰町田', '04', '04213', '9894575', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '瀬峰町田', 'セミネマチダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市瀬峰高土山', '04', '04213', '9894576', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '瀬峰高土山', 'セミネコウドサン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市瀬峰薬沢西', '04', '04213', '9894577', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '瀬峰薬沢西', 'セミネクスリザワニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市瀬峰薬沢東', '04', '04213', '9894578', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '瀬峰薬沢東', 'セミネクスリザワヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市瀬峰橋本浦', '04', '04213', '9894579', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '瀬峰橋本浦', 'セミネハシモトウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市瀬峰大境前', '04', '04213', '9894580', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '瀬峰大境前', 'セミネオオサカイマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市瀬峰藤沢要害', '04', '04213', '9894581', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '瀬峰藤沢要害', 'セミネフジサワヨウガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市瀬峰坂ノ下浦', '04', '04213', '9894582', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '瀬峰坂ノ下浦', 'セミネサカノシタウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市瀬峰大境山', '04', '04213', '9894583', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '瀬峰大境山', 'セミネオオザカイヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市瀬峰清水山', '04', '04213', '9894584', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '瀬峰清水山', 'セミネシミズヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市瀬峰坂ノ下前北', '04', '04213', '9894585', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '瀬峰坂ノ下前北', 'セミネサカノシタマエキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市瀬峰蔵王', '04', '04213', '9894586', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '瀬峰蔵王', 'セミネゾウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市瀬峰薬師堂前', '04', '04213', '9894587', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '瀬峰薬師堂前', 'セミネヤクシドウマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市瀬峰蒲盛', '04', '04213', '9894588', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '瀬峰蒲盛', 'セミネカバモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市瀬峰富要害', '04', '04213', '9894589', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '瀬峰富要害', 'セミネトミヨウガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市迫町新田', '04', '04212', '9894601', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '迫町新田', 'ハサマチョウニッタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市石越町北郷', '04', '04212', '9894701', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '石越町北郷', 'イシコシマチキタゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市石越町東郷', '04', '04212', '9894702', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '石越町東郷', 'イシコシマチヒガシゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県登米市石越町南郷', '04', '04212', '9894703', '宮城県', 'ミヤギケン', '登米市', 'トメシ', '石越町南郷', 'イシコシマチミナミゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市金成末野', '04', '04213', '9894802', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '金成末野', 'カンナリスエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市金成藤渡戸', '04', '04213', '9894803', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '金成藤渡戸', 'カンナリフジワタト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市金成片馬合', '04', '04213', '9894805', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '金成片馬合', 'カンナリカタマセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市金成有壁', '04', '04213', '9894806', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '金成有壁', 'カンナリアリカベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市金成赤児', '04', '04213', '9894807', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '金成赤児', 'カンナリアカチゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市金成普賢堂', '04', '04213', '9894808', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '金成普賢堂', 'カンナリフゲンドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市金成日向', '04', '04213', '9895111', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '金成日向', 'カンナリヒムカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市金成宇南崎', '04', '04213', '9895112', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '金成宇南崎', 'カンナリウナンザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市金成宮前', '04', '04213', '9895113', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '金成宮前', 'カンナリミヤマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市金成下富田', '04', '04213', '9895114', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '金成下富田', 'カンナリシモトミダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市金成上富田', '04', '04213', '9895115', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '金成上富田', 'カンナリカミトミダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市金成大梨', '04', '04213', '9895116', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '金成大梨', 'カンナリオオナシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市金成柧木沢', '04', '04213', '9895117', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '金成柧木沢', 'カンナリハヌキザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市金成入ノ沢', '04', '04213', '9895118', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '金成入ノ沢', 'カンナリイリノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市金成狼ノ沢', '04', '04213', '9895119', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '金成狼ノ沢', 'カンナリオイノザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市金成大平', '04', '04213', '9895121', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '金成大平', 'カンナリオオヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市金成三沢', '04', '04213', '9895122', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '金成三沢', 'カンナリミサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市金成平治屋敷', '04', '04213', '9895123', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '金成平治屋敷', 'カンナリヘイジヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市金成山中堤下', '04', '04213', '9895124', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '金成山中堤下', 'カンナリヤマナカツツミシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市金成大林寺沢', '04', '04213', '9895125', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '金成大林寺沢', 'カンナリダイリンジザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市金成鍔ノ瓦', '04', '04213', '9895126', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '金成鍔ノ瓦', 'カンナリツバノカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市金成稲荷前', '04', '04213', '9895127', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '金成稲荷前', 'カンナリイナリマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市金成金山沢', '04', '04213', '9895128', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '金成金山沢', 'カンナリカナヤマザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市金成清水田', '04', '04213', '9895130', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '金成清水田', 'カンナリシミズタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市金成日向田', '04', '04213', '9895131', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '金成日向田', 'カンナリヒムカイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143752', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市金成干谷沢', '04', '04213', '9895132', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '金成干谷沢', 'カンナリホシヤザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143753', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市金成新町', '04', '04213', '9895133', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '金成新町', 'カンナリシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市金成新町裏', '04', '04213', '9895134', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '金成新町裏', 'カンナリシンマチウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市金成台畑', '04', '04213', '9895135', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '金成台畑', 'カンナリダイハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市金成熊ノ下', '04', '04213', '9895136', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '金成熊ノ下', 'カンナリクマノシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市金成髪長', '04', '04213', '9895137', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '金成髪長', 'カンナリカミナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市金成翁沢', '04', '04213', '9895138', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '金成翁沢', 'カンナリオキナザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市金成黄金田', '04', '04213', '9895139', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '金成黄金田', 'カンナリコガネダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市金成翁留', '04', '04213', '9895141', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '金成翁留', 'カンナリオキナドメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市金成入生田', '04', '04213', '9895142', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '金成入生田', 'カンナリイリウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市金成奉公田', '04', '04213', '9895143', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '金成奉公田', 'カンナリホウコウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市金成中町', '04', '04213', '9895144', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '金成中町', 'カンナリナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市金成中町西裏', '04', '04213', '9895145', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '金成中町西裏', 'カンナリナカマチニシウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市金成祝', '04', '04213', '9895146', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '金成祝', 'カンナリイワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市金成桜町', '04', '04213', '9895151', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '金成桜町', 'カンナリサクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市金成四ツ屋敷', '04', '04213', '9895152', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '金成四ツ屋敷', 'カンナリヨツヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市金成上町東裏', '04', '04213', '9895153', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '金成上町東裏', 'カンナリカミマチヒガシウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市金成上町', '04', '04213', '9895154', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '金成上町', 'カンナリカミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市金成上町西裏', '04', '04213', '9895155', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '金成上町西裏', 'カンナリカミマチニシウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市金成館下', '04', '04213', '9895161', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '金成館下', 'カンナリタテシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市金成長根沢', '04', '04213', '9895162', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '金成長根沢', 'カンナリナガネザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市金成大久保沢', '04', '04213', '9895163', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '金成大久保沢', 'カンナリオオクボサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市金成金生', '04', '04213', '9895164', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '金成金生', 'カンナリキンセイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市金成長館', '04', '04213', '9895165', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '金成長館', 'カンナリナガタテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市金成長根前', '04', '04213', '9895166', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '金成長根前', 'カンナリナガネマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市金成沢辺', '04', '04213', '9895171', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '金成沢辺', 'カンナリサワベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市金成姉歯', '04', '04213', '9895172', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '金成姉歯', 'カンナリアネハ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市金成梨崎', '04', '04213', '9895173', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '金成梨崎', 'カンナリナシザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市金成津久毛', '04', '04213', '9895181', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '金成津久毛', 'カンナリツクモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市金成小堤', '04', '04213', '9895183', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '金成小堤', 'カンナリオツツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市金成小迫', '04', '04213', '9895184', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '金成小迫', 'カンナリオバサマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市金成大原木', '04', '04213', '9895185', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '金成大原木', 'カンナリオオハラギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市栗駒岩ケ崎', '04', '04213', '9895301', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '栗駒岩ケ崎', 'クリコマイワガサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市栗駒里谷', '04', '04213', '9895311', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '栗駒里谷', 'クリコマサトヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市栗駒猿飛来', '04', '04213', '9895312', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '栗駒猿飛来', 'クリコマサッピライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市栗駒栗原', '04', '04213', '9895321', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '栗駒栗原', 'クリコマクリバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市栗駒桜田', '04', '04213', '9895322', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '栗駒桜田', 'クリコマサクラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市栗駒菱沼', '04', '04213', '9895323', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '栗駒菱沼', 'クリコマヒシヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市栗駒八幡', '04', '04213', '9895324', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '栗駒八幡', 'クリコマヤハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市栗駒泉沢', '04', '04213', '9895331', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '栗駒泉沢', 'クリコマイズミザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市栗駒芋埣', '04', '04213', '9895332', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '栗駒芋埣', 'クリコマイモゾネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市栗駒片子沢', '04', '04213', '9895333', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '栗駒片子沢', 'クリコマカタゴザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市栗駒嶺崎', '04', '04213', '9895334', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '栗駒嶺崎', 'クリコマミネザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市栗駒渡丸', '04', '04213', '9895335', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '栗駒渡丸', 'クリコマワタマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市栗駒稲屋敷', '04', '04213', '9895341', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '栗駒稲屋敷', 'クリコマイナヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市栗駒中野', '04', '04213', '9895351', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '栗駒中野', 'クリコマナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市栗駒文字', '04', '04213', '9895361', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '栗駒文字', 'クリコマモンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市栗駒沼倉', '04', '04213', '9895371', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '栗駒沼倉', 'クリコマヌマクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市栗駒松倉', '04', '04213', '9895372', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '栗駒松倉', 'クリコママツクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市栗駒鳥沢', '04', '04213', '9895381', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '栗駒鳥沢', 'クリコマトリサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市栗駒深谷', '04', '04213', '9895382', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '栗駒深谷', 'クリコマフカヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市鶯沢袋', '04', '04213', '9895401', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '鶯沢袋', 'ウグイスザワフクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市鶯沢南郷', '04', '04213', '9895402', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '鶯沢南郷', 'ウグイスザワナンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市鶯沢北郷', '04', '04213', '9895403', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '鶯沢北郷', 'ウグイスザワキタゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市若柳川北', '04', '04213', '9895501', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '若柳川北', 'ワカヤナギカワキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市若柳川南', '04', '04213', '9895502', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '若柳川南', 'ワカヤナギカワミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市若柳下畑岡', '04', '04213', '9895503', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '若柳下畑岡', 'ワカヤナギシモハタオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市若柳上畑岡', '04', '04213', '9895504', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '若柳上畑岡', 'ワカヤナギカミハタオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市若柳福岡', '04', '04213', '9895505', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '若柳福岡', 'ワカヤナギフクオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市若柳大林', '04', '04213', '9895506', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '若柳大林', 'ワカヤナギオオハヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市若柳有賀', '04', '04213', '9895507', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '若柳有賀', 'ワカヤナギアリガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市若柳武鎗', '04', '04213', '9895508', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '若柳武鎗', 'ワカヤナギムヤリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市志波姫刈敷', '04', '04213', '9895601', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '志波姫刈敷', 'シワヒメカリシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市志波姫城内南', '04', '04213', '9895602', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '志波姫城内南', 'シワヒメジョウナイミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市志波姫伊豆野', '04', '04213', '9895603', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '志波姫伊豆野', 'シワヒメイズノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市志波姫大門南', '04', '04213', '9895604', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '志波姫大門南', 'シワヒメダイモンミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市志波姫北郷', '04', '04213', '9895605', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '志波姫北郷', 'シワヒメキタゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市志波姫荒町南', '04', '04213', '9895606', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '志波姫荒町南', 'シワヒメアラマチミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市志波姫蔵場南', '04', '04213', '9895607', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '志波姫蔵場南', 'シワヒメクラバミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市志波姫南郷', '04', '04213', '9895611', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '志波姫南郷', 'シワヒメミナミゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市志波姫新熊谷', '04', '04213', '9895612', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '志波姫新熊谷', 'シワヒメシンクマヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市志波姫新沼崎', '04', '04213', '9895613', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '志波姫新沼崎', 'シワヒメシンヌマザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市志波姫新原', '04', '04213', '9895614', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '志波姫新原', 'シワヒメシンハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市志波姫沼崎', '04', '04213', '9895615', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '志波姫沼崎', 'シワヒメヌマザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市志波姫新上戸', '04', '04213', '9895616', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '志波姫新上戸', 'シワヒメシンアガト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市志波姫新橋本', '04', '04213', '9895617', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '志波姫新橋本', 'シワヒメシンハシモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市志波姫新八樟', '04', '04213', '9895618', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '志波姫新八樟', 'シワヒメシンヤツクヌギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市志波姫下里', '04', '04213', '9895621', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '志波姫下里', 'シワヒメシモサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市志波姫八樟', '04', '04213', '9895622', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '志波姫八樟', 'シワヒメヤツクヌギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市志波姫南八樟', '04', '04213', '9895623', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '志波姫南八樟', 'シワヒメミナミヤツクヌギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市志波姫南堀口', '04', '04213', '9895624', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '志波姫南堀口', 'シワヒメミナミホリグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市志波姫堀口', '04', '04213', '9895625', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '志波姫堀口', 'シワヒメホリグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市志波姫中沖', '04', '04213', '9895626', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '志波姫中沖', 'シワヒメナカオキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市', '04', '04215', '9896100', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('143841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市古川福浦', '04', '04215', '9896101', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '古川福浦', 'フルカワフクウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市古川江合本町', '04', '04215', '9896102', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '古川江合本町', 'フルカワエアイホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市古川江合寿町', '04', '04215', '9896103', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '古川江合寿町', 'フルカワエアイコトブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市古川江合錦町', '04', '04215', '9896104', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '古川江合錦町', 'フルカワエアイニシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市古川福沼', '04', '04215', '9896105', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '古川福沼', 'フルカワフクヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市古川幸町', '04', '04215', '9896106', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '古川幸町', 'フルカワサイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市古川鶴ケ埣', '04', '04215', '9896111', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '古川鶴ケ埣', 'フルカワツルガソネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市古川馬寄', '04', '04215', '9896112', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '古川馬寄', 'フルカワマヨセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市古川蓑口沼', '04', '04215', '9896113', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '古川蓑口沼', 'フルカワミノクチヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市古川大幡', '04', '04215', '9896114', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '古川大幡', 'フルカワオオハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市古川駅東', '04', '04215', '9896115', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '古川駅東', 'フルカワエキヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市古川李埣', '04', '04215', '9896116', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '古川李埣', 'フルカワスモゾネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市古川旭', '04', '04215', '9896117', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '古川旭', 'フルカワアサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市古川深沼', '04', '04215', '9896121', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '古川深沼', 'フルカワフカヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市古川桑針', '04', '04215', '9896122', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '古川桑針', 'フルカワクワバリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市古川下中目', '04', '04215', '9896123', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '古川下中目', 'フルカワシモナカノメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市古川石森', '04', '04215', '9896124', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '古川石森', 'フルカワイシモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市古川師山', '04', '04215', '9896125', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '古川師山', 'フルカワモロヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市古川楡木', '04', '04215', '9896126', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '古川楡木', 'フルカワタマノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市古川宮内', '04', '04215', '9896127', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '古川宮内', 'フルカワミヤウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市古川境野宮', '04', '04215', '9896128', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '古川境野宮', 'フルカワサカイノミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市古川金五輪', '04', '04215', '9896131', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '古川金五輪', 'フルカワカナゴリン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市古川米袋', '04', '04215', '9896132', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '古川米袋', 'フルカワヨネブクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市古川西荒井', '04', '04215', '9896133', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '古川西荒井', 'フルカワニシアライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市古川米倉', '04', '04215', '9896134', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '古川米倉', 'フルカワヨネクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市古川稲葉', '04', '04215', '9896135', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '古川稲葉', 'フルカワイナバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市古川南新町', '04', '04215', '9896141', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '古川南新町', 'フルカワミナミシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市古川中島町', '04', '04215', '9896142', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '古川中島町', 'フルカワナカジマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市古川中里', '04', '04215', '9896143', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '古川中里', 'フルカワナカザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市古川小稲葉町', '04', '04215', '9896144', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '古川小稲葉町', 'フルカワコイナバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市古川北稲葉', '04', '04215', '9896145', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '古川北稲葉', 'フルカワキタイナバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市古川城西', '04', '04215', '9896151', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '古川城西', 'フルカワシロニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市古川二ノ構', '04', '04215', '9896152', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '古川二ノ構', 'フルカワニノカマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市古川七日町', '04', '04215', '9896153', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '古川七日町', 'フルカワナノカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市古川三日町', '04', '04215', '9896154', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '古川三日町', 'フルカワミッカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市古川南町', '04', '04215', '9896155', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '古川南町', 'フルカワミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市古川西館', '04', '04215', '9896156', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '古川西館', 'フルカワニシダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市古川栄町', '04', '04215', '9896157', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '古川栄町', 'フルカワサカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143879', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市古川駅南', '04', '04215', '9896161', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '古川駅南', 'フルカワエキミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市古川駅前大通', '04', '04215', '9896162', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '古川駅前大通', 'フルカワエキマエオオドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市古川台町', '04', '04215', '9896163', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '古川台町', 'フルカワダイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市古川荒川小金町', '04', '04215', '9896164', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '古川荒川小金町', 'フルカワアラカワコガネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市古川十日町', '04', '04215', '9896165', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '古川十日町', 'フルカワトオカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市古川東町', '04', '04215', '9896166', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '古川東町', 'フルカワヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市古川川端', '04', '04215', '9896167', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '古川川端', 'フルカワカワハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市古川北町', '04', '04215', '9896171', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '古川北町', 'フルカワキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市古川前田町', '04', '04215', '9896172', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '古川前田町', 'フルカワマエダチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市古川浦町', '04', '04215', '9896173', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '古川浦町', 'フルカワウラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市古川千手寺町', '04', '04215', '9896174', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '古川千手寺町', 'フルカワセンジュウジチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市古川諏訪', '04', '04215', '9896175', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '古川諏訪', 'フルカワスワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市古川渋井', '04', '04215', '9896201', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '古川渋井', 'フルカワシブイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市古川上中目', '04', '04215', '9896202', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '古川上中目', 'フルカワカミナカノメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市古川飯川', '04', '04215', '9896203', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '古川飯川', 'フルカワイイガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市古川矢目', '04', '04215', '9896204', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '古川矢目', 'フルカワヤノメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市古川新沼', '04', '04215', '9896205', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '古川新沼', 'フルカワニイヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市古川中沢', '04', '04215', '9896206', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '古川中沢', 'フルカワナカザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市古川堤根', '04', '04215', '9896207', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '古川堤根', 'フルカワツツミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市古川引田', '04', '04215', '9896208', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '古川引田', 'フルカワヒキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市古川斎下', '04', '04215', '9896211', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '古川斎下', 'フルカワサイゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市古川荒田目', '04', '04215', '9896212', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '古川荒田目', 'フルカワアラタノメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市古川保柳', '04', '04215', '9896213', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '古川保柳', 'フルカワホヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市古川新堀', '04', '04215', '9896214', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '古川新堀', 'フルカワニイボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市古川耳取', '04', '04215', '9896215', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '古川耳取', 'フルカワミミトリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市古川柏崎', '04', '04215', '9896216', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '古川柏崎', 'フルカワカシワザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市古川南沢', '04', '04215', '9896217', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '古川南沢', 'フルカワミナミザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市古川大宮', '04', '04215', '9896221', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '古川大宮', 'フルカワオオミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市古川若葉町', '04', '04215', '9896222', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '古川若葉町', 'フルカワワカバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市古川', '04', '04215', '9896223', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '古川', 'フルカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市古川小泉', '04', '04215', '9896224', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '古川小泉', 'フルカワコイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市古川塚目', '04', '04215', '9896225', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '古川塚目', 'フルカワツカノメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市古川新田', '04', '04215', '9896226', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '古川新田', 'フルカワニイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市古川大崎', '04', '04215', '9896227', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '古川大崎', 'フルカワオオサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市古川清水', '04', '04215', '9896228', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '古川清水', 'フルカワシミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市古川長岡', '04', '04215', '9896231', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '古川長岡', 'フルカワナガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市古川沢田', '04', '04215', '9896232', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '古川沢田', 'フルカワサワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市古川桜ノ目', '04', '04215', '9896233', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '古川桜ノ目', 'フルカワサクラノメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市古川小林', '04', '04215', '9896234', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '古川小林', 'フルカワオバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市古川宮沢', '04', '04215', '9896235', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '古川宮沢', 'フルカワミヤザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市古川川熊', '04', '04215', '9896236', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '古川川熊', 'フルカワカワクマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市古川清水沢', '04', '04215', '9896241', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '古川清水沢', 'フルカワシミズサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市古川北宮沢', '04', '04215', '9896242', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '古川北宮沢', 'フルカワキタミヤザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市古川雨生沢', '04', '04215', '9896243', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '古川雨生沢', 'フルカワアメオザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市古川清滝', '04', '04215', '9896244', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '古川清滝', 'フルカワキヨタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市古川小野', '04', '04215', '9896251', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '古川小野', 'フルカワコノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市古川荒谷', '04', '04215', '9896252', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '古川荒谷', 'フルカワアラヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市古川馬放', '04', '04215', '9896253', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '古川馬放', 'フルカワマハナシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市古川狐塚', '04', '04215', '9896254', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '古川狐塚', 'フルカワキツネヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市古川休塚', '04', '04215', '9896255', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '古川休塚', 'フルカワヤスミヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市古川長岡針', '04', '04215', '9896261', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '古川長岡針', 'フルカワナガオカハリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市古川馬櫛', '04', '04215', '9896262', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '古川馬櫛', 'フルカワマグシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市古川下谷地', '04', '04215', '9896263', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '古川下谷地', 'フルカワシモヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市古川上埣', '04', '04215', '9896264', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '古川上埣', 'フルカワカミゾネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市古川渕尻', '04', '04215', '9896265', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '古川渕尻', 'フルカワフチジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市古川富長', '04', '04215', '9896266', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '古川富長', 'フルカワトミナガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市三本木桑折', '04', '04215', '9896301', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '三本木桑折', 'サンボンギコオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市三本木上伊場野', '04', '04215', '9896302', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '三本木上伊場野', 'サンボンギカミイバノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市三本木伊場野', '04', '04215', '9896303', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '三本木伊場野', 'サンボンギイバノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市三本木秋田', '04', '04215', '9896304', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '三本木秋田', 'サンボンギアキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市三本木伊賀', '04', '04215', '9896305', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '三本木伊賀', 'サンボンギイガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市三本木新町', '04', '04215', '9896306', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '三本木新町', 'サンボンギシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市三本木坂本', '04', '04215', '9896311', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '三本木坂本', 'サンボンギサカモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市三本木蟻ケ袋', '04', '04215', '9896312', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '三本木蟻ケ袋', 'サンボンギアリガフクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市三本木音無', '04', '04215', '9896313', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '三本木音無', 'サンボンギオトナシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市三本木斉田', '04', '04215', '9896314', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '三本木斉田', 'サンボンギサイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市三本木新沼', '04', '04215', '9896315', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '三本木新沼', 'サンボンギニイヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市三本木高柳', '04', '04215', '9896316', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '三本木高柳', 'サンボンギタカヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市三本木蒜袋', '04', '04215', '9896317', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '三本木蒜袋', 'サンボンギヒルブクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市三本木', '04', '04215', '9896321', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '三本木', 'サンボンギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市三本木南谷地', '04', '04215', '9896322', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '三本木南谷地', 'サンボンギミナミヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市岩出山上真山', '04', '04215', '9896401', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '岩出山', 'イワデヤマ', null, null, '上真山', 'カミマヤマ');
INSERT INTO `ms_addresses` VALUES ('143959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市岩出山葛岡', '04', '04215', '9896401', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '岩出山', 'イワデヤマ', null, null, '葛岡', 'クズオカ');
INSERT INTO `ms_addresses` VALUES ('143960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市岩出山磯田', '04', '04215', '9896402', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '岩出山', 'イワデヤマ', null, null, '磯田', 'イソダ');
INSERT INTO `ms_addresses` VALUES ('143961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市岩出山下真山', '04', '04215', '9896402', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '岩出山', 'イワデヤマ', null, null, '下真山', 'シモマヤマ');
INSERT INTO `ms_addresses` VALUES ('143962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市岩出山上野目', '04', '04215', '9896403', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '岩出山上野目', 'イワデヤマカミノメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市岩出山下一栗', '04', '04215', '9896404', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '岩出山下一栗', 'イワデヤマシモイチクリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市岩出山池月', '04', '04215', '9896405', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '岩出山池月', 'イワデヤマイケツキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市岩出山船場', '04', '04215', '9896411', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '岩出山船場', 'イワデヤマフナバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市岩出山下野目', '04', '04215', '9896412', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '岩出山下野目', 'イワデヤマシモノメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市岩出山東川原町', '04', '04215', '9896413', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '岩出山東川原町', 'イワデヤマヒガシカワラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市岩出山下川原', '04', '04215', '9896414', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '岩出山下川原', 'イワデヤマシモカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市岩出山東川原', '04', '04215', '9896415', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '岩出山東川原', 'イワデヤマヒガシカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市岩出山上中江', '04', '04215', '9896421', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '岩出山上中江', 'イワデヤマカミナカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市岩出山重蔵', '04', '04215', '9896422', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '岩出山重蔵', 'イワデヤマジュウゾウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市岩出山前毘沙門', '04', '04215', '9896423', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '岩出山前毘沙門', 'イワデヤママエビシャモン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市岩出山丸山', '04', '04215', '9896424', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '岩出山丸山', 'イワデヤママルヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市岩出山西御名掛', '04', '04215', '9896425', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '岩出山西御名掛', 'イワデヤマニシオナカケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市岩出山東御名掛', '04', '04215', '9896426', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '岩出山東御名掛', 'イワデヤマヒガシオナカケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市岩出山上川原南', '04', '04215', '9896431', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '岩出山上川原南', 'イワデヤマカミカワラミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市岩出山上川原北', '04', '04215', '9896432', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '岩出山上川原北', 'イワデヤマカミカワラキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市岩出山上川原町', '04', '04215', '9896433', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '岩出山上川原町', 'イワデヤマカミカワラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市岩出山下川原町', '04', '04215', '9896434', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '岩出山下川原町', 'イワデヤマシモカワラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市岩出山浦小路', '04', '04215', '9896435', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '岩出山浦小路', 'イワデヤマウラコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市岩出山二ノ構', '04', '04215', '9896436', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '岩出山二ノ構', 'イワデヤマニノカマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市岩出山城山', '04', '04215', '9896437', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '岩出山城山', 'イワデヤマシロヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市岩出山通丁', '04', '04215', '9896441', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '岩出山通丁', 'イワデヤマトオリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市岩出山下金沢', '04', '04215', '9896442', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '岩出山下金沢', 'イワデヤマシモカネザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市岩出山轟', '04', '04215', '9896443', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '岩出山轟', 'イワデヤマトドロキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市岩出山細峰', '04', '04215', '9896444', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '岩出山細峰', 'イワデヤマホソミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市岩出山南沢', '04', '04215', '9896445', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '岩出山南沢', 'イワデヤマミナミザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市岩出山大学町', '04', '04215', '9896446', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '岩出山大学町', 'イワデヤマダイガクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市岩出山上金沢', '04', '04215', '9896447', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '岩出山上金沢', 'イワデヤマカミカネザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市岩出山松沢', '04', '04215', '9896461', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '岩出山松沢', 'イワデヤママツサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市岩出山蛭沢', '04', '04215', '9896462', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '岩出山蛭沢', 'イワデヤマヒルサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市岩出山木通沢', '04', '04215', '9896463', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '岩出山木通沢', 'イワデヤマアケビザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市岩出山下東昌寺沢', '04', '04215', '9896464', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '岩出山下東昌寺沢', 'イワデヤマシモトウショウジサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市岩出山上東昌寺沢', '04', '04215', '9896465', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '岩出山上東昌寺沢', 'イワデヤマカミトウショウジザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市岩出山保土沢', '04', '04215', '9896466', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '岩出山保土沢', 'イワデヤマホドサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市岩出山', '04', '04215', '9896471', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '岩出山', 'イワデヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('143999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県栗原市花山草木沢上原', '04', '04213', '9896701', '宮城県', 'ミヤギケン', '栗原市', 'クリハラシ', '花山草木沢上原', 'ハナヤマクサキサワウワハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市鳴子温泉赤這', '04', '04215', '9896711', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '鳴子温泉赤這', 'ナルコオンセンアカバイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市鳴子温泉石ノ梅', '04', '04215', '9896711', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '鳴子温泉石ノ梅', 'ナルコオンセンイシノウメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市鳴子温泉入沢', '04', '04215', '9896711', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '鳴子温泉入沢', 'ナルコオンセンイリサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市鳴子温泉上ノ原', '04', '04215', '9896711', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '鳴子温泉上ノ原', 'ナルコオンセンウエノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市鳴子温泉上川原', '04', '04215', '9896711', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '鳴子温泉上川原', 'ナルコオンセンカミガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市鳴子温泉通原', '04', '04215', '9896711', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '鳴子温泉通原', 'ナルコオンセンカヨバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市鳴子温泉川渡', '04', '04215', '9896711', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '鳴子温泉川渡', 'ナルコオンセンカワタビ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市鳴子温泉築沢', '04', '04215', '9896711', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '鳴子温泉築沢', 'ナルコオンセンキザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市鳴子温泉久田', '04', '04215', '9896711', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '鳴子温泉久田', 'ナルコオンセンキュウデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市鳴子温泉沢', '04', '04215', '9896711', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '鳴子温泉沢', 'ナルコオンセンサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市鳴子温泉新田', '04', '04215', '9896711', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '鳴子温泉新田', 'ナルコオンセンシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市鳴子温泉新町下', '04', '04215', '9896711', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '鳴子温泉新町下', 'ナルコオンセンシンマチシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市鳴子温泉玉ノ木', '04', '04215', '9896711', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '鳴子温泉玉ノ木', 'ナルコオンセンタマノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市鳴子温泉中野', '04', '04215', '9896711', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '鳴子温泉中野', 'ナルコオンセンナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市鳴子温泉沼井', '04', '04215', '9896711', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '鳴子温泉沼井', 'ナルコオンセンヌマイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市鳴子温泉馬場', '04', '04215', '9896711', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '鳴子温泉馬場', 'ナルコオンセンババ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市鳴子温泉原', '04', '04215', '9896711', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '鳴子温泉原', 'ナルコオンセンハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市鳴子温泉町', '04', '04215', '9896711', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '鳴子温泉町', 'ナルコオンセンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市鳴子温泉町下', '04', '04215', '9896711', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '鳴子温泉町下', 'ナルコオンセンマチシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市鳴子温泉町西', '04', '04215', '9896711', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '鳴子温泉町西', 'ナルコオンセンマチニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市鳴子温泉要害', '04', '04215', '9896711', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '鳴子温泉要害', 'ナルコオンセンヨウガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市鳴子温泉横山', '04', '04215', '9896711', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '鳴子温泉横山', 'ナルコオンセンヨコヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市鳴子温泉蓬田', '04', '04215', '9896711', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '鳴子温泉蓬田', 'ナルコオンセンヨモギダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市鳴子温泉小身川原', '04', '04215', '9896712', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '鳴子温泉小身川原', 'ナルコオンセンオミガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市鳴子温泉川袋', '04', '04215', '9896712', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '鳴子温泉川袋', 'ナルコオンセンカワブクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市鳴子温泉木戸脇', '04', '04215', '9896712', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '鳴子温泉木戸脇', 'ナルコオンセンキドワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市鳴子温泉黒崎', '04', '04215', '9896712', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '鳴子温泉黒崎', 'ナルコオンセンクロサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市鳴子温泉小室', '04', '04215', '9896712', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '鳴子温泉小室', 'ナルコオンセンコムロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市鳴子温泉小室山', '04', '04215', '9896712', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '鳴子温泉小室山', 'ナルコオンセンコムロヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市鳴子温泉境松', '04', '04215', '9896712', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '鳴子温泉境松', 'ナルコオンセンサカイマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市鳴子温泉坂ノ上', '04', '04215', '9896712', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '鳴子温泉坂ノ上', 'ナルコオンセンサカノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市鳴子温泉沢目木', '04', '04215', '9896712', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '鳴子温泉沢目木', 'ナルコオンセンサワメキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市鳴子温泉新小身川原', '04', '04215', '9896712', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '鳴子温泉新小身川原', 'ナルコオンセンシンオミガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市鳴子温泉関口', '04', '04215', '9896712', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '鳴子温泉関口', 'ナルコオンセンセキグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市鳴子温泉大尺', '04', '04215', '9896712', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '鳴子温泉大尺', 'ナルコオンセンダイシャク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市鳴子温泉滝岸', '04', '04215', '9896712', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '鳴子温泉滝岸', 'ナルコオンセンタキギシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市鳴子温泉竹原', '04', '04215', '9896712', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '鳴子温泉竹原', 'ナルコオンセンタケハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市鳴子温泉田中', '04', '04215', '9896712', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '鳴子温泉田中', 'ナルコオンセンタナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市鳴子温泉月山', '04', '04215', '9896712', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '鳴子温泉月山', 'ナルコオンセンツキヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市鳴子温泉堤下', '04', '04215', '9896712', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '鳴子温泉堤下', 'ナルコオンセンツツミシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市鳴子温泉鶴田', '04', '04215', '9896712', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '鳴子温泉鶴田', 'ナルコオンセンツルタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市鳴子温泉天神', '04', '04215', '9896712', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '鳴子温泉天神', 'ナルコオンセンテンジン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市鳴子温泉中道', '04', '04215', '9896712', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '鳴子温泉中道', 'ナルコオンセンナカミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市鳴子温泉野際', '04', '04215', '9896712', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '鳴子温泉野際', 'ナルコオンセンノギワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市鳴子温泉畑山', '04', '04215', '9896712', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '鳴子温泉畑山', 'ナルコオンセンハタヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市鳴子温泉原崎', '04', '04215', '9896712', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '鳴子温泉原崎', 'ナルコオンセンハラサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市鳴子温泉日向山', '04', '04215', '9896712', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '鳴子温泉日向山', 'ナルコオンセンヒナタヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市鳴子温泉不動山', '04', '04215', '9896712', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '鳴子温泉不動山', 'ナルコオンセンフドウヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市鳴子温泉前森', '04', '04215', '9896712', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '鳴子温泉前森', 'ナルコオンセンマエモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市鳴子温泉前山', '04', '04215', '9896712', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '鳴子温泉前山', 'ナルコオンセンマエヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市鳴子温泉水沼', '04', '04215', '9896712', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '鳴子温泉水沼', 'ナルコオンセンミズヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市鳴子温泉南山', '04', '04215', '9896712', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '鳴子温泉南山', 'ナルコオンセンミナミヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市鳴子温泉山際', '04', '04215', '9896712', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '鳴子温泉山際', 'ナルコオンセンヤマギワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市鳴子温泉和田', '04', '04215', '9896712', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '鳴子温泉和田', 'ナルコオンセンワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市鳴子温泉末沢', '04', '04215', '9896801', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '鳴子温泉末沢', 'ナルコオンセンスエザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市鳴子温泉末沢西', '04', '04215', '9896802', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '鳴子温泉末沢西', 'ナルコオンセンスエザワニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市鳴子温泉大畑', '04', '04215', '9896803', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '鳴子温泉大畑', 'ナルコオンセンオオバタケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市鳴子温泉中屋敷', '04', '04215', '9896804', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '鳴子温泉中屋敷', 'ナルコオンセンナカヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市鳴子温泉岩渕前', '04', '04215', '9896805', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '鳴子温泉岩渕前', 'ナルコオンセンイワブチマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市鳴子温泉岩渕', '04', '04215', '9896806', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '鳴子温泉岩渕', 'ナルコオンセンイワブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市鳴子温泉見手野原', '04', '04215', '9896807', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '鳴子温泉見手野原', 'ナルコオンセンミテノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市鳴子温泉赤湯', '04', '04215', '9896811', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '鳴子温泉赤湯', 'ナルコオンセンアカユ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市鳴子温泉鷲ノ巣', '04', '04215', '9896811', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '鳴子温泉鷲ノ巣', 'ナルコオンセンワシノス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市鳴子温泉車湯', '04', '04215', '9896821', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '鳴子温泉車湯', 'ナルコオンセンクルマユ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市鳴子温泉新屋敷', '04', '04215', '9896822', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '鳴子温泉新屋敷', 'ナルコオンセンシンヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市鳴子温泉湯元', '04', '04215', '9896823', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '鳴子温泉湯元', 'ナルコオンセンユモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市鳴子温泉河原湯', '04', '04215', '9896824', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '鳴子温泉河原湯', 'ナルコオンセンカワラユ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市鳴子温泉上鳴子', '04', '04215', '9896825', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '鳴子温泉上鳴子', 'ナルコオンセンカミナルコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市鳴子温泉古戸前', '04', '04215', '9896826', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '鳴子温泉古戸前', 'ナルコオンセンフルトマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市鳴子温泉尿前', '04', '04215', '9896827', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '鳴子温泉尿前', 'ナルコオンセンシトマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市鳴子温泉柳木', '04', '04215', '9896831', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '鳴子温泉柳木', 'ナルコオンセンヤギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市鳴子温泉星沼', '04', '04215', '9896832', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '鳴子温泉星沼', 'ナルコオンセンホシヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市鳴子温泉川端', '04', '04215', '9896833', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '鳴子温泉川端', 'ナルコオンセンカワハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市鳴子温泉西原', '04', '04215', '9896834', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '鳴子温泉西原', 'ナルコオンセンニシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市鳴子温泉南原', '04', '04215', '9896835', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '鳴子温泉南原', 'ナルコオンセンミナミハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市鳴子温泉焼石亦', '04', '04215', '9896836', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '鳴子温泉焼石亦', 'ナルコオンセンヤキイシマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市鳴子温泉南星沼', '04', '04215', '9896837', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '鳴子温泉南星沼', 'ナルコオンセンミナミホシヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市鳴子温泉奥羽岳', '04', '04215', '9896838', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '鳴子温泉奥羽岳', 'ナルコオンセンオオウダケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '宮城県大崎市鳴子温泉鬼首', '04', '04215', '9896941', '宮城県', 'ミヤギケン', '大崎市', 'オオサキシ', '鳴子温泉鬼首', 'ナルコオンセンオニコウベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市', '06', '06201', '9900000', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('144081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市穂積', '06', '06201', '9900001', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '穂積', 'ホヅミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市高原町', '06', '06201', '9900002', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '高原町', 'タカハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市早乙女', '06', '06201', '9900003', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '早乙女', 'サオトメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市上山家町', '06', '06201', '9900004', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '上山家町', 'カミヤンベマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市下山家町', '06', '06201', '9900005', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '下山家町', 'シモヤンベマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市山家本町', '06', '06201', '9900006', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '山家本町', 'ヤンベホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市沼の辺町', '06', '06201', '9900007', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '沼の辺町', 'ヌマノベマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市双月新町', '06', '06201', '9900008', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '双月新町', 'ソウツキシンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市妙見寺', '06', '06201', '9900011', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '妙見寺', 'ミョウケンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市釈迦堂', '06', '06201', '9900012', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '釈迦堂', 'シャカドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市防原町', '06', '06201', '9900013', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '防原町', 'ボウバラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市滑川', '06', '06201', '9900014', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '滑川', 'ナメカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市新山', '06', '06201', '9900015', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '新山', 'ニイヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市関沢', '06', '06201', '9900016', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '関沢', 'セキザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市上宝沢', '06', '06201', '9900017', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '上宝沢', 'カミホウザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市下宝沢', '06', '06201', '9900018', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '下宝沢', 'シモホウザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市小白川町', '06', '06201', '9900021', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '小白川町', 'コジラカワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市東山形', '06', '06201', '9900022', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '東山形', 'ヒガシヤマガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市松波', '06', '06201', '9900023', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '松波', 'マツナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市あさひ町', '06', '06201', '9900024', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', 'あさひ町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市あこや町', '06', '06201', '9900025', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', 'あこや町', 'アコヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市十日町', '06', '06201', '9900031', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '十日町', 'トオカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市小姓町', '06', '06201', '9900032', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '小姓町', 'コショウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市諏訪町', '06', '06201', '9900033', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '諏訪町', 'スワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市東原町', '06', '06201', '9900034', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '東原町', 'ヒガシハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市小荷駄町', '06', '06201', '9900035', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '小荷駄町', 'コニダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市三日町', '06', '06201', '9900036', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '三日町', 'ミッカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市八日町', '06', '06201', '9900037', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '八日町', 'ヨウカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市幸町', '06', '06201', '9900038', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市香澄町', '06', '06201', '9900039', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '香澄町', 'カスミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市緑町', '06', '06201', '9900041', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '緑町', 'ミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市七日町', '06', '06201', '9900042', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '七日町', 'ナヌカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市本町', '06', '06201', '9900043', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市木の実町', '06', '06201', '9900044', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '木の実町', 'キノミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市桜町', '06', '06201', '9900045', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '桜町', 'サクラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市大手町', '06', '06201', '9900046', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '大手町', 'オオテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市旅篭町', '06', '06201', '9900047', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '旅篭町', 'ハタゴマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市銅町', '06', '06201', '9900051', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '銅町', 'ドウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市円応寺町', '06', '06201', '9900052', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '円応寺町', 'エンノウジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市薬師町', '06', '06201', '9900053', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '薬師町', 'ヤクシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市六日町', '06', '06201', '9900054', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '六日町', 'ムイカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市相生町', '06', '06201', '9900055', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '相生町', 'アイオイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市錦町', '06', '06201', '9900056', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '錦町', 'ニシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市宮町', '06', '06201', '9900057', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '宮町', 'ミヤマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市五十鈴', '06', '06201', '9900061', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '五十鈴', 'イスズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市鈴川町', '06', '06201', '9900062', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '鈴川町', 'スズカワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市山家町', '06', '06201', '9900063', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '山家町', 'ヤンベマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市和合町', '06', '06201', '9900064', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '和合町', 'ワゴウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市双月町', '06', '06201', '9900065', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '双月町', 'ソウツキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市印役町', '06', '06201', '9900066', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '印役町', 'インヤクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市花楯', '06', '06201', '9900067', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '花楯', 'ハナタテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市泉町', '06', '06201', '9900068', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '泉町', 'イズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市流通センター', '06', '06201', '9900071', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '流通センター', 'リュウツウセンター', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市浜崎', '06', '06201', '9900072', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '浜崎', 'ハマザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市大野目', '06', '06201', '9900073', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '大野目', 'ダイノメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市芳野', '06', '06201', '9900074', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '芳野', 'ヨシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市落合町', '06', '06201', '9900075', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '落合町', 'オチアイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市平久保', '06', '06201', '9900076', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '平久保', 'ヒラクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市栄原', '06', '06201', '9900077', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '栄原', 'サカエバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東村山郡山辺町', '06', '06301', '9900300', '山形県', 'ヤマガタケン', '東村山郡山辺町', 'ヒガシムラヤマグンヤマノベマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('144141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東村山郡山辺町山辺', '06', '06301', '9900301', '山形県', 'ヤマガタケン', '東村山郡山辺町', 'ヒガシムラヤマグンヤマノベマチ', '山辺', 'ヤマノベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東村山郡山辺町近江', '06', '06301', '9900311', '山形県', 'ヤマガタケン', '東村山郡山辺町', 'ヒガシムラヤマグンヤマノベマチ', '近江', 'オウミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東村山郡山辺町三河尻', '06', '06301', '9900312', '山形県', 'ヤマガタケン', '東村山郡山辺町', 'ヒガシムラヤマグンヤマノベマチ', '三河尻', 'ミカワジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東村山郡山辺町根際', '06', '06301', '9900321', '山形県', 'ヤマガタケン', '東村山郡山辺町', 'ヒガシムラヤマグンヤマノベマチ', '根際', 'ネギワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東村山郡山辺町要害', '06', '06301', '9900322', '山形県', 'ヤマガタケン', '東村山郡山辺町', 'ヒガシムラヤマグンヤマノベマチ', '要害', 'ヨウガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東村山郡山辺町大塚', '06', '06301', '9900323', '山形県', 'ヤマガタケン', '東村山郡山辺町', 'ヒガシムラヤマグンヤマノベマチ', '大塚', 'オオツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東村山郡山辺町大寺', '06', '06301', '9900331', '山形県', 'ヤマガタケン', '東村山郡山辺町', 'ヒガシムラヤマグンヤマノベマチ', '大寺', 'オオテラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東村山郡山辺町北垣', '06', '06301', '9900332', '山形県', 'ヤマガタケン', '東村山郡山辺町', 'ヒガシムラヤマグンヤマノベマチ', '北垣', 'キタガキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東村山郡山辺町杉下', '06', '06301', '9900333', '山形県', 'ヤマガタケン', '東村山郡山辺町', 'ヒガシムラヤマグンヤマノベマチ', '杉下', 'スギシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東村山郡山辺町大蕨', '06', '06301', '9900341', '山形県', 'ヤマガタケン', '東村山郡山辺町', 'ヒガシムラヤマグンヤマノベマチ', '大蕨', 'オオワラビ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東村山郡山辺町北山', '06', '06301', '9900342', '山形県', 'ヤマガタケン', '東村山郡山辺町', 'ヒガシムラヤマグンヤマノベマチ', '北山', 'キタヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東村山郡山辺町簗沢', '06', '06301', '9900351', '山形県', 'ヤマガタケン', '東村山郡山辺町', 'ヒガシムラヤマグンヤマノベマチ', '簗沢', 'ヤナザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東村山郡山辺町北作', '06', '06301', '9900352', '山形県', 'ヤマガタケン', '東村山郡山辺町', 'ヒガシムラヤマグンヤマノベマチ', '北作', 'キタサク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東村山郡山辺町畑谷', '06', '06301', '9900361', '山形県', 'ヤマガタケン', '東村山郡山辺町', 'ヒガシムラヤマグンヤマノベマチ', '畑谷', 'ハタヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東村山郡中山町', '06', '06302', '9900400', '山形県', 'ヤマガタケン', '東村山郡中山町', 'ヒガシムラヤマグンナカヤママチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('144157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東村山郡中山町長崎', '06', '06302', '9900401', '山形県', 'ヤマガタケン', '東村山郡中山町', 'ヒガシムラヤマグンナカヤママチ', '長崎', 'ナガサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東村山郡中山町いずみ', '06', '06302', '9900402', '山形県', 'ヤマガタケン', '東村山郡中山町', 'ヒガシムラヤマグンナカヤママチ', 'いずみ', 'イズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東村山郡中山町達磨寺', '06', '06302', '9900403', '山形県', 'ヤマガタケン', '東村山郡中山町', 'ヒガシムラヤマグンナカヤママチ', '達磨寺', 'ダルマジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東村山郡中山町向新田', '06', '06302', '9900404', '山形県', 'ヤマガタケン', '東村山郡中山町', 'ヒガシムラヤマグンナカヤママチ', '向新田', 'ムコウシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東村山郡中山町金沢', '06', '06302', '9900405', '山形県', 'ヤマガタケン', '東村山郡中山町', 'ヒガシムラヤマグンナカヤママチ', '金沢', 'カネザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東村山郡中山町柳沢', '06', '06302', '9900406', '山形県', 'ヤマガタケン', '東村山郡中山町', 'ヒガシムラヤマグンナカヤママチ', '柳沢', 'ヤナギサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東村山郡中山町土橋', '06', '06302', '9900407', '山形県', 'ヤマガタケン', '東村山郡中山町', 'ヒガシムラヤマグンナカヤママチ', '土橋', 'ツチハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東村山郡中山町岡', '06', '06302', '9900408', '山形県', 'ヤマガタケン', '東村山郡中山町', 'ヒガシムラヤマグンナカヤママチ', '岡', 'オカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東村山郡中山町小塩', '06', '06302', '9900409', '山形県', 'ヤマガタケン', '東村山郡中山町', 'ヒガシムラヤマグンナカヤママチ', '小塩', 'コシオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東村山郡中山町あおば', '06', '06302', '9900411', '山形県', 'ヤマガタケン', '東村山郡中山町', 'ヒガシムラヤマグンナカヤママチ', 'あおば', 'アオバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県寒河江市宮内', '06', '06206', '9900501', '山形県', 'ヤマガタケン', '寒河江市', 'サガエシ', '宮内', 'ミヤウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県寒河江市幸生', '06', '06206', '9900502', '山形県', 'ヤマガタケン', '寒河江市', 'サガエシ', '幸生', 'サチウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県寒河江市田代', '06', '06206', '9900503', '山形県', 'ヤマガタケン', '寒河江市', 'サガエシ', '田代', 'タシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県寒河江市留場', '06', '06206', '9900504', '山形県', 'ヤマガタケン', '寒河江市', 'サガエシ', '留場', 'トメバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県寒河江市白岩', '06', '06206', '9900505', '山形県', 'ヤマガタケン', '寒河江市', 'サガエシ', '白岩', 'シライワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県寒河江市慈恩寺', '06', '06206', '9900511', '山形県', 'ヤマガタケン', '寒河江市', 'サガエシ', '慈恩寺', 'ジオンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県寒河江市箕輪', '06', '06206', '9900512', '山形県', 'ヤマガタケン', '寒河江市', 'サガエシ', '箕輪', 'ミノワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県寒河江市日和田', '06', '06206', '9900513', '山形県', 'ヤマガタケン', '寒河江市', 'サガエシ', '日和田', 'ヒワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県寒河江市谷沢', '06', '06206', '9900521', '山形県', 'ヤマガタケン', '寒河江市', 'サガエシ', '谷沢', 'ヤサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県寒河江市清助新田', '06', '06206', '9900522', '山形県', 'ヤマガタケン', '寒河江市', 'サガエシ', '清助新田', 'セイスケシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県寒河江市八鍬', '06', '06206', '9900523', '山形県', 'ヤマガタケン', '寒河江市', 'サガエシ', '八鍬', 'ヤクワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県寒河江市高松', '06', '06206', '9900524', '山形県', 'ヤマガタケン', '寒河江市', 'サガエシ', '高松', 'タカマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県寒河江市米沢', '06', '06206', '9900525', '山形県', 'ヤマガタケン', '寒河江市', 'サガエシ', '米沢', 'ヨナザ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県寒河江市中央工業団地', '06', '06206', '9900561', '山形県', 'ヤマガタケン', '寒河江市', 'サガエシ', '中央工業団地', 'チュウオウコウギョウダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西村山郡西川町', '06', '06322', '9900700', '山形県', 'ヤマガタケン', '西村山郡西川町', 'ニシムラヤマグンニシカワマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('144184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西村山郡西川町睦合', '06', '06322', '9900701', '山形県', 'ヤマガタケン', '西村山郡西川町', 'ニシムラヤマグンニシカワマチ', '睦合', 'ムツアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西村山郡西川町海味', '06', '06322', '9900702', '山形県', 'ヤマガタケン', '西村山郡西川町', 'ニシムラヤマグンニシカワマチ', '海味', 'カイシュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西村山郡西川町間沢', '06', '06322', '9900703', '山形県', 'ヤマガタケン', '西村山郡西川町', 'ニシムラヤマグンニシカワマチ', '間沢', 'マザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西村山郡西川町吉川', '06', '06322', '9900711', '山形県', 'ヤマガタケン', '西村山郡西川町', 'ニシムラヤマグンニシカワマチ', '吉川', 'ヨシカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西村山郡西川町原', '06', '06322', '9900712', '山形県', 'ヤマガタケン', '西村山郡西川町', 'ニシムラヤマグンニシカワマチ', '原', 'ハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西村山郡西川町沼山', '06', '06322', '9900713', '山形県', 'ヤマガタケン', '西村山郡西川町', 'ニシムラヤマグンニシカワマチ', '沼山', 'ヌマヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西村山郡西川町入間', '06', '06322', '9900714', '山形県', 'ヤマガタケン', '西村山郡西川町', 'ニシムラヤマグンニシカワマチ', '入間', 'イリマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西村山郡西川町大井沢', '06', '06322', '9900721', '山形県', 'ヤマガタケン', '西村山郡西川町', 'ニシムラヤマグンニシカワマチ', '大井沢', 'オオイサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西村山郡西川町月岡', '06', '06322', '9900731', '山形県', 'ヤマガタケン', '西村山郡西川町', 'ニシムラヤマグンニシカワマチ', '月岡', 'ツキオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西村山郡西川町砂子関', '06', '06322', '9900732', '山形県', 'ヤマガタケン', '西村山郡西川町', 'ニシムラヤマグンニシカワマチ', '砂子関', 'スナゴセキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西村山郡西川町月山沢', '06', '06322', '9900733', '山形県', 'ヤマガタケン', '西村山郡西川町', 'ニシムラヤマグンニシカワマチ', '月山沢', 'ツキヤマザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西村山郡西川町志津', '06', '06322', '9900734', '山形県', 'ヤマガタケン', '西村山郡西川町', 'ニシムラヤマグンニシカワマチ', '志津', 'シヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西村山郡西川町本道寺', '06', '06322', '9900735', '山形県', 'ヤマガタケン', '西村山郡西川町', 'ニシムラヤマグンニシカワマチ', '本道寺', 'ホンドウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西村山郡西川町綱取', '06', '06322', '9900741', '山形県', 'ヤマガタケン', '西村山郡西川町', 'ニシムラヤマグンニシカワマチ', '綱取', 'ツナトリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西村山郡西川町水沢', '06', '06322', '9900742', '山形県', 'ヤマガタケン', '西村山郡西川町', 'ニシムラヤマグンニシカワマチ', '水沢', 'ミズサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西村山郡西川町岩根沢', '06', '06322', '9900743', '山形県', 'ヤマガタケン', '西村山郡西川町', 'ニシムラヤマグンニシカワマチ', '岩根沢', 'イワネザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市天神町', '06', '06201', '9900801', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '天神町', 'テンジンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市見崎川原', '06', '06201', '9900802', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '見崎川原', 'ミサキカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市見崎', '06', '06201', '9900803', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '見崎', 'ミサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市七十刈', '06', '06201', '9900804', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '七十刈', 'ナナジュウガリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市壇野前', '06', '06201', '9900805', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '壇野前', 'ダンノマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市藤治屋敷', '06', '06201', '9900806', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '藤治屋敷', 'トウジヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市白川', '06', '06201', '9900807', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '白川', 'シラカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市高田', '06', '06201', '9900808', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '高田', 'タカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市下田', '06', '06201', '9900809', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '下田', 'シモダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市馬見ケ崎', '06', '06201', '9900810', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '馬見ケ崎', 'マミガサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市長町', '06', '06201', '9900811', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '長町', 'ナガマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市千歳', '06', '06201', '9900812', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '千歳', 'チトセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市桧町', '06', '06201', '9900813', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '桧町', 'ヒノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市土樋', '06', '06201', '9900814', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '土樋', 'ツチドイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市樋越', '06', '06201', '9900815', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '樋越', 'トヨゴシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市河原田', '06', '06201', '9900816', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '河原田', 'カワラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市今塚', '06', '06201', '9900817', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '今塚', 'イマヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市沖町', '06', '06201', '9900818', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '沖町', 'オキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市境田町', '06', '06201', '9900819', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '境田町', 'サカイダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市北町', '06', '06201', '9900821', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '北町', 'キタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市北山形', '06', '06201', '9900822', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '北山形', 'キタヤマガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市下条町', '06', '06201', '9900823', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '下条町', 'シモジョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市肴町', '06', '06201', '9900824', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '肴町', 'サカナマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市城北町', '06', '06201', '9900825', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '城北町', 'ジョウホクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市霞城町', '06', '06201', '9900826', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '霞城町', 'カジョウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市城南町', '06', '06201', '9900827', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '城南町', 'ジョウナンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市双葉町', '06', '06201', '9900828', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '双葉町', 'フタバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市五日町', '06', '06201', '9900829', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '五日町', 'イツカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市西田', '06', '06201', '9900831', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '西田', 'ニシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市城西町', '06', '06201', '9900832', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '城西町', 'シロニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市春日町', '06', '06201', '9900833', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '春日町', 'カスガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市清住町', '06', '06201', '9900834', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '清住町', 'キヨズミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市やよい', '06', '06201', '9900835', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', 'やよい', 'ヤヨイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市南石関', '06', '06201', '9900836', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '南石関', 'ミナミイシゼキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市飯塚口', '06', '06201', '9900841', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '飯塚口', 'イイヅカグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市石関', '06', '06201', '9900842', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '石関', 'イシゼキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市横道', '06', '06201', '9900843', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '横道', 'ヨコミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市西見田', '06', '06201', '9900844', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '西見田', 'ニシミダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市飯塚町', '06', '06201', '9900845', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '飯塚町', 'イイヅカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市志鎌', '06', '06201', '9900846', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '志鎌', 'シカマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市砂田', '06', '06201', '9900847', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '砂田', 'スナダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市宮浦', '06', '06201', '9900848', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '宮浦', 'ミヤウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市中沼', '06', '06201', '9900849', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '中沼', 'ナカヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市上椹沢', '06', '06201', '9900851', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '上椹沢', 'カミクヌギザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市黄金', '06', '06201', '9900852', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '黄金', 'コガネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市西崎', '06', '06201', '9900853', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '西崎', 'ニシザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市砂塚', '06', '06201', '9900854', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '砂塚', 'スナヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市千代田', '06', '06201', '9900855', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '千代田', 'チヨダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市金石田', '06', '06201', '9900856', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '金石田', 'カナイシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市平田', '06', '06201', '9900857', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '平田', 'ヘイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市下椹沢', '06', '06201', '9900858', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '下椹沢', 'シモクヌギザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市西原', '06', '06201', '9900859', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '西原', 'ニシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市陣場南', '06', '06201', '9900860', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '陣場南', 'ジンバミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市江俣', '06', '06201', '9900861', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '江俣', 'エマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市西江俣', '06', '06201', '9900862', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '西江俣', 'ニシエマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市江南', '06', '06201', '9900863', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '江南', 'コウナン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市陣場', '06', '06201', '9900864', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '陣場', 'ジンバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市馬上台', '06', '06201', '9900865', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '馬上台', 'バジョウダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市横井', '06', '06201', '9900866', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '横井', 'ヨコイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市天神台', '06', '06201', '9900867', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '天神台', 'テンジンダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市志戸田', '06', '06201', '9900868', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '志戸田', 'シトダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市東志戸田', '06', '06201', '9900869', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '東志戸田', 'ヒガシシトダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市島', '06', '06201', '9900870', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '島', 'シマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市銅谷口', '06', '06201', '9900871', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '銅谷口', 'ドウヤグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市八幡前', '06', '06201', '9900872', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '八幡前', 'ハチマンマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市田端', '06', '06201', '9900873', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '田端', 'タバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市梅野木前', '06', '06201', '9900874', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '梅野木前', 'ウメノキマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市北江俣', '06', '06201', '9900875', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '北江俣', 'キタエマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市行才', '06', '06201', '9900876', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '行才', 'ギョウサイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市内表', '06', '06201', '9900877', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '内表', 'ウチオモテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市内表東', '06', '06201', '9900878', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '内表東', 'ウチオモテヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市南志戸田', '06', '06201', '9900879', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '南志戸田', 'ミナミシトダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市瀬波', '06', '06201', '9900881', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '瀬波', 'セナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市陣場新田', '06', '06201', '9900882', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '陣場新田', 'ジンバシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市吉野宿', '06', '06201', '9900883', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '吉野宿', 'ヨシノジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市鮨洗', '06', '06201', '9900884', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '鮨洗', 'スシアライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市成安', '06', '06201', '9900891', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '成安', 'ナリヤス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市中野', '06', '06201', '9900892', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '中野', 'ナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市西中野', '06', '06201', '9900893', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '西中野', 'ニシナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市船町', '06', '06201', '9900894', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '船町', 'フナマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市向新田', '06', '06201', '9900895', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '向新田', 'ムカイシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市北田', '06', '06201', '9900896', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '北田', 'キタダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市東田', '06', '06201', '9900897', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '東田', 'ヒガシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市三社', '06', '06201', '9900898', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '三社', 'サンシャ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市東篭野町', '06', '06201', '9900899', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '東篭野町', 'ヒガシカゴノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡遠軽町下白滝', '01', '01555', '0990101', '北海道', 'ホッカイドウ', '紋別郡遠軽町', 'モンベツグンエンガルチョウ', '下白滝', 'シモシラタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡遠軽町旧白滝', '01', '01555', '0990102', '北海道', 'ホッカイドウ', '紋別郡遠軽町', 'モンベツグンエンガルチョウ', '旧白滝', 'キュウシラタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西村山郡大江町', '06', '06324', '9901100', '山形県', 'ヤマガタケン', '西村山郡大江町', 'ニシムラヤマグンオオエマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('144289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西村山郡大江町左沢', '06', '06324', '9901101', '山形県', 'ヤマガタケン', '西村山郡大江町', 'ニシムラヤマグンオオエマチ', '左沢', 'アテラザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡遠軽町白滝', '01', '01555', '0990111', '北海道', 'ホッカイドウ', '紋別郡遠軽町', 'モンベツグンエンガルチョウ', '白滝', 'シラタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西村山郡大江町三郷丙', '06', '06324', '9901111', '山形県', 'ヤマガタケン', '西村山郡大江町', 'ニシムラヤマグンオオエマチ', '三郷丙', 'サンゴウヘイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西村山郡大江町三郷乙', '06', '06324', '9901112', '山形県', 'ヤマガタケン', '西村山郡大江町', 'ニシムラヤマグンオオエマチ', '三郷乙', 'サンゴウオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西村山郡大江町三郷甲', '06', '06324', '9901113', '山形県', 'ヤマガタケン', '西村山郡大江町', 'ニシムラヤマグンオオエマチ', '三郷甲', 'サンゴウコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西村山郡大江町富沢', '06', '06324', '9901114', '山形県', 'ヤマガタケン', '西村山郡大江町', 'ニシムラヤマグンオオエマチ', '富沢', 'トミザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西村山郡大江町藤田', '06', '06324', '9901121', '山形県', 'ヤマガタケン', '西村山郡大江町', 'ニシムラヤマグンオオエマチ', '藤田', 'フジタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西村山郡大江町小見', '06', '06324', '9901122', '山形県', 'ヤマガタケン', '西村山郡大江町', 'ニシムラヤマグンオオエマチ', '小見', 'オオミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西村山郡大江町荻野', '06', '06324', '9901131', '山形県', 'ヤマガタケン', '西村山郡大江町', 'ニシムラヤマグンオオエマチ', '荻野', 'オギノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西村山郡大江町堂屋敷', '06', '06324', '9901132', '山形県', 'ヤマガタケン', '西村山郡大江町', 'ニシムラヤマグンオオエマチ', '堂屋敷', 'ドウヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西村山郡大江町塩ノ平', '06', '06324', '9901133', '山形県', 'ヤマガタケン', '西村山郡大江町', 'ニシムラヤマグンオオエマチ', '塩ノ平', 'シオノタイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西村山郡大江町所部', '06', '06324', '9901134', '山形県', 'ヤマガタケン', '西村山郡大江町', 'ニシムラヤマグンオオエマチ', '所部', 'トコロブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西村山郡大江町小釿', '06', '06324', '9901141', '山形県', 'ヤマガタケン', '西村山郡大江町', 'ニシムラヤマグンオオエマチ', '小釿', 'コジュウナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西村山郡大江町材木', '06', '06324', '9901142', '山形県', 'ヤマガタケン', '西村山郡大江町', 'ニシムラヤマグンオオエマチ', '材木', 'ザイモク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西村山郡大江町橋上', '06', '06324', '9901143', '山形県', 'ヤマガタケン', '西村山郡大江町', 'ニシムラヤマグンオオエマチ', '橋上', 'ハシカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西村山郡大江町十八才甲', '06', '06324', '9901144', '山形県', 'ヤマガタケン', '西村山郡大江町', 'ニシムラヤマグンオオエマチ', '十八才甲', 'ジュウハツサイコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西村山郡大江町十八才乙', '06', '06324', '9901145', '山形県', 'ヤマガタケン', '西村山郡大江町', 'ニシムラヤマグンオオエマチ', '十八才乙', 'ジュウハツサイオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西村山郡大江町楢山', '06', '06324', '9901146', '山形県', 'ヤマガタケン', '西村山郡大江町', 'ニシムラヤマグンオオエマチ', '楢山', 'ナラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西村山郡大江町本郷乙', '06', '06324', '9901151', '山形県', 'ヤマガタケン', '西村山郡大江町', 'ニシムラヤマグンオオエマチ', '本郷乙', 'ホンゴウオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西村山郡大江町顔好甲', '06', '06324', '9901152', '山形県', 'ヤマガタケン', '西村山郡大江町', 'ニシムラヤマグンオオエマチ', '顔好甲', 'カオヨシコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西村山郡大江町顔好乙', '06', '06324', '9901153', '山形県', 'ヤマガタケン', '西村山郡大江町', 'ニシムラヤマグンオオエマチ', '顔好乙', 'カオヨシオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西村山郡大江町本郷甲', '06', '06324', '9901154', '山形県', 'ヤマガタケン', '西村山郡大江町', 'ニシムラヤマグンオオエマチ', '本郷甲', 'ホンゴウコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西村山郡大江町原田', '06', '06324', '9901161', '山形県', 'ヤマガタケン', '西村山郡大江町', 'ニシムラヤマグンオオエマチ', '原田', 'ハラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西村山郡大江町本郷己', '06', '06324', '9901162', '山形県', 'ヤマガタケン', '西村山郡大江町', 'ニシムラヤマグンオオエマチ', '本郷己', 'ホンゴウキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西村山郡大江町本郷丁', '06', '06324', '9901163', '山形県', 'ヤマガタケン', '西村山郡大江町', 'ニシムラヤマグンオオエマチ', '本郷丁', 'ホンゴウテイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西村山郡大江町本郷丙', '06', '06324', '9901164', '山形県', 'ヤマガタケン', '西村山郡大江町', 'ニシムラヤマグンオオエマチ', '本郷丙', 'ホンゴウヘイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西村山郡大江町本郷戊', '06', '06324', '9901165', '山形県', 'ヤマガタケン', '西村山郡大江町', 'ニシムラヤマグンオオエマチ', '本郷戊', 'ホンゴウボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡遠軽町白滝北支湧別', '01', '01555', '0990121', '北海道', 'ホッカイドウ', '紋別郡遠軽町', 'モンベツグンエンガルチョウ', '白滝北支湧別', 'シラタキキタシュウベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡遠軽町白滝支湧別', '01', '01555', '0990122', '北海道', 'ホッカイドウ', '紋別郡遠軽町', 'モンベツグンエンガルチョウ', '白滝支湧別', 'シラタキシュウベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡遠軽町白滝上支湧別', '01', '01555', '0990123', '北海道', 'ホッカイドウ', '紋別郡遠軽町', 'モンベツグンエンガルチョウ', '白滝上支湧別', 'シラタキカミシュウベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡遠軽町東白滝', '01', '01555', '0990124', '北海道', 'ホッカイドウ', '紋別郡遠軽町', 'モンベツグンエンガルチョウ', '東白滝', 'ヒガシシラタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡遠軽町白滝天狗平', '01', '01555', '0990125', '北海道', 'ホッカイドウ', '紋別郡遠軽町', 'モンベツグンエンガルチョウ', '白滝天狗平', 'シラタキテングダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡遠軽町奥白滝', '01', '01555', '0990126', '北海道', 'ホッカイドウ', '紋別郡遠軽町', 'モンベツグンエンガルチョウ', '奥白滝', 'オクシラタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡遠軽町上白滝', '01', '01555', '0990127', '北海道', 'ホッカイドウ', '紋別郡遠軽町', 'モンベツグンエンガルチョウ', '上白滝', 'カミシラタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西村山郡大江町月布', '06', '06324', '9901271', '山形県', 'ヤマガタケン', '西村山郡大江町', 'ニシムラヤマグンオオエマチ', '月布', 'ツキヌノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西村山郡大江町貫見', '06', '06324', '9901272', '山形県', 'ヤマガタケン', '西村山郡大江町', 'ニシムラヤマグンオオエマチ', '貫見', 'ヌクミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西村山郡大江町小清', '06', '06324', '9901273', '山形県', 'ヤマガタケン', '西村山郡大江町', 'ニシムラヤマグンオオエマチ', '小清', 'コセイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西村山郡大江町柳川', '06', '06324', '9901274', '山形県', 'ヤマガタケン', '西村山郡大江町', 'ニシムラヤマグンオオエマチ', '柳川', 'ヤナガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西村山郡大江町沢口', '06', '06324', '9901275', '山形県', 'ヤマガタケン', '西村山郡大江町', 'ニシムラヤマグンオオエマチ', '沢口', 'サワグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西村山郡大江町黒森', '06', '06324', '9901276', '山形県', 'ヤマガタケン', '西村山郡大江町', 'ニシムラヤマグンオオエマチ', '黒森', 'クロモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西村山郡朝日町中沢', '06', '06323', '9901301', '山形県', 'ヤマガタケン', '西村山郡朝日町', 'ニシムラヤマグンアサヒマチ', '中沢', 'ナカザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西村山郡朝日町玉ノ井', '06', '06323', '9901302', '山形県', 'ヤマガタケン', '西村山郡朝日町', 'ニシムラヤマグンアサヒマチ', '玉ノ井', 'タマノイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西村山郡朝日町馬神', '06', '06323', '9901303', '山形県', 'ヤマガタケン', '西村山郡朝日町', 'ニシムラヤマグンアサヒマチ', '馬神', 'ウマガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西村山郡朝日町大谷', '06', '06323', '9901304', '山形県', 'ヤマガタケン', '西村山郡朝日町', 'ニシムラヤマグンアサヒマチ', '大谷', 'オオヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西村山郡朝日町大沼', '06', '06323', '9901305', '山形県', 'ヤマガタケン', '西村山郡朝日町', 'ニシムラヤマグンアサヒマチ', '大沼', 'オオヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西村山郡朝日町大暮山', '06', '06323', '9901306', '山形県', 'ヤマガタケン', '西村山郡朝日町', 'ニシムラヤマグンアサヒマチ', '大暮山', 'オオグレヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西村山郡朝日町', '06', '06323', '9901400', '山形県', 'ヤマガタケン', '西村山郡朝日町', 'ニシムラヤマグンアサヒマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('144336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西村山郡朝日町和合', '06', '06323', '9901411', '山形県', 'ヤマガタケン', '西村山郡朝日町', 'ニシムラヤマグンアサヒマチ', '和合', 'ワゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西村山郡朝日町古槇', '06', '06323', '9901421', '山形県', 'ヤマガタケン', '西村山郡朝日町', 'ニシムラヤマグンアサヒマチ', '古槇', 'フルマギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西村山郡朝日町送橋', '06', '06323', '9901422', '山形県', 'ヤマガタケン', '西村山郡朝日町', 'ニシムラヤマグンアサヒマチ', '送橋', 'オクリハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西村山郡朝日町下芦沢', '06', '06323', '9901423', '山形県', 'ヤマガタケン', '西村山郡朝日町', 'ニシムラヤマグンアサヒマチ', '下芦沢', 'シモアシザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西村山郡朝日町水本', '06', '06323', '9901424', '山形県', 'ヤマガタケン', '西村山郡朝日町', 'ニシムラヤマグンアサヒマチ', '水本', 'ミズモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西村山郡朝日町大滝', '06', '06323', '9901431', '山形県', 'ヤマガタケン', '西村山郡朝日町', 'ニシムラヤマグンアサヒマチ', '大滝', 'オオタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西村山郡朝日町上郷', '06', '06323', '9901432', '山形県', 'ヤマガタケン', '西村山郡朝日町', 'ニシムラヤマグンアサヒマチ', '上郷', 'カミゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西村山郡朝日町杉山', '06', '06323', '9901433', '山形県', 'ヤマガタケン', '西村山郡朝日町', 'ニシムラヤマグンアサヒマチ', '杉山', 'スギヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西村山郡朝日町新宿', '06', '06323', '9901441', '山形県', 'ヤマガタケン', '西村山郡朝日町', 'ニシムラヤマグンアサヒマチ', '新宿', 'アラジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西村山郡朝日町宮宿', '06', '06323', '9901442', '山形県', 'ヤマガタケン', '西村山郡朝日町', 'ニシムラヤマグンアサヒマチ', '宮宿', 'ミヤジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西村山郡朝日町雪谷', '06', '06323', '9901443', '山形県', 'ヤマガタケン', '西村山郡朝日町', 'ニシムラヤマグンアサヒマチ', '雪谷', 'ユキタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西村山郡朝日町四ノ沢', '06', '06323', '9901444', '山形県', 'ヤマガタケン', '西村山郡朝日町', 'ニシムラヤマグンアサヒマチ', '四ノ沢', 'シノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西村山郡朝日町三中', '06', '06323', '9901551', '山形県', 'ヤマガタケン', '西村山郡朝日町', 'ニシムラヤマグンアサヒマチ', '三中', 'ミナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西村山郡朝日町常盤', '06', '06323', '9901552', '山形県', 'ヤマガタケン', '西村山郡朝日町', 'ニシムラヤマグンアサヒマチ', '常盤', 'トキワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西村山郡朝日町長沼', '06', '06323', '9901553', '山形県', 'ヤマガタケン', '西村山郡朝日町', 'ニシムラヤマグンアサヒマチ', '長沼', 'ナガヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西村山郡朝日町松程', '06', '06323', '9901561', '山形県', 'ヤマガタケン', '西村山郡朝日町', 'ニシムラヤマグンアサヒマチ', '松程', 'マツホド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西村山郡朝日町大船木', '06', '06323', '9901562', '山形県', 'ヤマガタケン', '西村山郡朝日町', 'ニシムラヤマグンアサヒマチ', '大船木', 'オオフナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西村山郡朝日町今平', '06', '06323', '9901563', '山形県', 'ヤマガタケン', '西村山郡朝日町', 'ニシムラヤマグンアサヒマチ', '今平', 'コンペイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西村山郡朝日町石須部', '06', '06323', '9901571', '山形県', 'ヤマガタケン', '西村山郡朝日町', 'ニシムラヤマグンアサヒマチ', '石須部', 'コクスベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西村山郡朝日町太郎', '06', '06323', '9901572', '山形県', 'ヤマガタケン', '西村山郡朝日町', 'ニシムラヤマグンアサヒマチ', '太郎', 'タロウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西村山郡朝日町立木', '06', '06323', '9901573', '山形県', 'ヤマガタケン', '西村山郡朝日町', 'ニシムラヤマグンアサヒマチ', '立木', 'タテキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西村山郡朝日町白倉', '06', '06323', '9901574', '山形県', 'ヤマガタケン', '西村山郡朝日町', 'ニシムラヤマグンアサヒマチ', '白倉', 'シラクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡遠軽町丸瀬布新町', '01', '01555', '0990201', '北海道', 'ホッカイドウ', '紋別郡遠軽町', 'モンベツグンエンガルチョウ', '丸瀬布新町', 'マルセップシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡遠軽町丸瀬布天神町', '01', '01555', '0990202', '北海道', 'ホッカイドウ', '紋別郡遠軽町', 'モンベツグンエンガルチョウ', '丸瀬布天神町', 'マルセップテンジンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡遠軽町丸瀬布中町', '01', '01555', '0990203', '北海道', 'ホッカイドウ', '紋別郡遠軽町', 'モンベツグンエンガルチョウ', '丸瀬布中町', 'マルセップナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡遠軽町丸瀬布西町', '01', '01555', '0990204', '北海道', 'ホッカイドウ', '紋別郡遠軽町', 'モンベツグンエンガルチョウ', '丸瀬布西町', 'マルセップニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡遠軽町丸瀬布東町', '01', '01555', '0990205', '北海道', 'ホッカイドウ', '紋別郡遠軽町', 'モンベツグンエンガルチョウ', '丸瀬布東町', 'マルセップヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡遠軽町丸瀬布水谷町', '01', '01555', '0990206', '北海道', 'ホッカイドウ', '紋別郡遠軽町', 'モンベツグンエンガルチョウ', '丸瀬布水谷町', 'マルセップミズタニマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡遠軽町丸瀬布元町', '01', '01555', '0990207', '北海道', 'ホッカイドウ', '紋別郡遠軽町', 'モンベツグンエンガルチョウ', '丸瀬布元町', 'マルセップモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡遠軽町丸瀬布金山', '01', '01555', '0990211', '北海道', 'ホッカイドウ', '紋別郡遠軽町', 'モンベツグンエンガルチョウ', '丸瀬布金山', 'マルセップカナヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡遠軽町丸瀬布上丸', '01', '01555', '0990212', '北海道', 'ホッカイドウ', '紋別郡遠軽町', 'モンベツグンエンガルチョウ', '丸瀬布上丸', 'マルセップカミマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡遠軽町丸瀬布上武利', '01', '01555', '0990213', '北海道', 'ホッカイドウ', '紋別郡遠軽町', 'モンベツグンエンガルチョウ', '丸瀬布上武利', 'マルセップカミムリイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡遠軽町丸瀬布大平', '01', '01555', '0990214', '北海道', 'ホッカイドウ', '紋別郡遠軽町', 'モンベツグンエンガルチョウ', '丸瀬布大平', 'マルセップタイヘイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡遠軽町丸瀬布南丸', '01', '01555', '0990215', '北海道', 'ホッカイドウ', '紋別郡遠軽町', 'モンベツグンエンガルチョウ', '丸瀬布南丸', 'マルセップミナミマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡遠軽町丸瀬布武利', '01', '01555', '0990216', '北海道', 'ホッカイドウ', '紋別郡遠軽町', 'モンベツグンエンガルチョウ', '丸瀬布武利', 'マルセップムリイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市漆山', '06', '06201', '9902161', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '漆山', 'ウルシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市あけぼの', '06', '06201', '9902162', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', 'あけぼの', 'アケボノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市伊達城', '06', '06201', '9902163', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '伊達城', 'ダテジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市新開', '06', '06201', '9902164', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '新開', 'シンカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市七浦', '06', '06201', '9902171', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '七浦', 'ナナウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市千手堂', '06', '06201', '9902172', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '千手堂', 'センジュドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市渋江', '06', '06201', '9902173', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '渋江', 'シブエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市灰塚', '06', '06201', '9902174', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '灰塚', 'ハイヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市中野目', '06', '06201', '9902175', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '中野目', 'ナカノメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市十文字', '06', '06201', '9902211', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '十文字', 'ジュウモンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市上柳', '06', '06201', '9902212', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '上柳', 'カミヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市寺西', '06', '06201', '9902213', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '寺西', 'テラニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市青柳', '06', '06201', '9902214', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '青柳', 'アオヤギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市下柳', '06', '06201', '9902215', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '下柳', 'シモヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市千刈', '06', '06201', '9902216', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '千刈', 'センガリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市風間', '06', '06201', '9902221', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '風間', 'カザマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市青野', '06', '06201', '9902222', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '青野', 'アオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市塔の前', '06', '06201', '9902223', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '塔の前', 'トウノマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市近田', '06', '06201', '9902224', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '近田', 'チカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市花岡', '06', '06201', '9902225', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '花岡', 'ハナオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市西越', '06', '06201', '9902226', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '西越', 'ニシゴシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市千石', '06', '06201', '9902227', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '千石', 'センゴク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市大森', '06', '06201', '9902231', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '大森', 'オオモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市下東山', '06', '06201', '9902232', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '下東山', 'シモヒガシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市切畑', '06', '06201', '9902233', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '切畑', 'キリハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市こも石', '06', '06201', '9902234', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', 'こも石', 'コモイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市中里', '06', '06201', '9902235', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '中里', 'ナカザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市上東山', '06', '06201', '9902241', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '上東山', 'カミヒガシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市高沢', '06', '06201', '9902242', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '高沢', 'タカサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市立谷川', '06', '06201', '9902251', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '立谷川', 'タチヤガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市蔵王温泉', '06', '06201', '9902301', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '蔵王温泉', 'ザオウオンセン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市蔵王堀田', '06', '06201', '9902302', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '蔵王堀田', 'ザオウホッタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市蔵王上野', '06', '06201', '9902303', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '蔵王上野', 'ザオウウワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市蔵王山田', '06', '06201', '9902304', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '蔵王山田', 'ザオウヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市蔵王半郷', '06', '06201', '9902305', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '蔵王半郷', 'ザオウハンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市南半郷', '06', '06201', '9902306', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '南半郷', 'ミナミハンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市表蔵王', '06', '06201', '9902307', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '表蔵王', 'オモテザオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市東半郷', '06', '06201', '9902308', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '東半郷', 'ヒガシハンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市黒沢', '06', '06201', '9902311', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '黒沢', 'クロサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市南松原', '06', '06201', '9902312', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '南松原', 'ミナミマツバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市松原', '06', '06201', '9902313', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '松原', 'マツバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市谷柏', '06', '06201', '9902314', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '谷柏', 'ヤガシワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市津金沢', '06', '06201', '9902315', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '津金沢', 'ツガネザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市片谷地', '06', '06201', '9902316', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '片谷地', 'カタヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市桜田西', '06', '06201', '9902321', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '桜田西', 'サクラダニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市桜田南', '06', '06201', '9902322', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '桜田南', 'サクラダミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市桜田東', '06', '06201', '9902323', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '桜田東', 'サクラダヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市青田南', '06', '06201', '9902324', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '青田南', 'アオタミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市飯田西', '06', '06201', '9902331', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '飯田西', 'イイダニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市飯田', '06', '06201', '9902332', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '飯田', 'イイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市蔵王飯田', '06', '06201', '9902333', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '蔵王飯田', 'ザオウイイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市蔵王成沢', '06', '06201', '9902334', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '蔵王成沢', 'ザオウナリサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市蔵王南成沢', '06', '06201', '9902335', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '蔵王南成沢', 'ザオウミナミナリサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市蔵王西成沢', '06', '06201', '9902337', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '蔵王西成沢', 'ザオウニシナリサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市蔵王松ケ丘', '06', '06201', '9902338', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '蔵王松ケ丘', 'ザオウマツガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市成沢西', '06', '06201', '9902339', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '成沢西', 'ナリサワニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市柏倉', '06', '06201', '9902341', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '柏倉', 'カシワグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市富神前', '06', '06201', '9902342', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '富神前', 'トガミマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市門伝', '06', '06201', '9902342', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '門伝', 'モンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市城森', '06', '06201', '9902343', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '城森', 'シロモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市大道端', '06', '06201', '9902344', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '大道端', 'オオミチバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市富神台', '06', '06201', '9902345', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '富神台', 'トガミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市高木', '06', '06201', '9902346', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '高木', 'タカギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市鋳物町', '06', '06201', '9902351', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '鋳物町', 'イモノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市前明石', '06', '06201', '9902352', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '前明石', 'マエアカシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市明石堂', '06', '06201', '9902353', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '明石堂', 'アカシドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市東二位田', '06', '06201', '9902354', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '東二位田', 'ヒガシニイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市二位田', '06', '06201', '9902355', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '二位田', 'ニイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市百目鬼', '06', '06201', '9902361', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '百目鬼', 'ドメキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市菅沢', '06', '06201', '9902362', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '菅沢', 'スゲサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市長谷堂', '06', '06201', '9902363', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '長谷堂', 'ハセドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市大師堂', '06', '06201', '9902364', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '大師堂', 'ダイシドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市御手作', '06', '06201', '9902365', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '御手作', 'オテサク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市谷地前', '06', '06201', '9902366', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '谷地前', 'ヤチマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市すげさわの丘', '06', '06201', '9902367', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', 'すげさわの丘', 'スゲサワノオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市村木沢', '06', '06201', '9902371', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '村木沢', 'ムラキザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市みのりが丘', '06', '06201', '9902372', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', 'みのりが丘', 'ミノリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市若木', '06', '06201', '9902373', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '若木', 'ワカギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市古館', '06', '06201', '9902374', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '古館', 'フルダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市東古館', '06', '06201', '9902375', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '東古館', 'ヒガシフルダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市桜ケ丘', '06', '06201', '9902376', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '桜ケ丘', 'サクラガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市藤沢川', '06', '06201', '9902377', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '藤沢川', 'フジサワガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市反町', '06', '06201', '9902378', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '反町', 'ソリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市常明寺', '06', '06201', '9902381', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '常明寺', 'ジョウミョウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市滝平', '06', '06201', '9902382', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '滝平', 'タキノヒラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市芳沢', '06', '06201', '9902383', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '芳沢', 'ヨシザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市上反田', '06', '06201', '9902384', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '上反田', 'カミソリダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市下反田', '06', '06201', '9902385', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '下反田', 'シモソリダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市並柳', '06', '06201', '9902386', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '並柳', 'ナミヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市平清水', '06', '06201', '9902401', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '平清水', 'ヒラシミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市小立', '06', '06201', '9902402', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '小立', 'オダチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市岩波', '06', '06201', '9902403', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '岩波', 'イワナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市八森', '06', '06201', '9902404', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '八森', 'ハチモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市土坂', '06', '06201', '9902405', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '土坂', 'ツチザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市神尾', '06', '06201', '9902406', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '神尾', 'カンノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市前田町', '06', '06201', '9902411', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '前田町', 'マエタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市松山', '06', '06201', '9902412', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '松山', 'マツヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市南原町', '06', '06201', '9902413', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '南原町', 'ミナミハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市寿町', '06', '06201', '9902414', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '寿町', 'コトブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市上桜田', '06', '06201', '9902421', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '上桜田', 'カミサクラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市中桜田', '06', '06201', '9902422', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '中桜田', 'ナカサクラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市東青田', '06', '06201', '9902423', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '東青田', 'ヒガシアオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市松見町', '06', '06201', '9902431', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '松見町', 'マツミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市荒楯町', '06', '06201', '9902432', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '荒楯町', 'アラタテチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市鳥居ケ丘', '06', '06201', '9902433', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '鳥居ケ丘', 'トリイガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市旭が丘', '06', '06201', '9902434', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '旭が丘', 'アサヒガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市青田', '06', '06201', '9902435', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '青田', 'アオタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市南一番町', '06', '06201', '9902441', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '南一番町', 'ミナミ01バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市南二番町', '06', '06201', '9902442', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '南二番町', 'ミナミ02バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市南三番町', '06', '06201', '9902443', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '南三番町', 'ミナミ03バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市南四番町', '06', '06201', '9902444', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '南四番町', 'ミナミ04バンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市南栄町', '06', '06201', '9902445', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '南栄町', 'ナンエイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市白山', '06', '06201', '9902446', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '白山', 'ハクサン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市元木', '06', '06201', '9902447', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '元木', 'モトキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市吉原', '06', '06201', '9902451', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '吉原', 'ヨシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市若宮', '06', '06201', '9902453', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '若宮', 'ワカミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市吉原南', '06', '06201', '9902455', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '吉原南', 'ヨシハラミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市南館', '06', '06201', '9902461', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '南館', 'ミナミダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市深町', '06', '06201', '9902462', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '深町', 'フカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市富の中', '06', '06201', '9902463', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '富の中', 'トミノジュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市高堂', '06', '06201', '9902464', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '高堂', 'タカドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市南館西', '06', '06201', '9902465', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '南館西', 'ミナミダテニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市羽黒堂', '06', '06201', '9902471', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '羽黒堂', 'ハグロドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市明神前', '06', '06201', '9902472', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '明神前', 'ミョウジンマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市松栄', '06', '06201', '9902473', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '松栄', 'マツエイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市沼木', '06', '06201', '9902474', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '沼木', 'ヌマギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市木ノ目田', '06', '06201', '9902475', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '木ノ目田', 'キノメダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市飯沢', '06', '06201', '9902476', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '飯沢', 'イイザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市長苗代', '06', '06201', '9902477', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '長苗代', 'ナガナワシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市あかねケ丘', '06', '06201', '9902481', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', 'あかねケ丘', 'アカネガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市久保田', '06', '06201', '9902482', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '久保田', 'クボタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市上町', '06', '06201', '9902483', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '上町', 'ウワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市篭田', '06', '06201', '9902484', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '篭田', 'カゴタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市あずま町', '06', '06201', '9902491', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', 'あずま町', 'アズマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市鉄砲町', '06', '06201', '9902492', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '鉄砲町', 'テッポウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市美畑町', '06', '06201', '9902493', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '美畑町', 'ミハタチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市末広町', '06', '06201', '9902494', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '末広町', 'スエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市若葉町', '06', '06201', '9902495', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '若葉町', 'ワカバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡遠軽町瀬戸瀬東町', '01', '01555', '0990341', '北海道', 'ホッカイドウ', '紋別郡遠軽町', 'モンベツグンエンガルチョウ', '瀬戸瀬東町', 'セトセヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡遠軽町瀬戸瀬西町', '01', '01555', '0990342', '北海道', 'ホッカイドウ', '紋別郡遠軽町', 'モンベツグンエンガルチョウ', '瀬戸瀬西町', 'セトセニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡遠軽町栄野', '01', '01555', '0990343', '北海道', 'ホッカイドウ', '紋別郡遠軽町', 'モンベツグンエンガルチョウ', '栄野', 'サカエノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡遠軽町野上', '01', '01555', '0990344', '北海道', 'ホッカイドウ', '紋別郡遠軽町', 'モンベツグンエンガルチョウ', '野上', 'ノガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡遠軽町湯の里', '01', '01555', '0990345', '北海道', 'ホッカイドウ', '紋別郡遠軽町', 'モンベツグンエンガルチョウ', '湯の里', 'ユノサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡遠軽町若咲内', '01', '01555', '0990346', '北海道', 'ホッカイドウ', '紋別郡遠軽町', 'モンベツグンエンガルチョウ', '若咲内', 'ワカサクナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡遠軽町柏', '01', '01555', '0990347', '北海道', 'ホッカイドウ', '紋別郡遠軽町', 'モンベツグンエンガルチョウ', '柏', 'カシワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡遠軽町', '01', '01555', '0990400', '北海道', 'ホッカイドウ', '紋別郡遠軽町', 'モンベツグンエンガルチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('144519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡遠軽町学田', '01', '01555', '0990401', '北海道', 'ホッカイドウ', '紋別郡遠軽町', 'モンベツグンエンガルチョウ', '学田', 'ガクデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡遠軽町2条通北', '01', '01555', '0990402', '北海道', 'ホッカイドウ', '紋別郡遠軽町', 'モンベツグンエンガルチョウ', '2条通北', '02ジョウドオリキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡遠軽町1条通北', '01', '01555', '0990403', '北海道', 'ホッカイドウ', '紋別郡遠軽町', 'モンベツグンエンガルチョウ', '1条通北', '01ジョウドオリキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡遠軽町大通北', '01', '01555', '0990404', '北海道', 'ホッカイドウ', '紋別郡遠軽町', 'モンベツグンエンガルチョウ', '大通北', 'オオドオリキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡遠軽町岩見通北', '01', '01555', '0990405', '北海道', 'ホッカイドウ', '紋別郡遠軽町', 'モンベツグンエンガルチョウ', '岩見通北', 'イワミドオリキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡遠軽町宮前町', '01', '01555', '0990406', '北海道', 'ホッカイドウ', '紋別郡遠軽町', 'モンベツグンエンガルチョウ', '宮前町', 'ミヤマエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡遠軽町丸大', '01', '01555', '0990407', '北海道', 'ホッカイドウ', '紋別郡遠軽町', 'モンベツグンエンガルチョウ', '丸大', 'マルダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡遠軽町留岡', '01', '01555', '0990408', '北海道', 'ホッカイドウ', '紋別郡遠軽町', 'モンベツグンエンガルチョウ', '留岡', 'トメオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡遠軽町東町', '01', '01555', '0990410', '北海道', 'ホッカイドウ', '紋別郡遠軽町', 'モンベツグンエンガルチョウ', '東町', 'ヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡遠軽町向遠軽', '01', '01555', '0990411', '北海道', 'ホッカイドウ', '紋別郡遠軽町', 'モンベツグンエンガルチョウ', '向遠軽', 'ムカイエンガル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡遠軽町豊里', '01', '01555', '0990412', '北海道', 'ホッカイドウ', '紋別郡遠軽町', 'モンベツグンエンガルチョウ', '豊里', 'トヨサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡遠軽町寿町', '01', '01555', '0990413', '北海道', 'ホッカイドウ', '紋別郡遠軽町', 'モンベツグンエンガルチョウ', '寿町', 'コトブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡遠軽町南町', '01', '01555', '0990414', '北海道', 'ホッカイドウ', '紋別郡遠軽町', 'モンベツグンエンガルチョウ', '南町', 'ミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡遠軽町岩見通南', '01', '01555', '0990415', '北海道', 'ホッカイドウ', '紋別郡遠軽町', 'モンベツグンエンガルチョウ', '岩見通南', 'イワミドオリミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡遠軽町大通南', '01', '01555', '0990416', '北海道', 'ホッカイドウ', '紋別郡遠軽町', 'モンベツグンエンガルチョウ', '大通南', 'オオドオリミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡遠軽町1条通南', '01', '01555', '0990417', '北海道', 'ホッカイドウ', '紋別郡遠軽町', 'モンベツグンエンガルチョウ', '1条通南', '01ジョウドオリミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡遠軽町2条通南', '01', '01555', '0990418', '北海道', 'ホッカイドウ', '紋別郡遠軽町', 'モンベツグンエンガルチョウ', '2条通南', '02ジョウドオリミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡遠軽町福路', '01', '01555', '0990421', '北海道', 'ホッカイドウ', '紋別郡遠軽町', 'モンベツグンエンガルチョウ', '福路', 'フクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡遠軽町清川', '01', '01555', '0990422', '北海道', 'ホッカイドウ', '紋別郡遠軽町', 'モンベツグンエンガルチョウ', '清川', 'キヨカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡遠軽町若松', '01', '01555', '0990423', '北海道', 'ホッカイドウ', '紋別郡遠軽町', 'モンベツグンエンガルチョウ', '若松', 'ワカマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡遠軽町美山', '01', '01555', '0990424', '北海道', 'ホッカイドウ', '紋別郡遠軽町', 'モンベツグンエンガルチョウ', '美山', 'ミヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡遠軽町千代田', '01', '01555', '0990425', '北海道', 'ホッカイドウ', '紋別郡遠軽町', 'モンベツグンエンガルチョウ', '千代田', 'チヨダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡遠軽町社名淵', '01', '01555', '0990426', '北海道', 'ホッカイドウ', '紋別郡遠軽町', 'モンベツグンエンガルチョウ', '社名淵', 'シャナフチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡遠軽町見晴', '01', '01555', '0990427', '北海道', 'ホッカイドウ', '紋別郡遠軽町', 'モンベツグンエンガルチョウ', '見晴', 'ミハラシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡遠軽町西町', '01', '01555', '0990428', '北海道', 'ホッカイドウ', '紋別郡遠軽町', 'モンベツグンエンガルチョウ', '西町', 'ニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡遠軽町生田原水穂', '01', '01555', '0990621', '北海道', 'ホッカイドウ', '紋別郡遠軽町', 'モンベツグンエンガルチョウ', '生田原水穂', 'イクタハラミズホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡遠軽町生田原安国', '01', '01555', '0990622', '北海道', 'ホッカイドウ', '紋別郡遠軽町', 'モンベツグンエンガルチョウ', '生田原安国', 'イクタハラヤスクニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡遠軽町生田原旭野', '01', '01555', '0990623', '北海道', 'ホッカイドウ', '紋別郡遠軽町', 'モンベツグンエンガルチョウ', '生田原旭野', 'イクタハラアサヒノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡遠軽町生田原豊原', '01', '01555', '0990624', '北海道', 'ホッカイドウ', '紋別郡遠軽町', 'モンベツグンエンガルチョウ', '生田原豊原', 'イクタハラトヨハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡遠軽町生田原', '01', '01555', '0990701', '北海道', 'ホッカイドウ', '紋別郡遠軽町', 'モンベツグンエンガルチョウ', '生田原', 'イクタハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡遠軽町生田原伊吹', '01', '01555', '0990702', '北海道', 'ホッカイドウ', '紋別郡遠軽町', 'モンベツグンエンガルチョウ', '生田原伊吹', 'イクタハライブキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡遠軽町生田原八重', '01', '01555', '0990703', '北海道', 'ホッカイドウ', '紋別郡遠軽町', 'モンベツグンエンガルチョウ', '生田原八重', 'イクタハラヤエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡遠軽町生田原岩戸', '01', '01555', '0990704', '北海道', 'ホッカイドウ', '紋別郡遠軽町', 'モンベツグンエンガルチョウ', '生田原岩戸', 'イクタハライワト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡遠軽町生田原清里', '01', '01555', '0990705', '北海道', 'ホッカイドウ', '紋別郡遠軽町', 'モンベツグンエンガルチョウ', '生田原清里', 'イクタハラキヨサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市相内町', '01', '01208', '0990871', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '相内町', 'アイノナイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市豊田', '01', '01208', '0990872', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '豊田', 'トヨタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市西相内', '01', '01208', '0990873', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '西相内', 'ニシアイノナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市住吉', '01', '01208', '0990874', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '住吉', 'スミヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市本沢', '01', '01208', '0990875', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '本沢', 'ホンザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市富里', '01', '01208', '0990876', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '富里', 'トミサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市柏木', '01', '01208', '0990877', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '柏木', 'カシワギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市東相内町', '01', '01208', '0990878', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '東相内町', 'ヒガシアイノナイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市美園', '01', '01208', '0990879', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '美園', 'ミソノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県寒河江市', '06', '06206', '9910000', '山形県', 'ヤマガタケン', '寒河江市', 'サガエシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('144620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県寒河江市入倉', '06', '06206', '9910001', '山形県', 'ヤマガタケン', '寒河江市', 'サガエシ', '入倉', 'ニュウグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県寒河江市下河原', '06', '06206', '9910002', '山形県', 'ヤマガタケン', '寒河江市', 'サガエシ', '下河原', 'シモガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県寒河江市西根', '06', '06206', '9910003', '山形県', 'ヤマガタケン', '寒河江市', 'サガエシ', '西根', 'ニシネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県寒河江市西根北町', '06', '06206', '9910004', '山形県', 'ヤマガタケン', '寒河江市', 'サガエシ', '西根北町', 'ニシネキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県寒河江市中河原', '06', '06206', '9910005', '山形県', 'ヤマガタケン', '寒河江市', 'サガエシ', '中河原', 'ナカガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県寒河江市上河原', '06', '06206', '9910006', '山形県', 'ヤマガタケン', '寒河江市', 'サガエシ', '上河原', 'カミガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県寒河江市夕かへ', '06', '06206', '9910006', '山形県', 'ヤマガタケン', '寒河江市', 'サガエシ', '夕かへ', 'ユウガエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県寒河江市道生', '06', '06206', '9910007', '山形県', 'ヤマガタケン', '寒河江市', 'サガエシ', '道生', 'ドウショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県寒河江市菊地堂', '06', '06206', '9910008', '山形県', 'ヤマガタケン', '寒河江市', 'サガエシ', '菊地堂', 'キクチドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県寒河江市雲河原', '06', '06206', '9910008', '山形県', 'ヤマガタケン', '寒河江市', 'サガエシ', '雲河原', 'クモガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県寒河江市日田', '06', '06206', '9910011', '山形県', 'ヤマガタケン', '寒河江市', 'サガエシ', '日田', 'ニッタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県寒河江市新山町', '06', '06206', '9910012', '山形県', 'ヤマガタケン', '寒河江市', 'サガエシ', '新山町', 'シンザンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県寒河江市高田', '06', '06206', '9910013', '山形県', 'ヤマガタケン', '寒河江市', 'サガエシ', '高田', 'タカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県寒河江市中央', '06', '06206', '9910021', '山形県', 'ヤマガタケン', '寒河江市', 'サガエシ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県寒河江市七日町', '06', '06206', '9910022', '山形県', 'ヤマガタケン', '寒河江市', 'サガエシ', '七日町', 'ナノカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県寒河江市丸内', '06', '06206', '9910023', '山形県', 'ヤマガタケン', '寒河江市', 'サガエシ', '丸内', 'マルノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県寒河江市六供町', '06', '06206', '9910024', '山形県', 'ヤマガタケン', '寒河江市', 'サガエシ', '六供町', 'ロックマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県寒河江市八幡町', '06', '06206', '9910025', '山形県', 'ヤマガタケン', '寒河江市', 'サガエシ', '八幡町', 'ヤワタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県寒河江市山岸町', '06', '06206', '9910026', '山形県', 'ヤマガタケン', '寒河江市', 'サガエシ', '山岸町', 'ヤマギシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県寒河江市石持町', '06', '06206', '9910027', '山形県', 'ヤマガタケン', '寒河江市', 'サガエシ', '石持町', 'イシモチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県寒河江市本町', '06', '06206', '9910031', '山形県', 'ヤマガタケン', '寒河江市', 'サガエシ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県寒河江市南町', '06', '06206', '9910032', '山形県', 'ヤマガタケン', '寒河江市', 'サガエシ', '南町', 'ミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県寒河江市末広町', '06', '06206', '9910033', '山形県', 'ヤマガタケン', '寒河江市', 'サガエシ', '末広町', 'スエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県寒河江市栄町', '06', '06206', '9910034', '山形県', 'ヤマガタケン', '寒河江市', 'サガエシ', '栄町', 'サカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県寒河江市幸町', '06', '06206', '9910035', '山形県', 'ヤマガタケン', '寒河江市', 'サガエシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県寒河江市寒河江', '06', '06206', '9910041', '山形県', 'ヤマガタケン', '寒河江市', 'サガエシ', '寒河江', 'サガエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県寒河江市高屋', '06', '06206', '9910042', '山形県', 'ヤマガタケン', '寒河江市', 'サガエシ', '高屋', 'タカヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県寒河江市島', '06', '06206', '9910043', '山形県', 'ヤマガタケン', '寒河江市', 'サガエシ', '島', 'シマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県寒河江市越井坂町', '06', '06206', '9910044', '山形県', 'ヤマガタケン', '寒河江市', 'サガエシ', '越井坂町', 'コシイザカチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県寒河江市小沼町', '06', '06206', '9910045', '山形県', 'ヤマガタケン', '寒河江市', 'サガエシ', '小沼町', 'コヌマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県寒河江市東新山町', '06', '06206', '9910046', '山形県', 'ヤマガタケン', '寒河江市', 'サガエシ', '東新山町', 'ヒガシシンザンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県寒河江市新山', '06', '06206', '9910047', '山形県', 'ヤマガタケン', '寒河江市', 'サガエシ', '新山', 'シンザン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県寒河江市みずき', '06', '06206', '9910048', '山形県', 'ヤマガタケン', '寒河江市', 'サガエシ', 'みずき', 'ミズキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県寒河江市本楯', '06', '06206', '9910049', '山形県', 'ヤマガタケン', '寒河江市', 'サガエシ', '本楯', 'モトダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県寒河江市若葉町', '06', '06206', '9910051', '山形県', 'ヤマガタケン', '寒河江市', 'サガエシ', '若葉町', 'ワカバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県寒河江市幸田町', '06', '06206', '9910052', '山形県', 'ヤマガタケン', '寒河江市', 'サガエシ', '幸田町', 'サチタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県寒河江市元町', '06', '06206', '9910053', '山形県', 'ヤマガタケン', '寒河江市', 'サガエシ', '元町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県寒河江市仲谷地', '06', '06206', '9910054', '山形県', 'ヤマガタケン', '寒河江市', 'サガエシ', '仲谷地', 'ナカヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県寒河江市船橋町', '06', '06206', '9910055', '山形県', 'ヤマガタケン', '寒河江市', 'サガエシ', '船橋町', 'フナバシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県寒河江市中央工業団地', '06', '06206', '9910061', '山形県', 'ヤマガタケン', '寒河江市', 'サガエシ', '中央工業団地', 'チュウオウコウギョウダンチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県寒河江市緑町', '06', '06206', '9910062', '山形県', 'ヤマガタケン', '寒河江市', 'サガエシ', '緑町', 'ミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県寒河江市柴橋', '06', '06206', '9910063', '山形県', 'ヤマガタケン', '寒河江市', 'サガエシ', '柴橋', 'シバハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県寒河江市平塩', '06', '06206', '9910064', '山形県', 'ヤマガタケン', '寒河江市', 'サガエシ', '平塩', 'ヒラシオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県寒河江市中郷', '06', '06206', '9910065', '山形県', 'ヤマガタケン', '寒河江市', 'サガエシ', '中郷', 'ナカゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県寒河江市松川', '06', '06206', '9910066', '山形県', 'ヤマガタケン', '寒河江市', 'サガエシ', '松川', 'マツカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西村山郡大江町左沢', '06', '06324', '9910801', '山形県', 'ヤマガタケン', '西村山郡大江町', 'ニシムラヤマグンオオエマチ', '左沢', 'アテラザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道常呂郡置戸町', '01', '01550', '0991100', '北海道', 'ホッカイドウ', '常呂郡置戸町', 'トコログンオケトチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('144667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道常呂郡置戸町北光', '01', '01550', '0991101', '北海道', 'ホッカイドウ', '常呂郡置戸町', 'トコログンオケトチョウ', '北光', 'ホッコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道常呂郡置戸町緑', '01', '01550', '0991102', '北海道', 'ホッカイドウ', '常呂郡置戸町', 'トコログンオケトチョウ', '緑', 'ミドリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道常呂郡置戸町栄二', '01', '01550', '0991103', '北海道', 'ホッカイドウ', '常呂郡置戸町', 'トコログンオケトチョウ', '栄二', 'サカエニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道常呂郡置戸町栄一', '01', '01550', '0991104', '北海道', 'ホッカイドウ', '常呂郡置戸町', 'トコログンオケトチョウ', '栄一', 'サカエイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道常呂郡置戸町洗心', '01', '01550', '0991105', '北海道', 'ホッカイドウ', '常呂郡置戸町', 'トコログンオケトチョウ', '洗心', 'センシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道常呂郡置戸町新和', '01', '01550', '0991106', '北海道', 'ホッカイドウ', '常呂郡置戸町', 'トコログンオケトチョウ', '新和', 'シンワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道常呂郡置戸町若松', '01', '01550', '0991112', '北海道', 'ホッカイドウ', '常呂郡置戸町', 'トコログンオケトチョウ', '若松', 'ワカマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道常呂郡置戸町新光', '01', '01550', '0991113', '北海道', 'ホッカイドウ', '常呂郡置戸町', 'トコログンオケトチョウ', '新光', 'シンコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144675', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道常呂郡置戸町協生', '01', '01550', '0991114', '北海道', 'ホッカイドウ', '常呂郡置戸町', 'トコログンオケトチョウ', '協生', 'キョウセイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144676', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道常呂郡置戸町宮下', '01', '01550', '0991115', '北海道', 'ホッカイドウ', '常呂郡置戸町', 'トコログンオケトチョウ', '宮下', 'ミヤシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144677', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道常呂郡置戸町朝日', '01', '01550', '0991116', '北海道', 'ホッカイドウ', '常呂郡置戸町', 'トコログンオケトチョウ', '朝日', 'アサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144678', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道常呂郡置戸町宮坂', '01', '01550', '0991117', '北海道', 'ホッカイドウ', '常呂郡置戸町', 'トコログンオケトチョウ', '宮坂', 'ミヤサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144679', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道常呂郡置戸町若木', '01', '01550', '0991118', '北海道', 'ホッカイドウ', '常呂郡置戸町', 'トコログンオケトチョウ', '若木', 'ワカギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144680', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道常呂郡置戸町北農', '01', '01550', '0991121', '北海道', 'ホッカイドウ', '常呂郡置戸町', 'トコログンオケトチョウ', '北農', 'ホクノウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144681', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道常呂郡置戸町林友', '01', '01550', '0991122', '北海道', 'ホッカイドウ', '常呂郡置戸町', 'トコログンオケトチョウ', '林友', 'リンユウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144682', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道常呂郡置戸町拓殖', '01', '01550', '0991123', '北海道', 'ホッカイドウ', '常呂郡置戸町', 'トコログンオケトチョウ', '拓殖', 'タクショク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144683', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道常呂郡置戸町拓実', '01', '01550', '0991124', '北海道', 'ホッカイドウ', '常呂郡置戸町', 'トコログンオケトチョウ', '拓実', 'タクジツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144684', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道常呂郡置戸町中央', '01', '01550', '0991131', '北海道', 'ホッカイドウ', '常呂郡置戸町', 'トコログンオケトチョウ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144685', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道常呂郡置戸町協和', '01', '01550', '0991132', '北海道', 'ホッカイドウ', '常呂郡置戸町', 'トコログンオケトチョウ', '協和', 'キョウワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144686', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道常呂郡置戸町更盛', '01', '01550', '0991133', '北海道', 'ホッカイドウ', '常呂郡置戸町', 'トコログンオケトチョウ', '更盛', 'コウセイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144687', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道常呂郡置戸町十全', '01', '01550', '0991134', '北海道', 'ホッカイドウ', '常呂郡置戸町', 'トコログンオケトチョウ', '十全', 'ジュウゼン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144688', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道常呂郡置戸町国栄', '01', '01550', '0991135', '北海道', 'ホッカイドウ', '常呂郡置戸町', 'トコログンオケトチョウ', '国栄', 'コクエイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道常呂郡置戸町日進', '01', '01550', '0991136', '北海道', 'ホッカイドウ', '常呂郡置戸町', 'トコログンオケトチョウ', '日進', 'ニッシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道常呂郡置戸町大美', '01', '01550', '0991137', '北海道', 'ホッカイドウ', '常呂郡置戸町', 'トコログンオケトチョウ', '大美', 'オオミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道常呂郡置戸町中里', '01', '01550', '0991138', '北海道', 'ホッカイドウ', '常呂郡置戸町', 'トコログンオケトチョウ', '中里', 'ナカサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道常呂郡置戸町安住', '01', '01550', '0991251', '北海道', 'ホッカイドウ', '常呂郡置戸町', 'トコログンオケトチョウ', '安住', 'アズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道常呂郡置戸町勝山', '01', '01550', '0991252', '北海道', 'ホッカイドウ', '常呂郡置戸町', 'トコログンオケトチョウ', '勝山', 'カツヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道常呂郡置戸町春日', '01', '01550', '0991253', '北海道', 'ホッカイドウ', '常呂郡置戸町', 'トコログンオケトチョウ', '春日', 'カスガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道常呂郡置戸町常元', '01', '01550', '0991254', '北海道', 'ホッカイドウ', '常呂郡置戸町', 'トコログンオケトチョウ', '常元', 'ツネモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道常呂郡置戸町境野', '01', '01550', '0991361', '北海道', 'ホッカイドウ', '常呂郡置戸町', 'トコログンオケトチョウ', '境野', 'サカイノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道常呂郡置戸町雄勝', '01', '01550', '0991362', '北海道', 'ホッカイドウ', '常呂郡置戸町', 'トコログンオケトチョウ', '雄勝', 'オカチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道常呂郡置戸町幸岡', '01', '01550', '0991363', '北海道', 'ホッカイドウ', '常呂郡置戸町', 'トコログンオケトチョウ', '幸岡', 'サチオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道常呂郡置戸町秋田', '01', '01550', '0991364', '北海道', 'ホッカイドウ', '常呂郡置戸町', 'トコログンオケトチョウ', '秋田', 'アキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道常呂郡置戸町豊住', '01', '01550', '0991365', '北海道', 'ホッカイドウ', '常呂郡置戸町', 'トコログンオケトチョウ', '豊住', 'トヨズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道常呂郡置戸町川南', '01', '01550', '0991366', '北海道', 'ホッカイドウ', '常呂郡置戸町', 'トコログンオケトチョウ', '川南', 'カワミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道常呂郡置戸町常盤', '01', '01550', '0991367', '北海道', 'ホッカイドウ', '常呂郡置戸町', 'トコログンオケトチョウ', '常盤', 'トキワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道常呂郡訓子府町', '01', '01549', '0991400', '北海道', 'ホッカイドウ', '常呂郡訓子府町', 'トコログンクンネップチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('144706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道常呂郡訓子府町日出', '01', '01549', '0991401', '北海道', 'ホッカイドウ', '常呂郡訓子府町', 'トコログンクンネップチョウ', '日出', 'ヒノデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道常呂郡訓子府町穂波', '01', '01549', '0991402', '北海道', 'ホッカイドウ', '常呂郡訓子府町', 'トコログンクンネップチョウ', '穂波', 'ホナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道常呂郡訓子府町東幸町', '01', '01549', '0991403', '北海道', 'ホッカイドウ', '常呂郡訓子府町', 'トコログンクンネップチョウ', '東幸町', 'ヒガシサイワイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道常呂郡訓子府町柏丘', '01', '01549', '0991404', '北海道', 'ホッカイドウ', '常呂郡訓子府町', 'トコログンクンネップチョウ', '柏丘', 'カシワオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道常呂郡訓子府町高園', '01', '01549', '0991405', '北海道', 'ホッカイドウ', '常呂郡訓子府町', 'トコログンクンネップチョウ', '高園', 'タカゾノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道常呂郡訓子府町弥生', '01', '01549', '0991406', '北海道', 'ホッカイドウ', '常呂郡訓子府町', 'トコログンクンネップチョウ', '弥生', 'ヤヨイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道常呂郡訓子府町福野', '01', '01549', '0991407', '北海道', 'ホッカイドウ', '常呂郡訓子府町', 'トコログンクンネップチョウ', '福野', 'フクノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道常呂郡訓子府町大谷', '01', '01549', '0991411', '北海道', 'ホッカイドウ', '常呂郡訓子府町', 'トコログンクンネップチョウ', '大谷', 'オオタニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道常呂郡訓子府町緑丘', '01', '01549', '0991412', '北海道', 'ホッカイドウ', '常呂郡訓子府町', 'トコログンクンネップチョウ', '緑丘', 'ミドリオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道常呂郡訓子府町協成', '01', '01549', '0991413', '北海道', 'ホッカイドウ', '常呂郡訓子府町', 'トコログンクンネップチョウ', '協成', 'キョウセイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道常呂郡訓子府町開盛', '01', '01549', '0991414', '北海道', 'ホッカイドウ', '常呂郡訓子府町', 'トコログンクンネップチョウ', '開盛', 'カイセイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道常呂郡訓子府町美園', '01', '01549', '0991415', '北海道', 'ホッカイドウ', '常呂郡訓子府町', 'トコログンクンネップチョウ', '美園', 'ミソノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道常呂郡訓子府町常盤', '01', '01549', '0991416', '北海道', 'ホッカイドウ', '常呂郡訓子府町', 'トコログンクンネップチョウ', '常盤', 'トキワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道常呂郡訓子府町末広町', '01', '01549', '0991417', '北海道', 'ホッカイドウ', '常呂郡訓子府町', 'トコログンクンネップチョウ', '末広町', 'スエヒロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道常呂郡訓子府町実郷', '01', '01549', '0991418', '北海道', 'ホッカイドウ', '常呂郡訓子府町', 'トコログンクンネップチョウ', '実郷', 'ミサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道常呂郡訓子府町駒里', '01', '01549', '0991421', '北海道', 'ホッカイドウ', '常呂郡訓子府町', 'トコログンクンネップチョウ', '駒里', 'コマサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道常呂郡訓子府町北栄', '01', '01549', '0991422', '北海道', 'ホッカイドウ', '常呂郡訓子府町', 'トコログンクンネップチョウ', '北栄', 'ホクエイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道常呂郡訓子府町西幸町', '01', '01549', '0991423', '北海道', 'ホッカイドウ', '常呂郡訓子府町', 'トコログンクンネップチョウ', '西幸町', 'ニシサイワイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道常呂郡訓子府町西富', '01', '01549', '0991424', '北海道', 'ホッカイドウ', '常呂郡訓子府町', 'トコログンクンネップチョウ', '西富', 'ニシトミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道常呂郡訓子府町若葉町', '01', '01549', '0991425', '北海道', 'ホッカイドウ', '常呂郡訓子府町', 'トコログンクンネップチョウ', '若葉町', 'ワカバマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道常呂郡訓子府町清住', '01', '01549', '0991426', '北海道', 'ホッカイドウ', '常呂郡訓子府町', 'トコログンクンネップチョウ', '清住', 'キヨズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道常呂郡訓子府町豊坂', '01', '01549', '0991427', '北海道', 'ホッカイドウ', '常呂郡訓子府町', 'トコログンクンネップチョウ', '豊坂', 'トヨサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道常呂郡訓子府町東町', '01', '01549', '0991431', '北海道', 'ホッカイドウ', '常呂郡訓子府町', 'トコログンクンネップチョウ', '東町', 'ヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道常呂郡訓子府町旭町', '01', '01549', '0991432', '北海道', 'ホッカイドウ', '常呂郡訓子府町', 'トコログンクンネップチョウ', '旭町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道常呂郡訓子府町仲町', '01', '01549', '0991433', '北海道', 'ホッカイドウ', '常呂郡訓子府町', 'トコログンクンネップチョウ', '仲町', 'ナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道常呂郡訓子府町栄町', '01', '01549', '0991434', '北海道', 'ホッカイドウ', '常呂郡訓子府町', 'トコログンクンネップチョウ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道常呂郡訓子府町若富町', '01', '01549', '0991435', '北海道', 'ホッカイドウ', '常呂郡訓子府町', 'トコログンクンネップチョウ', '若富町', 'ワカトミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道常呂郡訓子府町大町', '01', '01549', '0991436', '北海道', 'ホッカイドウ', '常呂郡訓子府町', 'トコログンクンネップチョウ', '大町', 'オオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道常呂郡訓子府町元町', '01', '01549', '0991437', '北海道', 'ホッカイドウ', '常呂郡訓子府町', 'トコログンクンネップチョウ', '元町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市南丘', '01', '01208', '0991581', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '南丘', 'ミナミオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市開成', '01', '01208', '0991582', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '開成', 'カイセイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市北上', '01', '01208', '0991583', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '北上', 'キタガミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市常川', '01', '01208', '0991584', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '常川', 'ツネカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市上ところ', '01', '01208', '0991585', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '上ところ', 'カミトコロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市広郷', '01', '01208', '0991586', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '広郷', 'ヒロサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市豊地', '01', '01208', '0991587', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '豊地', 'ホウヂ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市', '06', '06202', '9920000', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('144760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市窪田町東江股', '06', '06202', '9920001', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '窪田町東江股', 'クボタマチヒガシエマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市窪田町矢野目', '06', '06202', '9920002', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '窪田町矢野目', 'クボタマチヤノメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市窪田町窪田', '06', '06202', '9920003', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '窪田町窪田', 'クボタマチクボタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市窪田町小瀬', '06', '06202', '9920004', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '窪田町小瀬', 'クボタマチコゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市窪田町藤泉', '06', '06202', '9920005', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '窪田町藤泉', 'クボタマチフジイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市中田町', '06', '06202', '9920011', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '中田町', 'ナカダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市金池', '06', '06202', '9920012', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '金池', 'カナイケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市栄町', '06', '06202', '9920013', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市鍛冶町', '06', '06202', '9920014', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '鍛冶町', 'カジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市立町', '06', '06202', '9920015', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '立町', 'タツマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市川井小路', '06', '06202', '9920016', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '川井小路', 'カワイコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市桜木町', '06', '06202', '9920017', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '桜木町', 'サクラギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市花沢', '06', '06202', '9920021', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '花沢', 'ハナザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市花沢町', '06', '06202', '9920022', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '花沢町', 'ハナザワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市下花沢', '06', '06202', '9920023', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '下花沢', 'シモハナザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市東大通', '06', '06202', '9920024', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '東大通', 'ヒガシオオドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市通町', '06', '06202', '9920025', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '通町', 'トオリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市東', '06', '06202', '9920026', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '東', 'ヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市駅前', '06', '06202', '9920027', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '駅前', 'エキマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市大町', '06', '06202', '9920031', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '大町', 'オオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市相生町', '06', '06202', '9920032', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '相生町', 'アイオイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市福田町', '06', '06202', '9920033', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '福田町', 'フクダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市吾妻町', '06', '06202', '9920034', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '吾妻町', 'アヅマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市太田町', '06', '06202', '9920035', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '太田町', 'オオタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市福田', '06', '06202', '9920036', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '福田', 'フクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市本町', '06', '06202', '9920037', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市城南', '06', '06202', '9920038', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '城南', 'ジョウナン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市門東町', '06', '06202', '9920039', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '門東町', 'モントウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市塩井町宮井', '06', '06202', '9920041', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '塩井町宮井', 'シオイマチミヤイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市塩井町塩野', '06', '06202', '9920042', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '塩井町塩野', 'シオイマチシオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市塩野', '06', '06202', '9920043', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '塩野', 'シオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市春日', '06', '06202', '9920044', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '春日', 'カスガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市中央', '06', '06202', '9920045', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市信夫町', '06', '06202', '9920046', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '信夫町', 'シノブマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市徳町', '06', '06202', '9920047', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '徳町', 'トクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市城北', '06', '06202', '9920051', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '城北', 'ジョウホク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市丸の内', '06', '06202', '9920052', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '丸の内', 'マルノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市松が岬', '06', '06202', '9920053', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '松が岬', 'マツガサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市城西', '06', '06202', '9920054', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '城西', 'ジョウセイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市御廟', '06', '06202', '9920055', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '御廟', 'ゴビョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市直江町', '06', '06202', '9920056', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '直江町', 'ナオエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市成島町', '06', '06202', '9920057', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '成島町', 'ナルシママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市木場町', '06', '06202', '9920058', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '木場町', 'キバマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市西大通', '06', '06202', '9920059', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '西大通', 'ニシオオドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市堀川町', '06', '06202', '9920061', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '堀川町', 'ホリカワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市林泉寺', '06', '06202', '9920062', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '林泉寺', 'リンセンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市泉町', '06', '06202', '9920063', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '泉町', 'イズミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市杉の目町', '06', '06202', '9920064', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '杉の目町', 'スギノメマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市古志田町', '06', '06202', '9920065', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '古志田町', 'フルシダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市遠山町', '06', '06202', '9920066', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '遠山町', 'トオヤママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市舘山矢子町', '06', '06202', '9920071', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '舘山矢子町', 'タテヤマヤゴマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144811', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市舘山', '06', '06202', '9920072', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '舘山', 'タテヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144812', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市吹屋敷町', '06', '06202', '9920073', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '吹屋敷町', 'ブキヤシキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144813', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市矢来', '06', '06202', '9920074', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '矢来', 'ヤライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144814', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市赤芝町', '06', '06202', '9920075', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '赤芝町', 'アカシバマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144815', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市小野川町', '06', '06202', '9920076', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '小野川町', 'オノガワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144816', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市簗沢', '06', '06202', '9920077', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '簗沢', 'ヤナザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144817', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市下小菅', '06', '06202', '9920081', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '下小菅', 'シモコスゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144818', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市広幡町小山田', '06', '06202', '9920082', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '広幡町小山田', 'ヒロハタマチオヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144819', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市広幡町成島', '06', '06202', '9920083', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '広幡町成島', 'ヒロハタマチナルシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144820', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市広幡町上小菅', '06', '06202', '9920084', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '広幡町上小菅', 'ヒロハタマチカミコスゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144821', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市広幡町沖仲', '06', '06202', '9920085', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '広幡町沖仲', 'ヒロハタマチオキナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144822', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市広幡町京塚', '06', '06202', '9920086', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '広幡町京塚', 'ヒロハタマチキョウヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144823', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市広幡町大沢', '06', '06202', '9920087', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '広幡町大沢', 'ヒロハタマチオオサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市六郷町桐原', '06', '06202', '9920091', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '六郷町桐原', 'ロクゴウマチキリバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市六郷町西江股', '06', '06202', '9920092', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '六郷町西江股', 'ロクゴウマチニシエマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市六郷町西藤泉', '06', '06202', '9920093', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '六郷町西藤泉', 'ロクゴウマチニシフジイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市六郷町轟', '06', '06202', '9920094', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '六郷町轟', 'ロクゴウマチトドロキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市六郷町一漆', '06', '06202', '9920095', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '六郷町一漆', 'ロクゴウマチヒトツウルシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市六郷町長橋', '06', '06202', '9920096', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '六郷町長橋', 'ロクゴウマチナガハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市下新田', '06', '06202', '9920111', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '下新田', 'シモニイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市浅川', '06', '06202', '9920112', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '浅川', 'アサガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市長手', '06', '06202', '9920113', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '長手', 'ナガテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市木和田', '06', '06202', '9920114', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '木和田', 'キワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市梓川', '06', '06202', '9920115', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '梓川', 'アズサガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市竹井', '06', '06202', '9920116', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '竹井', 'タケイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市川井', '06', '06202', '9920117', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '川井', 'カワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市上新田', '06', '06202', '9920118', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '上新田', 'カミニイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市アルカディア', '06', '06202', '9920119', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', 'アルカディア', 'アルカディア', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144839', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東置賜郡高畠町上和田', '06', '06381', '9920261', '山形県', 'ヤマガタケン', '東置賜郡高畠町', 'ヒガシオキタマグンタカハタマチ', '上和田', 'カミワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144840', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東置賜郡高畠町元和田', '06', '06381', '9920262', '山形県', 'ヤマガタケン', '東置賜郡高畠町', 'ヒガシオキタマグンタカハタマチ', '元和田', 'モトワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東置賜郡高畠町下和田', '06', '06381', '9920263', '山形県', 'ヤマガタケン', '東置賜郡高畠町', 'ヒガシオキタマグンタカハタマチ', '下和田', 'シモワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東置賜郡高畠町馬頭', '06', '06381', '9920264', '山形県', 'ヤマガタケン', '東置賜郡高畠町', 'ヒガシオキタマグンタカハタマチ', '馬頭', 'バトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東置賜郡高畠町佐沢', '06', '06381', '9920265', '山形県', 'ヤマガタケン', '東置賜郡高畠町', 'ヒガシオキタマグンタカハタマチ', '佐沢', 'サザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東置賜郡高畠町', '06', '06381', '9920300', '山形県', 'ヤマガタケン', '東置賜郡高畠町', 'ヒガシオキタマグンタカハタマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('144845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東置賜郡高畠町二井宿', '06', '06381', '9920301', '山形県', 'ヤマガタケン', '東置賜郡高畠町', 'ヒガシオキタマグンタカハタマチ', '二井宿', 'ニイジュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東置賜郡高畠町安久津', '06', '06381', '9920302', '山形県', 'ヤマガタケン', '東置賜郡高畠町', 'ヒガシオキタマグンタカハタマチ', '安久津', 'アクツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東置賜郡高畠町金原', '06', '06381', '9920311', '山形県', 'ヤマガタケン', '東置賜郡高畠町', 'ヒガシオキタマグンタカハタマチ', '金原', 'カナバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東置賜郡高畠町小郡山', '06', '06381', '9920312', '山形県', 'ヤマガタケン', '東置賜郡高畠町', 'ヒガシオキタマグンタカハタマチ', '小郡山', 'コゴオリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東置賜郡高畠町高安', '06', '06381', '9920313', '山形県', 'ヤマガタケン', '東置賜郡高畠町', 'ヒガシオキタマグンタカハタマチ', '高安', 'コウヤス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東置賜郡高畠町塩森', '06', '06381', '9920314', '山形県', 'ヤマガタケン', '東置賜郡高畠町', 'ヒガシオキタマグンタカハタマチ', '塩森', 'シオノモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東置賜郡高畠町泉岡', '06', '06381', '9920315', '山形県', 'ヤマガタケン', '東置賜郡高畠町', 'ヒガシオキタマグンタカハタマチ', '泉岡', 'イズミオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東置賜郡高畠町亀岡', '06', '06381', '9920321', '山形県', 'ヤマガタケン', '東置賜郡高畠町', 'ヒガシオキタマグンタカハタマチ', '亀岡', 'カメオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東置賜郡高畠町中島', '06', '06381', '9920322', '山形県', 'ヤマガタケン', '東置賜郡高畠町', 'ヒガシオキタマグンタカハタマチ', '中島', 'ナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東置賜郡高畠町露藤', '06', '06381', '9920323', '山形県', 'ヤマガタケン', '東置賜郡高畠町', 'ヒガシオキタマグンタカハタマチ', '露藤', 'ツユフジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東置賜郡高畠町入生田', '06', '06381', '9920324', '山形県', 'ヤマガタケン', '東置賜郡高畠町', 'ヒガシオキタマグンタカハタマチ', '入生田', 'イリュウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東置賜郡高畠町船橋', '06', '06381', '9920325', '山形県', 'ヤマガタケン', '東置賜郡高畠町', 'ヒガシオキタマグンタカハタマチ', '船橋', 'フナバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東置賜郡高畠町三条目', '06', '06381', '9920331', '山形県', 'ヤマガタケン', '東置賜郡高畠町', 'ヒガシオキタマグンタカハタマチ', '三条目', 'サンジョノメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東置賜郡高畠町相森', '06', '06381', '9920332', '山形県', 'ヤマガタケン', '東置賜郡高畠町', 'ヒガシオキタマグンタカハタマチ', '相森', 'アイノモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東置賜郡高畠町柏木目', '06', '06381', '9920333', '山形県', 'ヤマガタケン', '東置賜郡高畠町', 'ヒガシオキタマグンタカハタマチ', '柏木目', 'カシワギメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東置賜郡高畠町一本柳', '06', '06381', '9920334', '山形県', 'ヤマガタケン', '東置賜郡高畠町', 'ヒガシオキタマグンタカハタマチ', '一本柳', 'イッポンヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東置賜郡高畠町川沼', '06', '06381', '9920335', '山形県', 'ヤマガタケン', '東置賜郡高畠町', 'ヒガシオキタマグンタカハタマチ', '川沼', 'カワヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東置賜郡高畠町時沢', '06', '06381', '9920341', '山形県', 'ヤマガタケン', '東置賜郡高畠町', 'ヒガシオキタマグンタカハタマチ', '時沢', 'トキザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東置賜郡高畠町竹森', '06', '06381', '9920342', '山形県', 'ヤマガタケン', '東置賜郡高畠町', 'ヒガシオキタマグンタカハタマチ', '竹森', 'タケノモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東置賜郡高畠町根岸', '06', '06381', '9920343', '山形県', 'ヤマガタケン', '東置賜郡高畠町', 'ヒガシオキタマグンタカハタマチ', '根岸', 'ネギシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東置賜郡高畠町深沼', '06', '06381', '9920344', '山形県', 'ヤマガタケン', '東置賜郡高畠町', 'ヒガシオキタマグンタカハタマチ', '深沼', 'フカヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144866', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東置賜郡高畠町高畠', '06', '06381', '9920351', '山形県', 'ヤマガタケン', '東置賜郡高畠町', 'ヒガシオキタマグンタカハタマチ', '高畠', 'タカハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東置賜郡高畠町中里', '06', '06381', '9920352', '山形県', 'ヤマガタケン', '東置賜郡高畠町', 'ヒガシオキタマグンタカハタマチ', '中里', 'ナカザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県南陽市金山', '06', '06213', '9920471', '山形県', 'ヤマガタケン', '南陽市', 'ナンヨウシ', '金山', 'カネヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県南陽市宮内', '06', '06213', '9920472', '山形県', 'ヤマガタケン', '南陽市', 'ナンヨウシ', '宮内', 'ミヤウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県南陽市池黒', '06', '06213', '9920473', '山形県', 'ヤマガタケン', '南陽市', 'ナンヨウシ', '池黒', 'イケグロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県南陽市漆山', '06', '06213', '9920474', '山形県', 'ヤマガタケン', '南陽市', 'ナンヨウシ', '漆山', 'ウルシヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県南陽市羽付', '06', '06213', '9920475', '山形県', 'ヤマガタケン', '南陽市', 'ナンヨウシ', '羽付', 'ハネツキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県南陽市砂塚', '06', '06213', '9920476', '山形県', 'ヤマガタケン', '南陽市', 'ナンヨウシ', '砂塚', 'スナヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県南陽市梨郷', '06', '06213', '9920477', '山形県', 'ヤマガタケン', '南陽市', 'ナンヨウシ', '梨郷', 'リンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県南陽市竹原', '06', '06213', '9920478', '山形県', 'ヤマガタケン', '南陽市', 'ナンヨウシ', '竹原', 'タケハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県南陽市和田', '06', '06213', '9920479', '山形県', 'ヤマガタケン', '南陽市', 'ナンヨウシ', '和田', 'ワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県南陽市小滝', '06', '06213', '9920581', '山形県', 'ヤマガタケン', '南陽市', 'ナンヨウシ', '小滝', 'コタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県南陽市荻', '06', '06213', '9920582', '山形県', 'ヤマガタケン', '南陽市', 'ナンヨウシ', '荻', 'オギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県南陽市下荻', '06', '06213', '9920583', '山形県', 'ヤマガタケン', '南陽市', 'ナンヨウシ', '下荻', 'シモオギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県南陽市太郎', '06', '06213', '9920584', '山形県', 'ヤマガタケン', '南陽市', 'ナンヨウシ', '太郎', 'タロウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東置賜郡川西町西大塚', '06', '06382', '9920601', '山形県', 'ヤマガタケン', '東置賜郡川西町', 'ヒガシオキタマグンカワニシマチ', '西大塚', 'ニシオオツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東置賜郡川西町大塚', '06', '06382', '9920602', '山形県', 'ヤマガタケン', '東置賜郡川西町', 'ヒガシオキタマグンカワニシマチ', '大塚', 'オオツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東置賜郡川西町東大塚', '06', '06382', '9920603', '山形県', 'ヤマガタケン', '東置賜郡川西町', 'ヒガシオキタマグンカワニシマチ', '東大塚', 'ヒガシオオツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡白鷹町鮎貝', '06', '06402', '9920771', '山形県', 'ヤマガタケン', '西置賜郡白鷹町', 'ニシオキタマグンシラタカマチ', '鮎貝', 'アユカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡白鷹町横田尻', '06', '06402', '9920772', '山形県', 'ヤマガタケン', '西置賜郡白鷹町', 'ニシオキタマグンシラタカマチ', '横田尻', 'ヨコタジリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡白鷹町高玉', '06', '06402', '9920773', '山形県', 'ヤマガタケン', '西置賜郡白鷹町', 'ニシオキタマグンシラタカマチ', '高玉', 'タカダマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡白鷹町山口', '06', '06402', '9920774', '山形県', 'ヤマガタケン', '西置賜郡白鷹町', 'ニシオキタマグンシラタカマチ', '山口', 'ヤマグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡白鷹町黒鴨', '06', '06402', '9920775', '山形県', 'ヤマガタケン', '西置賜郡白鷹町', 'ニシオキタマグンシラタカマチ', '黒鴨', 'クロガモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡白鷹町深山', '06', '06402', '9920776', '山形県', 'ヤマガタケン', '西置賜郡白鷹町', 'ニシオキタマグンシラタカマチ', '深山', 'ミヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡白鷹町栃窪', '06', '06402', '9920777', '山形県', 'ヤマガタケン', '西置賜郡白鷹町', 'ニシオキタマグンシラタカマチ', '栃窪', 'トチクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡白鷹町高岡', '06', '06402', '9920778', '山形県', 'ヤマガタケン', '西置賜郡白鷹町', 'ニシオキタマグンシラタカマチ', '高岡', 'タカオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡白鷹町箕和田', '06', '06402', '9920779', '山形県', 'ヤマガタケン', '西置賜郡白鷹町', 'ニシオキタマグンシラタカマチ', '箕和田', 'ミノワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡白鷹町', '06', '06402', '9920800', '山形県', 'ヤマガタケン', '西置賜郡白鷹町', 'ニシオキタマグンシラタカマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('144897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡白鷹町針生', '06', '06402', '9920801', '山形県', 'ヤマガタケン', '西置賜郡白鷹町', 'ニシオキタマグンシラタカマチ', '針生', 'ハリュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡白鷹町中山', '06', '06402', '9920802', '山形県', 'ヤマガタケン', '西置賜郡白鷹町', 'ニシオキタマグンシラタカマチ', '中山', 'ナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡白鷹町萩野', '06', '06402', '9920811', '山形県', 'ヤマガタケン', '西置賜郡白鷹町', 'ニシオキタマグンシラタカマチ', '萩野', 'ハギノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡白鷹町滝野', '06', '06402', '9920812', '山形県', 'ヤマガタケン', '西置賜郡白鷹町', 'ニシオキタマグンシラタカマチ', '滝野', 'タキノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡白鷹町十王', '06', '06402', '9920821', '山形県', 'ヤマガタケン', '西置賜郡白鷹町', 'ニシオキタマグンシラタカマチ', '十王', 'ジュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡白鷹町荒砥甲', '06', '06402', '9920831', '山形県', 'ヤマガタケン', '西置賜郡白鷹町', 'ニシオキタマグンシラタカマチ', '荒砥甲', 'アラトコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡白鷹町荒砥乙', '06', '06402', '9920832', '山形県', 'ヤマガタケン', '西置賜郡白鷹町', 'ニシオキタマグンシラタカマチ', '荒砥乙', 'アラトオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡白鷹町畔藤', '06', '06402', '9920841', '山形県', 'ヤマガタケン', '西置賜郡白鷹町', 'ニシオキタマグンシラタカマチ', '畔藤', 'クロフジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡白鷹町広野', '06', '06402', '9920851', '山形県', 'ヤマガタケン', '西置賜郡白鷹町', 'ニシオキタマグンシラタカマチ', '広野', 'ヒロノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡白鷹町浅立', '06', '06402', '9920852', '山形県', 'ヤマガタケン', '西置賜郡白鷹町', 'ニシオキタマグンシラタカマチ', '浅立', 'アサダチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡白鷹町大瀬', '06', '06402', '9920861', '山形県', 'ヤマガタケン', '西置賜郡白鷹町', 'ニシオキタマグンシラタカマチ', '大瀬', 'オオセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡白鷹町下山', '06', '06402', '9920862', '山形県', 'ヤマガタケン', '西置賜郡白鷹町', 'ニシオキタマグンシラタカマチ', '下山', 'シモヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡白鷹町菖蒲', '06', '06402', '9920863', '山形県', 'ヤマガタケン', '西置賜郡白鷹町', 'ニシオキタマグンシラタカマチ', '菖蒲', 'ショウブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡白鷹町佐野原', '06', '06402', '9920864', '山形県', 'ヤマガタケン', '西置賜郡白鷹町', 'ニシオキタマグンシラタカマチ', '佐野原', 'サノハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市端野町一区', '01', '01208', '0992101', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '端野町一区', 'タンノチョウ01ク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市端野町二区', '01', '01208', '0992102', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '端野町二区', 'タンノチョウ02ク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市端野町三区', '01', '01208', '0992103', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '端野町三区', 'タンノチョウ03ク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市端野町端野', '01', '01208', '0992104', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '端野町端野', 'タンノチョウタンノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市端野町忠志', '01', '01208', '0992105', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '端野町忠志', 'タンノチョウチュウシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市端野町協和', '01', '01208', '0992106', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '端野町協和', 'タンノチョウキョウワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市端野町川向', '01', '01208', '0992107', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '端野町川向', 'タンノチョウカワムカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市端野町北登', '01', '01208', '0992111', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '端野町北登', 'タンノチョウホクト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市端野町豊実', '01', '01208', '0992112', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '端野町豊実', 'タンノチョウトヨミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市万世町刈安', '06', '06202', '9921121', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '万世町刈安', 'バンセイチョウカリヤス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市万世町梓山', '06', '06202', '9921122', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '万世町梓山', 'バンセイチョウズサヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市万世町桑山', '06', '06202', '9921123', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '万世町桑山', 'バンセイチョウクワヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市万世町金谷', '06', '06202', '9921124', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '万世町金谷', 'バンセイチョウカナヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市万世町片子', '06', '06202', '9921125', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '万世町片子', 'バンセイチョウカタコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市万世町堂森', '06', '06202', '9921126', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '万世町堂森', 'バンセイチョウドウモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市万世町牛森', '06', '06202', '9921127', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '万世町牛森', 'バンセイチョウウシモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市八幡原', '06', '06202', '9921128', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '八幡原', 'ハチマンパラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市万世町立沢', '06', '06202', '9921201', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '万世町立沢', 'バンセイチョウタツザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市三沢', '06', '06202', '9921202', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '三沢', 'ミサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市大沢大沢', '06', '06202', '9921203', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '大沢', 'オオサワ', null, null, '大沢', 'オオサワ');
INSERT INTO `ms_addresses` VALUES ('144932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市大沢笠松', '06', '06202', '9921203', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '大沢', 'オオサワ', null, null, '笠松', 'カサマツ');
INSERT INTO `ms_addresses` VALUES ('144933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市大小屋', '06', '06202', '9921204', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '大小屋', 'オオゴヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市関根', '06', '06202', '9921205', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '関根', 'セキネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市赤崩', '06', '06202', '9921206', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '赤崩', 'アカクズレ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市大沢', '06', '06202', '9921303', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '大沢', 'オオサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市板谷', '06', '06202', '9921331', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '板谷', 'イタヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市赤崩山王浦', '06', '06202', '9921406', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '赤崩', 'アカクズレ', null, null, '山王浦', 'サンノウウラ');
INSERT INTO `ms_addresses` VALUES ('144939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市笹野町', '06', '06202', '9921441', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '笹野町', 'ササノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市芳泉町', '06', '06202', '9921442', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '芳泉町', 'ホウセンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市笹野', '06', '06202', '9921443', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '笹野', 'ササノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市諸仏町', '06', '06202', '9921444', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '諸仏町', 'ショブツマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市笹野本町', '06', '06202', '9921445', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '笹野本町', 'ササノホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市直江石堤', '06', '06202', '9921446', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '直江石堤', 'ナオエセキテイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市南原笹野町', '06', '06202', '9921451', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '南原笹野町', 'ミナミハラササノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市南原横堀町', '06', '06202', '9921452', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '南原横堀町', 'ミナミハラヨコボリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市南原石垣町', '06', '06202', '9921453', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '南原石垣町', 'ミナミハライシガキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市南原新町', '06', '06202', '9921454', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '南原新町', 'ミナミハラシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市南原猪苗代町', '06', '06202', '9921455', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '南原猪苗代町', 'ミナミハライナワシロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市李山', '06', '06202', '9921461', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '李山', 'スモモヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市大平', '06', '06202', '9921462', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '大平', 'オオダイラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市立石', '06', '06202', '9921471', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '立石', 'タテイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市関', '06', '06202', '9921472', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '関', 'セキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市関町', '06', '06202', '9921473', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '関町', 'セキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市綱木', '06', '06202', '9921474', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '綱木', 'ツナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市口田沢', '06', '06202', '9921581', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '口田沢', 'クチタザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市神原', '06', '06202', '9921582', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '神原', 'カンバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県米沢市入田沢', '06', '06202', '9921583', '山形県', 'ヤマガタケン', '米沢市', 'ヨネザワシ', '入田沢', 'イリタザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道北見市端野町緋牛内', '01', '01208', '0992231', '北海道', 'ホッカイドウ', '北見市', 'キタミシ', '端野町緋牛内', 'タンノチョウヒウシナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡大空町', '01', '01564', '0992300', '北海道', 'ホッカイドウ', '網走郡大空町', 'アバシリグンオオゾラチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('144967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡大空町女満別本郷', '01', '01564', '0992301', '北海道', 'ホッカイドウ', '網走郡大空町', 'アバシリグンオオゾラチョウ', '女満別本郷', 'メマンベツホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡大空町女満別住吉', '01', '01564', '0992302', '北海道', 'ホッカイドウ', '網走郡大空町', 'アバシリグンオオゾラチョウ', '女満別住吉', 'メマンベツスミヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡大空町女満別豊里', '01', '01564', '0992303', '北海道', 'ホッカイドウ', '網走郡大空町', 'アバシリグンオオゾラチョウ', '女満別豊里', 'メマンベツトヨサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡大空町女満別公園', '01', '01564', '0992304', '北海道', 'ホッカイドウ', '網走郡大空町', 'アバシリグンオオゾラチョウ', '女満別公園', 'メマンベツコウエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡大空町女満別東陽', '01', '01564', '0992305', '北海道', 'ホッカイドウ', '網走郡大空町', 'アバシリグンオオゾラチョウ', '女満別東陽', 'メマンベツトウヨウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡大空町女満別湖畔', '01', '01564', '0992306', '北海道', 'ホッカイドウ', '網走郡大空町', 'アバシリグンオオゾラチョウ', '女満別湖畔', 'メマンベツコハン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡大空町女満別本通', '01', '01564', '0992310', '北海道', 'ホッカイドウ', '網走郡大空町', 'アバシリグンオオゾラチョウ', '女満別本通', 'メマンベツホンドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡大空町女満別東1条', '01', '01564', '0992311', '北海道', 'ホッカイドウ', '網走郡大空町', 'アバシリグンオオゾラチョウ', '女満別東1条', 'メマンベツヒガシ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡大空町女満別東2条', '01', '01564', '0992312', '北海道', 'ホッカイドウ', '網走郡大空町', 'アバシリグンオオゾラチョウ', '女満別東2条', 'メマンベツヒガシ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡大空町女満別西1条', '01', '01564', '0992321', '北海道', 'ホッカイドウ', '網走郡大空町', 'アバシリグンオオゾラチョウ', '女満別西1条', 'メマンベツニシ01ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡大空町女満別西2条', '01', '01564', '0992322', '北海道', 'ホッカイドウ', '網走郡大空町', 'アバシリグンオオゾラチョウ', '女満別西2条', 'メマンベツニシ02ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡大空町女満別西3条', '01', '01564', '0992323', '北海道', 'ホッカイドウ', '網走郡大空町', 'アバシリグンオオゾラチョウ', '女満別西3条', 'メマンベツニシ03ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡大空町女満別西4条', '01', '01564', '0992324', '北海道', 'ホッカイドウ', '網走郡大空町', 'アバシリグンオオゾラチョウ', '女満別西4条', 'メマンベツニシ04ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡大空町女満別西5条', '01', '01564', '0992325', '北海道', 'ホッカイドウ', '網走郡大空町', 'アバシリグンオオゾラチョウ', '女満別西5条', 'メマンベツニシ05ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡大空町女満別西6条', '01', '01564', '0992326', '北海道', 'ホッカイドウ', '網走郡大空町', 'アバシリグンオオゾラチョウ', '女満別西6条', 'メマンベツニシ06ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡大空町女満別西7条', '01', '01564', '0992327', '北海道', 'ホッカイドウ', '網走郡大空町', 'アバシリグンオオゾラチョウ', '女満別西7条', 'メマンベツニシ07ジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡大空町女満別公園通', '01', '01564', '0992351', '北海道', 'ホッカイドウ', '網走郡大空町', 'アバシリグンオオゾラチョウ', '女満別公園通', 'メマンベツコウエンドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡大空町女満別眺湖台', '01', '01564', '0992354', '北海道', 'ホッカイドウ', '網走郡大空町', 'アバシリグンオオゾラチョウ', '女満別眺湖台', 'メマンベツチョウコダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡大空町女満別夕陽台', '01', '01564', '0992355', '北海道', 'ホッカイドウ', '網走郡大空町', 'アバシリグンオオゾラチョウ', '女満別夕陽台', 'メマンベツユウヒダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡大空町女満別昭和', '01', '01564', '0992356', '北海道', 'ホッカイドウ', '網走郡大空町', 'アバシリグンオオゾラチョウ', '女満別昭和', 'メマンベツショウワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡大空町女満別湖南', '01', '01564', '0992361', '北海道', 'ホッカイドウ', '網走郡大空町', 'アバシリグンオオゾラチョウ', '女満別湖南', 'メマンベツコナン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡大空町女満別朝日', '01', '01564', '0992362', '北海道', 'ホッカイドウ', '網走郡大空町', 'アバシリグンオオゾラチョウ', '女満別朝日', 'メマンベツアサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡大空町女満別中央', '01', '01564', '0992371', '北海道', 'ホッカイドウ', '網走郡大空町', 'アバシリグンオオゾラチョウ', '女満別中央', 'メマンベツチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡大空町女満別大東', '01', '01564', '0992372', '北海道', 'ホッカイドウ', '網走郡大空町', 'アバシリグンオオゾラチョウ', '女満別大東', 'メマンベツダイトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144991', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡大空町女満別巴沢', '01', '01564', '0992373', '北海道', 'ホッカイドウ', '網走郡大空町', 'アバシリグンオオゾラチョウ', '女満別巴沢', 'メマンベツトモエザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144992', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡大空町女満別大成', '01', '01564', '0992381', '北海道', 'ホッカイドウ', '網走郡大空町', 'アバシリグンオオゾラチョウ', '女満別大成', 'メマンベツタイセイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡大空町女満別開陽', '01', '01564', '0992382', '北海道', 'ホッカイドウ', '網走郡大空町', 'アバシリグンオオゾラチョウ', '女満別開陽', 'メマンベツカイヨウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡大空町女満別日進', '01', '01564', '0992383', '北海道', 'ホッカイドウ', '網走郡大空町', 'アバシリグンオオゾラチョウ', '女満別日進', 'メマンベツニッシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走市呼人', '01', '01211', '0992421', '北海道', 'ホッカイドウ', '網走市', 'アバシリシ', '呼人', 'ヨビト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走市八坂', '01', '01211', '0992422', '北海道', 'ホッカイドウ', '網走市', 'アバシリシ', '八坂', 'ヤサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走市東網走', '01', '01211', '0992423', '北海道', 'ホッカイドウ', '網走市', 'アバシリシ', '東網走', 'ヒガシアバシリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('144999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走市中園', '01', '01211', '0992424', '北海道', 'ホッカイドウ', '網走市', 'アバシリシ', '中園', 'ナカゾノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県長井市', '06', '06209', '9930000', '山形県', 'ヤマガタケン', '長井市', 'ナガイシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('145018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県長井市ままの上', '06', '06209', '9930001', '山形県', 'ヤマガタケン', '長井市', 'ナガイシ', 'ままの上', 'ママノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県長井市屋城町', '06', '06209', '9930002', '山形県', 'ヤマガタケン', '長井市', 'ナガイシ', '屋城町', 'ヤシロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県長井市東町', '06', '06209', '9930003', '山形県', 'ヤマガタケン', '長井市', 'ナガイシ', '東町', 'ヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県長井市神明町', '06', '06209', '9930004', '山形県', 'ヤマガタケン', '長井市', 'ナガイシ', '神明町', 'シンメイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県長井市片田町', '06', '06209', '9930005', '山形県', 'ヤマガタケン', '長井市', 'ナガイシ', '片田町', 'カタタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県長井市あら町', '06', '06209', '9930006', '山形県', 'ヤマガタケン', '長井市', 'ナガイシ', 'あら町', 'アラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県長井市本町', '06', '06209', '9930007', '山形県', 'ヤマガタケン', '長井市', 'ナガイシ', '本町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県長井市館町北', '06', '06209', '9930011', '山形県', 'ヤマガタケン', '長井市', 'ナガイシ', '館町北', 'タテマチキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県長井市日の出町', '06', '06209', '9930012', '山形県', 'ヤマガタケン', '長井市', 'ナガイシ', '日の出町', 'ヒノデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県長井市館町南', '06', '06209', '9930013', '山形県', 'ヤマガタケン', '長井市', 'ナガイシ', '館町南', 'タテマチミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県長井市小出', '06', '06209', '9930014', '山形県', 'ヤマガタケン', '長井市', 'ナガイシ', '小出', 'コイデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県長井市四ツ谷', '06', '06209', '9930015', '山形県', 'ヤマガタケン', '長井市', 'ナガイシ', '四ツ谷', 'ヨツヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県長井市台町', '06', '06209', '9930016', '山形県', 'ヤマガタケン', '長井市', 'ナガイシ', '台町', 'ダイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県長井市花作町', '06', '06209', '9930017', '山形県', 'ヤマガタケン', '長井市', 'ナガイシ', '花作町', 'ハナヅクリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県長井市上伊佐沢', '06', '06209', '9930021', '山形県', 'ヤマガタケン', '長井市', 'ナガイシ', '上伊佐沢', 'カミイサザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県長井市芦沢', '06', '06209', '9930022', '山形県', 'ヤマガタケン', '長井市', 'ナガイシ', '芦沢', 'アシザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県長井市下伊佐沢', '06', '06209', '9930023', '山形県', 'ヤマガタケン', '長井市', 'ナガイシ', '下伊佐沢', 'シモイサザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県長井市中伊佐沢', '06', '06209', '9930024', '山形県', 'ヤマガタケン', '長井市', 'ナガイシ', '中伊佐沢', 'ナカイサザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県長井市泉', '06', '06209', '9930031', '山形県', 'ヤマガタケン', '長井市', 'ナガイシ', '泉', 'イズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県長井市河井', '06', '06209', '9930032', '山形県', 'ヤマガタケン', '長井市', 'ナガイシ', '河井', 'カワイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県長井市今泉', '06', '06209', '9930033', '山形県', 'ヤマガタケン', '長井市', 'ナガイシ', '今泉', 'イマイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145039', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県長井市歌丸', '06', '06209', '9930034', '山形県', 'ヤマガタケン', '長井市', 'ナガイシ', '歌丸', 'ウタマル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145040', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県長井市時庭', '06', '06209', '9930035', '山形県', 'ヤマガタケン', '長井市', 'ナガイシ', '時庭', 'トキニワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県長井市九野本', '06', '06209', '9930041', '山形県', 'ヤマガタケン', '長井市', 'ナガイシ', '九野本', 'クノモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県長井市平山', '06', '06209', '9930042', '山形県', 'ヤマガタケン', '長井市', 'ナガイシ', '平山', 'ヒラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県長井市幸町', '06', '06209', '9930051', '山形県', 'ヤマガタケン', '長井市', 'ナガイシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県長井市新町', '06', '06209', '9930052', '山形県', 'ヤマガタケン', '長井市', 'ナガイシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県長井市中道', '06', '06209', '9930053', '山形県', 'ヤマガタケン', '長井市', 'ナガイシ', '中道', 'ナカミチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県長井市清水町', '06', '06209', '9930054', '山形県', 'ヤマガタケン', '長井市', 'ナガイシ', '清水町', 'シミズチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県長井市寺泉', '06', '06209', '9930061', '山形県', 'ヤマガタケン', '長井市', 'ナガイシ', '寺泉', 'テライズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県長井市川原沢', '06', '06209', '9930062', '山形県', 'ヤマガタケン', '長井市', 'ナガイシ', '川原沢', 'カワラザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県長井市草岡', '06', '06209', '9930063', '山形県', 'ヤマガタケン', '長井市', 'ナガイシ', '草岡', 'クサオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県長井市勧進代', '06', '06209', '9930064', '山形県', 'ヤマガタケン', '長井市', 'ナガイシ', '勧進代', 'カンジンダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県長井市白兎', '06', '06209', '9930071', '山形県', 'ヤマガタケン', '長井市', 'ナガイシ', '白兎', 'シロウサギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県長井市五十川', '06', '06209', '9930072', '山形県', 'ヤマガタケン', '長井市', 'ナガイシ', '五十川', 'イカガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県長井市森', '06', '06209', '9930073', '山形県', 'ヤマガタケン', '長井市', 'ナガイシ', '森', 'モリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県長井市宮', '06', '06209', '9930074', '山形県', 'ヤマガタケン', '長井市', 'ナガイシ', '宮', 'ミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県長井市成田', '06', '06209', '9930075', '山形県', 'ヤマガタケン', '長井市', 'ナガイシ', '成田', 'ナリタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県長井市緑町', '06', '06209', '9930081', '山形県', 'ヤマガタケン', '長井市', 'ナガイシ', '緑町', 'ミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県長井市舟場', '06', '06209', '9930082', '山形県', 'ヤマガタケン', '長井市', 'ナガイシ', '舟場', 'フナバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県長井市大町', '06', '06209', '9930083', '山形県', 'ヤマガタケン', '長井市', 'ナガイシ', '大町', 'オオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県長井市栄町', '06', '06209', '9930084', '山形県', 'ヤマガタケン', '長井市', 'ナガイシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県長井市高野町', '06', '06209', '9930085', '山形県', 'ヤマガタケン', '長井市', 'ナガイシ', '高野町', 'コウヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県長井市十日町', '06', '06209', '9930086', '山形県', 'ヤマガタケン', '長井市', 'ナガイシ', '十日町', 'トオカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県長井市横町', '06', '06209', '9930087', '山形県', 'ヤマガタケン', '長井市', 'ナガイシ', '横町', 'ヨコマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走市藻琴', '01', '01211', '0993111', '北海道', 'ホッカイドウ', '網走市', 'アバシリシ', '藻琴', 'モコト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走市北浜', '01', '01211', '0993112', '北海道', 'ホッカイドウ', '網走市', 'アバシリシ', '北浜', 'キタハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走市実豊', '01', '01211', '0993113', '北海道', 'ホッカイドウ', '網走市', 'アバシリシ', '実豊', 'ミトヨ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走市丸万', '01', '01211', '0993114', '北海道', 'ホッカイドウ', '網走市', 'アバシリシ', '丸万', 'マルマン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走市稲富', '01', '01211', '0993115', '北海道', 'ホッカイドウ', '網走市', 'アバシリシ', '稲富', 'イナトミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走市山里', '01', '01211', '0993116', '北海道', 'ホッカイドウ', '網走市', 'アバシリシ', '山里', 'ヤマサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走市昭和', '01', '01211', '0993117', '北海道', 'ホッカイドウ', '網走市', 'アバシリシ', '昭和', 'ショウワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走市豊郷', '01', '01211', '0993118', '北海道', 'ホッカイドウ', '網走市', 'アバシリシ', '豊郷', 'トヨサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145071', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走市鱒浦', '01', '01211', '0993119', '北海道', 'ホッカイドウ', '網走市', 'アバシリシ', '鱒浦', 'マスウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡大空町東藻琴西区', '01', '01564', '0993201', '北海道', 'ホッカイドウ', '網走郡大空町', 'アバシリグンオオゾラチョウ', '東藻琴', 'ヒガシモコト', null, null, '西区', 'ニシク');
INSERT INTO `ms_addresses` VALUES ('145073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡大空町東藻琴西倉', '01', '01564', '0993202', '北海道', 'ホッカイドウ', '網走郡大空町', 'アバシリグンオオゾラチョウ', '東藻琴西倉', 'ヒガシモコトニシクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡大空町東藻琴北1区', '01', '01564', '0993211', '北海道', 'ホッカイドウ', '網走郡大空町', 'アバシリグンオオゾラチョウ', '東藻琴', 'ヒガシモコト', null, null, '北1区', 'キタ01ク');
INSERT INTO `ms_addresses` VALUES ('145075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡大空町東藻琴北2区', '01', '01564', '0993212', '北海道', 'ホッカイドウ', '網走郡大空町', 'アバシリグンオオゾラチョウ', '東藻琴', 'ヒガシモコト', null, null, '北2区', 'キタ02ク');
INSERT INTO `ms_addresses` VALUES ('145076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡大空町東藻琴中央区', '01', '01564', '0993213', '北海道', 'ホッカイドウ', '網走郡大空町', 'アバシリグンオオゾラチョウ', '東藻琴', 'ヒガシモコト', null, null, '中央区', 'チュウオウク');
INSERT INTO `ms_addresses` VALUES ('145077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡大空町東藻琴南区', '01', '01564', '0993214', '北海道', 'ホッカイドウ', '網走郡大空町', 'アバシリグンオオゾラチョウ', '東藻琴', 'ヒガシモコト', null, null, '南区', 'ミナミク');
INSERT INTO `ms_addresses` VALUES ('145078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡大空町東藻琴大進', '01', '01564', '0993221', '北海道', 'ホッカイドウ', '網走郡大空町', 'アバシリグンオオゾラチョウ', '東藻琴大進', 'ヒガシモコトタイシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡大空町東藻琴新富', '01', '01564', '0993222', '北海道', 'ホッカイドウ', '網走郡大空町', 'アバシリグンオオゾラチョウ', '東藻琴新富', 'ヒガシモコトシントミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡大空町東藻琴東区', '01', '01564', '0993223', '北海道', 'ホッカイドウ', '網走郡大空町', 'アバシリグンオオゾラチョウ', '東藻琴', 'ヒガシモコト', null, null, '東区', 'ヒガシク');
INSERT INTO `ms_addresses` VALUES ('145081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡大空町東藻琴明生', '01', '01564', '0993224', '北海道', 'ホッカイドウ', '網走郡大空町', 'アバシリグンオオゾラチョウ', '東藻琴明生', 'ヒガシモコトメイセイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡大空町東藻琴旭台', '01', '01564', '0993225', '北海道', 'ホッカイドウ', '網走郡大空町', 'アバシリグンオオゾラチョウ', '東藻琴', 'ヒガシモコト', null, null, '旭台', 'アサヒダイ');
INSERT INTO `ms_addresses` VALUES ('145083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡大空町東藻琴千草', '01', '01564', '0993231', '北海道', 'ホッカイドウ', '網走郡大空町', 'アバシリグンオオゾラチョウ', '東藻琴千草', 'ヒガシモコトチクサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡大空町東藻琴末広', '01', '01564', '0993232', '北海道', 'ホッカイドウ', '網走郡大空町', 'アバシリグンオオゾラチョウ', '東藻琴末広', 'ヒガシモコトスエヒロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡大空町東藻琴上東', '01', '01564', '0993233', '北海道', 'ホッカイドウ', '網走郡大空町', 'アバシリグンオオゾラチョウ', '東藻琴', 'ヒガシモコト', null, null, '上東', 'カミヒガシ');
INSERT INTO `ms_addresses` VALUES ('145086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡大空町東藻琴福富', '01', '01564', '0993234', '北海道', 'ホッカイドウ', '網走郡大空町', 'アバシリグンオオゾラチョウ', '東藻琴福富', 'ヒガシモコトフクトミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡大空町東藻琴山園', '01', '01564', '0993243', '北海道', 'ホッカイドウ', '網走郡大空町', 'アバシリグンオオゾラチョウ', '東藻琴山園', 'ヒガシモコトヤマゾノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走郡大空町東藻琴', '01', '01564', '0993244', '北海道', 'ホッカイドウ', '網走郡大空町', 'アバシリグンオオゾラチョウ', '東藻琴', 'ヒガシモコト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道斜里郡小清水町倉栄', '01', '01547', '0993451', '北海道', 'ホッカイドウ', '斜里郡小清水町', 'シャリグンコシミズチョウ', '倉栄', 'ソウエイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道斜里郡小清水町浜小清水', '01', '01547', '0993452', '北海道', 'ホッカイドウ', '斜里郡小清水町', 'シャリグンコシミズチョウ', '浜小清水', 'ハマコシミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道斜里郡小清水町北斗', '01', '01547', '0993453', '北海道', 'ホッカイドウ', '斜里郡小清水町', 'シャリグンコシミズチョウ', '北斗', 'ホクト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道斜里郡小清水町止別', '01', '01547', '0993454', '北海道', 'ホッカイドウ', '斜里郡小清水町', 'シャリグンコシミズチョウ', '止別', 'ヤンベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走市音根内', '01', '01211', '0993501', '北海道', 'ホッカイドウ', '網走市', 'アバシリシ', '音根内', 'オンネナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走市浦士別', '01', '01211', '0993502', '北海道', 'ホッカイドウ', '網走市', 'アバシリシ', '浦士別', 'ウラシベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走市栄', '01', '01211', '0993503', '北海道', 'ホッカイドウ', '網走市', 'アバシリシ', '栄', 'サカエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道網走市清浦', '01', '01211', '0993504', '北海道', 'ホッカイドウ', '網走市', 'アバシリシ', '清浦', 'キヨウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道斜里郡小清水町', '01', '01547', '0993600', '北海道', 'ホッカイドウ', '斜里郡小清水町', 'シャリグンコシミズチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('145100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道斜里郡小清水町萱野', '01', '01547', '0993601', '北海道', 'ホッカイドウ', '斜里郡小清水町', 'シャリグンコシミズチョウ', '萱野', 'カヤノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道斜里郡小清水町東野', '01', '01547', '0993602', '北海道', 'ホッカイドウ', '斜里郡小清水町', 'シャリグンコシミズチョウ', '東野', 'ヒガシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道斜里郡小清水町泉', '01', '01547', '0993603', '北海道', 'ホッカイドウ', '斜里郡小清水町', 'シャリグンコシミズチョウ', '泉', 'イズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道斜里郡小清水町水上', '01', '01547', '0993604', '北海道', 'ホッカイドウ', '斜里郡小清水町', 'シャリグンコシミズチョウ', '水上', 'ミズカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道斜里郡小清水町もこと山', '01', '01547', '0993605', '北海道', 'ホッカイドウ', '斜里郡小清水町', 'シャリグンコシミズチョウ', 'もこと山', 'モコトヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道斜里郡小清水町上徳', '01', '01547', '0993611', '北海道', 'ホッカイドウ', '斜里郡小清水町', 'シャリグンコシミズチョウ', '上徳', 'カミトク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道斜里郡小清水町共和', '01', '01547', '0993612', '北海道', 'ホッカイドウ', '斜里郡小清水町', 'シャリグンコシミズチョウ', '共和', 'キョウワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道斜里郡小清水町神浦', '01', '01547', '0993613', '北海道', 'ホッカイドウ', '斜里郡小清水町', 'シャリグンコシミズチョウ', '神浦', 'カミウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道斜里郡小清水町美和', '01', '01547', '0993614', '北海道', 'ホッカイドウ', '斜里郡小清水町', 'シャリグンコシミズチョウ', '美和', 'ミワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道斜里郡小清水町中里', '01', '01547', '0993615', '北海道', 'ホッカイドウ', '斜里郡小清水町', 'シャリグンコシミズチョウ', '中里', 'ナカサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道斜里郡小清水町旭', '01', '01547', '0993616', '北海道', 'ホッカイドウ', '斜里郡小清水町', 'シャリグンコシミズチョウ', '旭', 'アサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道斜里郡小清水町小清水1区桜ケ丘', '01', '01547', '0993621', '北海道', 'ホッカイドウ', '斜里郡小清水町', 'シャリグンコシミズチョウ', '小清水', 'コシミズ', null, null, '1区桜ケ丘', '01クサクラガオカ');
INSERT INTO `ms_addresses` VALUES ('145112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道斜里郡小清水町小清水1区', '01', '01547', '0993622', '北海道', 'ホッカイドウ', '斜里郡小清水町', 'シャリグンコシミズチョウ', '小清水', 'コシミズ', null, null, '1区', '01ク');
INSERT INTO `ms_addresses` VALUES ('145113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道斜里郡小清水町小清水2区', '01', '01547', '0993623', '北海道', 'ホッカイドウ', '斜里郡小清水町', 'シャリグンコシミズチョウ', '小清水', 'コシミズ', null, null, '2区', '02ク');
INSERT INTO `ms_addresses` VALUES ('145114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道斜里郡小清水町小清水3区', '01', '01547', '0993624', '北海道', 'ホッカイドウ', '斜里郡小清水町', 'シャリグンコシミズチョウ', '小清水', 'コシミズ', null, null, '3区', '03ク');
INSERT INTO `ms_addresses` VALUES ('145115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道斜里郡小清水町小清水4区', '01', '01547', '0993625', '北海道', 'ホッカイドウ', '斜里郡小清水町', 'シャリグンコシミズチョウ', '小清水', 'コシミズ', null, null, '4区', '04ク');
INSERT INTO `ms_addresses` VALUES ('145116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道斜里郡小清水町小清水5区', '01', '01547', '0993626', '北海道', 'ホッカイドウ', '斜里郡小清水町', 'シャリグンコシミズチョウ', '小清水', 'コシミズ', null, null, '5区', '05ク');
INSERT INTO `ms_addresses` VALUES ('145117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道斜里郡小清水町小清水6区', '01', '01547', '0993627', '北海道', 'ホッカイドウ', '斜里郡小清水町', 'シャリグンコシミズチョウ', '小清水', 'コシミズ', null, null, '6区', '06ク');
INSERT INTO `ms_addresses` VALUES ('145118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道斜里郡小清水町小清水7区', '01', '01547', '0993628', '北海道', 'ホッカイドウ', '斜里郡小清水町', 'シャリグンコシミズチョウ', '小清水', 'コシミズ', null, null, '7区', '07ク');
INSERT INTO `ms_addresses` VALUES ('145119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道斜里郡小清水町小清水7区川東', '01', '01547', '0993631', '北海道', 'ホッカイドウ', '斜里郡小清水町', 'シャリグンコシミズチョウ', '小清水', 'コシミズ', null, null, '7区川東', '07クカワヒガシ');
INSERT INTO `ms_addresses` VALUES ('145120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道斜里郡小清水町小清水8区北', '01', '01547', '0993632', '北海道', 'ホッカイドウ', '斜里郡小清水町', 'シャリグンコシミズチョウ', '小清水', 'コシミズ', null, null, '8区北', '08クキタ');
INSERT INTO `ms_addresses` VALUES ('145121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道斜里郡小清水町小清水8区南', '01', '01547', '0993633', '北海道', 'ホッカイドウ', '斜里郡小清水町', 'シャリグンコシミズチョウ', '小清水', 'コシミズ', null, null, '8区南', '08クミナミ');
INSERT INTO `ms_addresses` VALUES ('145122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道斜里郡小清水町小清水9区北', '01', '01547', '0993634', '北海道', 'ホッカイドウ', '斜里郡小清水町', 'シャリグンコシミズチョウ', '小清水', 'コシミズ', null, null, '9区北', '09クキタ');
INSERT INTO `ms_addresses` VALUES ('145123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道斜里郡小清水町小清水9区南', '01', '01547', '0993635', '北海道', 'ホッカイドウ', '斜里郡小清水町', 'シャリグンコシミズチョウ', '小清水', 'コシミズ', null, null, '9区南', '09クミナミ');
INSERT INTO `ms_addresses` VALUES ('145124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道斜里郡小清水町小清水10区', '01', '01547', '0993636', '北海道', 'ホッカイドウ', '斜里郡小清水町', 'シャリグンコシミズチョウ', '小清水', 'コシミズ', null, null, '10区', '10ク');
INSERT INTO `ms_addresses` VALUES ('145125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道斜里郡小清水町小清水11区', '01', '01547', '0993637', '北海道', 'ホッカイドウ', '斜里郡小清水町', 'シャリグンコシミズチョウ', '小清水', 'コシミズ', null, null, '11区', '11ク');
INSERT INTO `ms_addresses` VALUES ('145134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県天童市', '06', '06210', '9940000', '山形県', 'ヤマガタケン', '天童市', 'テンドウシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('145135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県天童市万代', '06', '06210', '9940001', '山形県', 'ヤマガタケン', '天童市', 'テンドウシ', '万代', 'バンダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県天童市乱川', '06', '06210', '9940002', '山形県', 'ヤマガタケン', '天童市', 'テンドウシ', '乱川', 'ミダレガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県天童市柏木町', '06', '06210', '9940003', '山形県', 'ヤマガタケン', '天童市', 'テンドウシ', '柏木町', 'カシワギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県天童市小関', '06', '06210', '9940004', '山形県', 'ヤマガタケン', '天童市', 'テンドウシ', '小関', 'コセキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県天童市高木', '06', '06210', '9940005', '山形県', 'ヤマガタケン', '天童市', 'テンドウシ', '高木', 'タカギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県天童市成生', '06', '06210', '9940006', '山形県', 'ヤマガタケン', '天童市', 'テンドウシ', '成生', 'ナリュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県天童市大清水', '06', '06210', '9940007', '山形県', 'ヤマガタケン', '天童市', 'テンドウシ', '大清水', 'オオシミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県天童市北久野本', '06', '06210', '9940011', '山形県', 'ヤマガタケン', '天童市', 'テンドウシ', '北久野本', 'キタクノモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県天童市久野本', '06', '06210', '9940012', '山形県', 'ヤマガタケン', '天童市', 'テンドウシ', '久野本', 'クノモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県天童市老野森', '06', '06210', '9940013', '山形県', 'ヤマガタケン', '天童市', 'テンドウシ', '老野森', 'オイノモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県天童市糠塚', '06', '06210', '9940014', '山形県', 'ヤマガタケン', '天童市', 'テンドウシ', '糠塚', 'ヌカヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県天童市泉町', '06', '06210', '9940015', '山形県', 'ヤマガタケン', '天童市', 'テンドウシ', '泉町', 'イズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県天童市山元', '06', '06210', '9940021', '山形県', 'ヤマガタケン', '天童市', 'テンドウシ', '山元', 'ヤマモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県天童市貫津', '06', '06210', '9940022', '山形県', 'ヤマガタケン', '天童市', 'テンドウシ', '貫津', 'ヌクヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県天童市東善寺', '06', '06210', '9940023', '山形県', 'ヤマガタケン', '天童市', 'テンドウシ', '東善寺', 'トウゼンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県天童市鎌田', '06', '06210', '9940024', '山形県', 'ヤマガタケン', '天童市', 'テンドウシ', '鎌田', 'カマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県天童市鎌田本町', '06', '06210', '9940025', '山形県', 'ヤマガタケン', '天童市', 'テンドウシ', '鎌田本町', 'カマタホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県天童市東本町', '06', '06210', '9940026', '山形県', 'ヤマガタケン', '天童市', 'テンドウシ', '東本町', 'ヒガシホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県天童市桜町', '06', '06210', '9940027', '山形県', 'ヤマガタケン', '天童市', 'テンドウシ', '桜町', 'サクラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県天童市天童中', '06', '06210', '9940031', '山形県', 'ヤマガタケン', '天童市', 'テンドウシ', '天童中', 'テンドウナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県天童市小路', '06', '06210', '9940032', '山形県', 'ヤマガタケン', '天童市', 'テンドウシ', '小路', 'コウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県天童市三日町', '06', '06210', '9940033', '山形県', 'ヤマガタケン', '天童市', 'テンドウシ', '三日町', 'ミッカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県天童市本町', '06', '06210', '9940034', '山形県', 'ヤマガタケン', '天童市', 'テンドウシ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県天童市五日町', '06', '06210', '9940041', '山形県', 'ヤマガタケン', '天童市', 'テンドウシ', '五日町', 'イツカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県天童市北目', '06', '06210', '9940042', '山形県', 'ヤマガタケン', '天童市', 'テンドウシ', '北目', 'キタメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県天童市松城町', '06', '06210', '9940043', '山形県', 'ヤマガタケン', '天童市', 'テンドウシ', '松城町', 'マツシロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県天童市一日町', '06', '06210', '9940044', '山形県', 'ヤマガタケン', '天童市', 'テンドウシ', '一日町', 'ヒトイチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145162', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県天童市仲町', '06', '06210', '9940045', '山形県', 'ヤマガタケン', '天童市', 'テンドウシ', '仲町', 'ナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145163', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県天童市田鶴町', '06', '06210', '9940046', '山形県', 'ヤマガタケン', '天童市', 'テンドウシ', '田鶴町', 'タヅルチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145164', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県天童市駅西', '06', '06210', '9940047', '山形県', 'ヤマガタケン', '天童市', 'テンドウシ', '駅西', 'エキニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145165', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県天童市交り江', '06', '06210', '9940048', '山形県', 'ヤマガタケン', '天童市', 'テンドウシ', '交り江', 'マジリエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県天童市南町', '06', '06210', '9940049', '山形県', 'ヤマガタケン', '天童市', 'テンドウシ', '南町', 'ミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県天童市奈良沢', '06', '06210', '9940051', '山形県', 'ヤマガタケン', '天童市', 'テンドウシ', '奈良沢', 'ナラザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県天童市下荻野戸', '06', '06210', '9940052', '山形県', 'ヤマガタケン', '天童市', 'テンドウシ', '下荻野戸', 'シモオギノト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県天童市上荻野戸', '06', '06210', '9940053', '山形県', 'ヤマガタケン', '天童市', 'テンドウシ', '上荻野戸', 'カミオギノト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県天童市荒谷', '06', '06210', '9940054', '山形県', 'ヤマガタケン', '天童市', 'テンドウシ', '荒谷', 'アラヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県天童市原町', '06', '06210', '9940055', '山形県', 'ヤマガタケン', '天童市', 'テンドウシ', '原町', 'ハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県天童市干布', '06', '06210', '9940056', '山形県', 'ヤマガタケン', '天童市', 'テンドウシ', '干布', 'ホシヌノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県天童市東芳賀', '06', '06210', '9940061', '山形県', 'ヤマガタケン', '天童市', 'テンドウシ', '東芳賀', 'ヒガシハガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県天童市長岡北', '06', '06210', '9940062', '山形県', 'ヤマガタケン', '天童市', 'テンドウシ', '長岡北', 'ナガオカキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県天童市東長岡', '06', '06210', '9940063', '山形県', 'ヤマガタケン', '天童市', 'テンドウシ', '東長岡', 'ヒガシナガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県天童市中里', '06', '06210', '9940064', '山形県', 'ヤマガタケン', '天童市', 'テンドウシ', '中里', 'ナカザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県天童市清池', '06', '06210', '9940065', '山形県', 'ヤマガタケン', '天童市', 'テンドウシ', '清池', 'ショウゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県天童市長岡', '06', '06210', '9940066', '山形県', 'ヤマガタケン', '天童市', 'テンドウシ', '長岡', 'ナガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県天童市芳賀', '06', '06210', '9940067', '山形県', 'ヤマガタケン', '天童市', 'テンドウシ', '芳賀', 'ハガ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県天童市高擶', '06', '06210', '9940068', '山形県', 'ヤマガタケン', '天童市', 'テンドウシ', '高擶', 'タカダマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県天童市清池東', '06', '06210', '9940069', '山形県', 'ヤマガタケン', '天童市', 'テンドウシ', '清池東', 'ショウゲヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県天童市矢野目', '06', '06210', '9940071', '山形県', 'ヤマガタケン', '天童市', 'テンドウシ', '矢野目', 'ヤノメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県天童市塚野目', '06', '06210', '9940072', '山形県', 'ヤマガタケン', '天童市', 'テンドウシ', '塚野目', 'ツカノメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県天童市寺津', '06', '06210', '9940073', '山形県', 'ヤマガタケン', '天童市', 'テンドウシ', '寺津', 'テラヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県天童市藤内新田', '06', '06210', '9940074', '山形県', 'ヤマガタケン', '天童市', 'テンドウシ', '藤内新田', 'トウナイシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県天童市蔵増', '06', '06210', '9940075', '山形県', 'ヤマガタケン', '天童市', 'テンドウシ', '蔵増', 'クラゾウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県天童市高野辺', '06', '06210', '9940076', '山形県', 'ヤマガタケン', '天童市', 'テンドウシ', '高野辺', 'タカノベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県天童市窪野目', '06', '06210', '9940077', '山形県', 'ヤマガタケン', '天童市', 'テンドウシ', '窪野目', 'クボノメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県天童市今町', '06', '06210', '9940078', '山形県', 'ヤマガタケン', '天童市', 'テンドウシ', '今町', 'イママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県天童市大町', '06', '06210', '9940079', '山形県', 'ヤマガタケン', '天童市', 'テンドウシ', '大町', 'オオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県天童市南小畑', '06', '06210', '9940081', '山形県', 'ヤマガタケン', '天童市', 'テンドウシ', '南小畑', 'ミナミオバタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県天童市山口', '06', '06210', '9940101', '山形県', 'ヤマガタケン', '天童市', 'テンドウシ', '山口', 'ヤマグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県天童市道満', '06', '06210', '9940102', '山形県', 'ヤマガタケン', '天童市', 'テンドウシ', '道満', 'ドウマン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県天童市川原子', '06', '06210', '9940103', '山形県', 'ヤマガタケン', '天童市', 'テンドウシ', '川原子', 'カワラゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県天童市田麦野', '06', '06210', '9940104', '山形県', 'ヤマガタケン', '天童市', 'テンドウシ', '田麦野', 'タムギノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道斜里郡斜里町', '01', '01545', '0994100', '北海道', 'ホッカイドウ', '斜里郡斜里町', 'シャリグンシャリチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('145197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道斜里郡斜里町前浜町', '01', '01545', '0994111', '北海道', 'ホッカイドウ', '斜里郡斜里町', 'シャリグンシャリチョウ', '前浜町', 'マエハママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道斜里郡斜里町港町', '01', '01545', '0994112', '北海道', 'ホッカイドウ', '斜里郡斜里町', 'シャリグンシャリチョウ', '港町', 'ミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道斜里郡斜里町本町', '01', '01545', '0994113', '北海道', 'ホッカイドウ', '斜里郡斜里町', 'シャリグンシャリチョウ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道斜里郡斜里町朝日町', '01', '01545', '0994114', '北海道', 'ホッカイドウ', '斜里郡斜里町', 'シャリグンシャリチョウ', '朝日町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道斜里郡斜里町光陽町', '01', '01545', '0994115', '北海道', 'ホッカイドウ', '斜里郡斜里町', 'シャリグンシャリチョウ', '光陽町', 'コウヨウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道斜里郡斜里町文光町', '01', '01545', '0994116', '北海道', 'ホッカイドウ', '斜里郡斜里町', 'シャリグンシャリチョウ', '文光町', 'ブンコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道斜里郡斜里町青葉町', '01', '01545', '0994117', '北海道', 'ホッカイドウ', '斜里郡斜里町', 'シャリグンシャリチョウ', '青葉町', 'アオバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道斜里郡斜里町新光町', '01', '01545', '0994118', '北海道', 'ホッカイドウ', '斜里郡斜里町', 'シャリグンシャリチョウ', '新光町', 'シンコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道斜里郡斜里町日の出', '01', '01545', '0994121', '北海道', 'ホッカイドウ', '斜里郡斜里町', 'シャリグンシャリチョウ', '日の出', 'ヒノデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145206', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道斜里郡斜里町峰浜', '01', '01545', '0994122', '北海道', 'ホッカイドウ', '斜里郡斜里町', 'シャリグンシャリチョウ', '峰浜', 'ミネハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道斜里郡斜里町朱円東', '01', '01545', '0994123', '北海道', 'ホッカイドウ', '斜里郡斜里町', 'シャリグンシャリチョウ', '朱円東', 'シュエンヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道斜里郡斜里町朱円', '01', '01545', '0994124', '北海道', 'ホッカイドウ', '斜里郡斜里町', 'シャリグンシャリチョウ', '朱円', 'シュエン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道斜里郡斜里町朱円西', '01', '01545', '0994125', '北海道', 'ホッカイドウ', '斜里郡斜里町', 'シャリグンシャリチョウ', '朱円西', 'シュエンニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道斜里郡斜里町以久科北', '01', '01545', '0994126', '北海道', 'ホッカイドウ', '斜里郡斜里町', 'シャリグンシャリチョウ', '以久科北', 'イクシナキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道斜里郡斜里町以久科南', '01', '01545', '0994127', '北海道', 'ホッカイドウ', '斜里郡斜里町', 'シャリグンシャリチョウ', '以久科南', 'イクシナミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道斜里郡斜里町越川', '01', '01545', '0994131', '北海道', 'ホッカイドウ', '斜里郡斜里町', 'シャリグンシャリチョウ', '越川', 'コシカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道斜里郡斜里町富士', '01', '01545', '0994132', '北海道', 'ホッカイドウ', '斜里郡斜里町', 'シャリグンシャリチョウ', '富士', 'フジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道斜里郡斜里町三井', '01', '01545', '0994133', '北海道', 'ホッカイドウ', '斜里郡斜里町', 'シャリグンシャリチョウ', '三井', 'ミツイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道斜里郡斜里町豊里', '01', '01545', '0994134', '北海道', 'ホッカイドウ', '斜里郡斜里町', 'シャリグンシャリチョウ', '豊里', 'トヨサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道斜里郡斜里町来運', '01', '01545', '0994135', '北海道', 'ホッカイドウ', '斜里郡斜里町', 'シャリグンシャリチョウ', '来運', 'ライウン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道斜里郡斜里町豊倉', '01', '01545', '0994141', '北海道', 'ホッカイドウ', '斜里郡斜里町', 'シャリグンシャリチョウ', '豊倉', 'トヨクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道斜里郡斜里町中斜里', '01', '01545', '0994142', '北海道', 'ホッカイドウ', '斜里郡斜里町', 'シャリグンシャリチョウ', '中斜里', 'ナカシャリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道斜里郡斜里町川上', '01', '01545', '0994143', '北海道', 'ホッカイドウ', '斜里郡斜里町', 'シャリグンシャリチョウ', '川上', 'カワカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道斜里郡斜里町大栄', '01', '01545', '0994144', '北海道', 'ホッカイドウ', '斜里郡斜里町', 'シャリグンシャリチョウ', '大栄', 'タイエイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道斜里郡斜里町美咲', '01', '01545', '0994145', '北海道', 'ホッカイドウ', '斜里郡斜里町', 'シャリグンシャリチョウ', '美咲', 'ミサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道斜里郡斜里町港西町', '01', '01545', '0994146', '北海道', 'ホッカイドウ', '斜里郡斜里町', 'シャリグンシャリチョウ', '港西町', 'ミナトニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道斜里郡斜里町西町', '01', '01545', '0994147', '北海道', 'ホッカイドウ', '斜里郡斜里町', 'シャリグンシャリチョウ', '西町', 'ニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道斜里郡斜里町ウトロ香川', '01', '01545', '0994351', '北海道', 'ホッカイドウ', '斜里郡斜里町', 'シャリグンシャリチョウ', 'ウトロ香川', 'ウトロカガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道斜里郡斜里町ウトロ高原', '01', '01545', '0994352', '北海道', 'ホッカイドウ', '斜里郡斜里町', 'シャリグンシャリチョウ', 'ウトロ高原', 'ウトロコウゲン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道斜里郡斜里町ウトロ中島', '01', '01545', '0994353', '北海道', 'ホッカイドウ', '斜里郡斜里町', 'シャリグンシャリチョウ', 'ウトロ中島', 'ウトロナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道斜里郡斜里町ウトロ西', '01', '01545', '0994354', '北海道', 'ホッカイドウ', '斜里郡斜里町', 'シャリグンシャリチョウ', 'ウトロ西', 'ウトロニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道斜里郡斜里町ウトロ東', '01', '01545', '0994355', '北海道', 'ホッカイドウ', '斜里郡斜里町', 'シャリグンシャリチョウ', 'ウトロ東', 'ウトロヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道斜里郡斜里町岩尾別', '01', '01545', '0994356', '北海道', 'ホッカイドウ', '斜里郡斜里町', 'シャリグンシャリチョウ', '岩尾別', 'イワオベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道斜里郡斜里町真鯉', '01', '01545', '0994357', '北海道', 'ホッカイドウ', '斜里郡斜里町', 'シャリグンシャリチョウ', '真鯉', 'マコイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道斜里郡清里町', '01', '01546', '0994400', '北海道', 'ホッカイドウ', '斜里郡清里町', 'シャリグンキヨサトチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('145235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道斜里郡清里町上斜里', '01', '01546', '0994401', '北海道', 'ホッカイドウ', '斜里郡清里町', 'シャリグンキヨサトチョウ', '上斜里', 'カミシャリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道斜里郡清里町下江鳶', '01', '01546', '0994402', '北海道', 'ホッカイドウ', '斜里郡清里町', 'シャリグンキヨサトチョウ', '下江鳶', 'シモエトンビ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道斜里郡清里町向陽', '01', '01546', '0994403', '北海道', 'ホッカイドウ', '斜里郡清里町', 'シャリグンキヨサトチョウ', '向陽', 'コウヨウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道斜里郡清里町江南', '01', '01546', '0994404', '北海道', 'ホッカイドウ', '斜里郡清里町', 'シャリグンキヨサトチョウ', '江南', 'コウナン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道斜里郡清里町羽衣町', '01', '01546', '0994405', '北海道', 'ホッカイドウ', '斜里郡清里町', 'シャリグンキヨサトチョウ', '羽衣町', 'ハゴロモマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道斜里郡清里町水元町', '01', '01546', '0994406', '北海道', 'ホッカイドウ', '斜里郡清里町', 'シャリグンキヨサトチョウ', '水元町', 'ミズモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道斜里郡清里町新町', '01', '01546', '0994407', '北海道', 'ホッカイドウ', '斜里郡清里町', 'シャリグンキヨサトチョウ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道斜里郡清里町札弦町', '01', '01546', '0994521', '北海道', 'ホッカイドウ', '斜里郡清里町', 'シャリグンキヨサトチョウ', '札弦町', 'サッツルマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道斜里郡清里町神威', '01', '01546', '0994522', '北海道', 'ホッカイドウ', '斜里郡清里町', 'シャリグンキヨサトチョウ', '神威', 'カモイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道斜里郡清里町川向', '01', '01546', '0994523', '北海道', 'ホッカイドウ', '斜里郡清里町', 'シャリグンキヨサトチョウ', '川向', 'カワムカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道斜里郡清里町青葉', '01', '01546', '0994524', '北海道', 'ホッカイドウ', '斜里郡清里町', 'シャリグンキヨサトチョウ', '青葉', 'アオバ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145247', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道斜里郡清里町緑町', '01', '01546', '0994525', '北海道', 'ホッカイドウ', '斜里郡清里町', 'シャリグンキヨサトチョウ', '緑町', 'ミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道斜里郡清里町清泉', '01', '01546', '0994526', '北海道', 'ホッカイドウ', '斜里郡清里町', 'シャリグンキヨサトチョウ', '清泉', 'キヨイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県村山市', '06', '06208', '9950000', '山形県', 'ヤマガタケン', '村山市', 'ムラヤマシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('145256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県村山市土生田', '06', '06208', '9950001', '山形県', 'ヤマガタケン', '村山市', 'ムラヤマシ', '土生田', 'トチウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県村山市五十沢', '06', '06208', '9950002', '山形県', 'ヤマガタケン', '村山市', 'ムラヤマシ', '五十沢', 'イサザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県村山市本飯田', '06', '06208', '9950003', '山形県', 'ヤマガタケン', '村山市', 'ムラヤマシ', '本飯田', 'モトイイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県村山市金谷', '06', '06208', '9950004', '山形県', 'ヤマガタケン', '村山市', 'ムラヤマシ', '金谷', 'カナヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県村山市たも山', '06', '06208', '9950005', '山形県', 'ヤマガタケン', '村山市', 'ムラヤマシ', 'たも山', 'タモヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県村山市林崎', '06', '06208', '9950006', '山形県', 'ヤマガタケン', '村山市', 'ムラヤマシ', '林崎', 'ハヤシザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県村山市楯岡北町', '06', '06208', '9950011', '山形県', 'ヤマガタケン', '村山市', 'ムラヤマシ', '楯岡北町', 'タテオカキタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県村山市湯沢', '06', '06208', '9950012', '山形県', 'ヤマガタケン', '村山市', 'ムラヤマシ', '湯沢', 'ユザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県村山市楯岡湯沢', '06', '06208', '9950013', '山形県', 'ヤマガタケン', '村山市', 'ムラヤマシ', '楯岡湯沢', 'タテオカユザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県村山市楯岡鶴ケ町', '06', '06208', '9950014', '山形県', 'ヤマガタケン', '村山市', 'ムラヤマシ', '楯岡鶴ケ町', 'タテオカツルガチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県村山市楯岡二日町', '06', '06208', '9950015', '山形県', 'ヤマガタケン', '村山市', 'ムラヤマシ', '楯岡二日町', 'タテオカフツカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県村山市楯岡晦日町', '06', '06208', '9950016', '山形県', 'ヤマガタケン', '村山市', 'ムラヤマシ', '楯岡晦日町', 'タテオカミソカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県村山市楯岡十日町', '06', '06208', '9950017', '山形県', 'ヤマガタケン', '村山市', 'ムラヤマシ', '楯岡十日町', 'タテオカトオカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県村山市楯岡新高田', '06', '06208', '9950018', '山形県', 'ヤマガタケン', '村山市', 'ムラヤマシ', '楯岡新高田', 'タテオカシンタカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県村山市楯岡楯', '06', '06208', '9950021', '山形県', 'ヤマガタケン', '村山市', 'ムラヤマシ', '楯岡楯', 'タテオカタテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県村山市楯岡馬場', '06', '06208', '9950022', '山形県', 'ヤマガタケン', '村山市', 'ムラヤマシ', '楯岡馬場', 'タテオカババ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県村山市楯岡東沢', '06', '06208', '9950023', '山形県', 'ヤマガタケン', '村山市', 'ムラヤマシ', '楯岡東沢', 'タテオカヒガシザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県村山市楯岡笛田', '06', '06208', '9950024', '山形県', 'ヤマガタケン', '村山市', 'ムラヤマシ', '楯岡笛田', 'タテオカフエダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県村山市楯岡', '06', '06208', '9950025', '山形県', 'ヤマガタケン', '村山市', 'ムラヤマシ', '楯岡', 'タテオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県村山市楯岡大沢川', '06', '06208', '9950031', '山形県', 'ヤマガタケン', '村山市', 'ムラヤマシ', '楯岡大沢川', 'タテオカオオサワガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県村山市楯岡荒町', '06', '06208', '9950032', '山形県', 'ヤマガタケン', '村山市', 'ムラヤマシ', '楯岡荒町', 'タテオカアラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県村山市楯岡新町', '06', '06208', '9950033', '山形県', 'ヤマガタケン', '村山市', 'ムラヤマシ', '楯岡新町', 'タテオカシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県村山市楯岡五日町', '06', '06208', '9950034', '山形県', 'ヤマガタケン', '村山市', 'ムラヤマシ', '楯岡五日町', 'タテオカイツカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県村山市中央', '06', '06208', '9950035', '山形県', 'ヤマガタケン', '村山市', 'ムラヤマシ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県村山市楯岡中町', '06', '06208', '9950036', '山形県', 'ヤマガタケン', '村山市', 'ムラヤマシ', '楯岡中町', 'タテオカナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県村山市楯岡俵町', '06', '06208', '9950037', '山形県', 'ヤマガタケン', '村山市', 'ムラヤマシ', '楯岡俵町', 'タテオカタワラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県村山市駅西', '06', '06208', '9950038', '山形県', 'ヤマガタケン', '村山市', 'ムラヤマシ', '駅西', 'エキニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県村山市河島', '06', '06208', '9950041', '山形県', 'ヤマガタケン', '村山市', 'ムラヤマシ', '河島', 'カワシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県村山市杉島', '06', '06208', '9950042', '山形県', 'ヤマガタケン', '村山市', 'ムラヤマシ', '杉島', 'スギシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県村山市田沢', '06', '06208', '9950051', '山形県', 'ヤマガタケン', '村山市', 'ムラヤマシ', '田沢', 'タザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県村山市名取', '06', '06208', '9950052', '山形県', 'ヤマガタケン', '村山市', 'ムラヤマシ', '名取', 'ナトリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県村山市西郷', '06', '06208', '9950053', '山形県', 'ヤマガタケン', '村山市', 'ムラヤマシ', '西郷', 'ニシゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県村山市大淀', '06', '06208', '9950054', '山形県', 'ヤマガタケン', '村山市', 'ムラヤマシ', '大淀', 'オオヨド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県村山市長島', '06', '06208', '9950055', '山形県', 'ヤマガタケン', '村山市', 'ムラヤマシ', '長島', 'ナガシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県村山市河島山', '06', '06208', '9950056', '山形県', 'ヤマガタケン', '村山市', 'ムラヤマシ', '河島山', 'カワシマヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県村山市大久保', '06', '06208', '9950111', '山形県', 'ヤマガタケン', '村山市', 'ムラヤマシ', '大久保', 'オオクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県村山市湯野沢', '06', '06208', '9950112', '山形県', 'ヤマガタケン', '村山市', 'ムラヤマシ', '湯野沢', 'ユノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県村山市岩野', '06', '06208', '9950113', '山形県', 'ヤマガタケン', '村山市', 'ムラヤマシ', '岩野', 'イワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県村山市長善寺', '06', '06208', '9950201', '山形県', 'ヤマガタケン', '村山市', 'ムラヤマシ', '長善寺', 'チョウゼンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県村山市白鳥', '06', '06208', '9950202', '山形県', 'ヤマガタケン', '村山市', 'ムラヤマシ', '白鳥', 'シロトリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県村山市大槇', '06', '06208', '9950203', '山形県', 'ヤマガタケン', '村山市', 'ムラヤマシ', '大槇', 'オオマキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県村山市稲下', '06', '06208', '9950204', '山形県', 'ヤマガタケン', '村山市', 'ムラヤマシ', '稲下', 'イナクダシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県村山市樽石', '06', '06208', '9950205', '山形県', 'ヤマガタケン', '村山市', 'ムラヤマシ', '樽石', 'タルイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県村山市山の内', '06', '06208', '9950206', '山形県', 'ヤマガタケン', '村山市', 'ムラヤマシ', '山の内', 'ヤマノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県村山市雪の観音郷', '06', '06208', '9950207', '山形県', 'ヤマガタケン', '村山市', 'ムラヤマシ', '雪の観音郷', 'ユキノカンノンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県村山市富並', '06', '06208', '9950208', '山形県', 'ヤマガタケン', '村山市', 'ムラヤマシ', '富並', 'トミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県村山市碁点', '06', '06208', '9950209', '山形県', 'ヤマガタケン', '村山市', 'ムラヤマシ', '碁点', 'ゴテン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別市渚滑町', '01', '01219', '0995171', '北海道', 'ホッカイドウ', '紋別市', 'モンベツシ', '渚滑町', 'ショコツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別市渚滑町元新', '01', '01219', '0995172', '北海道', 'ホッカイドウ', '紋別市', 'モンベツシ', '渚滑町元新', 'ショコツチョウモトシン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別市渚滑町元西', '01', '01219', '0995173', '北海道', 'ホッカイドウ', '紋別市', 'モンベツシ', '渚滑町元西', 'ショコツチョウモトニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別市渚滑町宇津々', '01', '01219', '0995174', '北海道', 'ホッカイドウ', '紋別市', 'モンベツシ', '渚滑町宇津々', 'ショコツチョウウツツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別市渚滑町川向', '01', '01219', '0995175', '北海道', 'ホッカイドウ', '紋別市', 'モンベツシ', '渚滑町川向', 'ショコツチョウカワムカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別市上渚滑町下渚滑', '01', '01219', '0995351', '北海道', 'ホッカイドウ', '紋別市', 'モンベツシ', '上渚滑町下渚滑', 'カミショコツチョウシモショコツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別市上渚滑町中渚滑', '01', '01219', '0995352', '北海道', 'ホッカイドウ', '紋別市', 'モンベツシ', '上渚滑町中渚滑', 'カミショコツチョウナカショコツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別市上渚滑町上東', '01', '01219', '0995353', '北海道', 'ホッカイドウ', '紋別市', 'モンベツシ', '上渚滑町上東', 'カミショコツチョウジョウトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別市上渚滑町', '01', '01219', '0995354', '北海道', 'ホッカイドウ', '紋別市', 'モンベツシ', '上渚滑町', 'カミショコツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別市上渚滑町更生', '01', '01219', '0995355', '北海道', 'ホッカイドウ', '紋別市', 'モンベツシ', '上渚滑町更生', 'カミショコツチョウコウセイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別市上渚滑町和訓辺', '01', '01219', '0995361', '北海道', 'ホッカイドウ', '紋別市', 'モンベツシ', '上渚滑町和訓辺', 'カミショコツチョウワクンベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別市上渚滑町奥東', '01', '01219', '0995362', '北海道', 'ホッカイドウ', '紋別市', 'モンベツシ', '上渚滑町奥東', 'カミショコツチョウオクトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別市上渚滑町下立牛', '01', '01219', '0995363', '北海道', 'ホッカイドウ', '紋別市', 'モンベツシ', '上渚滑町下立牛', 'カミショコツチョウシモタツウシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別市上渚滑町上古丹', '01', '01219', '0995364', '北海道', 'ホッカイドウ', '紋別市', 'モンベツシ', '上渚滑町上古丹', 'カミショコツチョウウエコタン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別市上渚滑町中立牛', '01', '01219', '0995365', '北海道', 'ホッカイドウ', '紋別市', 'モンベツシ', '上渚滑町中立牛', 'カミショコツチョウナカタツウシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡滝上町濁川中央', '01', '01560', '0995541', '北海道', 'ホッカイドウ', '紋別郡滝上町', 'モンベツグンタキノウエチョウ', '濁川中央', 'ニゴリカワチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡滝上町濁川みどり町', '01', '01560', '0995542', '北海道', 'ホッカイドウ', '紋別郡滝上町', 'モンベツグンタキノウエチョウ', '濁川みどり町', 'ニゴリカワミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡滝上町新町', '01', '01560', '0995543', '北海道', 'ホッカイドウ', '紋別郡滝上町', 'モンベツグンタキノウエチョウ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡滝上町雄鎮内', '01', '01560', '0995544', '北海道', 'ホッカイドウ', '紋別郡滝上町', 'モンベツグンタキノウエチョウ', '雄鎮内', 'オチンナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡滝上町大正', '01', '01560', '0995551', '北海道', 'ホッカイドウ', '紋別郡滝上町', 'モンベツグンタキノウエチョウ', '大正', 'タイショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡滝上町滝下', '01', '01560', '0995552', '北海道', 'ホッカイドウ', '紋別郡滝上町', 'モンベツグンタキノウエチョウ', '滝下', 'タキシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡滝上町雄柏', '01', '01560', '0995553', '北海道', 'ホッカイドウ', '紋別郡滝上町', 'モンベツグンタキノウエチョウ', '雄柏', 'ユウハク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡滝上町', '01', '01560', '0995600', '北海道', 'ホッカイドウ', '紋別郡滝上町', 'モンベツグンタキノウエチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('145326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡滝上町あけぼの町', '01', '01560', '0995601', '北海道', 'ホッカイドウ', '紋別郡滝上町', 'モンベツグンタキノウエチョウ', 'あけぼの町', 'アケボノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡滝上町旭町', '01', '01560', '0995602', '北海道', 'ホッカイドウ', '紋別郡滝上町', 'モンベツグンタキノウエチョウ', '旭町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡滝上町滝美町', '01', '01560', '0995603', '北海道', 'ホッカイドウ', '紋別郡滝上町', 'モンベツグンタキノウエチョウ', '滝美町', 'タキミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡滝上町元町', '01', '01560', '0995604', '北海道', 'ホッカイドウ', '紋別郡滝上町', 'モンベツグンタキノウエチョウ', '元町', 'モトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡滝上町栄町', '01', '01560', '0995605', '北海道', 'ホッカイドウ', '紋別郡滝上町', 'モンベツグンタキノウエチョウ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡滝上町幸町', '01', '01560', '0995606', '北海道', 'ホッカイドウ', '紋別郡滝上町', 'モンベツグンタキノウエチョウ', '幸町', 'サイワイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡滝上町第1区', '01', '01560', '0995611', '北海道', 'ホッカイドウ', '紋別郡滝上町', 'モンベツグンタキノウエチョウ', '第1区', 'ダイ01ク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡滝上町白鳥', '01', '01560', '0995612', '北海道', 'ホッカイドウ', '紋別郡滝上町', 'モンベツグンタキノウエチョウ', '白鳥', 'シラトリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡滝上町第2区', '01', '01560', '0995612', '北海道', 'ホッカイドウ', '紋別郡滝上町', 'モンベツグンタキノウエチョウ', '第2区', 'ダイ02ク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡滝上町第3区', '01', '01560', '0995613', '北海道', 'ホッカイドウ', '紋別郡滝上町', 'モンベツグンタキノウエチョウ', '第3区', 'ダイ03ク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡滝上町第4区', '01', '01560', '0995613', '北海道', 'ホッカイドウ', '紋別郡滝上町', 'モンベツグンタキノウエチョウ', '第4区', 'ダイ04ク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡滝上町第5区', '01', '01560', '0995613', '北海道', 'ホッカイドウ', '紋別郡滝上町', 'モンベツグンタキノウエチョウ', '第5区', 'ダイ05ク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡滝上町滝西', '01', '01560', '0995613', '北海道', 'ホッカイドウ', '紋別郡滝上町', 'モンベツグンタキノウエチョウ', '滝西', 'タキニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡滝上町札久留', '01', '01560', '0995614', '北海道', 'ホッカイドウ', '紋別郡滝上町', 'モンベツグンタキノウエチョウ', '札久留', 'サックル', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県新庄市', '06', '06205', '9960000', '山形県', 'ヤマガタケン', '新庄市', 'シンジョウシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('145343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県新庄市五日町', '06', '06205', '9960001', '山形県', 'ヤマガタケン', '新庄市', 'シンジョウシ', '五日町', 'イツカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県新庄市金沢', '06', '06205', '9960002', '山形県', 'ヤマガタケン', '新庄市', 'シンジョウシ', '金沢', 'カナザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県新庄市東谷地田町', '06', '06205', '9960011', '山形県', 'ヤマガタケン', '新庄市', 'シンジョウシ', '東谷地田町', 'ヒガシヤチタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県新庄市常葉町', '06', '06205', '9960021', '山形県', 'ヤマガタケン', '新庄市', 'シンジョウシ', '常葉町', 'トキハマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県新庄市住吉町', '06', '06205', '9960022', '山形県', 'ヤマガタケン', '新庄市', 'シンジョウシ', '住吉町', 'スミヨシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県新庄市沖の町', '06', '06205', '9960023', '山形県', 'ヤマガタケン', '新庄市', 'シンジョウシ', '沖の町', 'オキノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県新庄市多門町', '06', '06205', '9960024', '山形県', 'ヤマガタケン', '新庄市', 'シンジョウシ', '多門町', 'タモンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県新庄市若葉町', '06', '06205', '9960025', '山形県', 'ヤマガタケン', '新庄市', 'シンジョウシ', '若葉町', 'ワカバマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県新庄市大町', '06', '06205', '9960026', '山形県', 'ヤマガタケン', '新庄市', 'シンジョウシ', '大町', 'オオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県新庄市本町', '06', '06205', '9960027', '山形県', 'ヤマガタケン', '新庄市', 'シンジョウシ', '本町', 'ホンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県新庄市万場町', '06', '06205', '9960028', '山形県', 'ヤマガタケン', '新庄市', 'シンジョウシ', '万場町', 'バンバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県新庄市末広町', '06', '06205', '9960031', '山形県', 'ヤマガタケン', '新庄市', 'シンジョウシ', '末広町', 'スエヒロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県新庄市上金沢町', '06', '06205', '9960032', '山形県', 'ヤマガタケン', '新庄市', 'シンジョウシ', '上金沢町', 'カミカネザワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県新庄市下金沢町', '06', '06205', '9960033', '山形県', 'ヤマガタケン', '新庄市', 'シンジョウシ', '下金沢町', 'シモカネザワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県新庄市下田町', '06', '06205', '9960034', '山形県', 'ヤマガタケン', '新庄市', 'シンジョウシ', '下田町', 'シモダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県新庄市鉄砲町', '06', '06205', '9960035', '山形県', 'ヤマガタケン', '新庄市', 'シンジョウシ', '鉄砲町', 'テッポウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県新庄市鳥越', '06', '06205', '9960041', '山形県', 'ヤマガタケン', '新庄市', 'シンジョウシ', '鳥越', 'トリゴエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県新庄市松本', '06', '06205', '9960051', '山形県', 'ヤマガタケン', '新庄市', 'シンジョウシ', '松本', 'マツモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県新庄市角沢', '06', '06205', '9960052', '山形県', 'ヤマガタケン', '新庄市', 'シンジョウシ', '角沢', 'ツノザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県新庄市福田', '06', '06205', '9960053', '山形県', 'ヤマガタケン', '新庄市', 'シンジョウシ', '福田', 'フクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県新庄市仁間', '06', '06205', '9960054', '山形県', 'ヤマガタケン', '新庄市', 'シンジョウシ', '仁間', 'ニケン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県新庄市飛田', '06', '06205', '9960061', '山形県', 'ヤマガタケン', '新庄市', 'シンジョウシ', '飛田', 'トビタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県新庄市小田島町', '06', '06205', '9960071', '山形県', 'ヤマガタケン', '新庄市', 'シンジョウシ', '小田島町', 'オダシママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県新庄市宮内町', '06', '06205', '9960072', '山形県', 'ヤマガタケン', '新庄市', 'シンジョウシ', '宮内町', 'ミヤウチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県新庄市栄町', '06', '06205', '9960073', '山形県', 'ヤマガタケン', '新庄市', 'シンジョウシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県新庄市小田島', '06', '06205', '9960074', '山形県', 'ヤマガタケン', '新庄市', 'シンジョウシ', '小田島', 'オダシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県新庄市横打町', '06', '06205', '9960075', '山形県', 'ヤマガタケン', '新庄市', 'シンジョウシ', '横打町', 'ヨコウチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県新庄市城西町', '06', '06205', '9960076', '山形県', 'ヤマガタケン', '新庄市', 'シンジョウシ', '城西町', 'シロニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県新庄市城南町', '06', '06205', '9960077', '山形県', 'ヤマガタケン', '新庄市', 'シンジョウシ', '城南町', 'ジョウナンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県新庄市新町', '06', '06205', '9960078', '山形県', 'ヤマガタケン', '新庄市', 'シンジョウシ', '新町', 'アラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県新庄市千門町', '06', '06205', '9960079', '山形県', 'ヤマガタケン', '新庄市', 'シンジョウシ', '千門町', 'センモンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県新庄市中道町', '06', '06205', '9960081', '山形県', 'ヤマガタケン', '新庄市', 'シンジョウシ', '中道町', 'ナカミチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県新庄市北町', '06', '06205', '9960082', '山形県', 'ヤマガタケン', '新庄市', 'シンジョウシ', '北町', 'キタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県新庄市沼田町', '06', '06205', '9960083', '山形県', 'ヤマガタケン', '新庄市', 'シンジョウシ', '沼田町', 'ヌマタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県新庄市大手町', '06', '06205', '9960084', '山形県', 'ヤマガタケン', '新庄市', 'シンジョウシ', '大手町', 'オオテマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県新庄市堀端町', '06', '06205', '9960085', '山形県', 'ヤマガタケン', '新庄市', 'シンジョウシ', '堀端町', 'ホリバタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県新庄市石川町', '06', '06205', '9960086', '山形県', 'ヤマガタケン', '新庄市', 'シンジョウシ', '石川町', 'イシカワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県新庄市沼田', '06', '06205', '9960087', '山形県', 'ヤマガタケン', '新庄市', 'シンジョウシ', '沼田', 'ヌマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県新庄市桧町', '06', '06205', '9960088', '山形県', 'ヤマガタケン', '新庄市', 'シンジョウシ', '桧町', 'ヒノキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145382', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県新庄市十日町', '06', '06205', '9960091', '山形県', 'ヤマガタケン', '新庄市', 'シンジョウシ', '十日町', 'トオカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県新庄市升形', '06', '06205', '9960111', '山形県', 'ヤマガタケン', '新庄市', 'シンジョウシ', '升形', 'マスガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県新庄市本合海', '06', '06205', '9960112', '山形県', 'ヤマガタケン', '新庄市', 'シンジョウシ', '本合海', 'モトアイカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県最上郡大蔵村', '06', '06365', '9960200', '山形県', 'ヤマガタケン', '最上郡大蔵村', 'モガミグンオオクラムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('145386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県最上郡大蔵村南山', '06', '06365', '9960201', '山形県', 'ヤマガタケン', '最上郡大蔵村', 'モガミグンオオクラムラ', '南山', 'ミナミヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県最上郡大蔵村合海', '06', '06365', '9960211', '山形県', 'ヤマガタケン', '最上郡大蔵村', 'モガミグンオオクラムラ', '合海', 'アイカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県最上郡大蔵村清水', '06', '06365', '9960212', '山形県', 'ヤマガタケン', '最上郡大蔵村', 'モガミグンオオクラムラ', '清水', 'シミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県最上郡大蔵村赤松', '06', '06365', '9960213', '山形県', 'ヤマガタケン', '最上郡大蔵村', 'モガミグンオオクラムラ', '赤松', 'アカマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県最上郡大蔵村南山', '06', '06365', '9960301', '山形県', 'ヤマガタケン', '最上郡大蔵村', 'モガミグンオオクラムラ', '南山', 'ミナミヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県最上郡大蔵村南山大谷地', '06', '06365', '9960301', '山形県', 'ヤマガタケン', '最上郡大蔵村', 'モガミグンオオクラムラ', '南山', 'ミナミヤマ', null, null, '大谷地', 'オオヤチ');
INSERT INTO `ms_addresses` VALUES ('145392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県最上郡大蔵村南山折渡', '06', '06365', '9960301', '山形県', 'ヤマガタケン', '最上郡大蔵村', 'モガミグンオオクラムラ', '南山', 'ミナミヤマ', null, null, '折渡', 'オリワタリ');
INSERT INTO `ms_addresses` VALUES ('145393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県最上郡大蔵村南山鍵金野', '06', '06365', '9960301', '山形県', 'ヤマガタケン', '最上郡大蔵村', 'モガミグンオオクラムラ', '南山', 'ミナミヤマ', null, null, '鍵金野', 'カンカネノ');
INSERT INTO `ms_addresses` VALUES ('145394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県最上郡大蔵村南山金山', '06', '06365', '9960301', '山形県', 'ヤマガタケン', '最上郡大蔵村', 'モガミグンオオクラムラ', '南山', 'ミナミヤマ', null, null, '金山', 'キンザン');
INSERT INTO `ms_addresses` VALUES ('145395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県最上郡大蔵村南山滝ノ沢', '06', '06365', '9960301', '山形県', 'ヤマガタケン', '最上郡大蔵村', 'モガミグンオオクラムラ', '南山', 'ミナミヤマ', null, null, '滝ノ沢', 'タキノサワ');
INSERT INTO `ms_addresses` VALUES ('145396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県最上郡大蔵村南山豊牧', '06', '06365', '9960301', '山形県', 'ヤマガタケン', '最上郡大蔵村', 'モガミグンオオクラムラ', '南山', 'ミナミヤマ', null, null, '豊牧', 'トヨマキ');
INSERT INTO `ms_addresses` VALUES ('145397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県最上郡大蔵村南山沼の台', '06', '06365', '9960301', '山形県', 'ヤマガタケン', '最上郡大蔵村', 'モガミグンオオクラムラ', '南山', 'ミナミヤマ', null, null, '沼の台', 'ヌマノダイ');
INSERT INTO `ms_addresses` VALUES ('145398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県最上郡大蔵村南山肘折', '06', '06365', '9960301', '山形県', 'ヤマガタケン', '最上郡大蔵村', 'モガミグンオオクラムラ', '南山', 'ミナミヤマ', null, null, '肘折', 'ヒジオリ');
INSERT INTO `ms_addresses` VALUES ('145399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県最上郡大蔵村南山平林', '06', '06365', '9960301', '山形県', 'ヤマガタケン', '最上郡大蔵村', 'モガミグンオオクラムラ', '南山', 'ミナミヤマ', null, null, '平林', 'ヒラバヤシ');
INSERT INTO `ms_addresses` VALUES ('145400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別市一本松', '01', '01219', '0996131', '北海道', 'ホッカイドウ', '紋別市', 'モンベツシ', '一本松', 'イッポンマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別市八十士', '01', '01219', '0996131', '北海道', 'ホッカイドウ', '紋別市', 'モンベツシ', '八十士', 'ヤソシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別市小向', '01', '01219', '0996132', '北海道', 'ホッカイドウ', '紋別市', 'モンベツシ', '小向', 'コムカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別市弘道', '01', '01219', '0996133', '北海道', 'ホッカイドウ', '紋別市', 'モンベツシ', '弘道', 'コウドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別市沼の上', '01', '01219', '0996241', '北海道', 'ホッカイドウ', '紋別市', 'モンベツシ', '沼の上', 'ヌマノウエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別市志文', '01', '01219', '0996242', '北海道', 'ホッカイドウ', '紋別市', 'モンベツシ', '志文', 'シブン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡湧別町信部内', '01', '01559', '0996271', '北海道', 'ホッカイドウ', '紋別郡湧別町', 'モンベツグンユウベツチョウ', '信部内', 'シブナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡湧別町緑蔭', '01', '01559', '0996272', '北海道', 'ホッカイドウ', '紋別郡湧別町', 'モンベツグンユウベツチョウ', '緑蔭', 'リョクイン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡上湧別町旭', '01', '01558', '0996321', '北海道', 'ホッカイドウ', '紋別郡上湧別町', 'モンベツグンカミユウベツチョウ', '旭', 'アサヒ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡上湧別町北兵村三区', '01', '01558', '0996322', '北海道', 'ホッカイドウ', '紋別郡上湧別町', 'モンベツグンカミユウベツチョウ', '北兵村', 'キタヘイソン', null, null, '三区', '03ク');
INSERT INTO `ms_addresses` VALUES ('145410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡上湧別町北兵村二区', '01', '01558', '0996323', '北海道', 'ホッカイドウ', '紋別郡上湧別町', 'モンベツグンカミユウベツチョウ', '北兵村', 'キタヘイソン', null, null, '二区', '02ク');
INSERT INTO `ms_addresses` VALUES ('145411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡上湧別町中湧別', '01', '01558', '0996324', '北海道', 'ホッカイドウ', '紋別郡上湧別町', 'モンベツグンカミユウベツチョウ', '中湧別', 'ナカユウベツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡上湧別町北兵村一区', '01', '01558', '0996325', '北海道', 'ホッカイドウ', '紋別郡上湧別町', 'モンベツグンカミユウベツチョウ', '北兵村', 'キタヘイソン', null, null, '一区', '01ク');
INSERT INTO `ms_addresses` VALUES ('145413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡湧別町', '01', '01559', '0996400', '北海道', 'ホッカイドウ', '紋別郡湧別町', 'モンベツグンユウベツチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('145414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡湧別町港町', '01', '01559', '0996401', '北海道', 'ホッカイドウ', '紋別郡湧別町', 'モンベツグンユウベツチョウ', '港町', 'ミナトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡湧別町曙町', '01', '01559', '0996402', '北海道', 'ホッカイドウ', '紋別郡湧別町', 'モンベツグンユウベツチョウ', '曙町', 'アケボノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡湧別町緑町', '01', '01559', '0996403', '北海道', 'ホッカイドウ', '紋別郡湧別町', 'モンベツグンユウベツチョウ', '緑町', 'ミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡湧別町栄町', '01', '01559', '0996404', '北海道', 'ホッカイドウ', '紋別郡湧別町', 'モンベツグンユウベツチョウ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡湧別町東', '01', '01559', '0996411', '北海道', 'ホッカイドウ', '紋別郡湧別町', 'モンベツグンユウベツチョウ', '東', 'ヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡湧別町登栄床', '01', '01559', '0996412', '北海道', 'ホッカイドウ', '紋別郡湧別町', 'モンベツグンユウベツチョウ', '登栄床', 'トエトコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡湧別町福島', '01', '01559', '0996413', '北海道', 'ホッカイドウ', '紋別郡湧別町', 'モンベツグンユウベツチョウ', '福島', 'フクシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡湧別町錦', '01', '01559', '0996414', '北海道', 'ホッカイドウ', '紋別郡湧別町', 'モンベツグンユウベツチョウ', '錦', 'ニシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡湧別町川西', '01', '01559', '0996415', '北海道', 'ホッカイドウ', '紋別郡湧別町', 'モンベツグンユウベツチョウ', '川西', 'カワニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡上湧別町', '01', '01558', '0996500', '北海道', 'ホッカイドウ', '紋別郡上湧別町', 'モンベツグンカミユウベツチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('145424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡上湧別町屯田市街', '01', '01558', '0996501', '北海道', 'ホッカイドウ', '紋別郡上湧別町', 'モンベツグンカミユウベツチョウ', '屯田市街', 'トンデンシガイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡上湧別町南兵村', '01', '01558', '0996502', '北海道', 'ホッカイドウ', '紋別郡上湧別町', 'モンベツグンカミユウベツチョウ', '南兵村', 'ミナミヘイソン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡上湧別町開盛', '01', '01558', '0996503', '北海道', 'ホッカイドウ', '紋別郡上湧別町', 'モンベツグンカミユウベツチョウ', '開盛', 'カイセイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡上湧別町上富美', '01', '01558', '0996504', '北海道', 'ホッカイドウ', '紋別郡上湧別町', 'モンベツグンカミユウベツチョウ', '上富美', 'カミフミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡上湧別町富美', '01', '01558', '0996505', '北海道', 'ホッカイドウ', '紋別郡上湧別町', 'モンベツグンカミユウベツチョウ', '富美', 'フミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '北海道紋別郡上湧別町札富美', '01', '01558', '0996506', '北海道', 'ホッカイドウ', '紋別郡上湧別町', 'モンベツグンカミユウベツチョウ', '札富美', 'サツフミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市', '06', '06203', '9970000', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('145435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市湯野沢', '06', '06203', '9970001', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '湯野沢', 'ユノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市播磨', '06', '06203', '9970002', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '播磨', 'ハリマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市文下', '06', '06203', '9970003', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '文下', 'ホウダシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市本田', '06', '06203', '9970004', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '本田', 'ホンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市小京田', '06', '06203', '9970005', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '小京田', 'コキョウデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145440', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市福田', '06', '06203', '9970006', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '福田', 'フクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市豊田', '06', '06203', '9970007', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '豊田', 'トヨダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市平田', '06', '06203', '9970008', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '平田', 'ヒラタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市中京田', '06', '06203', '9970009', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '中京田', 'ナカキョウデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市余慶町', '06', '06203', '9970010', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '余慶町', 'ヨケイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市宝田', '06', '06203', '9970011', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '宝田', 'タカラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市道形', '06', '06203', '9970012', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '道形', 'ドウガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市道形町', '06', '06203', '9970013', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '道形町', 'ドウガタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市大宝寺町', '06', '06203', '9970014', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '大宝寺町', 'ダイホウジマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市末広町', '06', '06203', '9970015', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '末広町', 'スエヒロマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市日和田町', '06', '06203', '9970016', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '日和田町', 'ヒヨリダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市大宝寺', '06', '06203', '9970017', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '大宝寺', 'ダイホウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市茅原町', '06', '06203', '9970018', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '茅原町', 'チワラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市茅原', '06', '06203', '9970019', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '茅原', 'チワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市宝町', '06', '06203', '9970021', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '宝町', 'タカラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市切添町', '06', '06203', '9970022', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '切添町', 'キリゾエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市鳥居町', '06', '06203', '9970023', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '鳥居町', 'トリイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市朝暘町', '06', '06203', '9970024', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '朝暘町', 'チョウヨウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市日出', '06', '06203', '9970025', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '日出', 'ヒノデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市大東町', '06', '06203', '9970026', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '大東町', 'ダイトウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市昭和町', '06', '06203', '9970027', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '昭和町', 'ショウワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市山王町', '06', '06203', '9970028', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '山王町', 'サンノウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市日吉町', '06', '06203', '9970029', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '日吉町', 'ヒヨシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市錦町', '06', '06203', '9970031', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '錦町', 'ニシキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市上畑町', '06', '06203', '9970032', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '上畑町', 'カミハタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市泉町', '06', '06203', '9970033', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '泉町', 'イズミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市本町', '06', '06203', '9970034', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市馬場町', '06', '06203', '9970035', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '馬場町', 'ババチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市家中新町', '06', '06203', '9970036', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '家中新町', 'カチュウシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市若葉町', '06', '06203', '9970037', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '若葉町', 'ワカバマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市城北町', '06', '06203', '9970041', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '城北町', 'ジョウホクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市新形町', '06', '06203', '9970042', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '新形町', 'ニイガタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市東新斎町', '06', '06203', '9970043', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '東新斎町', 'ヒガシシンサイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市新海町', '06', '06203', '9970044', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '新海町', 'シンカイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市西新斎町', '06', '06203', '9970045', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '西新斎町', 'ニシシンサイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市みどり町', '06', '06203', '9970046', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', 'みどり町', 'ミドリマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市大塚町', '06', '06203', '9970047', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '大塚町', 'オオツカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市平京田', '06', '06203', '9970048', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '平京田', 'ヘイキョウデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市大部町', '06', '06203', '9970049', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '大部町', 'ダイブマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市荒井京田', '06', '06203', '9970051', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '荒井京田', 'アライキョウデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市覚岸寺', '06', '06203', '9970052', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '覚岸寺', 'カクガンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市北京田', '06', '06203', '9970053', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '北京田', 'キタキョウデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市高田', '06', '06203', '9970054', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '高田', 'タカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市西京田', '06', '06203', '9970055', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '西京田', 'ニシキョウデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市中野京田', '06', '06203', '9970056', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '中野京田', 'ナカノキョウデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市安丹', '06', '06203', '9970057', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '安丹', 'アンタン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市林崎', '06', '06203', '9970058', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '林崎', 'ハヤシザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市羽黒町町屋', '06', '06203', '9970101', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '羽黒町町屋', 'ハグロマチマチヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市羽黒町中里', '06', '06203', '9970102', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '羽黒町中里', 'ハグロマチナカザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市羽黒町戸野', '06', '06203', '9970103', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '羽黒町戸野', 'ハグロマチトノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市羽黒町坂ノ下', '06', '06203', '9970104', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '羽黒町坂ノ下', 'ハグロマチサカノシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市羽黒町川行', '06', '06203', '9970105', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '羽黒町川行', 'ハグロマチカワツラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市羽黒町染興屋', '06', '06203', '9970106', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '羽黒町染興屋', 'ハグロマチソメコウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市羽黒町小増川', '06', '06203', '9970107', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '羽黒町小増川', 'ハグロマチコマスガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市羽黒町金森目', '06', '06203', '9970108', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '羽黒町金森目', 'ハグロマチカナモリメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市大宝寺中野', '06', '06203', '9970117', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '大宝寺', 'ダイホウジ', null, null, '中野', 'ナカノ');
INSERT INTO `ms_addresses` VALUES ('145496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市羽黒町玉川', '06', '06203', '9970121', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '羽黒町玉川', 'ハグロマチタマガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市羽黒町大口', '06', '06203', '9970122', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '羽黒町大口', 'ハグロマチオオグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市羽黒町市野山', '06', '06203', '9970123', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '羽黒町市野山', 'ハグロマチイチノヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市羽黒町増川新田', '06', '06203', '9970124', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '羽黒町増川新田', 'ハグロマチマスカワシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市羽黒町仙道', '06', '06203', '9970125', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '羽黒町仙道', 'ハグロマチセンドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市羽黒町野荒町', '06', '06203', '9970126', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '羽黒町野荒町', 'ハグロマチノアラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市羽黒町十文字', '06', '06203', '9970127', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '羽黒町十文字', 'ハグロマチジュウモンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市羽黒町川代', '06', '06203', '9970131', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '羽黒町川代', 'ハグロマチカワダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市羽黒町荒川', '06', '06203', '9970141', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '羽黒町荒川', 'ハグロマチアラカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市羽黒町上野新田', '06', '06203', '9970142', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '羽黒町上野新田', 'ハグロマチウワノシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市羽黒町野田', '06', '06203', '9970143', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '羽黒町野田', 'ハグロマチノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市羽黒町黒瀬', '06', '06203', '9970151', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '羽黒町黒瀬', 'ハグロマチクロセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市羽黒町猪俣新田', '06', '06203', '9970152', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '羽黒町猪俣新田', 'ハグロマチイノマタシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市羽黒町高寺', '06', '06203', '9970153', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '羽黒町高寺', 'ハグロマチタカデラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市羽黒町馬渡ノ内下', '06', '06203', '9970154', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '羽黒町馬渡ノ内下', 'ハグロマチマワタリノウチシモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市羽黒町石野新田', '06', '06203', '9970155', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '羽黒町石野新田', 'ハグロマチイシノシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市羽黒町松尾', '06', '06203', '9970156', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '羽黒町松尾', 'ハグロマチマツオ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市羽黒町後田', '06', '06203', '9970157', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '羽黒町後田', 'ハグロマチウシロダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市羽黒町松ケ岡', '06', '06203', '9970158', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '羽黒町松ケ岡', 'ハグロマチマツガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市羽黒町押口', '06', '06203', '9970161', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '羽黒町押口', 'ハグロマチオサエグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市羽黒町細谷', '06', '06203', '9970162', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '羽黒町細谷', 'ハグロマチホソヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市羽黒町狩谷野目', '06', '06203', '9970163', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '羽黒町狩谷野目', 'ハグロマチカリヤノメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市羽黒町昼田', '06', '06203', '9970164', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '羽黒町昼田', 'ハグロマチヒルダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市羽黒町富沢', '06', '06203', '9970165', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '羽黒町富沢', 'ハグロマチトミザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市羽黒町三ツ橋', '06', '06203', '9970166', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '羽黒町三ツ橋', 'ハグロマチミツハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市羽黒町赤川', '06', '06203', '9970167', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '羽黒町赤川', 'ハグロマチアカガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市羽黒町手向', '06', '06203', '9970211', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '羽黒町手向', 'ハグロマチトウゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市馬渡', '06', '06203', '9970301', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '馬渡', 'マワタリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市田代', '06', '06203', '9970302', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '田代', 'タシロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市たらのき代', '06', '06203', '9970303', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', 'たらのき代', 'タラノキダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市黒川', '06', '06203', '9970311', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '黒川', 'クロカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市宝谷', '06', '06203', '9970321', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '宝谷', 'ホウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市松根', '06', '06203', '9970322', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '松根', 'マツネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市西片屋', '06', '06203', '9970323', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '西片屋', 'ニシカタヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市板井川', '06', '06203', '9970331', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '板井川', 'イタイガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市西荒屋', '06', '06203', '9970332', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '西荒屋', 'ニシアラヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市常盤木', '06', '06203', '9970333', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '常盤木', 'トキワギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市丸岡', '06', '06203', '9970334', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '丸岡', 'マルオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市下山添', '06', '06203', '9970341', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '下山添', 'シモヤマゾエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市三千刈', '06', '06203', '9970342', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '三千刈', 'サンゼンガリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市桂荒俣', '06', '06203', '9970343', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '桂荒俣', 'カツラアラマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市東荒屋', '06', '06203', '9970344', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '東荒屋', 'ヒガシアラヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市中田', '06', '06203', '9970345', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '中田', 'ナカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市上山添', '06', '06203', '9970346', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '上山添', 'カミヤマゾエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市勝福寺', '06', '06203', '9970351', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '勝福寺', 'ショウフクジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市民田', '06', '06203', '9970361', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '民田', 'ミンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市中橋', '06', '06203', '9970362', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '中橋', 'ナカハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市寿', '06', '06203', '9970363', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '寿', 'コトブキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市滝沢', '06', '06203', '9970364', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '滝沢', 'タキザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市金谷', '06', '06203', '9970365', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '金谷', 'カナヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市谷定', '06', '06203', '9970366', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '谷定', 'タニサダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市上山谷', '06', '06203', '9970367', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '上山谷', 'カミヤマヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市青龍寺', '06', '06203', '9970368', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '青龍寺', 'ショウリュウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市高坂', '06', '06203', '9970369', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '高坂', 'タカサカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市中野新田', '06', '06203', '9970401', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '中野新田', 'ナカノシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市東岩本', '06', '06203', '9970402', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '東岩本', 'ヒガシイワモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市越中山', '06', '06203', '9970403', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '越中山', 'エッチュウヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145556', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市下名川', '06', '06203', '9970404', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '下名川', 'シモナガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市上名川', '06', '06203', '9970405', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '上名川', 'カミナガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市熊出', '06', '06203', '9970411', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '熊出', 'クマイデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市本郷', '06', '06203', '9970412', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '本郷', 'ホンゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市行沢', '06', '06203', '9970413', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '行沢', 'ナメザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市大針', '06', '06203', '9970414', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '大針', 'オオバリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市砂川', '06', '06203', '9970415', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '砂川', 'スナガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市大網', '06', '06203', '9970531', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '大網', 'オオアミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市田麦俣', '06', '06203', '9970532', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '田麦俣', 'タムギマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市荒沢', '06', '06203', '9970621', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '荒沢', 'アラサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市大鳥', '06', '06203', '9970622', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '大鳥', 'オオトリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市上田沢', '06', '06203', '9970623', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '上田沢', 'カミタザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市倉沢', '06', '06203', '9970624', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '倉沢', 'クラサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市下田沢', '06', '06203', '9970625', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '下田沢', 'シモタザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市松沢', '06', '06203', '9970626', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '松沢', 'マツザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市藤沢', '06', '06203', '9970751', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '藤沢', 'フジサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市湯田川', '06', '06203', '9970752', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '湯田川', 'ユタガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市田川', '06', '06203', '9970753', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '田川', 'タガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市少連寺', '06', '06203', '9970754', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '少連寺', 'ショウレンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市砂谷', '06', '06203', '9970755', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '砂谷', 'イサゴダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市東目', '06', '06203', '9970756', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '東目', 'ヒガシメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市坂野下', '06', '06203', '9970757', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '坂野下', 'サカノシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市関根', '06', '06203', '9970758', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '関根', 'セキネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市東原町', '06', '06203', '9970801', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '東原町', 'ヒガシハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市伊勢原町', '06', '06203', '9970802', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '伊勢原町', 'イセハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市伊勢横内', '06', '06203', '9970803', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '伊勢横内', 'イセヨコウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市斎藤川原', '06', '06203', '9970804', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '斎藤川原', 'サイトウガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市我老林', '06', '06203', '9970805', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '我老林', 'ガロウバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市遠賀原', '06', '06203', '9970806', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '遠賀原', 'オガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145586', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市八ツ興屋', '06', '06203', '9970807', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '八ツ興屋', 'ヤツゴウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145587', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市苗津', '06', '06203', '9970808', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '苗津', 'ナエヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145588', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市苗津町', '06', '06203', '9970809', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '苗津町', 'ナエヅマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145589', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市神明町', '06', '06203', '9970811', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '神明町', 'シンメイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145590', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市長者町', '06', '06203', '9970812', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '長者町', 'チョウジャマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145591', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市千石町', '06', '06203', '9970813', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '千石町', 'センゴクマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145592', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市城南町', '06', '06203', '9970814', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '城南町', 'ジョウナンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145593', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市外内島', '06', '06203', '9970815', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '外内島', 'トノジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145594', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市文園町', '06', '06203', '9970816', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '文園町', 'フミゾノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145595', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市睦町', '06', '06203', '9970817', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '睦町', 'ムツミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145596', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市三和町', '06', '06203', '9970818', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '三和町', 'ミワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145597', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市のぞみ町', '06', '06203', '9970819', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', 'のぞみ町', 'ノゾミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145598', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市三光町', '06', '06203', '9970821', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '三光町', 'サンコウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145599', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市双葉町', '06', '06203', '9970822', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '双葉町', 'フタバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145600', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市海老島町', '06', '06203', '9970823', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '海老島町', 'エビジママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145601', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市日枝', '06', '06203', '9970824', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '日枝', 'ヒエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145602', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市小真木原町', '06', '06203', '9970825', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '小真木原町', 'コマギハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145603', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市美原町', '06', '06203', '9970826', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '美原町', 'ミハラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145604', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市陽光町', '06', '06203', '9970827', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '陽光町', 'ヨウコウマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145605', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市大西町', '06', '06203', '9970831', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '大西町', 'オオニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145606', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市青柳町', '06', '06203', '9970832', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '青柳町', 'アオヤギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145607', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市柳田', '06', '06203', '9970833', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '柳田', 'ヤナギダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145608', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市稲生', '06', '06203', '9970834', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '稲生', 'イナオイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145609', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市番田', '06', '06203', '9970835', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '番田', 'バンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145610', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市寺田', '06', '06203', '9970836', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '寺田', 'テラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145611', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市道田町', '06', '06203', '9970837', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '道田町', 'ミチダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145612', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市淀川町', '06', '06203', '9970838', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '淀川町', 'ヨドカワマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145613', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市砂田町', '06', '06203', '9970839', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '砂田町', 'スナダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145614', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市白山', '06', '06203', '9970841', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '白山', 'シラヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145615', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市井岡', '06', '06203', '9970842', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '井岡', 'イノオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145616', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市岡山', '06', '06203', '9970843', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '岡山', 'オカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145617', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市森片', '06', '06203', '9970844', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '森片', 'モリカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145618', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市下清水', '06', '06203', '9970845', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '下清水', 'シモシミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145619', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市中清水', '06', '06203', '9970846', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '中清水', 'ナカシミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145620', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市上清水', '06', '06203', '9970847', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '上清水', 'カミシミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145621', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市清水新田', '06', '06203', '9970848', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '清水新田', 'シミズシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145622', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市布目', '06', '06203', '9970851', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '布目', 'ヌノメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145623', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市新斎部', '06', '06203', '9970852', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '新斎部', 'シンサイブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145624', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市小淀川', '06', '06203', '9970853', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '小淀川', 'コヨドカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145625', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市大淀川', '06', '06203', '9970854', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '大淀川', 'オオヨドカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145626', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市矢馳', '06', '06203', '9970855', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '矢馳', 'ヤバセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145627', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市山田', '06', '06203', '9970856', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '山田', 'ヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145628', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市美咲町', '06', '06203', '9970857', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '美咲町', 'ミサキマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145629', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市桜新町', '06', '06203', '9970861', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '桜新町', 'サクラシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145630', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市ほなみ町', '06', '06203', '9970862', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', 'ほなみ町', 'ホナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145631', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市茨新田', '06', '06203', '9971111', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '茨新田', 'バラシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145632', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市西沼', '06', '06203', '9971112', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '西沼', 'ニシヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145633', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市長崎', '06', '06203', '9971113', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '長崎', 'ナガサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145634', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市千安京田', '06', '06203', '9971114', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '千安京田', 'チヤスキョウデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145635', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市辻興屋', '06', '06203', '9971115', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '辻興屋', 'ツジコウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145636', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市面野山', '06', '06203', '9971116', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '面野山', 'オモノヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145637', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市下川', '06', '06203', '9971117', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '下川', 'シモガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145638', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市大山', '06', '06203', '9971121', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '大山', 'オオヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145639', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市友江', '06', '06203', '9971122', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '友江', 'トモエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145640', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市友江町', '06', '06203', '9971123', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '友江町', 'トモエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145641', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市大山', '06', '06203', '9971124', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '大山', 'オオヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145642', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市馬町', '06', '06203', '9971125', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '馬町', 'ウママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145643', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市菱津', '06', '06203', '9971131', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '菱津', 'ヒシヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145644', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市栃屋', '06', '06203', '9971132', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '栃屋', 'トチヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145645', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市下興屋', '06', '06203', '9971133', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '下興屋', 'シモコウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145646', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市下小中', '06', '06203', '9971134', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '下小中', 'シモコナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145647', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市中楯', '06', '06203', '9971135', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '中楯', 'ナカダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145648', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市平成町', '06', '06203', '9971156', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '平成町', 'ヘイセイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145649', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市湯野浜', '06', '06203', '9971201', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '湯野浜', 'ユノハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145650', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市宮沢', '06', '06203', '9971202', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '宮沢', 'ミヤザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145651', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市金沢', '06', '06203', '9971203', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '金沢', 'カネザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145652', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市加茂', '06', '06203', '9971204', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '加茂', 'カモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145653', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市油戸', '06', '06203', '9971205', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '油戸', 'アブラト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145654', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市今泉', '06', '06203', '9971206', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '今泉', 'イマイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145655', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東田川郡三川町', '06', '06426', '9971300', '山形県', 'ヤマガタケン', '東田川郡三川町', 'ヒガシタガワグンミカワマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('145656', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東田川郡三川町横山', '06', '06426', '9971301', '山形県', 'ヤマガタケン', '東田川郡三川町', 'ヒガシタガワグンミカワマチ', '横山', 'ヨコヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145657', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東田川郡三川町青山', '06', '06426', '9971311', '山形県', 'ヤマガタケン', '東田川郡三川町', 'ヒガシタガワグンミカワマチ', '青山', 'アオヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145658', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東田川郡三川町善阿弥', '06', '06426', '9971312', '山形県', 'ヤマガタケン', '東田川郡三川町', 'ヒガシタガワグンミカワマチ', '善阿弥', 'ゼンナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145659', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東田川郡三川町角田二口', '06', '06426', '9971313', '山形県', 'ヤマガタケン', '東田川郡三川町', 'ヒガシタガワグンミカワマチ', '角田二口', 'カクタフタクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145660', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東田川郡三川町東沼', '06', '06426', '9971314', '山形県', 'ヤマガタケン', '東田川郡三川町', 'ヒガシタガワグンミカワマチ', '東沼', 'ヒガシヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145661', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東田川郡三川町神花', '06', '06426', '9971315', '山形県', 'ヤマガタケン', '東田川郡三川町', 'ヒガシタガワグンミカワマチ', '神花', 'カンバナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145662', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東田川郡三川町猪子', '06', '06426', '9971316', '山形県', 'ヤマガタケン', '東田川郡三川町', 'ヒガシタガワグンミカワマチ', '猪子', 'イノコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145663', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東田川郡三川町成田新田', '06', '06426', '9971317', '山形県', 'ヤマガタケン', '東田川郡三川町', 'ヒガシタガワグンミカワマチ', '成田新田', 'ナリタシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145664', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東田川郡三川町押切新田', '06', '06426', '9971321', '山形県', 'ヤマガタケン', '東田川郡三川町', 'ヒガシタガワグンミカワマチ', '押切新田', 'オシキリシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145665', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東田川郡三川町土口', '06', '06426', '9971322', '山形県', 'ヤマガタケン', '東田川郡三川町', 'ヒガシタガワグンミカワマチ', '土口', 'ドグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145666', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東田川郡三川町助川', '06', '06426', '9971331', '山形県', 'ヤマガタケン', '東田川郡三川町', 'ヒガシタガワグンミカワマチ', '助川', 'スケカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145667', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東田川郡三川町堤野', '06', '06426', '9971332', '山形県', 'ヤマガタケン', '東田川郡三川町', 'ヒガシタガワグンミカワマチ', '堤野', 'ツツミノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145668', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東田川郡三川町横内', '06', '06426', '9971333', '山形県', 'ヤマガタケン', '東田川郡三川町', 'ヒガシタガワグンミカワマチ', '横内', 'ヨコウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145669', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東田川郡三川町竹原田', '06', '06426', '9971334', '山形県', 'ヤマガタケン', '東田川郡三川町', 'ヒガシタガワグンミカワマチ', '竹原田', 'タケハラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145670', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東田川郡三川町菱沼', '06', '06426', '9971335', '山形県', 'ヤマガタケン', '東田川郡三川町', 'ヒガシタガワグンミカワマチ', '菱沼', 'ヒシヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145671', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東田川郡三川町加藤', '06', '06426', '9971336', '山形県', 'ヤマガタケン', '東田川郡三川町', 'ヒガシタガワグンミカワマチ', '加藤', 'カトウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145672', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東田川郡三川町小尺', '06', '06426', '9971337', '山形県', 'ヤマガタケン', '東田川郡三川町', 'ヒガシタガワグンミカワマチ', '小尺', 'ショウシャク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145673', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東田川郡三川町横川', '06', '06426', '9971338', '山形県', 'ヤマガタケン', '東田川郡三川町', 'ヒガシタガワグンミカワマチ', '横川', 'ヨコカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145674', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東田川郡三川町横川新田', '06', '06426', '9971339', '山形県', 'ヤマガタケン', '東田川郡三川町', 'ヒガシタガワグンミカワマチ', '横川新田', 'ヨコカワシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145689', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市', '06', '06204', '9980000', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('145690', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市穂積', '06', '06204', '9980001', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '穂積', 'ホヅミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145691', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市藤塚', '06', '06204', '9980002', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '藤塚', 'フジツカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145692', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市酒井新田', '06', '06204', '9980003', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '酒井新田', 'サカイシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145693', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市豊里', '06', '06204', '9980004', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '豊里', 'トヨサト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145694', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市宮海', '06', '06204', '9980005', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '宮海', 'ミヤウミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145695', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市ゆたか', '06', '06204', '9980006', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', 'ゆたか', 'ユタカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145696', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市上安町', '06', '06204', '9980011', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '上安町', 'カミヤスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145697', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市下安町', '06', '06204', '9980012', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '下安町', 'シモヤスチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145698', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市東泉町', '06', '06204', '9980013', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '東泉町', 'ヒガシイズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145699', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市千日町', '06', '06204', '9980014', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '千日町', 'センニチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145700', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市北千日堂前', '06', '06204', '9980015', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '北千日堂前', 'キタセンニチドウマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145701', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市北千日町', '06', '06204', '9980016', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '北千日町', 'キタセンニチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145702', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市西野町', '06', '06204', '9980017', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '西野町', 'ニシノマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145703', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市泉町', '06', '06204', '9980018', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '泉町', 'イズミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145704', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市旭新町', '06', '06204', '9980021', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '旭新町', 'アサヒシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145705', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市駅東', '06', '06204', '9980022', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '駅東', 'エキヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145706', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市幸町', '06', '06204', '9980023', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145707', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市御成町', '06', '06204', '9980024', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '御成町', 'オナリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145708', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市南千日町', '06', '06204', '9980025', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '南千日町', 'ミナミセンニチチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145709', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市栄町', '06', '06204', '9980026', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '栄町', 'サカエチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145710', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市北今町', '06', '06204', '9980027', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '北今町', 'キタイママチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145711', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市北里町', '06', '06204', '9980028', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '北里町', 'キタザトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145712', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市住吉町', '06', '06204', '9980029', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '住吉町', 'スミヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145713', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市浜田', '06', '06204', '9980031', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '浜田', 'ハマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145714', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市相生町', '06', '06204', '9980032', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '相生町', 'アイオイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145715', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市中央東町', '06', '06204', '9980033', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '中央東町', 'チュウオウヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145716', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市中央西町', '06', '06204', '9980034', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '中央西町', 'チュウオウニシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145717', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市寿町', '06', '06204', '9980035', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '寿町', 'コトブキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145718', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市船場町', '06', '06204', '9980036', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '船場町', 'フナバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145719', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市日吉町', '06', '06204', '9980037', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '日吉町', 'ヒヨシチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145720', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市新井田町', '06', '06204', '9980041', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '新井田町', 'ニイダマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145721', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市上本町', '06', '06204', '9980042', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '上本町', 'カミホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145722', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市本町1丁目', '06', '06204', '9980043', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '本町', 'ホンチョウ', '（－チョウ）', null, '1丁目', '01チョウメ');
INSERT INTO `ms_addresses` VALUES ('145723', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市本町2丁目', '06', '06204', '9980043', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '本町', 'ホンチョウ', '（－チョウ）', null, '2丁目', '02チョウメ');
INSERT INTO `ms_addresses` VALUES ('145724', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市本町3丁目', '06', '06204', '9980043', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '本町', 'ホンチョウ', '（－チョウ）', null, '3丁目', '03チョウメ');
INSERT INTO `ms_addresses` VALUES ('145725', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市中町', '06', '06204', '9980044', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '中町', 'ナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145726', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市二番町', '06', '06204', '9980045', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '二番町', 'ニバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145727', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市一番町', '06', '06204', '9980046', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '一番町', 'イチバンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145728', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市高見台', '06', '06204', '9980051', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '高見台', 'タカミダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145729', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市緑ケ丘', '06', '06204', '9980052', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '緑ケ丘', 'ミドリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145730', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市若宮町', '06', '06204', '9980053', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '若宮町', 'ワカミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145731', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市宮野浦', '06', '06204', '9980054', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '宮野浦', 'ミヤノウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145732', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市飯森山', '06', '06204', '9980055', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '飯森山', 'イイモリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145733', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市光ケ丘', '06', '06204', '9980061', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '光ケ丘', 'ヒカリガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145734', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市北新町', '06', '06204', '9980062', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '北新町', 'キタシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145735', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市南新町', '06', '06204', '9980063', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '南新町', 'ミナミシンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145736', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市大浜', '06', '06204', '9980064', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '大浜', 'オオハマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145737', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市古湊町', '06', '06204', '9980071', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '古湊町', 'コミナトチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145738', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市北浜町', '06', '06204', '9980072', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '北浜町', 'キタハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145739', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市松美町', '06', '06204', '9980073', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '松美町', 'マツミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145740', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市浜松町', '06', '06204', '9980074', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '浜松町', 'ハママツチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145741', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市高砂', '06', '06204', '9980075', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '高砂', 'タカサゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145742', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市坂野辺新田', '06', '06204', '9980101', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '坂野辺新田', 'サカノベシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145743', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市京田', '06', '06204', '9980102', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '京田', 'キョウデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145744', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市錦町', '06', '06204', '9980103', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '錦町', 'ニシキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145745', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市広栄町', '06', '06204', '9980104', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '広栄町', 'コウエイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145746', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市広野新田', '06', '06204', '9980105', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '広野新田', 'ヒロノシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145747', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市黒森', '06', '06204', '9980111', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '黒森', 'クロモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145748', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市浜中', '06', '06204', '9980112', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '浜中', 'ハマナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145749', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市広岡新田', '06', '06204', '9980113', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '広岡新田', 'ヒロオカシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145750', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市十里塚', '06', '06204', '9980114', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '十里塚', 'ジュウリヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145751', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市広野', '06', '06204', '9980125', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '広野', 'ヒロノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145754', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市飛島', '06', '06204', '9980281', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '飛島', 'トビシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145755', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市北沢', '06', '06204', '9980801', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '北沢', 'キタザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145756', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市生石', '06', '06204', '9980802', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '生石', 'オイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145757', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市大槻新田', '06', '06204', '9980803', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '大槻新田', 'オオツキシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145758', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市横代', '06', '06204', '9980804', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '横代', 'ヨコダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145759', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市関', '06', '06204', '9980805', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '関', 'セキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145760', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市境興野', '06', '06204', '9980806', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '境興野', 'サカイコウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145761', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市手蔵田', '06', '06204', '9980811', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '手蔵田', 'テグラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145762', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市本川', '06', '06204', '9980812', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '本川', 'ホンガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145763', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市茨野新田', '06', '06204', '9980813', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '茨野新田', 'バラノシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145764', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市小牧新田', '06', '06204', '9980814', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '小牧新田', 'コマギシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145765', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市小牧', '06', '06204', '9980815', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '小牧', 'コマギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145766', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市大野新田', '06', '06204', '9980816', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '大野新田', 'オオノシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145767', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市熊手島', '06', '06204', '9980817', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '熊手島', 'クマテジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145768', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市勝保関', '06', '06204', '9980818', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '勝保関', 'ガツボゼキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145769', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市熊野田', '06', '06204', '9980819', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '熊野田', 'クマノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145770', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市遊摺部', '06', '06204', '9980821', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '遊摺部', 'ユスルベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145771', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市大宮', '06', '06204', '9980822', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '大宮', 'オオミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145772', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市卸町', '06', '06204', '9980823', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '卸町', 'オロシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145773', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市大宮町', '06', '06204', '9980824', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '大宮町', 'オオミヤチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145774', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市初瀬', '06', '06204', '9980826', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '初瀬', 'ハツセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145775', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市草刈谷地', '06', '06204', '9980827', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '草刈谷地', 'クサカリヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145776', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市あきほ町', '06', '06204', '9980828', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', 'あきほ町', 'アキホチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145777', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市仁助谷地', '06', '06204', '9980829', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '仁助谷地', 'ニスケヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145778', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市東両羽町', '06', '06204', '9980831', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '東両羽町', 'ヒガシリョウウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145779', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市両羽町', '06', '06204', '9980832', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '両羽町', 'リョウウチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145780', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市若原町', '06', '06204', '9980833', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '若原町', 'ワカハラチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145781', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市若竹町', '06', '06204', '9980834', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '若竹町', 'ワカタケチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145782', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市堤町', '06', '06204', '9980835', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '堤町', 'ツツミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145783', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市入船町', '06', '06204', '9980836', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '入船町', 'イリフネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145784', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市下瀬', '06', '06204', '9980837', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '下瀬', 'シタセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145785', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市山居町', '06', '06204', '9980838', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '山居町', 'サンキョマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145786', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市松原南', '06', '06204', '9980841', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '松原南', 'マツバラミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145787', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市亀ケ崎', '06', '06204', '9980842', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '亀ケ崎', 'カメガサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145788', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市千石町', '06', '06204', '9980843', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '千石町', 'センゴクチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145789', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市東大町', '06', '06204', '9980851', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '東大町', 'ヒガシオオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145790', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市こがね町', '06', '06204', '9980852', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', 'こがね町', 'コガネチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145791', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市みずほ', '06', '06204', '9980853', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', 'みずほ', 'ミズホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145792', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市末広町', '06', '06204', '9980854', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '末広町', 'スエヒロチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145793', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市東中の口町', '06', '06204', '9980855', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '東中の口町', 'ヒガシナカノクチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145794', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市東栄町', '06', '06204', '9980856', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '東栄町', 'トウエイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145795', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市若浜町', '06', '06204', '9980857', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '若浜町', 'ワカハマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145796', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市緑町', '06', '06204', '9980858', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '緑町', 'ミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145797', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市大町', '06', '06204', '9980859', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '大町', 'オオマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145798', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市富士見町', '06', '06204', '9980861', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '富士見町', 'フジミチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145799', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市曙町', '06', '06204', '9980862', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '曙町', 'アケボノチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145800', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市日の出町', '06', '06204', '9980863', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '日の出町', 'ヒノデチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145801', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市新橋', '06', '06204', '9980864', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '新橋', 'シンバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145802', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市北新橋', '06', '06204', '9980865', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '北新橋', 'キタシンバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145803', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市荻島', '06', '06204', '9980871', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '荻島', 'オギジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145804', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市中野新田', '06', '06204', '9980872', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '中野新田', 'ナカノシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145805', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市土崎', '06', '06204', '9980873', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '土崎', 'ツチザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145806', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市四ツ興野', '06', '06204', '9980874', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '四ツ興野', 'ヨツゴヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145807', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市東町', '06', '06204', '9980875', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '東町', 'アズマチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145808', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市古荒新田', '06', '06204', '9980876', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '古荒新田', 'コアラシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145809', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市大多新田', '06', '06204', '9980877', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '大多新田', 'オオタシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145810', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市こあら', '06', '06204', '9980878', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', 'こあら', 'コアラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145824', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東置賜郡川西町', '06', '06382', '9990100', '山形県', 'ヤマガタケン', '東置賜郡川西町', 'ヒガシオキタマグンカワニシマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('145825', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東置賜郡川西町上小松', '06', '06382', '9990121', '山形県', 'ヤマガタケン', '東置賜郡川西町', 'ヒガシオキタマグンカワニシマチ', '上小松', 'カミコマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145826', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東置賜郡川西町中小松', '06', '06382', '9990122', '山形県', 'ヤマガタケン', '東置賜郡川西町', 'ヒガシオキタマグンカワニシマチ', '中小松', 'ナカコマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145827', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東置賜郡川西町黒川', '06', '06382', '9990131', '山形県', 'ヤマガタケン', '東置賜郡川西町', 'ヒガシオキタマグンカワニシマチ', '黒川', 'クロカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145828', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東置賜郡川西町高豆蒄', '06', '06382', '9990132', '山形県', 'ヤマガタケン', '東置賜郡川西町', 'ヒガシオキタマグンカワニシマチ', '高豆蒄', 'コウヅク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145829', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東置賜郡川西町小松', '06', '06382', '9990133', '山形県', 'ヤマガタケン', '東置賜郡川西町', 'ヒガシオキタマグンカワニシマチ', '小松', 'コマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145830', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東置賜郡川西町下小松', '06', '06382', '9990134', '山形県', 'ヤマガタケン', '東置賜郡川西町', 'ヒガシオキタマグンカワニシマチ', '下小松', 'シモコマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145831', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東置賜郡川西町高山', '06', '06382', '9990141', '山形県', 'ヤマガタケン', '東置賜郡川西町', 'ヒガシオキタマグンカワニシマチ', '高山', 'タカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145832', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東置賜郡川西町堀金', '06', '06382', '9990142', '山形県', 'ヤマガタケン', '東置賜郡川西町', 'ヒガシオキタマグンカワニシマチ', '堀金', 'ホリガネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145833', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東置賜郡川西町莅', '06', '06382', '9990143', '山形県', 'ヤマガタケン', '東置賜郡川西町', 'ヒガシオキタマグンカワニシマチ', '莅', 'ノゾキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145834', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東置賜郡川西町時田', '06', '06382', '9990144', '山形県', 'ヤマガタケン', '東置賜郡川西町', 'ヒガシオキタマグンカワニシマチ', '時田', 'トキダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145835', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東置賜郡川西町下奥田', '06', '06382', '9990145', '山形県', 'ヤマガタケン', '東置賜郡川西町', 'ヒガシオキタマグンカワニシマチ', '下奥田', 'シモオクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145836', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東置賜郡川西町大舟', '06', '06382', '9990151', '山形県', 'ヤマガタケン', '東置賜郡川西町', 'ヒガシオキタマグンカワニシマチ', '大舟', 'オオブネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145837', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東置賜郡川西町上奥田', '06', '06382', '9990152', '山形県', 'ヤマガタケン', '東置賜郡川西町', 'ヒガシオキタマグンカワニシマチ', '上奥田', 'カミオクダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145838', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東置賜郡川西町朴沢', '06', '06382', '9990153', '山形県', 'ヤマガタケン', '東置賜郡川西町', 'ヒガシオキタマグンカワニシマチ', '朴沢', 'ホオノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145841', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東置賜郡川西町洲島', '06', '06382', '9990211', '山形県', 'ヤマガタケン', '東置賜郡川西町', 'ヒガシオキタマグンカワニシマチ', '洲島', 'スノシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145842', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東置賜郡川西町下平柳', '06', '06382', '9990212', '山形県', 'ヤマガタケン', '東置賜郡川西町', 'ヒガシオキタマグンカワニシマチ', '下平柳', 'シモヒラヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145843', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東置賜郡川西町尾長島', '06', '06382', '9990213', '山形県', 'ヤマガタケン', '東置賜郡川西町', 'ヒガシオキタマグンカワニシマチ', '尾長島', 'オナガシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145844', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東置賜郡川西町吉田', '06', '06382', '9990214', '山形県', 'ヤマガタケン', '東置賜郡川西町', 'ヒガシオキタマグンカワニシマチ', '吉田', 'ヨシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145845', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東置賜郡川西町玉庭', '06', '06382', '9990361', '山形県', 'ヤマガタケン', '東置賜郡川西町', 'ヒガシオキタマグンカワニシマチ', '玉庭', 'タマニワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145846', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡飯豊町小屋', '06', '06403', '9990421', '山形県', 'ヤマガタケン', '西置賜郡飯豊町', 'ニシオキタマグンイイデマチ', '小屋', 'コヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145847', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡飯豊町広河原', '06', '06403', '9990422', '山形県', 'ヤマガタケン', '西置賜郡飯豊町', 'ニシオキタマグンイイデマチ', '広河原', 'ヒロカワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145848', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡飯豊町須郷', '06', '06403', '9990423', '山形県', 'ヤマガタケン', '西置賜郡飯豊町', 'ニシオキタマグンイイデマチ', '須郷', 'スゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145849', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡飯豊町数馬', '06', '06403', '9990424', '山形県', 'ヤマガタケン', '西置賜郡飯豊町', 'ニシオキタマグンイイデマチ', '数馬', 'カズマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145850', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡飯豊町宇津沢', '06', '06403', '9990425', '山形県', 'ヤマガタケン', '西置賜郡飯豊町', 'ニシオキタマグンイイデマチ', '宇津沢', 'ウツサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145851', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡飯豊町遅谷', '06', '06403', '9990426', '山形県', 'ヤマガタケン', '西置賜郡飯豊町', 'ニシオキタマグンイイデマチ', '遅谷', 'オソダニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145852', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡飯豊町上原', '06', '06403', '9990427', '山形県', 'ヤマガタケン', '西置賜郡飯豊町', 'ニシオキタマグンイイデマチ', '上原', 'ウワバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145853', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡飯豊町下屋地', '06', '06403', '9990431', '山形県', 'ヤマガタケン', '西置賜郡飯豊町', 'ニシオキタマグンイイデマチ', '下屋地', 'シモヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145854', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡飯豊町白川', '06', '06403', '9990432', '山形県', 'ヤマガタケン', '西置賜郡飯豊町', 'ニシオキタマグンイイデマチ', '白川', 'シラカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145855', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡飯豊町上屋地', '06', '06403', '9990433', '山形県', 'ヤマガタケン', '西置賜郡飯豊町', 'ニシオキタマグンイイデマチ', '上屋地', 'カミヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145856', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡飯豊町川内戸', '06', '06403', '9990434', '山形県', 'ヤマガタケン', '西置賜郡飯豊町', 'ニシオキタマグンイイデマチ', '川内戸', 'カワナイド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145857', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡飯豊町高造路', '06', '06403', '9990435', '山形県', 'ヤマガタケン', '西置賜郡飯豊町', 'ニシオキタマグンイイデマチ', '高造路', 'タカゾウロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145858', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡飯豊町岩倉', '06', '06403', '9990436', '山形県', 'ヤマガタケン', '西置賜郡飯豊町', 'ニシオキタマグンイイデマチ', '岩倉', 'イワクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145859', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡飯豊町', '06', '06403', '9990600', '山形県', 'ヤマガタケン', '西置賜郡飯豊町', 'ニシオキタマグンイイデマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('145860', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡飯豊町中', '06', '06403', '9990601', '山形県', 'ヤマガタケン', '西置賜郡飯豊町', 'ニシオキタマグンイイデマチ', '中', 'ナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145861', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡飯豊町萩生', '06', '06403', '9990602', '山形県', 'ヤマガタケン', '西置賜郡飯豊町', 'ニシオキタマグンイイデマチ', '萩生', 'ハギュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145862', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡飯豊町黒沢', '06', '06403', '9990603', '山形県', 'ヤマガタケン', '西置賜郡飯豊町', 'ニシオキタマグンイイデマチ', '黒沢', 'クロサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145863', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡飯豊町椿', '06', '06403', '9990604', '山形県', 'ヤマガタケン', '西置賜郡飯豊町', 'ニシオキタマグンイイデマチ', '椿', 'ツバキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145864', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡飯豊町添川', '06', '06403', '9990605', '山形県', 'ヤマガタケン', '西置賜郡飯豊町', 'ニシオキタマグンイイデマチ', '添川', 'ソエガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145865', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡飯豊町松原', '06', '06403', '9990606', '山形県', 'ヤマガタケン', '西置賜郡飯豊町', 'ニシオキタマグンイイデマチ', '松原', 'マツバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145867', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡飯豊町手ノ子', '06', '06403', '9991111', '山形県', 'ヤマガタケン', '西置賜郡飯豊町', 'ニシオキタマグンイイデマチ', '手ノ子', 'テノコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145868', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡飯豊町高峰', '06', '06403', '9991112', '山形県', 'ヤマガタケン', '西置賜郡飯豊町', 'ニシオキタマグンイイデマチ', '高峰', 'タカミネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145869', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡飯豊町小白川', '06', '06403', '9991113', '山形県', 'ヤマガタケン', '西置賜郡飯豊町', 'ニシオキタマグンイイデマチ', '小白川', 'コジラカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145870', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡小国町沼沢', '06', '06401', '9991201', '山形県', 'ヤマガタケン', '西置賜郡小国町', 'ニシオキタマグンオグニマチ', '沼沢', 'ヌマザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145871', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡小国町白子沢', '06', '06401', '9991202', '山形県', 'ヤマガタケン', '西置賜郡小国町', 'ニシオキタマグンオグニマチ', '白子沢', 'シラコザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145872', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡小国町市野々', '06', '06401', '9991203', '山形県', 'ヤマガタケン', '西置賜郡小国町', 'ニシオキタマグンオグニマチ', '市野々', 'イチノノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145873', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡小国町叶水', '06', '06401', '9991211', '山形県', 'ヤマガタケン', '西置賜郡小国町', 'ニシオキタマグンオグニマチ', '叶水', 'カノミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145874', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡小国町大石沢', '06', '06401', '9991212', '山形県', 'ヤマガタケン', '西置賜郡小国町', 'ニシオキタマグンオグニマチ', '大石沢', 'オオイシザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145875', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡小国町新股', '06', '06401', '9991213', '山形県', 'ヤマガタケン', '西置賜郡小国町', 'ニシオキタマグンオグニマチ', '新股', 'アラマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145876', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡小国町河原角', '06', '06401', '9991214', '山形県', 'ヤマガタケン', '西置賜郡小国町', 'ニシオキタマグンオグニマチ', '河原角', 'カワラヅノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145877', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡小国町西滝', '06', '06401', '9991215', '山形県', 'ヤマガタケン', '西置賜郡小国町', 'ニシオキタマグンオグニマチ', '西滝', 'ニシダキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145878', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡小国町東滝', '06', '06401', '9991216', '山形県', 'ヤマガタケン', '西置賜郡小国町', 'ニシオキタマグンオグニマチ', '東滝', 'ヒガシダキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145880', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡小国町', '06', '06401', '9991300', '山形県', 'ヤマガタケン', '西置賜郡小国町', 'ニシオキタマグンオグニマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('145881', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡小国町金目', '06', '06401', '9991301', '山形県', 'ヤマガタケン', '西置賜郡小国町', 'ニシオキタマグンオグニマチ', '金目', 'カナメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145882', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡小国町古田', '06', '06401', '9991302', '山形県', 'ヤマガタケン', '西置賜郡小国町', 'ニシオキタマグンオグニマチ', '古田', 'フルタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145883', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡小国町若山', '06', '06401', '9991303', '山形県', 'ヤマガタケン', '西置賜郡小国町', 'ニシオキタマグンオグニマチ', '若山', 'ワカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145884', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡小国町貝少', '06', '06401', '9991311', '山形県', 'ヤマガタケン', '西置賜郡小国町', 'ニシオキタマグンオグニマチ', '貝少', 'カイショウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145885', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡小国町小渡', '06', '06401', '9991312', '山形県', 'ヤマガタケン', '西置賜郡小国町', 'ニシオキタマグンオグニマチ', '小渡', 'オド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145886', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡小国町針生', '06', '06401', '9991313', '山形県', 'ヤマガタケン', '西置賜郡小国町', 'ニシオキタマグンオグニマチ', '針生', 'ハリウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145887', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡小国町新屋敷', '06', '06401', '9991314', '山形県', 'ヤマガタケン', '西置賜郡小国町', 'ニシオキタマグンオグニマチ', '新屋敷', 'シンヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145888', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡小国町綱木箱口', '06', '06401', '9991321', '山形県', 'ヤマガタケン', '西置賜郡小国町', 'ニシオキタマグンオグニマチ', '綱木箱口', 'ツナギハコノグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145889', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡小国町伊佐領', '06', '06401', '9991322', '山形県', 'ヤマガタケン', '西置賜郡小国町', 'ニシオキタマグンオグニマチ', '伊佐領', 'イサリョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145890', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡小国町朝篠', '06', '06401', '9991323', '山形県', 'ヤマガタケン', '西置賜郡小国町', 'ニシオキタマグンオグニマチ', '朝篠', 'アザシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145891', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡小国町松岡', '06', '06401', '9991324', '山形県', 'ヤマガタケン', '西置賜郡小国町', 'ニシオキタマグンオグニマチ', '松岡', 'マツオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145892', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡小国町東原', '06', '06401', '9991331', '山形県', 'ヤマガタケン', '西置賜郡小国町', 'ニシオキタマグンオグニマチ', '東原', 'ヒガシハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145893', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡小国町町原', '06', '06401', '9991332', '山形県', 'ヤマガタケン', '西置賜郡小国町', 'ニシオキタマグンオグニマチ', '町原', 'マチバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145894', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡小国町芹出', '06', '06401', '9991333', '山形県', 'ヤマガタケン', '西置賜郡小国町', 'ニシオキタマグンオグニマチ', '芹出', 'セリデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145895', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡小国町黒沢', '06', '06401', '9991334', '山形県', 'ヤマガタケン', '西置賜郡小国町', 'ニシオキタマグンオグニマチ', '黒沢', 'クロサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145896', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡小国町種沢', '06', '06401', '9991335', '山形県', 'ヤマガタケン', '西置賜郡小国町', 'ニシオキタマグンオグニマチ', '種沢', 'タネザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145897', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡小国町大滝', '06', '06401', '9991336', '山形県', 'ヤマガタケン', '西置賜郡小国町', 'ニシオキタマグンオグニマチ', '大滝', 'オオタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145898', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡小国町新原', '06', '06401', '9991337', '山形県', 'ヤマガタケン', '西置賜郡小国町', 'ニシオキタマグンオグニマチ', '新原', 'シンバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145899', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡小国町杉沢', '06', '06401', '9991338', '山形県', 'ヤマガタケン', '西置賜郡小国町', 'ニシオキタマグンオグニマチ', '杉沢', 'スギサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145900', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡小国町小倉', '06', '06401', '9991339', '山形県', 'ヤマガタケン', '西置賜郡小国町', 'ニシオキタマグンオグニマチ', '小倉', 'コグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145901', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡小国町増岡', '06', '06401', '9991341', '山形県', 'ヤマガタケン', '西置賜郡小国町', 'ニシオキタマグンオグニマチ', '増岡', 'マスオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145902', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡小国町大宮', '06', '06401', '9991342', '山形県', 'ヤマガタケン', '西置賜郡小国町', 'ニシオキタマグンオグニマチ', '大宮', 'オオミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145903', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡小国町宮の台', '06', '06401', '9991343', '山形県', 'ヤマガタケン', '西置賜郡小国町', 'ニシオキタマグンオグニマチ', '宮の台', 'ミヤノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145904', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡小国町田沢頭', '06', '06401', '9991344', '山形県', 'ヤマガタケン', '西置賜郡小国町', 'ニシオキタマグンオグニマチ', '田沢頭', 'タザワガシラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145905', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡小国町北', '06', '06401', '9991345', '山形県', 'ヤマガタケン', '西置賜郡小国町', 'ニシオキタマグンオグニマチ', '北', 'キタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145906', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡小国町湯ノ花', '06', '06401', '9991346', '山形県', 'ヤマガタケン', '西置賜郡小国町', 'ニシオキタマグンオグニマチ', '湯ノ花', 'ユノハナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145907', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡小国町小国町', '06', '06401', '9991351', '山形県', 'ヤマガタケン', '西置賜郡小国町', 'ニシオキタマグンオグニマチ', '小国町', 'オグニマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145908', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡小国町岩井沢', '06', '06401', '9991352', '山形県', 'ヤマガタケン', '西置賜郡小国町', 'ニシオキタマグンオグニマチ', '岩井沢', 'イワイザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145909', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡小国町兵庫舘', '06', '06401', '9991353', '山形県', 'ヤマガタケン', '西置賜郡小国町', 'ニシオキタマグンオグニマチ', '兵庫舘', 'ヒョウゴダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145910', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡小国町幸町', '06', '06401', '9991354', '山形県', 'ヤマガタケン', '西置賜郡小国町', 'ニシオキタマグンオグニマチ', '幸町', 'サイワイチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145911', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡小国町西', '06', '06401', '9991355', '山形県', 'ヤマガタケン', '西置賜郡小国町', 'ニシオキタマグンオグニマチ', '西', 'ニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145912', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡小国町あけぼの', '06', '06401', '9991356', '山形県', 'ヤマガタケン', '西置賜郡小国町', 'ニシオキタマグンオグニマチ', 'あけぼの', 'アケボノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145913', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡小国町栄町', '06', '06401', '9991361', '山形県', 'ヤマガタケン', '西置賜郡小国町', 'ニシオキタマグンオグニマチ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145914', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡小国町緑町', '06', '06401', '9991362', '山形県', 'ヤマガタケン', '西置賜郡小国町', 'ニシオキタマグンオグニマチ', '緑町', 'ミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145915', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡小国町小国小坂町', '06', '06401', '9991363', '山形県', 'ヤマガタケン', '西置賜郡小国町', 'ニシオキタマグンオグニマチ', '小国小坂町', 'オグニコサカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145916', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡小国町舟渡', '06', '06401', '9991401', '山形県', 'ヤマガタケン', '西置賜郡小国町', 'ニシオキタマグンオグニマチ', '舟渡', 'フナト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145917', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡小国町網代瀬', '06', '06401', '9991402', '山形県', 'ヤマガタケン', '西置賜郡小国町', 'ニシオキタマグンオグニマチ', '網代瀬', 'アジロセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145918', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡小国町松崎', '06', '06401', '9991411', '山形県', 'ヤマガタケン', '西置賜郡小国町', 'ニシオキタマグンオグニマチ', '松崎', 'マツザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145919', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡小国町尻無沢', '06', '06401', '9991412', '山形県', 'ヤマガタケン', '西置賜郡小国町', 'ニシオキタマグンオグニマチ', '尻無沢', 'シリナシザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145920', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡小国町今市', '06', '06401', '9991413', '山形県', 'ヤマガタケン', '西置賜郡小国町', 'ニシオキタマグンオグニマチ', '今市', 'イマイチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145921', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡小国町栃倉', '06', '06401', '9991414', '山形県', 'ヤマガタケン', '西置賜郡小国町', 'ニシオキタマグンオグニマチ', '栃倉', 'トチグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145922', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡小国町越中里', '06', '06401', '9991421', '山形県', 'ヤマガタケン', '西置賜郡小国町', 'ニシオキタマグンオグニマチ', '越中里', 'エッチュウザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145923', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡小国町長沢', '06', '06401', '9991422', '山形県', 'ヤマガタケン', '西置賜郡小国町', 'ニシオキタマグンオグニマチ', '長沢', 'ナガサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145924', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡小国町焼山', '06', '06401', '9991431', '山形県', 'ヤマガタケン', '西置賜郡小国町', 'ニシオキタマグンオグニマチ', '焼山', 'ヤケヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145925', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡小国町中島', '06', '06401', '9991432', '山形県', 'ヤマガタケン', '西置賜郡小国町', 'ニシオキタマグンオグニマチ', '中島', 'ナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145926', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡小国町樋ノ沢', '06', '06401', '9991433', '山形県', 'ヤマガタケン', '西置賜郡小国町', 'ニシオキタマグンオグニマチ', '樋ノ沢', 'ヒノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145927', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡小国町荒沢', '06', '06401', '9991434', '山形県', 'ヤマガタケン', '西置賜郡小国町', 'ニシオキタマグンオグニマチ', '荒沢', 'アラサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145928', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡小国町入折戸', '06', '06401', '9991435', '山形県', 'ヤマガタケン', '西置賜郡小国町', 'ニシオキタマグンオグニマチ', '入折戸', 'イリオリト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145929', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡小国町折戸', '06', '06401', '9991436', '山形県', 'ヤマガタケン', '西置賜郡小国町', 'ニシオキタマグンオグニマチ', '折戸', 'オリト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145930', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡小国町驚', '06', '06401', '9991441', '山形県', 'ヤマガタケン', '西置賜郡小国町', 'ニシオキタマグンオグニマチ', '驚', 'オドロク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145931', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡小国町太鼓沢', '06', '06401', '9991442', '山形県', 'ヤマガタケン', '西置賜郡小国町', 'ニシオキタマグンオグニマチ', '太鼓沢', 'タイコザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145932', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡小国町小股', '06', '06401', '9991443', '山形県', 'ヤマガタケン', '西置賜郡小国町', 'ニシオキタマグンオグニマチ', '小股', 'オマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145933', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡小国町石滝', '06', '06401', '9991451', '山形県', 'ヤマガタケン', '西置賜郡小国町', 'ニシオキタマグンオグニマチ', '石滝', 'イシダキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145934', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡小国町五味沢', '06', '06401', '9991452', '山形県', 'ヤマガタケン', '西置賜郡小国町', 'ニシオキタマグンオグニマチ', '五味沢', 'ゴミザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145935', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡小国町樽口', '06', '06401', '9991501', '山形県', 'ヤマガタケン', '西置賜郡小国町', 'ニシオキタマグンオグニマチ', '樽口', 'タルグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145936', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡小国町滝倉', '06', '06401', '9991502', '山形県', 'ヤマガタケン', '西置賜郡小国町', 'ニシオキタマグンオグニマチ', '滝倉', 'タキグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145937', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡小国町菅沼', '06', '06401', '9991503', '山形県', 'ヤマガタケン', '西置賜郡小国町', 'ニシオキタマグンオグニマチ', '菅沼', 'スガヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145938', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡小国町足水中里', '06', '06401', '9991504', '山形県', 'ヤマガタケン', '西置賜郡小国町', 'ニシオキタマグンオグニマチ', '足水中里', 'アシミズナカザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145939', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡小国町百子沢', '06', '06401', '9991505', '山形県', 'ヤマガタケン', '西置賜郡小国町', 'ニシオキタマグンオグニマチ', '百子沢', 'ヒャッコザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145940', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡小国町市野沢', '06', '06401', '9991506', '山形県', 'ヤマガタケン', '西置賜郡小国町', 'ニシオキタマグンオグニマチ', '市野沢', 'イチノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145941', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡小国町足野水', '06', '06401', '9991507', '山形県', 'ヤマガタケン', '西置賜郡小国町', 'ニシオキタマグンオグニマチ', '足野水', 'アシノミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145942', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡小国町玉川', '06', '06401', '9991511', '山形県', 'ヤマガタケン', '西置賜郡小国町', 'ニシオキタマグンオグニマチ', '玉川', 'タマガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145943', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡小国町片貝', '06', '06401', '9991512', '山形県', 'ヤマガタケン', '西置賜郡小国町', 'ニシオキタマグンオグニマチ', '片貝', 'カタカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145944', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡小国町中田山崎', '06', '06401', '9991513', '山形県', 'ヤマガタケン', '西置賜郡小国町', 'ニシオキタマグンオグニマチ', '中田山崎', 'ナカダヤマザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145945', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡小国町玉川中里', '06', '06401', '9991514', '山形県', 'ヤマガタケン', '西置賜郡小国町', 'ニシオキタマグンオグニマチ', '玉川中里', 'タマガワナカザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145946', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡小国町泉岡', '06', '06401', '9991521', '山形県', 'ヤマガタケン', '西置賜郡小国町', 'ニシオキタマグンオグニマチ', '泉岡', 'イズミオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145947', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西置賜郡小国町小玉川', '06', '06401', '9991522', '山形県', 'ヤマガタケン', '西置賜郡小国町', 'ニシオキタマグンオグニマチ', '小玉川', 'コタマガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145948', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東置賜郡高畠町石岡', '06', '06381', '9992171', '山形県', 'ヤマガタケン', '東置賜郡高畠町', 'ヒガシオキタマグンタカハタマチ', '石岡', 'イシオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145949', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東置賜郡高畠町夏茂', '06', '06381', '9992172', '山形県', 'ヤマガタケン', '東置賜郡高畠町', 'ヒガシオキタマグンタカハタマチ', '夏茂', 'ナツモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145950', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東置賜郡高畠町山崎', '06', '06381', '9992173', '山形県', 'ヤマガタケン', '東置賜郡高畠町', 'ヒガシオキタマグンタカハタマチ', '山崎', 'ヤマザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145951', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東置賜郡高畠町福沢', '06', '06381', '9992174', '山形県', 'ヤマガタケン', '東置賜郡高畠町', 'ヒガシオキタマグンタカハタマチ', '福沢', 'フクザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145952', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東置賜郡高畠町福沢南', '06', '06381', '9992175', '山形県', 'ヤマガタケン', '東置賜郡高畠町', 'ヒガシオキタマグンタカハタマチ', '福沢南', 'フクザワミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145953', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東置賜郡高畠町糠野目', '06', '06381', '9992176', '山形県', 'ヤマガタケン', '東置賜郡高畠町', 'ヒガシオキタマグンタカハタマチ', '糠野目', 'ヌカノメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145954', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東置賜郡高畠町小其塚', '06', '06381', '9992177', '山形県', 'ヤマガタケン', '東置賜郡高畠町', 'ヒガシオキタマグンタカハタマチ', '小其塚', 'オソノヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145955', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東置賜郡高畠町上平柳', '06', '06381', '9992178', '山形県', 'ヤマガタケン', '東置賜郡高畠町', 'ヒガシオキタマグンタカハタマチ', '上平柳', 'カミヒラヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145956', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東置賜郡高畠町蛇口', '06', '06381', '9992179', '山形県', 'ヤマガタケン', '東置賜郡高畠町', 'ヒガシオキタマグンタカハタマチ', '蛇口', 'ジャグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145957', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県南陽市', '06', '06213', '9992200', '山形県', 'ヤマガタケン', '南陽市', 'ナンヨウシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('145958', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県南陽市釜渡戸', '06', '06213', '9992201', '山形県', 'ヤマガタケン', '南陽市', 'ナンヨウシ', '釜渡戸', 'カマノハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145959', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県南陽市元中山', '06', '06213', '9992202', '山形県', 'ヤマガタケン', '南陽市', 'ナンヨウシ', '元中山', 'モトナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145960', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県南陽市小岩沢', '06', '06213', '9992203', '山形県', 'ヤマガタケン', '南陽市', 'ナンヨウシ', '小岩沢', 'コイワサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145961', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県南陽市川樋', '06', '06213', '9992204', '山形県', 'ヤマガタケン', '南陽市', 'ナンヨウシ', '川樋', 'カワトイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145962', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県南陽市新田', '06', '06213', '9992205', '山形県', 'ヤマガタケン', '南陽市', 'ナンヨウシ', '新田', 'シンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145963', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県南陽市赤湯', '06', '06213', '9992211', '山形県', 'ヤマガタケン', '南陽市', 'ナンヨウシ', '赤湯', 'アカユ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145964', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県南陽市金沢', '06', '06213', '9992212', '山形県', 'ヤマガタケン', '南陽市', 'ナンヨウシ', '金沢', 'カネザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145965', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県南陽市松沢', '06', '06213', '9992213', '山形県', 'ヤマガタケン', '南陽市', 'ナンヨウシ', '松沢', 'マツザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145966', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県南陽市椚塚', '06', '06213', '9992221', '山形県', 'ヤマガタケン', '南陽市', 'ナンヨウシ', '椚塚', 'クヌギヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145967', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県南陽市長岡', '06', '06213', '9992222', '山形県', 'ヤマガタケン', '南陽市', 'ナンヨウシ', '長岡', 'ナガオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145968', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県南陽市俎柳', '06', '06213', '9992223', '山形県', 'ヤマガタケン', '南陽市', 'ナンヨウシ', '俎柳', 'マナイタヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145969', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県南陽市大橋', '06', '06213', '9992224', '山形県', 'ヤマガタケン', '南陽市', 'ナンヨウシ', '大橋', 'オオハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145970', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県南陽市二色根', '06', '06213', '9992231', '山形県', 'ヤマガタケン', '南陽市', 'ナンヨウシ', '二色根', 'ニイロネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145971', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県南陽市三間通', '06', '06213', '9992232', '山形県', 'ヤマガタケン', '南陽市', 'ナンヨウシ', '三間通', 'ミツマドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145972', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県南陽市上野', '06', '06213', '9992233', '山形県', 'ヤマガタケン', '南陽市', 'ナンヨウシ', '上野', 'ワノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145973', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県南陽市中央東', '06', '06213', '9992234', '山形県', 'ヤマガタケン', '南陽市', 'ナンヨウシ', '中央東', 'チュウオウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145974', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県南陽市郡山', '06', '06213', '9992241', '山形県', 'ヤマガタケン', '南陽市', 'ナンヨウシ', '郡山', 'コオリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145975', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県南陽市中ノ目', '06', '06213', '9992242', '山形県', 'ヤマガタケン', '南陽市', 'ナンヨウシ', '中ノ目', 'ナカノメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145976', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県南陽市鍋田', '06', '06213', '9992243', '山形県', 'ヤマガタケン', '南陽市', 'ナンヨウシ', '鍋田', 'ナベタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145977', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県南陽市島貫', '06', '06213', '9992244', '山形県', 'ヤマガタケン', '南陽市', 'ナンヨウシ', '島貫', 'シマヌキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145978', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県南陽市高梨', '06', '06213', '9992251', '山形県', 'ヤマガタケン', '南陽市', 'ナンヨウシ', '高梨', 'タカナシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145979', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県南陽市沖田', '06', '06213', '9992252', '山形県', 'ヤマガタケン', '南陽市', 'ナンヨウシ', '沖田', 'オキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145980', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県南陽市宮崎', '06', '06213', '9992253', '山形県', 'ヤマガタケン', '南陽市', 'ナンヨウシ', '宮崎', 'ミヤザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145981', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県南陽市露橋', '06', '06213', '9992254', '山形県', 'ヤマガタケン', '南陽市', 'ナンヨウシ', '露橋', 'ツユハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145982', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県南陽市関根', '06', '06213', '9992255', '山形県', 'ヤマガタケン', '南陽市', 'ナンヨウシ', '関根', 'セキネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145983', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県南陽市坂井', '06', '06213', '9992256', '山形県', 'ヤマガタケン', '南陽市', 'ナンヨウシ', '坂井', 'サカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145984', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県南陽市蒲生田', '06', '06213', '9992261', '山形県', 'ヤマガタケン', '南陽市', 'ナンヨウシ', '蒲生田', 'カモウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145985', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県南陽市若狭郷屋', '06', '06213', '9992262', '山形県', 'ヤマガタケン', '南陽市', 'ナンヨウシ', '若狭郷屋', 'ワカサゴウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145986', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県南陽市萩生田', '06', '06213', '9992263', '山形県', 'ヤマガタケン', '南陽市', 'ナンヨウシ', '萩生田', 'ハギュウダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145987', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県南陽市中落合', '06', '06213', '9992264', '山形県', 'ヤマガタケン', '南陽市', 'ナンヨウシ', '中落合', 'ナカオチアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145988', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県南陽市西落合', '06', '06213', '9992265', '山形県', 'ヤマガタケン', '南陽市', 'ナンヨウシ', '西落合', 'ニシオチアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145989', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県南陽市長瀞', '06', '06213', '9992266', '山形県', 'ヤマガタケン', '南陽市', 'ナンヨウシ', '長瀞', 'ナガトロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145990', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県南陽市法師柳', '06', '06213', '9992267', '山形県', 'ヤマガタケン', '南陽市', 'ナンヨウシ', '法師柳', 'ホウシヤナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145993', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県上山市', '06', '06207', '9993100', '山形県', 'ヤマガタケン', '上山市', 'カミノヤマシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('145994', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県上山市金瓶', '06', '06207', '9993101', '山形県', 'ヤマガタケン', '上山市', 'カミノヤマシ', '金瓶', 'カナカメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145995', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県上山市新金谷', '06', '06207', '9993102', '山形県', 'ヤマガタケン', '上山市', 'カミノヤマシ', '新金谷', 'シンカナヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145996', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県上山市金谷', '06', '06207', '9993103', '山形県', 'ヤマガタケン', '上山市', 'カミノヤマシ', '金谷', 'カナヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145997', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県上山市蔵王の森', '06', '06207', '9993104', '山形県', 'ヤマガタケン', '上山市', 'カミノヤマシ', '蔵王の森', 'ザオウノモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145998', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県上山市泉川', '06', '06207', '9993105', '山形県', 'ヤマガタケン', '上山市', 'カミノヤマシ', '泉川', 'イズミカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('145999', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県上山市旭町', '06', '06207', '9993106', '山形県', 'ヤマガタケン', '上山市', 'カミノヤマシ', '旭町', 'アサヒマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146000', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県上山市権現堂', '06', '06207', '9993111', '山形県', 'ヤマガタケン', '上山市', 'カミノヤマシ', '権現堂', 'ゴンゲンドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146001', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県上山市小倉', '06', '06207', '9993112', '山形県', 'ヤマガタケン', '上山市', 'カミノヤマシ', '小倉', 'オグラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146002', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県上山市蔵王', '06', '06207', '9993113', '山形県', 'ヤマガタケン', '上山市', 'カミノヤマシ', '蔵王', 'ザオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146003', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県上山市永野', '06', '06207', '9993114', '山形県', 'ヤマガタケン', '上山市', 'カミノヤマシ', '永野', 'ナガノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146004', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県上山市高野', '06', '06207', '9993115', '山形県', 'ヤマガタケン', '上山市', 'カミノヤマシ', '高野', 'コウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146005', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県上山市東町', '06', '06207', '9993121', '山形県', 'ヤマガタケン', '上山市', 'カミノヤマシ', '東町', 'ヒガシマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146006', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県上山市仙石', '06', '06207', '9993122', '山形県', 'ヤマガタケン', '上山市', 'カミノヤマシ', '仙石', 'センゴク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146007', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県上山市美咲町', '06', '06207', '9993123', '山形県', 'ヤマガタケン', '上山市', 'カミノヤマシ', '美咲町', 'ミサキチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146008', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県上山市金生', '06', '06207', '9993124', '山形県', 'ヤマガタケン', '上山市', 'カミノヤマシ', '金生', 'カナオイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146009', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県上山市金生東', '06', '06207', '9993125', '山形県', 'ヤマガタケン', '上山市', 'カミノヤマシ', '金生東', 'カナオイヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146010', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県上山市金生西', '06', '06207', '9993126', '山形県', 'ヤマガタケン', '上山市', 'カミノヤマシ', '金生西', 'カナオイニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146011', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県上山市北町', '06', '06207', '9993131', '山形県', 'ヤマガタケン', '上山市', 'カミノヤマシ', '北町', 'キタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146012', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県上山市栄町', '06', '06207', '9993132', '山形県', 'ヤマガタケン', '上山市', 'カミノヤマシ', '栄町', 'サカエマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146013', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県上山市八日町', '06', '06207', '9993133', '山形県', 'ヤマガタケン', '上山市', 'カミノヤマシ', '八日町', 'ヨウカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146014', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県上山市矢来', '06', '06207', '9993134', '山形県', 'ヤマガタケン', '上山市', 'カミノヤマシ', '矢来', 'ヤライ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146015', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県上山市南町', '06', '06207', '9993135', '山形県', 'ヤマガタケン', '上山市', 'カミノヤマシ', '南町', 'ミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146016', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県上山市新湯', '06', '06207', '9993141', '山形県', 'ヤマガタケン', '上山市', 'カミノヤマシ', '新湯', 'シンユ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146017', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県上山市沢丁', '06', '06207', '9993142', '山形県', 'ヤマガタケン', '上山市', 'カミノヤマシ', '沢丁', 'サワチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146018', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県上山市二日町', '06', '06207', '9993143', '山形県', 'ヤマガタケン', '上山市', 'カミノヤマシ', '二日町', 'フツカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146019', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県上山市石崎', '06', '06207', '9993144', '山形県', 'ヤマガタケン', '上山市', 'カミノヤマシ', '石崎', 'イシザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146020', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県上山市河崎', '06', '06207', '9993145', '山形県', 'ヤマガタケン', '上山市', 'カミノヤマシ', '河崎', 'カワサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146021', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県上山市松山', '06', '06207', '9993146', '山形県', 'ヤマガタケン', '上山市', 'カミノヤマシ', '松山', 'マツヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146022', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県上山市北町本丁', '06', '06207', '9993151', '山形県', 'ヤマガタケン', '上山市', 'カミノヤマシ', '北町本丁', 'キタマチホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146023', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県上山市新丁', '06', '06207', '9993152', '山形県', 'ヤマガタケン', '上山市', 'カミノヤマシ', '新丁', 'シンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146024', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県上山市十日町', '06', '06207', '9993153', '山形県', 'ヤマガタケン', '上山市', 'カミノヤマシ', '十日町', 'トオカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146025', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県上山市元城内', '06', '06207', '9993154', '山形県', 'ヤマガタケン', '上山市', 'カミノヤマシ', '元城内', 'モトジョウナイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146026', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県上山市鶴脛町', '06', '06207', '9993155', '山形県', 'ヤマガタケン', '上山市', 'カミノヤマシ', '鶴脛町', 'ツルハギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146027', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県上山市湯町', '06', '06207', '9993156', '山形県', 'ヤマガタケン', '上山市', 'カミノヤマシ', '湯町', 'ユマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146028', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県上山市御井戸丁', '06', '06207', '9993157', '山形県', 'ヤマガタケン', '上山市', 'カミノヤマシ', '御井戸丁', 'オイドチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146029', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県上山市新町', '06', '06207', '9993158', '山形県', 'ヤマガタケン', '上山市', 'カミノヤマシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146030', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県上山市弁天', '06', '06207', '9993161', '山形県', 'ヤマガタケン', '上山市', 'カミノヤマシ', '弁天', 'ベンテン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146031', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県上山市四ツ谷', '06', '06207', '9993162', '山形県', 'ヤマガタケン', '上山市', 'カミノヤマシ', '四ツ谷', 'ヨツヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146032', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県上山市軽井沢', '06', '06207', '9993163', '山形県', 'ヤマガタケン', '上山市', 'カミノヤマシ', '軽井沢', 'カルイザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146033', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県上山市朝日台', '06', '06207', '9993164', '山形県', 'ヤマガタケン', '上山市', 'カミノヤマシ', '朝日台', 'アサヒダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146034', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県上山市裏町', '06', '06207', '9993165', '山形県', 'ヤマガタケン', '上山市', 'カミノヤマシ', '裏町', 'ウラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146035', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県上山市久保手', '06', '06207', '9993166', '山形県', 'ヤマガタケン', '上山市', 'カミノヤマシ', '久保手', 'クボテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146036', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県上山市大石', '06', '06207', '9993167', '山形県', 'ヤマガタケン', '上山市', 'カミノヤマシ', '大石', 'オオイシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146037', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県上山市狸森', '06', '06207', '9993171', '山形県', 'ヤマガタケン', '上山市', 'カミノヤマシ', '狸森', 'ムジナモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146038', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県上山市小白府', '06', '06207', '9993172', '山形県', 'ヤマガタケン', '上山市', 'カミノヤマシ', '小白府', 'オジラフ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146041', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県上山市宮脇', '06', '06207', '9993201', '山形県', 'ヤマガタケン', '上山市', 'カミノヤマシ', '宮脇', 'ミヤノワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146042', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県上山市下生居', '06', '06207', '9993202', '山形県', 'ヤマガタケン', '上山市', 'カミノヤマシ', '下生居', 'シモナマイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146043', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県上山市中生居', '06', '06207', '9993203', '山形県', 'ヤマガタケン', '上山市', 'カミノヤマシ', '中生居', 'ナカナマイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146044', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県上山市上生居', '06', '06207', '9993204', '山形県', 'ヤマガタケン', '上山市', 'カミノヤマシ', '上生居', 'カミナマイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146045', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県上山市牧野', '06', '06207', '9993211', '山形県', 'ヤマガタケン', '上山市', 'カミノヤマシ', '牧野', 'マギノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146046', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県上山市原口', '06', '06207', '9993212', '山形県', 'ヤマガタケン', '上山市', 'カミノヤマシ', '原口', 'ハラグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146047', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県上山市須田板', '06', '06207', '9993213', '山形県', 'ヤマガタケン', '上山市', 'カミノヤマシ', '須田板', 'スダイタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146048', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県上山市小笹', '06', '06207', '9993214', '山形県', 'ヤマガタケン', '上山市', 'カミノヤマシ', '小笹', 'オザサ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146049', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県上山市久保川', '06', '06207', '9993215', '山形県', 'ヤマガタケン', '上山市', 'カミノヤマシ', '久保川', 'クボカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146050', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県上山市大門', '06', '06207', '9993216', '山形県', 'ヤマガタケン', '上山市', 'カミノヤマシ', '大門', 'ダイモン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146051', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県上山市菖蒲', '06', '06207', '9993217', '山形県', 'ヤマガタケン', '上山市', 'カミノヤマシ', '菖蒲', 'ショウブ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146052', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県上山市関根', '06', '06207', '9993221', '山形県', 'ヤマガタケン', '上山市', 'カミノヤマシ', '関根', 'セキネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146053', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県上山市相生', '06', '06207', '9993222', '山形県', 'ヤマガタケン', '上山市', 'カミノヤマシ', '相生', 'アイオイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146054', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県上山市三上', '06', '06207', '9993223', '山形県', 'ヤマガタケン', '上山市', 'カミノヤマシ', '三上', 'ミカミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146055', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県上山市皆沢', '06', '06207', '9993224', '山形県', 'ヤマガタケン', '上山市', 'カミノヤマシ', '皆沢', 'ミナザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146056', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県上山市楢下', '06', '06207', '9993225', '山形県', 'ヤマガタケン', '上山市', 'カミノヤマシ', '楢下', 'ナラゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146057', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県上山市金山', '06', '06207', '9993226', '山形県', 'ヤマガタケン', '上山市', 'カミノヤマシ', '金山', 'カネヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146058', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県上山市石堂', '06', '06207', '9993231', '山形県', 'ヤマガタケン', '上山市', 'カミノヤマシ', '石堂', 'イシドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146059', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県上山市長清水', '06', '06207', '9993232', '山形県', 'ヤマガタケン', '上山市', 'カミノヤマシ', '長清水', 'ナガシミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146060', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県上山市三本松', '06', '06207', '9993233', '山形県', 'ヤマガタケン', '上山市', 'カミノヤマシ', '三本松', 'サンボンマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146061', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県上山市藤吾', '06', '06207', '9993234', '山形県', 'ヤマガタケン', '上山市', 'カミノヤマシ', '藤吾', 'トウゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146062', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県上山市阿弥陀地', '06', '06207', '9993235', '山形県', 'ヤマガタケン', '上山市', 'カミノヤマシ', '阿弥陀地', 'アミダチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146063', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県上山市細谷', '06', '06207', '9993236', '山形県', 'ヤマガタケン', '上山市', 'カミノヤマシ', '細谷', 'ホソヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146064', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県上山市小穴', '06', '06207', '9993237', '山形県', 'ヤマガタケン', '上山市', 'カミノヤマシ', '小穴', 'コアナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146065', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県上山市けやきの森', '06', '06207', '9993241', '山形県', 'ヤマガタケン', '上山市', 'カミノヤマシ', 'けやきの森', 'ケヤキノモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146066', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県上山市葉山', '06', '06207', '9993242', '山形県', 'ヤマガタケン', '上山市', 'カミノヤマシ', '葉山', 'ハヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146067', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県上山市高松', '06', '06207', '9993243', '山形県', 'ヤマガタケン', '上山市', 'カミノヤマシ', '高松', 'タカマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146068', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県上山市石曽根', '06', '06207', '9993244', '山形県', 'ヤマガタケン', '上山市', 'カミノヤマシ', '石曽根', 'イシゾネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146069', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県上山市川口', '06', '06207', '9993245', '山形県', 'ヤマガタケン', '上山市', 'カミノヤマシ', '川口', 'カワグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146070', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県上山市中山', '06', '06207', '9993246', '山形県', 'ヤマガタケン', '上山市', 'カミノヤマシ', '中山', 'ナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146072', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県山形市山寺', '06', '06201', '9993301', '山形県', 'ヤマガタケン', '山形市', 'ヤマガタシ', '山寺', 'ヤマデラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146073', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西村山郡河北町', '06', '06321', '9993500', '山形県', 'ヤマガタケン', '西村山郡河北町', 'ニシムラヤマグンカホクチョウ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('146074', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西村山郡河北町新吉田', '06', '06321', '9993501', '山形県', 'ヤマガタケン', '西村山郡河北町', 'ニシムラヤマグンカホクチョウ', '新吉田', 'シンヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146075', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西村山郡河北町吉田', '06', '06321', '9993502', '山形県', 'ヤマガタケン', '西村山郡河北町', 'ニシムラヤマグンカホクチョウ', '吉田', 'ヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146076', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西村山郡河北町岩木', '06', '06321', '9993503', '山形県', 'ヤマガタケン', '西村山郡河北町', 'ニシムラヤマグンカホクチョウ', '岩木', 'イワキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146077', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西村山郡河北町谷地', '06', '06321', '9993511', '山形県', 'ヤマガタケン', '西村山郡河北町', 'ニシムラヤマグンカホクチョウ', '谷地', 'ヤチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146078', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西村山郡河北町谷地中央', '06', '06321', '9993512', '山形県', 'ヤマガタケン', '西村山郡河北町', 'ニシムラヤマグンカホクチョウ', '谷地中央', 'ヤチチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146079', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西村山郡河北町谷地所岡', '06', '06321', '9993513', '山形県', 'ヤマガタケン', '西村山郡河北町', 'ニシムラヤマグンカホクチョウ', '谷地所岡', 'ヤチトコロオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146080', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西村山郡河北町田井', '06', '06321', '9993521', '山形県', 'ヤマガタケン', '西村山郡河北町', 'ニシムラヤマグンカホクチョウ', '田井', 'ダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146081', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西村山郡河北町溝延', '06', '06321', '9993522', '山形県', 'ヤマガタケン', '西村山郡河北町', 'ニシムラヤマグンカホクチョウ', '溝延', 'ミゾノベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146082', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西村山郡河北町畑中', '06', '06321', '9993531', '山形県', 'ヤマガタケン', '西村山郡河北町', 'ニシムラヤマグンカホクチョウ', '畑中', 'ハタケナカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146083', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西村山郡河北町造山', '06', '06321', '9993532', '山形県', 'ヤマガタケン', '西村山郡河北町', 'ニシムラヤマグンカホクチョウ', '造山', 'ツクリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146084', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県西村山郡河北町西里', '06', '06321', '9993533', '山形県', 'ヤマガタケン', '西村山郡河北町', 'ニシムラヤマグンカホクチョウ', '西里', 'ニシザト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146085', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東根市', '06', '06211', '9993700', '山形県', 'ヤマガタケン', '東根市', 'ヒガシネシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('146086', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東根市東根甲', '06', '06211', '9993701', '山形県', 'ヤマガタケン', '東根市', 'ヒガシネシ', '東根甲', 'ヒガシネコウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146087', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東根市温泉町', '06', '06211', '9993702', '山形県', 'ヤマガタケン', '東根市', 'ヒガシネシ', '温泉町', 'オンセンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146088', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東根市鷺ノ森', '06', '06211', '9993703', '山形県', 'ヤマガタケン', '東根市', 'ヒガシネシ', '鷺ノ森', 'サギノモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146089', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東根市東根丙', '06', '06211', '9993704', '山形県', 'ヤマガタケン', '東根市', 'ヒガシネシ', '東根丙', 'ヒガシネヘイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146090', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東根市宮崎', '06', '06211', '9993705', '山形県', 'ヤマガタケン', '東根市', 'ヒガシネシ', '宮崎', 'ミヤザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146091', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東根市三日町', '06', '06211', '9993706', '山形県', 'ヤマガタケン', '東根市', 'ヒガシネシ', '三日町', 'ミッカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146092', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東根市新田町', '06', '06211', '9993707', '山形県', 'ヤマガタケン', '東根市', 'ヒガシネシ', '新田町', 'シンデンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146093', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東根市下川原', '06', '06211', '9993708', '山形県', 'ヤマガタケン', '東根市', 'ヒガシネシ', '下川原', 'シモガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146094', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東根市六田', '06', '06211', '9993709', '山形県', 'ヤマガタケン', '東根市', 'ヒガシネシ', '六田', 'ロクタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146095', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東根市小林', '06', '06211', '9993710', '山形県', 'ヤマガタケン', '東根市', 'ヒガシネシ', '小林', 'コバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146096', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東根市中央', '06', '06211', '9993711', '山形県', 'ヤマガタケン', '東根市', 'ヒガシネシ', '中央', 'チュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146097', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東根市大森', '06', '06211', '9993712', '山形県', 'ヤマガタケン', '東根市', 'ヒガシネシ', '大森', 'オオモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146098', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東根市東根丁', '06', '06211', '9993713', '山形県', 'ヤマガタケン', '東根市', 'ヒガシネシ', '東根丁', 'ヒガシネテイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146099', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東根市大林', '06', '06211', '9993714', '山形県', 'ヤマガタケン', '東根市', 'ヒガシネシ', '大林', 'オオバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146100', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東根市大林新田', '06', '06211', '9993715', '山形県', 'ヤマガタケン', '東根市', 'ヒガシネシ', '大林新田', 'オオバヤシシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146101', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東根市蟹沢', '06', '06211', '9993716', '山形県', 'ヤマガタケン', '東根市', 'ヒガシネシ', '蟹沢', 'カニサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146102', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東根市一本木', '06', '06211', '9993717', '山形県', 'ヤマガタケン', '東根市', 'ヒガシネシ', '一本木', 'イッポンギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146103', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東根市四ツ家', '06', '06211', '9993718', '山形県', 'ヤマガタケン', '東根市', 'ヒガシネシ', '四ツ家', 'ヨツヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146104', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東根市中央西', '06', '06211', '9993719', '山形県', 'ヤマガタケン', '東根市', 'ヒガシネシ', '中央西', 'チュウオウニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146105', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東根市さくらんぼ駅前', '06', '06211', '9993720', '山形県', 'ヤマガタケン', '東根市', 'ヒガシネシ', 'さくらんぼ駅前', 'サクランボエキマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146106', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東根市東根乙', '06', '06211', '9993721', '山形県', 'ヤマガタケン', '東根市', 'ヒガシネシ', '東根乙', 'ヒガシネオツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146107', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東根市泉郷', '06', '06211', '9993722', '山形県', 'ヤマガタケン', '東根市', 'ヒガシネシ', '泉郷', 'イズミゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146108', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東根市観音寺', '06', '06211', '9993723', '山形県', 'ヤマガタケン', '東根市', 'ヒガシネシ', '観音寺', 'カンノンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146109', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東根市関山', '06', '06211', '9993724', '山形県', 'ヤマガタケン', '東根市', 'ヒガシネシ', '関山', 'セキヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146110', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東根市沼沢', '06', '06211', '9993725', '山形県', 'ヤマガタケン', '東根市', 'ヒガシネシ', '沼沢', 'ヌマザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146111', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東根市猪野沢', '06', '06211', '9993726', '山形県', 'ヤマガタケン', '東根市', 'ヒガシネシ', '猪野沢', 'イノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146112', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東根市野川', '06', '06211', '9993727', '山形県', 'ヤマガタケン', '東根市', 'ヒガシネシ', '野川', 'ノガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146113', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東根市太田新田', '06', '06211', '9993728', '山形県', 'ヤマガタケン', '東根市', 'ヒガシネシ', '太田新田', 'オオタシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146114', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東根市中央東', '06', '06211', '9993729', '山形県', 'ヤマガタケン', '東根市', 'ヒガシネシ', '中央東', 'チュウオウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146115', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東根市中央南', '06', '06211', '9993730', '山形県', 'ヤマガタケン', '東根市', 'ヒガシネシ', '中央南', 'チュウオウミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146116', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東根市神町営団大通り', '06', '06211', '9993731', '山形県', 'ヤマガタケン', '東根市', 'ヒガシネシ', '神町営団大通り', 'ジンマチエイダンオオドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146117', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東根市神町営団中通り', '06', '06211', '9993732', '山形県', 'ヤマガタケン', '東根市', 'ヒガシネシ', '神町営団中通り', 'ジンマチエイダンナカドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146118', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東根市神町営団三条通り', '06', '06211', '9993733', '山形県', 'ヤマガタケン', '東根市', 'ヒガシネシ', '神町営団三条通り', 'ジンマチエイダン03ジョウドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146119', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東根市神町営団二条通り', '06', '06211', '9993734', '山形県', 'ヤマガタケン', '東根市', 'ヒガシネシ', '神町営団二条通り', 'ジンマチエイダン02ジョウドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146120', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東根市神町営団一条通り', '06', '06211', '9993735', '山形県', 'ヤマガタケン', '東根市', 'ヒガシネシ', '神町営団一条通り', 'ジンマチエイダン01ジョウドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146121', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東根市神町営団南通り', '06', '06211', '9993736', '山形県', 'ヤマガタケン', '東根市', 'ヒガシネシ', '神町営団南通り', 'ジンマチエイダンミナミドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146122', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東根市若木', '06', '06211', '9993737', '山形県', 'ヤマガタケン', '東根市', 'ヒガシネシ', '若木', 'オサナギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146123', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東根市若木大通り', '06', '06211', '9993738', '山形県', 'ヤマガタケン', '東根市', 'ヒガシネシ', '若木大通り', 'オサナギオオドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146124', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東根市中島東通り', '06', '06211', '9993741', '山形県', 'ヤマガタケン', '東根市', 'ヒガシネシ', '中島東通り', 'ナカジマヒガシドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146125', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東根市中島通り', '06', '06211', '9993742', '山形県', 'ヤマガタケン', '東根市', 'ヒガシネシ', '中島通り', 'ナカジマドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146126', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東根市中島新田', '06', '06211', '9993743', '山形県', 'ヤマガタケン', '東根市', 'ヒガシネシ', '中島新田', 'ナカジマシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146127', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東根市板垣北通り', '06', '06211', '9993744', '山形県', 'ヤマガタケン', '東根市', 'ヒガシネシ', '板垣北通り', 'イタガキキタドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146128', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東根市板垣中通り', '06', '06211', '9993745', '山形県', 'ヤマガタケン', '東根市', 'ヒガシネシ', '板垣中通り', 'イタガキナカドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146129', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東根市板垣新田', '06', '06211', '9993746', '山形県', 'ヤマガタケン', '東根市', 'ヒガシネシ', '板垣新田', 'イタガキシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146130', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東根市板垣大通り', '06', '06211', '9993747', '山形県', 'ヤマガタケン', '東根市', 'ヒガシネシ', '板垣大通り', 'イタガキオオドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146131', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東根市板垣西小路', '06', '06211', '9993748', '山形県', 'ヤマガタケン', '東根市', 'ヒガシネシ', '板垣西小路', 'イタガキニシコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146132', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東根市板垣北小路', '06', '06211', '9993749', '山形県', 'ヤマガタケン', '東根市', 'ヒガシネシ', '板垣北小路', 'イタガキキタコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146133', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東根市若木通り', '06', '06211', '9993751', '山形県', 'ヤマガタケン', '東根市', 'ヒガシネシ', '若木通り', 'オサナギドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146134', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東根市若木五条通り', '06', '06211', '9993752', '山形県', 'ヤマガタケン', '東根市', 'ヒガシネシ', '若木五条通り', 'オサナギ05ジョウドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146135', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東根市若木四条通り', '06', '06211', '9993753', '山形県', 'ヤマガタケン', '東根市', 'ヒガシネシ', '若木四条通り', 'オサナギ04ジョウドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146136', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東根市若木三条通り', '06', '06211', '9993754', '山形県', 'ヤマガタケン', '東根市', 'ヒガシネシ', '若木三条通り', 'オサナギ03ジョウドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146137', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東根市若木二条通り', '06', '06211', '9993755', '山形県', 'ヤマガタケン', '東根市', 'ヒガシネシ', '若木二条通り', 'オサナギ02ジョウドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146138', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東根市若木一条通り', '06', '06211', '9993756', '山形県', 'ヤマガタケン', '東根市', 'ヒガシネシ', '若木一条通り', 'オサナギ01ジョウドオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146139', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東根市若木小路', '06', '06211', '9993757', '山形県', 'ヤマガタケン', '東根市', 'ヒガシネシ', '若木小路', 'オサナギコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146140', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東根市神町', '06', '06211', '9993761', '山形県', 'ヤマガタケン', '東根市', 'ヒガシネシ', '神町', 'ジンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146141', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東根市神町北', '06', '06211', '9993762', '山形県', 'ヤマガタケン', '東根市', 'ヒガシネシ', '神町北', 'ジンマチキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146142', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東根市神町中央', '06', '06211', '9993763', '山形県', 'ヤマガタケン', '東根市', 'ヒガシネシ', '神町中央', 'ジンマチチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146143', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東根市神町東', '06', '06211', '9993764', '山形県', 'ヤマガタケン', '東根市', 'ヒガシネシ', '神町東', 'ジンマチヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146144', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東根市神町南', '06', '06211', '9993765', '山形県', 'ヤマガタケン', '東根市', 'ヒガシネシ', '神町南', 'ジンマチミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146145', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東根市神町西', '06', '06211', '9993766', '山形県', 'ヤマガタケン', '東根市', 'ヒガシネシ', '神町西', 'ジンマチニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146146', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東根市柏原', '06', '06211', '9993770', '山形県', 'ヤマガタケン', '東根市', 'ヒガシネシ', '柏原', 'カシワバラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146147', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東根市長瀞', '06', '06211', '9993771', '山形県', 'ヤマガタケン', '東根市', 'ヒガシネシ', '長瀞', 'ナガトロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146148', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東根市松沢', '06', '06211', '9993772', '山形県', 'ヤマガタケン', '東根市', 'ヒガシネシ', '松沢', 'マツザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146149', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東根市島大堀', '06', '06211', '9993773', '山形県', 'ヤマガタケン', '東根市', 'ヒガシネシ', '島大堀', 'シマオオホリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146150', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東根市郡山', '06', '06211', '9993774', '山形県', 'ヤマガタケン', '東根市', 'ヒガシネシ', '郡山', 'コオリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146151', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東根市野田', '06', '06211', '9993775', '山形県', 'ヤマガタケン', '東根市', 'ヒガシネシ', '野田', 'ノダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146152', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東根市羽入', '06', '06211', '9993776', '山形県', 'ヤマガタケン', '東根市', 'ヒガシネシ', '羽入', 'ハニュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146153', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東根市荷口', '06', '06211', '9993777', '山形県', 'ヤマガタケン', '東根市', 'ヒガシネシ', '荷口', 'ニクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146154', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東根市藤助新田', '06', '06211', '9993778', '山形県', 'ヤマガタケン', '東根市', 'ヒガシネシ', '藤助新田', 'トウスケシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146155', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東根市羽入東', '06', '06211', '9993779', '山形県', 'ヤマガタケン', '東根市', 'ヒガシネシ', '羽入東', 'ハニュウヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146156', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東根市本丸北', '06', '06211', '9993781', '山形県', 'ヤマガタケン', '東根市', 'ヒガシネシ', '本丸北', 'ホンマルキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146157', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東根市本丸東', '06', '06211', '9993782', '山形県', 'ヤマガタケン', '東根市', 'ヒガシネシ', '本丸東', 'ホンマルヒガシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146158', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東根市本丸南', '06', '06211', '9993783', '山形県', 'ヤマガタケン', '東根市', 'ヒガシネシ', '本丸南', 'ホンマルミナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146159', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東根市本町', '06', '06211', '9993784', '山形県', 'ヤマガタケン', '東根市', 'ヒガシネシ', '本町', 'ホンチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146160', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東根市本丸西', '06', '06211', '9993785', '山形県', 'ヤマガタケン', '東根市', 'ヒガシネシ', '本丸西', 'ホンマルニシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146161', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東根市鷺の宿', '06', '06211', '9993786', '山形県', 'ヤマガタケン', '東根市', 'ヒガシネシ', '鷺の宿', 'サギノシュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146166', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県北村山郡大石田町', '06', '06341', '9994100', '山形県', 'ヤマガタケン', '北村山郡大石田町', 'キタムラヤマグンオオイシダマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('146167', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県北村山郡大石田町鷹巣', '06', '06341', '9994101', '山形県', 'ヤマガタケン', '北村山郡大石田町', 'キタムラヤマグンオオイシダマチ', '鷹巣', 'タカノス', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146168', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県北村山郡大石田町海谷', '06', '06341', '9994102', '山形県', 'ヤマガタケン', '北村山郡大石田町', 'キタムラヤマグンオオイシダマチ', '海谷', 'カイヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146169', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県北村山郡大石田町岩ケ袋', '06', '06341', '9994103', '山形県', 'ヤマガタケン', '北村山郡大石田町', 'キタムラヤマグンオオイシダマチ', '岩ケ袋', 'イワガフクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146170', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県北村山郡大石田町大石田', '06', '06341', '9994111', '山形県', 'ヤマガタケン', '北村山郡大石田町', 'キタムラヤマグンオオイシダマチ', '大石田', 'オオイシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146171', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県北村山郡大石田町緑町', '06', '06341', '9994112', '山形県', 'ヤマガタケン', '北村山郡大石田町', 'キタムラヤマグンオオイシダマチ', '緑町', 'ミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146172', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県北村山郡大石田町今宿', '06', '06341', '9994113', '山形県', 'ヤマガタケン', '北村山郡大石田町', 'キタムラヤマグンオオイシダマチ', '今宿', 'イマシュク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146173', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県北村山郡大石田町四日町', '06', '06341', '9994114', '山形県', 'ヤマガタケン', '北村山郡大石田町', 'キタムラヤマグンオオイシダマチ', '四日町', 'ヨッカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146174', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県北村山郡大石田町桂木町', '06', '06341', '9994115', '山形県', 'ヤマガタケン', '北村山郡大石田町', 'キタムラヤマグンオオイシダマチ', '桂木町', 'カツラギチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146175', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県北村山郡大石田町横山', '06', '06341', '9994121', '山形県', 'ヤマガタケン', '北村山郡大石田町', 'キタムラヤマグンオオイシダマチ', '横山', 'ヨコヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146176', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県北村山郡大石田町田沢', '06', '06341', '9994122', '山形県', 'ヤマガタケン', '北村山郡大石田町', 'キタムラヤマグンオオイシダマチ', '田沢', 'タザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146177', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県北村山郡大石田町大浦', '06', '06341', '9994131', '山形県', 'ヤマガタケン', '北村山郡大石田町', 'キタムラヤマグンオオイシダマチ', '大浦', 'オオウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146178', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県北村山郡大石田町駒籠', '06', '06341', '9994132', '山形県', 'ヤマガタケン', '北村山郡大石田町', 'キタムラヤマグンオオイシダマチ', '駒籠', 'コマゴメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146179', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県北村山郡大石田町川前', '06', '06341', '9994133', '山形県', 'ヤマガタケン', '北村山郡大石田町', 'キタムラヤマグンオオイシダマチ', '川前', 'カワマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146180', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県北村山郡大石田町豊田', '06', '06341', '9994134', '山形県', 'ヤマガタケン', '北村山郡大石田町', 'キタムラヤマグンオオイシダマチ', '豊田', 'トヨダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146181', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県北村山郡大石田町次年子', '06', '06341', '9994141', '山形県', 'ヤマガタケン', '北村山郡大石田町', 'キタムラヤマグンオオイシダマチ', '次年子', 'ジネンゴ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146182', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県尾花沢市', '06', '06212', '9994200', '山形県', 'ヤマガタケン', '尾花沢市', 'オバナザワシ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('146183', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県尾花沢市高橋', '06', '06212', '9994201', '山形県', 'ヤマガタケン', '尾花沢市', 'オバナザワシ', '高橋', 'タカハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146184', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県尾花沢市行沢', '06', '06212', '9994202', '山形県', 'ヤマガタケン', '尾花沢市', 'オバナザワシ', '行沢', 'ナメサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146185', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県尾花沢市中島', '06', '06212', '9994203', '山形県', 'ヤマガタケン', '尾花沢市', 'オバナザワシ', '中島', 'ナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146186', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県尾花沢市上ノ畑', '06', '06212', '9994204', '山形県', 'ヤマガタケン', '尾花沢市', 'オバナザワシ', '上ノ畑', 'カミノハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146187', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県尾花沢市押切', '06', '06212', '9994205', '山形県', 'ヤマガタケン', '尾花沢市', 'オバナザワシ', '押切', 'オシキリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146188', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県尾花沢市富山', '06', '06212', '9994206', '山形県', 'ヤマガタケン', '尾花沢市', 'オバナザワシ', '富山', 'トミヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146189', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県尾花沢市岩谷沢', '06', '06212', '9994207', '山形県', 'ヤマガタケン', '尾花沢市', 'オバナザワシ', '岩谷沢', 'イワヤサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146190', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県尾花沢市市野々', '06', '06212', '9994208', '山形県', 'ヤマガタケン', '尾花沢市', 'オバナザワシ', '市野々', 'イチノノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146191', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県尾花沢市正厳', '06', '06212', '9994211', '山形県', 'ヤマガタケン', '尾花沢市', 'オバナザワシ', '正厳', 'ショウゴン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146192', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県尾花沢市二藤袋', '06', '06212', '9994212', '山形県', 'ヤマガタケン', '尾花沢市', 'オバナザワシ', '二藤袋', 'ニトウブクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146193', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県尾花沢市丹生', '06', '06212', '9994213', '山形県', 'ヤマガタケン', '尾花沢市', 'オバナザワシ', '丹生', 'ニュウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146194', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県尾花沢市牛房野', '06', '06212', '9994214', '山形県', 'ヤマガタケン', '尾花沢市', 'オバナザワシ', '牛房野', 'ゴボウノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146195', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県尾花沢市尾花沢', '06', '06212', '9994221', '山形県', 'ヤマガタケン', '尾花沢市', 'オバナザワシ', '尾花沢', 'オバナザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146196', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県尾花沢市朧気', '06', '06212', '9994222', '山形県', 'ヤマガタケン', '尾花沢市', 'オバナザワシ', '朧気', 'オボロケ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146197', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県尾花沢市五十沢', '06', '06212', '9994223', '山形県', 'ヤマガタケン', '尾花沢市', 'オバナザワシ', '五十沢', 'イサザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146198', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県尾花沢市新町', '06', '06212', '9994224', '山形県', 'ヤマガタケン', '尾花沢市', 'オバナザワシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146199', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県尾花沢市若葉町', '06', '06212', '9994225', '山形県', 'ヤマガタケン', '尾花沢市', 'オバナザワシ', '若葉町', 'ワカバチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146200', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県尾花沢市新町中央', '06', '06212', '9994226', '山形県', 'ヤマガタケン', '尾花沢市', 'オバナザワシ', '新町中央', 'シンマチチュウオウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146201', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県尾花沢市中町', '06', '06212', '9994227', '山形県', 'ヤマガタケン', '尾花沢市', 'オバナザワシ', '中町', 'ナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146202', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県尾花沢市上町', '06', '06212', '9994228', '山形県', 'ヤマガタケン', '尾花沢市', 'オバナザワシ', '上町', 'カンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146203', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県尾花沢市横町', '06', '06212', '9994229', '山形県', 'ヤマガタケン', '尾花沢市', 'オバナザワシ', '横町', 'ヨコマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146204', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県尾花沢市北町', '06', '06212', '9994231', '山形県', 'ヤマガタケン', '尾花沢市', 'オバナザワシ', '北町', 'キタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146205', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県尾花沢市梺町', '06', '06212', '9994232', '山形県', 'ヤマガタケン', '尾花沢市', 'オバナザワシ', '梺町', 'フモトマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146207', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県尾花沢市上ノ畑', '06', '06212', '9994304', '山形県', 'ヤマガタケン', '尾花沢市', 'オバナザワシ', '上ノ畑', 'カミノハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146208', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県尾花沢市母袋', '06', '06212', '9994331', '山形県', 'ヤマガタケン', '尾花沢市', 'オバナザワシ', '母袋', 'モタイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146209', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県尾花沢市上柳渡戸', '06', '06212', '9994332', '山形県', 'ヤマガタケン', '尾花沢市', 'オバナザワシ', '上柳渡戸', 'カミヤナギワタリド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146210', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県尾花沢市銀山新畑', '06', '06212', '9994333', '山形県', 'ヤマガタケン', '尾花沢市', 'オバナザワシ', '銀山新畑', 'ギンザンシンハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146211', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県尾花沢市下柳渡戸', '06', '06212', '9994334', '山形県', 'ヤマガタケン', '尾花沢市', 'オバナザワシ', '下柳渡戸', 'シモヤナギワタリド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146212', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県尾花沢市原田', '06', '06212', '9994335', '山形県', 'ヤマガタケン', '尾花沢市', 'オバナザワシ', '原田', 'ハラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146213', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県尾花沢市北郷', '06', '06212', '9994336', '山形県', 'ヤマガタケン', '尾花沢市', 'オバナザワシ', '北郷', 'キタゴウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146214', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県尾花沢市鶴巻田', '06', '06212', '9994337', '山形県', 'ヤマガタケン', '尾花沢市', 'オバナザワシ', '鶴巻田', 'ツルマキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146215', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県尾花沢市延沢', '06', '06212', '9994441', '山形県', 'ヤマガタケン', '尾花沢市', 'オバナザワシ', '延沢', 'ノベサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146216', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県尾花沢市六沢', '06', '06212', '9994442', '山形県', 'ヤマガタケン', '尾花沢市', 'オバナザワシ', '六沢', 'ロクサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146217', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県尾花沢市鶴子', '06', '06212', '9994443', '山形県', 'ヤマガタケン', '尾花沢市', 'オバナザワシ', '鶴子', 'ツルコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146218', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県尾花沢市細野', '06', '06212', '9994444', '山形県', 'ヤマガタケン', '尾花沢市', 'オバナザワシ', '細野', 'ホソノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146219', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県尾花沢市畑沢', '06', '06212', '9994445', '山形県', 'ヤマガタケン', '尾花沢市', 'オバナザワシ', '畑沢', 'ハタサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146220', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県尾花沢市寺内', '06', '06212', '9994551', '山形県', 'ヤマガタケン', '尾花沢市', 'オバナザワシ', '寺内', 'テラウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146221', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県尾花沢市荻袋', '06', '06212', '9994552', '山形県', 'ヤマガタケン', '尾花沢市', 'オバナザワシ', '荻袋', 'オギノフクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146222', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県尾花沢市野黒沢', '06', '06212', '9994553', '山形県', 'ヤマガタケン', '尾花沢市', 'オバナザワシ', '野黒沢', 'ノクロサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146223', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県尾花沢市芦沢', '06', '06212', '9994554', '山形県', 'ヤマガタケン', '尾花沢市', 'オバナザワシ', '芦沢', 'アシザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146224', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県北村山郡大石田町鷹巣岡草山', '06', '06341', '9994554', '山形県', 'ヤマガタケン', '北村山郡大石田町', 'キタムラヤマグンオオイシダマチ', '鷹巣', 'タカノス', null, null, '岡草山', 'オカクサヤマ');
INSERT INTO `ms_addresses` VALUES ('146225', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県尾花沢市毒沢', '06', '06212', '9994555', '山形県', 'ヤマガタケン', '尾花沢市', 'オバナザワシ', '毒沢', 'ドクサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146226', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県尾花沢市名木沢', '06', '06212', '9994556', '山形県', 'ヤマガタケン', '尾花沢市', 'オバナザワシ', '名木沢', 'ナギサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146227', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県尾花沢市南沢', '06', '06212', '9994557', '山形県', 'ヤマガタケン', '尾花沢市', 'オバナザワシ', '南沢', 'ミナミサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146228', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県最上郡舟形町', '06', '06363', '9994600', '山形県', 'ヤマガタケン', '最上郡舟形町', 'モガミグンフナガタマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('146229', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県最上郡舟形町舟形', '06', '06363', '9994601', '山形県', 'ヤマガタケン', '最上郡舟形町', 'モガミグンフナガタマチ', '舟形', 'フナガタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146230', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県最上郡舟形町長者原', '06', '06363', '9994602', '山形県', 'ヤマガタケン', '最上郡舟形町', 'モガミグンフナガタマチ', '長者原', 'チョウジャハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146231', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県最上郡舟形町富田', '06', '06363', '9994603', '山形県', 'ヤマガタケン', '最上郡舟形町', 'モガミグンフナガタマチ', '富田', 'トミタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146232', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県最上郡舟形町堀内', '06', '06363', '9994604', '山形県', 'ヤマガタケン', '最上郡舟形町', 'モガミグンフナガタマチ', '堀内', 'ホリウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146233', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県最上郡舟形町長沢', '06', '06363', '9994605', '山形県', 'ヤマガタケン', '最上郡舟形町', 'モガミグンフナガタマチ', '長沢', 'ナガサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146234', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県新庄市昭和', '06', '06205', '9995101', '山形県', 'ヤマガタケン', '新庄市', 'シンジョウシ', '昭和', 'ショウワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146235', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県新庄市萩野', '06', '06205', '9995102', '山形県', 'ヤマガタケン', '新庄市', 'シンジョウシ', '萩野', 'ハギノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146236', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県新庄市泉田', '06', '06205', '9995103', '山形県', 'ヤマガタケン', '新庄市', 'シンジョウシ', '泉田', 'イズミタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146237', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県新庄市十日町', '06', '06205', '9995191', '山形県', 'ヤマガタケン', '新庄市', 'シンジョウシ', '十日町', 'トオカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146238', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県最上郡鮭川村', '06', '06366', '9995200', '山形県', 'ヤマガタケン', '最上郡鮭川村', 'モガミグンサケガワムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('146239', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県最上郡鮭川村京塚', '06', '06366', '9995201', '山形県', 'ヤマガタケン', '最上郡鮭川村', 'モガミグンサケガワムラ', '京塚', 'キョウヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146240', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県最上郡鮭川村佐渡', '06', '06366', '9995202', '山形県', 'ヤマガタケン', '最上郡鮭川村', 'モガミグンサケガワムラ', '佐渡', 'サド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146241', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県最上郡鮭川村川口', '06', '06366', '9995203', '山形県', 'ヤマガタケン', '最上郡鮭川村', 'モガミグンサケガワムラ', '川口', 'カワグチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146242', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県最上郡鮭川村向居', '06', '06366', '9995204', '山形県', 'ヤマガタケン', '最上郡鮭川村', 'モガミグンサケガワムラ', '向居', 'ムカイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146243', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県最上郡鮭川村中渡', '06', '06366', '9995205', '山形県', 'ヤマガタケン', '最上郡鮭川村', 'モガミグンサケガワムラ', '中渡', 'ナカワタリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146244', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県最上郡鮭川村曲川', '06', '06366', '9995206', '山形県', 'ヤマガタケン', '最上郡鮭川村', 'モガミグンサケガワムラ', '曲川', 'マガリガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146245', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県最上郡鮭川村庭月', '06', '06366', '9995207', '山形県', 'ヤマガタケン', '最上郡鮭川村', 'モガミグンサケガワムラ', '庭月', 'ニワヅキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146246', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県最上郡鮭川村石名坂', '06', '06366', '9995208', '山形県', 'ヤマガタケン', '最上郡鮭川村', 'モガミグンサケガワムラ', '石名坂', 'イシナザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146248', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県最上郡真室川町', '06', '06364', '9995300', '山形県', 'ヤマガタケン', '最上郡真室川町', 'モガミグンマムロガワマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('146249', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県最上郡真室川町川ノ内', '06', '06364', '9995301', '山形県', 'ヤマガタケン', '最上郡真室川町', 'モガミグンマムロガワマチ', '川ノ内', 'カワノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146250', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県最上郡真室川町平岡', '06', '06364', '9995311', '山形県', 'ヤマガタケン', '最上郡真室川町', 'モガミグンマムロガワマチ', '平岡', 'ヒラオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146251', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県最上郡真室川町新町', '06', '06364', '9995312', '山形県', 'ヤマガタケン', '最上郡真室川町', 'モガミグンマムロガワマチ', '新町', 'アラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146252', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県最上郡真室川町内町', '06', '06364', '9995313', '山形県', 'ヤマガタケン', '最上郡真室川町', 'モガミグンマムロガワマチ', '内町', 'ウチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146253', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県最上郡真室川町木ノ下', '06', '06364', '9995314', '山形県', 'ヤマガタケン', '最上郡真室川町', 'モガミグンマムロガワマチ', '木ノ下', 'キノシタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146254', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県最上郡金山町', '06', '06361', '9995400', '山形県', 'ヤマガタケン', '最上郡金山町', 'モガミグンカネヤママチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('146255', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県最上郡金山町有屋', '06', '06361', '9995401', '山形県', 'ヤマガタケン', '最上郡金山町', 'モガミグンカネヤママチ', '有屋', 'アリヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146256', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県最上郡金山町金山', '06', '06361', '9995402', '山形県', 'ヤマガタケン', '最上郡金山町', 'モガミグンカネヤママチ', '金山', 'カネヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146257', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県最上郡金山町安沢', '06', '06361', '9995403', '山形県', 'ヤマガタケン', '最上郡金山町', 'モガミグンカネヤママチ', '安沢', 'ヤスザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146258', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県最上郡金山町下野明', '06', '06361', '9995404', '山形県', 'ヤマガタケン', '最上郡金山町', 'モガミグンカネヤママチ', '下野明', 'シモノミョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146259', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県最上郡金山町上台', '06', '06361', '9995405', '山形県', 'ヤマガタケン', '最上郡金山町', 'モガミグンカネヤママチ', '上台', 'ウワダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146260', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県最上郡金山町山崎', '06', '06361', '9995406', '山形県', 'ヤマガタケン', '最上郡金山町', 'モガミグンカネヤママチ', '山崎', 'ヤマザキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146261', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県最上郡金山町中田', '06', '06361', '9995411', '山形県', 'ヤマガタケン', '最上郡金山町', 'モガミグンカネヤママチ', '中田', 'ナカダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146262', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県最上郡金山町飛森', '06', '06361', '9995412', '山形県', 'ヤマガタケン', '最上郡金山町', 'モガミグンカネヤママチ', '飛森', 'トビノモリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146263', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県最上郡金山町谷口銀山', '06', '06361', '9995413', '山形県', 'ヤマガタケン', '最上郡金山町', 'モガミグンカネヤママチ', '谷口銀山', 'タニグチギンザン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146264', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県最上郡金山町漆野', '06', '06361', '9995414', '山形県', 'ヤマガタケン', '最上郡金山町', 'モガミグンカネヤママチ', '漆野', 'ウルシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146265', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県最上郡金山町朴山', '06', '06361', '9995415', '山形県', 'ヤマガタケン', '最上郡金山町', 'モガミグンカネヤママチ', '朴山', 'ホオヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146266', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県最上郡真室川町大沢', '06', '06364', '9995521', '山形県', 'ヤマガタケン', '最上郡真室川町', 'モガミグンマムロガワマチ', '大沢', 'オオサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146267', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県最上郡真室川町差首鍋', '06', '06364', '9995522', '山形県', 'ヤマガタケン', '最上郡真室川町', 'モガミグンマムロガワマチ', '差首鍋', 'サスナベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146268', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県最上郡真室川町川ノ内', '06', '06364', '9995601', '山形県', 'ヤマガタケン', '最上郡真室川町', 'モガミグンマムロガワマチ', '川ノ内', 'カワノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146269', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県最上郡真室川町川ノ内三滝', '06', '06364', '9995601', '山形県', 'ヤマガタケン', '最上郡真室川町', 'モガミグンマムロガワマチ', '川ノ内', 'カワノウチ', null, null, '三滝', 'サンタキ');
INSERT INTO `ms_addresses` VALUES ('146270', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県最上郡真室川町川ノ内春木', '06', '06364', '9995601', '山形県', 'ヤマガタケン', '最上郡真室川町', 'モガミグンマムロガワマチ', '川ノ内', 'カワノウチ', null, null, '春木', 'ハルキ');
INSERT INTO `ms_addresses` VALUES ('146271', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県最上郡真室川町及位', '06', '06364', '9995602', '山形県', 'ヤマガタケン', '最上郡真室川町', 'モガミグンマムロガワマチ', '及位', 'ノゾキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146272', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県最上郡真室川町大滝', '06', '06364', '9995603', '山形県', 'ヤマガタケン', '最上郡真室川町', 'モガミグンマムロガワマチ', '大滝', 'オオタキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146273', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県最上郡真室川町釜淵', '06', '06364', '9995604', '山形県', 'ヤマガタケン', '最上郡真室川町', 'モガミグンマムロガワマチ', '釜淵', 'カマブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146274', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県最上郡最上町', '06', '06362', '9996100', '山形県', 'ヤマガタケン', '最上郡最上町', 'モガミグンモガミマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('146275', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県最上郡最上町向町', '06', '06362', '9996101', '山形県', 'ヤマガタケン', '最上郡最上町', 'モガミグンモガミマチ', '向町', 'ムカイマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146276', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県最上郡最上町東法田', '06', '06362', '9996102', '山形県', 'ヤマガタケン', '最上郡最上町', 'モガミグンモガミマチ', '東法田', 'ヒガシホウデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146277', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県最上郡最上町黒澤', '06', '06362', '9996103', '山形県', 'ヤマガタケン', '最上郡最上町', 'モガミグンモガミマチ', '黒澤', 'クロサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146278', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県最上郡最上町本城', '06', '06362', '9996104', '山形県', 'ヤマガタケン', '最上郡最上町', 'モガミグンモガミマチ', '本城', 'ホンジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146279', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県最上郡最上町富澤', '06', '06362', '9996105', '山形県', 'ヤマガタケン', '最上郡最上町', 'モガミグンモガミマチ', '富澤', 'トミサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146280', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県最上郡最上町堺田', '06', '06362', '9996106', '山形県', 'ヤマガタケン', '最上郡最上町', 'モガミグンモガミマチ', '堺田', 'サカイダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146281', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県最上郡最上町満澤', '06', '06362', '9996107', '山形県', 'ヤマガタケン', '最上郡最上町', 'モガミグンモガミマチ', '満澤', 'ミツザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146282', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県最上郡最上町大堀', '06', '06362', '9996211', '山形県', 'ヤマガタケン', '最上郡最上町', 'モガミグンモガミマチ', '大堀', 'オオホリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146283', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県最上郡最上町瀬見', '06', '06362', '9996211', '山形県', 'ヤマガタケン', '最上郡最上町', 'モガミグンモガミマチ', '瀬見', 'セミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146284', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県最上郡最上町志茂', '06', '06362', '9996212', '山形県', 'ヤマガタケン', '最上郡最上町', 'モガミグンモガミマチ', '志茂', 'シモ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146285', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県最上郡最上町法田', '06', '06362', '9996213', '山形県', 'ヤマガタケン', '最上郡最上町', 'モガミグンモガミマチ', '法田', 'ホウデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146286', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県最上郡最上町若宮', '06', '06362', '9996214', '山形県', 'ヤマガタケン', '最上郡最上町', 'モガミグンモガミマチ', '若宮', 'ワカミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146287', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県最上郡最上町月楯', '06', '06362', '9996215', '山形県', 'ヤマガタケン', '最上郡最上町', 'モガミグンモガミマチ', '月楯', 'ツキダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146288', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県最上郡戸沢村津谷', '06', '06367', '9996311', '山形県', 'ヤマガタケン', '最上郡戸沢村', 'モガミグントザワムラ', '津谷', 'ツヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146289', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県最上郡戸沢村岩清水', '06', '06367', '9996312', '山形県', 'ヤマガタケン', '最上郡戸沢村', 'モガミグントザワムラ', '岩清水', 'イワシミズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146290', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県最上郡戸沢村名高', '06', '06367', '9996313', '山形県', 'ヤマガタケン', '最上郡戸沢村', 'モガミグントザワムラ', '名高', 'ナダカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146291', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県最上郡戸沢村松坂', '06', '06367', '9996314', '山形県', 'ヤマガタケン', '最上郡戸沢村', 'モガミグントザワムラ', '松坂', 'マツザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146292', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県最上郡戸沢村神田', '06', '06367', '9996315', '山形県', 'ヤマガタケン', '最上郡戸沢村', 'モガミグントザワムラ', '神田', 'ジンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146293', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県最上郡戸沢村', '06', '06367', '9996400', '山形県', 'ヤマガタケン', '最上郡戸沢村', 'モガミグントザワムラ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('146294', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県最上郡戸沢村古口', '06', '06367', '9996401', '山形県', 'ヤマガタケン', '最上郡戸沢村', 'モガミグントザワムラ', '古口', 'フルクチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146295', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県最上郡戸沢村蔵岡', '06', '06367', '9996402', '山形県', 'ヤマガタケン', '最上郡戸沢村', 'モガミグントザワムラ', '蔵岡', 'クラオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146296', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県最上郡戸沢村角川', '06', '06367', '9996403', '山形県', 'ヤマガタケン', '最上郡戸沢村', 'モガミグントザワムラ', '角川', 'ツノカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146297', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東田川郡庄内町狩川', '06', '06428', '9996601', '山形県', 'ヤマガタケン', '東田川郡庄内町', 'ヒガシタガワグンショウナイマチ', '狩川', 'カリカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146298', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東田川郡庄内町三ケ沢', '06', '06428', '9996602', '山形県', 'ヤマガタケン', '東田川郡庄内町', 'ヒガシタガワグンショウナイマチ', '三ケ沢', 'ミカザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146299', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東田川郡庄内町添津', '06', '06428', '9996603', '山形県', 'ヤマガタケン', '東田川郡庄内町', 'ヒガシタガワグンショウナイマチ', '添津', 'ソエヅ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146300', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東田川郡庄内町千本杉', '06', '06428', '9996604', '山形県', 'ヤマガタケン', '東田川郡庄内町', 'ヒガシタガワグンショウナイマチ', '千本杉', 'センボンスギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146301', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東田川郡庄内町桑田', '06', '06428', '9996605', '山形県', 'ヤマガタケン', '東田川郡庄内町', 'ヒガシタガワグンショウナイマチ', '桑田', 'クワダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146302', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東田川郡庄内町清川', '06', '06428', '9996606', '山形県', 'ヤマガタケン', '東田川郡庄内町', 'ヒガシタガワグンショウナイマチ', '清川', 'キヨカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146303', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東田川郡庄内町肝煎', '06', '06428', '9996607', '山形県', 'ヤマガタケン', '東田川郡庄内町', 'ヒガシタガワグンショウナイマチ', '肝煎', 'キモイリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146304', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東田川郡庄内町科沢', '06', '06428', '9996608', '山形県', 'ヤマガタケン', '東田川郡庄内町', 'ヒガシタガワグンショウナイマチ', '科沢', 'シナザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146305', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東田川郡庄内町立谷沢', '06', '06428', '9996609', '山形県', 'ヤマガタケン', '東田川郡庄内町', 'ヒガシタガワグンショウナイマチ', '立谷沢', 'タチヤザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146306', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市添川渡戸沢「筍沢温泉」', '06', '06203', '9996652', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '添川', 'ソエガワ', null, null, '渡戸沢「筍沢温泉」', 'ワタトザワ＜タケノコザワオンセン＞');
INSERT INTO `ms_addresses` VALUES ('146307', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市砂越', '06', '06204', '9996701', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '砂越', 'サゴシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146308', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市砂越緑町', '06', '06204', '9996702', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '砂越緑町', 'サゴシミドリチョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146309', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市天神堂', '06', '06204', '9996703', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '天神堂', 'テンジンドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146310', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市石橋', '06', '06204', '9996704', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '石橋', 'イシバシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146311', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市桜林', '06', '06204', '9996705', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '桜林', 'サクラバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146312', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市桜林興野', '06', '06204', '9996706', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '桜林興野', 'サクラバヤシコウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146313', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市郡山', '06', '06204', '9996707', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '郡山', 'コオリヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146314', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市泉興野', '06', '06204', '9996708', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '泉興野', 'イズミコウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146315', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市飛鳥', '06', '06204', '9996711', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '飛鳥', 'アスカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146316', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市楢橋', '06', '06204', '9996712', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '楢橋', 'ナラハシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146317', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市堀野内', '06', '06204', '9996721', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '堀野内', 'ホリノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146318', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市中野目', '06', '06204', '9996722', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '中野目', 'ナカノメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146319', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市三之宮', '06', '06204', '9996723', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '三之宮', 'サンノミヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146320', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市山楯', '06', '06204', '9996724', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '山楯', 'ヤマダテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146321', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市山谷新田', '06', '06204', '9996725', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '山谷新田', 'ヤマヤシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146322', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市山谷', '06', '06204', '9996726', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '山谷', 'ヤマヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146323', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市中野俣', '06', '06204', '9996727', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '中野俣', 'ナカノマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146324', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市田沢', '06', '06204', '9996731', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '田沢', 'タザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146325', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市楯山', '06', '06204', '9996732', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '楯山', 'タテヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146326', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市西坂本', '06', '06204', '9996733', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '西坂本', 'ニシサカモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146327', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市山元', '06', '06204', '9996734', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '山元', 'ヤマモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146328', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市小林', '06', '06204', '9996735', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '小林', 'コバヤシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146329', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市北俣', '06', '06204', '9996741', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '北俣', 'キタマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146330', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県最上郡戸沢村古口柏沢', '06', '06367', '9996801', '山形県', 'ヤマガタケン', '最上郡戸沢村', 'モガミグントザワムラ', '古口', 'フルクチ', null, null, '柏沢', 'カシザワ');
INSERT INTO `ms_addresses` VALUES ('146331', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市柏谷沢', '06', '06204', '9996811', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '柏谷沢', 'カシヤザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146332', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市成興野', '06', '06204', '9996812', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '成興野', 'ナリコウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146333', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市大川渡', '06', '06204', '9996813', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '大川渡', 'オオカワド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146334', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市地見興屋', '06', '06204', '9996814', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '地見興屋', 'ジミコウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146335', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市臼ケ沢', '06', '06204', '9996815', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '臼ケ沢', 'ウスガサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146336', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市大沼新田', '06', '06204', '9996816', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '大沼新田', 'オオヌマシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146337', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市山寺', '06', '06204', '9996821', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '山寺', 'ヤマデラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146338', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市南新屋敷', '06', '06204', '9996822', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '南新屋敷', 'ミナミシンヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146339', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市真学寺沢', '06', '06204', '9996823', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '真学寺沢', 'シンガクジサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146340', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市元新屋敷', '06', '06204', '9996824', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '元新屋敷', 'モトシンヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146341', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市南町', '06', '06204', '9996825', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '南町', 'ミナミマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146342', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市稲荷沢', '06', '06204', '9996826', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '稲荷沢', 'イナリザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146343', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市仲町', '06', '06204', '9996827', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '仲町', 'ナカマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146344', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市内町', '06', '06204', '9996831', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '内町', 'ウチマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146345', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市総光寺沢', '06', '06204', '9996831', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '総光寺沢', 'ソウコウジサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146346', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市新屋敷', '06', '06204', '9996832', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '新屋敷', 'シンヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146347', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市北町', '06', '06204', '9996833', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '北町', 'キタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146348', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市荒町', '06', '06204', '9996834', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '荒町', 'アラマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146349', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市蔵小路', '06', '06204', '9996835', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '蔵小路', 'クラコウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146350', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市本町', '06', '06204', '9996835', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '本町', 'ホンマチ', '（－マチ）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('146351', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市肴町', '06', '06204', '9996836', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '肴町', 'サカナマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146352', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市金谷', '06', '06204', '9996837', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '金谷', 'カナヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146353', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市新町', '06', '06204', '9996837', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '新町', 'シンマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146354', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市片町', '06', '06204', '9996838', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '片町', 'カタマチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146355', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市土渕', '06', '06204', '9996839', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '土渕', 'ツチブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146356', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市茗ケ沢', '06', '06204', '9996841', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '茗ケ沢', 'ミョウガサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146357', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市上餅山', '06', '06204', '9996842', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '上餅山', 'カミモチヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146358', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市上北目', '06', '06204', '9996843', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '上北目', 'カミキタメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146359', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市中北目', '06', '06204', '9996844', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '中北目', 'ナカキタメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146360', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市小見', '06', '06204', '9996845', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '小見', 'オミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146361', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市下餅山', '06', '06204', '9996846', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '下餅山', 'シモモチヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146362', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市引地', '06', '06204', '9996847', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '引地', 'ヒキジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146363', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市竹田', '06', '06204', '9996848', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '竹田', 'タケダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146364', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市中牧田', '06', '06204', '9996851', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '中牧田', 'ナカマキタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146365', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市相沢', '06', '06204', '9996852', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '相沢', 'アイサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146366', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市石名坂', '06', '06204', '9996853', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '石名坂', 'イシナザカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146367', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市山田', '06', '06204', '9996861', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '山田', 'ヤマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146368', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市西田', '06', '06204', '9996862', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '西田', 'ニシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146369', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市早田', '06', '06203', '9997121', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '早田', 'ワサダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146370', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市小岩川', '06', '06203', '9997122', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '小岩川', 'コイワガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146371', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市大岩川', '06', '06203', '9997123', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '大岩川', 'オオイワガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146372', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市槇代', '06', '06203', '9997124', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '槇代', 'マキダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146373', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市小名部', '06', '06203', '9997125', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '小名部', 'オナベ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146374', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市鼠ケ関', '06', '06203', '9997126', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '鼠ケ関', 'ネズガセキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146375', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市山五十川', '06', '06203', '9997201', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '山五十川', 'ヤマイラガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146376', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市戸沢', '06', '06203', '9997202', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '戸沢', 'トザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146377', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市一霞', '06', '06203', '9997203', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '一霞', 'ヒトカスミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146378', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市湯温海', '06', '06203', '9997204', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '湯温海', 'ユアツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146379', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市温海', '06', '06203', '9997205', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '温海', 'アツミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146380', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市小菅野代', '06', '06203', '9997206', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '小菅野代', 'コスガノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146381', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市五十川', '06', '06203', '9997207', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '五十川', 'イラガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146383', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市菅野代', '06', '06203', '9997311', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '菅野代', 'スガノダイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146384', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市温海川', '06', '06203', '9997312', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '温海川', 'アツミガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146385', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市木野俣', '06', '06203', '9997313', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '木野俣', 'キノマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146386', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市越沢', '06', '06203', '9997314', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '越沢', 'コエサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146387', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市関川', '06', '06203', '9997315', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '関川', 'セキガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146388', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市小国', '06', '06203', '9997316', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '小国', 'オグニ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146389', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市堅苔沢', '06', '06203', '9997461', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '堅苔沢', 'カタノリザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146390', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市小波渡', '06', '06203', '9997462', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '小波渡', 'コバト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146391', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市三瀬', '06', '06203', '9997463', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '三瀬', 'サンゼ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146392', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市由良', '06', '06203', '9997464', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '由良', 'ユラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146393', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市西目', '06', '06203', '9997541', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '西目', 'ニシメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146394', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市水沢', '06', '06203', '9997542', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '水沢', 'ミズサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146395', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市大広', '06', '06203', '9997543', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '大広', 'オオヒロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146396', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市中山', '06', '06203', '9997544', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '中山', 'ナカヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146397', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市矢引', '06', '06203', '9997545', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '矢引', 'ヤビキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146398', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市中沢', '06', '06203', '9997546', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '中沢', 'ナカザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146399', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市大荒', '06', '06203', '9997547', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '大荒', 'オオアラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146400', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市みずほ', '06', '06203', '9997548', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', 'みずほ', 'ミズホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146401', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市藤島', '06', '06203', '9997601', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '藤島', 'フジシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146402', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市藤の花', '06', '06203', '9997602', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '藤の花', 'フジノハナ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146403', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市藤浪', '06', '06203', '9997604', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '藤浪', 'フジナミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146404', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市上藤島', '06', '06203', '9997611', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '上藤島', 'カミフジシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146405', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市長沼', '06', '06203', '9997621', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '長沼', 'ナガヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146406', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市豊栄', '06', '06203', '9997622', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '豊栄', 'ホウエイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146407', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市八色木', '06', '06203', '9997631', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '八色木', 'ヤイロギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146408', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市小中島', '06', '06203', '9997632', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '小中島', 'コナカジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146409', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市須走', '06', '06203', '9997633', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '須走', 'スバシリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146410', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市三和', '06', '06203', '9997634', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '三和', 'ミワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146411', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市越後京田', '06', '06203', '9997635', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '越後京田', 'エチゴキョウデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146412', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市野田目', '06', '06203', '9997636', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '野田目', 'ノダノメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146413', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市下中野目', '06', '06203', '9997637', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '下中野目', 'シモナカノメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146414', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市藤岡', '06', '06203', '9997638', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '藤岡', 'フジオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146415', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市楪', '06', '06203', '9997641', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '楪', 'ユズリハ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146416', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市藤島関根', '06', '06203', '9997642', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '藤島関根', 'フジシマセキネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146417', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市無音', '06', '06203', '9997643', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '無音', 'ヨバラズ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146418', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市川尻', '06', '06203', '9997644', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '川尻', 'カワシリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146419', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市平足', '06', '06203', '9997645', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '平足', 'ヘイソク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146420', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市工藤', '06', '06203', '9997646', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '工藤', 'クドウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146421', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市鷺畑', '06', '06203', '9997651', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '鷺畑', 'サギハタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146422', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市添川', '06', '06203', '9997652', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '添川', 'ソエガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146423', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市東堀越', '06', '06203', '9997653', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '東堀越', 'ヒガシホリコシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146424', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市大川渡', '06', '06203', '9997661', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '大川渡', 'オオカワド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146425', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市谷地興屋', '06', '06203', '9997662', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '谷地興屋', 'ヤチコウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146426', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市蛸井興屋', '06', '06203', '9997663', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '蛸井興屋', 'タコイコウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146427', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市上中野目', '06', '06203', '9997664', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '上中野目', 'カミナカノメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146428', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市古郡', '06', '06203', '9997671', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '古郡', 'フルコオリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146429', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市柳久瀬', '06', '06203', '9997672', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '柳久瀬', 'ヤナクセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146430', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市荒俣', '06', '06203', '9997673', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '荒俣', 'アラマタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146431', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市箕升新田', '06', '06203', '9997674', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '箕升新田', 'ミマスシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146432', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市宝徳', '06', '06203', '9997675', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '宝徳', 'ホウトク', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146433', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市幕野内', '06', '06203', '9997676', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '幕野内', 'マクノウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146434', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市大半田', '06', '06203', '9997677', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '大半田', 'ダイハンダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146435', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市平形', '06', '06203', '9997681', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '平形', 'ヒラカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146436', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市新屋敷', '06', '06203', '9997682', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '新屋敷', 'アラヤシキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146437', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市渡前', '06', '06203', '9997683', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '渡前', 'ワタマエ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146438', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市和名川', '06', '06203', '9997684', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '和名川', 'ワナガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146439', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県鶴岡市砂塚', '06', '06203', '9997685', '山形県', 'ヤマガタケン', '鶴岡市', 'ツルオカシ', '砂塚', 'スナヅカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146441', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東田川郡庄内町', '06', '06428', '9997700', '山形県', 'ヤマガタケン', '東田川郡庄内町', 'ヒガシタガワグンショウナイマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('146442', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東田川郡庄内町跡', '06', '06428', '9997701', '山形県', 'ヤマガタケン', '東田川郡庄内町', 'ヒガシタガワグンショウナイマチ', '跡', 'アト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146443', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東田川郡庄内町榎木', '06', '06428', '9997702', '山形県', 'ヤマガタケン', '東田川郡庄内町', 'ヒガシタガワグンショウナイマチ', '榎木', 'エノキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146444', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東田川郡庄内町平岡', '06', '06428', '9997703', '山形県', 'ヤマガタケン', '東田川郡庄内町', 'ヒガシタガワグンショウナイマチ', '平岡', 'ヒラオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146445', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東田川郡庄内町千河原', '06', '06428', '9997704', '山形県', 'ヤマガタケン', '東田川郡庄内町', 'ヒガシタガワグンショウナイマチ', '千河原', 'チガワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146446', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東田川郡庄内町槇島', '06', '06428', '9997705', '山形県', 'ヤマガタケン', '東田川郡庄内町', 'ヒガシタガワグンショウナイマチ', '槇島', 'マギシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146447', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東田川郡庄内町提興屋', '06', '06428', '9997706', '山形県', 'ヤマガタケン', '東田川郡庄内町', 'ヒガシタガワグンショウナイマチ', '提興屋', 'ヒサゲコウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146448', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東田川郡庄内町廿六木', '06', '06428', '9997707', '山形県', 'ヤマガタケン', '東田川郡庄内町', 'ヒガシタガワグンショウナイマチ', '廿六木', 'トドロキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146449', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東田川郡庄内町福原', '06', '06428', '9997711', '山形県', 'ヤマガタケン', '東田川郡庄内町', 'ヒガシタガワグンショウナイマチ', '福原', 'フクワラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146450', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東田川郡庄内町堀野', '06', '06428', '9997712', '山形県', 'ヤマガタケン', '東田川郡庄内町', 'ヒガシタガワグンショウナイマチ', '堀野', 'ホリノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146451', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東田川郡庄内町常万', '06', '06428', '9997713', '山形県', 'ヤマガタケン', '東田川郡庄内町', 'ヒガシタガワグンショウナイマチ', '常万', 'ジョウマン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146452', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東田川郡庄内町余目新田', '06', '06428', '9997714', '山形県', 'ヤマガタケン', '東田川郡庄内町', 'ヒガシタガワグンショウナイマチ', '余目新田', 'アマルメシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146453', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東田川郡庄内町廻館', '06', '06428', '9997715', '山形県', 'ヤマガタケン', '東田川郡庄内町', 'ヒガシタガワグンショウナイマチ', '廻館', 'マワタテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146454', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東田川郡庄内町堤新田', '06', '06428', '9997721', '山形県', 'ヤマガタケン', '東田川郡庄内町', 'ヒガシタガワグンショウナイマチ', '堤新田', 'ツツミシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146455', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東田川郡庄内町小出新田', '06', '06428', '9997722', '山形県', 'ヤマガタケン', '東田川郡庄内町', 'ヒガシタガワグンショウナイマチ', '小出新田', 'コイデシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146456', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東田川郡庄内町連枝', '06', '06428', '9997723', '山形県', 'ヤマガタケン', '東田川郡庄内町', 'ヒガシタガワグンショウナイマチ', '連枝', 'レンシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146457', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東田川郡庄内町赤渕新田', '06', '06428', '9997724', '山形県', 'ヤマガタケン', '東田川郡庄内町', 'ヒガシタガワグンショウナイマチ', '赤渕新田', 'アカブチシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146458', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東田川郡庄内町沢新田', '06', '06428', '9997725', '山形県', 'ヤマガタケン', '東田川郡庄内町', 'ヒガシタガワグンショウナイマチ', '沢新田', 'サワシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146459', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東田川郡庄内町古関', '06', '06428', '9997726', '山形県', 'ヤマガタケン', '東田川郡庄内町', 'ヒガシタガワグンショウナイマチ', '古関', 'フルセキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146460', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東田川郡庄内町南野', '06', '06428', '9997727', '山形県', 'ヤマガタケン', '東田川郡庄内町', 'ヒガシタガワグンショウナイマチ', '南野', 'ミナミノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146461', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東田川郡庄内町主殿新田', '06', '06428', '9997731', '山形県', 'ヤマガタケン', '東田川郡庄内町', 'ヒガシタガワグンショウナイマチ', '主殿新田', 'トノモシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146462', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東田川郡庄内町南野新田', '06', '06428', '9997732', '山形県', 'ヤマガタケン', '東田川郡庄内町', 'ヒガシタガワグンショウナイマチ', '南野新田', 'ミナミノシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146463', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東田川郡庄内町南興屋', '06', '06428', '9997733', '山形県', 'ヤマガタケン', '東田川郡庄内町', 'ヒガシタガワグンショウナイマチ', '南興屋', 'ミナミコウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146464', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東田川郡庄内町中野', '06', '06428', '9997734', '山形県', 'ヤマガタケン', '東田川郡庄内町', 'ヒガシタガワグンショウナイマチ', '中野', 'ナカノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146465', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東田川郡庄内町前田野目', '06', '06428', '9997735', '山形県', 'ヤマガタケン', '東田川郡庄内町', 'ヒガシタガワグンショウナイマチ', '前田野目', 'マエタノメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146466', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東田川郡庄内町福島', '06', '06428', '9997736', '山形県', 'ヤマガタケン', '東田川郡庄内町', 'ヒガシタガワグンショウナイマチ', '福島', 'フクシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146467', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東田川郡庄内町大真木', '06', '06428', '9997737', '山形県', 'ヤマガタケン', '東田川郡庄内町', 'ヒガシタガワグンショウナイマチ', '大真木', 'オオマギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146468', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東田川郡庄内町返吉', '06', '06428', '9997741', '山形県', 'ヤマガタケン', '東田川郡庄内町', 'ヒガシタガワグンショウナイマチ', '返吉', 'ソリヨシ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146469', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東田川郡庄内町京島', '06', '06428', '9997742', '山形県', 'ヤマガタケン', '東田川郡庄内町', 'ヒガシタガワグンショウナイマチ', '京島', 'キョウジマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146470', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東田川郡庄内町新田目', '06', '06428', '9997743', '山形県', 'ヤマガタケン', '東田川郡庄内町', 'ヒガシタガワグンショウナイマチ', '新田目', 'アラタメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146471', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東田川郡庄内町本小野方', '06', '06428', '9997744', '山形県', 'ヤマガタケン', '東田川郡庄内町', 'ヒガシタガワグンショウナイマチ', '本小野方', 'モトオノカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146472', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東田川郡庄内町境興屋', '06', '06428', '9997745', '山形県', 'ヤマガタケン', '東田川郡庄内町', 'ヒガシタガワグンショウナイマチ', '境興屋', 'サカイコウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146473', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東田川郡庄内町西袋', '06', '06428', '9997746', '山形県', 'ヤマガタケン', '東田川郡庄内町', 'ヒガシタガワグンショウナイマチ', '西袋', 'ニシブクロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146474', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東田川郡庄内町大野', '06', '06428', '9997747', '山形県', 'ヤマガタケン', '東田川郡庄内町', 'ヒガシタガワグンショウナイマチ', '大野', 'オオノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146475', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東田川郡庄内町田谷', '06', '06428', '9997748', '山形県', 'ヤマガタケン', '東田川郡庄内町', 'ヒガシタガワグンショウナイマチ', '田谷', 'タヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146476', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東田川郡庄内町吉方', '06', '06428', '9997749', '山形県', 'ヤマガタケン', '東田川郡庄内町', 'ヒガシタガワグンショウナイマチ', '吉方', 'ヨシカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146477', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東田川郡庄内町西小野方', '06', '06428', '9997751', '山形県', 'ヤマガタケン', '東田川郡庄内町', 'ヒガシタガワグンショウナイマチ', '西小野方', 'ニシオノカタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146478', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東田川郡庄内町近江新田', '06', '06428', '9997752', '山形県', 'ヤマガタケン', '東田川郡庄内町', 'ヒガシタガワグンショウナイマチ', '近江新田', 'オオミシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146479', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東田川郡庄内町吉岡', '06', '06428', '9997753', '山形県', 'ヤマガタケン', '東田川郡庄内町', 'ヒガシタガワグンショウナイマチ', '吉岡', 'ヨシオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146480', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東田川郡庄内町島田', '06', '06428', '9997754', '山形県', 'ヤマガタケン', '東田川郡庄内町', 'ヒガシタガワグンショウナイマチ', '島田', 'シマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146481', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東田川郡庄内町生三', '06', '06428', '9997755', '山形県', 'ヤマガタケン', '東田川郡庄内町', 'ヒガシタガワグンショウナイマチ', '生三', 'イクサン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146482', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東田川郡庄内町茗荷瀬', '06', '06428', '9997756', '山形県', 'ヤマガタケン', '東田川郡庄内町', 'ヒガシタガワグンショウナイマチ', '茗荷瀬', 'ミョウガセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146483', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東田川郡庄内町払田', '06', '06428', '9997757', '山形県', 'ヤマガタケン', '東田川郡庄内町', 'ヒガシタガワグンショウナイマチ', '払田', 'ハライダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146484', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東田川郡庄内町高田麦', '06', '06428', '9997761', '山形県', 'ヤマガタケン', '東田川郡庄内町', 'ヒガシタガワグンショウナイマチ', '高田麦', 'タカダムギ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146485', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東田川郡庄内町家根合', '06', '06428', '9997762', '山形県', 'ヤマガタケン', '東田川郡庄内町', 'ヒガシタガワグンショウナイマチ', '家根合', 'カネアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146486', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東田川郡庄内町落合', '06', '06428', '9997763', '山形県', 'ヤマガタケン', '東田川郡庄内町', 'ヒガシタガワグンショウナイマチ', '落合', 'オチアイ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146487', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東田川郡庄内町宮曽根', '06', '06428', '9997764', '山形県', 'ヤマガタケン', '東田川郡庄内町', 'ヒガシタガワグンショウナイマチ', '宮曽根', 'ミヤソネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146488', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東田川郡庄内町杉浦', '06', '06428', '9997765', '山形県', 'ヤマガタケン', '東田川郡庄内町', 'ヒガシタガワグンショウナイマチ', '杉浦', 'スギウラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146489', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東田川郡庄内町久田', '06', '06428', '9997766', '山形県', 'ヤマガタケン', '東田川郡庄内町', 'ヒガシタガワグンショウナイマチ', '久田', 'キュウデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146490', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東田川郡庄内町深川', '06', '06428', '9997767', '山形県', 'ヤマガタケン', '東田川郡庄内町', 'ヒガシタガワグンショウナイマチ', '深川', 'フカガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146491', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東田川郡庄内町西野', '06', '06428', '9997768', '山形県', 'ヤマガタケン', '東田川郡庄内町', 'ヒガシタガワグンショウナイマチ', '西野', 'ニシノ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146492', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市局', '06', '06204', '9997771', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '局', 'ツボネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146493', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市門田', '06', '06204', '9997772', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '門田', 'カドタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146494', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市木川', '06', '06204', '9997773', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '木川', 'キガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146495', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市板戸', '06', '06204', '9997774', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '板戸', 'イタド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146496', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市落野目', '06', '06204', '9997775', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '落野目', 'オチノメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146497', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市新堀', '06', '06204', '9997776', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '新堀', 'ニイボリ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146498', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市丸沼', '06', '06204', '9997777', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '丸沼', 'マルヌマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146499', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東田川郡庄内町余目', '06', '06428', '9997781', '山形県', 'ヤマガタケン', '東田川郡庄内町', 'ヒガシタガワグンショウナイマチ', '余目', 'アマルメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146500', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県東田川郡庄内町松陽', '06', '06428', '9997782', '山形県', 'ヤマガタケン', '東田川郡庄内町', 'ヒガシタガワグンショウナイマチ', '松陽', 'ショウヨウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146501', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市穂積門田', '06', '06204', '9998131', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '穂積', 'ホヅミ', null, null, '門田', 'モンデン');
INSERT INTO `ms_addresses` VALUES ('146502', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市刈屋', '06', '06204', '9998132', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '刈屋', 'カリヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146503', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市大豊田', '06', '06204', '9998133', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '大豊田', 'オオトヨダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146504', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市本楯', '06', '06204', '9998134', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '本楯', 'モトタテ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146505', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市豊原', '06', '06204', '9998141', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '豊原', 'トヨハラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146506', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市城輪', '06', '06204', '9998142', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '城輪', 'キノワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146507', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市刈穂', '06', '06204', '9998143', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '刈穂', 'カリホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146508', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市庭田', '06', '06204', '9998144', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '庭田', 'ニワタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146509', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市保岡', '06', '06204', '9998145', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '保岡', 'ヤスオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146510', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市安田', '06', '06204', '9998151', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '安田', 'ヤスダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146511', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市上安田', '06', '06204', '9998152', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '上安田', 'カミヤスダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146512', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市円能寺', '06', '06204', '9998153', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '円能寺', 'エンノウジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146513', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市古青渡', '06', '06204', '9998154', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '古青渡', 'フルアオド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146514', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市曽根田', '06', '06204', '9998155', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '曽根田', 'ソネダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146515', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市久保田', '06', '06204', '9998156', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '久保田', 'クボタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146516', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市新青渡', '06', '06204', '9998157', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '新青渡', 'ニイアオド', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146517', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市布目', '06', '06204', '9998158', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '布目', 'ヌノメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146518', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市吉田', '06', '06204', '9998161', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '吉田', 'ヨシダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146519', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市上野曽根', '06', '06204', '9998162', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '上野曽根', 'カミノソネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146520', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市上興野', '06', '06204', '9998163', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '上興野', 'カミコウヤ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146521', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市漆曽根', '06', '06204', '9998164', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '漆曽根', 'ウルシゾネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146522', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市中野曽根', '06', '06204', '9998165', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '中野曽根', 'ナカノソネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146523', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市牧曽根', '06', '06204', '9998166', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '牧曽根', 'マキソネ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146524', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市吉田新田', '06', '06204', '9998167', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '吉田新田', 'ヨシダシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146525', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市鶴田', '06', '06204', '9998168', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '鶴田', 'ツルタ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146526', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市升田', '06', '06204', '9998201', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '升田', 'マスダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146527', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市泥沢', '06', '06204', '9998202', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '泥沢', 'ドロザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146528', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市赤剥', '06', '06204', '9998203', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '赤剥', 'アカハゲ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146529', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市新出', '06', '06204', '9998204', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '新出', 'シンデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146530', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市下黒川', '06', '06204', '9998205', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '下黒川', 'シモクロカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146531', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市上黒川', '06', '06204', '9998206', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '上黒川', 'カミクロカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146532', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市草津', '06', '06204', '9998207', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '草津', 'クサツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146533', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市北青沢', '06', '06204', '9998211', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '北青沢', 'キタアオサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146534', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市上青沢', '06', '06204', '9998212', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '上青沢', 'カミアオサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146535', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市下青沢', '06', '06204', '9998213', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '下青沢', 'シモアオサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146536', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市常禅寺', '06', '06204', '9998214', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '常禅寺', 'ジョウゼンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146537', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市大蕨', '06', '06204', '9998215', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '大蕨', 'オオワラビ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146538', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市寺田', '06', '06204', '9998221', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '寺田', 'テラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146539', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市北平沢', '06', '06204', '9998222', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '北平沢', 'キタヘイザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146540', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市南平沢', '06', '06204', '9998223', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '南平沢', 'ミナミヘイザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146541', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市前川', '06', '06204', '9998224', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '前川', 'マエカワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146542', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市大島田', '06', '06204', '9998225', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '大島田', 'オオシマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146543', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市政所', '06', '06204', '9998226', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '政所', 'マンドコロ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146544', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市岡島田', '06', '06204', '9998227', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '岡島田', 'オカシマダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146545', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市麓', '06', '06204', '9998231', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '麓', 'フモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146546', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市市条', '06', '06204', '9998232', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '市条', 'イチジョウ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146547', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市法連寺', '06', '06204', '9998233', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '法連寺', 'ホウレンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146548', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市小泉', '06', '06204', '9998234', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '小泉', 'コイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146549', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市観音寺', '06', '06204', '9998235', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '観音寺', 'カンノンジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146550', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市福山', '06', '06204', '9998241', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '福山', 'フクヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146551', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市橋本', '06', '06204', '9998242', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '橋本', 'ハシモト', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146552', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市北仁田', '06', '06204', '9998243', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '北仁田', 'キタジンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146553', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市大久保', '06', '06204', '9998244', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '大久保', 'オオクボ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146554', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市塚淵', '06', '06204', '9998245', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '塚淵', 'ツカブチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146555', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市芹田', '06', '06204', '9998246', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '芹田', 'セツダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146557', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県飽海郡遊佐町', '06', '06461', '9998300', '山形県', 'ヤマガタケン', '飽海郡遊佐町', 'アクミグンユザマチ', null, '　', '（該当なし）', null, null, null);
INSERT INTO `ms_addresses` VALUES ('146558', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県飽海郡遊佐町遊佐', '06', '06461', '9998301', '山形県', 'ヤマガタケン', '飽海郡遊佐町', 'アクミグンユザマチ', '遊佐', 'ユザ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146559', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県飽海郡遊佐町吉出', '06', '06461', '9998302', '山形県', 'ヤマガタケン', '飽海郡遊佐町', 'アクミグンユザマチ', '吉出', 'ヨシデ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146560', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県飽海郡遊佐町野沢', '06', '06461', '9998303', '山形県', 'ヤマガタケン', '飽海郡遊佐町', 'アクミグンユザマチ', '野沢', 'ノザワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146561', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県飽海郡遊佐町白井新田', '06', '06461', '9998304', '山形県', 'ヤマガタケン', '飽海郡遊佐町', 'アクミグンユザマチ', '白井新田', 'シライシンデン', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146562', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県飽海郡遊佐町小原田', '06', '06461', '9998311', '山形県', 'ヤマガタケン', '飽海郡遊佐町', 'アクミグンユザマチ', '小原田', 'オハラダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146563', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県飽海郡遊佐町鹿野沢', '06', '06461', '9998312', '山形県', 'ヤマガタケン', '飽海郡遊佐町', 'アクミグンユザマチ', '鹿野沢', 'カノサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146564', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県飽海郡遊佐町杉沢', '06', '06461', '9998313', '山形県', 'ヤマガタケン', '飽海郡遊佐町', 'アクミグンユザマチ', '杉沢', 'スギサワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146565', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県飽海郡遊佐町上蕨岡', '06', '06461', '9998314', '山形県', 'ヤマガタケン', '飽海郡遊佐町', 'アクミグンユザマチ', '上蕨岡', 'カミワラビオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146566', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県飽海郡遊佐町大蕨岡', '06', '06461', '9998315', '山形県', 'ヤマガタケン', '飽海郡遊佐町', 'アクミグンユザマチ', '大蕨岡', 'オオワラビオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146567', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県飽海郡遊佐町豊岡', '06', '06461', '9998316', '山形県', 'ヤマガタケン', '飽海郡遊佐町', 'アクミグンユザマチ', '豊岡', 'トヨオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146568', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県飽海郡遊佐町小松', '06', '06461', '9998317', '山形県', 'ヤマガタケン', '飽海郡遊佐町', 'アクミグンユザマチ', '小松', 'コマツ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146569', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市米島', '06', '06204', '9998421', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '米島', 'ヨネシマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146570', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市千代田', '06', '06204', '9998422', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '千代田', 'チヨダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146571', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県酒田市宮内', '06', '06204', '9998423', '山形県', 'ヤマガタケン', '酒田市', 'サカタシ', '宮内', 'ミヤウチ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146572', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県飽海郡遊佐町菅里十里塚', '06', '06461', '9998431', '山形県', 'ヤマガタケン', '飽海郡遊佐町', 'アクミグンユザマチ', '菅里', 'スガサト', null, null, '十里塚', 'ジュウリヅカ');
INSERT INTO `ms_addresses` VALUES ('146573', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県飽海郡遊佐町宮田', '06', '06461', '9998432', '山形県', 'ヤマガタケン', '飽海郡遊佐町', 'アクミグンユザマチ', '宮田', 'ミヤダ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146574', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県飽海郡遊佐町江地', '06', '06461', '9998433', '山形県', 'ヤマガタケン', '飽海郡遊佐町', 'アクミグンユザマチ', '江地', 'エジ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146575', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県飽海郡遊佐町増穂', '06', '06461', '9998434', '山形県', 'ヤマガタケン', '飽海郡遊佐町', 'アクミグンユザマチ', '増穂', 'マスホ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146576', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県飽海郡遊佐町庄泉', '06', '06461', '9998435', '山形県', 'ヤマガタケン', '飽海郡遊佐町', 'アクミグンユザマチ', '庄泉', 'ショウイズミ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146577', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県飽海郡遊佐町岩川', '06', '06461', '9998436', '山形県', 'ヤマガタケン', '飽海郡遊佐町', 'アクミグンユザマチ', '岩川', 'イワガワ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146578', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県飽海郡遊佐町藤崎', '06', '06461', '9998437', '山形県', 'ヤマガタケン', '飽海郡遊佐町', 'アクミグンユザマチ', '藤崎', 'フジサキ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146579', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県飽海郡遊佐町比子', '06', '06461', '9998438', '山形県', 'ヤマガタケン', '飽海郡遊佐町', 'アクミグンユザマチ', '比子', 'ヒコ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146580', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県飽海郡遊佐町吹浦', '06', '06461', '9998521', '山形県', 'ヤマガタケン', '飽海郡遊佐町', 'アクミグンユザマチ', '吹浦', 'フクラ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146581', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県飽海郡遊佐町北目', '06', '06461', '9998522', '山形県', 'ヤマガタケン', '飽海郡遊佐町', 'アクミグンユザマチ', '北目', 'キタメ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146582', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県飽海郡遊佐町当山', '06', '06461', '9998523', '山形県', 'ヤマガタケン', '飽海郡遊佐町', 'アクミグンユザマチ', '当山', 'トウヤマ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146583', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県飽海郡遊佐町富岡', '06', '06461', '9998524', '山形県', 'ヤマガタケン', '飽海郡遊佐町', 'アクミグンユザマチ', '富岡', 'トミオカ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146584', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県飽海郡遊佐町直世', '06', '06461', '9998525', '山形県', 'ヤマガタケン', '飽海郡遊佐町', 'アクミグンユザマチ', '直世', 'スグセ', null, null, null, null);
INSERT INTO `ms_addresses` VALUES ('146585', 'SYSTEM', '2009-07-13 17:40:59', 'SYSTEM', '2009-07-13 17:40:59', '山形県飽海郡遊佐町菅里', '06', '06461', '9998531', '山形県', 'ヤマガタケン', '飽海郡遊佐町', 'アクミグンユザマチ', '菅里', 'スガサト', null, null, null, null);
INSERT INTO `ms_addresses_pref` VALUES ('1', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '北海道', '01');
INSERT INTO `ms_addresses_pref` VALUES ('2', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '秋田県', '05');
INSERT INTO `ms_addresses_pref` VALUES ('3', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '東京都', '13');
INSERT INTO `ms_addresses_pref` VALUES ('4', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '青森県', '02');
INSERT INTO `ms_addresses_pref` VALUES ('5', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '岩手県', '03');
INSERT INTO `ms_addresses_pref` VALUES ('6', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '神奈川県', '14');
INSERT INTO `ms_addresses_pref` VALUES ('7', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '千葉県', '12');
INSERT INTO `ms_addresses_pref` VALUES ('8', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '茨城県', '08');
INSERT INTO `ms_addresses_pref` VALUES ('9', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '栃木県', '09');
INSERT INTO `ms_addresses_pref` VALUES ('10', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '埼玉県', '11');
INSERT INTO `ms_addresses_pref` VALUES ('11', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '群馬県', '10');
INSERT INTO `ms_addresses_pref` VALUES ('12', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '長野県', '20');
INSERT INTO `ms_addresses_pref` VALUES ('13', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '新潟県', '15');
INSERT INTO `ms_addresses_pref` VALUES ('14', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '山梨県', '19');
INSERT INTO `ms_addresses_pref` VALUES ('15', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '静岡県', '22');
INSERT INTO `ms_addresses_pref` VALUES ('16', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '愛知県', '23');
INSERT INTO `ms_addresses_pref` VALUES ('17', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '三重県', '24');
INSERT INTO `ms_addresses_pref` VALUES ('18', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '岐阜県', '21');
INSERT INTO `ms_addresses_pref` VALUES ('19', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '滋賀県', '25');
INSERT INTO `ms_addresses_pref` VALUES ('20', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '京都府', '26');
INSERT INTO `ms_addresses_pref` VALUES ('21', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '大阪府', '27');
INSERT INTO `ms_addresses_pref` VALUES ('22', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '兵庫県', '28');
INSERT INTO `ms_addresses_pref` VALUES ('23', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '奈良県', '29');
INSERT INTO `ms_addresses_pref` VALUES ('24', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '和歌山県', '30');
INSERT INTO `ms_addresses_pref` VALUES ('25', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '鳥取県', '31');
INSERT INTO `ms_addresses_pref` VALUES ('26', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '島根県', '32');
INSERT INTO `ms_addresses_pref` VALUES ('27', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '岡山県', '33');
INSERT INTO `ms_addresses_pref` VALUES ('28', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '広島県', '34');
INSERT INTO `ms_addresses_pref` VALUES ('29', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '山口県', '35');
INSERT INTO `ms_addresses_pref` VALUES ('30', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '香川県', '37');
INSERT INTO `ms_addresses_pref` VALUES ('31', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '徳島県', '36');
INSERT INTO `ms_addresses_pref` VALUES ('32', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '高知県', '39');
INSERT INTO `ms_addresses_pref` VALUES ('33', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '愛媛県', '38');
INSERT INTO `ms_addresses_pref` VALUES ('34', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '福岡県', '40');
INSERT INTO `ms_addresses_pref` VALUES ('35', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '長崎県', '42');
INSERT INTO `ms_addresses_pref` VALUES ('36', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '大分県', '44');
INSERT INTO `ms_addresses_pref` VALUES ('37', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '佐賀県', '41');
INSERT INTO `ms_addresses_pref` VALUES ('38', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '熊本県', '43');
INSERT INTO `ms_addresses_pref` VALUES ('39', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '宮崎県', '45');
INSERT INTO `ms_addresses_pref` VALUES ('40', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '鹿児島県', '46');
INSERT INTO `ms_addresses_pref` VALUES ('41', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '沖縄県', '47');
INSERT INTO `ms_addresses_pref` VALUES ('42', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '福井県', '18');
INSERT INTO `ms_addresses_pref` VALUES ('43', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '石川県', '17');
INSERT INTO `ms_addresses_pref` VALUES ('44', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '富山県', '16');
INSERT INTO `ms_addresses_pref` VALUES ('45', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '福島県', '07');
INSERT INTO `ms_addresses_pref` VALUES ('46', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '宮城県', '04');
INSERT INTO `ms_addresses_pref` VALUES ('47', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '山形県', '06');
INSERT INTO `ms_addresses_pref` VALUES ('48', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '札幌市北区', '01');
INSERT INTO `ms_addresses_pref` VALUES ('49', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '秋田市', '05');
INSERT INTO `ms_addresses_pref` VALUES ('50', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '千代田区', '13');
INSERT INTO `ms_addresses_pref` VALUES ('51', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '大島町', '13');
INSERT INTO `ms_addresses_pref` VALUES ('52', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '利島村', '13');
INSERT INTO `ms_addresses_pref` VALUES ('53', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '新島村', '13');
INSERT INTO `ms_addresses_pref` VALUES ('54', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '神津島村', '13');
INSERT INTO `ms_addresses_pref` VALUES ('55', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '潟上市', '05');
INSERT INTO `ms_addresses_pref` VALUES ('56', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '三宅島三宅村', '13');
INSERT INTO `ms_addresses_pref` VALUES ('57', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '御蔵島村', '13');
INSERT INTO `ms_addresses_pref` VALUES ('58', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '八丈島八丈町', '13');
INSERT INTO `ms_addresses_pref` VALUES ('59', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '青ヶ島村', '13');
INSERT INTO `ms_addresses_pref` VALUES ('60', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '小笠原村', '13');
INSERT INTO `ms_addresses_pref` VALUES ('61', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '男鹿市', '05');
INSERT INTO `ms_addresses_pref` VALUES ('62', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '南秋田郡大潟村', '05');
INSERT INTO `ms_addresses_pref` VALUES ('63', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '中央区', '13');
INSERT INTO `ms_addresses_pref` VALUES ('64', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '港区', '13');
INSERT INTO `ms_addresses_pref` VALUES ('65', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '台東区', '13');
INSERT INTO `ms_addresses_pref` VALUES ('66', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '文京区', '13');
INSERT INTO `ms_addresses_pref` VALUES ('67', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '北区', '13');
INSERT INTO `ms_addresses_pref` VALUES ('68', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '荒川区', '13');
INSERT INTO `ms_addresses_pref` VALUES ('69', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '湯沢市', '05');
INSERT INTO `ms_addresses_pref` VALUES ('70', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '足立区', '13');
INSERT INTO `ms_addresses_pref` VALUES ('71', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '雄勝郡羽後町', '05');
INSERT INTO `ms_addresses_pref` VALUES ('72', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '葛飾区', '13');
INSERT INTO `ms_addresses_pref` VALUES ('73', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '横手市', '05');
INSERT INTO `ms_addresses_pref` VALUES ('74', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '墨田区', '13');
INSERT INTO `ms_addresses_pref` VALUES ('75', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '江戸川区', '13');
INSERT INTO `ms_addresses_pref` VALUES ('76', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '江東区', '13');
INSERT INTO `ms_addresses_pref` VALUES ('77', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '品川区', '13');
INSERT INTO `ms_addresses_pref` VALUES ('78', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '大仙市', '05');
INSERT INTO `ms_addresses_pref` VALUES ('79', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '仙北市', '05');
INSERT INTO `ms_addresses_pref` VALUES ('80', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '大田区', '13');
INSERT INTO `ms_addresses_pref` VALUES ('81', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '由利本荘市', '05');
INSERT INTO `ms_addresses_pref` VALUES ('82', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '渋谷区', '13');
INSERT INTO `ms_addresses_pref` VALUES ('83', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '目黒区', '13');
INSERT INTO `ms_addresses_pref` VALUES ('84', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '世田谷区', '13');
INSERT INTO `ms_addresses_pref` VALUES ('85', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '能代市', '05');
INSERT INTO `ms_addresses_pref` VALUES ('86', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '新宿区', '13');
INSERT INTO `ms_addresses_pref` VALUES ('87', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '中野区', '13');
INSERT INTO `ms_addresses_pref` VALUES ('88', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '杉並区', '13');
INSERT INTO `ms_addresses_pref` VALUES ('89', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '大館市', '05');
INSERT INTO `ms_addresses_pref` VALUES ('90', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '豊島区', '13');
INSERT INTO `ms_addresses_pref` VALUES ('91', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '鹿角郡小坂町', '05');
INSERT INTO `ms_addresses_pref` VALUES ('92', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '板橋区', '13');
INSERT INTO `ms_addresses_pref` VALUES ('93', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '練馬区', '13');
INSERT INTO `ms_addresses_pref` VALUES ('94', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '武蔵野市', '13');
INSERT INTO `ms_addresses_pref` VALUES ('95', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', 'にかほ市', '05');
INSERT INTO `ms_addresses_pref` VALUES ('96', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '三鷹市', '13');
INSERT INTO `ms_addresses_pref` VALUES ('97', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '南秋田郡井川町', '05');
INSERT INTO `ms_addresses_pref` VALUES ('98', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '南秋田郡八郎潟町', '05');
INSERT INTO `ms_addresses_pref` VALUES ('99', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '南秋田郡五城目町', '05');
INSERT INTO `ms_addresses_pref` VALUES ('100', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '調布市', '13');
INSERT INTO `ms_addresses_pref` VALUES ('101', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '山本郡三種町', '05');
INSERT INTO `ms_addresses_pref` VALUES ('102', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '山本郡八峰町', '05');
INSERT INTO `ms_addresses_pref` VALUES ('103', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '府中市', '13');
INSERT INTO `ms_addresses_pref` VALUES ('104', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '山本郡藤里町', '05');
INSERT INTO `ms_addresses_pref` VALUES ('105', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '北秋田市', '05');
INSERT INTO `ms_addresses_pref` VALUES ('106', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '小金井市', '13');
INSERT INTO `ms_addresses_pref` VALUES ('107', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '北秋田郡上小阿仁村', '05');
INSERT INTO `ms_addresses_pref` VALUES ('108', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '国分寺市', '13');
INSERT INTO `ms_addresses_pref` VALUES ('109', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '鹿角市', '05');
INSERT INTO `ms_addresses_pref` VALUES ('110', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '十和田市', '02');
INSERT INTO `ms_addresses_pref` VALUES ('111', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '国立市', '13');
INSERT INTO `ms_addresses_pref` VALUES ('112', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '小平市', '13');
INSERT INTO `ms_addresses_pref` VALUES ('113', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '西東京市', '13');
INSERT INTO `ms_addresses_pref` VALUES ('114', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '東村山市', '13');
INSERT INTO `ms_addresses_pref` VALUES ('115', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '立川市', '13');
INSERT INTO `ms_addresses_pref` VALUES ('116', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', 'あきる野市', '13');
INSERT INTO `ms_addresses_pref` VALUES ('117', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '西多摩郡日の出町', '13');
INSERT INTO `ms_addresses_pref` VALUES ('118', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '西多摩郡檜原村', '13');
INSERT INTO `ms_addresses_pref` VALUES ('119', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '西多摩郡瑞穂町', '13');
INSERT INTO `ms_addresses_pref` VALUES ('120', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '雄勝郡東成瀬村', '05');
INSERT INTO `ms_addresses_pref` VALUES ('121', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '日野市', '13');
INSERT INTO `ms_addresses_pref` VALUES ('122', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '仙北郡美郷町', '05');
INSERT INTO `ms_addresses_pref` VALUES ('123', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '八王子市', '13');
INSERT INTO `ms_addresses_pref` VALUES ('124', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '町田市', '13');
INSERT INTO `ms_addresses_pref` VALUES ('125', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '昭島市', '13');
INSERT INTO `ms_addresses_pref` VALUES ('126', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '福生市', '13');
INSERT INTO `ms_addresses_pref` VALUES ('127', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '青梅市', '13');
INSERT INTO `ms_addresses_pref` VALUES ('128', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '西多摩郡奥多摩町', '13');
INSERT INTO `ms_addresses_pref` VALUES ('129', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '盛岡市', '03');
INSERT INTO `ms_addresses_pref` VALUES ('130', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '岩手郡滝沢村', '03');
INSERT INTO `ms_addresses_pref` VALUES ('131', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '岩手郡雫石町', '03');
INSERT INTO `ms_addresses_pref` VALUES ('132', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '紫波郡矢巾町', '03');
INSERT INTO `ms_addresses_pref` VALUES ('133', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '狛江市', '13');
INSERT INTO `ms_addresses_pref` VALUES ('134', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '東久留米市', '13');
INSERT INTO `ms_addresses_pref` VALUES ('135', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '清瀬市', '13');
INSERT INTO `ms_addresses_pref` VALUES ('136', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '羽村市', '13');
INSERT INTO `ms_addresses_pref` VALUES ('137', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '多摩市', '13');
INSERT INTO `ms_addresses_pref` VALUES ('138', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '稲城市', '13');
INSERT INTO `ms_addresses_pref` VALUES ('139', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '東大和市', '13');
INSERT INTO `ms_addresses_pref` VALUES ('140', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '武蔵村山市', '13');
INSERT INTO `ms_addresses_pref` VALUES ('141', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '一関市', '03');
INSERT INTO `ms_addresses_pref` VALUES ('142', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '川崎市川崎区', '14');
INSERT INTO `ms_addresses_pref` VALUES ('143', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '川崎市中原区', '14');
INSERT INTO `ms_addresses_pref` VALUES ('144', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '川崎市幸区', '14');
INSERT INTO `ms_addresses_pref` VALUES ('145', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '川崎市高津区', '14');
INSERT INTO `ms_addresses_pref` VALUES ('146', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '川崎市多摩区', '14');
INSERT INTO `ms_addresses_pref` VALUES ('147', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '川崎市麻生区', '14');
INSERT INTO `ms_addresses_pref` VALUES ('148', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '川崎市宮前区', '14');
INSERT INTO `ms_addresses_pref` VALUES ('149', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '大船渡市', '03');
INSERT INTO `ms_addresses_pref` VALUES ('150', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '横浜市西区', '14');
INSERT INTO `ms_addresses_pref` VALUES ('151', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '相模原市', '14');
INSERT INTO `ms_addresses_pref` VALUES ('152', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '横浜市神奈川区', '14');
INSERT INTO `ms_addresses_pref` VALUES ('153', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '横浜市港北区', '14');
INSERT INTO `ms_addresses_pref` VALUES ('154', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '横浜市都筑区', '14');
INSERT INTO `ms_addresses_pref` VALUES ('155', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '横浜市青葉区', '14');
INSERT INTO `ms_addresses_pref` VALUES ('156', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '横浜市緑区', '14');
INSERT INTO `ms_addresses_pref` VALUES ('157', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '座間市', '14');
INSERT INTO `ms_addresses_pref` VALUES ('158', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '奥州市', '03');
INSERT INTO `ms_addresses_pref` VALUES ('159', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '横浜市鶴見区', '14');
INSERT INTO `ms_addresses_pref` VALUES ('160', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '横浜市中区', '14');
INSERT INTO `ms_addresses_pref` VALUES ('161', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '横浜市南区', '14');
INSERT INTO `ms_addresses_pref` VALUES ('162', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '横浜市港南区', '14');
INSERT INTO `ms_addresses_pref` VALUES ('163', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '横浜市磯子区', '14');
INSERT INTO `ms_addresses_pref` VALUES ('164', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '横浜市金沢区', '14');
INSERT INTO `ms_addresses_pref` VALUES ('165', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '横須賀市', '14');
INSERT INTO `ms_addresses_pref` VALUES ('166', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '三浦市', '14');
INSERT INTO `ms_addresses_pref` VALUES ('167', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '北上市', '03');
INSERT INTO `ms_addresses_pref` VALUES ('168', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '横浜市保土ケ谷区', '14');
INSERT INTO `ms_addresses_pref` VALUES ('169', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '三浦郡葉山町', '14');
INSERT INTO `ms_addresses_pref` VALUES ('170', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '和賀郡西和賀町', '03');
INSERT INTO `ms_addresses_pref` VALUES ('171', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '横浜市旭区', '14');
INSERT INTO `ms_addresses_pref` VALUES ('172', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '大和市', '14');
INSERT INTO `ms_addresses_pref` VALUES ('173', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '厚木市', '14');
INSERT INTO `ms_addresses_pref` VALUES ('174', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '愛甲郡清川村', '14');
INSERT INTO `ms_addresses_pref` VALUES ('175', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '愛甲郡愛川町', '14');
INSERT INTO `ms_addresses_pref` VALUES ('176', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '海老名市', '14');
INSERT INTO `ms_addresses_pref` VALUES ('177', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '横浜市戸塚区', '14');
INSERT INTO `ms_addresses_pref` VALUES ('178', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '横浜市栄区', '14');
INSERT INTO `ms_addresses_pref` VALUES ('179', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '横浜市泉区', '14');
INSERT INTO `ms_addresses_pref` VALUES ('180', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '横浜市瀬谷区', '14');
INSERT INTO `ms_addresses_pref` VALUES ('181', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '鎌倉市', '14');
INSERT INTO `ms_addresses_pref` VALUES ('182', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '逗子市', '14');
INSERT INTO `ms_addresses_pref` VALUES ('183', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '花巻市', '03');
INSERT INTO `ms_addresses_pref` VALUES ('184', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '小田原市', '14');
INSERT INTO `ms_addresses_pref` VALUES ('185', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '南足柄市', '14');
INSERT INTO `ms_addresses_pref` VALUES ('186', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '足柄下郡箱根町', '14');
INSERT INTO `ms_addresses_pref` VALUES ('187', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '藤沢市', '14');
INSERT INTO `ms_addresses_pref` VALUES ('188', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '綾瀬市', '14');
INSERT INTO `ms_addresses_pref` VALUES ('189', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '茅ヶ崎市', '14');
INSERT INTO `ms_addresses_pref` VALUES ('190', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '高座郡寒川町', '14');
INSERT INTO `ms_addresses_pref` VALUES ('191', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '平塚市', '14');
INSERT INTO `ms_addresses_pref` VALUES ('192', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '中郡大磯町', '14');
INSERT INTO `ms_addresses_pref` VALUES ('193', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '秦野市', '14');
INSERT INTO `ms_addresses_pref` VALUES ('194', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '足柄上郡大井町', '14');
INSERT INTO `ms_addresses_pref` VALUES ('195', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '足柄上郡松田町', '14');
INSERT INTO `ms_addresses_pref` VALUES ('196', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '足柄上郡開成町', '14');
INSERT INTO `ms_addresses_pref` VALUES ('197', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '足柄上郡山北町', '14');
INSERT INTO `ms_addresses_pref` VALUES ('198', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '中郡二宮町', '14');
INSERT INTO `ms_addresses_pref` VALUES ('199', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '足柄上郡中井町', '14');
INSERT INTO `ms_addresses_pref` VALUES ('200', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '足柄下郡真鶴町', '14');
INSERT INTO `ms_addresses_pref` VALUES ('201', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '足柄下郡湯河原町', '14');
INSERT INTO `ms_addresses_pref` VALUES ('202', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '伊勢原市', '14');
INSERT INTO `ms_addresses_pref` VALUES ('203', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '釜石市', '03');
INSERT INTO `ms_addresses_pref` VALUES ('204', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '千葉市中央区', '12');
INSERT INTO `ms_addresses_pref` VALUES ('205', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '千葉市美浜区', '12');
INSERT INTO `ms_addresses_pref` VALUES ('206', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '千葉市花見川区', '12');
INSERT INTO `ms_addresses_pref` VALUES ('207', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '千葉市稲毛区', '12');
INSERT INTO `ms_addresses_pref` VALUES ('208', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '千葉市若葉区', '12');
INSERT INTO `ms_addresses_pref` VALUES ('209', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '千葉市緑区', '12');
INSERT INTO `ms_addresses_pref` VALUES ('210', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '宮古市', '03');
INSERT INTO `ms_addresses_pref` VALUES ('211', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '松戸市', '12');
INSERT INTO `ms_addresses_pref` VALUES ('212', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '流山市', '12');
INSERT INTO `ms_addresses_pref` VALUES ('213', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '野田市', '12');
INSERT INTO `ms_addresses_pref` VALUES ('214', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '我孫子市', '12');
INSERT INTO `ms_addresses_pref` VALUES ('215', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '印西市', '12');
INSERT INTO `ms_addresses_pref` VALUES ('216', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '白井市', '12');
INSERT INTO `ms_addresses_pref` VALUES ('217', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '柏市', '12');
INSERT INTO `ms_addresses_pref` VALUES ('218', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '船橋市', '12');
INSERT INTO `ms_addresses_pref` VALUES ('219', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '印旛郡栄町', '12');
INSERT INTO `ms_addresses_pref` VALUES ('220', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '印旛郡印旛村', '12');
INSERT INTO `ms_addresses_pref` VALUES ('221', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '印旛郡本埜村', '12');
INSERT INTO `ms_addresses_pref` VALUES ('222', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '下閉伊郡岩泉町', '03');
INSERT INTO `ms_addresses_pref` VALUES ('223', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '市川市', '12');
INSERT INTO `ms_addresses_pref` VALUES ('224', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '鎌ケ谷市', '12');
INSERT INTO `ms_addresses_pref` VALUES ('225', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '習志野市', '12');
INSERT INTO `ms_addresses_pref` VALUES ('226', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '八千代市', '12');
INSERT INTO `ms_addresses_pref` VALUES ('227', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '浦安市', '12');
INSERT INTO `ms_addresses_pref` VALUES ('228', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '久慈市', '03');
INSERT INTO `ms_addresses_pref` VALUES ('229', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '遠野市', '03');
INSERT INTO `ms_addresses_pref` VALUES ('230', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '石狩郡当別町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('231', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '上閉伊郡大槌町', '03');
INSERT INTO `ms_addresses_pref` VALUES ('232', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '下閉伊郡山田町', '03');
INSERT INTO `ms_addresses_pref` VALUES ('233', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '成田市', '12');
INSERT INTO `ms_addresses_pref` VALUES ('234', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '香取郡多古町', '12');
INSERT INTO `ms_addresses_pref` VALUES ('235', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '山武郡芝山町', '12');
INSERT INTO `ms_addresses_pref` VALUES ('236', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '下閉伊郡川井村', '03');
INSERT INTO `ms_addresses_pref` VALUES ('237', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '東金市', '12');
INSERT INTO `ms_addresses_pref` VALUES ('238', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '山武郡九十九里町', '12');
INSERT INTO `ms_addresses_pref` VALUES ('239', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '紫波郡紫波町', '03');
INSERT INTO `ms_addresses_pref` VALUES ('240', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '四街道市', '12');
INSERT INTO `ms_addresses_pref` VALUES ('241', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '岩手郡岩手町', '03');
INSERT INTO `ms_addresses_pref` VALUES ('242', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '佐倉市', '12');
INSERT INTO `ms_addresses_pref` VALUES ('243', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '印旛郡酒々井町', '12');
INSERT INTO `ms_addresses_pref` VALUES ('244', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '岩手郡葛巻町', '03');
INSERT INTO `ms_addresses_pref` VALUES ('245', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '二戸郡一戸町', '03');
INSERT INTO `ms_addresses_pref` VALUES ('246', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '二戸市', '03');
INSERT INTO `ms_addresses_pref` VALUES ('247', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '富里市', '12');
INSERT INTO `ms_addresses_pref` VALUES ('248', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '九戸郡軽米町', '03');
INSERT INTO `ms_addresses_pref` VALUES ('249', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '九戸郡九戸村', '03');
INSERT INTO `ms_addresses_pref` VALUES ('250', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '香取市', '12');
INSERT INTO `ms_addresses_pref` VALUES ('251', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '八幡平市', '03');
INSERT INTO `ms_addresses_pref` VALUES ('252', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '九戸郡洋野町', '03');
INSERT INTO `ms_addresses_pref` VALUES ('253', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '銚子市', '12');
INSERT INTO `ms_addresses_pref` VALUES ('254', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '九戸郡野田村', '03');
INSERT INTO `ms_addresses_pref` VALUES ('255', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '下閉伊郡普代村', '03');
INSERT INTO `ms_addresses_pref` VALUES ('256', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '下閉伊郡田野畑村', '03');
INSERT INTO `ms_addresses_pref` VALUES ('257', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '香取郡神崎町', '12');
INSERT INTO `ms_addresses_pref` VALUES ('258', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '旭市', '12');
INSERT INTO `ms_addresses_pref` VALUES ('259', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '香取郡東庄町', '12');
INSERT INTO `ms_addresses_pref` VALUES ('260', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '八街市', '12');
INSERT INTO `ms_addresses_pref` VALUES ('261', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '山武市', '12');
INSERT INTO `ms_addresses_pref` VALUES ('262', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '山武郡横芝光町', '12');
INSERT INTO `ms_addresses_pref` VALUES ('263', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '匝瑳市', '12');
INSERT INTO `ms_addresses_pref` VALUES ('264', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '市原市', '12');
INSERT INTO `ms_addresses_pref` VALUES ('265', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '木更津市', '12');
INSERT INTO `ms_addresses_pref` VALUES ('266', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '君津市', '12');
INSERT INTO `ms_addresses_pref` VALUES ('267', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '陸前高田市', '03');
INSERT INTO `ms_addresses_pref` VALUES ('268', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '気仙郡住田町', '03');
INSERT INTO `ms_addresses_pref` VALUES ('269', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '富津市', '12');
INSERT INTO `ms_addresses_pref` VALUES ('270', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '東磐井郡藤沢町', '03');
INSERT INTO `ms_addresses_pref` VALUES ('271', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '館山市', '12');
INSERT INTO `ms_addresses_pref` VALUES ('272', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '南房総市', '12');
INSERT INTO `ms_addresses_pref` VALUES ('273', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '西磐井郡平泉町', '03');
INSERT INTO `ms_addresses_pref` VALUES ('274', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '胆沢郡金ケ崎町', '03');
INSERT INTO `ms_addresses_pref` VALUES ('275', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '鴨川市', '12');
INSERT INTO `ms_addresses_pref` VALUES ('276', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '茂原市', '12');
INSERT INTO `ms_addresses_pref` VALUES ('277', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '長生郡長南町', '12');
INSERT INTO `ms_addresses_pref` VALUES ('278', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '長生郡長柄町', '12');
INSERT INTO `ms_addresses_pref` VALUES ('279', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', 'いすみ市', '12');
INSERT INTO `ms_addresses_pref` VALUES ('280', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '夷隅郡大多喜町', '12');
INSERT INTO `ms_addresses_pref` VALUES ('281', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '袖ケ浦市', '12');
INSERT INTO `ms_addresses_pref` VALUES ('282', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '安房郡鋸南町', '12');
INSERT INTO `ms_addresses_pref` VALUES ('283', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '山武郡大網白里町', '12');
INSERT INTO `ms_addresses_pref` VALUES ('284', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '長生郡白子町', '12');
INSERT INTO `ms_addresses_pref` VALUES ('285', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '長生郡一宮町', '12');
INSERT INTO `ms_addresses_pref` VALUES ('286', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '長生郡長生村', '12');
INSERT INTO `ms_addresses_pref` VALUES ('287', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '長生郡睦沢町', '12');
INSERT INTO `ms_addresses_pref` VALUES ('288', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '夷隅郡御宿町', '12');
INSERT INTO `ms_addresses_pref` VALUES ('289', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '勝浦市', '12');
INSERT INTO `ms_addresses_pref` VALUES ('290', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '札幌市白石区', '01');
INSERT INTO `ms_addresses_pref` VALUES ('291', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '土浦市', '08');
INSERT INTO `ms_addresses_pref` VALUES ('292', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', 'かすみがうら市', '08');
INSERT INTO `ms_addresses_pref` VALUES ('293', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '稲敷郡阿見町', '08');
INSERT INTO `ms_addresses_pref` VALUES ('294', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '稲敷郡美浦村', '08');
INSERT INTO `ms_addresses_pref` VALUES ('295', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '稲敷市', '08');
INSERT INTO `ms_addresses_pref` VALUES ('296', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '青森市', '02');
INSERT INTO `ms_addresses_pref` VALUES ('297', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '牛久市', '08');
INSERT INTO `ms_addresses_pref` VALUES ('298', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', 'つくば市', '08');
INSERT INTO `ms_addresses_pref` VALUES ('299', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '稲敷郡河内町', '08');
INSERT INTO `ms_addresses_pref` VALUES ('300', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '取手市', '08');
INSERT INTO `ms_addresses_pref` VALUES ('301', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '北相馬郡利根町', '08');
INSERT INTO `ms_addresses_pref` VALUES ('302', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', 'つくばみらい市', '08');
INSERT INTO `ms_addresses_pref` VALUES ('303', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '常総市', '08');
INSERT INTO `ms_addresses_pref` VALUES ('304', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '結城郡八千代町', '08');
INSERT INTO `ms_addresses_pref` VALUES ('305', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '桜川市', '08');
INSERT INTO `ms_addresses_pref` VALUES ('306', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '筑西市', '08');
INSERT INTO `ms_addresses_pref` VALUES ('307', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '龍ケ崎市', '08');
INSERT INTO `ms_addresses_pref` VALUES ('308', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '東津軽郡蓬田村', '02');
INSERT INTO `ms_addresses_pref` VALUES ('309', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '東津軽郡外ヶ浜町', '02');
INSERT INTO `ms_addresses_pref` VALUES ('310', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '東津軽郡今別町', '02');
INSERT INTO `ms_addresses_pref` VALUES ('311', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '北津軽郡中泊町', '02');
INSERT INTO `ms_addresses_pref` VALUES ('312', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '守谷市', '08');
INSERT INTO `ms_addresses_pref` VALUES ('313', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '下妻市', '08');
INSERT INTO `ms_addresses_pref` VALUES ('314', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '古河市', '08');
INSERT INTO `ms_addresses_pref` VALUES ('315', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '猿島郡五霞町', '08');
INSERT INTO `ms_addresses_pref` VALUES ('316', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '猿島郡境町', '08');
INSERT INTO `ms_addresses_pref` VALUES ('317', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '坂東市', '08');
INSERT INTO `ms_addresses_pref` VALUES ('318', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '結城市', '08');
INSERT INTO `ms_addresses_pref` VALUES ('319', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '笠間市', '08');
INSERT INTO `ms_addresses_pref` VALUES ('320', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '八戸市', '02');
INSERT INTO `ms_addresses_pref` VALUES ('321', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '水戸市', '08');
INSERT INTO `ms_addresses_pref` VALUES ('322', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '那珂市', '08');
INSERT INTO `ms_addresses_pref` VALUES ('323', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '常陸太田市', '08');
INSERT INTO `ms_addresses_pref` VALUES ('324', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '日立市', '08');
INSERT INTO `ms_addresses_pref` VALUES ('325', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', 'ひたちなか市', '08');
INSERT INTO `ms_addresses_pref` VALUES ('326', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '東茨城郡大洗町', '08');
INSERT INTO `ms_addresses_pref` VALUES ('327', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '鉾田市', '08');
INSERT INTO `ms_addresses_pref` VALUES ('328', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '行方市', '08');
INSERT INTO `ms_addresses_pref` VALUES ('329', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '鹿嶋市', '08');
INSERT INTO `ms_addresses_pref` VALUES ('330', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '潮来市', '08');
INSERT INTO `ms_addresses_pref` VALUES ('331', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '東茨城郡茨城町', '08');
INSERT INTO `ms_addresses_pref` VALUES ('332', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '小美玉市', '08');
INSERT INTO `ms_addresses_pref` VALUES ('333', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '東茨城郡城里町', '08');
INSERT INTO `ms_addresses_pref` VALUES ('334', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '芳賀郡茂木町', '09');
INSERT INTO `ms_addresses_pref` VALUES ('335', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '常陸大宮市', '08');
INSERT INTO `ms_addresses_pref` VALUES ('336', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '神栖市', '08');
INSERT INTO `ms_addresses_pref` VALUES ('337', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '石岡市', '08');
INSERT INTO `ms_addresses_pref` VALUES ('338', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '高萩市', '08');
INSERT INTO `ms_addresses_pref` VALUES ('339', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '那珂郡東海村', '08');
INSERT INTO `ms_addresses_pref` VALUES ('340', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '北茨城市', '08');
INSERT INTO `ms_addresses_pref` VALUES ('341', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '久慈郡大子町', '08');
INSERT INTO `ms_addresses_pref` VALUES ('342', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '宇都宮市', '09');
INSERT INTO `ms_addresses_pref` VALUES ('343', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '下都賀郡壬生町', '09');
INSERT INTO `ms_addresses_pref` VALUES ('344', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '那須烏山市', '09');
INSERT INTO `ms_addresses_pref` VALUES ('345', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '日光市', '09');
INSERT INTO `ms_addresses_pref` VALUES ('346', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '鹿沼市', '09');
INSERT INTO `ms_addresses_pref` VALUES ('347', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '塩谷郡塩谷町', '09');
INSERT INTO `ms_addresses_pref` VALUES ('348', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '芳賀郡芳賀町', '09');
INSERT INTO `ms_addresses_pref` VALUES ('349', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '芳賀郡市貝町', '09');
INSERT INTO `ms_addresses_pref` VALUES ('350', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '芳賀郡益子町', '09');
INSERT INTO `ms_addresses_pref` VALUES ('351', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '真岡市', '09');
INSERT INTO `ms_addresses_pref` VALUES ('352', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '上都賀郡西方町', '09');
INSERT INTO `ms_addresses_pref` VALUES ('353', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '小山市', '09');
INSERT INTO `ms_addresses_pref` VALUES ('354', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '下野市', '09');
INSERT INTO `ms_addresses_pref` VALUES ('355', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '下都賀郡藤岡町', '09');
INSERT INTO `ms_addresses_pref` VALUES ('356', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '大田原市', '09');
INSERT INTO `ms_addresses_pref` VALUES ('357', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '那須郡那珂川町', '09');
INSERT INTO `ms_addresses_pref` VALUES ('358', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '那須塩原市', '09');
INSERT INTO `ms_addresses_pref` VALUES ('359', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '那須郡那須町', '09');
INSERT INTO `ms_addresses_pref` VALUES ('360', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '足利市', '09');
INSERT INTO `ms_addresses_pref` VALUES ('361', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '佐野市', '09');
INSERT INTO `ms_addresses_pref` VALUES ('362', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '栃木市', '09');
INSERT INTO `ms_addresses_pref` VALUES ('363', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '下都賀郡都賀町', '09');
INSERT INTO `ms_addresses_pref` VALUES ('364', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '下都賀郡野木町', '09');
INSERT INTO `ms_addresses_pref` VALUES ('365', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '河内郡上三川町', '09');
INSERT INTO `ms_addresses_pref` VALUES ('366', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '塩谷郡高根沢町', '09');
INSERT INTO `ms_addresses_pref` VALUES ('367', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', 'さくら市', '09');
INSERT INTO `ms_addresses_pref` VALUES ('368', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '矢板市', '09');
INSERT INTO `ms_addresses_pref` VALUES ('369', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '下都賀郡岩舟町', '09');
INSERT INTO `ms_addresses_pref` VALUES ('370', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '下都賀郡大平町', '09');
INSERT INTO `ms_addresses_pref` VALUES ('371', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '三沢市', '02');
INSERT INTO `ms_addresses_pref` VALUES ('372', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', 'さいたま市中央区', '11');
INSERT INTO `ms_addresses_pref` VALUES ('373', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', 'さいたま市浦和区', '11');
INSERT INTO `ms_addresses_pref` VALUES ('374', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '上北郡六戸町', '02');
INSERT INTO `ms_addresses_pref` VALUES ('375', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', 'さいたま市大宮区', '11');
INSERT INTO `ms_addresses_pref` VALUES ('376', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', 'さいたま市西区', '11');
INSERT INTO `ms_addresses_pref` VALUES ('377', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', 'さいたま市北区', '11');
INSERT INTO `ms_addresses_pref` VALUES ('378', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '川口市', '11');
INSERT INTO `ms_addresses_pref` VALUES ('379', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '鳩ケ谷市', '11');
INSERT INTO `ms_addresses_pref` VALUES ('380', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '蕨市', '11');
INSERT INTO `ms_addresses_pref` VALUES ('381', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '戸田市', '11');
INSERT INTO `ms_addresses_pref` VALUES ('382', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', 'さいたま市南区', '11');
INSERT INTO `ms_addresses_pref` VALUES ('383', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', 'さいたま市緑区', '11');
INSERT INTO `ms_addresses_pref` VALUES ('384', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', 'さいたま市見沼区', '11');
INSERT INTO `ms_addresses_pref` VALUES ('385', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', 'さいたま市桜区', '11');
INSERT INTO `ms_addresses_pref` VALUES ('386', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', 'さいたま市岩槻区', '11');
INSERT INTO `ms_addresses_pref` VALUES ('387', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '草加市', '11');
INSERT INTO `ms_addresses_pref` VALUES ('388', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '幸手市', '11');
INSERT INTO `ms_addresses_pref` VALUES ('389', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '北葛飾郡鷲宮町', '11');
INSERT INTO `ms_addresses_pref` VALUES ('390', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '八潮市', '11');
INSERT INTO `ms_addresses_pref` VALUES ('391', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '三郷市', '11');
INSERT INTO `ms_addresses_pref` VALUES ('392', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '吉川市', '11');
INSERT INTO `ms_addresses_pref` VALUES ('393', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '越谷市', '11');
INSERT INTO `ms_addresses_pref` VALUES ('394', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '北葛飾郡松伏町', '11');
INSERT INTO `ms_addresses_pref` VALUES ('395', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '春日部市', '11');
INSERT INTO `ms_addresses_pref` VALUES ('396', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '南埼玉郡宮代町', '11');
INSERT INTO `ms_addresses_pref` VALUES ('397', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '北葛飾郡杉戸町', '11');
INSERT INTO `ms_addresses_pref` VALUES ('398', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '久喜市', '11');
INSERT INTO `ms_addresses_pref` VALUES ('399', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '南埼玉郡菖蒲町', '11');
INSERT INTO `ms_addresses_pref` VALUES ('400', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '加須市', '11');
INSERT INTO `ms_addresses_pref` VALUES ('401', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '北埼玉郡騎西町', '11');
INSERT INTO `ms_addresses_pref` VALUES ('402', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '羽生市', '11');
INSERT INTO `ms_addresses_pref` VALUES ('403', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '蓮田市', '11');
INSERT INTO `ms_addresses_pref` VALUES ('404', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '南埼玉郡白岡町', '11');
INSERT INTO `ms_addresses_pref` VALUES ('405', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '北埼玉郡大利根町', '11');
INSERT INTO `ms_addresses_pref` VALUES ('406', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '北葛飾郡栗橋町', '11');
INSERT INTO `ms_addresses_pref` VALUES ('407', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '北埼玉郡北川辺町', '11');
INSERT INTO `ms_addresses_pref` VALUES ('408', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', 'むつ市', '02');
INSERT INTO `ms_addresses_pref` VALUES ('409', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '下北郡東通村', '02');
INSERT INTO `ms_addresses_pref` VALUES ('410', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '川越市', '11');
INSERT INTO `ms_addresses_pref` VALUES ('411', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '比企郡川島町', '11');
INSERT INTO `ms_addresses_pref` VALUES ('412', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '坂戸市', '11');
INSERT INTO `ms_addresses_pref` VALUES ('413', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '比企郡鳩山町', '11');
INSERT INTO `ms_addresses_pref` VALUES ('414', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '入間郡毛呂山町', '11');
INSERT INTO `ms_addresses_pref` VALUES ('415', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '入間郡越生町', '11');
INSERT INTO `ms_addresses_pref` VALUES ('416', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '日高市', '11');
INSERT INTO `ms_addresses_pref` VALUES ('417', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '狭山市', '11');
INSERT INTO `ms_addresses_pref` VALUES ('418', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '鶴ヶ島市', '11');
INSERT INTO `ms_addresses_pref` VALUES ('419', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '朝霞市', '11');
INSERT INTO `ms_addresses_pref` VALUES ('420', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '和光市', '11');
INSERT INTO `ms_addresses_pref` VALUES ('421', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '新座市', '11');
INSERT INTO `ms_addresses_pref` VALUES ('422', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '志木市', '11');
INSERT INTO `ms_addresses_pref` VALUES ('423', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '富士見市', '11');
INSERT INTO `ms_addresses_pref` VALUES ('424', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '入間郡三芳町', '11');
INSERT INTO `ms_addresses_pref` VALUES ('425', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '東松山市', '11');
INSERT INTO `ms_addresses_pref` VALUES ('426', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '比企郡吉見町', '11');
INSERT INTO `ms_addresses_pref` VALUES ('427', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '比企郡嵐山町', '11');
INSERT INTO `ms_addresses_pref` VALUES ('428', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '比企郡小川町', '11');
INSERT INTO `ms_addresses_pref` VALUES ('429', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '比企郡ときがわ町', '11');
INSERT INTO `ms_addresses_pref` VALUES ('430', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '秩父郡東秩父村', '11');
INSERT INTO `ms_addresses_pref` VALUES ('431', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '比企郡滑川町', '11');
INSERT INTO `ms_addresses_pref` VALUES ('432', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', 'ふじみ野市', '11');
INSERT INTO `ms_addresses_pref` VALUES ('433', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '飯能市', '11');
INSERT INTO `ms_addresses_pref` VALUES ('434', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '入間市', '11');
INSERT INTO `ms_addresses_pref` VALUES ('435', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '所沢市', '11');
INSERT INTO `ms_addresses_pref` VALUES ('436', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '弘前市', '02');
INSERT INTO `ms_addresses_pref` VALUES ('437', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '熊谷市', '11');
INSERT INTO `ms_addresses_pref` VALUES ('438', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '平川市', '02');
INSERT INTO `ms_addresses_pref` VALUES ('439', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '黒石市', '02');
INSERT INTO `ms_addresses_pref` VALUES ('440', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '行田市', '11');
INSERT INTO `ms_addresses_pref` VALUES ('441', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '中津軽郡西目屋村', '02');
INSERT INTO `ms_addresses_pref` VALUES ('442', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '上尾市', '11');
INSERT INTO `ms_addresses_pref` VALUES ('443', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '北足立郡伊奈町', '11');
INSERT INTO `ms_addresses_pref` VALUES ('444', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '桶川市', '11');
INSERT INTO `ms_addresses_pref` VALUES ('445', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '北本市', '11');
INSERT INTO `ms_addresses_pref` VALUES ('446', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '鴻巣市', '11');
INSERT INTO `ms_addresses_pref` VALUES ('447', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '深谷市', '11');
INSERT INTO `ms_addresses_pref` VALUES ('448', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '本庄市', '11');
INSERT INTO `ms_addresses_pref` VALUES ('449', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '児玉郡美里町', '11');
INSERT INTO `ms_addresses_pref` VALUES ('450', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '児玉郡神川町', '11');
INSERT INTO `ms_addresses_pref` VALUES ('451', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '秩父市', '11');
INSERT INTO `ms_addresses_pref` VALUES ('452', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '秩父郡横瀬町', '11');
INSERT INTO `ms_addresses_pref` VALUES ('453', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '秩父郡小鹿野町', '11');
INSERT INTO `ms_addresses_pref` VALUES ('454', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '児玉郡上里町', '11');
INSERT INTO `ms_addresses_pref` VALUES ('455', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '大里郡寄居町', '11');
INSERT INTO `ms_addresses_pref` VALUES ('456', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '秩父郡長瀞町', '11');
INSERT INTO `ms_addresses_pref` VALUES ('457', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '秩父郡皆野町', '11');
INSERT INTO `ms_addresses_pref` VALUES ('458', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '五所川原市', '02');
INSERT INTO `ms_addresses_pref` VALUES ('459', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '高崎市', '10');
INSERT INTO `ms_addresses_pref` VALUES ('460', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '伊勢崎市', '10');
INSERT INTO `ms_addresses_pref` VALUES ('461', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '太田市', '10');
INSERT INTO `ms_addresses_pref` VALUES ('462', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '邑楽郡千代田町', '10');
INSERT INTO `ms_addresses_pref` VALUES ('463', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '邑楽郡大泉町', '10');
INSERT INTO `ms_addresses_pref` VALUES ('464', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '邑楽郡邑楽町', '10');
INSERT INTO `ms_addresses_pref` VALUES ('465', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '邑楽郡明和町', '10');
INSERT INTO `ms_addresses_pref` VALUES ('466', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', 'つがる市', '02');
INSERT INTO `ms_addresses_pref` VALUES ('467', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '佐波郡玉村町', '10');
INSERT INTO `ms_addresses_pref` VALUES ('468', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '藤岡市', '10');
INSERT INTO `ms_addresses_pref` VALUES ('469', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '多野郡神流町', '10');
INSERT INTO `ms_addresses_pref` VALUES ('470', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '多野郡上野村', '10');
INSERT INTO `ms_addresses_pref` VALUES ('471', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '多野郡吉井町', '10');
INSERT INTO `ms_addresses_pref` VALUES ('472', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '甘楽郡甘楽町', '10');
INSERT INTO `ms_addresses_pref` VALUES ('473', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '富岡市', '10');
INSERT INTO `ms_addresses_pref` VALUES ('474', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '甘楽郡下仁田町', '10');
INSERT INTO `ms_addresses_pref` VALUES ('475', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '甘楽郡南牧村', '10');
INSERT INTO `ms_addresses_pref` VALUES ('476', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '吾妻郡東吾妻町', '10');
INSERT INTO `ms_addresses_pref` VALUES ('477', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '北群馬郡榛東村', '10');
INSERT INTO `ms_addresses_pref` VALUES ('478', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '前橋市', '10');
INSERT INTO `ms_addresses_pref` VALUES ('479', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '北群馬郡吉岡町', '10');
INSERT INTO `ms_addresses_pref` VALUES ('480', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '勢多郡富士見村', '10');
INSERT INTO `ms_addresses_pref` VALUES ('481', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '館林市', '10');
INSERT INTO `ms_addresses_pref` VALUES ('482', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '邑楽郡板倉町', '10');
INSERT INTO `ms_addresses_pref` VALUES ('483', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '桐生市', '10');
INSERT INTO `ms_addresses_pref` VALUES ('484', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', 'みどり市', '10');
INSERT INTO `ms_addresses_pref` VALUES ('485', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '渋川市', '10');
INSERT INTO `ms_addresses_pref` VALUES ('486', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '吾妻郡中之条町', '10');
INSERT INTO `ms_addresses_pref` VALUES ('487', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '吾妻郡高山村', '10');
INSERT INTO `ms_addresses_pref` VALUES ('488', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '吾妻郡長野原町', '10');
INSERT INTO `ms_addresses_pref` VALUES ('489', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '吾妻郡六合村', '10');
INSERT INTO `ms_addresses_pref` VALUES ('490', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '吾妻郡嬬恋村', '10');
INSERT INTO `ms_addresses_pref` VALUES ('491', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '吾妻郡草津町', '10');
INSERT INTO `ms_addresses_pref` VALUES ('492', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '沼田市', '10');
INSERT INTO `ms_addresses_pref` VALUES ('493', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '利根郡川場村', '10');
INSERT INTO `ms_addresses_pref` VALUES ('494', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '利根郡片品村', '10');
INSERT INTO `ms_addresses_pref` VALUES ('495', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '安中市', '10');
INSERT INTO `ms_addresses_pref` VALUES ('496', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '利根郡昭和村', '10');
INSERT INTO `ms_addresses_pref` VALUES ('497', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '利根郡みなかみ町', '10');
INSERT INTO `ms_addresses_pref` VALUES ('498', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '長野市', '20');
INSERT INTO `ms_addresses_pref` VALUES ('499', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '南津軽郡大鰐町', '02');
INSERT INTO `ms_addresses_pref` VALUES ('500', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '上高井郡小布施町', '20');
INSERT INTO `ms_addresses_pref` VALUES ('501', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '下高井郡山ノ内町', '20');
INSERT INTO `ms_addresses_pref` VALUES ('502', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '南津軽郡田舎館村', '02');
INSERT INTO `ms_addresses_pref` VALUES ('503', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '南津軽郡藤崎町', '02');
INSERT INTO `ms_addresses_pref` VALUES ('504', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '上水内郡信州新町', '20');
INSERT INTO `ms_addresses_pref` VALUES ('505', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '上水内郡中条村', '20');
INSERT INTO `ms_addresses_pref` VALUES ('506', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '上水内郡小川村', '20');
INSERT INTO `ms_addresses_pref` VALUES ('507', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '須坂市', '20');
INSERT INTO `ms_addresses_pref` VALUES ('508', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '上高井郡高山村', '20');
INSERT INTO `ms_addresses_pref` VALUES ('509', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '西津軽郡深浦町', '02');
INSERT INTO `ms_addresses_pref` VALUES ('510', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '西津軽郡鰺ヶ沢町', '02');
INSERT INTO `ms_addresses_pref` VALUES ('511', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '中野市', '20');
INSERT INTO `ms_addresses_pref` VALUES ('512', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '北津軽郡鶴田町', '02');
INSERT INTO `ms_addresses_pref` VALUES ('513', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '北津軽郡板柳町', '02');
INSERT INTO `ms_addresses_pref` VALUES ('514', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '小諸市', '20');
INSERT INTO `ms_addresses_pref` VALUES ('515', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '佐久市', '20');
INSERT INTO `ms_addresses_pref` VALUES ('516', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '南佐久郡佐久穂町', '20');
INSERT INTO `ms_addresses_pref` VALUES ('517', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '南佐久郡小海町', '20');
INSERT INTO `ms_addresses_pref` VALUES ('518', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '南佐久郡北相木村', '20');
INSERT INTO `ms_addresses_pref` VALUES ('519', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '南佐久郡南相木村', '20');
INSERT INTO `ms_addresses_pref` VALUES ('520', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '南佐久郡南牧村', '20');
INSERT INTO `ms_addresses_pref` VALUES ('521', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '南佐久郡川上村', '20');
INSERT INTO `ms_addresses_pref` VALUES ('522', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '北佐久郡立科町', '20');
INSERT INTO `ms_addresses_pref` VALUES ('523', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '上田市', '20');
INSERT INTO `ms_addresses_pref` VALUES ('524', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '小県郡長和町', '20');
INSERT INTO `ms_addresses_pref` VALUES ('525', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '小県郡青木村', '20');
INSERT INTO `ms_addresses_pref` VALUES ('526', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '千曲市', '20');
INSERT INTO `ms_addresses_pref` VALUES ('527', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '北佐久郡軽井沢町', '20');
INSERT INTO `ms_addresses_pref` VALUES ('528', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '北佐久郡御代田町', '20');
INSERT INTO `ms_addresses_pref` VALUES ('529', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '東御市', '20');
INSERT INTO `ms_addresses_pref` VALUES ('530', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '埴科郡坂城町', '20');
INSERT INTO `ms_addresses_pref` VALUES ('531', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '上水内郡飯綱町', '20');
INSERT INTO `ms_addresses_pref` VALUES ('532', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '上水内郡信濃町', '20');
INSERT INTO `ms_addresses_pref` VALUES ('533', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '飯山市', '20');
INSERT INTO `ms_addresses_pref` VALUES ('534', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '妙高市', '15');
INSERT INTO `ms_addresses_pref` VALUES ('535', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '下高井郡木島平村', '20');
INSERT INTO `ms_addresses_pref` VALUES ('536', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '下高井郡野沢温泉村', '20');
INSERT INTO `ms_addresses_pref` VALUES ('537', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '下水内郡栄村', '20');
INSERT INTO `ms_addresses_pref` VALUES ('538', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '松本市', '20');
INSERT INTO `ms_addresses_pref` VALUES ('539', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '三戸郡三戸町', '02');
INSERT INTO `ms_addresses_pref` VALUES ('540', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '三戸郡南部町', '02');
INSERT INTO `ms_addresses_pref` VALUES ('541', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '東筑摩郡朝日村', '20');
INSERT INTO `ms_addresses_pref` VALUES ('542', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '東筑摩郡山形村', '20');
INSERT INTO `ms_addresses_pref` VALUES ('543', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '東筑摩郡波田町', '20');
INSERT INTO `ms_addresses_pref` VALUES ('544', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '三戸郡田子町', '02');
INSERT INTO `ms_addresses_pref` VALUES ('545', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '茅野市', '20');
INSERT INTO `ms_addresses_pref` VALUES ('546', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '諏訪郡富士見町', '20');
INSERT INTO `ms_addresses_pref` VALUES ('547', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '諏訪郡原村', '20');
INSERT INTO `ms_addresses_pref` VALUES ('548', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '三戸郡階上町', '02');
INSERT INTO `ms_addresses_pref` VALUES ('549', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '三戸郡五戸町', '02');
INSERT INTO `ms_addresses_pref` VALUES ('550', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '三戸郡新郷村', '02');
INSERT INTO `ms_addresses_pref` VALUES ('551', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '諏訪市', '20');
INSERT INTO `ms_addresses_pref` VALUES ('552', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '上北郡おいらせ町', '02');
INSERT INTO `ms_addresses_pref` VALUES ('553', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '上北郡東北町', '02');
INSERT INTO `ms_addresses_pref` VALUES ('554', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '上北郡七戸町', '02');
INSERT INTO `ms_addresses_pref` VALUES ('555', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '諏訪郡下諏訪町', '20');
INSERT INTO `ms_addresses_pref` VALUES ('556', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '上北郡野辺地町', '02');
INSERT INTO `ms_addresses_pref` VALUES ('557', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '上北郡六ヶ所村', '02');
INSERT INTO `ms_addresses_pref` VALUES ('558', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '東津軽郡平内町', '02');
INSERT INTO `ms_addresses_pref` VALUES ('559', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '岡谷市', '20');
INSERT INTO `ms_addresses_pref` VALUES ('560', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '上北郡横浜町', '02');
INSERT INTO `ms_addresses_pref` VALUES ('561', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '下北郡風間浦村', '02');
INSERT INTO `ms_addresses_pref` VALUES ('562', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '下北郡大間町', '02');
INSERT INTO `ms_addresses_pref` VALUES ('563', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '下北郡佐井村', '02');
INSERT INTO `ms_addresses_pref` VALUES ('564', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '飯田市', '20');
INSERT INTO `ms_addresses_pref` VALUES ('565', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '下伊那郡阿智村', '20');
INSERT INTO `ms_addresses_pref` VALUES ('566', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '下伊那郡平谷村', '20');
INSERT INTO `ms_addresses_pref` VALUES ('567', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '下伊那郡根羽村', '20');
INSERT INTO `ms_addresses_pref` VALUES ('568', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '下伊那郡喬木村', '20');
INSERT INTO `ms_addresses_pref` VALUES ('569', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '伊那市', '20');
INSERT INTO `ms_addresses_pref` VALUES ('570', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '木曽郡木曽町', '20');
INSERT INTO `ms_addresses_pref` VALUES ('571', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '木曽郡王滝村', '20');
INSERT INTO `ms_addresses_pref` VALUES ('572', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '大町市', '20');
INSERT INTO `ms_addresses_pref` VALUES ('573', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '塩尻市', '20');
INSERT INTO `ms_addresses_pref` VALUES ('574', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '上伊那郡辰野町', '20');
INSERT INTO `ms_addresses_pref` VALUES ('575', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '下伊那郡天龍村', '20');
INSERT INTO `ms_addresses_pref` VALUES ('576', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '下伊那郡阿南町', '20');
INSERT INTO `ms_addresses_pref` VALUES ('577', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '下伊那郡売木村', '20');
INSERT INTO `ms_addresses_pref` VALUES ('578', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '下伊那郡泰阜村', '20');
INSERT INTO `ms_addresses_pref` VALUES ('579', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '下伊那郡下條村', '20');
INSERT INTO `ms_addresses_pref` VALUES ('580', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '下伊那郡高森町', '20');
INSERT INTO `ms_addresses_pref` VALUES ('581', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '下伊那郡豊丘村', '20');
INSERT INTO `ms_addresses_pref` VALUES ('582', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '下伊那郡松川町', '20');
INSERT INTO `ms_addresses_pref` VALUES ('583', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '下伊那郡大鹿村', '20');
INSERT INTO `ms_addresses_pref` VALUES ('584', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '上伊那郡飯島町', '20');
INSERT INTO `ms_addresses_pref` VALUES ('585', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '上伊那郡中川村', '20');
INSERT INTO `ms_addresses_pref` VALUES ('586', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '駒ヶ根市', '20');
INSERT INTO `ms_addresses_pref` VALUES ('587', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '上伊那郡宮田村', '20');
INSERT INTO `ms_addresses_pref` VALUES ('588', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '上伊那郡南箕輪村', '20');
INSERT INTO `ms_addresses_pref` VALUES ('589', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '上伊那郡箕輪町', '20');
INSERT INTO `ms_addresses_pref` VALUES ('590', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '木曽郡南木曽町', '20');
INSERT INTO `ms_addresses_pref` VALUES ('591', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '木曽郡大桑村', '20');
INSERT INTO `ms_addresses_pref` VALUES ('592', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '木曽郡上松町', '20');
INSERT INTO `ms_addresses_pref` VALUES ('593', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '木曽郡木祖村', '20');
INSERT INTO `ms_addresses_pref` VALUES ('594', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '安曇野市', '20');
INSERT INTO `ms_addresses_pref` VALUES ('595', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '東筑摩郡生坂村', '20');
INSERT INTO `ms_addresses_pref` VALUES ('596', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '東筑摩郡筑北村', '20');
INSERT INTO `ms_addresses_pref` VALUES ('597', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '東筑摩郡麻績村', '20');
INSERT INTO `ms_addresses_pref` VALUES ('598', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '北安曇郡松川村', '20');
INSERT INTO `ms_addresses_pref` VALUES ('599', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '北安曇郡池田町', '20');
INSERT INTO `ms_addresses_pref` VALUES ('600', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '北安曇郡白馬村', '20');
INSERT INTO `ms_addresses_pref` VALUES ('601', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '北安曇郡小谷村', '20');
INSERT INTO `ms_addresses_pref` VALUES ('602', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '札幌市厚別区', '01');
INSERT INTO `ms_addresses_pref` VALUES ('603', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '函館市', '01');
INSERT INTO `ms_addresses_pref` VALUES ('604', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '甲府市', '19');
INSERT INTO `ms_addresses_pref` VALUES ('605', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '札幌市清田区', '01');
INSERT INTO `ms_addresses_pref` VALUES ('606', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '甲斐市', '19');
INSERT INTO `ms_addresses_pref` VALUES ('607', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '南アルプス市', '19');
INSERT INTO `ms_addresses_pref` VALUES ('608', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '南巨摩郡増穂町', '19');
INSERT INTO `ms_addresses_pref` VALUES ('609', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '南巨摩郡鰍沢町', '19');
INSERT INTO `ms_addresses_pref` VALUES ('610', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '中央市', '19');
INSERT INTO `ms_addresses_pref` VALUES ('611', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '大月市', '19');
INSERT INTO `ms_addresses_pref` VALUES ('612', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '上野原市', '19');
INSERT INTO `ms_addresses_pref` VALUES ('613', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '南都留郡富士河口湖町', '19');
INSERT INTO `ms_addresses_pref` VALUES ('614', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '南都留郡鳴沢村', '19');
INSERT INTO `ms_addresses_pref` VALUES ('615', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '南都留郡忍野村', '19');
INSERT INTO `ms_addresses_pref` VALUES ('616', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '南都留郡山中湖村', '19');
INSERT INTO `ms_addresses_pref` VALUES ('617', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '都留市', '19');
INSERT INTO `ms_addresses_pref` VALUES ('618', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '南都留郡道志村', '19');
INSERT INTO `ms_addresses_pref` VALUES ('619', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '富士吉田市', '19');
INSERT INTO `ms_addresses_pref` VALUES ('620', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '南都留郡西桂町', '19');
INSERT INTO `ms_addresses_pref` VALUES ('621', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '甲州市', '19');
INSERT INTO `ms_addresses_pref` VALUES ('622', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '山梨市', '19');
INSERT INTO `ms_addresses_pref` VALUES ('623', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '笛吹市', '19');
INSERT INTO `ms_addresses_pref` VALUES ('624', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '韮崎市', '19');
INSERT INTO `ms_addresses_pref` VALUES ('625', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '北杜市', '19');
INSERT INTO `ms_addresses_pref` VALUES ('626', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '北都留郡小菅村', '19');
INSERT INTO `ms_addresses_pref` VALUES ('627', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '北都留郡丹波山村', '19');
INSERT INTO `ms_addresses_pref` VALUES ('628', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '南巨摩郡南部町', '19');
INSERT INTO `ms_addresses_pref` VALUES ('629', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '南巨摩郡身延町', '19');
INSERT INTO `ms_addresses_pref` VALUES ('630', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '南巨摩郡早川町', '19');
INSERT INTO `ms_addresses_pref` VALUES ('631', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '西八代郡市川三郷町', '19');
INSERT INTO `ms_addresses_pref` VALUES ('632', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '中巨摩郡昭和町', '19');
INSERT INTO `ms_addresses_pref` VALUES ('633', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '沼津市', '22');
INSERT INTO `ms_addresses_pref` VALUES ('634', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '裾野市', '22');
INSERT INTO `ms_addresses_pref` VALUES ('635', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '駿東郡小山町', '22');
INSERT INTO `ms_addresses_pref` VALUES ('636', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '伊豆の国市', '22');
INSERT INTO `ms_addresses_pref` VALUES ('637', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '伊豆市', '22');
INSERT INTO `ms_addresses_pref` VALUES ('638', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '賀茂郡西伊豆町', '22');
INSERT INTO `ms_addresses_pref` VALUES ('639', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '賀茂郡松崎町', '22');
INSERT INTO `ms_addresses_pref` VALUES ('640', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '三島市', '22');
INSERT INTO `ms_addresses_pref` VALUES ('641', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '駿東郡清水町', '22');
INSERT INTO `ms_addresses_pref` VALUES ('642', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '駿東郡長泉町', '22');
INSERT INTO `ms_addresses_pref` VALUES ('643', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '田方郡函南町', '22');
INSERT INTO `ms_addresses_pref` VALUES ('644', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '亀田郡七飯町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('645', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '北斗市', '01');
INSERT INTO `ms_addresses_pref` VALUES ('646', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '茅部郡鹿部町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('647', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '御殿場市', '22');
INSERT INTO `ms_addresses_pref` VALUES ('648', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '熱海市', '22');
INSERT INTO `ms_addresses_pref` VALUES ('649', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '伊東市', '22');
INSERT INTO `ms_addresses_pref` VALUES ('650', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '賀茂郡東伊豆町', '22');
INSERT INTO `ms_addresses_pref` VALUES ('651', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '賀茂郡河津町', '22');
INSERT INTO `ms_addresses_pref` VALUES ('652', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '下田市', '22');
INSERT INTO `ms_addresses_pref` VALUES ('653', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '賀茂郡南伊豆町', '22');
INSERT INTO `ms_addresses_pref` VALUES ('654', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '富士市', '22');
INSERT INTO `ms_addresses_pref` VALUES ('655', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '富士宮市', '22');
INSERT INTO `ms_addresses_pref` VALUES ('656', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '富士郡芝川町', '22');
INSERT INTO `ms_addresses_pref` VALUES ('657', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '静岡市葵区', '22');
INSERT INTO `ms_addresses_pref` VALUES ('658', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '静岡市駿河区', '22');
INSERT INTO `ms_addresses_pref` VALUES ('659', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '焼津市', '22');
INSERT INTO `ms_addresses_pref` VALUES ('660', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '榛原郡吉田町', '22');
INSERT INTO `ms_addresses_pref` VALUES ('661', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '牧之原市', '22');
INSERT INTO `ms_addresses_pref` VALUES ('662', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '藤枝市', '22');
INSERT INTO `ms_addresses_pref` VALUES ('663', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '静岡市清水区', '22');
INSERT INTO `ms_addresses_pref` VALUES ('664', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '島田市', '22');
INSERT INTO `ms_addresses_pref` VALUES ('665', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '榛原郡川根本町', '22');
INSERT INTO `ms_addresses_pref` VALUES ('666', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '檜山郡江差町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('667', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '浜松市東区', '22');
INSERT INTO `ms_addresses_pref` VALUES ('668', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '浜松市中区', '22');
INSERT INTO `ms_addresses_pref` VALUES ('669', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '浜松市南区', '22');
INSERT INTO `ms_addresses_pref` VALUES ('670', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '爾志郡乙部町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('671', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '二海郡八雲町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('672', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '久遠郡せたな町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('673', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '浜松市西区', '22');
INSERT INTO `ms_addresses_pref` VALUES ('674', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '浜名郡新居町', '22');
INSERT INTO `ms_addresses_pref` VALUES ('675', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '湖西市', '22');
INSERT INTO `ms_addresses_pref` VALUES ('676', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '檜山郡厚沢部町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('677', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '浜松市北区', '22');
INSERT INTO `ms_addresses_pref` VALUES ('678', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '浜松市天竜区', '22');
INSERT INTO `ms_addresses_pref` VALUES ('679', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '奥尻郡奥尻町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('680', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '北設楽郡豊根村', '23');
INSERT INTO `ms_addresses_pref` VALUES ('681', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '浜松市浜北区', '22');
INSERT INTO `ms_addresses_pref` VALUES ('682', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '掛川市', '22');
INSERT INTO `ms_addresses_pref` VALUES ('683', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '袋井市', '22');
INSERT INTO `ms_addresses_pref` VALUES ('684', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '周智郡森町', '22');
INSERT INTO `ms_addresses_pref` VALUES ('685', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '磐田市', '22');
INSERT INTO `ms_addresses_pref` VALUES ('686', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '菊川市', '22');
INSERT INTO `ms_addresses_pref` VALUES ('687', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '御前崎市', '22');
INSERT INTO `ms_addresses_pref` VALUES ('688', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '虻田郡倶知安町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('689', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '豊橋市', '23');
INSERT INTO `ms_addresses_pref` VALUES ('690', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '虻田郡京極町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('691', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '虻田郡喜茂別町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('692', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '伊達市', '01');
INSERT INTO `ms_addresses_pref` VALUES ('693', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '宝飯郡小坂井町', '23');
INSERT INTO `ms_addresses_pref` VALUES ('694', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '豊川市', '23');
INSERT INTO `ms_addresses_pref` VALUES ('695', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '新城市', '23');
INSERT INTO `ms_addresses_pref` VALUES ('696', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '北設楽郡設楽町', '23');
INSERT INTO `ms_addresses_pref` VALUES ('697', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '豊田市', '23');
INSERT INTO `ms_addresses_pref` VALUES ('698', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '田原市', '23');
INSERT INTO `ms_addresses_pref` VALUES ('699', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '蒲郡市', '23');
INSERT INTO `ms_addresses_pref` VALUES ('700', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '岡崎市', '23');
INSERT INTO `ms_addresses_pref` VALUES ('701', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '額田郡幸田町', '23');
INSERT INTO `ms_addresses_pref` VALUES ('702', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '西尾市', '23');
INSERT INTO `ms_addresses_pref` VALUES ('703', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '幡豆郡一色町', '23');
INSERT INTO `ms_addresses_pref` VALUES ('704', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '幡豆郡吉良町', '23');
INSERT INTO `ms_addresses_pref` VALUES ('705', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '幡豆郡幡豆町', '23');
INSERT INTO `ms_addresses_pref` VALUES ('706', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '安城市', '23');
INSERT INTO `ms_addresses_pref` VALUES ('707', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '高浜市', '23');
INSERT INTO `ms_addresses_pref` VALUES ('708', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '碧南市', '23');
INSERT INTO `ms_addresses_pref` VALUES ('709', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '刈谷市', '23');
INSERT INTO `ms_addresses_pref` VALUES ('710', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '北設楽郡東栄町', '23');
INSERT INTO `ms_addresses_pref` VALUES ('711', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '岩内郡岩内町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('712', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '名古屋市中村区', '23');
INSERT INTO `ms_addresses_pref` VALUES ('713', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '岩内郡共和町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('714', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '古宇郡泊村', '01');
INSERT INTO `ms_addresses_pref` VALUES ('715', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '古宇郡神恵内村', '01');
INSERT INTO `ms_addresses_pref` VALUES ('716', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '名古屋市西区', '23');
INSERT INTO `ms_addresses_pref` VALUES ('717', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '清須市', '23');
INSERT INTO `ms_addresses_pref` VALUES ('718', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '西春日井郡春日町', '23');
INSERT INTO `ms_addresses_pref` VALUES ('719', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '名古屋市中川区', '23');
INSERT INTO `ms_addresses_pref` VALUES ('720', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '名古屋市港区', '23');
INSERT INTO `ms_addresses_pref` VALUES ('721', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '名古屋市熱田区', '23');
INSERT INTO `ms_addresses_pref` VALUES ('722', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '名古屋市南区', '23');
INSERT INTO `ms_addresses_pref` VALUES ('723', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '名古屋市緑区', '23');
INSERT INTO `ms_addresses_pref` VALUES ('724', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '余市郡余市町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('725', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '名古屋市中区', '23');
INSERT INTO `ms_addresses_pref` VALUES ('726', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '古平郡古平町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('727', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '積丹郡積丹町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('728', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '余市郡赤井川村', '01');
INSERT INTO `ms_addresses_pref` VALUES ('729', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '名古屋市東区', '23');
INSERT INTO `ms_addresses_pref` VALUES ('730', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '名古屋市北区', '23');
INSERT INTO `ms_addresses_pref` VALUES ('731', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '名古屋市守山区', '23');
INSERT INTO `ms_addresses_pref` VALUES ('732', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '名古屋市千種区', '23');
INSERT INTO `ms_addresses_pref` VALUES ('733', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '名古屋市名東区', '23');
INSERT INTO `ms_addresses_pref` VALUES ('734', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '名古屋市昭和区', '23');
INSERT INTO `ms_addresses_pref` VALUES ('735', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '名古屋市瑞穂区', '23');
INSERT INTO `ms_addresses_pref` VALUES ('736', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '名古屋市天白区', '23');
INSERT INTO `ms_addresses_pref` VALUES ('737', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '小樽市', '01');
INSERT INTO `ms_addresses_pref` VALUES ('738', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '日進市', '23');
INSERT INTO `ms_addresses_pref` VALUES ('739', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '愛知郡東郷町', '23');
INSERT INTO `ms_addresses_pref` VALUES ('740', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '西加茂郡三好町', '23');
INSERT INTO `ms_addresses_pref` VALUES ('741', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '豊明市', '23');
INSERT INTO `ms_addresses_pref` VALUES ('742', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '知多郡東浦町', '23');
INSERT INTO `ms_addresses_pref` VALUES ('743', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '知多郡阿久比町', '23');
INSERT INTO `ms_addresses_pref` VALUES ('744', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '知多郡武豊町', '23');
INSERT INTO `ms_addresses_pref` VALUES ('745', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '知多郡美浜町', '23');
INSERT INTO `ms_addresses_pref` VALUES ('746', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '知多郡南知多町', '23');
INSERT INTO `ms_addresses_pref` VALUES ('747', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '知立市', '23');
INSERT INTO `ms_addresses_pref` VALUES ('748', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '大府市', '23');
INSERT INTO `ms_addresses_pref` VALUES ('749', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '半田市', '23');
INSERT INTO `ms_addresses_pref` VALUES ('750', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '東海市', '23');
INSERT INTO `ms_addresses_pref` VALUES ('751', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '知多市', '23');
INSERT INTO `ms_addresses_pref` VALUES ('752', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '常滑市', '23');
INSERT INTO `ms_addresses_pref` VALUES ('753', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '丹羽郡大口町', '23');
INSERT INTO `ms_addresses_pref` VALUES ('754', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '丹羽郡扶桑町', '23');
INSERT INTO `ms_addresses_pref` VALUES ('755', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '西春日井郡豊山町', '23');
INSERT INTO `ms_addresses_pref` VALUES ('756', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '春日井市', '23');
INSERT INTO `ms_addresses_pref` VALUES ('757', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '寿都郡黒松内町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('758', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '愛知郡長久手町', '23');
INSERT INTO `ms_addresses_pref` VALUES ('759', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '瀬戸市', '23');
INSERT INTO `ms_addresses_pref` VALUES ('760', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '寿都郡寿都町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('761', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '島牧郡島牧村', '01');
INSERT INTO `ms_addresses_pref` VALUES ('762', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '北名古屋市', '23');
INSERT INTO `ms_addresses_pref` VALUES ('763', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '磯谷郡蘭越町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('764', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '虻田郡ニセコ町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('765', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '虻田郡真狩村', '01');
INSERT INTO `ms_addresses_pref` VALUES ('766', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '虻田郡留寿都村', '01');
INSERT INTO `ms_addresses_pref` VALUES ('767', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '岩倉市', '23');
INSERT INTO `ms_addresses_pref` VALUES ('768', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '余市郡仁木町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('769', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '江南市', '23');
INSERT INTO `ms_addresses_pref` VALUES ('770', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '犬山市', '23');
INSERT INTO `ms_addresses_pref` VALUES ('771', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '小牧市', '23');
INSERT INTO `ms_addresses_pref` VALUES ('772', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '尾張旭市', '23');
INSERT INTO `ms_addresses_pref` VALUES ('773', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '海部郡甚目寺町', '23');
INSERT INTO `ms_addresses_pref` VALUES ('774', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '海部郡大治町', '23');
INSERT INTO `ms_addresses_pref` VALUES ('775', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '海部郡美和町', '23');
INSERT INTO `ms_addresses_pref` VALUES ('776', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '稲沢市', '23');
INSERT INTO `ms_addresses_pref` VALUES ('777', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '海部郡飛島村', '23');
INSERT INTO `ms_addresses_pref` VALUES ('778', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '弥富市', '23');
INSERT INTO `ms_addresses_pref` VALUES ('779', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '上磯郡木古内町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('780', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '檜山郡上ノ国町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('781', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '一宮市', '23');
INSERT INTO `ms_addresses_pref` VALUES ('782', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '上磯郡知内町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('783', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '松前郡福島町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('784', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '松前郡松前町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('785', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '茅部郡森町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('786', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '山越郡長万部町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('787', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '瀬棚郡今金町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('788', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '虻田郡豊浦町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('789', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '虻田郡洞爺湖町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('790', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '有珠郡壮瞥町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('791', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '津島市', '23');
INSERT INTO `ms_addresses_pref` VALUES ('792', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '愛西市', '23');
INSERT INTO `ms_addresses_pref` VALUES ('793', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '海部郡七宝町', '23');
INSERT INTO `ms_addresses_pref` VALUES ('794', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '海部郡蟹江町', '23');
INSERT INTO `ms_addresses_pref` VALUES ('795', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '桑名郡木曽岬町', '24');
INSERT INTO `ms_addresses_pref` VALUES ('796', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '札幌市南区', '01');
INSERT INTO `ms_addresses_pref` VALUES ('797', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '室蘭市', '01');
INSERT INTO `ms_addresses_pref` VALUES ('798', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '岐阜市', '21');
INSERT INTO `ms_addresses_pref` VALUES ('799', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '瑞穂市', '21');
INSERT INTO `ms_addresses_pref` VALUES ('800', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '本巣市', '21');
INSERT INTO `ms_addresses_pref` VALUES ('801', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '本巣郡北方町', '21');
INSERT INTO `ms_addresses_pref` VALUES ('802', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '揖斐郡大野町', '21');
INSERT INTO `ms_addresses_pref` VALUES ('803', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '揖斐郡揖斐川町', '21');
INSERT INTO `ms_addresses_pref` VALUES ('804', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '山県市', '21');
INSERT INTO `ms_addresses_pref` VALUES ('805', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '関市', '21');
INSERT INTO `ms_addresses_pref` VALUES ('806', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '加茂郡富加町', '21');
INSERT INTO `ms_addresses_pref` VALUES ('807', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '美濃市', '21');
INSERT INTO `ms_addresses_pref` VALUES ('808', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '郡上市', '21');
INSERT INTO `ms_addresses_pref` VALUES ('809', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '高山市', '21');
INSERT INTO `ms_addresses_pref` VALUES ('810', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '大野郡白川村', '21');
INSERT INTO `ms_addresses_pref` VALUES ('811', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '羽島郡岐南町', '21');
INSERT INTO `ms_addresses_pref` VALUES ('812', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '各務原市', '21');
INSERT INTO `ms_addresses_pref` VALUES ('813', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '羽島郡笠松町', '21');
INSERT INTO `ms_addresses_pref` VALUES ('814', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '羽島市', '21');
INSERT INTO `ms_addresses_pref` VALUES ('815', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '大垣市', '21');
INSERT INTO `ms_addresses_pref` VALUES ('816', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '安八郡安八町', '21');
INSERT INTO `ms_addresses_pref` VALUES ('817', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '安八郡輪之内町', '21');
INSERT INTO `ms_addresses_pref` VALUES ('818', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '海津市', '21');
INSERT INTO `ms_addresses_pref` VALUES ('819', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '養老郡養老町', '21');
INSERT INTO `ms_addresses_pref` VALUES ('820', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '不破郡関ケ原町', '21');
INSERT INTO `ms_addresses_pref` VALUES ('821', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '不破郡垂井町', '21');
INSERT INTO `ms_addresses_pref` VALUES ('822', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '安八郡神戸町', '21');
INSERT INTO `ms_addresses_pref` VALUES ('823', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '揖斐郡池田町', '21');
INSERT INTO `ms_addresses_pref` VALUES ('824', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '美濃加茂市', '21');
INSERT INTO `ms_addresses_pref` VALUES ('825', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '加茂郡坂祝町', '21');
INSERT INTO `ms_addresses_pref` VALUES ('826', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '可児郡御嵩町', '21');
INSERT INTO `ms_addresses_pref` VALUES ('827', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '可児市', '21');
INSERT INTO `ms_addresses_pref` VALUES ('828', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '加茂郡八百津町', '21');
INSERT INTO `ms_addresses_pref` VALUES ('829', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '飛騨市', '21');
INSERT INTO `ms_addresses_pref` VALUES ('830', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '多治見市', '21');
INSERT INTO `ms_addresses_pref` VALUES ('831', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '中津川市', '21');
INSERT INTO `ms_addresses_pref` VALUES ('832', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '加茂郡川辺町', '21');
INSERT INTO `ms_addresses_pref` VALUES ('833', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '加茂郡七宗町', '21');
INSERT INTO `ms_addresses_pref` VALUES ('834', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '加茂郡白川町', '21');
INSERT INTO `ms_addresses_pref` VALUES ('835', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '加茂郡東白川村', '21');
INSERT INTO `ms_addresses_pref` VALUES ('836', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '下呂市', '21');
INSERT INTO `ms_addresses_pref` VALUES ('837', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '土岐市', '21');
INSERT INTO `ms_addresses_pref` VALUES ('838', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '瑞浪市', '21');
INSERT INTO `ms_addresses_pref` VALUES ('839', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '恵那市', '21');
INSERT INTO `ms_addresses_pref` VALUES ('840', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '四日市市', '24');
INSERT INTO `ms_addresses_pref` VALUES ('841', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '三重郡朝日町', '24');
INSERT INTO `ms_addresses_pref` VALUES ('842', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '三重郡川越町', '24');
INSERT INTO `ms_addresses_pref` VALUES ('843', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '鈴鹿市', '24');
INSERT INTO `ms_addresses_pref` VALUES ('844', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '津市', '24');
INSERT INTO `ms_addresses_pref` VALUES ('845', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '三重郡菰野町', '24');
INSERT INTO `ms_addresses_pref` VALUES ('846', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '桑名市', '24');
INSERT INTO `ms_addresses_pref` VALUES ('847', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', 'いなべ市', '24');
INSERT INTO `ms_addresses_pref` VALUES ('848', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '員弁郡東員町', '24');
INSERT INTO `ms_addresses_pref` VALUES ('849', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '松阪市', '24');
INSERT INTO `ms_addresses_pref` VALUES ('850', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '多気郡明和町', '24');
INSERT INTO `ms_addresses_pref` VALUES ('851', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '伊勢市', '24');
INSERT INTO `ms_addresses_pref` VALUES ('852', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '度会郡南伊勢町', '24');
INSERT INTO `ms_addresses_pref` VALUES ('853', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '度会郡度会町', '24');
INSERT INTO `ms_addresses_pref` VALUES ('854', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '鳥羽市', '24');
INSERT INTO `ms_addresses_pref` VALUES ('855', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '志摩市', '24');
INSERT INTO `ms_addresses_pref` VALUES ('856', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '伊賀市', '24');
INSERT INTO `ms_addresses_pref` VALUES ('857', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '名張市', '24');
INSERT INTO `ms_addresses_pref` VALUES ('858', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '亀山市', '24');
INSERT INTO `ms_addresses_pref` VALUES ('859', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '度会郡玉城町', '24');
INSERT INTO `ms_addresses_pref` VALUES ('860', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '多気郡多気町', '24');
INSERT INTO `ms_addresses_pref` VALUES ('861', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '多気郡大台町', '24');
INSERT INTO `ms_addresses_pref` VALUES ('862', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '度会郡大紀町', '24');
INSERT INTO `ms_addresses_pref` VALUES ('863', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '北牟婁郡紀北町', '24');
INSERT INTO `ms_addresses_pref` VALUES ('864', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '尾鷲市', '24');
INSERT INTO `ms_addresses_pref` VALUES ('865', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '熊野市', '24');
INSERT INTO `ms_addresses_pref` VALUES ('866', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '南牟婁郡御浜町', '24');
INSERT INTO `ms_addresses_pref` VALUES ('867', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '南牟婁郡紀宝町', '24');
INSERT INTO `ms_addresses_pref` VALUES ('868', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '大津市', '25');
INSERT INTO `ms_addresses_pref` VALUES ('869', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '京都市左京区', '26');
INSERT INTO `ms_addresses_pref` VALUES ('870', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '高島市', '25');
INSERT INTO `ms_addresses_pref` VALUES ('871', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '野洲市', '25');
INSERT INTO `ms_addresses_pref` VALUES ('872', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '蒲生郡竜王町', '25');
INSERT INTO `ms_addresses_pref` VALUES ('873', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '栗東市', '25');
INSERT INTO `ms_addresses_pref` VALUES ('874', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '湖南市', '25');
INSERT INTO `ms_addresses_pref` VALUES ('875', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '甲賀市', '25');
INSERT INTO `ms_addresses_pref` VALUES ('876', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '米原市', '25');
INSERT INTO `ms_addresses_pref` VALUES ('877', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '彦根市', '25');
INSERT INTO `ms_addresses_pref` VALUES ('878', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '東近江市', '25');
INSERT INTO `ms_addresses_pref` VALUES ('879', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '蒲生郡安土町', '25');
INSERT INTO `ms_addresses_pref` VALUES ('880', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '犬上郡甲良町', '25');
INSERT INTO `ms_addresses_pref` VALUES ('881', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '犬上郡多賀町', '25');
INSERT INTO `ms_addresses_pref` VALUES ('882', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '近江八幡市', '25');
INSERT INTO `ms_addresses_pref` VALUES ('883', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '守山市', '25');
INSERT INTO `ms_addresses_pref` VALUES ('884', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '草津市', '25');
INSERT INTO `ms_addresses_pref` VALUES ('885', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '長浜市', '25');
INSERT INTO `ms_addresses_pref` VALUES ('886', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '東浅井郡虎姫町', '25');
INSERT INTO `ms_addresses_pref` VALUES ('887', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '伊香郡高月町', '25');
INSERT INTO `ms_addresses_pref` VALUES ('888', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '東浅井郡湖北町', '25');
INSERT INTO `ms_addresses_pref` VALUES ('889', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '伊香郡木之本町', '25');
INSERT INTO `ms_addresses_pref` VALUES ('890', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '伊香郡余呉町', '25');
INSERT INTO `ms_addresses_pref` VALUES ('891', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '伊香郡西浅井町', '25');
INSERT INTO `ms_addresses_pref` VALUES ('892', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '犬上郡豊郷町', '25');
INSERT INTO `ms_addresses_pref` VALUES ('893', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '愛知郡愛荘町', '25');
INSERT INTO `ms_addresses_pref` VALUES ('894', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '蒲生郡日野町', '25');
INSERT INTO `ms_addresses_pref` VALUES ('895', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '苫小牧市', '01');
INSERT INTO `ms_addresses_pref` VALUES ('896', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '大阪市北区', '27');
INSERT INTO `ms_addresses_pref` VALUES ('897', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '大阪市淀川区', '27');
INSERT INTO `ms_addresses_pref` VALUES ('898', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '大阪市東淀川区', '27');
INSERT INTO `ms_addresses_pref` VALUES ('899', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '大阪市都島区', '27');
INSERT INTO `ms_addresses_pref` VALUES ('900', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '大阪市旭区', '27');
INSERT INTO `ms_addresses_pref` VALUES ('901', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '大阪市城東区', '27');
INSERT INTO `ms_addresses_pref` VALUES ('902', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '大阪市東成区', '27');
INSERT INTO `ms_addresses_pref` VALUES ('903', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '大阪市鶴見区', '27');
INSERT INTO `ms_addresses_pref` VALUES ('904', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '大阪市中央区', '27');
INSERT INTO `ms_addresses_pref` VALUES ('905', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '勇払郡むかわ町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('906', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '大阪市天王寺区', '27');
INSERT INTO `ms_addresses_pref` VALUES ('907', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '大阪市生野区', '27');
INSERT INTO `ms_addresses_pref` VALUES ('908', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '大阪市阿倍野区', '27');
INSERT INTO `ms_addresses_pref` VALUES ('909', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '大阪市東住吉区', '27');
INSERT INTO `ms_addresses_pref` VALUES ('910', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '大阪市平野区', '27');
INSERT INTO `ms_addresses_pref` VALUES ('911', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '泉佐野市', '27');
INSERT INTO `ms_addresses_pref` VALUES ('912', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '泉南郡田尻町', '27');
INSERT INTO `ms_addresses_pref` VALUES ('913', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '泉南市', '27');
INSERT INTO `ms_addresses_pref` VALUES ('914', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '沙流郡日高町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('915', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '大阪市西区', '27');
INSERT INTO `ms_addresses_pref` VALUES ('916', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '沙流郡平取町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('917', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '大阪市大正区', '27');
INSERT INTO `ms_addresses_pref` VALUES ('918', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '大阪市港区', '27');
INSERT INTO `ms_addresses_pref` VALUES ('919', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '大阪市福島区', '27');
INSERT INTO `ms_addresses_pref` VALUES ('920', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '大阪市此花区', '27');
INSERT INTO `ms_addresses_pref` VALUES ('921', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '大阪市西淀川区', '27');
INSERT INTO `ms_addresses_pref` VALUES ('922', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '大阪市浪速区', '27');
INSERT INTO `ms_addresses_pref` VALUES ('923', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '大阪市西成区', '27');
INSERT INTO `ms_addresses_pref` VALUES ('924', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '大阪市住吉区', '27');
INSERT INTO `ms_addresses_pref` VALUES ('925', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '大阪市住之江区', '27');
INSERT INTO `ms_addresses_pref` VALUES ('926', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '日高郡新ひだか町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('927', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '豊中市', '27');
INSERT INTO `ms_addresses_pref` VALUES ('928', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '箕面市', '27');
INSERT INTO `ms_addresses_pref` VALUES ('929', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '池田市', '27');
INSERT INTO `ms_addresses_pref` VALUES ('930', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '豊能郡豊能町', '27');
INSERT INTO `ms_addresses_pref` VALUES ('931', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '豊能郡能勢町', '27');
INSERT INTO `ms_addresses_pref` VALUES ('932', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '伊丹市', '28');
INSERT INTO `ms_addresses_pref` VALUES ('933', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '吹田市', '27');
INSERT INTO `ms_addresses_pref` VALUES ('934', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '摂津市', '27');
INSERT INTO `ms_addresses_pref` VALUES ('935', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '茨木市', '27');
INSERT INTO `ms_addresses_pref` VALUES ('936', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '高槻市', '27');
INSERT INTO `ms_addresses_pref` VALUES ('937', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '浦河郡浦河町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('938', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '守口市', '27');
INSERT INTO `ms_addresses_pref` VALUES ('939', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '門真市', '27');
INSERT INTO `ms_addresses_pref` VALUES ('940', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '寝屋川市', '27');
INSERT INTO `ms_addresses_pref` VALUES ('941', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '枚方市', '27');
INSERT INTO `ms_addresses_pref` VALUES ('942', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '大東市', '27');
INSERT INTO `ms_addresses_pref` VALUES ('943', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '四條畷市', '27');
INSERT INTO `ms_addresses_pref` VALUES ('944', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '交野市', '27');
INSERT INTO `ms_addresses_pref` VALUES ('945', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '東大阪市', '27');
INSERT INTO `ms_addresses_pref` VALUES ('946', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '様似郡様似町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('947', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '松原市', '27');
INSERT INTO `ms_addresses_pref` VALUES ('948', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '幌泉郡えりも町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('949', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '八尾市', '27');
INSERT INTO `ms_addresses_pref` VALUES ('950', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '柏原市', '27');
INSERT INTO `ms_addresses_pref` VALUES ('951', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '羽曳野市', '27');
INSERT INTO `ms_addresses_pref` VALUES ('952', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '藤井寺市', '27');
INSERT INTO `ms_addresses_pref` VALUES ('953', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '南河内郡太子町', '27');
INSERT INTO `ms_addresses_pref` VALUES ('954', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '富田林市', '27');
INSERT INTO `ms_addresses_pref` VALUES ('955', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '南河内郡河南町', '27');
INSERT INTO `ms_addresses_pref` VALUES ('956', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '南河内郡千早赤阪村', '27');
INSERT INTO `ms_addresses_pref` VALUES ('957', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '河内長野市', '27');
INSERT INTO `ms_addresses_pref` VALUES ('958', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '堺市美原区', '27');
INSERT INTO `ms_addresses_pref` VALUES ('959', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '大阪狭山市', '27');
INSERT INTO `ms_addresses_pref` VALUES ('960', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '登別市', '01');
INSERT INTO `ms_addresses_pref` VALUES ('961', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '堺市堺区', '27');
INSERT INTO `ms_addresses_pref` VALUES ('962', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '堺市南区', '27');
INSERT INTO `ms_addresses_pref` VALUES ('963', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '堺市中区', '27');
INSERT INTO `ms_addresses_pref` VALUES ('964', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '泉南郡熊取町', '27');
INSERT INTO `ms_addresses_pref` VALUES ('965', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '貝塚市', '27');
INSERT INTO `ms_addresses_pref` VALUES ('966', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '白老郡白老町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('967', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '堺市北区', '27');
INSERT INTO `ms_addresses_pref` VALUES ('968', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '勇払郡安平町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('969', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '勇払郡厚真町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('970', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '高石市', '27');
INSERT INTO `ms_addresses_pref` VALUES ('971', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '新冠郡新冠町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('972', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '堺市西区', '27');
INSERT INTO `ms_addresses_pref` VALUES ('973', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '和泉市', '27');
INSERT INTO `ms_addresses_pref` VALUES ('974', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '泉大津市', '27');
INSERT INTO `ms_addresses_pref` VALUES ('975', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '泉北郡忠岡町', '27');
INSERT INTO `ms_addresses_pref` VALUES ('976', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '岸和田市', '27');
INSERT INTO `ms_addresses_pref` VALUES ('977', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '堺市東区', '27');
INSERT INTO `ms_addresses_pref` VALUES ('978', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '阪南市', '27');
INSERT INTO `ms_addresses_pref` VALUES ('979', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '泉南郡岬町', '27');
INSERT INTO `ms_addresses_pref` VALUES ('980', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '札幌市手稲区', '01');
INSERT INTO `ms_addresses_pref` VALUES ('981', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '札幌市中央区', '01');
INSERT INTO `ms_addresses_pref` VALUES ('982', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '京都市下京区', '26');
INSERT INTO `ms_addresses_pref` VALUES ('983', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '札幌市東区', '01');
INSERT INTO `ms_addresses_pref` VALUES ('984', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '京都市南区', '26');
INSERT INTO `ms_addresses_pref` VALUES ('985', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '京都市北区', '26');
INSERT INTO `ms_addresses_pref` VALUES ('986', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '京都市右京区', '26');
INSERT INTO `ms_addresses_pref` VALUES ('987', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '南丹市', '26');
INSERT INTO `ms_addresses_pref` VALUES ('988', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '京都市伏見区', '26');
INSERT INTO `ms_addresses_pref` VALUES ('989', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '宇治市', '26');
INSERT INTO `ms_addresses_pref` VALUES ('990', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '京都市上京区', '26');
INSERT INTO `ms_addresses_pref` VALUES ('991', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '京都市中京区', '26');
INSERT INTO `ms_addresses_pref` VALUES ('992', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '京都市東山区', '26');
INSERT INTO `ms_addresses_pref` VALUES ('993', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '京都市山科区', '26');
INSERT INTO `ms_addresses_pref` VALUES ('994', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '京都市西京区', '26');
INSERT INTO `ms_addresses_pref` VALUES ('995', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '城陽市', '26');
INSERT INTO `ms_addresses_pref` VALUES ('996', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '綴喜郡宇治田原町', '26');
INSERT INTO `ms_addresses_pref` VALUES ('997', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '京田辺市', '26');
INSERT INTO `ms_addresses_pref` VALUES ('998', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '綴喜郡井手町', '26');
INSERT INTO `ms_addresses_pref` VALUES ('999', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '樺戸郡月形町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1000', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '樺戸郡浦臼町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1001', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '北広島市', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1002', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '恵庭市', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1003', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '久世郡久御山町', '26');
INSERT INTO `ms_addresses_pref` VALUES ('1004', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '八幡市', '26');
INSERT INTO `ms_addresses_pref` VALUES ('1005', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '石狩市', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1006', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '向日市', '26');
INSERT INTO `ms_addresses_pref` VALUES ('1007', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '長岡京市', '26');
INSERT INTO `ms_addresses_pref` VALUES ('1008', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '乙訓郡大山崎町', '26');
INSERT INTO `ms_addresses_pref` VALUES ('1009', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '三島郡島本町', '27');
INSERT INTO `ms_addresses_pref` VALUES ('1010', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '木津川市', '26');
INSERT INTO `ms_addresses_pref` VALUES ('1011', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '相楽郡精華町', '26');
INSERT INTO `ms_addresses_pref` VALUES ('1012', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '相楽郡和束町', '26');
INSERT INTO `ms_addresses_pref` VALUES ('1013', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '相楽郡笠置町', '26');
INSERT INTO `ms_addresses_pref` VALUES ('1014', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '相楽郡南山城村', '26');
INSERT INTO `ms_addresses_pref` VALUES ('1015', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '札幌市豊平区', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1016', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '福知山市', '26');
INSERT INTO `ms_addresses_pref` VALUES ('1017', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '亀岡市', '26');
INSERT INTO `ms_addresses_pref` VALUES ('1018', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '船井郡京丹波町', '26');
INSERT INTO `ms_addresses_pref` VALUES ('1019', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '綾部市', '26');
INSERT INTO `ms_addresses_pref` VALUES ('1020', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '舞鶴市', '26');
INSERT INTO `ms_addresses_pref` VALUES ('1021', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '宮津市', '26');
INSERT INTO `ms_addresses_pref` VALUES ('1022', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '与謝郡伊根町', '26');
INSERT INTO `ms_addresses_pref` VALUES ('1023', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '京丹後市', '26');
INSERT INTO `ms_addresses_pref` VALUES ('1024', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '与謝郡与謝野町', '26');
INSERT INTO `ms_addresses_pref` VALUES ('1025', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '札幌市西区', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1026', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '奈良市', '29');
INSERT INTO `ms_addresses_pref` VALUES ('1027', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '山辺郡山添村', '29');
INSERT INTO `ms_addresses_pref` VALUES ('1028', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '生駒市', '29');
INSERT INTO `ms_addresses_pref` VALUES ('1029', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '天理市', '29');
INSERT INTO `ms_addresses_pref` VALUES ('1030', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '宇陀市', '29');
INSERT INTO `ms_addresses_pref` VALUES ('1031', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '桜井市', '29');
INSERT INTO `ms_addresses_pref` VALUES ('1032', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '宇陀郡曽爾村', '29');
INSERT INTO `ms_addresses_pref` VALUES ('1033', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '宇陀郡御杖村', '29');
INSERT INTO `ms_addresses_pref` VALUES ('1034', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '吉野郡東吉野村', '29');
INSERT INTO `ms_addresses_pref` VALUES ('1035', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '橿原市', '29');
INSERT INTO `ms_addresses_pref` VALUES ('1036', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '高市郡明日香村', '29');
INSERT INTO `ms_addresses_pref` VALUES ('1037', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '大和高田市', '29');
INSERT INTO `ms_addresses_pref` VALUES ('1038', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '北葛城郡広陵町', '29');
INSERT INTO `ms_addresses_pref` VALUES ('1039', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '高市郡高取町', '29');
INSERT INTO `ms_addresses_pref` VALUES ('1040', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '生駒郡平群町', '29');
INSERT INTO `ms_addresses_pref` VALUES ('1041', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '生駒郡三郷町', '29');
INSERT INTO `ms_addresses_pref` VALUES ('1042', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '北葛城郡王寺町', '29');
INSERT INTO `ms_addresses_pref` VALUES ('1043', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '北葛城郡河合町', '29');
INSERT INTO `ms_addresses_pref` VALUES ('1044', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '生駒郡斑鳩町', '29');
INSERT INTO `ms_addresses_pref` VALUES ('1045', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '磯城郡川西町', '29');
INSERT INTO `ms_addresses_pref` VALUES ('1046', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '磯城郡三宅町', '29');
INSERT INTO `ms_addresses_pref` VALUES ('1047', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '磯城郡田原本町', '29');
INSERT INTO `ms_addresses_pref` VALUES ('1048', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '五條市', '29');
INSERT INTO `ms_addresses_pref` VALUES ('1049', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '吉野郡野迫川村', '29');
INSERT INTO `ms_addresses_pref` VALUES ('1050', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '吉野郡十津川村', '29');
INSERT INTO `ms_addresses_pref` VALUES ('1051', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '吉野郡大淀町', '29');
INSERT INTO `ms_addresses_pref` VALUES ('1052', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '吉野郡下市町', '29');
INSERT INTO `ms_addresses_pref` VALUES ('1053', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '吉野郡黒滝村', '29');
INSERT INTO `ms_addresses_pref` VALUES ('1054', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '吉野郡天川村', '29');
INSERT INTO `ms_addresses_pref` VALUES ('1055', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '香芝市', '29');
INSERT INTO `ms_addresses_pref` VALUES ('1056', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '北葛城郡上牧町', '29');
INSERT INTO `ms_addresses_pref` VALUES ('1057', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '葛城市', '29');
INSERT INTO `ms_addresses_pref` VALUES ('1058', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '大和郡山市', '29');
INSERT INTO `ms_addresses_pref` VALUES ('1059', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '生駒郡安堵町', '29');
INSERT INTO `ms_addresses_pref` VALUES ('1060', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '御所市', '29');
INSERT INTO `ms_addresses_pref` VALUES ('1061', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '吉野郡吉野町', '29');
INSERT INTO `ms_addresses_pref` VALUES ('1062', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '吉野郡川上村', '29');
INSERT INTO `ms_addresses_pref` VALUES ('1063', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '吉野郡上北山村', '29');
INSERT INTO `ms_addresses_pref` VALUES ('1064', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '吉野郡下北山村', '29');
INSERT INTO `ms_addresses_pref` VALUES ('1065', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '和歌山市', '30');
INSERT INTO `ms_addresses_pref` VALUES ('1066', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '紀の川市', '30');
INSERT INTO `ms_addresses_pref` VALUES ('1067', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '海南市', '30');
INSERT INTO `ms_addresses_pref` VALUES ('1068', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '海草郡紀美野町', '30');
INSERT INTO `ms_addresses_pref` VALUES ('1069', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '伊都郡かつらぎ町', '30');
INSERT INTO `ms_addresses_pref` VALUES ('1070', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '有田郡湯浅町', '30');
INSERT INTO `ms_addresses_pref` VALUES ('1071', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '有田郡広川町', '30');
INSERT INTO `ms_addresses_pref` VALUES ('1072', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '有田郡有田川町', '30');
INSERT INTO `ms_addresses_pref` VALUES ('1073', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '御坊市', '30');
INSERT INTO `ms_addresses_pref` VALUES ('1074', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '日高郡美浜町', '30');
INSERT INTO `ms_addresses_pref` VALUES ('1075', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '日高郡印南町', '30');
INSERT INTO `ms_addresses_pref` VALUES ('1076', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '日高郡日高川町', '30');
INSERT INTO `ms_addresses_pref` VALUES ('1077', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '日高郡みなべ町', '30');
INSERT INTO `ms_addresses_pref` VALUES ('1078', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '田辺市', '30');
INSERT INTO `ms_addresses_pref` VALUES ('1079', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '西牟婁郡白浜町', '30');
INSERT INTO `ms_addresses_pref` VALUES ('1080', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '西牟婁郡上富田町', '30');
INSERT INTO `ms_addresses_pref` VALUES ('1081', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '新宮市', '30');
INSERT INTO `ms_addresses_pref` VALUES ('1082', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '東牟婁郡北山村', '30');
INSERT INTO `ms_addresses_pref` VALUES ('1083', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '橋本市', '30');
INSERT INTO `ms_addresses_pref` VALUES ('1084', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '伊都郡九度山町', '30');
INSERT INTO `ms_addresses_pref` VALUES ('1085', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '伊都郡高野町', '30');
INSERT INTO `ms_addresses_pref` VALUES ('1086', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '有田市', '30');
INSERT INTO `ms_addresses_pref` VALUES ('1087', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '日高郡由良町', '30');
INSERT INTO `ms_addresses_pref` VALUES ('1088', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '日高郡日高町', '30');
INSERT INTO `ms_addresses_pref` VALUES ('1089', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '西牟婁郡すさみ町', '30');
INSERT INTO `ms_addresses_pref` VALUES ('1090', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '東牟婁郡串本町', '30');
INSERT INTO `ms_addresses_pref` VALUES ('1091', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '東牟婁郡古座川町', '30');
INSERT INTO `ms_addresses_pref` VALUES ('1092', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '東牟婁郡太地町', '30');
INSERT INTO `ms_addresses_pref` VALUES ('1093', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '東牟婁郡那智勝浦町', '30');
INSERT INTO `ms_addresses_pref` VALUES ('1094', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '岩出市', '30');
INSERT INTO `ms_addresses_pref` VALUES ('1095', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '神戸市中央区', '28');
INSERT INTO `ms_addresses_pref` VALUES ('1096', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '神戸市西区', '28');
INSERT INTO `ms_addresses_pref` VALUES ('1097', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '神戸市北区', '28');
INSERT INTO `ms_addresses_pref` VALUES ('1098', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '西宮市', '28');
INSERT INTO `ms_addresses_pref` VALUES ('1099', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '神戸市兵庫区', '28');
INSERT INTO `ms_addresses_pref` VALUES ('1100', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '神戸市長田区', '28');
INSERT INTO `ms_addresses_pref` VALUES ('1101', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '神戸市須磨区', '28');
INSERT INTO `ms_addresses_pref` VALUES ('1102', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '神戸市垂水区', '28');
INSERT INTO `ms_addresses_pref` VALUES ('1103', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '洲本市', '28');
INSERT INTO `ms_addresses_pref` VALUES ('1104', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '南あわじ市', '28');
INSERT INTO `ms_addresses_pref` VALUES ('1105', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '淡路市', '28');
INSERT INTO `ms_addresses_pref` VALUES ('1106', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '神戸市灘区', '28');
INSERT INTO `ms_addresses_pref` VALUES ('1107', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '神戸市東灘区', '28');
INSERT INTO `ms_addresses_pref` VALUES ('1108', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '芦屋市', '28');
INSERT INTO `ms_addresses_pref` VALUES ('1109', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '千歳市', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1110', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '尼崎市', '28');
INSERT INTO `ms_addresses_pref` VALUES ('1111', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '宝塚市', '28');
INSERT INTO `ms_addresses_pref` VALUES ('1112', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '川西市', '28');
INSERT INTO `ms_addresses_pref` VALUES ('1113', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '川辺郡猪名川町', '28');
INSERT INTO `ms_addresses_pref` VALUES ('1114', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '養父市', '28');
INSERT INTO `ms_addresses_pref` VALUES ('1115', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '美方郡香美町', '28');
INSERT INTO `ms_addresses_pref` VALUES ('1116', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '豊岡市', '28');
INSERT INTO `ms_addresses_pref` VALUES ('1117', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '三田市', '28');
INSERT INTO `ms_addresses_pref` VALUES ('1118', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '篠山市', '28');
INSERT INTO `ms_addresses_pref` VALUES ('1119', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '丹波市', '28');
INSERT INTO `ms_addresses_pref` VALUES ('1120', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '朝来市', '28');
INSERT INTO `ms_addresses_pref` VALUES ('1121', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '美方郡新温泉町', '28');
INSERT INTO `ms_addresses_pref` VALUES ('1122', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '江別市', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1123', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '姫路市', '28');
INSERT INTO `ms_addresses_pref` VALUES ('1124', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '高砂市', '28');
INSERT INTO `ms_addresses_pref` VALUES ('1125', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', 'たつの市', '28');
INSERT INTO `ms_addresses_pref` VALUES ('1126', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '揖保郡太子町', '28');
INSERT INTO `ms_addresses_pref` VALUES ('1127', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '宍粟市', '28');
INSERT INTO `ms_addresses_pref` VALUES ('1128', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '明石市', '28');
INSERT INTO `ms_addresses_pref` VALUES ('1129', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '三木市', '28');
INSERT INTO `ms_addresses_pref` VALUES ('1130', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '加東市', '28');
INSERT INTO `ms_addresses_pref` VALUES ('1131', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '加古川市', '28');
INSERT INTO `ms_addresses_pref` VALUES ('1132', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '加西市', '28');
INSERT INTO `ms_addresses_pref` VALUES ('1133', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '加古郡播磨町', '28');
INSERT INTO `ms_addresses_pref` VALUES ('1134', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '加古郡稲美町', '28');
INSERT INTO `ms_addresses_pref` VALUES ('1135', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '小野市', '28');
INSERT INTO `ms_addresses_pref` VALUES ('1136', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '西脇市', '28');
INSERT INTO `ms_addresses_pref` VALUES ('1137', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '多可郡多可町', '28');
INSERT INTO `ms_addresses_pref` VALUES ('1138', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '相生市', '28');
INSERT INTO `ms_addresses_pref` VALUES ('1139', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '赤穂市', '28');
INSERT INTO `ms_addresses_pref` VALUES ('1140', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '赤穂郡上郡町', '28');
INSERT INTO `ms_addresses_pref` VALUES ('1141', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '神崎郡福崎町', '28');
INSERT INTO `ms_addresses_pref` VALUES ('1142', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '神崎郡市川町', '28');
INSERT INTO `ms_addresses_pref` VALUES ('1143', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '神崎郡神河町', '28');
INSERT INTO `ms_addresses_pref` VALUES ('1144', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '佐用郡佐用町', '28');
INSERT INTO `ms_addresses_pref` VALUES ('1145', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '岩見沢市', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1146', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '鳥取市', '31');
INSERT INTO `ms_addresses_pref` VALUES ('1147', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '八頭郡八頭町', '31');
INSERT INTO `ms_addresses_pref` VALUES ('1148', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '八頭郡若桜町', '31');
INSERT INTO `ms_addresses_pref` VALUES ('1149', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '夕張郡栗山町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1150', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '夕張市', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1151', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '岩美郡岩美町', '31');
INSERT INTO `ms_addresses_pref` VALUES ('1152', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '石狩郡新篠津村', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1153', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '倉吉市', '31');
INSERT INTO `ms_addresses_pref` VALUES ('1154', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '東伯郡三朝町', '31');
INSERT INTO `ms_addresses_pref` VALUES ('1155', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '東伯郡湯梨浜町', '31');
INSERT INTO `ms_addresses_pref` VALUES ('1156', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '三笠市', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1157', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '美唄市', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1158', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '米子市', '31');
INSERT INTO `ms_addresses_pref` VALUES ('1159', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '西伯郡南部町', '31');
INSERT INTO `ms_addresses_pref` VALUES ('1160', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '境港市', '31');
INSERT INTO `ms_addresses_pref` VALUES ('1161', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '隠岐郡知夫村', '32');
INSERT INTO `ms_addresses_pref` VALUES ('1162', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '隠岐郡西ノ島町', '32');
INSERT INTO `ms_addresses_pref` VALUES ('1163', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '隠岐郡海士町', '32');
INSERT INTO `ms_addresses_pref` VALUES ('1164', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '隠岐郡隠岐の島町', '32');
INSERT INTO `ms_addresses_pref` VALUES ('1165', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '八頭郡智頭町', '31');
INSERT INTO `ms_addresses_pref` VALUES ('1166', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '東伯郡北栄町', '31');
INSERT INTO `ms_addresses_pref` VALUES ('1167', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '東伯郡琴浦町', '31');
INSERT INTO `ms_addresses_pref` VALUES ('1168', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '西伯郡大山町', '31');
INSERT INTO `ms_addresses_pref` VALUES ('1169', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '西伯郡日吉津村', '31');
INSERT INTO `ms_addresses_pref` VALUES ('1170', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '西伯郡伯耆町', '31');
INSERT INTO `ms_addresses_pref` VALUES ('1171', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '日野郡江府町', '31');
INSERT INTO `ms_addresses_pref` VALUES ('1172', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '日野郡日野町', '31');
INSERT INTO `ms_addresses_pref` VALUES ('1173', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '日野郡日南町', '31');
INSERT INTO `ms_addresses_pref` VALUES ('1174', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '松江市', '32');
INSERT INTO `ms_addresses_pref` VALUES ('1175', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '空知郡南幌町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1176', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '雲南市', '32');
INSERT INTO `ms_addresses_pref` VALUES ('1177', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '飯石郡飯南町', '32');
INSERT INTO `ms_addresses_pref` VALUES ('1178', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '出雲市', '32');
INSERT INTO `ms_addresses_pref` VALUES ('1179', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '夕張郡由仁町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1180', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '夕張郡長沼町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1181', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '安来市', '32');
INSERT INTO `ms_addresses_pref` VALUES ('1182', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '大田市', '32');
INSERT INTO `ms_addresses_pref` VALUES ('1183', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '江津市', '32');
INSERT INTO `ms_addresses_pref` VALUES ('1184', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '浜田市', '32');
INSERT INTO `ms_addresses_pref` VALUES ('1185', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '邑智郡川本町', '32');
INSERT INTO `ms_addresses_pref` VALUES ('1186', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '邑智郡邑南町', '32');
INSERT INTO `ms_addresses_pref` VALUES ('1187', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '邑智郡美郷町', '32');
INSERT INTO `ms_addresses_pref` VALUES ('1188', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '益田市', '32');
INSERT INTO `ms_addresses_pref` VALUES ('1189', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '八束郡東出雲町', '32');
INSERT INTO `ms_addresses_pref` VALUES ('1190', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '簸川郡斐川町', '32');
INSERT INTO `ms_addresses_pref` VALUES ('1191', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '仁多郡奥出雲町', '32');
INSERT INTO `ms_addresses_pref` VALUES ('1192', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '鹿足郡津和野町', '32');
INSERT INTO `ms_addresses_pref` VALUES ('1193', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '鹿足郡吉賀町', '32');
INSERT INTO `ms_addresses_pref` VALUES ('1194', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '旭川市', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1195', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '岡山市', '33');
INSERT INTO `ms_addresses_pref` VALUES ('1196', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '倉敷市', '33');
INSERT INTO `ms_addresses_pref` VALUES ('1197', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '都窪郡早島町', '33');
INSERT INTO `ms_addresses_pref` VALUES ('1198', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '赤磐市', '33');
INSERT INTO `ms_addresses_pref` VALUES ('1199', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '美作市', '33');
INSERT INTO `ms_addresses_pref` VALUES ('1200', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '備前市', '33');
INSERT INTO `ms_addresses_pref` VALUES ('1201', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '瀬戸内市', '33');
INSERT INTO `ms_addresses_pref` VALUES ('1202', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '玉野市', '33');
INSERT INTO `ms_addresses_pref` VALUES ('1203', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '英田郡西粟倉村', '33');
INSERT INTO `ms_addresses_pref` VALUES ('1204', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '津山市', '33');
INSERT INTO `ms_addresses_pref` VALUES ('1205', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '苫田郡鏡野町', '33');
INSERT INTO `ms_addresses_pref` VALUES ('1206', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '勝田郡奈義町', '33');
INSERT INTO `ms_addresses_pref` VALUES ('1207', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '久米郡美咲町', '33');
INSERT INTO `ms_addresses_pref` VALUES ('1208', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '和気郡和気町', '33');
INSERT INTO `ms_addresses_pref` VALUES ('1209', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '加賀郡吉備中央町', '33');
INSERT INTO `ms_addresses_pref` VALUES ('1210', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '久米郡久米南町', '33');
INSERT INTO `ms_addresses_pref` VALUES ('1211', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '勝田郡勝央町', '33');
INSERT INTO `ms_addresses_pref` VALUES ('1212', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '総社市', '33');
INSERT INTO `ms_addresses_pref` VALUES ('1213', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '上川郡美瑛町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1214', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '空知郡上富良野町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1215', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '空知郡中富良野町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1216', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '上川郡鷹栖町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1217', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '上川郡東川町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1218', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '上川郡東神楽町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1219', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '笠岡市', '33');
INSERT INTO `ms_addresses_pref` VALUES ('1220', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '浅口市', '33');
INSERT INTO `ms_addresses_pref` VALUES ('1221', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '小田郡矢掛町', '33');
INSERT INTO `ms_addresses_pref` VALUES ('1222', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '井原市', '33');
INSERT INTO `ms_addresses_pref` VALUES ('1223', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '高梁市', '33');
INSERT INTO `ms_addresses_pref` VALUES ('1224', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '真庭市', '33');
INSERT INTO `ms_addresses_pref` VALUES ('1225', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '真庭郡新庄村', '33');
INSERT INTO `ms_addresses_pref` VALUES ('1226', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '新見市', '33');
INSERT INTO `ms_addresses_pref` VALUES ('1227', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '浅口郡里庄町', '33');
INSERT INTO `ms_addresses_pref` VALUES ('1228', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '福山市', '34');
INSERT INTO `ms_addresses_pref` VALUES ('1229', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '尾道市', '34');
INSERT INTO `ms_addresses_pref` VALUES ('1230', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '神石郡神石高原町', '34');
INSERT INTO `ms_addresses_pref` VALUES ('1231', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '世羅郡世羅町', '34');
INSERT INTO `ms_addresses_pref` VALUES ('1232', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '府中市', '34');
INSERT INTO `ms_addresses_pref` VALUES ('1233', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '三原市', '34');
INSERT INTO `ms_addresses_pref` VALUES ('1234', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '竹原市', '34');
INSERT INTO `ms_addresses_pref` VALUES ('1235', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '豊田郡大崎上島町', '34');
INSERT INTO `ms_addresses_pref` VALUES ('1236', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '庄原市', '34');
INSERT INTO `ms_addresses_pref` VALUES ('1237', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '三次市', '34');
INSERT INTO `ms_addresses_pref` VALUES ('1238', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '滝川市', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1239', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '広島市中区', '34');
INSERT INTO `ms_addresses_pref` VALUES ('1240', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '砂川市', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1241', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '樺戸郡新十津川町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1242', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '空知郡上砂川町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1243', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '歌志内市', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1244', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '広島市安佐南区', '34');
INSERT INTO `ms_addresses_pref` VALUES ('1245', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '広島市安佐北区', '34');
INSERT INTO `ms_addresses_pref` VALUES ('1246', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '安芸高田市', '34');
INSERT INTO `ms_addresses_pref` VALUES ('1247', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '山県郡北広島町', '34');
INSERT INTO `ms_addresses_pref` VALUES ('1248', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '山県郡安芸太田町', '34');
INSERT INTO `ms_addresses_pref` VALUES ('1249', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '安芸郡熊野町', '34');
INSERT INTO `ms_addresses_pref` VALUES ('1250', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '広島市安芸区', '34');
INSERT INTO `ms_addresses_pref` VALUES ('1251', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '安芸郡坂町', '34');
INSERT INTO `ms_addresses_pref` VALUES ('1252', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '広島市佐伯区', '34');
INSERT INTO `ms_addresses_pref` VALUES ('1253', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '広島市東区', '34');
INSERT INTO `ms_addresses_pref` VALUES ('1254', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '広島市南区', '34');
INSERT INTO `ms_addresses_pref` VALUES ('1255', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '広島市西区', '34');
INSERT INTO `ms_addresses_pref` VALUES ('1256', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '呉市', '34');
INSERT INTO `ms_addresses_pref` VALUES ('1257', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '安芸郡府中町', '34');
INSERT INTO `ms_addresses_pref` VALUES ('1258', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '安芸郡海田町', '34');
INSERT INTO `ms_addresses_pref` VALUES ('1259', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '江田島市', '34');
INSERT INTO `ms_addresses_pref` VALUES ('1260', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '廿日市市', '34');
INSERT INTO `ms_addresses_pref` VALUES ('1261', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '東広島市', '34');
INSERT INTO `ms_addresses_pref` VALUES ('1262', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '大竹市', '34');
INSERT INTO `ms_addresses_pref` VALUES ('1263', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '深川市', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1264', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '岩国市', '35');
INSERT INTO `ms_addresses_pref` VALUES ('1265', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '玖珂郡和木町', '35');
INSERT INTO `ms_addresses_pref` VALUES ('1266', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '雨竜郡幌加内町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1267', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '柳井市', '35');
INSERT INTO `ms_addresses_pref` VALUES ('1268', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '熊毛郡平生町', '35');
INSERT INTO `ms_addresses_pref` VALUES ('1269', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '熊毛郡上関町', '35');
INSERT INTO `ms_addresses_pref` VALUES ('1270', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '熊毛郡田布施町', '35');
INSERT INTO `ms_addresses_pref` VALUES ('1271', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '大島郡周防大島町', '35');
INSERT INTO `ms_addresses_pref` VALUES ('1272', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '光市', '35');
INSERT INTO `ms_addresses_pref` VALUES ('1273', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '下松市', '35');
INSERT INTO `ms_addresses_pref` VALUES ('1274', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '周南市', '35');
INSERT INTO `ms_addresses_pref` VALUES ('1275', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '防府市', '35');
INSERT INTO `ms_addresses_pref` VALUES ('1276', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '山口市', '35');
INSERT INTO `ms_addresses_pref` VALUES ('1277', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '芦別市', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1278', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '下関市', '35');
INSERT INTO `ms_addresses_pref` VALUES ('1279', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '美祢市', '35');
INSERT INTO `ms_addresses_pref` VALUES ('1280', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '萩市', '35');
INSERT INTO `ms_addresses_pref` VALUES ('1281', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '宇部市', '35');
INSERT INTO `ms_addresses_pref` VALUES ('1282', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '山陽小野田市', '35');
INSERT INTO `ms_addresses_pref` VALUES ('1283', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '阿武郡阿武町', '35');
INSERT INTO `ms_addresses_pref` VALUES ('1284', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '阿武郡阿東町', '35');
INSERT INTO `ms_addresses_pref` VALUES ('1285', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '長門市', '35');
INSERT INTO `ms_addresses_pref` VALUES ('1286', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '富良野市', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1287', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '高松市', '37');
INSERT INTO `ms_addresses_pref` VALUES ('1288', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '木田郡三木町', '37');
INSERT INTO `ms_addresses_pref` VALUES ('1289', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', 'さぬき市', '37');
INSERT INTO `ms_addresses_pref` VALUES ('1290', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '綾歌郡綾川町', '37');
INSERT INTO `ms_addresses_pref` VALUES ('1291', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '丸亀市', '37');
INSERT INTO `ms_addresses_pref` VALUES ('1292', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '香川郡直島町', '37');
INSERT INTO `ms_addresses_pref` VALUES ('1293', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '小豆郡土庄町', '37');
INSERT INTO `ms_addresses_pref` VALUES ('1294', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '小豆郡小豆島町', '37');
INSERT INTO `ms_addresses_pref` VALUES ('1295', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '坂出市', '37');
INSERT INTO `ms_addresses_pref` VALUES ('1296', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '仲多度郡多度津町', '37');
INSERT INTO `ms_addresses_pref` VALUES ('1297', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '善通寺市', '37');
INSERT INTO `ms_addresses_pref` VALUES ('1298', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '仲多度郡琴平町', '37');
INSERT INTO `ms_addresses_pref` VALUES ('1299', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '仲多度郡まんのう町', '37');
INSERT INTO `ms_addresses_pref` VALUES ('1300', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '三豊市', '37');
INSERT INTO `ms_addresses_pref` VALUES ('1301', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '観音寺市', '37');
INSERT INTO `ms_addresses_pref` VALUES ('1302', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '綾歌郡宇多津町', '37');
INSERT INTO `ms_addresses_pref` VALUES ('1303', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '東かがわ市', '37');
INSERT INTO `ms_addresses_pref` VALUES ('1304', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '留萌市', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1305', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '徳島市', '36');
INSERT INTO `ms_addresses_pref` VALUES ('1306', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '増毛郡増毛町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1307', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '留萌郡小平町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1308', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '板野郡松茂町', '36');
INSERT INTO `ms_addresses_pref` VALUES ('1309', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '板野郡北島町', '36');
INSERT INTO `ms_addresses_pref` VALUES ('1310', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '鳴門市', '36');
INSERT INTO `ms_addresses_pref` VALUES ('1311', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '板野郡藍住町', '36');
INSERT INTO `ms_addresses_pref` VALUES ('1312', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '板野郡上板町', '36');
INSERT INTO `ms_addresses_pref` VALUES ('1313', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '阿波市', '36');
INSERT INTO `ms_addresses_pref` VALUES ('1314', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '美馬市', '36');
INSERT INTO `ms_addresses_pref` VALUES ('1315', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '三好市', '36');
INSERT INTO `ms_addresses_pref` VALUES ('1316', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '三好郡東みよし町', '36');
INSERT INTO `ms_addresses_pref` VALUES ('1317', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '名西郡神山町', '36');
INSERT INTO `ms_addresses_pref` VALUES ('1318', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '名東郡佐那河内村', '36');
INSERT INTO `ms_addresses_pref` VALUES ('1319', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '勝浦郡勝浦町', '36');
INSERT INTO `ms_addresses_pref` VALUES ('1320', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '勝浦郡上勝町', '36');
INSERT INTO `ms_addresses_pref` VALUES ('1321', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '阿南市', '36');
INSERT INTO `ms_addresses_pref` VALUES ('1322', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '那賀郡那賀町', '36');
INSERT INTO `ms_addresses_pref` VALUES ('1323', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '小松島市', '36');
INSERT INTO `ms_addresses_pref` VALUES ('1324', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '海部郡牟岐町', '36');
INSERT INTO `ms_addresses_pref` VALUES ('1325', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '海部郡海陽町', '36');
INSERT INTO `ms_addresses_pref` VALUES ('1326', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '吉野川市', '36');
INSERT INTO `ms_addresses_pref` VALUES ('1327', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '板野郡板野町', '36');
INSERT INTO `ms_addresses_pref` VALUES ('1328', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '海部郡美波町', '36');
INSERT INTO `ms_addresses_pref` VALUES ('1329', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '名西郡石井町', '36');
INSERT INTO `ms_addresses_pref` VALUES ('1330', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '美馬郡つるぎ町', '36');
INSERT INTO `ms_addresses_pref` VALUES ('1331', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '高知市', '39');
INSERT INTO `ms_addresses_pref` VALUES ('1332', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '上川郡比布町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1333', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '土佐市', '39');
INSERT INTO `ms_addresses_pref` VALUES ('1334', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '高岡郡越知町', '39');
INSERT INTO `ms_addresses_pref` VALUES ('1335', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '吾川郡仁淀川町', '39');
INSERT INTO `ms_addresses_pref` VALUES ('1336', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '吾川郡いの町', '39');
INSERT INTO `ms_addresses_pref` VALUES ('1337', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '高岡郡日高村', '39');
INSERT INTO `ms_addresses_pref` VALUES ('1338', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '上川郡当麻町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1339', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '土佐郡土佐町', '39');
INSERT INTO `ms_addresses_pref` VALUES ('1340', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '長岡郡本山町', '39');
INSERT INTO `ms_addresses_pref` VALUES ('1341', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '土佐郡大川村', '39');
INSERT INTO `ms_addresses_pref` VALUES ('1342', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '上川郡愛別町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1343', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '香美市', '39');
INSERT INTO `ms_addresses_pref` VALUES ('1344', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '香南市', '39');
INSERT INTO `ms_addresses_pref` VALUES ('1345', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '安芸郡芸西村', '39');
INSERT INTO `ms_addresses_pref` VALUES ('1346', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '安芸郡馬路村', '39');
INSERT INTO `ms_addresses_pref` VALUES ('1347', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '安芸郡奈半利町', '39');
INSERT INTO `ms_addresses_pref` VALUES ('1348', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '安芸郡安田町', '39');
INSERT INTO `ms_addresses_pref` VALUES ('1349', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '安芸郡北川村', '39');
INSERT INTO `ms_addresses_pref` VALUES ('1350', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '安芸郡田野町', '39');
INSERT INTO `ms_addresses_pref` VALUES ('1351', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '室戸市', '39');
INSERT INTO `ms_addresses_pref` VALUES ('1352', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '上川郡上川町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1353', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '安芸郡東洋町', '39');
INSERT INTO `ms_addresses_pref` VALUES ('1354', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '雨竜郡秩父別町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1355', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '雨竜郡沼田町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1356', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '雨竜郡北竜町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1357', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '雨竜郡雨竜町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1358', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '南国市', '39');
INSERT INTO `ms_addresses_pref` VALUES ('1359', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '苫前郡苫前町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1360', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '苫前郡羽幌町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1361', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '安芸市', '39');
INSERT INTO `ms_addresses_pref` VALUES ('1362', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '苫前郡初山別村', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1363', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '須崎市', '39');
INSERT INTO `ms_addresses_pref` VALUES ('1364', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '高岡郡津野町', '39');
INSERT INTO `ms_addresses_pref` VALUES ('1365', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '高岡郡檮原町', '39');
INSERT INTO `ms_addresses_pref` VALUES ('1366', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '高岡郡四万十町', '39');
INSERT INTO `ms_addresses_pref` VALUES ('1367', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '四万十市', '39');
INSERT INTO `ms_addresses_pref` VALUES ('1368', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '土佐清水市', '39');
INSERT INTO `ms_addresses_pref` VALUES ('1369', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '幡多郡三原村', '39');
INSERT INTO `ms_addresses_pref` VALUES ('1370', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '宿毛市', '39');
INSERT INTO `ms_addresses_pref` VALUES ('1371', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '幡多郡大月町', '39');
INSERT INTO `ms_addresses_pref` VALUES ('1372', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '長岡郡大豊町', '39');
INSERT INTO `ms_addresses_pref` VALUES ('1373', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '高岡郡佐川町', '39');
INSERT INTO `ms_addresses_pref` VALUES ('1374', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '高岡郡中土佐町', '39');
INSERT INTO `ms_addresses_pref` VALUES ('1375', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '幡多郡黒潮町', '39');
INSERT INTO `ms_addresses_pref` VALUES ('1376', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '松山市', '38');
INSERT INTO `ms_addresses_pref` VALUES ('1377', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '空知郡奈井江町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1378', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '雨竜郡妹背牛町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1379', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '東温市', '38');
INSERT INTO `ms_addresses_pref` VALUES ('1380', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '西条市', '38');
INSERT INTO `ms_addresses_pref` VALUES ('1381', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '赤平市', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1382', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '上浮穴郡久万高原町', '38');
INSERT INTO `ms_addresses_pref` VALUES ('1383', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '伊予郡砥部町', '38');
INSERT INTO `ms_addresses_pref` VALUES ('1384', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '伊予郡松前町', '38');
INSERT INTO `ms_addresses_pref` VALUES ('1385', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '伊予市', '38');
INSERT INTO `ms_addresses_pref` VALUES ('1386', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '喜多郡内子町', '38');
INSERT INTO `ms_addresses_pref` VALUES ('1387', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '新居浜市', '38');
INSERT INTO `ms_addresses_pref` VALUES ('1388', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '今治市', '38');
INSERT INTO `ms_addresses_pref` VALUES ('1389', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '空知郡南富良野町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1390', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '勇払郡占冠村', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1391', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '越智郡上島町', '38');
INSERT INTO `ms_addresses_pref` VALUES ('1392', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '大洲市', '38');
INSERT INTO `ms_addresses_pref` VALUES ('1393', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '八幡浜市', '38');
INSERT INTO `ms_addresses_pref` VALUES ('1394', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '西宇和郡伊方町', '38');
INSERT INTO `ms_addresses_pref` VALUES ('1395', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '西予市', '38');
INSERT INTO `ms_addresses_pref` VALUES ('1396', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '宇和島市', '38');
INSERT INTO `ms_addresses_pref` VALUES ('1397', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '北宇和郡鬼北町', '38');
INSERT INTO `ms_addresses_pref` VALUES ('1398', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '北宇和郡松野町', '38');
INSERT INTO `ms_addresses_pref` VALUES ('1399', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '南宇和郡愛南町', '38');
INSERT INTO `ms_addresses_pref` VALUES ('1400', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '四国中央市', '38');
INSERT INTO `ms_addresses_pref` VALUES ('1401', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '帯広市', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1402', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '北九州市門司区', '40');
INSERT INTO `ms_addresses_pref` VALUES ('1403', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '北九州市小倉南区', '40');
INSERT INTO `ms_addresses_pref` VALUES ('1404', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '京都郡苅田町', '40');
INSERT INTO `ms_addresses_pref` VALUES ('1405', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '河東郡音更町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1406', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '河東郡士幌町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1407', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '河東郡上士幌町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1408', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '北九州市小倉北区', '40');
INSERT INTO `ms_addresses_pref` VALUES ('1409', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '北九州市戸畑区', '40');
INSERT INTO `ms_addresses_pref` VALUES ('1410', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '北九州市八幡東区', '40');
INSERT INTO `ms_addresses_pref` VALUES ('1411', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '北九州市八幡西区', '40');
INSERT INTO `ms_addresses_pref` VALUES ('1412', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '遠賀郡水巻町', '40');
INSERT INTO `ms_addresses_pref` VALUES ('1413', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '遠賀郡芦屋町', '40');
INSERT INTO `ms_addresses_pref` VALUES ('1414', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '鞍手郡鞍手町', '40');
INSERT INTO `ms_addresses_pref` VALUES ('1415', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '北九州市若松区', '40');
INSERT INTO `ms_addresses_pref` VALUES ('1416', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '中間市', '40');
INSERT INTO `ms_addresses_pref` VALUES ('1417', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '上川郡新得町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1418', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '福岡市中央区', '40');
INSERT INTO `ms_addresses_pref` VALUES ('1419', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '福岡市博多区', '40');
INSERT INTO `ms_addresses_pref` VALUES ('1420', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '河東郡鹿追町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1421', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '糟屋郡新宮町', '40');
INSERT INTO `ms_addresses_pref` VALUES ('1422', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '福岡市東区', '40');
INSERT INTO `ms_addresses_pref` VALUES ('1423', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '福岡市早良区', '40');
INSERT INTO `ms_addresses_pref` VALUES ('1424', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '筑紫郡那珂川町', '40');
INSERT INTO `ms_addresses_pref` VALUES ('1425', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '福岡市南区', '40');
INSERT INTO `ms_addresses_pref` VALUES ('1426', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '糟屋郡宇美町', '40');
INSERT INTO `ms_addresses_pref` VALUES ('1427', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '糟屋郡須惠町', '40');
INSERT INTO `ms_addresses_pref` VALUES ('1428', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '糟屋郡志免町', '40');
INSERT INTO `ms_addresses_pref` VALUES ('1429', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '糟屋郡粕屋町', '40');
INSERT INTO `ms_addresses_pref` VALUES ('1430', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '糟屋郡篠栗町', '40');
INSERT INTO `ms_addresses_pref` VALUES ('1431', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '糟屋郡久山町', '40');
INSERT INTO `ms_addresses_pref` VALUES ('1432', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '古賀市', '40');
INSERT INTO `ms_addresses_pref` VALUES ('1433', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '福津市', '40');
INSERT INTO `ms_addresses_pref` VALUES ('1434', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '宗像市', '40');
INSERT INTO `ms_addresses_pref` VALUES ('1435', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '遠賀郡岡垣町', '40');
INSERT INTO `ms_addresses_pref` VALUES ('1436', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '遠賀郡遠賀町', '40');
INSERT INTO `ms_addresses_pref` VALUES ('1437', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '壱岐市', '42');
INSERT INTO `ms_addresses_pref` VALUES ('1438', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '福岡市城南区', '40');
INSERT INTO `ms_addresses_pref` VALUES ('1439', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '春日市', '40');
INSERT INTO `ms_addresses_pref` VALUES ('1440', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '大野城市', '40');
INSERT INTO `ms_addresses_pref` VALUES ('1441', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '対馬市', '42');
INSERT INTO `ms_addresses_pref` VALUES ('1442', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '筑紫野市', '40');
INSERT INTO `ms_addresses_pref` VALUES ('1443', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '太宰府市', '40');
INSERT INTO `ms_addresses_pref` VALUES ('1444', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '福岡市西区', '40');
INSERT INTO `ms_addresses_pref` VALUES ('1445', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '前原市', '40');
INSERT INTO `ms_addresses_pref` VALUES ('1446', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '糸島郡志摩町', '40');
INSERT INTO `ms_addresses_pref` VALUES ('1447', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '糸島郡二丈町', '40');
INSERT INTO `ms_addresses_pref` VALUES ('1448', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '河西郡芽室町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1449', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '飯塚市', '40');
INSERT INTO `ms_addresses_pref` VALUES ('1450', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '嘉麻市', '40');
INSERT INTO `ms_addresses_pref` VALUES ('1451', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '嘉穂郡桂川町', '40');
INSERT INTO `ms_addresses_pref` VALUES ('1452', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '鞍手郡小竹町', '40');
INSERT INTO `ms_addresses_pref` VALUES ('1453', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '直方市', '40');
INSERT INTO `ms_addresses_pref` VALUES ('1454', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '宮若市', '40');
INSERT INTO `ms_addresses_pref` VALUES ('1455', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '田川郡福智町', '40');
INSERT INTO `ms_addresses_pref` VALUES ('1456', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '田川郡糸田町', '40');
INSERT INTO `ms_addresses_pref` VALUES ('1457', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '田川郡香春町', '40');
INSERT INTO `ms_addresses_pref` VALUES ('1458', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '行橋市', '40');
INSERT INTO `ms_addresses_pref` VALUES ('1459', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '京都郡みやこ町', '40');
INSERT INTO `ms_addresses_pref` VALUES ('1460', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '田川郡赤村', '40');
INSERT INTO `ms_addresses_pref` VALUES ('1461', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '田川郡添田町', '40');
INSERT INTO `ms_addresses_pref` VALUES ('1462', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '田川郡大任町', '40');
INSERT INTO `ms_addresses_pref` VALUES ('1463', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '田川市', '40');
INSERT INTO `ms_addresses_pref` VALUES ('1464', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '田川郡川崎町', '40');
INSERT INTO `ms_addresses_pref` VALUES ('1465', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '豊前市', '40');
INSERT INTO `ms_addresses_pref` VALUES ('1466', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '築上郡築上町', '40');
INSERT INTO `ms_addresses_pref` VALUES ('1467', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '中川郡池田町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1468', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '久留米市', '40');
INSERT INTO `ms_addresses_pref` VALUES ('1469', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '三潴郡大木町', '40');
INSERT INTO `ms_addresses_pref` VALUES ('1470', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '三井郡大刀洗町', '40');
INSERT INTO `ms_addresses_pref` VALUES ('1471', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '大川市', '40');
INSERT INTO `ms_addresses_pref` VALUES ('1472', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '柳川市', '40');
INSERT INTO `ms_addresses_pref` VALUES ('1473', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '筑後市', '40');
INSERT INTO `ms_addresses_pref` VALUES ('1474', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '八女市', '40');
INSERT INTO `ms_addresses_pref` VALUES ('1475', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '八女郡立花町', '40');
INSERT INTO `ms_addresses_pref` VALUES ('1476', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '八女郡広川町', '40');
INSERT INTO `ms_addresses_pref` VALUES ('1477', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '八女郡星野村', '40');
INSERT INTO `ms_addresses_pref` VALUES ('1478', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '八女郡黒木町', '40');
INSERT INTO `ms_addresses_pref` VALUES ('1479', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '八女郡矢部村', '40');
INSERT INTO `ms_addresses_pref` VALUES ('1480', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', 'みやま市', '40');
INSERT INTO `ms_addresses_pref` VALUES ('1481', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '大牟田市', '40');
INSERT INTO `ms_addresses_pref` VALUES ('1482', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '朝倉市', '40');
INSERT INTO `ms_addresses_pref` VALUES ('1483', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '朝倉郡筑前町', '40');
INSERT INTO `ms_addresses_pref` VALUES ('1484', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '小郡市', '40');
INSERT INTO `ms_addresses_pref` VALUES ('1485', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '朝倉郡東峰村', '40');
INSERT INTO `ms_addresses_pref` VALUES ('1486', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', 'うきは市', '40');
INSERT INTO `ms_addresses_pref` VALUES ('1487', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '日田市', '44');
INSERT INTO `ms_addresses_pref` VALUES ('1488', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '佐賀市', '41');
INSERT INTO `ms_addresses_pref` VALUES ('1489', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '三養基郡みやき町', '41');
INSERT INTO `ms_addresses_pref` VALUES ('1490', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '釧路市', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1491', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '鳥栖市', '41');
INSERT INTO `ms_addresses_pref` VALUES ('1492', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '三養基郡基山町', '41');
INSERT INTO `ms_addresses_pref` VALUES ('1493', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '神埼市', '41');
INSERT INTO `ms_addresses_pref` VALUES ('1494', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '神埼郡吉野ヶ里町', '41');
INSERT INTO `ms_addresses_pref` VALUES ('1495', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '武雄市', '41');
INSERT INTO `ms_addresses_pref` VALUES ('1496', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '嬉野市', '41');
INSERT INTO `ms_addresses_pref` VALUES ('1497', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '西松浦郡有田町', '41');
INSERT INTO `ms_addresses_pref` VALUES ('1498', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '小城市', '41');
INSERT INTO `ms_addresses_pref` VALUES ('1499', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '多久市', '41');
INSERT INTO `ms_addresses_pref` VALUES ('1500', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '唐津市', '41');
INSERT INTO `ms_addresses_pref` VALUES ('1501', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '東松浦郡玄海町', '41');
INSERT INTO `ms_addresses_pref` VALUES ('1502', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '伊万里市', '41');
INSERT INTO `ms_addresses_pref` VALUES ('1503', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '松浦市', '42');
INSERT INTO `ms_addresses_pref` VALUES ('1504', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '三養基郡上峰町', '41');
INSERT INTO `ms_addresses_pref` VALUES ('1505', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '杵島郡白石町', '41');
INSERT INTO `ms_addresses_pref` VALUES ('1506', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '杵島郡江北町', '41');
INSERT INTO `ms_addresses_pref` VALUES ('1507', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '鹿島市', '41');
INSERT INTO `ms_addresses_pref` VALUES ('1508', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '藤津郡太良町', '41');
INSERT INTO `ms_addresses_pref` VALUES ('1509', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '杵島郡大町町', '41');
INSERT INTO `ms_addresses_pref` VALUES ('1510', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '長崎市', '42');
INSERT INTO `ms_addresses_pref` VALUES ('1511', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '阿寒郡鶴居村', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1512', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '西彼杵郡長与町', '42');
INSERT INTO `ms_addresses_pref` VALUES ('1513', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '西彼杵郡時津町', '42');
INSERT INTO `ms_addresses_pref` VALUES ('1514', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '西海市', '42');
INSERT INTO `ms_addresses_pref` VALUES ('1515', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '川上郡標茶町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1516', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '釧路郡釧路町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1517', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '五島市', '42');
INSERT INTO `ms_addresses_pref` VALUES ('1518', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '南松浦郡新上五島町', '42');
INSERT INTO `ms_addresses_pref` VALUES ('1519', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '諫早市', '42');
INSERT INTO `ms_addresses_pref` VALUES ('1520', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '雲仙市', '42');
INSERT INTO `ms_addresses_pref` VALUES ('1521', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '島原市', '42');
INSERT INTO `ms_addresses_pref` VALUES ('1522', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '大村市', '42');
INSERT INTO `ms_addresses_pref` VALUES ('1523', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '佐世保市', '42');
INSERT INTO `ms_addresses_pref` VALUES ('1524', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '北松浦郡佐々町', '42');
INSERT INTO `ms_addresses_pref` VALUES ('1525', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '北松浦郡小値賀町', '42');
INSERT INTO `ms_addresses_pref` VALUES ('1526', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '南島原市', '42');
INSERT INTO `ms_addresses_pref` VALUES ('1527', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '東彼杵郡川棚町', '42');
INSERT INTO `ms_addresses_pref` VALUES ('1528', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '東彼杵郡波佐見町', '42');
INSERT INTO `ms_addresses_pref` VALUES ('1529', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '東彼杵郡東彼杵町', '42');
INSERT INTO `ms_addresses_pref` VALUES ('1530', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '平戸市', '42');
INSERT INTO `ms_addresses_pref` VALUES ('1531', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '北松浦郡江迎町', '42');
INSERT INTO `ms_addresses_pref` VALUES ('1532', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '北松浦郡鹿町町', '42');
INSERT INTO `ms_addresses_pref` VALUES ('1533', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '熊本市', '43');
INSERT INTO `ms_addresses_pref` VALUES ('1534', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '根室市', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1535', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '厚岸郡浜中町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1536', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '野付郡別海町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1537', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '標津郡中標津町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1538', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '鹿本郡植木町', '43');
INSERT INTO `ms_addresses_pref` VALUES ('1539', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '山鹿市', '43');
INSERT INTO `ms_addresses_pref` VALUES ('1540', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '玉名郡南関町', '43');
INSERT INTO `ms_addresses_pref` VALUES ('1541', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '玉名郡和水町', '43');
INSERT INTO `ms_addresses_pref` VALUES ('1542', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '合志市', '43');
INSERT INTO `ms_addresses_pref` VALUES ('1543', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '菊池市', '43');
INSERT INTO `ms_addresses_pref` VALUES ('1544', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '上益城郡益城町', '43');
INSERT INTO `ms_addresses_pref` VALUES ('1545', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '阿蘇郡西原村', '43');
INSERT INTO `ms_addresses_pref` VALUES ('1546', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '上益城郡嘉島町', '43');
INSERT INTO `ms_addresses_pref` VALUES ('1547', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '上益城郡御船町', '43');
INSERT INTO `ms_addresses_pref` VALUES ('1548', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '上益城郡甲佐町', '43');
INSERT INTO `ms_addresses_pref` VALUES ('1549', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '上益城郡山都町', '43');
INSERT INTO `ms_addresses_pref` VALUES ('1550', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '下益城郡城南町', '43');
INSERT INTO `ms_addresses_pref` VALUES ('1551', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '宇城市', '43');
INSERT INTO `ms_addresses_pref` VALUES ('1552', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '下益城郡美里町', '43');
INSERT INTO `ms_addresses_pref` VALUES ('1553', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '標津郡標津町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1554', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '玉名市', '43');
INSERT INTO `ms_addresses_pref` VALUES ('1555', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '上天草市', '43');
INSERT INTO `ms_addresses_pref` VALUES ('1556', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '天草市', '43');
INSERT INTO `ms_addresses_pref` VALUES ('1557', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '目梨郡羅臼町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1558', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '天草郡苓北町', '43');
INSERT INTO `ms_addresses_pref` VALUES ('1559', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '荒尾市', '43');
INSERT INTO `ms_addresses_pref` VALUES ('1560', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '八代市', '43');
INSERT INTO `ms_addresses_pref` VALUES ('1561', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '水俣市', '43');
INSERT INTO `ms_addresses_pref` VALUES ('1562', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '人吉市', '43');
INSERT INTO `ms_addresses_pref` VALUES ('1563', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '球磨郡相良村', '43');
INSERT INTO `ms_addresses_pref` VALUES ('1564', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '球磨郡山江村', '43');
INSERT INTO `ms_addresses_pref` VALUES ('1565', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '球磨郡五木村', '43');
INSERT INTO `ms_addresses_pref` VALUES ('1566', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '球磨郡錦町', '43');
INSERT INTO `ms_addresses_pref` VALUES ('1567', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '球磨郡あさぎり町', '43');
INSERT INTO `ms_addresses_pref` VALUES ('1568', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '球磨郡多良木町', '43');
INSERT INTO `ms_addresses_pref` VALUES ('1569', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '球磨郡湯前町', '43');
INSERT INTO `ms_addresses_pref` VALUES ('1570', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '球磨郡水上村', '43');
INSERT INTO `ms_addresses_pref` VALUES ('1571', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '玉名郡長洲町', '43');
INSERT INTO `ms_addresses_pref` VALUES ('1572', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '玉名郡玉東町', '43');
INSERT INTO `ms_addresses_pref` VALUES ('1573', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '宇土市', '43');
INSERT INTO `ms_addresses_pref` VALUES ('1574', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '菊池郡菊陽町', '43');
INSERT INTO `ms_addresses_pref` VALUES ('1575', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '菊池郡大津町', '43');
INSERT INTO `ms_addresses_pref` VALUES ('1576', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '阿蘇郡南阿蘇村', '43');
INSERT INTO `ms_addresses_pref` VALUES ('1577', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '阿蘇郡高森町', '43');
INSERT INTO `ms_addresses_pref` VALUES ('1578', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '阿蘇市', '43');
INSERT INTO `ms_addresses_pref` VALUES ('1579', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '阿蘇郡南小国町', '43');
INSERT INTO `ms_addresses_pref` VALUES ('1580', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '阿蘇郡小国町', '43');
INSERT INTO `ms_addresses_pref` VALUES ('1581', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '阿蘇郡産山村', '43');
INSERT INTO `ms_addresses_pref` VALUES ('1582', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '八代郡氷川町', '43');
INSERT INTO `ms_addresses_pref` VALUES ('1583', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '葦北郡芦北町', '43');
INSERT INTO `ms_addresses_pref` VALUES ('1584', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '葦北郡津奈木町', '43');
INSERT INTO `ms_addresses_pref` VALUES ('1585', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '球磨郡球磨村', '43');
INSERT INTO `ms_addresses_pref` VALUES ('1586', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '大分市', '44');
INSERT INTO `ms_addresses_pref` VALUES ('1587', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '築上郡吉富町', '40');
INSERT INTO `ms_addresses_pref` VALUES ('1588', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '中津市', '44');
INSERT INTO `ms_addresses_pref` VALUES ('1589', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '築上郡上毛町', '40');
INSERT INTO `ms_addresses_pref` VALUES ('1590', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '宇佐市', '44');
INSERT INTO `ms_addresses_pref` VALUES ('1591', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '豊後高田市', '44');
INSERT INTO `ms_addresses_pref` VALUES ('1592', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '国東市', '44');
INSERT INTO `ms_addresses_pref` VALUES ('1593', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '東国東郡姫島村', '44');
INSERT INTO `ms_addresses_pref` VALUES ('1594', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '杵築市', '44');
INSERT INTO `ms_addresses_pref` VALUES ('1595', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '別府市', '44');
INSERT INTO `ms_addresses_pref` VALUES ('1596', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '臼杵市', '44');
INSERT INTO `ms_addresses_pref` VALUES ('1597', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '佐伯市', '44');
INSERT INTO `ms_addresses_pref` VALUES ('1598', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '竹田市', '44');
INSERT INTO `ms_addresses_pref` VALUES ('1599', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '速見郡日出町', '44');
INSERT INTO `ms_addresses_pref` VALUES ('1600', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '津久見市', '44');
INSERT INTO `ms_addresses_pref` VALUES ('1601', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '玖珠郡玖珠町', '44');
INSERT INTO `ms_addresses_pref` VALUES ('1602', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '玖珠郡九重町', '44');
INSERT INTO `ms_addresses_pref` VALUES ('1603', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '由布市', '44');
INSERT INTO `ms_addresses_pref` VALUES ('1604', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '豊後大野市', '44');
INSERT INTO `ms_addresses_pref` VALUES ('1605', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '宮崎市', '45');
INSERT INTO `ms_addresses_pref` VALUES ('1606', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '西都市', '45');
INSERT INTO `ms_addresses_pref` VALUES ('1607', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '東諸県郡国富町', '45');
INSERT INTO `ms_addresses_pref` VALUES ('1608', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '東諸県郡綾町', '45');
INSERT INTO `ms_addresses_pref` VALUES ('1609', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '十勝郡浦幌町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1610', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '都城市', '45');
INSERT INTO `ms_addresses_pref` VALUES ('1611', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '白糠郡白糠町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1612', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '厚岸郡厚岸町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1613', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '児湯郡西米良村', '45');
INSERT INTO `ms_addresses_pref` VALUES ('1614', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '延岡市', '45');
INSERT INTO `ms_addresses_pref` VALUES ('1615', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '西臼杵郡日之影町', '45');
INSERT INTO `ms_addresses_pref` VALUES ('1616', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '西臼杵郡高千穂町', '45');
INSERT INTO `ms_addresses_pref` VALUES ('1617', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '西臼杵郡五ヶ瀬町', '45');
INSERT INTO `ms_addresses_pref` VALUES ('1618', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '日向市', '45');
INSERT INTO `ms_addresses_pref` VALUES ('1619', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '東臼杵郡美郷町', '45');
INSERT INTO `ms_addresses_pref` VALUES ('1620', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '東臼杵郡椎葉村', '45');
INSERT INTO `ms_addresses_pref` VALUES ('1621', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '東臼杵郡諸塚村', '45');
INSERT INTO `ms_addresses_pref` VALUES ('1622', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '川上郡弟子屈町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1623', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '児湯郡高鍋町', '45');
INSERT INTO `ms_addresses_pref` VALUES ('1624', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '児湯郡木城町', '45');
INSERT INTO `ms_addresses_pref` VALUES ('1625', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '小林市', '45');
INSERT INTO `ms_addresses_pref` VALUES ('1626', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '西諸県郡野尻町', '45');
INSERT INTO `ms_addresses_pref` VALUES ('1627', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '日南市', '45');
INSERT INTO `ms_addresses_pref` VALUES ('1628', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '串間市', '45');
INSERT INTO `ms_addresses_pref` VALUES ('1629', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '東臼杵郡門川町', '45');
INSERT INTO `ms_addresses_pref` VALUES ('1630', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '児湯郡都農町', '45');
INSERT INTO `ms_addresses_pref` VALUES ('1631', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '児湯郡川南町', '45');
INSERT INTO `ms_addresses_pref` VALUES ('1632', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '児湯郡新富町', '45');
INSERT INTO `ms_addresses_pref` VALUES ('1633', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '宮崎郡清武町', '45');
INSERT INTO `ms_addresses_pref` VALUES ('1634', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '北諸県郡三股町', '45');
INSERT INTO `ms_addresses_pref` VALUES ('1635', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', 'えびの市', '45');
INSERT INTO `ms_addresses_pref` VALUES ('1636', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '西諸県郡高原町', '45');
INSERT INTO `ms_addresses_pref` VALUES ('1637', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '鹿児島市', '46');
INSERT INTO `ms_addresses_pref` VALUES ('1638', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '鹿児島郡三島村', '46');
INSERT INTO `ms_addresses_pref` VALUES ('1639', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '上川郡清水町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1640', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '中川郡幕別町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1641', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '指宿市', '46');
INSERT INTO `ms_addresses_pref` VALUES ('1642', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '南九州市', '46');
INSERT INTO `ms_addresses_pref` VALUES ('1643', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '垂水市', '46');
INSERT INTO `ms_addresses_pref` VALUES ('1644', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '鹿屋市', '46');
INSERT INTO `ms_addresses_pref` VALUES ('1645', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '河西郡中札内村', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1646', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '西之表市', '46');
INSERT INTO `ms_addresses_pref` VALUES ('1647', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '熊毛郡中種子町', '46');
INSERT INTO `ms_addresses_pref` VALUES ('1648', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '熊毛郡南種子町', '46');
INSERT INTO `ms_addresses_pref` VALUES ('1649', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '熊毛郡屋久島町', '46');
INSERT INTO `ms_addresses_pref` VALUES ('1650', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '河西郡更別村', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1651', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '鹿児島郡十島村', '46');
INSERT INTO `ms_addresses_pref` VALUES ('1652', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '大島郡喜界町', '46');
INSERT INTO `ms_addresses_pref` VALUES ('1653', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '大島郡徳之島町', '46');
INSERT INTO `ms_addresses_pref` VALUES ('1654', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '大島郡天城町', '46');
INSERT INTO `ms_addresses_pref` VALUES ('1655', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '大島郡伊仙町', '46');
INSERT INTO `ms_addresses_pref` VALUES ('1656', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '広尾郡大樹町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1657', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '大島郡和泊町', '46');
INSERT INTO `ms_addresses_pref` VALUES ('1658', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '大島郡知名町', '46');
INSERT INTO `ms_addresses_pref` VALUES ('1659', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '大島郡与論町', '46');
INSERT INTO `ms_addresses_pref` VALUES ('1660', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '広尾郡広尾町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1661', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '肝属郡肝付町', '46');
INSERT INTO `ms_addresses_pref` VALUES ('1662', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '肝属郡東串良町', '46');
INSERT INTO `ms_addresses_pref` VALUES ('1663', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '肝属郡錦江町', '46');
INSERT INTO `ms_addresses_pref` VALUES ('1664', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '肝属郡南大隅町', '46');
INSERT INTO `ms_addresses_pref` VALUES ('1665', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '中川郡本別町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1666', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '足寄郡足寄町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1667', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '奄美市', '46');
INSERT INTO `ms_addresses_pref` VALUES ('1668', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '大島郡龍郷町', '46');
INSERT INTO `ms_addresses_pref` VALUES ('1669', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '大島郡瀬戸内町', '46');
INSERT INTO `ms_addresses_pref` VALUES ('1670', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '足寄郡陸別町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1671', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '大島郡大和村', '46');
INSERT INTO `ms_addresses_pref` VALUES ('1672', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '大島郡宇検村', '46');
INSERT INTO `ms_addresses_pref` VALUES ('1673', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '薩摩川内市', '46');
INSERT INTO `ms_addresses_pref` VALUES ('1674', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '薩摩郡さつま町', '46');
INSERT INTO `ms_addresses_pref` VALUES ('1675', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '中川郡豊頃町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1676', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '伊佐市', '46');
INSERT INTO `ms_addresses_pref` VALUES ('1677', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', 'いちき串木野市', '46');
INSERT INTO `ms_addresses_pref` VALUES ('1678', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '南さつま市', '46');
INSERT INTO `ms_addresses_pref` VALUES ('1679', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '枕崎市', '46');
INSERT INTO `ms_addresses_pref` VALUES ('1680', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '出水市', '46');
INSERT INTO `ms_addresses_pref` VALUES ('1681', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '阿久根市', '46');
INSERT INTO `ms_addresses_pref` VALUES ('1682', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '出水郡長島町', '46');
INSERT INTO `ms_addresses_pref` VALUES ('1683', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '日置市', '46');
INSERT INTO `ms_addresses_pref` VALUES ('1684', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '曽於市', '46');
INSERT INTO `ms_addresses_pref` VALUES ('1685', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '霧島市', '46');
INSERT INTO `ms_addresses_pref` VALUES ('1686', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '姶良郡加治木町', '46');
INSERT INTO `ms_addresses_pref` VALUES ('1687', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '姶良郡蒲生町', '46');
INSERT INTO `ms_addresses_pref` VALUES ('1688', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '姶良郡姶良町', '46');
INSERT INTO `ms_addresses_pref` VALUES ('1689', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '姶良郡湧水町', '46');
INSERT INTO `ms_addresses_pref` VALUES ('1690', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '志布志市', '46');
INSERT INTO `ms_addresses_pref` VALUES ('1691', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '曽於郡大崎町', '46');
INSERT INTO `ms_addresses_pref` VALUES ('1692', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '北見市', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1693', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '那覇市', '47');
INSERT INTO `ms_addresses_pref` VALUES ('1694', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '豊見城市', '47');
INSERT INTO `ms_addresses_pref` VALUES ('1695', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '糸満市', '47');
INSERT INTO `ms_addresses_pref` VALUES ('1696', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '島尻郡八重瀬町', '47');
INSERT INTO `ms_addresses_pref` VALUES ('1697', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '南城市', '47');
INSERT INTO `ms_addresses_pref` VALUES ('1698', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '島尻郡南風原町', '47');
INSERT INTO `ms_addresses_pref` VALUES ('1699', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '島尻郡与那原町', '47');
INSERT INTO `ms_addresses_pref` VALUES ('1700', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '浦添市', '47');
INSERT INTO `ms_addresses_pref` VALUES ('1701', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '宜野湾市', '47');
INSERT INTO `ms_addresses_pref` VALUES ('1702', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '中頭郡北中城村', '47');
INSERT INTO `ms_addresses_pref` VALUES ('1703', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '中頭郡中城村', '47');
INSERT INTO `ms_addresses_pref` VALUES ('1704', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '島尻郡久米島町', '47');
INSERT INTO `ms_addresses_pref` VALUES ('1705', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '島尻郡座間味村', '47');
INSERT INTO `ms_addresses_pref` VALUES ('1706', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '島尻郡渡嘉敷村', '47');
INSERT INTO `ms_addresses_pref` VALUES ('1707', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '島尻郡渡名喜村', '47');
INSERT INTO `ms_addresses_pref` VALUES ('1708', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '島尻郡粟国村', '47');
INSERT INTO `ms_addresses_pref` VALUES ('1709', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '島尻郡南大東村', '47');
INSERT INTO `ms_addresses_pref` VALUES ('1710', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '島尻郡北大東村', '47');
INSERT INTO `ms_addresses_pref` VALUES ('1711', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '中頭郡西原町', '47');
INSERT INTO `ms_addresses_pref` VALUES ('1712', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '沖縄市', '47');
INSERT INTO `ms_addresses_pref` VALUES ('1713', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '中頭郡北谷町', '47');
INSERT INTO `ms_addresses_pref` VALUES ('1714', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '中頭郡嘉手納町', '47');
INSERT INTO `ms_addresses_pref` VALUES ('1715', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '中頭郡読谷村', '47');
INSERT INTO `ms_addresses_pref` VALUES ('1716', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '国頭郡恩納村', '47');
INSERT INTO `ms_addresses_pref` VALUES ('1717', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', 'うるま市', '47');
INSERT INTO `ms_addresses_pref` VALUES ('1718', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '国頭郡金武町', '47');
INSERT INTO `ms_addresses_pref` VALUES ('1719', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '国頭郡宜野座村', '47');
INSERT INTO `ms_addresses_pref` VALUES ('1720', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '名護市', '47');
INSERT INTO `ms_addresses_pref` VALUES ('1721', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '国頭郡本部町', '47');
INSERT INTO `ms_addresses_pref` VALUES ('1722', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '国頭郡今帰仁村', '47');
INSERT INTO `ms_addresses_pref` VALUES ('1723', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '国頭郡伊江村', '47');
INSERT INTO `ms_addresses_pref` VALUES ('1724', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '島尻郡伊是名村', '47');
INSERT INTO `ms_addresses_pref` VALUES ('1725', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '島尻郡伊平屋村', '47');
INSERT INTO `ms_addresses_pref` VALUES ('1726', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '国頭郡東村', '47');
INSERT INTO `ms_addresses_pref` VALUES ('1727', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '国頭郡大宜味村', '47');
INSERT INTO `ms_addresses_pref` VALUES ('1728', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '国頭郡国頭村', '47');
INSERT INTO `ms_addresses_pref` VALUES ('1729', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '宮古島市', '47');
INSERT INTO `ms_addresses_pref` VALUES ('1730', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '宮古郡多良間村', '47');
INSERT INTO `ms_addresses_pref` VALUES ('1731', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '石垣市', '47');
INSERT INTO `ms_addresses_pref` VALUES ('1732', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '八重山郡竹富町', '47');
INSERT INTO `ms_addresses_pref` VALUES ('1733', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '八重山郡与那国町', '47');
INSERT INTO `ms_addresses_pref` VALUES ('1734', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '福井市', '18');
INSERT INTO `ms_addresses_pref` VALUES ('1735', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '坂井市', '18');
INSERT INTO `ms_addresses_pref` VALUES ('1736', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '吉田郡永平寺町', '18');
INSERT INTO `ms_addresses_pref` VALUES ('1737', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '今立郡池田町', '18');
INSERT INTO `ms_addresses_pref` VALUES ('1738', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', 'あわら市', '18');
INSERT INTO `ms_addresses_pref` VALUES ('1739', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '常呂郡佐呂間町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1740', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '勝山市', '18');
INSERT INTO `ms_addresses_pref` VALUES ('1741', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '大野市', '18');
INSERT INTO `ms_addresses_pref` VALUES ('1742', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '敦賀市', '18');
INSERT INTO `ms_addresses_pref` VALUES ('1743', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '越前市', '18');
INSERT INTO `ms_addresses_pref` VALUES ('1744', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '南条郡南越前町', '18');
INSERT INTO `ms_addresses_pref` VALUES ('1745', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '鯖江市', '18');
INSERT INTO `ms_addresses_pref` VALUES ('1746', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '丹生郡越前町', '18');
INSERT INTO `ms_addresses_pref` VALUES ('1747', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '小浜市', '18');
INSERT INTO `ms_addresses_pref` VALUES ('1748', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '大飯郡おおい町', '18');
INSERT INTO `ms_addresses_pref` VALUES ('1749', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '三方郡美浜町', '18');
INSERT INTO `ms_addresses_pref` VALUES ('1750', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '三方上中郡若狭町', '18');
INSERT INTO `ms_addresses_pref` VALUES ('1751', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '大飯郡高浜町', '18');
INSERT INTO `ms_addresses_pref` VALUES ('1752', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '網走郡美幌町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1753', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '金沢市', '17');
INSERT INTO `ms_addresses_pref` VALUES ('1754', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '河北郡内灘町', '17');
INSERT INTO `ms_addresses_pref` VALUES ('1755', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '網走郡津別町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1756', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '白山市', '17');
INSERT INTO `ms_addresses_pref` VALUES ('1757', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '石川郡野々市町', '17');
INSERT INTO `ms_addresses_pref` VALUES ('1758', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '加賀市', '17');
INSERT INTO `ms_addresses_pref` VALUES ('1759', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '小松市', '17');
INSERT INTO `ms_addresses_pref` VALUES ('1760', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '能美市', '17');
INSERT INTO `ms_addresses_pref` VALUES ('1761', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '能美郡川北町', '17');
INSERT INTO `ms_addresses_pref` VALUES ('1762', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '羽咋市', '17');
INSERT INTO `ms_addresses_pref` VALUES ('1763', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '羽咋郡志賀町', '17');
INSERT INTO `ms_addresses_pref` VALUES ('1764', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '七尾市', '17');
INSERT INTO `ms_addresses_pref` VALUES ('1765', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '鳳珠郡穴水町', '17');
INSERT INTO `ms_addresses_pref` VALUES ('1766', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '鳳珠郡能登町', '17');
INSERT INTO `ms_addresses_pref` VALUES ('1767', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '珠洲市', '17');
INSERT INTO `ms_addresses_pref` VALUES ('1768', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '輪島市', '17');
INSERT INTO `ms_addresses_pref` VALUES ('1769', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '河北郡津幡町', '17');
INSERT INTO `ms_addresses_pref` VALUES ('1770', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', 'かほく市', '17');
INSERT INTO `ms_addresses_pref` VALUES ('1771', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '羽咋郡宝達志水町', '17');
INSERT INTO `ms_addresses_pref` VALUES ('1772', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '鹿島郡中能登町', '17');
INSERT INTO `ms_addresses_pref` VALUES ('1773', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '網走市', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1774', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '富山市', '16');
INSERT INTO `ms_addresses_pref` VALUES ('1775', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '中新川郡舟橋村', '16');
INSERT INTO `ms_addresses_pref` VALUES ('1776', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '中新川郡立山町', '16');
INSERT INTO `ms_addresses_pref` VALUES ('1777', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '中新川郡上市町', '16');
INSERT INTO `ms_addresses_pref` VALUES ('1778', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '紋別郡湧別町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1779', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '小矢部市', '16');
INSERT INTO `ms_addresses_pref` VALUES ('1780', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '南砺市', '16');
INSERT INTO `ms_addresses_pref` VALUES ('1781', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '砺波市', '16');
INSERT INTO `ms_addresses_pref` VALUES ('1782', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '高岡市', '16');
INSERT INTO `ms_addresses_pref` VALUES ('1783', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '射水市', '16');
INSERT INTO `ms_addresses_pref` VALUES ('1784', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '氷見市', '16');
INSERT INTO `ms_addresses_pref` VALUES ('1785', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '滑川市', '16');
INSERT INTO `ms_addresses_pref` VALUES ('1786', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '魚津市', '16');
INSERT INTO `ms_addresses_pref` VALUES ('1787', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '黒部市', '16');
INSERT INTO `ms_addresses_pref` VALUES ('1788', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '下新川郡入善町', '16');
INSERT INTO `ms_addresses_pref` VALUES ('1789', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '下新川郡朝日町', '16');
INSERT INTO `ms_addresses_pref` VALUES ('1790', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '紋別市', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1791', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '長岡市', '15');
INSERT INTO `ms_addresses_pref` VALUES ('1792', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '糸魚川市', '15');
INSERT INTO `ms_addresses_pref` VALUES ('1793', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '上越市', '15');
INSERT INTO `ms_addresses_pref` VALUES ('1794', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '十日町市', '15');
INSERT INTO `ms_addresses_pref` VALUES ('1795', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '柏崎市', '15');
INSERT INTO `ms_addresses_pref` VALUES ('1796', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '刈羽郡刈羽村', '15');
INSERT INTO `ms_addresses_pref` VALUES ('1797', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '魚沼市', '15');
INSERT INTO `ms_addresses_pref` VALUES ('1798', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '小千谷市', '15');
INSERT INTO `ms_addresses_pref` VALUES ('1799', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '三島郡出雲崎町', '15');
INSERT INTO `ms_addresses_pref` VALUES ('1800', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '南魚沼郡湯沢町', '15');
INSERT INTO `ms_addresses_pref` VALUES ('1801', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '南魚沼市', '15');
INSERT INTO `ms_addresses_pref` VALUES ('1802', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '北魚沼郡川口町', '15');
INSERT INTO `ms_addresses_pref` VALUES ('1803', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '中魚沼郡津南町', '15');
INSERT INTO `ms_addresses_pref` VALUES ('1804', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '士別市', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1805', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '新潟市北区', '15');
INSERT INTO `ms_addresses_pref` VALUES ('1806', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '新潟市東区', '15');
INSERT INTO `ms_addresses_pref` VALUES ('1807', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '新潟市中央区', '15');
INSERT INTO `ms_addresses_pref` VALUES ('1808', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '新潟市江南区', '15');
INSERT INTO `ms_addresses_pref` VALUES ('1809', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '新潟市西区', '15');
INSERT INTO `ms_addresses_pref` VALUES ('1810', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '新潟市西蒲区', '15');
INSERT INTO `ms_addresses_pref` VALUES ('1811', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '新潟市南区', '15');
INSERT INTO `ms_addresses_pref` VALUES ('1812', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '佐渡市', '15');
INSERT INTO `ms_addresses_pref` VALUES ('1813', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '見附市', '15');
INSERT INTO `ms_addresses_pref` VALUES ('1814', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '三条市', '15');
INSERT INTO `ms_addresses_pref` VALUES ('1815', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '新潟市秋葉区', '15');
INSERT INTO `ms_addresses_pref` VALUES ('1816', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '新発田市', '15');
INSERT INTO `ms_addresses_pref` VALUES ('1817', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '北蒲原郡聖籠町', '15');
INSERT INTO `ms_addresses_pref` VALUES ('1818', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '村上市', '15');
INSERT INTO `ms_addresses_pref` VALUES ('1819', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '岩船郡粟島浦村', '15');
INSERT INTO `ms_addresses_pref` VALUES ('1820', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '燕市', '15');
INSERT INTO `ms_addresses_pref` VALUES ('1821', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '西蒲原郡弥彦村', '15');
INSERT INTO `ms_addresses_pref` VALUES ('1822', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '加茂市', '15');
INSERT INTO `ms_addresses_pref` VALUES ('1823', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '南蒲原郡田上町', '15');
INSERT INTO `ms_addresses_pref` VALUES ('1824', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '五泉市', '15');
INSERT INTO `ms_addresses_pref` VALUES ('1825', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '阿賀野市', '15');
INSERT INTO `ms_addresses_pref` VALUES ('1826', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '胎内市', '15');
INSERT INTO `ms_addresses_pref` VALUES ('1827', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '岩船郡関川村', '15');
INSERT INTO `ms_addresses_pref` VALUES ('1828', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '東蒲原郡阿賀町', '15');
INSERT INTO `ms_addresses_pref` VALUES ('1829', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '名寄市', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1830', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '福島市', '07');
INSERT INTO `ms_addresses_pref` VALUES ('1831', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '伊達市', '07');
INSERT INTO `ms_addresses_pref` VALUES ('1832', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '伊達郡川俣町', '07');
INSERT INTO `ms_addresses_pref` VALUES ('1833', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '相馬郡飯舘村', '07');
INSERT INTO `ms_addresses_pref` VALUES ('1834', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '白河市', '07');
INSERT INTO `ms_addresses_pref` VALUES ('1835', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '西白河郡西郷村', '07');
INSERT INTO `ms_addresses_pref` VALUES ('1836', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '西白河郡中島村', '07');
INSERT INTO `ms_addresses_pref` VALUES ('1837', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '須賀川市', '07');
INSERT INTO `ms_addresses_pref` VALUES ('1838', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '岩瀬郡天栄村', '07');
INSERT INTO `ms_addresses_pref` VALUES ('1839', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '郡山市', '07');
INSERT INTO `ms_addresses_pref` VALUES ('1840', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '田村郡小野町', '07');
INSERT INTO `ms_addresses_pref` VALUES ('1841', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '田村市', '07');
INSERT INTO `ms_addresses_pref` VALUES ('1842', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '東白川郡矢祭町', '07');
INSERT INTO `ms_addresses_pref` VALUES ('1843', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '東白川郡塙町', '07');
INSERT INTO `ms_addresses_pref` VALUES ('1844', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '東白川郡鮫川村', '07');
INSERT INTO `ms_addresses_pref` VALUES ('1845', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '東白川郡棚倉町', '07');
INSERT INTO `ms_addresses_pref` VALUES ('1846', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '石川郡浅川町', '07');
INSERT INTO `ms_addresses_pref` VALUES ('1847', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '石川郡玉川村', '07');
INSERT INTO `ms_addresses_pref` VALUES ('1848', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '田村郡三春町', '07');
INSERT INTO `ms_addresses_pref` VALUES ('1849', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '石川郡石川町', '07');
INSERT INTO `ms_addresses_pref` VALUES ('1850', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '石川郡平田村', '07');
INSERT INTO `ms_addresses_pref` VALUES ('1851', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '石川郡古殿町', '07');
INSERT INTO `ms_addresses_pref` VALUES ('1852', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '二本松市', '07');
INSERT INTO `ms_addresses_pref` VALUES ('1853', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '安達郡大玉村', '07');
INSERT INTO `ms_addresses_pref` VALUES ('1854', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '会津若松市', '07');
INSERT INTO `ms_addresses_pref` VALUES ('1855', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '喜多方市', '07');
INSERT INTO `ms_addresses_pref` VALUES ('1856', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '耶麻郡北塩原村', '07');
INSERT INTO `ms_addresses_pref` VALUES ('1857', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '南会津郡南会津町', '07');
INSERT INTO `ms_addresses_pref` VALUES ('1858', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '南会津郡檜枝岐村', '07');
INSERT INTO `ms_addresses_pref` VALUES ('1859', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '大沼郡金山町', '07');
INSERT INTO `ms_addresses_pref` VALUES ('1860', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '大沼郡昭和村', '07');
INSERT INTO `ms_addresses_pref` VALUES ('1861', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '南会津郡只見町', '07');
INSERT INTO `ms_addresses_pref` VALUES ('1862', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '西白河郡泉崎村', '07');
INSERT INTO `ms_addresses_pref` VALUES ('1863', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '西白河郡矢吹町', '07');
INSERT INTO `ms_addresses_pref` VALUES ('1864', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '岩瀬郡鏡石町', '07');
INSERT INTO `ms_addresses_pref` VALUES ('1865', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '本宮市', '07');
INSERT INTO `ms_addresses_pref` VALUES ('1866', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '伊達郡桑折町', '07');
INSERT INTO `ms_addresses_pref` VALUES ('1867', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '伊達郡国見町', '07');
INSERT INTO `ms_addresses_pref` VALUES ('1868', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '耶麻郡猪苗代町', '07');
INSERT INTO `ms_addresses_pref` VALUES ('1869', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '耶麻郡磐梯町', '07');
INSERT INTO `ms_addresses_pref` VALUES ('1870', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '河沼郡湯川村', '07');
INSERT INTO `ms_addresses_pref` VALUES ('1871', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '耶麻郡西会津町', '07');
INSERT INTO `ms_addresses_pref` VALUES ('1872', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '南会津郡下郷町', '07');
INSERT INTO `ms_addresses_pref` VALUES ('1873', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '大沼郡会津美里町', '07');
INSERT INTO `ms_addresses_pref` VALUES ('1874', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '河沼郡会津坂下町', '07');
INSERT INTO `ms_addresses_pref` VALUES ('1875', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '河沼郡柳津町', '07');
INSERT INTO `ms_addresses_pref` VALUES ('1876', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '大沼郡三島町', '07');
INSERT INTO `ms_addresses_pref` VALUES ('1877', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '稚内市', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1878', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', 'いわき市', '07');
INSERT INTO `ms_addresses_pref` VALUES ('1879', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '利尻郡利尻富士町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1880', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '利尻郡利尻町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1881', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '礼文郡礼文町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1882', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '南相馬市', '07');
INSERT INTO `ms_addresses_pref` VALUES ('1883', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '相馬市', '07');
INSERT INTO `ms_addresses_pref` VALUES ('1884', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '双葉郡広野町', '07');
INSERT INTO `ms_addresses_pref` VALUES ('1885', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '双葉郡楢葉町', '07');
INSERT INTO `ms_addresses_pref` VALUES ('1886', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '双葉郡富岡町', '07');
INSERT INTO `ms_addresses_pref` VALUES ('1887', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '双葉郡川内村', '07');
INSERT INTO `ms_addresses_pref` VALUES ('1888', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '双葉郡大熊町', '07');
INSERT INTO `ms_addresses_pref` VALUES ('1889', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '双葉郡双葉町', '07');
INSERT INTO `ms_addresses_pref` VALUES ('1890', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '双葉郡浪江町', '07');
INSERT INTO `ms_addresses_pref` VALUES ('1891', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '双葉郡葛尾村', '07');
INSERT INTO `ms_addresses_pref` VALUES ('1892', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '相馬郡新地町', '07');
INSERT INTO `ms_addresses_pref` VALUES ('1893', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '仙台市青葉区', '04');
INSERT INTO `ms_addresses_pref` VALUES ('1894', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '上川郡和寒町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1895', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '上川郡剣淵町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1896', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '宮城郡利府町', '04');
INSERT INTO `ms_addresses_pref` VALUES ('1897', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '宮城郡松島町', '04');
INSERT INTO `ms_addresses_pref` VALUES ('1898', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '東松島市', '04');
INSERT INTO `ms_addresses_pref` VALUES ('1899', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '仙台市太白区', '04');
INSERT INTO `ms_addresses_pref` VALUES ('1900', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '名取市', '04');
INSERT INTO `ms_addresses_pref` VALUES ('1901', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '角田市', '04');
INSERT INTO `ms_addresses_pref` VALUES ('1902', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '上川郡下川町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1903', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '伊具郡丸森町', '04');
INSERT INTO `ms_addresses_pref` VALUES ('1904', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '仙台市泉区', '04');
INSERT INTO `ms_addresses_pref` VALUES ('1905', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '黒川郡大和町', '04');
INSERT INTO `ms_addresses_pref` VALUES ('1906', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '黒川郡富谷町', '04');
INSERT INTO `ms_addresses_pref` VALUES ('1907', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '黒川郡大郷町', '04');
INSERT INTO `ms_addresses_pref` VALUES ('1908', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '黒川郡大衡村', '04');
INSERT INTO `ms_addresses_pref` VALUES ('1909', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '加美郡色麻町', '04');
INSERT INTO `ms_addresses_pref` VALUES ('1910', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '加美郡加美町', '04');
INSERT INTO `ms_addresses_pref` VALUES ('1911', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '紋別郡西興部村', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1912', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '紋別郡興部町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1913', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '紋別郡雄武町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1914', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '中川郡美深町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1915', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '中川郡音威子府村', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1916', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '中川郡中川町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1917', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '天塩郡幌延町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1918', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '天塩郡天塩町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1919', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '仙台市宮城野区', '04');
INSERT INTO `ms_addresses_pref` VALUES ('1920', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '天塩郡遠別町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1921', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '仙台市若林区', '04');
INSERT INTO `ms_addresses_pref` VALUES ('1922', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '天塩郡豊富町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1923', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '塩竈市', '04');
INSERT INTO `ms_addresses_pref` VALUES ('1924', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '多賀城市', '04');
INSERT INTO `ms_addresses_pref` VALUES ('1925', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '宮城郡七ヶ浜町', '04');
INSERT INTO `ms_addresses_pref` VALUES ('1926', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '枝幸郡中頓別町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1927', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '枝幸郡枝幸町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1928', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '枝幸郡浜頓別町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1929', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '石巻市', '04');
INSERT INTO `ms_addresses_pref` VALUES ('1930', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '登米市', '04');
INSERT INTO `ms_addresses_pref` VALUES ('1931', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '本吉郡南三陸町', '04');
INSERT INTO `ms_addresses_pref` VALUES ('1932', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '宗谷郡猿払村', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1933', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '牡鹿郡女川町', '04');
INSERT INTO `ms_addresses_pref` VALUES ('1934', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '遠田郡美里町', '04');
INSERT INTO `ms_addresses_pref` VALUES ('1935', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '遠田郡涌谷町', '04');
INSERT INTO `ms_addresses_pref` VALUES ('1936', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '大崎市', '04');
INSERT INTO `ms_addresses_pref` VALUES ('1937', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '栗原市', '04');
INSERT INTO `ms_addresses_pref` VALUES ('1938', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '気仙沼市', '04');
INSERT INTO `ms_addresses_pref` VALUES ('1939', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '本吉郡本吉町', '04');
INSERT INTO `ms_addresses_pref` VALUES ('1940', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '白石市', '04');
INSERT INTO `ms_addresses_pref` VALUES ('1941', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '刈田郡七ヶ宿町', '04');
INSERT INTO `ms_addresses_pref` VALUES ('1942', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '刈田郡蔵王町', '04');
INSERT INTO `ms_addresses_pref` VALUES ('1943', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '柴田郡川崎町', '04');
INSERT INTO `ms_addresses_pref` VALUES ('1944', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '柴田郡大河原町', '04');
INSERT INTO `ms_addresses_pref` VALUES ('1945', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '柴田郡村田町', '04');
INSERT INTO `ms_addresses_pref` VALUES ('1946', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '柴田郡柴田町', '04');
INSERT INTO `ms_addresses_pref` VALUES ('1947', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '亘理郡山元町', '04');
INSERT INTO `ms_addresses_pref` VALUES ('1948', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '亘理郡亘理町', '04');
INSERT INTO `ms_addresses_pref` VALUES ('1949', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '岩沼市', '04');
INSERT INTO `ms_addresses_pref` VALUES ('1950', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '山形市', '06');
INSERT INTO `ms_addresses_pref` VALUES ('1951', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '東村山郡山辺町', '06');
INSERT INTO `ms_addresses_pref` VALUES ('1952', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '東村山郡中山町', '06');
INSERT INTO `ms_addresses_pref` VALUES ('1953', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '寒河江市', '06');
INSERT INTO `ms_addresses_pref` VALUES ('1954', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '西村山郡西川町', '06');
INSERT INTO `ms_addresses_pref` VALUES ('1955', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '紋別郡遠軽町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1956', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '西村山郡大江町', '06');
INSERT INTO `ms_addresses_pref` VALUES ('1957', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '西村山郡朝日町', '06');
INSERT INTO `ms_addresses_pref` VALUES ('1958', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '常呂郡置戸町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1959', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '常呂郡訓子府町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1960', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '米沢市', '06');
INSERT INTO `ms_addresses_pref` VALUES ('1961', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '東置賜郡高畠町', '06');
INSERT INTO `ms_addresses_pref` VALUES ('1962', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '南陽市', '06');
INSERT INTO `ms_addresses_pref` VALUES ('1963', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '東置賜郡川西町', '06');
INSERT INTO `ms_addresses_pref` VALUES ('1964', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '西置賜郡白鷹町', '06');
INSERT INTO `ms_addresses_pref` VALUES ('1965', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '網走郡大空町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1966', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '長井市', '06');
INSERT INTO `ms_addresses_pref` VALUES ('1967', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '斜里郡小清水町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1968', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '天童市', '06');
INSERT INTO `ms_addresses_pref` VALUES ('1969', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '斜里郡斜里町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1970', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '斜里郡清里町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1971', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '村山市', '06');
INSERT INTO `ms_addresses_pref` VALUES ('1972', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '紋別郡滝上町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1973', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '新庄市', '06');
INSERT INTO `ms_addresses_pref` VALUES ('1974', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '最上郡大蔵村', '06');
INSERT INTO `ms_addresses_pref` VALUES ('1975', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '紋別郡上湧別町', '01');
INSERT INTO `ms_addresses_pref` VALUES ('1976', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '鶴岡市', '06');
INSERT INTO `ms_addresses_pref` VALUES ('1977', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '東田川郡三川町', '06');
INSERT INTO `ms_addresses_pref` VALUES ('1978', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '酒田市', '06');
INSERT INTO `ms_addresses_pref` VALUES ('1979', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '西置賜郡飯豊町', '06');
INSERT INTO `ms_addresses_pref` VALUES ('1980', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '西置賜郡小国町', '06');
INSERT INTO `ms_addresses_pref` VALUES ('1981', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '上山市', '06');
INSERT INTO `ms_addresses_pref` VALUES ('1982', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '西村山郡河北町', '06');
INSERT INTO `ms_addresses_pref` VALUES ('1983', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '東根市', '06');
INSERT INTO `ms_addresses_pref` VALUES ('1984', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '北村山郡大石田町', '06');
INSERT INTO `ms_addresses_pref` VALUES ('1985', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '尾花沢市', '06');
INSERT INTO `ms_addresses_pref` VALUES ('1986', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '最上郡舟形町', '06');
INSERT INTO `ms_addresses_pref` VALUES ('1987', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '最上郡鮭川村', '06');
INSERT INTO `ms_addresses_pref` VALUES ('1988', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '最上郡真室川町', '06');
INSERT INTO `ms_addresses_pref` VALUES ('1989', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '最上郡金山町', '06');
INSERT INTO `ms_addresses_pref` VALUES ('1990', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '最上郡最上町', '06');
INSERT INTO `ms_addresses_pref` VALUES ('1991', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '最上郡戸沢村', '06');
INSERT INTO `ms_addresses_pref` VALUES ('1992', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '東田川郡庄内町', '06');
INSERT INTO `ms_addresses_pref` VALUES ('1993', 'SYSTEM', '2009-07-14 09:11:12', 'SYSTEM', '2009-07-14 09:11:12', '飽海郡遊佐町', '06');
